/*!
*  filename: ej.treemap.js
*  version : 12.3
*  Copyright Syncfusion Inc. 2001 - 2014. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
*/
(function (fn) {
    typeof define === 'function' && define.amd ? define(["./../common/ej.core","./../common/ej.data"], fn) : fn();
})
(function () {
	
/**
* @fileOverview Plugin to style the Html TreeMap elements
* @copyright Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author &lt;a href="mailto:licensing@syncfusion.com"&gt;Syncfusion Inc&lt;/a&gt;
*/
(function ($, ej, undefined) {
    /**
    * @namespace ej
    * @class ejTreeMap
    * @requires jQuery
    * @requires ej.datavisualization.TreeMap
    * @requires jsrender
    * @requires properties
    * @classdesc The treemap can be easily configured to the DOM element, such as div and can be created with a highly customized look and feel.
    * @example 
    * &lt;div id="container"&gt; <br> 
    * &lt;script&gt;
    * // Create TreeMap
    * $('#container').ejTreeMap(); 	
    * &lt;/script&gt; <br>  
    * &lt;/div&gt;
    */
   
    ej.widget({ "ejTreeMap": "ej.datavisualization.TreeMap" }, {

        validTags: ["div"],

        defaults: {
            /**
            * Specifies the leaf settings of the treemap
            * @default {borderThickness: 1,borderBrush: "white",showLabels: false,labelPath: null,itemTemplate: null}
			* @type {object}
			* @example 
            * //To set datasource API value during initialization 
			*   $("#container").ejTreeMap({leafItemSettings:{ labelPath: "GameName" , showLabels: true, itemTemplate: temp}});
            * @example 
            * //Get or set the datasource API, after initialization:<br>
            *	//Gets the datasource value 
            *   var property =$("#container").data("ejTreeMap").model.leafItemSettings;<br> 
            *	//Sets the datasource value 
            *	$("#container").data("ejTreeMap").model.leafItemSettings= { labelPath: "GameName" , showLabels: true, itemTemplate: temp}; 
            * @memberof ejTreeMap
            * @instance
            */
            leafItemSettings: {
                /**
                * Specifies the border thickness of the leaf item.
                * @default null
			    * @type {object}
			    * @example 
                * //To set borderThickness API value during initialization 
			    *   $("#container").ejTreeMap({leafItemSettings:{ borderThickness: 1}});
                * @example 
                * //Get or set the borderThickness API, after initialization:<br>
                *	//Gets the borderThickness value 
                *   var property =$("#container").data("ejTreeMap").model.leafItemSettings.borderThickness;<br> 
                *	//Sets the borderThickness value 
                *	$("#container").data("ejTreeMap").model.leafItemSettings = { borderThickness: 1}; 
                * @alias ejTreeMap#leafItemSettings->borderThickness
                * @instance
                */
                borderThickness: 1,

                /**
                * Specifies the border bruch color of the leaf item.
                * @default "white"
			    * @type {string}
			    * @example 
                * //To set borderBrush API value during initialization 
			    *   $("#container").ejTreeMap({leafItemSettings:{ borderBrush: "white"}});
                * @example 
                * //Get or set the borderBrush API, after initialization:<br>
                *	//Gets the borderBrush value 
                *   var property =$("#container").data("ejTreeMap").model.leafItemSettings.borderBrush;<br> 
                *	//Sets the borderBrush value 
                *	$("#container").data("ejTreeMap").model.leafItemSettings = { borderBrush: "white"}; 
                * @alias ejTreeMap#leafItemSettings->borderBrush
                * @instance
                */
                borderBrush: "white",

                /**
                * Shows or hides the label of the leaf item.
                * @default "false"
			    * @type {boolean}
			    * @example 
                * //To set showLabels API value during initialization 
			    *   $("#container").ejTreeMap({leafItemSettings:{ showLabels: "false"}});
                * @example 
                * //Get or set the showLabels API, after initialization:<br>
                *	//Gets the showLabels value 
                *   var property =$("#container").data("ejTreeMap").model.leafItemSettings.showLabels;<br> 
                *	//Sets the showLabels value 
                *	$("#container").data("ejTreeMap").model.leafItemSettings = { showLabels: "false"}; 
                * @alias ejTreeMap#leafItemSettings->showLabels
                * @instance
                */
                showLabels: false,

                /**
                * Specifies the label path of the leaf item.
                * @default null
                * @type {string}
                * @example 
                * //To set labelPath API value during initialization 
                *   $("#container").ejTreeMap({leafItemSettings:{ labelPath: "GameName"}});
                * @example 
                * //Get or set the labelPath API, after initialization:<br>
                *	//Gets the labelPath value 
                *   var property =$("#container").data("ejTreeMap").model.leafItemSettings.labelPath;<br> 
                *	//Sets the labelPath value 
                *	$("#container").data("ejTreeMap").model.leafItemSettings = { labelPath: "GameName"}; 
                * @alias ejTreeMap#leafItemSettings->labelPath
                * @instance
                */
                labelPath: null,

                /**
                * Specifies the label template of the leaf item.
                * @default null
			    * @type {string}
			    * @example 
                * //To set itemTemplate API value during initialization 
			    *   $("#container").ejTreeMap({leafItemSettings:{ itemTemplate: "temp"}});
                * @example 
                * //Get or set the itemTemplate API, after initialization:<br>
                *	//Gets the itemTemplate value 
                *   var property =$("#container").data("ejTreeMap").model.leafItemSettings.itemTemplate;<br> 
                *	//Sets the itemTemplate value 
                *	$("#container").data("ejTreeMap").model.leafItemSettings = { itemTemplate: "temp"}; 
                * @alias ejTreeMap#leafItemSettings->itemTemplate
                * @instance
                */
                itemTemplate: null,

                /**
               * Specifies the position of the leaf labels.
               * @default center
               * @type{ej.datavisualization.TreeMap.Position}
               * @example 
               * //To set labelPosition API value during initialization 
               *   $("#container").ejTreeMap({leafItemSettings:{ labelPosition: "center"}});
               * @example 
               * //Get or set the labelPosition API, after initialization:<br>
               *	//Gets the labelPosition value 
               *   var property =$("#container").data("ejTreeMap").model.leafItemSettings.labelPosition;<br> 
               *	//Sets the labelPosition value 
               *	$("#container").data("ejTreeMap").model.leafItemSettings.labelPosition= "topleft"; 
               * @alias ejTreeMap#leafItemSettings->labelPosition
               * @instance
               */
                labelPosition: "center",


               /**
              * Specifies the mode of label visibility
              * @default visible
              * @type{ej.datavisualization.TreeMap.VisibilityMode}
              * @example 
              * //To set labelVisibilityMode API value during initialization 
              *   $("#container").ejTreeMap({leafItemSettings:{ labelVisibilityMode: "visible"}});
              * @example 
              * //Get or set the labelVisibilityMode API, after initialization:<br>
              *	//Gets the labelVisibilityMode value 
              *   var property =$("#container").data("ejTreeMap").model.leafItemSettings.labelVisibilityMode;<br> 
              *	//Sets the labelVisibilityMode value 
              *	$("#container").data("ejTreeMap").model.leafItemSettings.labelVisibilityMode= "visible"; 
              * @alias ejTreeMap#leafItemSettings->labelVisibilityMode
              * @instance
              */
                labelVisibilityMode: "visible"
            },
            /**		
			* Specifies the datasource of the treemap
            * @default null
			* @type {object}
			* @example 
            * //To set datasource API value during initialization 
			*   $("#container").ejTreeMap({datasource:medal_data});
            * @example 
			* //Get or set the datasource API, after initialization:<br>
			*	//Gets the datasource value 
            *   var property =$("#container").data("ejTreeMap").model.datasource;<br> 
            *	//Sets the datasource value 
			*	$("#container").data("ejTreeMap").model.datasource = medal_data; 
			* @memberof ejTreeMap
			* @instance
            */
            dataSource: null,

			/**		
			* Enable/Disable the drillDown for treemap
            * @default false
			* @type {boolean}
			* @example 
            * //To set enableDrillDown API value during initialization 
			*   $("#container").ejTreeMap({enableDrillDown:true});
            * @example 
			* //Get or set the enableDrillDown API, after initialization:<br>
			*	//Gets the enableDrillDown value 
            *   var property =$("#container").data("ejTreeMap").model.enableDrillDown;<br> 
            *	//Sets the enableDrillDown value 
			*	$("#container").data("ejTreeMap").model.enableDrillDown = true; 
			* @memberof ejTreeMap
			* @instance
            */
            enableDrillDown: false,

            /** 
            * specifies the drillDown header color
                 * @default 'null'
                 * @type {string} 
                 * @example  
                 * // Set the drillDownHeaderColor during initialization. 			
                 * 	$("#container").ejTreeMap({drillDownHeaderColor:'#0478c3'});
                * @example 
                * //Get or set the drillDownHeaderColor API, after initialization:<br>
                *	//Gets the drillDownHeaderColor value 
                *   var property =$("#container").data("ejTreeMap").model.drillDownHeaderColor;<br> 
                *	//Sets the drillDownHeaderColor value 
                *	$("#container").data("ejTreeMap").model.drillDownHeaderColor = '#0478c3'; 
                * @memberof ejTreeMap
                * @instance
                 */
            drillDownHeaderColor: null,

            /** 
            * specifies the drillDown selection color
                 * @default '#000000'
                 * @type {string} 
                 * @example  
                 * // Set the drillDownSelectionColor during initialization. 			
                 * 	$("#container").ejTreeMap({drillDownSelectionColor:'#e5e5e5'});
                * @example 
			    * //Get or set the drillDownSelectionColor API, after initialization:<br>
			    *	//Gets the drillDownSelectionColor value 
                *   var property =$("#container").data("ejTreeMap").model.drillDownSelectionColor;<br> 
                *	//Sets the drillDownSelectionColor value 
			    *	$("#container").data("ejTreeMap").model.drillDownSelectionColor = '#000000'; 
			    * @memberof ejTreeMap
			    * @instance
                 */
            drillDownSelectionColor: '#000000',

            /** 
            * Specifies the selection mode of the treemap. Accepted selection mode values are Default and Multiple.
            * @default "default"
			* @type {string}
             * @example  
             * // Set the selection mode during initialization. 			
             * 	$("#container").ejTreeMap({layers: [{ selectionMode:'default' }]})
             * @example 
             * //Get or set the groupSelection mode after initialization:<br>
             *   //Gets the selection mode from treemap.
             *   var property =$("#container").data("ejTreeMap").model.layers[layerIndex].groupSelectionMode;
             *   //Sets the selection mode to treemap.
             *   $("#container").data("ejTreeMap").model.layers[layerIndex].groupSelectionMode  = 'default';
             * @alias ejTreeMap#shapeLayer->groupSelectionMode
             * @instance
             */
            groupSelectionMode : "default",
			
            /**		
			* Specifies the color valuepath of the treemap
            * @default null
			* @type {string}
			* @example 
            * //To set colorValuePath API value during initialization 
			*   $("#container").ejTreeMap({colorValuePath:'GoldMedals'});
            * @example 
			* //Get or set the colorValuePath API, after initialization:<br>
			*	//Gets the colorValuePath value 
            *   var property =$("#container").data("ejTreeMap").model.colorValuePath;<br> 
            *	//Sets the colorValuePath value 
			*	$("#container").data("ejTreeMap").model.colorValuePath = 'GoldMedals'; 
			* @memberof ejTreeMap
			* @instance
            */
            colorValuePath: null,

            /**		
			* Specifies the weight valuepath of the treemap
            * @default null
			* @type {string}
			* @example 
            * //To set weightValuePath API value during initialization 
			*   $("#container").ejTreeMap({weightValuePath:'TotalMedals'});
            * @example 
			* //Get or set the weightValuePath API, after initialization:<br>
			*	//Gets the weightValuePath value 
            *   var property =$("#container").data("ejTreeMap").model.weightValuePath;<br> 
            *	//Sets the weightValuePath value 
			*	$("#container").data("ejTreeMap").model.weightValuePath = 'TotalMedals'; 
			* @memberof ejTreeMap
			* @instance
            */
            weightValuePath: null,


            treeMapItems: [],

            /**		
			* Specifies the legend visibility  status of the treemap
            * @default false
			* @type {boolean}
			* @example 
            * //To set showLegend API value during initialization 
			*   $("#container").ejTreeMap({showLegend:false});
            * @example 
			* //Get or set the showLegend API, after initialization:<br>
			*	//Gets the showLegend value 
            *   var property =$("#container").data("ejTreeMap").model.showLegend;<br> 
            *	//Sets the showLegend value 
			*	$("#container").data("ejTreeMap").model.showLegend = false; 
			* @memberof ejTreeMap
			* @instance
            */
            showLegend: false,

            /**		
			* Specifies the border brush color of the treemap
            * @default "white"
			* @type {string}
			* @example 
            * //To set borderBrush API value during initialization 
			*   $("#container").ejTreeMap( {borderBrush:'white'});
            * @example 
			* //Get or set the borderBrush API, after initialization:<br>
			*	//Gets the borderBrush value 
            *   var property =$("#container").data("ejTreeMap").model.borderBrush;<br> 
            *	//Sets the borderBrush value 
			*	$("#container").data("ejTreeMap").model.borderBrush = 'white'; 
			* @memberof ejTreeMap
			* @instance
            */
            borderBrush: "white",

            /**		
			* Specifies the border thickness of the treemap
            * @default 1
			* @type {number}
			* @example 
            * //To set borderThickness API value during initialization 
			*   $("#container").ejTreeMap({borderThickness:1});
            * @example 
			* //Get or set the borderThickness API, after initialization:<br>
			*	//Gets the borderThickness value 
            *   var property =$("#container").data("ejTreeMap").model.borderThickness;<br> 
            *	//Sets the borderThickness value 
			*	$("#container").data("ejTreeMap").model.borderThickness = 1; 
			* @memberof ejTreeMap
			* @instance
            */
            borderThickness: 1,

            /**		
			* Specifies whether treemap need to resize when container is resized
            * @default true
			* @type {boolean}
			* @example 
            * //To set enableResize API value during initialization 
			*   $("#container").ejTreeMap({enableResize:false});
            * @example 
			* //Get or set the enableResize API, after initialization:<br>
			*	//Gets the enableResize value 
            *   var property =$("#container").data("ejTreeMap").model.enableResize;<br> 
            *	//Sets the enableResize value 
			*	$("#container").data("ejTreeMap").model.enableResize = false; 
			* @memberof ejTreeMap
			* @instance
            */
            enableResize: true,

            /**		
			* Specifies the items layout mode of the treemap. Accepted itemsLayoutMode values are Squarified, SliceAndDiceHorizontal, SliceAndDiceVertical and SliceAndDiceAuto
            * @default "Squarified"
			* @type {string}
			* @example 
            * //To set itemsLayoutMode API value during initialization 
			*   $("#container").ejTreeMap({itemsLayoutMode:ej.datavisualization.TreeMap.ItemsLayoutMode.Squarified});
            * @example 
			* //Get or set the itemsLayoutMode API, after initialization:<br>
			*	//Gets the itemsLayoutMode value 
            *   var property =$("#container").data("ejTreeMap").model.itemsLayoutMode;<br> 
            *	//Sets the itemsLayoutMode value 
			*	$("#container").data("ejTreeMap").model.itemsLayoutMode = ej.datavisualization.TreeMap.ItemsLayoutMode.Squarified; 
			* @memberof ejTreeMap
			* @instance
            */
            itemsLayoutMode: "squarified",
			
			
            // Level Collection
            /**		
            * Specify levels of treemap for grouped visualization of datas
            * @default []
            * @type {treeMapLevel} 
            * @example  
            * // Set the levels during initialization. 		
            *   $("#container").ejTreeMap({	levels: [{ groupPath: "Continent", groupGap: 5, headerHeight: 30, headerTemplate: 'headertemplate' }]})
            * @example 
            * //Get or set the levels after initialization:<br>
            *   //Gets the levels from map.
            *   var levels =$("#container").data("ejTreeMap").model.levels[levelIndex];
            *   //Sets the levels to map.
            *   $("#container").data("ejTreeMap").model.levels[levelIndex]  = { groupPath: "Continent", groupGap: 5, headerHeight: 30, headerTemplate: 'headertemplate' };
            * @memberof ejTreeMap
            * @instance
            */
            levels: [],

            /**		
			* Specifies the legendSettings of the treemap
            * @default null
			* @type {object}
			* @example 
            * //To set legendSettings API value during initialization 
			*   $("#container").ejTreeMap( {legendSettings:{ template: null, iconHeight: 15, iconWidth: 25 }});
            * @example 
			* //Get or set the legendSettings API, after initialization:<br>
			*	//Gets the legendSettings value 
            *   var property =$("#container").data("ejTreeMap").model.legendSettings;<br> 
            *	//Sets the legendSettings value 
			*	$("#container").data("ejTreeMap").model.legendSettings = { template: null, iconHeight: 15, iconWidth: 25 }; 
			* @memberof ejTreeMap
			* @instance
            */
            legendSettings: { template: null, iconHeight: 15, iconWidth: 25 },

            /**		
			* Specifies the range color mapping of the treemap
            * @default []
			* @type {collection}
			* @example 
            * //To set rangeColorMapping API value during initialization 
			*   $("#container").ejTreeMap( {rangeColorMapping:[{ color: "#77D8D8",legendLabel:"1% Growth", from: "0", to: "1" }]});
            * @example 
			* //Get or set the rangeColorMapping API, after initialization:<br>
			*	//Gets the rangeColorMapping value 
            *   var property =$("#container").data("ejTreeMap").model.rangeColorMapping;<br> 
            *	//Sets the rangeColorMapping value 
			*	$("#container").data("ejTreeMap").model.rangeColorMapping = [{ color: "#77D8D8",legendLabel:"1% Growth", from: "0", to: "1" }]; 
			* @memberof ejTreeMap
			* @instance
            */
            rangeColorMapping: [],
            /**		
			* Specifies the uniform color mapping of the treemap
            * @default { color: null }
			* @type {object}
			* @example 
            * //To set uniColorMapping API value during initialization 
			*   $("#container").ejTreeMap( {uniColorMapping{ color: null }});
            * @example 
			* //Get or set the uniColorMapping API, after initialization:<br>
			*	//Gets the uniColorMapping value 
            *   var property =$("#container").data("ejTreeMap").model.uniColorMapping;<br> 
            *	//Sets the uniColorMapping value 
			*	$("#container").data("ejTreeMap").model.uniColorMapping = { color: null }; 
			* @memberof ejTreeMap
			* @instance
            */
            uniColorMapping: { color: null },

            /**		
			* Specifies the desaturation color mapping of the treemap
            * @default { from: 0, to: 0, color: 'blue', rangeMinimum: 0, rangeMaximum: 0 }
			* @type {object}
			* @example 
            * //To set desaturationColorMapping API value during initialization 
			*   $("#container").ejTreeMap( {desaturationColorMapping{ from:1, to:0.5 ,color:"#41B8C4", rangeMinimum:2000,rangeMaximum:8000}});
            * @example 
			* //Get or set the desaturationColorMapping API, after initialization:<br>
			*	//Gets the desaturationColorMapping value 
            *   var property =$("#container").data("ejTreeMap").model.desaturationColorMapping;<br> 
            *	//Sets the desaturationColorMapping value 
			*	$("#container").data("ejTreeMap").model.desaturationColorMapping = { from:1, to:0.5 ,color:"#41B8C4", rangeMinimum:2000,rangeMaximum:8000}; 
			* @memberof ejTreeMap
			* @instance
            */
            desaturationColorMapping: { from:0, to:0,color:null, rangeMinimum:0,rangeMaximum:0},

            /**		
			* Specifies the palette color mapping of the treemap
            * @default null
			* @type {object}
			* @example 
            * //To set paletteColorMapping API value during initialization 
			*   $("#container").ejTreeMap( {paletteColorMapping{colors: ["red","green","blue", "yellow"]}});
            * @example 
			* //Get or set the paletteColorMapping API, after initialization:<br>
			*	//Gets the paletteColorMapping value 
            *   var property =$("#container").data("ejTreeMap").model.paletteColorMapping;<br> 
            *	//Sets the paletteColorMapping value 
			*	$("#container").data("ejTreeMap").model.paletteColorMapping = {colors: ["red","green","blue", "yellow"]}; 
			* @memberof ejTreeMap
			* @instance
            */
            paletteColorMapping: null,

            /**		
			* Specifies whether treemap item need to highlighted on selection
            * @default false
			* @type {boolean}
			* @example 
            * //To set highlightOnSelection API value during initialization 
			*   $("#container").ejTreeMap({highlightOnSelection:false});
            * @example 
			* //Get or set the highlightOnSelection API, after initialization:<br>
			*	//Gets the highlightOnSelection value 
            *   var property =$("#container").data("ejTreeMap").model.highlightOnSelection;<br> 
            *	//Sets the highlightOnSelection value 
			*	$("#container").data("ejTreeMap").model.highlightOnSelection = false; 
			* @memberof ejTreeMap
			* @instance
            */
            highlightOnSelection: false,
			
			 /**		
			* Specifies whether treemap item need to highlighted on selection
            * @default false
			* @type {boolean}
			* @example 
            * //To set highlightGroupOnSelection API value during initialization 
			*   $("#container").ejTreeMap({highlightGroupOnSelection:false});
            * @example 
			* //Get or set the highlightGroupOnSelection API, after initialization:<br>
			*	//Gets the highlightGroupOnSelection value 
            *   var property =$("#container").data("ejTreeMap").model.highlightGroupOnSelection;<br> 
            *	//Sets the highlightGroupOnSelection value 
			*	$("#container").data("ejTreeMap").model.highlightGroupOnSelection = false; 
			* @memberof ejTreeMap
			* @instance
            */
            highlightGroupOnSelection: false,

            /**		
			* Specifies whether treemap tooltip need to be visible
            * @default false
			* @type {boolean}
			* @example 
            * //To set showTooltip API value during initialization 
			*   $("#container").ejTreeMap({showTooltip:false});
            * @example 
			* //Get or set the showTooltip API, after initialization:<br>
			*	//Gets the showTooltip value 
            *   var property =$("#container").data("ejTreeMap").model.showTooltip;<br> 
            *	//Sets the showTooltip value 
			*	$("#container").data("ejTreeMap").model.showTooltip = false; 
			* @memberof ejTreeMap
			* @instance
            */
            showTooltip: false,

            /**		
			* Specifies the tooltip template of the treemap
            * @default null
			* @type {string}
			* @example 
            * //To set tooltipTemplate API value during initialization 
			*   $("#container").ejTreeMap({tooltipTemplate:'template'});
            * @example 
			* //Get or set the tooltipTemplate API, after initialization:<br>
			*	//Gets the tooltipTemplate value 
            *   var property =$("#container").data("ejTreeMap").model.tooltipTemplate;<br> 
            *	//Sets the tooltipTemplate value 
			*	$("#container").data("ejTreeMap").model.tooltipTemplate = 'template'; 
			* @memberof ejTreeMap
			* @instance
            */
            tooltipTemplate: null,

            /**		
			* Specifies the border thickness when treemap items is highlighted in the treemap
            * @default 5
			* @type {number}
			* @example 
            * //To set highlightBorderThickness API value during initialization 
			*   $("#container").ejTreeMap({highlightBorderThickness:5});
            * @example 
			* //Get or set the highlightBorderThickness API, after initialization:<br>
			*	//Gets the highlightBorderThickness value 
            *   var property =$("#container").data("ejTreeMap").model.highlightBorderThickness;<br> 
            *	//Sets the highlightBorderThickness value 
			*	$("#container").data("ejTreeMap").model.highlightBorderThickness = 5; 
			* @memberof ejTreeMap
			* @instance
            */
            highlightBorderThickness: 5,

            /**		
           * Specifies the border thickness when treemap items is highlighted in the treemap
           * @default 5
           * @type {number}
           * @example 
           * //To set highlightGroupBorderThickness API value during initialization 
           *   $("#container").ejTreeMap({highlightGroupBorderThickness:5});
           * @example 
           * //Get or set the highlightGroupBorderThickness API, after initialization:<br>
           *	//Gets the highlightGroupBorderThickness value 
           *   var property =$("#container").data("ejTreeMap").model.highlightGroupBorderThickness;<br> 
           *	//Sets the highlightGroupBorderThickness value 
           *	$("#container").data("ejTreeMap").model.highlightGroupBorderThickness = 5; 
           * @memberof ejTreeMap
           * @instance
           */
            highlightGroupBorderThickness: 4,

            /**		
			* Specifies the highlight border brush of treemap
            * @default "gray"
			* @type {string}
			* @example 
            * //To set highlightBorderBrush API value during initialization 
			*   $("#container").ejTreeMap({highlightBorderBrush:'gray'});
            * @example 
			* //Get or set the highlightBorderBrush API, after initialization:<br>
			*	//Gets the highlightBorderBrush value 
            *   var property =$("#container").data("ejTreeMap").model.highlightBorderBrush;<br> 
            *	//Sets the highlightBorderBrush value 
			*	$("#container").data("ejTreeMap").model.highlightBorderBrush = 'gray'; 
			* @memberof ejTreeMap
			* @instance
            */
            highlightBorderBrush: "gray",

            /**		
           * Specifies the highlight border brush of treemap
           * @default "gray"
           * @type {string}
           * @example 
           * //To set highlightGroupBorderBrush API value during initialization 
           *   $("#container").ejTreeMap({highlightGroupBorderBrush:'gray'});
           * @example 
           * //Get or set the highlightGroupBorderBrush API, after initialization:<br>
           *	//Gets the highlightGroupBorderBrush value 
           *   var property =$("#container").data("ejTreeMap").model.highlightGroupBorderBrush;<br> 
           *	//Sets the highlightGroupBorderBrush value 
           *	$("#container").data("ejTreeMap").model.highlightGroupBorderBrush = 'gray'; 
           * @memberof ejTreeMap
           * @instance
           */
            highlightGroupBorderBrush: "gray"

        },
        /**
         * Specify the data types for default properties 
		 * @private
         */
        dataTypes: {
            dataSource: "data",
            treeMapItems: "array",
            levels: "array",
            rangeColorMapping: "array",
            paletteColorMapping: "array"
        },
		
        observables: ["dataSource", "colorValuePath", "weightValuePath"],
		_tags: [	{
					tag: "levels", 
					attr: ["groupPath", "groupGap", "headerHeight", "headerTemplate"]
					}, 
					{
					tag: "rangeColorMapping",
					attr: ["color", "legendLabel", "from", "to"]
					}
				],

        dataSource: ej.util.valueFunction("dataSource"),
        colorValuePath: ej.util.valueFunction("colorValuePath"),
        weightValuePath: ej.util.valueFunction("weightValuePath"),

        _initPrivateProperties: function () {
            this._svgDocument = null;
            this._templateDiv = null;
            this._legenddiv = null;
            this._drillHeaderDiv = null;
            this._drillHoverDiv = null;
            this._legendHeight = 0;
            this._backgroundTile = null;
            this._tooltipSize = { height: 0, width: 0 };
            this._height = 500;
            this._margintop = null;
            this._marginleft = null;
            this._initDiv = null;
            this._width = 500;
            this._svgns = "http://www.w3.org/2000/svg";
            this._prevSelectedItems=[];
			this._prevSelectedHeaders = [];
            /**     
        * Triggers on treemap item selected. 
        * @event
        * @name ejTreeMap#treeMapItemSelected            
        * @param {object} originalEvent.data Returns selected treeMapItem object.
        * @example 
        * //treemap item selected event for treemap
        * $("#container").ejTreeMap({
        *    treeMapItemSelected: function () {}
        * });
        * @memberof ejTreeMap
        * @instance
        */
            this.treeMapItemSelected = null;
            this.treeMapGroupSelected = null;
            this._browser = null;
            this._header = null;
            this._toolTipElement = null;
            this._rootTreeMapItems = [];
            this._drillHeader = null;
            this._drilldownItem = null;
            this._drilldownItems = [];
            this._treeMapHeaders = [];
            this._drillDownItemSelected = null;
            this._treeMapLabels = [];
            this._labelTemplateElements = [];
            this._itemGroups = [];
			this._prevSelectedItemDatas=[];
            this._prevSelectedGroupDatas = [];

        },

        /**
          * To configure the properties at runtime using SetModel		
          * @private
          */
        _setModel: function (options) {
            for (var prop in options) {
                switch (prop) {
                    case "itemsLayoutMode":
                        this.model.itemsLayoutMode = options[prop];
                        this.refresh();
                        break;
                }
            }
        },
		
		
		
_levels: function(index, property, value, old){
	 this.refresh();
    },
_rangeColorMapping: function(index, property, value, old){
	this._setColorMappings(this._rootTreeMapItems, this.model);
    },

        /**
        * Create the treemap widget
        * @private
        */
        _init: function () {

            this._initPrivateProperties();
            var style = $('<style>.drillGroupRect:hover{ background-color:' + this.model.drillDownSelectionColor + ';}</style>');
            $('html > head').append(style);
            this._levelInitialize();

            this.refresh();           

        },

        /**
        * Destroy the map widget
        * @private
        */
        _destroy: function() {

        },
        
        /**
        * Create level for treemap
        * @private
        */
        _levelInitialize: function () {
            var proxy = this;
            if (this.model.levels != null) {
                $.each(this.model.levels, function (index, element) {                    
                    element = proxy._checkArrayObject(element, index);
                    var obj = new treeMapLevel();                    
                    $.extend(obj, element);
                    $.extend(element, obj);                    
                });
            }
            else {
                this.levels.treeMapLevel = new treeMapLevel();

            }
			
			$(document).click({treeMap: this}, this._docClickFunction);
        },

        /**
       * Checks array object
       * @private
       */
        _checkArrayObject: function (element, initialName) {
            var proxy = this;
            $.each(element, function (name, innerElement) {
                if (innerElement instanceof Array) {
                    proxy._checkArrayObject(innerElement, name);
                }
                else if (innerElement != null && typeof innerElement == "object") {
                    var allObjects = new treeMapLevel();
                    proxy._loadIndividualDefaultValues(innerElement, allObjects, (typeof name === "number") ? initialName : name);
                }
            });
            return element;
        },

        /**
          * Loads individual default values
          * @private
          */
        _loadIndividualDefaultValues: function (obj, allObjects, name) {
            var defaultObj = null;
            var proxy = this;
            $.each(allObjects, function (n, element) {
                if (name == n) {
                    defaultObj = element;
                    return;
                }
            });
            if (defaultObj instanceof Array) defaultObj = defaultObj[0];

            $.each(obj, function (objName, ele) {
                if (ele instanceof Array) {
                    proxy._checkArrayObject(ele, name);
                }
                else if (ele != null && typeof ele == "object") {
                    proxy._loadIndividualDefaultValues(ele, ele, (typeof objName === "number") ? name : objName);
                }
            });

            $.extend(defaultObj, obj);
            $.extend(obj, defaultObj);
            return obj;
        },


        /**     
       * Method to reload treemap with updated values.
       * @return jQuery
       * @example 
       * //refresh method for treemap
       * $("#container").ejTreeMap({
       *    refresh: function () {}
       * });
       * @memberof ejTreeMap
       * @instance
       */
        refresh: function () {

            if (this._drilldownItems.length == 0) {
                this._initPrivateProperties();
            }

            $(this.element).empty();
            if (this._svgDocument != null) {
                $(this._svgDocument).empty();
            }
            this._height = this.element.height();
            this._width = this.element.width();
             if (this._height == 0) {
                 this._height = this.element[0].parentElement.clientHeight != 0 ? this.element[0].parentElement.clientHeight : $(document).height();
            }
            if (this._width == 0) {
                this._width = this.element[0].parentElement.clientWidth != 0 ? this.element[0].parentElement.clientWidth : $(document).width();
            }
            if (this.model.showLegend) {
                this._sizeCalculation();
            }            
		    var matched = jQuery.uaMatch(navigator.userAgent);
            var browser = matched.browser.toLowerCase();
            var isIE11 = !!navigator.userAgent.match(/Trident\/7\./);
            this._browser = browser;
			  $(this.element).css({ 'position': 'relative' });			
           
            if (this._height != 0 && this._width != 0) {                
                this._templateDiv = $("<div class='_templateDiv'></div>");
                this._templateDiv.css({
                    'pointer-events': 'none', 'overflow': 'hidden', 'float': 'left',
                    'z-index': '2', 'height': this._height, 'width': this._width, "margin-top": this._margintop,  "margin-left": this._marginleft, "position": "absolute", "left": "0", "top": "0"
                });
                if (this.model.enableDrillDown && this._drilldownItems.length == 0) {
                    this._drillHeaderDiv = $("<div class='_drillHeaderDiv'></div>");
                    this._drillHeaderDiv.css({
                        'overflow': 'hidden', 'float': 'left',
                        'z-index': '3', "position": "absolute", "left": "0", "top": "0"
                    });
                    this._drillHoverDiv = $("<div class='_drillHoverDiv'></div>");
                    this._drillHoverDiv.css({
                        'overflow': 'hidden', 'float': 'left',
                        'z-index': '3', 'height': this._height - 30, 'width': this._width, "position": "absolute", "left": "0", "top": "30px"
                    });
                }
                this._backgroundTile = $('<div id="backgroundTile" style="overflow:hidden;z-index:0;"></div>');
                if(this.model.showLegend) {
                    if (this.model.legendSettings != null) {
						this._renderLegend();                       
                    }
                }
				if(this.model.dataSource!=null){
                    if (this._drilldownItems.length > 0) {
                        if (this.model.enableDrillDown && this.model.levels.length >= 1 && ((this._drilldownItem != null) || this._drilldownItem == null)) {
                            for (var i = 0; i < this._drillHeaderDiv[0].children[0].children.length; i++) {
                                if (this._drillHeaderDiv[0].children[0].children[i].className == "e-treemapheader")
                                    header = this._drillHeaderDiv[0].children[0].children[i].innerHTML;
                            }
                            this._backgroundTile[0].innerHTML = "";
                            this._drillHeaderDiv[0].innerHTML = "";
                            this._templateDiv[0].innerHTML = "";
                            this._drillHoverDiv[0].innerHTML = "";
                            this._drillDownHeader(header, true);
                            this._groupdrillDownLevels(this._drilldownItems[this._drilldownItems.length - 1], this._drilldownItems.length);
                        }
                        if (this.model.showLegend) {
                            this._generateLegend();
                        }
                        this._generateToolTip();
                    }
                    else {
                        if (this.model.dataSource instanceof ej.DataManager) {
                            this._processOData(this);
                        }
                        else {
                            this._renderTreeMap(this.dataSource());
                        }
                    }
                }
                if (this.model.enableResize) {
                    this._on($(window), "resize", this._treeMapResize);
                }
            }
        },
		
	   /**
      * Section For handling treemap redering
      * @private
      */
		_renderTreeMap:function(data)
		{
		    this._groupLevels(data);
            if (this.model.showLegend) {
                this._generateLegend();
            }
            this._generateToolTip();
            this._renderLabels();
		},

		_renderLegend: function () {
		    this._legenddiv = $("<div class='LegendDiv'/>");
		    this._legenddiv.appendTo(this.element);

		        if (this.model.legendSettings.dockPosition == ej.datavisualization.TreeMap.DockPosition.Bottom) {
		            this._legenddiv.css({
		                'pointer-events': 'none', 'overflow': 'hidden', "position": "absolute",
		                'z-index': '2', 'height': this.model.legendSettings.height, 'width': this.model.legendSettings.width, 'margin-top': this._height
		            });
		        }

		        else if (this.model.legendSettings.dockPosition == ej.datavisualization.TreeMap.DockPosition.Top) {
		            this._legenddiv.css({
		                'pointer-events': 'none', 'overflow': 'hidden', "position": "absolute",
		                'z-index': '2', 'height': this.model.legendSettings.height, 'width': this.model.legendSettings.width
		            });
		        }
		        else if (this.model.legendSettings.dockPosition == ej.datavisualization.TreeMap.DockPosition.Left) {
		            this._legenddiv.css({
		                'pointer-events': 'none', 'overflow': 'hidden', "position": "absolute",
		                'z-index': '2', 'height': this.model.legendSettings.height, 'width': this.model.legendSettings.width
		            });
		        }
		        else if (this.model.legendSettings.dockPosition == ej.datavisualization.TreeMap.DockPosition.Right) {
		            this._legenddiv.css({
		                'pointer-events': 'none', 'overflow': 'hidden', "position": "absolute",
		                'z-index': '2', 'height': this.model.legendSettings.height, 'width': this.model.legendSettings.width, 'margin-left': this._width
		            });
		        }
		        else {
		            this._legenddiv.css({
		                'pointer-events': 'none', 'overflow': 'hidden', "position": "absolute",
		                'z-index': '2', 'height': this.model.legendSettings.height, 'width': this.model.legendSettings.width
		            });
		        }

		},

		 /**
         * Section For handling treemap redering
         * @private
         */
		_processOData: function (treemap) {  
			var treeMap= this;		 
			var queryPromise = treemap.model.dataSource.executeQuery(treemap.model.query);
			queryPromise.done(function (e) {
			    if(e.result!=null)
				{
                   treeMap._renderTreeMap(e.result);
				}
			});        
        },
    
        /**
      * Section For handling treemap resize
      * @private
      */
        _treeMapResize: function (event) {
            event.preventDefault();
            event.stopPropagation();
            var treemap = this;
            if (this.resizeTO) clearTimeout(this.resizeTO);
            this.resizeTO = setTimeout(function () {
                treemap.refresh();
            }, 500);
        },
       
        /**
          * Groups levels of treemap
          * @private
          */
        _groupLevels: function (data) {
           
            var subItems = null;
            if(this.model.enableDrillDown)
                this._drillDownHeader(this.model.levels[0].groupPath,false);
            var rootItems = this._getTopGroupitem(this.model.leafItemSettings.labelPath, data, 0);
            subItems = rootItems;
            if (this.model.levels.length == 0) {
                var levelItem = this.model.leafItemSettings;
                this._rootTreeMapItems = rootItems;
                this._getTopLevels(rootItems[0].innerItems, levelItem);
                if (levelItem.itemTemplate != null) {
                    this._generateTreeMapItems(rootItems[0].innerItems, "gray", this.colorValuePath());
                }
                if(levelItem.showLabels)
                this._generateLabels(rootItems[0].innerItems, levelItem);
            }
            if(this.model.levels.length>0){
                for (var i = 0; i <= this.model.levels.length; i++) {
                    var levelItem = this.model.levels[i];
                    if (i != 0) {
                        var cloneItems = subItems;
                        var PrevItem = this.model.levels[i - 1];
                        subItems = [];
                        if (levelItem == null) levelItem = this.model.leafItemSettings;
                        this._generateSubItems(cloneItems, levelItem, subItems, PrevItem);
                        
                        this._rootTreeMapItems = subItems;                        
                        if (this.model.enableDrillDown)
                        {
                            if (i == 1) {
                                this._generateTreeMapItems(subItems, "gray", PrevItem.DisplayPath);                                
                                return false;                          
                            }
                        }
                        else if (i == this.model.levels.length) {
                            this._generateTreeMapItems(subItems, "gray", PrevItem.DisplayPath);
                        }                                                  
                        if (levelItem.showLabels && i == this.model.levels.length) {
                            this._generateLabels(subItems, levelItem);
                        }
                      
                    }
                    else {
                        var rootItems1 = this._getGroupitem(levelItem.groupPath, rootItems[0].Data, levelItem.headerHeight);
                        this._rootTreeMapItems = rootItems1;
                        this._getTopLevels(rootItems1, levelItem);
                        subItems = rootItems1;                        
                    }
                }
                
            }
        },


        _groupdrillDownLevels: function (data, actualindex) {       

            var subItems = null;
            if (actualindex == this.model.levels.length-1)
            {
                this._drillHoverDiv.css("pointer-events", "none");
            }
            else
            {
                this._drillHoverDiv.css("pointer-events", "auto");
            }
            if (this.model.levels.length > 0) {

                for (var i = 0; i < this.model.levels.length; i++) {                   
                    var levelItem = this.model.levels[i];
                    if (i != 0) {
                        var cloneItems = subItems;
                        var PrevItem = this.model.levels[i - 1];
                        subItems = [];
                        if (levelItem == null) {
                            levelItem = this.model.leafItemSettings;
                           }
                        if (i == actualindex + 1) {
                            this._generateSubItems(cloneItems, levelItem, subItems, PrevItem, null, (actualindex + 1 != i));

                             }
                        else {
                             this._generateSubItems(cloneItems, levelItem, subItems, PrevItem, true, (actualindex + 1 != i));

                        }
                        this._rootTreeMapItems = subItems;
                        if (i == actualindex + 1 || i== this.model.levels.length-1) {
                            this._generateTreeMapItems(subItems, "gray", PrevItem.DisplayPath);
                        }
                        if (actualindex == this.model.levels.length - 1 && i == actualindex && this.model.leafItemSettings.showLabels) {
                            this._generateLabels(subItems, this.model.leafItemSettings);
                        }
                           
                    }
                    else {

                        var rootItems1 = this._getGroupitem(levelItem.groupPath, data.Data, levelItem.headerHeight);
                        this._rootTreeMapItems = rootItems1;
                        this._getTopLevels(rootItems1, levelItem);
                        subItems = rootItems1;
                    }
                }
            }
            
            if (this.model.showLegend) {
                this._generateLegend();
            }
            this._renderLabels();
            this._trigger("drillDownItemSelected", { level: actualindex, header: this._header, prevLevel: actualindex - 1 });
        },

        /**
          * Gets top levels of treemap
          * @private
          */
        _getTopLevels: function (rootItems, level) {
            var gap = (level.groupGap != null) ? level.groupGap : 0;
            var layout = this.model.itemsLayoutMode;
            var legendHeight = 0;
            var defaultspacing = 0;
            if (this.model.enableDrillDown) {
                defaultspacing = 30;
            }
                if (this.model.showLegend && this.model.legendSettings != null) {
					legendHeight = legendHeight;                    
                }
                
                this._legendHeight = legendHeight;
                if (this.model.enableDrillDown) {
                    this._drillHeaderDiv.css({
                        "top": legendHeight
                    });

                    this._drillHoverDiv.css({
                        "top": 30 + legendHeight
                    })
                }               
                
                if (layout == ej.datavisualization.TreeMap.ItemsLayoutMode.SliceAndDiceHorizontal) {
                    this._calculateSliceAndDiceItemSize(rootItems, 0, legendHeight, this._width, this._height, gap, defaultspacing, true, legendHeight);
                }
                else if (layout == ej.datavisualization.TreeMap.ItemsLayoutMode.SliceAndDiceVertical) {
                    this._calculateSliceAndDiceItemSize(rootItems, 0, legendHeight, this._width, this._height, gap, defaultspacing, false, legendHeight);
                }
                else if (layout == ej.datavisualization.TreeMap.ItemsLayoutMode.SliceAndDiceAuto) {
                    this._calculateSliceAndDiceItemSize(rootItems, 0, legendHeight, this._width, this._height, gap, defaultspacing, null, legendHeight);
                }
                else {
                    this._calculateSquarifiedItemSize(rootItems, 0, legendHeight, this._width, this._height, gap, defaultspacing, legendHeight);
                }
            
        },

      
        /**
         * Generates sub treemap items
         * @private
         */
        _generateSubItems: function (cloneItems, levelItem, subItems, PrevItem, disablelabels, disablebackground) {            
            var layout = this.model.itemsLayoutMode;
            var cloneItemsCount = cloneItems.length;
            var path = levelItem.groupPath;
            if (path == null) path = this.model.leafItemSettings.labelPath;
            if (path == null) path = this.weightValuePath();
            var gap = (levelItem.groupGap != null) ? levelItem.groupGap : (levelItem.gap != null) ? levelItem.gap:0;
            var headerHeight = ((PrevItem.showHeader || PrevItem.showHeader == null) && !this.model.enableDrillDown) ? PrevItem.headerHeight : 0;
            var totalItemsCount = 0;
            for (var j = 0; j < cloneItemsCount; j++) {
                var treeItems = this._getGroupitem(path, cloneItems[j].Data, levelItem.headerHeight);
                if (layout == ej.datavisualization.TreeMap.ItemsLayoutMode.SliceAndDiceHorizontal) {
                    this._calculateSliceAndDiceItemSize(treeItems, cloneItems[j].LeftPosition + (PrevItem.groupPadding), cloneItems[j].TopPosition + (PrevItem.groupPadding), cloneItems[j].ItemWidth - (PrevItem.groupBorderThickness + (2 * PrevItem.groupPadding)), cloneItems[j].ItemHeight - (PrevItem.groupBorderThickness + (2 * PrevItem.groupPadding)), gap, headerHeight, true, 0);
                }
                else if (layout == ej.datavisualization.TreeMap.ItemsLayoutMode.SliceAndDiceVertical) {
                    this._calculateSliceAndDiceItemSize(treeItems, cloneItems[j].LeftPosition + (PrevItem.groupPadding), cloneItems[j].TopPosition + (PrevItem.groupPadding), cloneItems[j].ItemWidth - (PrevItem.groupBorderThickness + (2 * PrevItem.groupPadding)), cloneItems[j].ItemHeight - (PrevItem.groupBorderThickness + (2 * PrevItem.groupPadding)), gap, headerHeight, false, 0);
                }
                else if (layout == ej.datavisualization.TreeMap.ItemsLayoutMode.SliceAndDiceAuto) {
                    this._calculateSliceAndDiceItemSize(treeItems, cloneItems[j].LeftPosition + (PrevItem.groupPadding), cloneItems[j].TopPosition + (PrevItem.groupPadding), cloneItems[j].ItemWidth - (PrevItem.groupBorderThickness + (2 * PrevItem.groupPadding)), cloneItems[j].ItemHeight - (PrevItem.groupBorderThickness + (2 * PrevItem.groupPadding)), gap, headerHeight, null, 0);
                }
                else {
                    this._calculateSquarifiedItemSize(treeItems, cloneItems[j].LeftPosition + (PrevItem.groupPadding), cloneItems[j].TopPosition + (PrevItem.groupPadding), cloneItems[j].ItemWidth - (PrevItem.groupBorderThickness + (2 * PrevItem.groupPadding)), cloneItems[j].ItemHeight - (PrevItem.groupBorderThickness + (2 * PrevItem.groupPadding)), gap, headerHeight, 0);
                }                
                var headerItem = this._rootTreeMapItems[j];                
                headerItem.headerHeight = PrevItem.headerHeight;
                headerItem.showHeader = PrevItem.showHeader;
                headerItem.headerWidth = cloneItems[j].ItemWidth;
                headerItem.headerTemplate = PrevItem.headerTemplate;
                headerItem.headerLeftPosition = cloneItems[j].LeftPosition;
                headerItem.headerTopPosition = cloneItems[j].TopPosition;
                if (PrevItem.showHeader || PrevItem.showHeader==null) {
						if (this.model.enableDrillDown)
                            this._createBackGround(headerItem, PrevItem, cloneItems[j], disablebackground);
                        else {
						    this._createBackGround(headerItem, PrevItem, cloneItems[j]);
						    this._generateHeaders(headerItem, PrevItem);
						}
                }              
               
                cloneItems[j].ChildtreeMapItems = treeItems;
                cloneItems[j].GroupingLevel = this.model.levels.indexOf(PrevItem) + 1;
                for (var k = 0; k < treeItems.length; k++) {
                    subItems[totalItemsCount] = treeItems[k];                   
                    if ((this.model.enableDrillDown) || (subItems[totalItemsCount].ItemHeight < headerItem.ItemHeight - headerItem.headerHeight)) {
                        subItems[totalItemsCount].ParentHeader = headerItem.header;
                        subItems[totalItemsCount].ItemHeight -= PrevItem.groupPadding;
                        subItems[totalItemsCount].ItemWidth -= PrevItem.groupPadding;
                        subItems[totalItemsCount].LeftPosition += PrevItem.groupBorderThickness;
                        subItems[totalItemsCount].TopPosition += PrevItem.groupBorderThickness;
                       
                    }
                    totalItemsCount++;
                }              
            }
            if (disablelabels == undefined &&  PrevItem.showLabels) {
                this._generateLabels(cloneItems, PrevItem);
            }
        },

        /**

        * create background for treemap items
        * @private
        */
        _createBackGround: function (header, level,parentitem, disablebackground) {            
            var rect = $("<div />");
            var height = (header.showHeader|| header.showHeader==null) ? header.ItemHeight - (2*level.groupBorderThickness) : 0;
            var top = (header.showHeader || header.showHeader == null) ? header.TopPosition : 0;
            rect.css({
                "height": height + "px",
                "width": header.ItemWidth - (2 * level.groupBorderThickness) + "px",
                "left": header.LeftPosition + "px",
                "top": top + "px",
                "border-style": "solid",
                "border-width": level.groupBorderThickness+"px",
                "position": "absolute"               
            });

			if(level.groupBorderColor!=null)
			{
			     rect.css("border-color",level.groupBorderColor);
			}
			if(level.groupBackground!=null)
			{
			     rect.css("background-color",level.groupBackground);
			}
            rect.appendTo(this._backgroundTile);
            var height = parseFloat(rect[0].style.top) - 30 - this._legendHeight + "px";            
            if (this.model.enableDrillDown && !disablebackground) {
                var hoverrect = $("<div class='drillGroupRect'/>");
                hoverrect.css({
                    "height": rect[0].style.height,
                    "width": rect[0].style.width,
                    "left": rect[0].style.left,
                    "top": height,
                    "position": "absolute",
                    "opacity": 0.2,
                    "display": "block"
                });
                this._drillHoverDiv.append(hoverrect);
                $(hoverrect).mousedown({ treemap: this, level: level, param1: parentitem }, this._headerClickFunction);
                $(hoverrect).mouseleave({ treemap: this, param1: header.header }, this._mouseLeaveFunction);
                $(hoverrect).mousemove({ treemap: this, hoverItem: header }, this._mouseRectHoverFunction);
            }
            $(rect).mousedown({ treemap: this, level: level, param1: parentitem }, this._headerClickFunction);
            $(rect).mousemove({ treemap: this, param1: header.header, hoverItem: header }, this._mouseHoverFunction);
        },

        _mouseRectHoverFunction: function (event) {
          
            var treeMap = event.data.treemap;
            if (treeMap.model.showTooltip) {
                var element = treeMap._toolTipElement;
                var template = treeMap.model.tooltipTemplate;
                if (element != null && template != null) {
                    $(element).css({ "left": event.pageX + 10, "top": event.pageY + 10, "display": "block" });
                    var htmlString = $("#" + template).render(event.data.hoverItem);
                    $(element).html(htmlString);
                    

                }
            }
        },
		
        _mouseHoverFunction: function (event) {
            var treeMap = event.data.treemap;
            if (treeMap.model.showTooltip) {
                var element = treeMap._toolTipElement;
                var template = treeMap.model.tooltipTemplate;
                if (element != null && template != null) {
                    $(element).css({ "left": event.pageX + 10, "top": event.pageY + 10, "display": "block" });
                    var htmlString = $("#" + template).render(event.data.hoverItem);
                    $(element).html(htmlString);
                   

                }
            }
        },

       
        _mouseLeaveFunction: function (event) {
            var treeMap = event.data.treemap;
            if (treeMap.model.showTooltip)
            {
                if (treeMap._toolTipElement != null) {
                    $(treeMap._toolTipElement).css("display", "none");
                }
            }
        },
		
        _headerClickFunction: function (event) {
            var level = event.data.level;
            var data = event.data.param1;
		    var ctrlkey = event.ctrlKey;
		    var treeMap = event.data.treemap;
		    if (treeMap.model.highlightGroupOnSelection) {
		        if (treeMap._browser != "msie") {
		            var lastItem = treeMap._backgroundTile[0].children[treeMap._backgroundTile[0].children.length - 0];
		            treeMap._backgroundTile[0].insertBefore(this, lastItem);
		        }
		        if (ctrlkey) {

		            if ($.inArray(this,treeMap._prevSelectedHeaders)==-1) {
		                $(this).css({ "border-width": treeMap.model.highlightGroupBorderThickness, "border-color": treeMap.model.highlightBorderBrush });
		                treeMap._prevSelectedHeaders.push(this);
		                treeMap._prevSelectedGroupDatas.push(event.data.Param1);
		            }
		            else {
                        
                        $(this).css({ "border-width": level.groupBorderThickness, "border-color": level.groupBorderColor });
                        var index = treeMap._prevSelectedHeaders.indexOf(this);
                        treeMap._prevSelectedHeaders.splice(index, 1);
                        treeMap._prevSelectedGroupDatas.splice(index, 1);
		            }
		        }
		        else {
		            for (var k = 0; k < treeMap._prevSelectedHeaders.length; k++) {
		               
		                $(treeMap._prevSelectedHeaders[k]).css({ "border-width": level.groupBorderThickness, "border-color": level.groupBorderColor });
		            }

		            if ($.inArray(this, treeMap._prevSelectedHeaders) == -1) {
		                $(this).css({ "border-width": treeMap.model.highlightGroupBorderThickness, "border-color": treeMap.model.highlightBorderBrush });
		                treeMap._prevSelectedHeaders = [];
		                treeMap._prevSelectedHeaders.push(this);
		            }
		            else {
		                treeMap._prevSelectedHeaders = [];
		            }
		            
		            treeMap._prevSelectedGroupDatas.push(event.data.Param1);
		        }
		    }

		    if (treeMap.model.enableDrillDown && treeMap.model.levels.length > 1 && ((treeMap._drilldownItem != null && treeMap._drilldownItem.header != data.header) || treeMap._drilldownItem == null)) {
                var header = "";
                for(var i=0;i< treeMap._drillHeaderDiv[0].children[0].children.length;i++)
		        {
                    if (treeMap._drillHeaderDiv[0].children[0].children[i].className == "e-treemapheader")
                        header = treeMap._drillHeaderDiv[0].children[0].children[i].innerHTML;
		        }
                treeMap._backgroundTile[0].innerHTML = "";
                treeMap._labelTemplateElements = [];
                treeMap._drillHeaderDiv[0].innerHTML = "";
                treeMap._templateDiv[0].innerHTML = "";
                treeMap._drillHoverDiv[0].innerHTML = "";
		        treeMap._drillDownHeader(header + "." + data.header,true);
		        treeMap._drilldownItem = data;
		        treeMap._drilldownItems.push(data);
		        treeMap._groupdrillDownLevels(data, treeMap._drilldownItems.length);
		        return false;
		       		        
		    }
		    treeMap._trigger("treeMapGroupSelected", { selectedGroups: treeMap._prevSelectedHeaders,orginalEvent:event });
			
		},

        /**
        * Generates labels for treemap items
        * @private
        */
        _generateLabels: function (Items,level) {            
            for (var i = 0; i < Items.length; i++) {
                var item = Items[i];
				if (level.labelTemplate == null) {                    
					var leftpaddingsize = 10;
					var toppaddingsize = 5;
				    var textcon = $('<label style="font-size:14px;font-weight:normal;font-family:Segoe UI;">' + item.label + '</label>');
					if (this.model.enableDrillDown)
					{
						$(textcon).css({
							"position": "absolute","color":"black",
							"overflow": "hidden", "width": item.ItemWidth - leftpaddingsize + "px", "left": item.LeftPosition + leftpaddingsize + "px",
							"top": item.TopPosition + toppaddingsize + "px", "height": item.ItemHeight-toppaddingsize,"font-weight":"normal","pointer-events":"none"
						});
					}
					else
					{
					    $(textcon).css({
					        "position": "absolute", "color": "white",
					        "overflow": "hidden", "width": item.ItemWidth - leftpaddingsize + "px", "left": item.LeftPosition + leftpaddingsize + "px",
					        "top": item.TopPosition + toppaddingsize + "px", "height": item.ItemHeight - toppaddingsize, "font-weight": "normal", "pointer-events": "none"
					    });
					}
                    this._treeMapLabels.push(textcon);
                    this._templateDiv.append(textcon);
                    var textMode = level.labelVisibilityMode;
					if (textMode == ej.datavisualization.TreeMap.VisibilityMode.HideOnExceededLength){						
						var textelement = $('<span>'+textcon[0].innerHTML+'</span>');
						$(document.body).append(textelement);
						var width = textelement.outerWidth();
						var height = textelement.outerHeight();
						textelement.remove();
						var widthfactor;
						if (width > item.ItemWidth)
						{							
							widthfactor = width / item.ItemWidth;
						}
						else
						{
							widthfactor = item.ItemWidth / width;
						}			
						var neededWidth = widthfactor * height + (2 * leftpaddingsize * widthfactor);	
						var availableheight = item.ItemHeight - (2 * toppaddingsize);						
						var hidelabel = false;						
						if (width > (item.ItemWidth - leftpaddingsize) && height < (item.ItemHeight - toppaddingsize)){
							if ( neededWidth < availableheight){
								$(textcon).css({
									"display": "block",
									"word-wrap": "break-word"
								});
							}
							else{
								hidelabel = true;
							}
						}
						else if (height > (item.ItemHeight - 2*toppaddingsize)){
							hidelabel = true;
						}
						else if (width > (item.ItemWidth - leftpaddingsize)){
							hidelabel = true;
						}
						
						if (hidelabel){
							$(textcon).css({
									"display": "none"
								});
						}
					}
                }            
                if(level.labelTemplate != null) {
                    var OriginalNode = $("#" + level.labelTemplate);
                    var item_templateDiv = $("<div style='overflow:hidden;display:block;position:absolute;pointer-events: none;'></div>");
                    item_templateDiv[0].data = item;
                    item.labelPosition = level.labelPosition;
                    item.labelVisibilityMode = level.labelVisibilityMode;
                    var tmpl2 = $.templates(OriginalNode.html());
                    if(item.Data!=null && item.Data.length>1)
                        var htmlString = tmpl2.render(item.groupedData);
                    else if (item.Data.length == 1) {
                        var htmlString = tmpl2.render(item.Data[0]);
                    }
                    else
                        var htmlString = tmpl2.render(item.Data);
                    $(item_templateDiv).html(htmlString);
                    this._templateDiv.append(item_templateDiv);
                    this._labelTemplateElements.push(item_templateDiv);
                }
            }
        },

        /**
        * Generates tooltip for treemap
        * @private
        */
        _generateToolTip: function () {

            if (this.model.showTooltip) {
                if (document.documentMode == 8){
					var tooltip = document.querySelectorAll("tooltipelement");
				}
				else{
					var tooltip = document.getElementsByClassName("tooltipelement");
				}
                if (tooltip != null && tooltip.length == 0) {
                    var tooltip_templateDiv = $("<div class='tooltipelement' style='display:none;position:absolute;z-index:1000;pointer-events:none;'></div>");
                    $(document.body).append(tooltip_templateDiv);
                    this._toolTipElement = tooltip_templateDiv;
                }
                else
                {
                    this._toolTipElement = tooltip[0];
                }
                if (this.model.tooltipTemplate == null) {

                    var path;
                    if (this.model.leafItemSettings.labelPath!=null)
                        path = this.model.leafItemSettings.labelPath;
                    else 
                        path = this.weightValuePath();
                    if (path != null) {
                        this.model.tooltipTemplate = 'defaultTooltip';

                        this.element.append($('<div id="defaultTooltip" style="display:none;"><div style="margin-left:10px;margin-top:-25px;"><div class="defaultToolTip"><p style="margin-top:-4px"><label  style="color:rgb(27, 20, 20);font-size:14px;font-weight:normal;font-family:Segoe UI">{{:#data["' + path + '"]}}</label></p></div></div></div>'));
                    }
                }
            }
            

        },

        /**
        * Generates legend for treemap
        * @private
        */
        _generateLegend: function () {            
            if (this.model.rangeColorMapping != null) {
                var colormapping = this.model.rangeColorMapping;
                var xPos = 10;
                var yPos = 10;
                var totalwidth = 0;
                var totalheight = 0;
                var legendSettings = this.model.legendSettings;
                var legendtype = legendSettings.template;
                var legenddiv = $("<div/>");
                for (var i = 0; i < colormapping.length; i++) {
                    var legendItem;

                    if (legendtype == "Ellipse") {
                        legendItem = this._getEllipseLegend(legendSettings, xPos, yPos);
                    }
                    else {
                        legendItem = this._getRectLegend(legendSettings, xPos, yPos);
                    }

                    $(legendItem).css("background-color", colormapping[i].color);
                    legendItem.appendTo(this._legenddiv);                                   
                                      
                    xPos += legendSettings.iconWidth + 5;                   
                    var legendText = $("<div/>");
                    legendText.css({                        
                        "left": xPos + "px",
                        "top": yPos + "px",
                        "position": "absolute"
                    });                    
                    $(legendText).css({"font-size":"15px"});
                    legendText[0].innerHTML= colormapping[i].legendLabel;
                    legendText.appendTo(this._legenddiv);
                                                  
                    var bounds = legendText[0].getBoundingClientRect();
                    var boundwidth = window.SVGSVGElement ? bounds.width : bounds.right - bounds.left;
                    xPos += boundwidth + 18;

                    if (xPos + totalwidth + 150 >= this.model.legendSettings.width) {
                        xPos = 10;
                        yPos += 40;
                    }                    

                }
            }
        },

        /**
        * Gets ellipse legend
        * @private
        */
        _getEllipseLegend: function (legengItem, xPos, yPos) {

            var rect = $("<div class='e-mapLegend'/>");
            rect.css({
                "height": this.model.legendSettings.iconHeight+ "px",
                "width": this.model.legendSettings.iconWidth + "px",
                "border-radius":this.model.legendSettings.iconHeight/2+"px",
                "left": xPos + "px",
                "top": yPos + "px",
                "position": "absolute"
            });
            return rect;

        },

        /**
        * Gets rect legend
        * @private
        */
        _getRectLegend: function (legengItem, xPos, yPos) {
            var rect = $("<div />");
            rect.css({
                "height": this.model.legendSettings.iconHeight+ "px",
                "width": this.model.legendSettings.iconWidth + "px",                
                "left": xPos + "px",
                "top": yPos + "px",
                "position": "absolute"
            });
            return rect;
        },

        /**
        * Gets position from parent
        * @private
        */
        _getPositionFromParent: function (element, parentelement) {
            var child = element.getBoundingClientRect();
            var parent = parentelement.getBoundingClientRect();
            var width = window.SVGSVGElement ? child.width: child.right-child.left;
            var height = window.SVGSVGElement ? child.height : child.bottom - child.top;            
            return { left: child.left - parent.left, top: child.top - parent.top, height: height, width: width };
        },

        /**
       * Renders labels
       * @private
       */
        _renderLabels: function () {

           
            for (var j = 0; j < this._labelTemplateElements.length; j++) {
                var label = this._labelTemplateElements[j];
                var bounds = this._getPositionFromParent(label[0], this._templateDiv[0]);
                var item = label[0].data;
                var pos = this._getDockPositionPoint(item.labelPosition, {left:item.LeftPosition,top:item.TopPosition, width: item.ItemWidth, height: item.ItemHeight }, bounds);
                
                $(label).css({
                    "left": pos.x,
                    "top": pos.y,
                    "height": item.ItemHeight,
                    "width":item.ItemWidth,
                    "pointer-events": "none",
                    "overflow":"hidden"
                });
                if (item.labelVisibilityMode == ej.datavisualization.TreeMap.VisibilityMode.HideOnExceededLength) {
                    if (bounds.height > item.ItemHeight || bounds.width > item.ItemWidth) {
                        $(label).css("display", "none");
                    }
                }


            }

        },

        /**
       * Generates headers
       * @private
       */
        _generateHeaders: function (headerValue,level) {           
			var textMode = level.headerVisibilityMode;
			var generateHeader = false;
			var leftpadding = 2;
			var toppadding = 2;
			if (textMode == ej.datavisualization.TreeMap.VisibilityMode.HideOnExceededLength) {
				var textelement = $('<span>'+headerValue.header+'</span>');
				$(document.body).append(textelement);
				var width = textelement.outerWidth();
				textelement.remove();
				if (headerValue.headerHeight < (headerValue.ItemHeight- (2 * leftpadding)) && width < (headerValue.ItemWidth-(2 * toppadding))){
					generateHeader = true;
				}					
			}
			else {
				if (headerValue.headerHeight < headerValue.ItemHeight){
					generateHeader = true;
				}
			}
			if(generateHeader) {
				if (headerValue.headerTemplate == null) {
						var headerItem = $('<div style="display:block;position:absolute;pointer-events: stroke;overflow: hidden;"><label style="font-size:15px;font-weight:normal;font-family:Segoe UI;">' + headerValue.header + '</label></div>');
							$(headerItem).css({
								"left": headerValue.headerLeftPosition+leftpadding,
								"top": headerValue.headerTopPosition+toppadding,
								"width": headerValue.headerWidth - level.groupPadding,
								"height": headerValue.headerHeight,
								"margin-left": level.groupPadding                    
							});
						this._templateDiv.append(headerItem);
				}
				else {
						var item_templateDiv = $("<div style='display:block;position:absolute;pointer-events: none;overflow: hidden;'></div>");
						this._templateDiv.append(item_templateDiv);
						$(item_templateDiv).css({
							"left": headerValue.headerLeftPosition,
							"width": headerValue.headerWidth, "top": headerValue.headerTopPosition,
							"height": headerValue.headerHeight
						});
						var htmlString = $("#" + headerValue.headerTemplate).render(headerValue);
						$(item_templateDiv).html(htmlString);
				}
			}
        },

        _drillDownHeader: function (header, enableNavigation) {
            var item_templateDiv = $("<div class='e-drilldownHeader' style='display:block;overflow: hidden;'><div class='e-treemapheader' style='margin-top:5px;height:30px;position:absolute;'>" + header + "</div></div>");

            if (enableNavigation)
                item_templateDiv = $("<div class='e-drilldownHeader' style='display:block;overflow: hidden;'><svg style='margin-top:10px;width:15px;height:15px'><polyline points='8,0 8,10 0,5 8,0' style='fill:white;stroke:white'/></svg><div class='e-treemapheader'  style='left:17px;top:0px;position:absolute;margin-top:6px;height:30px;position:absolute'>" + header + "</div></div>");
            
            $(item_templateDiv).css({
                "left": "0px",
                "width": this._width+"px","top": 0,
                "height": "30px", "color":"white", "font-size": "15px","text-indent":"10px","cursor":"pointer"
            });    
            if(this.model.drillDownHeaderColor!=null)
            {
			    $(item_templateDiv).css("background-color",this.model.drillDownHeaderColor);
            }			
            this._drillHeaderDiv.append(item_templateDiv);
            $(item_templateDiv).mousedown({ treemap: this }, this._drilldownfunction);
            this._header = header;
        },

        _drilldownfunction: function (event) {
            var treeMap = event.data.treemap;                       
            if (treeMap._drilldownItems.length > 0) {
                if (treeMap._drilldownItems.length == 1) {
                    treeMap._drilldownItems = [];
                    treeMap.refresh();
                }
                else {
                    var header = "";
                    for (var i = 0; i < treeMap._drillHeaderDiv[0].children[0].children.length; i++) {
                        if (treeMap._drillHeaderDiv[0].children[0].children[i].className == "e-treemapheader")
                            header = treeMap._drillHeaderDiv[0].children[0].children[i].innerHTML;
                    }
                    var headers = header.split(".");
                    treeMap._drillHeaderDiv[0].innerHTML = "";
                    var drillHeader = "";
                    for (i = 0; i < headers.length - 1; i++) {
                        drillHeader = drillHeader + headers[i];
                        if (i != headers.length - 2)
                            drillHeader = drillHeader + ".";
                    }
                    treeMap._labelTemplateElements = [];
                    treeMap._drillDownHeader(drillHeader, true);
                    treeMap._drilldownItem = treeMap._drilldownItems[treeMap._drilldownItems.length - 2];
                    treeMap._drilldownItems.pop(treeMap._drilldownItems[treeMap._drilldownItems.length - 1]);
                    treeMap._templateDiv[0].innerHTML = "";
                    treeMap._groupdrillDownLevels(treeMap._drilldownItem, treeMap._drilldownItems.length);
                }
                treeMap._trigger("drillDownItemSelected", { level: treeMap._drilldownItems.length, header: treeMap._header, prevLevel: treeMap._drilldownItems.length - 1 });
            }            
        },

        _sizeCalculation : function() {
            if (this.model.legendSettings != null) {

                    if (this.model.legendSettings.dockPosition == ej.datavisualization.TreeMap.DockPosition.Bottom) {
                        this._height = this._height - parseFloat(this.model.legendSettings.height);
                    }

                    else if (this.model.legendSettings.dockPosition == ej.datavisualization.TreeMap.DockPosition.Top) {
                        this._height = this._height - parseFloat(this.model.legendSettings.height);
                        this._width = this._width;
                        this._margintop = parseFloat(this.model.legendSettings.height);
                    }
                    else if (this.model.legendSettings.dockPosition == ej.datavisualization.TreeMap.DockPosition.Left) {
                        this._height = this._height;
                        this._width = this._width - parseFloat(this.model.legendSettings.width);
                        this._marginleft = parseFloat(this.model.legendSettings.width);
                    }
                    else if (this.model.legendSettings.dockPosition == ej.datavisualization.TreeMap.DockPosition.Right) {
                        this._height = this._height;
                        this._width = this._width - parseFloat(this.model.legendSettings.width);
                    }
                    else {
                        this._height = this._height;
                        this._width = this._width;
                    }
            }

        },


        _getDockPositionPoint:function(position,size,bounds)
        {
            var x=0,y=0;
            if (position == ej.datavisualization.TreeMap.Position.TopLeft) {
                x=0;
                y=0;
            }
            else if (position == ej.datavisualization.TreeMap.Position.TopCenter) {
                x = (size.width/2)-(bounds.width/2);
                y = 0;
            }
            else if (position == ej.datavisualization.TreeMap.Position.TopRight) {
                x = size.width - bounds.width;
                y = 0;
            }
            else if (position == ej.datavisualization.TreeMap.Position.CenterLeft) {
                x = 0;
                y = (size.height / 2) - (bounds.height / 2);
            }
            else if (position == ej.datavisualization.TreeMap.Position.Center || position!=null) {
                x = (size.width / 2) - (bounds.width / 2);
                y = (size.height / 2) - (bounds.height / 2);
            }
            else if (position == ej.datavisualization.TreeMap.Position.CenterRight) {
                x = size.width - bounds.width;
                y = (size.height / 2) - (bounds.height / 2);
            }
            else if (position == ej.datavisualization.TreeMap.Position.BottomLeft) {
                x = 0;
                y = size.height - bounds.height;
            }
            else if (position == ej.datavisualization.TreeMap.Position.BottomCenter) {
                x = (size.width / 2) - (bounds.width / 2);
                y = size.height - bounds.height;
            }
            else if (position == ej.datavisualization.TreeMap.Position.BottomRight) {
                x = size.width - bounds.width;
                y = size.height - bounds.height;
            }
            return {x:size.left+x,y:size.top+y};
        },
       
        /**
          * Generates treemap items
          * @private
          */
        _generateTreeMapItems: function (Items, fill, path) {
		     this._rootTreeMapItems= Items;
            this._getTreeMapItemTemplate(Items);
            if (Items != null) {
			this._setColorMappings(Items, this.model);
                for (var i = 0; i < Items.length; i++) {
                    var item = Items[i];                    
                                      
                    var rect = item.rectangle;
                    if (item.Data != null && item.Data.length>0) {
                        item.Data = item.Data[0];
                    }
                    item.Rectangle = rect;
					if(item.backgroundColor!=null)
					$(rect).css("background-color",item.backgroundColor);
					else
					$(rect).css("background-color","#E5E5E5");
					if(item.backgroundOpacity !=null)
					{
					   $(rect).css("opacity",item.backgroundOpacity);
					}
					this._wireEventForTreeMapItem(item, rect);
                 
                }
                if (this.model.rangeColorMapping.length == 0 && this.model.uniColorMapping.color == null && this.model.desaturationColorMapping.color != null) {
                    this._setDesaturationColor(Items, this.model.desaturationColorMapping);
                }
                else if (this.model.PaletteColorMapping != null) {
                    this._setPaletteColor(Items, this.model.PaletteColorMapping);
                }
            }
        },

        _wireEventForTreeMapItem: function (item,rect) {
            $(rect).mouseenter({ Param1: item, Param2: this }, this._rectMouseEnter);
            $(rect).mousemove({ Param1: item, Param2: this }, this._rectMouseMove);
            $(rect).mouseleave({ treeMap: this }, this._rectMouseLeave);
            $(rect).mouseup({ treeMap: this }, this._docClickFunction);
            this._on($(rect), ej.eventType.mouseDown, { Param1: item.Data, rect: rect }, this._rectClickFunction);
        },

        /**
          * Gets treemap item template
          * @private
          */
        _getTreeMapItemTemplate: function (Items) {            
            
            var rects ="";
            for (var i = 0; i < Items.length; i++) {
                var item = Items[i];
                if (this.model.leafItemSettings.itemTemplate == null)
                    rects += '<div style="border-style:solid;position:absolute;left:' + item.LeftPosition + 'px;top:' + item.TopPosition + 'px;height:' + item.ItemHeight + 'px;width:' + item.ItemWidth + 'px;border-width:' + this.model.leafItemSettings.borderThickness + 'px;border-color:' + this.model.leafItemSettings.borderBrush + '"></div>';
                else {
                    var OriginalNode = $("#" + this.model.leafItemSettings.itemTemplate);
                    if (item.Data != null && item.Data.length == 1) {
                        item.Data = item.Data[0];
                    }
                    var tmpl2 = $.templates(OriginalNode.html());
                    var htmlString = "<div style='overflow:hidden;position:absolute;pointer-events: none;left:" + item.LeftPosition + "px;top:" + item.TopPosition + "px;height:" + item.ItemHeight + "px;width:" + item.ItemWidth + "px'>" + tmpl2.render(item) + "</div>";
                    rects += htmlString;
                }
            }
            if (this._svgDocument != null && this.model.enableDrillDown) {
                this._svgDocument[0].innerHTML = "";
            }
            this._svgDocument = $('<div style= "overflow:hidden;' +
                              'z-index:1;"' +
                             'id="svgDocument">' + rects + '</div>');
            this._backgroundTile.appendTo(this.element);
            this._svgDocument.appendTo(this.element);           
            this._svgDocument.css({
                "height": this._height + "px", "width": this._width + "px", "margin-top": this._margintop + "px", "margin-left": this._marginleft, "overflow": "hidden",
                "z-index": 1, "position": "absolute", "left": "0", "top": "0"
            });
            $(this._backgroundTile).css({
                "height": this._height + "px", "width": this._width + "px", "margin-top": this._margintop + "px", "margin-left": this._marginleft, "overflow": "hidden",
                "z-index": 0, "position": "absolute", "left": "0", "top": "0"
            });
            this._templateDiv.appendTo(this.element);
            if (this.model.enableDrillDown) {
                this._drillHeaderDiv.appendTo(this.element);
                this._drillHoverDiv.appendTo(this.element);
            }
            for (var i = 0; i<Items.length; i++) {
                Items[i].rectangle = this._svgDocument[0].childNodes[i];
            }
        },

        /**
         * Section For handling mouse click event for treemap item
         * @private
         */
        _rectClickFunction: function (event) {
            var ctrlkey = event.ctrlKey;
            var treeMap = this;
            var rect = event.data.rect;
            if (treeMap.model.highlightOnSelection) {
                if (treeMap._browser != "msie") {
                    var lastItem = treeMap._svgDocument[0].children[treeMap._svgDocument[0].children.length - 1];
                    treeMap._svgDocument[0].insertBefore(rect, lastItem);
                }
                if (ctrlkey) {
                    if ($.inArray(rect, treeMap._prevSelectedItems) == -1) {
                        $(rect).css({ "border-width": treeMap.model.highlightBorderThickness, "border-color": treeMap.model.highlightBorderBrush });
                        treeMap._prevSelectedItems.push(rect);
                        treeMap._prevSelectedItemDatas.push(event.data.Param1);
                    }
                    else {
                        $(rect).css({ "border-width": treeMap.model.leafItemSettings.borderThickness, "border-color": treeMap.model.leafItemSettings.borderBrush });
                        var index = treeMap._prevSelectedItems.indexOf(rect);
                        treeMap._prevSelectedItems.splice(index, 1);
                        treeMap._prevSelectedItemDatas.splice(index,1);
                    }
                }
                else {
                    for (var k = 0; k < treeMap._prevSelectedItems.length; k++) {
                        $(treeMap._prevSelectedItems[k]).css({ "border-width": treeMap.model.leafItemSettings.borderThickness, "border-color": treeMap.model.leafItemSettings.borderBrush });
                    }

                    if ($.inArray(rect, treeMap._prevSelectedItems) == -1) {
                        $(rect).css({ "border-width": treeMap.model.highlightBorderThickness, "border-color": treeMap.model.highlightBorderBrush });
                        treeMap._prevSelectedItems = [];
						treeMap._prevSelectedItemDatas=[];
						treeMap._prevSelectedItems.push(rect);
						 treeMap._prevSelectedItemDatas.push(event.data.Param1);
                    }
                    else {
                        treeMap._prevSelectedItems = [];
                    }                    
                   
                }
            }

            var element = treeMap._toolTipElement;
            var position;
            if (event.type == "mousedown")
                position = { x: event.pageX, y: event.pageY };
            else if (event.type == "touchstart")
                position = { x: event.originalEvent.changedTouches[0].pageX, y: event.originalEvent.changedTouches[0].pageY };
            else if (event.type == "MSPointerDown")
                position = { x: event.originalEvent.pageX, y: event.originalEvent.pageY };
            var tooltipSize = treeMap._tooltipSize;
            if (tooltipSize.width + position.x >= treeMap._width) {
                position.x -= tooltipSize.width;
            }
            if (tooltipSize.height + position.y >= treeMap._height) {
                position.y -= tooltipSize.height;
            }

            if (element != null && event.data.Param1!=null) {
                var template = treeMap.model.tooltipTemplate;
                $(element).css({ "left": position.x + 10, "top": position.y + 10, "display": "block" });
                var htmlString = $("#" + template).render(event.data.Param1);
                $(element).html(htmlString);
            }

            treeMap._trigger("treeMapItemSelected", {selectedItems:treeMap._prevSelectedItemDatas,originalEvent:event});
        },
        /**
         * Section For handling mouse enter event for  treemap item
         * @private
         */
        _rectMouseEnter: function(event) {
            var tooltipObject = event.data.Param1.Data;
            if (tooltipObject != null) {
                var element = event.data.Param2._toolTipElement;
                var template = event.data.Param2.model.tooltipTemplate;
                if (element != null && template != null) {
                    $(element).css({ "left": event.pageX+10, "top": event.pageY+10, "display": "block" });
                    var htmlString = $("#" + template).render(tooltipObject);
                    $(element).html(htmlString);
                    var height= element[0]!=null ? element[0].clientHeight : element.clientHeight;
					var width= element[0]!=null ? element[0].clientWidth : element.clientWidth;
                    event.data.Param2._tooltipSize = { height: height, width: width };
                    
                }
            }
        },
        /**
         * Section For handling mouse move event for  treemap item
         * @private
         */
        _rectMouseMove: function (event) {
		    var treeMap= event.data.Param2;
            var element = treeMap._toolTipElement;
            var tooltipSize = treeMap._tooltipSize;
            if (tooltipSize.width+ event.pageX >= treeMap._width) {
                event.pageX -= tooltipSize.width;              
            }
            if (tooltipSize.height+event.pageY >= treeMap._height) {
                event.pageY -= tooltipSize.height;
            }
            if (treeMap.model.enableDrillDown && treeMap._browser != 'msie') {
                for (var i = 0; i < treeMap._drillHoverDiv[0].children.length; i++) {
                    var child = treeMap._drillHoverDiv[0].children[i];
                    if (child.className == event.data.Param1.ParentHeader) {
                        $(child).css({ "display": "block" });
                    }
                }
            }
                if (element != null) {
                    $(element).css({ "left": event.pageX+10, "top": event.pageY+10, "display": "block" });
                }
        },

        /**
        * Section For handling mouse leave event for  treemap item
        * @private
        */
        _rectMouseLeave: function (event) {            
            var element = event.data.treeMap._toolTipElement;
            if (element != null) {
                $(element).css("display", "none");
            }
        },
		
		_docClickFunction: function(event) {
            var element = event.data.treeMap._toolTipElement;
            if (element != null) {
                $(element).delay(200).queue( function(next){ 
						$(this).css('display','none'); 
						next();
				});
            }
        },

        /**
		* Sets ColorMappings for the treemap items
		* @private
		*/		
		
		_setColorMappings: function(Items, colorMappings){
			for (var i = 0; i < Items.length; i++) {			
				if ((colorMappings.rangeColorMapping != null && colorMappings.rangeColorMapping.length>0) || (colorMappings.uniColorMapping!=null && colorMappings.uniColorMapping.color != null)){					
					var ColorValue = Items[i]._generateColorMappings(colorMappings);
					 Items[i].backgroundColor = ColorValue;
				}
				else if (colorMappings.desaturationColorMapping != null && colorMappings.desaturationColorMapping.color != null){
					this._setDesaturationColor(Items, colorMappings.desaturationColorMapping);
				}
				else if (colorMappings.paletteColorMapping != null){
					this._setPaletteColor(Items, colorMappings.paletteColorMapping);
				}
			}
		},
        /**
        * Sets desaturation color for treemap items
        * @private
        */
        _setDesaturationColor: function (Items, desaturationColorMapping) {
		    Items = Items.sort(this._orderBycolorWeight);
            var from = desaturationColorMapping.from;
            var to = desaturationColorMapping.to;
            if (from < 0 || from > 1)
                from = 1;
            if (to > 1 || to < 0)
                to = 0;

            var interval = (from - to) / Items.length;
            for (var i = 0; i < Items.length; i++) {
               Items[i].backgroundColor = desaturationColorMapping.color;
                if (Items[i].colorWeight >= desaturationColorMapping.rangeMinimum && Items[i].colorWeight <= desaturationColorMapping.rangeMaximum) {
                    Items[i].backgroundOpacity= from;
                    from = from - interval;
                }
            }
        },

        /**
        * Sets palette color for treemap items
        * @private
        */
        _setPaletteColor: function (Items, PaletteColors) {
            Items = Items.sort(this._orderBycolorWeight);
            for (var i = 0; i < Items.length; i++) {
                if (PaletteColors.colors != null && PaletteColors.colors.length > 0) {
					Items[i].backgroundColor= PaletteColors.colors[i % (PaletteColors.colors.length)];
                } 
            }
        },

        /**
        * Orders items by color weight
        * @private
        */
        _orderBycolorWeight: function (a, b) {
            if (a.colorWeight == b.colorWeight) {
                return 0;
            } else if (a.colorWeight < b.colorWeight) {
                return 1;
            }
            return -1;
        },
       /**
       * Orders items by area weight
       * @private
       */
        _orderByAreaWight: function (a, b) {
            if (a.AreaByWeight == b.AreaByWeight) {
                return 0;
            } else if (a.AreaByWeight < b.AreaByWeight) {
                return 1;
            }
            return -1;
        },

        /**
       * Calculates slice and dice item size 
       * @private
       */
        _calculateSliceAndDiceItemSize: function (Items, xPos, yPos, width, height, gap, headerHeight, isHorizontal,legendHeight) {

            var Gap = gap;
            var totalWeight = this._getTotalWeight(Items);
            if (isHorizontal == undefined) {
                isHorizontal = width > height ? true : false;
            }
            var AvailableSize = { "Width": width, "Height": height-legendHeight };
            var headerSize = headerHeight < AvailableSize.Height ? headerHeight : 0;
            AvailableSize.Height = AvailableSize.Height - headerSize;
            var AvailableArea = { "X": xPos, "Y": yPos + headerSize, "Width": AvailableSize.Width, "Height": AvailableSize.Height };
            var parentArea = AvailableSize.Height * AvailableSize.Width;
            var itemsCount = Items.length;
            if (isHorizontal) {
                var parentHeight = AvailableSize.Height;
                var allottedWidth = 0;
                for (var i = 0; i < itemsCount; i++) {
                    var childarea = (parentArea / totalWeight) * Items[i].weight;
                    var childWidth = childarea / parentHeight;
                    gap = (childWidth > Gap) ? Gap : 0;

                    if (allottedWidth <= AvailableSize.Width) {
                        Items[i].ItemWidth = (i != itemsCount - 1) ? childWidth - gap : childWidth;
                        Items[i].ItemHeight = parentHeight;
                        Items[i].LeftPosition = allottedWidth + xPos;
                        Items[i].TopPosition = yPos + headerHeight;
                        allottedWidth += childWidth;
                    }
                }
            }
            else {
                var parentWidth = AvailableSize.Width;
                var allottedHeight = 0;
                for (var i = 0; i < itemsCount; i++) {
                    var childarea = (parentArea / totalWeight) * Items[i].weight;
                    var childHeight = childarea / parentWidth;
                    gap = (childHeight > Gap) ? Gap : 0;
                    if (allottedHeight <= AvailableSize.Height) {
                        Items[i].ItemWidth = parentWidth;
                        Items[i].ItemHeight = (i != itemsCount - 1) ? childHeight - gap : childHeight;
                        Items[i].LeftPosition = xPos;
                        Items[i].TopPosition = allottedHeight + yPos + headerSize;
                        allottedHeight += childHeight;
                    }
                }
            }
        },

        /**
       * Calculates squarified item size
       * @private
       */
        _calculateSquarifiedItemSize: function (Items, xPos, yPos, width, height, Gap, headerHeight, legendHeight) {
            var totalweight = this._getTotalWeight(Items);
            var AvailableSize = { "Width": width, "Height": height-legendHeight };
            var headerSize = headerHeight < AvailableSize.Height ? headerHeight : 0;
            AvailableSize.Height = AvailableSize.Height - headerSize;
            for (var i = Items.length - 1; i >= 0; i--) {
                var item = Items[i];
                item["AreaByWeight"] = (AvailableSize.Height * AvailableSize.Width) * item.weight / totalweight;
                item.headerTopPosition = yPos;
            }
            var AvailableArea = { "X": xPos, "Y": yPos + headerSize, "Width": AvailableSize.Width, "Height": AvailableSize.Height };
            var OrderedItems = Items.sort(this._orderByAreaWight);
            var curX = 0, curY = 0;
            var j = 0;
            for (var i = 0; i < Items.length; i = j) {
                var firstTreemapItem = OrderedItems[i];
                weightObject = this._getGroupTotalWeight(firstTreemapItem, OrderedItems, AvailableArea, i);
                var GroupTotalWeight = weightObject.totalWeight;
                j = weightObject.index;
                var currentRect = {};
                var isHorizontal = (AvailableArea.Width > AvailableArea.Height) ? true : false;
                for (var k = i; k < j; k++) {
                    var item = OrderedItems[k];
                    var areaSum = GroupTotalWeight;
                    if (k == i) {
                        currentRect.X = AvailableArea.X;
                        currentRect.Y = AvailableArea.Y;
                        if (isHorizontal) {
                            currentRect.Width = areaSum / AvailableArea.Height;
                            currentRect.Height = AvailableArea.Height;
                            AvailableArea.X += currentRect.Width;
                            AvailableArea.Width = Math.max(0, AvailableArea.Width - currentRect.Width);
                        }
                        else {
                            currentRect.Width = AvailableArea.Width;
                            currentRect.Height = areaSum / AvailableArea.Width;
                            AvailableArea.Y += currentRect.Height;
                            AvailableArea.Height = Math.max(0, AvailableArea.Height - currentRect.Height);
                        }
                        curX = currentRect.X;
                        curY = currentRect.Y;
                    }
                    var rect = {};
                    if (OrderedItems.indexOf(item) != OrderedItems.length - 1) {
                        rect.X = 0;
                        rect.Y = 0;
                        rect.Width = (isHorizontal) ? currentRect.Width - Gap : item.AreaByWeight / currentRect.Height;
                        rect.Height = (isHorizontal) ? item.AreaByWeight / currentRect.Width : currentRect.Height - Gap;
                        if (j - k != 1) {
                            if (isHorizontal) {
                                rect.Height -= Gap;
                            }
                            else {
                                rect.Width -= Gap;
                            }
                        }
                    }
                    else {
                        rect.Width = (isHorizontal) ? currentRect.Width : item.AreaByWeight / currentRect.Height;
                        rect.Height = (isHorizontal) ? item.AreaByWeight / currentRect.Width : currentRect.Height;
                    }
                    item.ItemWidth = rect.Width;
                    item.ItemHeight = rect.Height;
                    item.LeftPosition = curX;
                    item.TopPosition = curY;
                    if (isHorizontal) {
                        curY += (j - k != 1) ? rect.Height + Gap : rect.Height;
                    }
                    else {
                        curX += (j - k != 1) ? rect.Width + Gap : rect.Width;
                    }
                }
            }
        },

        /**
      * Gets group total weight
      * @private
      */
        _getGroupTotalWeight: function (firstTreemapItem, OrderedItems, AvailableArea, j) {
            var GroupTotalWeight = 0;
            var GroupMaxAspectRatio = 0;
            for (; j < OrderedItems.length; j++) {
                var ShorterSideLength = this._getShortersideLength(AvailableArea.Width, AvailableArea.Height);
                var lastTreemapItem = OrderedItems[j];
                GroupTotalWeight += lastTreemapItem.AreaByWeight;
                var GroupWidth = GroupTotalWeight / ShorterSideLength;
                var firstitemheight = firstTreemapItem.AreaByWeight / GroupWidth;
                var lastitemheight = lastTreemapItem.AreaByWeight / GroupWidth;
                if (j == 0)
                    GroupMaxAspectRatio = this._aspectRatio(GroupWidth, ShorterSideLength);
                var TempAspectRatio = Math.max(this._aspectRatio(firstitemheight, GroupWidth), this._aspectRatio(lastitemheight, GroupWidth));
                if (GroupTotalWeight == lastTreemapItem.AreaByWeight || TempAspectRatio < GroupMaxAspectRatio) {
                    GroupMaxAspectRatio = TempAspectRatio;
                }
                else {
                    GroupTotalWeight -= lastTreemapItem.AreaByWeight;
                    GroupWidth = GroupTotalWeight / ShorterSideLength;
                    GroupMaxAspectRatio = Math.max(this._aspectRatio(firstitemheight, GroupWidth), this._aspectRatio(lastitemheight, GroupWidth));
                    break;
                }
            }
            return { totalWeight: GroupTotalWeight, index: j };
        },

        /**
      * Calculates aspect ratio
      * @private
      */
        _aspectRatio: function (x, y) {
            return (x > y) ? (x / y) : (y / x);
        },

        /**
     * Calculates shorter side length
     * @private
     */
        _getShortersideLength: function (width, height) {
            return width > height ? height : width;
        },

        /**
     * Calculates total weight
     * @private
     */

        _getTotalWeight: function (Items) {
            var total = 0;
            for (var i = 0; i < Items.length; i++) {
                total += parseFloat(Items[i].weight);
            }
            return total;

        },

        /**
     * Gets group item
     * @private
     */
        _getGroupitem: function (path, dataSource, headerHeight) {
            var obj = [];            
            if (dataSource != null && this.weightValuePath() != null) {                
                    for (var i in dataSource) {
                        var item = dataSource[i];
                        if (item != null && item.hasOwnProperty(path) ? true : this._containsProperty(item,path)) {
                            var itemValue = this._reflection(item, path);
                            if ($.inArray(itemValue, obj) == -1) {
                                obj.push(itemValue);
                            }
                        }
                    }                
                var objCollection = [];
                for (var i = 0; i < obj.length; i++) {
                    var Coll = {};
                    var groupObj = [];
                    var groupId = obj[i];
                    var colorWeight = 0;
                    var weight = 0;
                    var count = 0;
                    for (var j = 0; j < dataSource.length;j++) {
                        var item = dataSource[j];
                        var itemValue = this._reflection(item, path);
                        if (itemValue == groupId) {
                            var weightValue = this._reflection(item, this.weightValuePath());
                            var colorWeightValue = this._reflection(item, this.colorValuePath());
                            groupObj.push(item);
                            count++;
                            if (weightValue != null) {
                                weight += parseFloat(weightValue);
                            }
                            if (colorWeightValue != null) {
                                colorWeight += parseFloat(colorWeightValue);
                            }
                        }
                    }
                    
                    Coll["header"] = groupId;
                    Coll["data"] = groupObj;
                    Coll["weight"] = weight;
                    Coll["colorWeight"] = colorWeight;
                    Coll["headerHeight"] = headerHeight;
                    if (weight > 0) {
                        var newTreemapItem = new treeMapItem(Coll);
                        objCollection.push(newTreemapItem);
                    }
                }
                return objCollection;
            }
            else { return null; }
        },

     /**
     * Gets top group item
     * @private
     */
        _getTopGroupitem: function (path, dataSource) {            
            if (path == null) path = this.model.leafItemSettings.labelPath;
            if (path == null) path = this.weightValuePath();
            var obj = [];
            var Coll = {};
            var weight = 0, colorWeight = 0;
            var groupId="";
            var innerobjCollection = [];
            var itemColl = [];
            for (var j = 0; j < dataSource.length; j++) {
                var item = dataSource[j];
                var itemValue = this._reflection(item, path);
                var innerColl={};
                var weightValue = this._reflection(item, this.weightValuePath());
                var colorWeightValue = this._reflection(item, this.colorValuePath());      
                if (weightValue != null) {
                    weight += parseFloat(weightValue);
                }
                if (colorWeightValue != null) {
                    colorWeight += parseFloat(colorWeightValue);
                }
                itemColl.push(item);
                innerColl["weight"] = weightValue;
                innerColl["data"] = item;                
                innerColl["header"] = itemValue;
                innerColl["colorWeight"] = colorWeightValue;                                       
                var newinnerTreemapItem = new treeMapItem(innerColl);
                innerobjCollection.push(newinnerTreemapItem);
            }        
            Coll["header"] = groupId;
            Coll["data"] = itemColl;
            Coll["weight"] = weight;
            Coll["innerItem"] = innerobjCollection;
            Coll["colorWeight"] = colorWeight;                                   
            var treemapColl = [];
            var treeitem = new treeMapItem(Coll);
            treemapColl.push(treeitem);
            return  treemapColl;
        },         
                     
        /**
        * Checks whether property exists in object
        * @private
        */
        _containsProperty: function (object, propertyName) {
              for (var key in object)
              {
                  if(key == propertyName)
                  {
                      return true;
                  }
              }
              return false;
        },

        /**
        * Gets property from object
        * @private
        */
        _reflection: function (Source, Path) {
            var ShapeValues = Source;
            if (Path != null && Source != null) {
                var parts = Path.split(".");
                var i = 0;
                for (; i < parts.length; i++) {
                    var hasProperty = ShapeValues.hasOwnProperty(parts[i]) ? true : this._containsProperty(ShapeValues,parts[i]);
                    if (hasProperty) {
                        $.each(ShapeValues, function (prop, propval) {
                            if (prop == parts[i]) {
                                ShapeValues = propval;
                                return false;
                            }
                        });
                    }
                }
                return ShapeValues;
            }
            else {
                return null;
            }

        }

    });
    /**
    * Hold the Level settings of TreeMap
    *  @memberof ejTreeMap
    * @member
    * @instance
    */
    var treeMapLevel = function () {

        /** 
        * specifies the group background
			 * @default null
             * @type {string} 
             * @example  
             * // Set the groupBackground during initialization. 			
             * 	$("#container").ejTreeMap({levels: [{ groupBackground:"white" }]})
             * @example 
             * //Get or set the groupBackground after initialization:<br>
             *   //Gets the groupBackground from map.
             *   var property =$("#container").data("ejTreeMap").model.levels[levelIndex].groupBackground;
             *   //Sets the groupBackground to map.
             *   $("#container").data("ejTreeMap").model.levels[levelIndex].groupBackground  = "white";
             * @alias ejTreeMap#treeMapLevel->groupBackground
             */
        this.groupBackground = null;

            /** 
            * Specifies the group border color for tree map level.
			 * @default null
             * @type {string} 
             * @example  
             * // Set the groupBorderColor during initialization. 			
             * 	$("#container").ejTreeMap({levels: [{ groupBorderColor:"#58585B" }]})
             * @example 
             * //Get or set the groupBorderColor after initialization:<br>
             *   //Gets the groupBorderColor from map.
             *   var property =$("#container").data("ejTreeMap").model.levels[levelIndex].groupBorderColor;
             *   //Sets the groupBorderColor to map.
             *   $("#container").data("ejTreeMap").model.levels[levelIndex].groupBorderColor  = "#58585B";
             * @alias ejTreeMap#treeMapLevel->groupBorderColor
             */
        this.groupBorderColor = null;

        /** 
        * Specifies the group border thickness for tree map level.
			 * @default 1
             * @type {number} 
             * @example  
             * // Set the groupBorderThickness during initialization. 			
             * 	$("#container").ejTreeMap({levels: [{ groupBorderThickness:1 }]})
             * @example 
             * //Get or set the groupBorderThickness after initialization:<br>
             *   //Gets the groupBorderThickness from map.
             *   var property =$("#container").data("ejTreeMap").model.levels[levelIndex].groupBorderThickness;
             *   //Sets the groupBorderThickness to map.
             *   $("#container").data("ejTreeMap").model.levels[levelIndex].groupBorderThickness  = 1;
             * @alias ejTreeMap#treeMapLevel->groupBorderThickness
             */
        this.groupBorderThickness = 1;

/** 
        * Specifies the group padding for tree map level.
			 * @default 4
             * @type {number} 
             * @example  
             * // Set the groupPadding during initialization. 			
             * 	$("#container").ejTreeMap({levels: [{ groupPadding:4 }]})
             * @example 
             * //Get or set the groupPadding after initialization:<br>
             *   //Gets the groupPadding from map.
             *   var property =$("#container").data("ejTreeMap").model.levels[levelIndex].groupPadding;
             *   //Sets the groupPadding to map.
             *   $("#container").data("ejTreeMap").model.levels[levelIndex].groupPadding  = 4;
             * @alias ejTreeMap#treeMapLevel->groupPadding
             */
        this.groupPadding = 4;

        /** 
        * Specifies the group path for tree map level.
             * @type {string} 
             * @example  
             * // Set the groupPath during initialization. 			
             * 	$("#container").ejTreeMap({levels: [{ groupPath:"pathName" }]})
             * @example 
             * //Get or set the groupPath after initialization:<br>
             *   //Gets the groupPath from map.
             *   var property =$("#container").data("ejTreeMap").model.levels[levelIndex].groupPath;
             *   //Sets the groupPath to map.
             *   $("#container").data("ejTreeMap").model.levels[levelIndex].groupPath  = "pathName";
             * @alias ejTreeMap#treeMapLevel->groupPath
             */
        this.groupPath = null;

        /**
        * Specifies the group gap for tree map level.
			 * @default 1
             * @type {number} 
             * @example  
             * // Set the groupGap during initialization. 			
             * 	$("#container").ejTreeMap({levels: [{ groupGap:1 }]})
             * @example 
             * //Get or set the groupGap after initialization:<br>
             *   //Gets the groupGap from map.
             *   var property =$("#container").data("ejTreeMap").model.levels[levelIndex].groupGap;
             *   //Sets the groupGap to map.
             *   $("#container").data("ejTreeMap").model.levels[levelIndex].groupGap  = 1;
             * @alias ejTreeMap#treeMapLevel->groupGap
             */
        this.groupGap = 1;

        /**
        * Specifies the header height for tree map level.
			 * @default 0
             * @type {number} 
             * @example  
             * // Set the headerHeight during initialization. 			
             * 	$("#container").ejTreeMap({levels: [{ headerHeight:20 }]})
             * @example 
             * //Get or set the headerHeight after initialization:<br>
             *   //Gets the headerHeight from map.
             *   var property =$("#container").data("ejTreeMap").model.levels[levelIndex].headerHeight;
             *   //Sets the headerHeight to map.
             *   $("#container").data("ejTreeMap").model.levels[levelIndex].headerHeight  = 1;
             * @alias ejTreeMap#treeMapLevel->headerHeight
             */
        this.headerHeight = 20;

        /** 
        * Shows or hides the header for tree map level.
            * @default false
            * @type {bool} 
            * @example  
            * // Set the shoeHeader during initialization. 			
            * 	$("#container").ejTreeMap({levels: [{ showHeader:false }]})
            * @example 
            * //Get or set the showHeader after initialization:<br>
            *   //Gets the showHeader from treemap.
            *   var property =$("#container").data("ejTreeMap").model.levels[levelIndex].showHeader;
            *   //Sets the headerHeight to map.
            *   $("#container").data("ejTreeMap").model.levels[levelIndex].showHeader  = true;
            * @alias ejTreeMap#treeMapLevel->showHeader
            */
        this.showHeader = true;

        /**
        * Shows or hides the labels for tree map level.
             * @default false
             * @type {boolean} 
             * @example  
             * // Set the showLabels during initialization. 			
             * 	$("#container").ejTreeMap({levels: [{ showLabels:false }]})
             * @example 
             * //Get or set the showLabels after initialization:<br>
             *   //Gets the showLabels from map.
             *   var property =$("#container").data("ejTreeMap").model.levels[levelIndex].showLabels;
             *   //Sets the showLabels to map.
             *   $("#container").data("ejTreeMap").model.levels[levelIndex].showLabels  = false;
             * @alias ejTreeMap#treeMapLevel->showLabels
             */
        this.showLabels = false;

        /** 
        * Specifies the header template for tree map level.
         * @default null
             * @type {string} 
             * @example  
             * // Set the headerTemplate during initialization. 			
             * 	$("#container").ejTreeMap({levels: [{ headerTemplate:"template" }]})
             * @example 
             * //Get or set the headerTemplate after initialization:<br>
             *   //Gets the headerTemplate from map.
             *   var property =$("#container").data("ejTreeMap").model.levels[levelIndex].headerTemplate;
             *   //Sets the headerTemplate to map.
             *   $("#container").data("ejTreeMap").model.levels[levelIndex].headerTemplate  = "template";
             * @alias ejTreeMap#treeMapLevel->headerTemplate
             */
        this.headerTemplate = null;
        /**
        * Specifies the label template for tree map level.
        * @default null
             * @type {string} 
             * @example  
             * // Set the labelTemplate during initialization. 			
             * 	$("#container").ejTreeMap({levels: [{ labelTemplate:"template" }]})
             * @example 
             * //Get or set the labelTemplate after initialization:<br>
             *   //Gets the labelTemplate from map.
             *   var property =$("#container").data("ejTreeMap").model.levels[levelIndex].labelTemplate;
             *   //Sets the labelTemplate to map.
             *   $("#container").data("ejTreeMap").model.levels[levelIndex].labelTemplate  = "template";
             * @alias ejTreeMap#treeMapLevel->labelTemplate
             */
        this.labelTemplate = null;


        /**
              * Specifies the position of the labels.
              * @default center
              * @type{ej.datavisualization.TreeMap.Position}
              * @example 
              * //To set labelPosition API value during initialization 
              *   $("#container").ejTreeMap({levels:[{ labelPosition: "center"]}});
              * @example 
              * //Get or set the labelPosition API, after initialization:<br>
              *	//Gets the labelPosition value 
              *   var property =$("#container").data("ejTreeMap").model.levels[0].labelPosition;<br> 
              *	//Sets the labelPosition value 
              *	$("#container").data("ejTreeMap").model.levels[0].labelPosition= "topleft"; 
              * @alias ejTreeMap#treeMapLevel->labelPosition
              * @instance
              */
        this.labelPosition = "center";


        /**
       * Specifies the mode of label visibility
       * @default visible
       * @type{ej.datavisualization.TreeMap.VisibilityMode}
       * @example 
       * //To set labelVisibilityMode API value during initialization 
       *   $("#container").ejTreeMap({levels:[{ labelVisibilityMode: "visible"}]});
       * @example 
       * //Get or set the labelVisibilityMode API, after initialization:<br>
       *	//Gets the labelVisibilityMode value 
       *   var property =$("#container").data("ejTreeMap").model.levels[0].labelVisibilityMode;<br> 
       *	//Sets the labelVisibilityMode value 
       *	$("#container").data("ejTreeMap").model.levels[0].labelVisibilityMode= "visible"; 
       * @alias ejTreeMap#treeMapLevel->labelVisibilityMode
       * @instance
       */
        labelVisibilityMode = "visible";

        /**
     * Specifies the mode of header visibility
     * @default visible
     * @type{ej.datavisualization.TreeMap.VisibilityMode}
     * @example 
     * //To set labelVisibilityMode API value during initialization 
     *   $("#container").ejTreeMap({levels:[{ headerVisibilityMode: "visible"}]});
     * @example 
     * //Get or set the headerVisibilityMode API, after initialization:<br>
     *	//Gets the headerVisibilityMode value 
     *   var property =$("#container").data("ejTreeMap").model.levels[0].headerVisibilityMode;<br> 
     *	//Sets the headerVisibilityMode value 
     *	$("#container").data("ejTreeMap").model.levels[0].headerVisibilityMode= "visible"; 
     * @alias ejTreeMap#treeMapLevel->headerVisibilityMode
     * @instance
     */
        headerVisibilityMode = "visible";

        this.treeMapItems = [];
    };

    treeMapLevel.prototype = {

    };

    var treeMapItem = function (params) {
        this.weight = params.weight;
        this.colorWeight = params.colorWeight;
        this.Data = params.data;
        this.headerHeight = params.headerHeight;
        this.header = params.header;
        this.label = params.header;
        this.headerLeftPosition = 0;
        this.headerTopPosition = 0;
        this.innerItems = params.innerItem;
        this.headerWidth = 0;
        this.headerTemplate = null;

    };

    treeMapItem.prototype = {
        /**
        * Generates color mapping for treemap items
        * @private
        */
        _generateColorMappings: function (colorMappings) {
            if (colorMappings.rangeColorMapping != null && colorMappings.rangeColorMapping.length > 0) {
                return this._getRangeBrushColor(colorMappings.rangeColorMapping);
            }
            if (colorMappings.uniColorMapping.color != null && colorMappings.uniColorMapping!=null) {
                return this._getUniColor(colorMappings.uniColorMapping);
            }
        },

        /**
        * Get unicolor for treemap items
        * @private
        */
        _getUniColor: function (uniColorMapping) {

            return uniColorMapping.color;
        },

        /**
        * Get range brush color for treemap items
        * @private
        */
        _getRangeBrushColor: function (rangeColorMapping) {
            for (var j = 0; j < rangeColorMapping.length; j++) {
                var rangeBrush = rangeColorMapping[j];
                if (this.colorWeight >= rangeBrush.from && this.colorWeight <= rangeBrush.to) {
                    return rangeBrush.color;
                }
            }
        }

    };
	
	/**
    * Enum for TreeMap items layout mode
    * @enum {string}
    * @global 
    */
	ej.datavisualization.TreeMap.ItemsLayoutMode = {
			Squarified: "squarified",
			SliceAndDiceHorizontal: "sliceanddicehorizontal",
			SliceAndDiceVertical: "sliceanddicevertical",
			SliceAndDiceAuto: "sliceanddiceauto"
	};  
	
	ej.datavisualization.TreeMap.SelectionMode={
		Default: "default",
		Multiple: "multiple"
	};
	
	ej.datavisualization.TreeMap.GroupSelectionMode={
		Default: "default",
		Multiple: "multiple"
	};

	ej.datavisualization.TreeMap.DockPosition = {
	    Top: "top",
	    Bottom: "bottom",
	    Right: "right",
	    Left: "left"
	};

	ej.datavisualization.TreeMap.Position = {
	    TopLeft: "topleft",
	    TopCenter: "topcenter",
	    TopRight: "topright",
	    CenterLeft: "centerleft",
	    Center: "center",
	    CenterRight: "centerright",
	    BottomLeft: "bottomleft",
	    BottomCenter: "bottomcenter",
        BottomRight:"bottomright"
	};

	ej.datavisualization.TreeMap.VisibilityMode = {
		Visible:"visible",
		HideOnExceededLength:"hideonexceededlength"
	};
})(jQuery, Syncfusion);
;
});