/*!
*  filename: ej.colorpicker.js
*  version : 12.3
*  Copyright Syncfusion Inc. 2001 - 2014. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
*/
(function (fn) {
    typeof define === 'function' && define.amd ? define(["./../common/ej.core","./../common/ej.button","./ej.slider","./ej.splitbutton","./ej.menu"], fn) : fn();
})
(function () {
	
/**
* @fileOverview Plugin provides support to display color picker within your web page and allows to pick the color.
* @copyright Copyright Syncfusion Inc. 2001 - 2014. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.3 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/
(function ($, ej, undefined) {
    /**
  * @namespace ej
  * @classdesc Custom Design for Html color picker control.
  * @class ejColorPicker
  * @param {object} options - settings for color picker
  * @requires jQuery
  * @requires jquery.easing.1.3.js
  * @requires ej.core.js
  * @requires ej.colorpicker.js
  * @requires ej.button.js
  * @requires ej.splitbutton.js
  * @requires ej.menu.js
  * @requires ej.slider.js
  * @example   
  * &lt;input type="text" id="colorPick"/&gt; <br> 
  * &lt;script&gt;
  * // Create Color picker
  * $('#colorPick').ejColorPicker({ value: "#278787" });
  * &lt;/script&gt;
  */
    ej.widget("ejColorPicker", "ej.ColorPicker", {
        _rootCSS: "e-colorpicker",
        // widget element will be automatically set in this
        element: null,

        // user defined model will be automatically set in this
        model: null,
        validTags: ["input", "div"],
        _setFirst: false,

        // default model
        defaults: {

            //colorpicker  
            /**		
			* This property allows to enable or disable the opacity slider in the color picker control
			* @default true
			* @type {boolean}
			* @example   
            * &lt;input type="text" id="colorPick"/&gt; <br> 
            * &lt;script&gt;
            * //To set enableOpacity API during initialization  
            * $('#colorPick').ejColorPicker({ value: "#278787", enableOpacity: false });
            * &lt;/script&gt;
			* @memberof ejColorPicker
			* @instance
			*/
            enableOpacity: true,
            /**		
           * This property allows to change the opacity value .The selected color opacity will be adjusted by using this opacity value.
           * @default 100
           * @type {number}
           * @example   
           * &lt;input type="text" id="colorPick"/&gt; <br> 
           * &lt;script&gt;
           * //To set opacityValue API during initialization  
           * $('#colorPick').ejColorPicker({ value: "#278787", opacityValue: 20 });
           * &lt;/script&gt;
           * @memberof ejColorPicker
           * @instance
           */
            opacityValue: 100,

            //colorpalette
            /**		
           * Specifies the number of columns to be displayed color palette model.
           * @default 10
           * @type {number}
           * @example   
           * &lt;input type="text" id="colorPick"/&gt; <br> 
           * &lt;script&gt;
           * //To set columns API during initialization  
           * $('#colorPick').ejColorPicker({ value: "#278787", modelType: "palette", columns: 5});
           * &lt;/script&gt;
           * @memberof ejColorPicker
           * @instance
           */
            columns: 10,
            //colorpalette
            /**		
           * Specifies the palette type to be displayed at initial time in palette model.There two types of palette model availabale in colorpicker control. See {@link Palette}
           * @default  ej.ColorPicker.Palette.BasicPalette
           * @type {enum}
           * @example   
           * &lt;input type="text" id="colorPick"/&gt; <br> 
           * &lt;script&gt;
           * //To set palette API during initialization 
           * $('#colorPick').ejColorPicker({ value: "#278787", modelType: "palette", palette: "basicpalette"});
           * &lt;/script&gt;
           * @memberof ejColorPicker
           * @instance
           */
            palette: "basicpalette",

            /**		
           * This property allows to define the custom colors in the palette model.Custom palettes are created by passing a comma delimited string of HEX values or an array of colors.
           * @default  empty
           * @type {data}
           * @example   
           * &lt;input type="text" id="colorPick"/&gt; <br> 
           * &lt;script&gt;
           * //To set custom API during initialization
           * $('#colorPick').ejColorPicker({ value: "#278787", modelType: "palette", palette: "custompalette", custom: ["ffffff", "ffccff", "ff99ff", "ff66ff", "ff33ff", "ff00ff", "ccffff", "ccccff"]});
           * &lt;/script&gt;
           * @memberof ejColorPicker
           * @instance
           */
            custom: [],

            /**		
          * This property allows to define the preset model to be rendered initially in palette type.It consists of 12 different types of presets. Each presets have 50 colors. See {@link Presets}
          * @default  ej.ColorPicker.Presets.Basic
          * @type {enum}
          * @example   
          * &lt;input type="text" id="colorPick"/&gt; <br> 
          * &lt;script&gt;
          * //To set presetType API during initialization 
          * $('#colorPick').ejColorPicker({ value: "#278787", modelType: "palette", presetType: "vintage"});
          * &lt;/script&gt;
          * @memberof ejColorPicker
          * @instance
          */
            presetType: "basic",

            //common API's
            /**		
            * Specifies the model type to be rendered initially in the colorpicker control. There are three different types of model type availabale in colorpicker control.  See {@link ModelType} 
            * @default  ej.ColorPicker.ModelType.Default
            * @type {enum}
            * @example   
            * &lt;input type="text" id="colorPick"/&gt; <br> 
            * &lt;script&gt;
            * //To set modelType API during initialization
            * $('#colorPick').ejColorPicker({ value: "#278787", modelType: "palette"});
            * &lt;/script&gt;
            * @memberof ejColorPicker
            * @instance
            */
            modelType: "default",
            /**		
            * This property allows to provides live preview support for current cursor selection color and selected color.
            * @default  true
            * @type {boolean}
            * @example   
            * &lt;input type="text" id="colorPick"/&gt; <br> 
            * &lt;script&gt;
            * //To set showPreview API during initialization
            * $('#colorPick').ejColorPicker({ value: "#278787", showPreview: false});
            * &lt;/script&gt;
            * @memberof ejColorPicker
            * @instance
            */
            showPreview: true,
            /**		
            * Specifies the color value for colorpicker control, the value is in hexadecimal form with prefix of "#".
            * @default  null
            * @type {string}
            * @example   
            * &lt;input type="text" id="colorPick"/&gt; <br> 
            * &lt;script&gt;
            * //To set value API during initialization
            * $('#colorPick').ejColorPicker({ value: "#278787"});
            * &lt;/script&gt;
            * @memberof ejColorPicker
            * @instance
            */
            value: null,
            /**		
            * This property allows to embed the popup in the order of DOM element flow . When we set the value as true, the colorpicker popup is always in visible state. 
            * @default  false
            * @type {boolean}
            * @example   
            * &lt;input type="text" id="colorPick"/&gt; <br> 
            * &lt;script&gt;
            * //To set displayInline API during initialization
            * $('#colorPick').ejColorPicker({ value: "#278787",  displayInline: true});
            * &lt;/script&gt;
            * @memberof ejColorPicker
            * @instance
            */
            displayInline: false,
            /**		
            * The colorpicker control allows to define the customized text to displayed in button elements. Using the property to achieve the customized culture values. 
            * @default buttonText.apply= "Apply",  buttonText.cancel= "Cancel"
            * @type {string}
            * @example   
            * &lt;input type="text" id="colorPick"/&gt; <br> 
            * &lt;script&gt;
            * //To set buttonText API during initialization
            * $('#colorPick').ejColorPicker({ value: "#278787",   buttonText: {apply: "Set", cancel: "Close" }});
            * &lt;/script&gt;
            * @memberof ejColorPicker
            * @instance
            */
            buttonText: {
                apply: "Apply",
                cancel: "Cancel"
            },
            /**		
            * This property allows to define the customized text or content to displayed when mouse over the following elements. This property also allows to use the culture values.
            * @default 
            * tooltipText: {
              *  switcher: "Switcher",
               * addbutton: "Add Color",
               * basic: "Basic",
               * monochrome: "Mono Chrome",
               * flatcolors: "Flat Color",
               * seawolf: "Sea Wolf",
               * webcolors: "Web Colors",
               * sandy: "Sandy",
               * pinkshades: "Pink Shades",
               * misty: "Misty",
               * citrus: "Citrus",
               * vintage: "Vintage",
               * moonlight: "Moon Light",
               * candycrush: "Candy Crush",
               * currentcolor: "Current Color",
               * selectedcolor: "Selected Color"
            * }
            * @type {object}
            * @example   
            * &lt;input type="text" id="colorPick"/&gt; <br> 
            * &lt;script&gt;
            * //To set tooltipText API during initialization
            * $('#colorPick').ejColorPicker({ value: "#278787",   tooltipText: { switcher: "Switch",  currentcolor: "New Color", selectedcolor: "Old Color" }});
            * &lt;/script&gt;
            * @memberof ejColorPicker
            * @instance
            */
            tooltipText: {
                switcher: "Switcher",
                addbutton: "Add Color",
                basic: "Basic",
                monochrome: "Mono Chrome",
                flatcolors: "Flat Color",
                seawolf: "Sea Wolf",
                webcolors: "Web Colors",
                sandy: "Sandy",
                pinkshades: "Pink Shades",
                misty: "Misty",
                citrus: "Citrus",
                vintage: "Vintage",
                moonlight: "Moon Light",
                candycrush: "Candy Crush",
                currentcolor: "Current Color",
                selectedcolor: "Selected Color"
            },
            /**		
            * This property allows to store the color values in custom list.The colorpicker will keep up to 11 colors in a custom list.By clicking the add button, the selected color from picker or palette will get added in the recent color list.  
            * @default false
            * @type {boolean}
            * @example   
            * &lt;input type="text" id="colorPick"/&gt; <br> 
            * &lt;script&gt;
            * //To set showRecentColors API during initialization
            * $('#colorPick').ejColorPicker({ value: "#278787",   showRecentColors: true});
            * &lt;/script&gt;
            * @memberof ejColorPicker
            * @instance
            */
            showRecentColors: false,
            /**		
            * Specifies the toolIcon to be disaplyed in dropdown control color area.
            * @default null
            * @type {string}
            * @example   
            * &lt;input type="text" id="colorPick"/&gt; <br> 
            * &lt;script&gt;
            * //To set toolIcon API during initialization
            * $('#colorPick').ejColorPicker({ value: "#278787",  toolIcon: "e-fontcolor-icon"});
            * &lt;/script&gt;
            * &lt;style&gt;
            * .e-colorwidget .e-tool .e-fontcolor-icon:before
            * {
            * content: "\e632";
            * margin-top: 9px;
            * font-size: 10px;
            * margin-left: 5px;
            * }
            * &lt;/style&gt;
            * @memberof ejColorPicker
            * @instance
            */
            toolIcon: null,
            /**		
            * This property allows you to customize its appearance using user-defined CSS and custom skin options such as colors and backgrounds.
            * @default emptyString
            * @type {string}
            * @example   
            * &lt;input type="text" id="colorPick"/&gt; <br> 
            * &lt;script&gt;
            * //To set cssClass API during initialization
            * $('#colorPick').ejColorPicker({ value: "#278787",  cssClass : "gradient-lime"});
            * &lt;/script&gt;
            * @memberof ejColorPicker
            * @instance
            */
            cssClass: "",
            /**		
            * This property allows to change the control in enabled or disabled state.
            * @default true
            * @type {boolean}
            * @example   
            * &lt;input type="text" id="colorPick"/&gt; <br> 
            * &lt;script&gt;
            * //To set enabled API during initialization
            * $('#colorPick').ejColorPicker({ value: "#278787",  enabled: false});
            * &lt;/script&gt;
            * @memberof ejColorPicker
            * @instance
            */
            enabled: true,

            //Events
            /**     
			 * Fires after Color value has been changed sucessfully.If the user want to perform any operation after the color value changed then the user can make use of this change event. 
			 * @event
			 * @name ejColorPicker#change
			 * @param {Object} argument Event parameters from color picker     
			 * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
			 * @param {object}  argument.model returns the color picker model
			 * @param {string}  argument.type returns the name of the event
			 * @param {string}  argument.value return the changed color value
			 * @example   
             * &lt;input type="text" id="colorPick"/&gt; <br> 
             * &lt;script&gt;
			 * //change event for color picker
             * $('#colorPick').ejColorPicker({              
             * value: "#278787", 
             * change: function (args) {
			 * // Write a code block to perform operation after changing the color.
			 * }
             *});
            * &lt;/script&gt;
            * @memberof ejColorPicker
            * @instance
            */
            change: null,
            /**     
			 * Fires after Color value has been selected sucessfully. If the user want to perform any operation after the color value selected then the user can make use of this select event. 
			 * @event
			 * @name ejColorPicker#select
			 * @param {Object} argument Event parameters from color picker     
			 * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
			 * @param {object}  argument.model returns the color picker model
			 * @param {string}  argument.type returns the name of the event
			 * @param {string}  argument.value return the selected color value
			 * @example   
             * &lt;input type="text" id="colorPick"/&gt; <br> 
             * &lt;script&gt;
			 * //select event for color picker
             * $('#colorPick').ejColorPicker({              
             * value: "#278787", 
             * select: function (args) {
			 * // Write a code block to perform operation after selecting the color.
			 * }
             *});
            * &lt;/script&gt;
            * @memberof ejColorPicker
            * @instance
            */
            select: null,
            /**     
			 * Fires after opening the color picker popup
			 * @event
			 * @name ejColorPicker#open
			 * @param {Object} argument Event parameters from color picker     
			 * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
			 * @param {object}  argument.model returns the color picker model
			 * @param {string}  argument.type returns the name of the event			 
			 * @example   
             * &lt;input type="text" id="colorPick"/&gt; <br> 
             * &lt;script&gt;
			 * //open event for color picker
             * $('#colorPick').ejColorPicker({              
             * value: "#278787", 
             * open: function (args) {
			 * // Write a code block to perform operation after opening the color picker popup.
			 * }
             *});
            * &lt;/script&gt;
            * @memberof ejColorPicker
            * @instance
            */
            open: null,
            /**     
			 * Fires after closing the color picker popup.
			 * @event
			 * @name ejColorPicker#close
			 * @param {Object} argument Event parameters from color picker     
			 * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
			 * @param {object}  argument.model returns the color picker model
			 * @param {string}  argument.type returns the name of the event			 
			 * @example   
             * &lt;input type="text" id="colorPick"/&gt; <br> 
             * &lt;script&gt;
			 * //close event for color picker
             * $('#colorPick').ejColorPicker({              
             * value: "#278787", 
             * close: function (args) {
			 * // Write a code block to perform operation after closing the color picker popup.
			 * }
             *});
             * &lt;/script&gt;
             * @memberof ejColorPicker
             * @instance
             */
            close: null,
            /**     
			 * Fires after Color picker control is created. If the user want to perform any operation after the color picker control creation then the user can make use of this create event. 
			 * @event
			 * @name ejColorPicker#create		
			 * @param {Object} argument Event parameters from color picker     
			 * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
			 * @param {object}  argument.model returns the color picker model
			 * @param {string}  argument.type returns the name of the event			 
			 * @example   
             * &lt;input type="text" id="colorPick"/&gt; <br> 
             * &lt;script&gt;
			 * //create event for color picker
             * $('#colorPick').ejColorPicker({              
             * value: "#278787", 
             * create: function (args) {
			 * // Write a code block to perform operation after creating the color picker.
			 * }
             *});
            * &lt;/script&gt;
            * @memberof ejColorPicker
            * @instance
            */
            create: null,
            /**     
            * Fires after Color picker control is destroyed. If the user want to perform any operation after the color picker control destroyed then the user can make use of this destroy event. 
            * @event
            * @name ejColorPicker#destroy		
            * @param {Object} argument Event parameters from color picker     
            * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
            * @param {object}  argument.model returns the color picker model
            * @param {string}  argument.type returns the name of the event            
            * @example   
            * &lt;input type="text" id="colorPick"/&gt; <br> 
            * &lt;script&gt;
            * //create event for color picker
            * $('#colorPick').ejColorPicker({              
            * value: "#278787", 
            * destroy: function (args) {
            * // Write a code block to perform operation after creating the color picker.
            * }
            *});
           * &lt;/script&gt;
           * @memberof ejColorPicker
           * @instance
           */
            destroy: null,
        },
        datetypes: {
            columns: "number",
            modelType: "enum",
            palette: "enum",
            presetType: "enum",
            cssClass: "string",
            opacityValue: "number",
            displayInline: "boolean",
            showRecentColors: "boolean",
            enabled: "boolean",
            showPreview: "boolean",
            enableOpacity: "boolean",
            buttonText: "data",
            custom: "data"
        },

        observables: ["value"],
        value: ej.util.valueFunction("value"),

        _setModel: function (jsondata) {
            if (!(this.model.enabled) && ej.isNullOrUndefined(jsondata["enabled"])) return false;
            for (var key in jsondata) {
                switch (key) {
                    //colorpicker API's                    
                    case "enableOpacity":
                        this.model.enableOpacity = jsondata[key];
                        this._previewSlider(this.model.enableOpacity);
                        break;
                    case "opacityValue":
                        if (this.model.enableOpacity) {
                            this.model.opacityValue = jsondata[key];
                            this._changeAlpha();
                            this._opacity.option('value', this.model.opacityValue);
                            this._updateValue();
                            break;
                        } else return false;
                        //ColorPalette API's
                    case "custom":
                        this.model.custom = jsondata[key];
                        this._reInitialize();
                        break;
                    case "palette":
                        this.model.palette = jsondata[key];
                        this._reInitialize();
                        break;
                    case "columns":
                        this.model.columns = jsondata[key];
                        this._reInitialize();
                        break;
                    case "presetType":
                        this.model.presetType = jsondata[key];
                        if (ej.isNullOrUndefined(Colors[this.model.presetType])) return false;
                        else
                            this._reInitialize();
                        break;
                        //common API's
                    case "value":
                        this.setValue(ej.util.getVal(jsondata[key]));
                        break;
                    case "modelType":
                        this.model.modelType = jsondata[key];
                        this.model.modelType == "default" ? this._defaultRender() : this._reInitialize();
                        break;
                    case "tooltipText":
                        this._toolTipText(jsondata[key]);
                        break;
                    case "showPreview":
                        this.model.showPreview = jsondata[key];
                        this._previewPane(this.model.showPreview);
                        break;
                    case "buttonText":
                        this._buttonText(jsondata[key]);
                        break;
                    case "displayInline":
                        this._setDisplayInline(jsondata[key]);
                        break;
                    case "cssClass":
                        this.model.cssClass = jsondata[key];
                        break;
                    case "enabled":
                        this.model.enabled = jsondata[key];
                        this._enabled(this.model.enabled);
                        break;
                    case "showRecentColors":
                        this.model.showRecentColors = jsondata[key];
                        this._previewColor(this.model.showRecentColors);
                        break;
                }
            }
        },
        _defaultRender: function () {
            this._pickerType();
            this.PaletteWrapper = this._layoutType(this.model.palette);
            this.PaletteWrapper.addClass('e-hide');
            if (this.model.displayInline && !this.element.is('input'))
                this._footer.removeClass('e-hide');
            this.popupList.prepend(this.PaletteWrapper);
        },
        _pickerType: function () {
            this._modelType = "picker";
            this.PaletteWrapper.removeAttr('style');
            this.PaletteWrapper.addClass('e-hide');
            this._gradient.removeClass('e-hide');
            this._gradient.fadeIn(200);
            this._presetTag.parents('.e-split.e-widget').addClass('e-hide');
            this._switcher.removeAttr('class');
            this._switcher.addClass('e-color-image e-pickerModel');
            this._switch = true;
            this._rgbValue();
            this._hueGradient();
            this._updateUI();
            this._templateWrapper.find('#' + this._id + "hsv").ejButton("enable");
            this._switchEvents();
            this._unSwitchEvents();
            this._hideUnBindEvents();
            this._showBindEvents();
            this.model.modelType == "default" ? this._changeTag.removeClass('e-hide') : this._changeTag.addClass('e-hide');
            this.popupList.prepend(this._gradient);
        },
        _paletteType: function () {
            this._gradient.removeAttr('style');
            this._presetTag.parents('.e-split.e-widget').removeClass('e-hide');
            this.PaletteWrapper.removeClass('e-hide');
            this.PaletteWrapper.fadeIn(200);
            this._templateWrapper.find('#' + this._id + "hsv").ejButton("disable");
            this._switch = false;
            this._disableHSVButton();
            this._cellSelect();
            this._switchEvents();
            this._unSwitchEvents();
            this.model.modelType == "default" ? this._changeTag.removeClass('e-hide') : this._changeTag.addClass('e-hide');
            this._splitObj.option('prefixIcon', 'e-color-image e-' + this.model.presetType);
            this.popupList.prepend(this.PaletteWrapper);
        },
        _reInitialize: function () {
            this._destroyPalette(false);
        },
        _destroyPalette: function (presets) {
            if (this.model.modelType == "default" || this.model.modelType == "picker" || this.model.modelType == "palette")
                this.PaletteWrapper.remove();
            if (presets || this._temp != this.model.columns && this.model.palette !== "custompalette") this.PaletteWrapper = this._presetType(this._presetsId);
            else if (this.model.modelType == "palette") {
                this._modelType = "palette";
                this.PaletteWrapper = this._layoutType(this.model.palette);
                this._hideUnBindEvents();
                this._showBindEvents();
            }
            if (this.model.modelType == "picker") {
                this._pickerType();
                if (this.model.displayInline && !this.element.is('input'))
                    this._footer.addClass('e-hide');
            }
            else if (this.model.modelType == "palette") {
                this._gradient.addClass('e-hide');
                this._paletteType();
                presets || this.model.palette == "custompalette" ? "" : this._splitObj.option('prefixIcon', 'e-color-image e-' + this.model.presetType);
            }
            else if (this.model.modelType == "default")
                if (this._modelType == "palette") {
                    this.PaletteWrapper = this._layoutType(this.model.palette);
                    this._gradient.addClass('e-hide');
                    this._paletteType();
                }
            this._temp = this.model.columns;
            if (this.model.palette == "custompalette" || this.model.modelType == "picker")
                this._presetTag.parents('.e-split.e-widget').addClass('e-hide');
            else
                this._presetTag.parents('.e-split.e-widget').removeClass('e-hide');
        },
        _previewColor: function (color) {
            if (color) {
                this._swatchesArea.fadeIn(200);
                this._bindRecentEvent();
            }
            else {
                this._swatchesArea.fadeOut(200);
                this._unBindRecentEvent();
            }
        },
        _buttonText: function (data) {
            $.extend(this.model.buttonText, data);
            this._buttonTag.html(this.model.buttonText.apply);
            this._cancelTag.html(this.model.buttonText.cancel);
        },
        _toolTipText: function (data) {
            $.extend(this.model.tooltipText, data);
            this._addTitleText();
        },
        _previewPane: function (showPreview) {
            showPreview ? this._previewTag.removeClass("e-hide") : this._previewTag.addClass("e-hide");
        },
        _previewSlider: function (slider) {
            slider ? this._opacity.enable() : this._opacity.disable();
        },
        _destroy: function () {
            if (this.isPopupOpen) this.hide();
            this.popupContainer.remove();
            if (this.wrapper) {
                this.element.insertAfter(this.wrapper);
                this.wrapper.remove();
                $('#' + this._id + "_Presets").parent('.e-menu-wrap').remove();
            }
            if (this.element.is("input")) this.element.attr('type', 'text');
            this.element.removeClass('e-colorpicker e-input');
        },
        _init: function () {
            this._browser = ej.browserInfo();
            this._isFocused = false;
            this.isPopupOpen = false;
            this._dataBind = false;
            this._modelType = "picker";
            this.model.palette === "basicpalette" ? this._presetsId = "e-presets30" : "";
            if(this.element[0].value !== "") this.value(this.element[0].value);
            this._renderControl();
            this.model.palette === "custompalette" ? this._presetTag.parents('.e-split.e-widget').addClass('e-hide') : "";
            this.popupContainer.find('button.e-presets').ejSplitButton({ targetID: this._id + "_Presets" });
            if (this.value()) {
                this._setValue(this.value());
                if (this._switch) this._rgbValue();
                this._alphaGradient(this.value());
            }
            else {
                this._colorSlider.option('value', parseInt(this._hsv.h));
                this._opacity.option('value', this.model.opacityValue);
            }
            this._hsvValue();
            this._alphaGradient(this.RGBToHEX(this.rgb))
            this._hueGradient();
            this._addTitleText();
            this._temp = this.model.columns;
        },
        _renderControl: function () {
            this._createWrapper();
            this._renderPopupPanelWrapper();
            this._renderPopupElement();
            this._selectedButton = this._groupTag.find('.e-click');
            this._setDisplayInline(this.model.displayInline);
            this._previewPane(this.model.showPreview);
            this._previewColor(this.model.showRecentColors);
            if (this._switch) this._previewSlider(this.model.enableOpacity);
            this._wireEvents();
            this._switchEvents();
        },

        _createWrapper: function () {
            if (this.element.is("input")) {
                this.element.addClass('e-input');
                this.spanElement = ej.buildTag("span.e-selected-color");     //style
                this.wrapper = ej.buildTag("span.e-colorwidget e-picker e-widget " + this.model.cssClass + "#" + this._id + "Wrapper").attr({ 'tabindex': '0', "aria-expanded": false, "aria-haspopup": true, "aria-owns": this._id + "_popup" });
                this.container = ej.buildTag("span.e-in-wrap e-box");
                this.drpbtnspan = ej.buildTag("span.e-icon e-down-arrow", "", {}, { "aria-label": "select" });
                this.dropdownbutton = ej.buildTag("span.e-select#" + this._id + "_dropdown", "", {}, { "role": "button" }).append(this.drpbtnspan);
                this.iconWrapper = ej.buildTag("span.e-tool-icon " + this.model.toolIcon);
                this.container.insertAfter(this.element);
                if (!ej.isNullOrUndefined(this.model.toolIcon)) {
                    this.iconWrapper.append(this.spanElement);
                    this.container.addClass('e-tool');
                    this.container.append(this.iconWrapper);
                }
                else
                    this.container.append(this.spanElement);
                this.container.append(this.element, this.dropdownbutton);
                this.wrapper.insertBefore(this.container);
                this.wrapper.append(this.container);
                this.element.attr({ 'type': 'hidden' }).val(this.value())
            }
            this._checkNameAttr();
        },
        _addTitleText: function () {
            this._switcher.attr('title', this.model.tooltipText.switcher);
            this._spanTag.attr('title', this.model.tooltipText.addbutton);
            this._presetLi.find("#e-presets00").attr('title', this.model.tooltipText.webcolors);
            this._presetLi.find("#e-presets01").attr('title', this.model.tooltipText.vintage);
            this._presetLi.find("#e-presets02").attr('title', this.model.tooltipText.seawolf);
            this._presetLi.find("#e-presets10").attr('title', this.model.tooltipText.sandy);
            this._presetLi.find("#e-presets11").attr('title', this.model.tooltipText.pinkshades);
            this._presetLi.find("#e-presets12").attr('title', this.model.tooltipText.moonlight);
            this._presetLi.find("#e-presets20").attr('title', this.model.tooltipText.monochrome);
            this._presetLi.find("#e-presets21").attr('title', this.model.tooltipText.misty);
            this._presetLi.find("#e-presets22").attr('title', this.model.tooltipText.flatcolors);
            this._presetLi.find("#e-presets30").attr('title', this.model.tooltipText.basic);
            this._presetLi.find("#e-presets31").attr('title', this.model.tooltipText.candycrush);
            this._presetLi.find("#e-presets32").attr('title', this.model.tooltipText.citrus);
            this._currentTag.attr('title', this.model.tooltipText.currentcolor);
            this._previousTag.attr('title', this.model.tooltipText.selectedcolor);
        },
        _renderPopupPanelWrapper: function () {
            this.popupContainer = ej.buildTag("div.e-colorpicker e-box e-popup e-widget " + this.model.cssClass + "#" + this._id + "_popup", "", { "role": "grid", "aria-readonly": "true", "tabIndex": 0, "style": "visibility:hidden" });
            $('body').append(this.popupContainer);

            this.popupList = ej.buildTag("div.e-popupWrapper");
            //render color area
            this._gradient = ej.buildTag("div.e-container");
            //gradient Area            
            this._colorArea = ej.buildTag("div.e-hsv-color");
            this._gradientArea = ej.buildTag("div.e-hsv-gradient")//style
            this._handleArea = ej.buildTag("div.e-draghandle e-color-image").attr({ 'tabindex': '0' });
            this._colorArea.append(this._gradientArea, this._handleArea);
            //slider area
            this._picker = ej.buildTag("div.e-gradient");
            this._hueSlider = ej.buildTag("div.e-widget e-hue e-state-default#" + this._id + "hue");
            this._alphaSlider = ej.buildTag("div.e-widget e-opacity e-state-default#" + this._id + "alpha");
            this._picker.append(this._hueSlider, this._alphaSlider);
            //gradient and slider container            
            this._gradient.append(this._colorArea, this._picker);
            //first level block design       
            this.popupList.append(this._gradient);

            //second block
            this._footerBlock = ej.buildTag("div.e-footerContainer");
            //container for code switcher and input element
            this._templateWrapper = ej.buildTag("div.e-buttons");

            //buttons area
            this._groupTag = ej.buildTag("div.e-groupButton");

            this._formEle = ej.buildTag("div.e-form");
            this._rgb = ej.buildTag("button.e-rgbButton e-click#" + this._id + "rgba","", {}, { type: "button" });
            this._hexCode = ej.buildTag("button.e-hexButton#" + this._id + "hex","", {}, { type: "button" });
            this._hsva = ej.buildTag("button.e-hsvButton#" + this._id + "hsv","", {}, { type: "button" });
            this._groupTag.append(this._rgb, this._hexCode, this._hsva);

            //input area
            this._codeEditor = ej.buildTag("div.e-codeeditor");
            this._inputTag = ej.buildTag("input.e-color-code", "", {}, { "type": "text", 'tabindex': '0', "maxLength": "22" });
            this._codeEditor.append(this._inputTag);

            this._formEle.append(this._groupTag, this._codeEditor);
            //container for preview area
            this._previewTag = ej.buildTag("div.e-preview").attr({ 'tabindex': '0' });
            this._currentTag = ej.buildTag("div.e-current").attr({ 'tabindex': '0' });
            this._previousTag = ej.buildTag("div.e-previous").attr({ 'tabindex': '0' });
            this._previewTag.append(this._currentTag, this._previousTag);

            this._templateWrapper.append(this._formEle, this._previewTag);

            //swatches area
            this._swatchesArea = ej.buildTag("div.e-color-labels");
            var blockCount = 11;     //No.of blocks for save the selected colors
            this._divTag = ej.buildTag("div.e-recent-color");
            this._addTag = ej.buildTag('div.e-colorblock e-block');
            this._spanTag = ej.buildTag('div.e-color e-color-image e-add');
            this._addTag.append(this._spanTag)
            this._divTag.append(this._addTag);
            for (var count = 0; count < blockCount; count++) {
                this._liTag = ej.buildTag('div.e-colorblock e-block');
                var spanTag = ej.buildTag('div.e-color e-color-image e-empty');
                this._liTag.append(spanTag);
                this._divTag.prepend(this._liTag);
            }
            this._swatchesArea.append(this._divTag);

            //footer area             

            this._footer = ej.buildTag('div.e-footer');
            this._swatches = ej.buildTag('div.e-element');
            this._changeTag = ej.buildTag('div.e-switcher');
            this._switcher = ej.buildTag('div.e-color-image');
            this._presetTag = ej.buildTag('button.e-presets#' + this._id + "-split");
            this._presets = ej.buildTag('div');
            this._buttonTag = ej.buildTag("button.e-applyButton","", {}, { type: "button" });
            this._cancelTag = ej.buildTag("button.e-cancelButton","", {}, { type: "button" });
            this._changeTag.append(this._switcher);
            this._presetTag.append(this._presets);
            this._swatches.append(this._changeTag, this._presetTag);
            this._footer.append(this._swatches, this._buttonTag, this._cancelTag);

            this._footerBlock.append(this._templateWrapper, this._swatchesArea, this._footer);


            //for this design purpose                                   

            this.PaletteWrapper = this._layoutType(this.model.palette);
            this.popupList.append(this.PaletteWrapper, this._footerBlock);
            this._presetContainer = ej.buildTag('ul.e-presetWrapper' + "#" + this._id + "_Presets", "", {}, { "style": "top:87px" });
            this._presetLi = ej.buildTag('li.e-item');
            this._presetLi.append(this._renderPresets());
            this._presetContainer.append(this._presetLi);
            this.popupList.append(this._presetContainer);
            this.popupContainer.append(this.popupList);

            //IE Support
            if (this._browser.name = "msie" && (this._browser.version == "9.0" || this._browser.version == "8.0"))
                this._hueSlider.addClass('e-color-image e-filter');
            else
                this._hueSlider.addClass('e-common');
        },
        _colorPresetsClick: function (e) {
            this._presetsId = e.currentTarget.id;
            if (this._presetsId === "e-presets00") this.model.presetType = "webcolors";
            else if (this._presetsId === "e-presets01") this.model.presetType = "vintage";
            else if (this._presetsId === "e-presets02") this.model.presetType = "seawolf";
            else if (this._presetsId === "e-presets10") this.model.presetType = "sandy";
            else if (this._presetsId === "e-presets11") this.model.presetType = "pinkshades";
            else if (this._presetsId === "e-presets12") this.model.presetType = "moonlight";
            else if (this._presetsId === "e-presets20") this.model.presetType = "monochrome";
            else if (this._presetsId === "e-presets21") this.model.presetType = "misty";
            else if (this._presetsId === "e-presets22") this.model.presetType = "flatcolors";
            else if (this._presetsId === "e-presets30") this.model.presetType = "basic";
            else if (this._presetsId === "e-presets31") this.model.presetType = "candycrush";
            else if (this._presetsId === "e-presets32") this.model.presetType = "citrus";
            this._splitObj.option('prefixIcon', 'e-color-image e-' + this.model.presetType);
            this._destroyPalette(true, false);
        },

        _renderPresets: function () {
            var tableDiv = ej.buildTag("div.e-presets-table");
            var spanTag = ej.buildTag("span.e-presetHeader");
            spanTag.html("Swatches");
            tableDiv.append(spanTag);
            var color = 0, hexCode, rowDiv;
            for (var row = 0; row < 4 ; row++) {
                rowDiv = ej.buildTag("ul.e-tablerow");
                for (var col = 0; col < 3 ; col++) {
                    tableCell = ej.buildTag("li.e-color-image e-preset-row" + "#" + "e-presets" + [row] + [col]);
                    tableCell.appendTo(rowDiv);
                }
                rowDiv.appendTo(tableDiv);
            }
            return tableDiv;
        },
        _renderPopupElement: function () {
            var proxy = this;
            this._hsv =
            {
                h: 360, s: 100, v: 100
            };
            this._templateWrapper.find('#' + this._id + "rgba").ejButton({ text: "RGBA", type: "button" });
            this._templateWrapper.find('#' + this._id + "hex").ejButton({ text: "HEX", type: "button" });
            this._templateWrapper.find('#' + this._id + "hsv").ejButton({ text: "HSVA", type: "button" });
            this._applyObj = this.popupContainer.find('button.e-applyButton').ejButton({ text: this.model.buttonText.apply, type: "button" }).data('ejButton');
            this._cancelObj = this.popupContainer.find('button.e-cancelButton').ejButton({ text: this.model.buttonText.cancel, type: "button" }).data('ejButton');
            this._splitObj = this.popupContainer.find('#' + this._id + "-split").ejSplitButton({ size: "normal", showRoundedCorner: true, contentType: "imageonly" }).data('ejSplitButton');
            this._presetTag.parents('.e-split.e-widget').css({ "height": "27px" });
            this.model.custom.length == 0 ? this._splitObj.option('prefixIcon', "e-color-image e-" + this.model.presetType) : "";
            this._splitObj._getXYpos = function (e) {
                $("#" + this.model.targetID).ejMenu({ animationType: "none" });
                $("#" + this.model.targetID).ejMenu('hide', e);
                btnpos = this.dropbutton.offset();
                btnposx = btnpos.left - this.dropbutton.prev().outerWidth() - 1;
                btnposy = (btnpos.top - $("#" + this.model.targetID).outerHeight()) - 1;
                return { x: btnposx, y: btnposy }
            }
            this._colorSlider = this.popupContainer.find("#" + this._id + "hue").ejSlider({ orientation: "Vertical", minValue: 0, maxValue: 360, change: function (e) { proxy._changeHue(e); }, slide: function (e) { proxy._changeHue(e); } }).data('ejSlider');
            this._opacity = this.popupContainer.find("#" + this._id + "alpha").ejSlider({ value: this.model.opacityValue, orientation: "Vertical", incrementStep: 5, value: 100, change: function (e) { proxy._changeAlpha(e); }, slide: function (e) { proxy._changeAlpha(e); } }).data('ejSlider');
            this._colorSlider.firstHandle.css({ "height": "13px", "margin": "0px 0px -12px -2px", "width": "13px" });
            this._opacity.firstHandle.css({ "height": "13px", "margin": "0px 0px -12px -2px", "width": "13px" });
            this.popupContainer.css({ "visibility": "visible", "display": "none" });
            if (this.model.modelType == "picker") {
                this._modelType = "picker";
                this._gradient.removeClass('e-hide');
                this._changeTag.addClass('e-hide');
                this.PaletteWrapper.addClass('e-hide');
                this._presetTag.parents('.e-split.e-widget').addClass('e-hide');
                this._switch = true;
            } else if (this.model.modelType == "palette") {
                this._modelType = "palette"
                this._changeTag.addClass('e-hide');
                this._presetTag.parents('.e-split.e-widget').removeClass('e-hide');
                this.PaletteWrapper.removeClass('e-hide');
                this._gradient.addClass('e-hide');
                this._templateWrapper.find('#' + this._id + "hsv").ejButton("disable");
                this._switch = false;
            } else if (this.model.modelType == "default") {
                this._modelType = "picker";
                this._gradient.removeClass('e-hide');
                this._switcher.addClass('e-pickerModel');
                this.PaletteWrapper.addClass('e-hide');
                this._presetTag.parents('.e-split.e-widget').addClass('e-hide');
                this._switch = true;
            }
        },
        _layoutType: function (type) {
            if (typeof type === "string" && type == "basicpalette")
                this._collection = this._paletteGenerate(Colors[this.model.presetType], this.model.columns);
            else if (typeof type === "string" && type == "custompalette" && this.model.modelType == "palette")
                this._collection = this._paletteGenerate(this.model.custom, this.model.columns);
            type == "custompalette" ? this._collection.addClass('e-custom') : "";
            return this._collection;
        },
        _presetType: function (type) {
            if (type === "e-presets00") this._collection = this._paletteGenerate(Colors.webcolors, this.model.columns);
            else if (type === "e-presets01") this._collection = this._paletteGenerate(Colors.vintage, this.model.columns);
            else if (type === "e-presets02") this._collection = this._paletteGenerate(Colors.seawolf, this.model.columns);
            else if (type === "e-presets10") this._collection = this._paletteGenerate(Colors.sandy, this.model.columns);
            else if (type === "e-presets11") this._collection = this._paletteGenerate(Colors.pinkshades, this.model.columns);
            else if (type === "e-presets12") this._collection = this._paletteGenerate(Colors.moonlight, this.model.columns);
            else if (type === "e-presets20") this._collection = this._paletteGenerate(Colors.monochrome, this.model.columns);
            else if (type === "e-presets21") this._collection = this._paletteGenerate(Colors.misty, this.model.columns);
            else if (type === "e-presets22") this._collection = this._paletteGenerate(Colors.flatcolors, this.model.columns);
            else if (type === "e-presets30") this._collection = this._paletteGenerate(Colors.basic, this.model.columns);
            else if (type === "e-presets31") this._collection = this._paletteGenerate(Colors.candycrush, this.model.columns);
            else if (type === "e-presets32") this._collection = this._paletteGenerate(Colors.citrus, this.model.columns);
            return this._collection;
        },
        _paletteGenerate: function (colors, columns) {
            var color;
            this._PresetTable = ej.buildTag("div.e-palette-color").attr({ "role": "presentation" });
            this._tag = ej.buildTag("div.e-row");
            for (color = 0; color < colors.length; color++) {
                if (color && color % columns == 0)
                    this._tag = ej.buildTag("div.e-row");
                this._td = ej.buildTag("div.e-item").attr({ 'role': 'gridcell', "aria-label": "#" + $.trim(colors[color]), "value": "#" + $.trim(colors[color]), "style": "background-color:" + "#" + $.trim(colors[color]), "tabindex": "0" });
                this._tag.append(this._td);
                this._PresetTable.append(this._tag);
            }
            return this._PresetTable;
        },
        _checkNameAttr: function () {
            if (!this.element.attr("name"))
                this.element.attr({ "name": this.element[0].id });
        },
        _enabled: function (bool) {
            bool ? this.enable() : this.disable();
        },
        _setDisplayInline: function (isDisplayInline) {
            this.model.displayInline = isDisplayInline;
            if (isDisplayInline && this.element.is("input")) {
                this.popupContainer.insertAfter(this.wrapper);
                this._setPopupPosition();
            }
            else if (isDisplayInline) {
                this.element.append(this.popupContainer);
                this.popupContainer.find('button.e-applyButton').css({ "display": "none" });
                this.popupContainer.find('button.e-cancelButton').css({ "display": "none" });
                this._footer.css({ "display": "none" });
            }
            else {
                this.popupContainer.css('display', 'none');
                $('body').append(this.popupContainer);
                this._isOpen = false;
                this._bindIconClick();
                this._isFocused = false;
                this.isPopupOpen = false;
                this.wrapper.removeClass("e-focus");
            }
            if (isDisplayInline) {
                this.show();
                if (this.element.is("input")) this._off($(this.dropdownbutton), "mousedown", this._iconClick);
            }
        },
        _bindIconClick: function () {
            var count = $._data($(this.dropdownbutton)[0], "events");
            ej.isNullOrUndefined(count) ? this._on(this.dropdownbutton, "mousedown", this._iconClick) : count.mousedown.length == 0 ? this._on(this.dropdownbutton, "mousedown", this._iconClick) : "";
        },
        _unBindIconClick: function () {
            this._off(this.dropdownbutton, "mousedown", this._iconClick);
        },
        _setPopupPosition: function () {
            var elementObj = this.wrapper;
            var pos = elementObj.offset(),
            left = pos.left,
            totalHeight = elementObj.outerHeight(),
            border = (totalHeight - elementObj.height()) / 2,
            maxZ = this._getZindexPartial();
            this.popupContainer.css({
                "left": left + 3 + "px",
                'position': 'absolute',
                "top": pos.top + totalHeight - border + 3 + "px",
                "z-index": maxZ
            });
        },
        _getZindexPartial: function () {
            var parents = this.element.parents(), bodyEle;
            bodyEle = $('body').children(), index = bodyEle.index(this.popupList);
            bodyEle.splice(index, 1);
            $(bodyEle).each(function (i, ele) { parents.push(ele); });

            var maxZ = Math.max.apply(maxZ, $.map(parents, function (e, n) {
                if ($(e).css('position') != 'static')
                    return parseInt($(e).css('z-index')) || 1;
            }));
            if (!maxZ || maxZ < 10000) maxZ = 10000;
            else maxZ += 1;
            return maxZ;
        },
        _setValue: function (value) {
            var color;
            this.value(value);
            if (value) {
                color = this._HexToHSV(value);
                this._oldValue = this.rgb;
                if (this._switch) {
                    this._valueOperation();
                    this._colorSlider.option('value', parseInt(this._hsv.h));
                }
                this._inputTagValue(this._selectedButton);
                if (this.element.is("input")) this._updateValue();
                if (!this._switch) {
                    this._updateUI();
                    this.element.val(this.value());
                }
            }
        },
        setValue: function (code) {
            this._setValue(code);
            this._hueGradient();
            this._trigger("change", { value: this.value() });
        },
        /**
       * Enable the color picker control
       * @return jQuery
       
       * @example   
       * &lt;input type="text" id="colorPick"/&gt; <br> 
       * &lt;script&gt;
       * // Create Color picker
       * $('#colorPick').ejColorPicker({ value: "#278787" });
       * // Create ColorPicker instance
       * var colorObj = $("#colorPick").data("ejColorPicker");
       * colorObj.enable(); // enables the colorPicker
       * &lt;/script&gt; 
       
       * @example   
       * &lt;input type="text" id="colorPick"/&gt; <br> 
       * &lt;script&gt;
       * // Create Color picker
       * $('#colorPick').ejColorPicker({ value: "#278787" });
        * // enable the colorPicker
       * $("#colorPick").ejColorPicker("enable");
       * &lt;/script&gt;       
       
       * @memberof ejColorPicker
       * @instance
       */
        enable: function () {
            if (this.wrapper.hasClass("e-disable")) {
                this.wrapper.removeClass("e-disable");
            if (this.container.hasClass("e-disable")) 
                this.container.removeClass('e-disable');
                this.popupList.removeClass('e-disable');
                this.dropdownbutton.removeClass('e-disable');
                var temp = this._switch;
                this._switch = true;
                this._cancelObj.enable();
                this._colorSlider.enable();
                this._opacity.enable();
                this._splitObj.enable();
                this._applyObj.enable();
                this._wireEvents();
                this._switchEvents();
                this._switch = temp;
                $(this._inputTag).removeAttr('readonly');
                this._on(this.dropdownbutton, "mousedown", this._iconClick);
                if (this._switcher.hasClass('e-paletteModel')) {
                    this._on($(document), "keydown", this._keyDown);
                    this._on(this._collection, "mousedown", this._onSelect);
                } else
                    this._on($(document), "keydown", this._onKeyDown);

            }
        },
        /**
        * Disables the color picker control
		* @return jQuery
		
        * @example   
        * &lt;input type="text" id="colorPick"/&gt; <br> 
        * &lt;script&gt;
        * // Create Color picker
        * $('#colorPick').ejColorPicker({ value: "#278787" });
        * // Create ColorPicker instance
		* var colorObj = $("#colorPick").data("ejColorPicker");
		* colorObj.disable(); // disables the colorPicker
        * &lt;/script&gt; 
        
        * @example   
        * &lt;input type="text" id="colorPick"/&gt; <br> 
        * &lt;script&gt;
        * // Create Color picker
        * $('#colorPick').ejColorPicker({ value: "#278787" });
         * // disables the colorPicker
        * $("#colorPick").ejColorPicker("disable");
        * &lt;/script&gt;       
		
        * @memberof ejColorPicker
	    * @instance
		*/
        disable: function () {
            if (!this.wrapper.hasClass("e-disable")) {
                this.wrapper.addClass("e-disable");
            if (!this.container.hasClass("e-disable"))
                this.container.addClass('e-disable');
                this.popupList.addClass('e-disable');
                this.dropdownbutton.addClass('e-disable');
                var temp = this._switch;
                this._switch = false;
                this._cancelObj.disable();
                this._colorSlider.disable();
                this._opacity.disable();
                this._splitObj.disable();
                this._applyObj.disable();
                this._unWireEvents();
                this._unSwitchEvents();
                this._switch = temp;
                this._unBindIconClick();
                $(this._inputTag).attr('readonly', 'readonly');
                if (this._switcher.hasClass('e-paletteModel')) {
                    this._off($(document), "keydown", this._keyDown);
                    this._off(this._collection, "mousedown", this._onSelect);
                } else
                    this._off($(document), "keydown", this._onKeyDown);
            }
            if (this.isPopupOpen && !this.model.displayInline)
                this.hide();
        },
        /**
        * Gets the selected color in RGB format
		* @return jQuery
		
        * @example   
        * &lt;input type="text" id="colorPick"/&gt; <br> 
        * &lt;script&gt;
        * // Create Color picker
        * $('#colorPick').ejColorPicker({ value: "#278787" });
        * // Create ColorPicker instance
		* var colorObj = $("#colorPick").data("ejColorPicker");
		* var color=colorObj.getColor(); // gets the selected color in RGB format
        * alert("Red="+color.r+", Green="+color.g+", Blue="+color.b);
        * &lt;/script&gt; 
        
        * @example   
        * &lt;input type="text" id="colorPick"/&gt; <br> 
        * &lt;script&gt;
        * // Create Color picker
        * $('#colorPick').ejColorPicker({ value: "#278787" });
         * // gets the selected color in RGB format
        * var color=$("#colorPick").ejColorPicker("getColor");
        * alert("Red="+color.r+", Green="+color.g+", Blue="+color.b);
        * &lt;/script&gt;       
		
        * @memberof ejColorPicker
	    * @instance
		*/
        getColor: function () {
            return this.rgb;
        },
        /**
        * Gets the selected color value as string
		* @return jQuery
		
        * @example   
        * &lt;input type="text" id="colorPick"/&gt; <br> 
        * &lt;script&gt;
        * // Create Color picker
        * $('#colorPick').ejColorPicker({ value: "#278787" });
        * // Create ColorPicker instance
		* var colorObj = $("#colorPick").data("ejColorPicker");
		* alert(colorObj.getValue()); // gets the selected color value as string
        * &lt;/script&gt; 
        
        * @example   
        * &lt;input type="text" id="colorPick"/&gt; <br> 
        * &lt;script&gt;
        * // Create Color picker
        * $('#colorPick').ejColorPicker({ value: "#278787" });
         * // gets the selected color value as string
        * alert($("#colorPick").ejColorPicker("getValue"));
        * &lt;/script&gt;       
		
        * @memberof ejColorPicker
	    * @instance
		*/
        getValue: function () {
            return this.value();
        },
        _alphaGradient: function (value) {
            var browser = ej.browserInfo();
            var value = ej.isNullOrUndefined(value) ? "#000000" : value;
            if (browser.name == "mozilla")
                this.popupList.find("#" + this._id + "alpha").attr({ "style": "background:-moz-linear-gradient(center top," + value + ",#fff) repeat scroll 0 0 rgba(0, 0, 0, 0);" });
            else if ((browser.name == "msie") && (browser.version == "9.0" || browser.version == "8.0"))
                this.popupList.find("#" + this._id + "alpha").attr({ "style": "filter: progid:DXImageTransform.Microsoft.gradient( startColorstr=" + value + ", endColorstr='#ffffff',GradientType=0 );" });
            else if (browser.name == "msie")
                this.popupList.find("#" + this._id + "alpha").attr({ "style": "background:-ms-linear-gradient(top," + value + ",#fff) repeat scroll 0 0 rgba(0, 0, 0, 0);" });
            else if (browser.name == "chrome" || browser.name == "safari")
                this.popupList.find("#" + this._id + "alpha").attr({ "style": "background:-webkit-linear-gradient(top," + value + ",#fff) repeat scroll 0 0 rgba(0, 0, 0, 0);" });
            else if (browser.name == "opera")
                this.popupList.find("#" + this._id + "alpha").attr({ "style": "background:-o-linear-gradient(top," + value + ",#fff) repeat scroll 0 0 rgba(0, 0, 0, 0);" });
            if (browser.name == "msie" && browser.version == "8.0")
                this.popupList.find("#" + this._id + "alpha").children(".e-handle").css({ "background": this._formRGB(this.rgb), "filter": "alpha(opacity=" + this.rgb.a * 100 + ")" });
        },
        _hueGradient: function () {
            var temp = this._hsv;
            var value = { h: this._hsv.h, s: 100, v: 100 };
            this.popupList.find("#" + this._id + "hue").children(".e-handle").css({ "background": this._formRGB(this.HSVToRGB(value)) });
            this._hsv = temp;
        },
        _changeEvent: function () {
            var colorCode;
            if (this._change) {
                colorCode = this.RGBToHEX(this.rgb);
                this._alphaGradient(colorCode);
                this._trigger("change", { value: colorCode });
            }
        },
        _selectEvent: function () {
            this.value(this.RGBToHEX(this.rgb));
            if (this.element.is("input")) this._updateValue();
            if (this._previousColor !== this.value()) {
                this.element.attr({ 'value': this.value() })
                this._trigger("select", { value: this.value() });
            }
        },
        _changeHue: function (e) {
            this._hsv.h = Math.round(e.value);
            this._hueGradient();
            this._hsvValue();
            this._changeEvent();
        },
        _changeAlpha: function (e) {
            this.rgb.a = ej.isNullOrUndefined(e) ? this.model.opacityValue / 100 : e.value / 100;
            if (this._browser.name = "msie" && this._browser.version == "8.0") {
                this._currentTag.css({ "background-color": this._formRGB(this.rgb), "filter": "alpha(opacity=" + this.rgb.a * 100 + ")" });
                this.popupList.find("#" + this._id + "alpha").children(".e-handle").css({ "background": this._formRGB(this.rgb), "filter": "alpha(opacity=" + this.rgb.a * 100 + ")" });
            }
            else {
                this._currentTag.css("background-color", this._formRGBA(this.rgb));
                this.popupList.find("#" + this._id + "alpha").children(".e-handle").css({ "background": this._formRGBA(this.rgb) });
            }
            this._inputTagValue(this._selectedButton);
        },
        _updateValue: function () {
            if (this._browser.name = "msie" && this._browser.version == "8.0") this.spanElement.css({ "background-color": this._formRGB(this.rgb), "filter": "alpha(opacity=" + this.rgb.a * 100 + ")" });
            else this.spanElement.css({ "background-color": this._formRGBA(this.rgb) });
        },
        _wireEvents: function () {
            if (this.element.is('input')) {
                this._on(this.wrapper, "blur", this._targetBlur);
                this._on(this.wrapper, "focus", this._targetFocus);
                this._on(this.wrapper, "keydown", this._popupShown);
            }
            this._on(this._cancelTag, "click", this.hide);
            this._on(this._changeTag, "click", this._switchModel);
            this._on(this._groupTag, "click", this._groupButton);
            this._on(this._addTag, "click", this._addColor);
            this._on(this._buttonTag, "click", this._buttonClick);
            this._on(this._presetContainer.find("li.e-preset-row"), "mousedown", this._colorPresetsClick);

        },
        _unWireEvents: function () {
            if (!this.model.displayInline && !this.element.is('input')) {
                this._off(this.wrapper, "blur", this._targetBlur);
                this._off(this.wrapper, "focus", this._targetFocus);
                this._off(this.wrapper, "keydown", this._popupShown);
            }
            this._off(this._cancelTag, "click", this.hide);
            this._off(this._changeTag, "click", this._switchModel);
            this._off(this._groupTag, "click", this._groupButton);
            this._off(this._addTag, "click", this._addColor);
            this._off(this._buttonTag, "click", this._buttonClick);
            this._off(this._presetContainer.find("li.e-preset-row"), "mousedown", this._colorPresetsClick);
        },
        _popupShown: function (e) {
            if (e.altKey && e.keyCode == 40) { this._showHidePopup(); return false; }
        },
        _recentColor: function (e) {
            this._divTag.find('.e-select').removeClass('e-select').addClass('e-block');
            var hexCode = e.target.attributes.value;
            var rgbCode = e.target.attributes.style;
            if (ej.isNullOrUndefined(hexCode) || ej.isNullOrUndefined(rgbCode)) { this._change = false; return false; }
            $(e.target.parentNode).addClass('e-select').removeClass('e-block');
            var alpha = rgbCode.value.replace(/^(background-color:rgb|background-color:rgba)\(/, '').replace(/\)$/, '').replace(/\s/g, '').split(',');
            this._opacity.option('value', parseFloat(alpha[3]) * 100);
            this.rgb.a = parseFloat(alpha[3]);
            this._HexToHSV(hexCode.value)
            this._valueOperation();
            this._inputTagValue(this._selectedButton);
            this._colorSlider.option('value', parseInt(this._hsv.h));
            this._hueGradient();
            this._changeEvent();
            if (!this.model.displayInline || this.element.is("input"))
                this.wrapper.focus();
        },

        _handleClick: function (e) {
            e.preventDefault();
            this.mouseDownPos = this._handlePos;
            this._gradientArea.bind("mousemove", $.proxy(this._handleMovement, this));
            $(document).bind("mouseup", $.proxy(this._handleUp, this));
        },
        _handleMove: function (e) {
            $(this._handleArea).focus();
            this._handleMovement(e);
        },
        _handleMovement: function (e) {
            //value 100 used to specify the highest value of s and v.
            //the value 146 specify the gradient area height
            //the value 152 specify the gradient area width
            if (!this.model.enabled) return false;
            if (!this.model.displayInline || this.element.is("input"))
                this.wrapper.focus();
            this._hsv.v = parseInt(100 * (this._gradientArea.height() - Math.max(0, Math.min(this._gradientArea.height(), (e.pageY - this._gradientArea.offset().top)))) / this._gradientArea.height(), 10);
            this._hsv.s = parseInt(100 * (Math.max(0, Math.min(this._gradientArea.width(), (e.pageX - this._gradientArea.offset().left)))) / this._gradientArea.width(), 10);
            this._hsvValue();
            this._change = true;
            this._changeEvent();
        },
        _handleUp: function () {
            $(document).unbind('mouseup', this._handleUp);
            this._gradientArea.unbind('mousemove', this._handleMovement);
            return false;
        },
        _handlePosition: function () {
            this._handlePos = this._handleArea ? {
                left: parseInt(this._gradientArea.width() * this._hsv.s / 100, 10) + "px",
                top: parseInt(this._gradientArea.height() * (100 - this._hsv.v) / 100, 10) + "px"
            } : "";
            this._handleArea.css({ "left": this._handlePos.left, "top": this._handlePos.top });
        },
        _addColor: function () {
            this._previousColor = this.value();
            var collection = this._divTag.find('> div');
            value = this._selectedButton.html() != "HSVA" ? this._inputTag.val() : this._formRGBA(this.HSVToRGB(this._hsv));
            if (value !== "" && this._change) {
                if (this.model.showRecentColors && collection.length <= 12) {
                    $($(collection)[collection.length - 2]).remove();
                    this._generateLi();
                }
            }
            if (!this.model.displayInline || this.element.is("input")) this.wrapper.focus();
        },
        _buttonClick: function (e) {
            this._change = true;
            this._previousColor = this.value();
            var value = this._inputTag.val(), collection = this._divTag.find('div');
            this.model.opacityValue = this.rgb.a * 100;
            this.value(this.RGBToHEX(this.rgb));
            this._updatePreviewColor();
            if (this.model.displayInline && this.element.is("input") || !this.model.displayInline) {
                this._selectEvent();
                this._change ? this.hide() : "";
                this.wrapper.focus();
            }
            this._opacity.option('value', this.model.opacityValue);
        },
        _generateLi: function () {
            this._liTag = ej.buildTag('div.e-colorblock e-block').attr({ "value": this.RGBToHEX(this.rgb), "tabindex": "0" });
            var spanTag = ej.buildTag('div.e-color e-set').attr({ "value": this.RGBToHEX(this.rgb), "title": this.RGBToHEX(this.rgb) });
            if (this._browser.name = "msie" && this._browser.version == "8.0") spanTag.css({ "background-color": this._formRGB(this.rgb), "filter": "alpha(opacity=" + this.rgb.a * 100 + ")" });                
            else spanTag.css({ "background-color": this._formRGBA(this.rgb) });                            
            this._liTag.append(spanTag);
            this._divTag.prepend(this._liTag);
        },
        _colorCodeValue: function (e) {
            var newValue = "", codeValue = this._inputTag.val(), color, value, code, count;
            value = $.trim(codeValue);
            value.length == 5 ? this._inputTag.removeClass('e-error') : "";
            if ((e.shiftKey && e.keyCode >= 35 && e.keyCode <= 40) || (e.ctrlKey && (e.keyCode == 88 || e.keyCode == 86)) || e.keyCode == 190)
                this._keyPressFlag = 1;
            else if ((!e.crtlKey && !e.shiftKey) && ((e.keyCode >= 65 && e.keyCode < 71) || (e.keyCode >= 35 && e.keyCode <= 40) || (e.keyCode >= 48 && e.keyCode <= 57) || e.keyCode == 13 || e.keyCode == 8 || e.keyCode == 46 || e.type === "blur"))
                this._keyPressFlag = 1;
            else this._keyPressFlag = 0;
            if (this.model.enableOpacity && (e.keyCode == 188 || e.keyCode == 71 || e.keyCode == 82) || (e.shiftKey && (e.keyCode == 57 || e.keyCode == 48)))
                this._keyPressFlag = 1;
            if (this._keyPressFlag == 1) {
                this._inputTag.removeClass('e-error');
                if (e.keyCode === 13 || e.type === "blur") {
                    this._inputTag.removeClass('e-error');
                    var regex = /^\#([a-fA-F0-9]{6}|[a-fA-F0-9]{3})$/;
                    code = value.match(regex);
                    if (!ej.isNullOrUndefined(code)) {
                        if (code[1].length === 3) {
                            for (count = 0; count < code[1].length; count++) {
                                newValue += code[1][count] + code[1][count];
                            }
                        }
                        else if (code[1].length === 6)
                            newValue = code[1];
                        value = this.hexCodeToRGB("#" + newValue);
                        this._inputTag.val("#" + newValue);
                        this.rgb = this.HSVToRGB(this.RGBToHSV(value));
                        this._change = true;
                    }
                    else {
                        var rgbRegex = /^rgba?\((\d+),\s*(\d+),\s*(\d+)(?:,\s*(\d+(?:\.\d+)?))?\)$/;
                        code = value.match(rgbRegex);
                        if (!ej.isNullOrUndefined(code)) {
                            this._rgbaColor(code);
                        }
                        else {
                            var hsvRegex = /^hsva?\((\d+),\s*(\d+),\s*(\d+)(?:,\s*(\d+(?:\.\d+)?))?\)$/;
                            code = value.match(hsvRegex);
                            if (!ej.isNullOrUndefined(code)) {
                                this._hsvColor(code);
                            }
                            else {
                                //this._inputTag.addClass('e-error');
                                this._showAlert();
                                this._change = false;
                                return false;
                            }
                        }
                    }
                    if (this._change) {
                        this._valueOperation();
                        this._colorSlider.option('value', parseInt(this._hsv.h));
                        this._hueGradient();
                        this._inputTag.removeClass("e-error");
                    }
                }
            }
            else {
                if (e.keyCode != 9)
                    e.preventDefault();
                if (!e.shiftKey && !e.ctrlKey)
                    this._showAlert();
            }
        },
        _rgbaColor: function (code) {
            var rgb = {}, color, newValue;
            if (code[0].split('(')[0] == "rgba" && !ej.isNullOrUndefined(code[4])) {
                rgb.r = code[1]; rgb.g = code[2]; rgb.b = code[3]; rgb.a = code[4];
            }
            else if (code[0].split('(')[0] == "rgb" && ej.isNullOrUndefined(code[4])) {
                rgb.r = code[1]; rgb.g = code[2]; rgb.b = code[3]; rgb.a = this.rgb.a;
                this._inputTag.val("rgba(" + rgb.r + "," + rgb.g + "," + rgb.b + "," + rgb.a + ")");
            }
            else {
                this._inputTag.addClass('e-error');
                this._change = false;
                return false;
            }
            this.rgb.a = parseFloat(rgb.a);
            newValue = this.RGBToHEX(rgb);
            this._HexToHSV(newValue);
            this._inputTag.removeClass("e-error");
            this._change = true;
        },
        _hsvColor: function (code) {
            var hsv = {};
            if (!ej.isNullOrUndefined(code[4])) {
                hsv.h = code[1]; hsv.s = code[2]; hsv.v = code[3]; hsv.a = code[4];
            }
            else {
                this._inputTag.addClass('e-error');
                this._change = false;
                return false;
            }
            this.rgb.a = parseFloat(hsv.a);
            this.rgb = this.HSVToRGB(hsv);
            this._inputTag.removeClass("e-error");
            this._change = true;
        },
        _showAlert: function () {
            var ptr = this;
            this._inputTag.addClass("e-error").attr('aria-invalid', "true").animate({ Opacity: 1 }, 700, null, function () {
                $(ptr._inputTag).removeClass("e-error").attr('aria-invalid', "false");
            });
        },
        _iconClick: function (e) {
            e.preventDefault();
            this._showHidePopup();
            this.wrapper.focus();
        },
        _showHidePopup: function () {
            if (this.model.displayInline) return false;
            if (!this.isPopupOpen)
                this.show();
            else {
                this.hide();
                this.wrapper.focus();
            }
        },
        /**
        * Hides the colorpicker popup, if in opended state.
		* @return jQuery
		
        * @example   
        * &lt;input type="text" id="colorPick"/&gt; <br> 
        * &lt;script&gt;
        * // Create Color picker
        * $('#colorPick').ejColorPicker({ value: "#278787" });
        * // Create ColorPicker instance
		* var colorObj = $("#colorPick").data("ejColorPicker");
		* colorObj.hide(); // hide the colorpicker popup
        * &lt;/script&gt; 
        
        * @example   
        * &lt;input type="text" id="colorPick"/&gt; <br> 
        * &lt;script&gt;
        * // Create Color picker
        * $('#colorPick').ejColorPicker({ value: "#278787" });
         * // hide the colorpicker popup
        * $("#colorPick").ejColorPicker("hide");
        * &lt;/script&gt;       
		
        * @memberof ejColorPicker
	    * @instance
		*/
        hide: function () {
            if (!this.isPopupOpen || this.model.displayInline) return false;
            this.isPopupOpen = false;
            this._dataBind = false;
            this.wrapper.focus();
            this.popupContainer.slideUp(200, "easeOutQuad");
            if (!this.model.displayInline)
                this._off($(document), "mousedown", this._onDocumentClick);
            this._off(this._inputTag, "keydown", this._colorCodeValue);
            this._off(this._inputTag, "blur", this._colorCodeValue);
            this._modelType == "palette" ? this._off($(document), "keydown", this._keyDown) : this._off($(document), "keydown", this._onKeyDown);
            this._trigger("close");
        },
        /**
        * Open the colorpicker popup.
		* @return jQuery
		
        * @example   
        * &lt;input type="text" id="colorPick"/&gt; <br> 
        * &lt;script&gt;
        * // Create Color picker
        * $('#colorPick').ejColorPicker({ value: "#278787" });
        * // Create ColorPicker instance
		* var colorObj = $("#colorPick").data("ejColorPicker");
		* colorObj.show(); // open the colorpicker popup
        * &lt;/script&gt; 
        
        * @example   
        * &lt;input type="text" id="colorPick"/&gt; <br> 
        * &lt;script&gt;
        * // Create Color picker
        * $('#colorPick').ejColorPicker({ value: "#278787" });
         * // open the colorpicker popup
        * $("#colorPick").ejColorPicker("show");
        * &lt;/script&gt;       
		
        * @memberof ejColorPicker
	    * @instance
		*/
        show: function () {
            if (!this.model.displayInline || this.element.is("input")) this.wrapper.focus();
            if (this.isPopupOpen || !this.model.enabled) return false;
            this.isPopupOpen = true;
            if (this.model.modelType == "palette") this._cellSelect();
            this._previousColor = this.value();
            this.popupContainer.children().find('.e-focus').removeClass('e-focus');
            if (!this.model.displayInline) this._setPopupPosition();
            var proxy = this;
            this.popupContainer.slideDown(200, "easeOutQuad", function () {
                proxy.isFocused = true;
                if (!proxy.model.displayInline)
                    proxy._on($(document), "mousedown", proxy._onDocumentClick);
            });
            if (!this._dataBind)
                this._modelType == "palette" ? this._on($(document), "keydown", this._keyDown) : this._on($(document), "keydown", this._onKeyDown);
            this._on(this._inputTag, "keydown", this._colorCodeValue);
            this._on(this._inputTag, "blur", this._colorCodeValue);
            this._trigger("open");
            this._dataBind = true;
        },
        _showBindEvents: function () {
            this._modelType == "palette" ? this._on($(document), "keydown", this._keyDown) : this._on($(document), "keydown", this._onKeyDown);
        },
        _hideUnBindEvents: function () {
            this._off($(document), "keydown");
            this._modelType == "palette" ? this._off($(document), "keydown", this._onKeyDown) : this._off($(document), "keydown", this._keyDown);
        },
        _switchEvents: function () {
            if (this._switch) {
                this._on(this._gradientArea, "mousedown", this._handleMove);
                this._on(this._handleArea, "mousedown", this._handleClick);
                this._on(this._gradientArea, "mousedown", this._handleClick);
            }
            else {
                this._on(this._collection, "mousedown", this._onSelect);
            }
        },
        _unSwitchEvents: function () {
            if (!this._switch) {
                this._off(this._gradientArea, "mousedown", this._handleMove);
                this._off(this._handleArea, "mousedown", this._handleClick);
                this._off(this._gradientArea, "mousedown", this._handleClick);
            }
            else {
                this._off(this._collection, "mousedown", this._onSelect);
            }
        },
        _groupButton: function (e) {
            if ($(e.target).hasClass('e-disable')) return false;
            if ($(e.target).hasClass("e-button")) {
                var element = this._groupTag.find('.e-btn.e-select');
                this._inputTagValue($(e.target));
                this._selectedButton.html() !== "HEX" ? this._inputTag.attr('maxLength', '22') : this._inputTag.attr('maxLength', '7');
                this._groupTag.find('.e-click').removeClass('e-click');
                $(e.target).addClass('e-click');
            }
        },
        _inputTagValue: function (type) {
            if (type.html() == "RGBA") this._inputTag.val(this._formRGBA(this.rgb));
            else if (type.html() == "HEX") this._inputTag.val(this.RGBToHEX(this.rgb));
            else if (type.html() == "HSVA") {
                if (this.model.modelType != "palette")
                    this._inputTag.val("hsva(" + Math.round(this._hsv.h) + "," + Math.round(this._hsv.s) + "," + Math.round(this._hsv.v) + "," + this.rgb.a + ")");
            }
            this._selectedButton = type;
        },
        _bindRecentEvent: function () {
            this._on(this._divTag, "click", this._recentColor);
        },
        _unBindRecentEvent: function () {
            this._off(this._divTag, "click", this._recentColor);
        },
        _handlePlacement: function (prop, value, bool) {
            var hsv = this._hsv;
            hsv[prop] += value * (bool ? 1 : 3);
            if (hsv[prop] < 0) { hsv[prop] = 0; }
            prop === "s" ? this._hsv.s = hsv[prop] : this._hsv.v = hsv[prop];
            this._hsvValue();
            this._changeEvent();
        },
        _onKeyDown: function (e) {
            if (!this.model.enabled) return false;
            var key = e.keyCode, active;
            this._change = true;
            if (e.shiftKey && key == 9) {
                active = document.activeElement;
                $(active).hasClass('e-draghandle') ? this._focusWrapper(e) : "";
            }
            if ((!e.altKey && !e.shiftKey)) {
                switch (key) {
                    case 39:
                        if (e.target.className === "e-draghandle e-color-image" || (this.element.is('input') && e.target == this.wrapper[0])) {
                            e.preventDefault();
                            this._handlePlacement("s", 1, e.ctrlKey);
                        }
                        break;
                    case 38:
                        if (e.target.className === "e-draghandle e-color-image" || (this.element.is('input') && e.target == this.wrapper[0])) {
                            e.preventDefault();
                            this._handlePlacement("v", 1, e.ctrlKey);
                        }
                        break;
                    case 37:
                        if (e.target.className === "e-draghandle e-color-image" || (this.element.is('input') && e.target == this.wrapper[0])) {
                            e.preventDefault();
                            this._handlePlacement("s", -1, e.ctrlKey);
                        }
                        break;
                    case 40:
                        if (e.target.className === "e-draghandle e-color-image" || (this.element.is('input') && e.target == this.wrapper[0])) {
                            e.preventDefault();
                            this._handlePlacement("v", -1, e.ctrlKey);
                        }
                        break;
                    case 13:
                        e.preventDefault();
                        this._buttonClick(e);
                        break;
                    case 27:        // Esc Key
                        e.preventDefault();
                        this.hide();
                        break;
                    case 9:
                        active = document.activeElement;
                        $(active).hasClass('e-colorwidget') ? this._focusPopup(e) : "";
                        break;
                }
            }
        },
        _focusPopup: function (e) {
            $(this._handleArea).focus();
            e.preventDefault();
        },
        _focusWrapper: function (e) {
            $(this.wrapper).focus();
            e.preventDefault();
        },
        _onDocumentClick: function (e) {
            if (!$(e.target).is(this.popupContainer) && !$(e.target).parents(".e-colorpicker").is(this.popupContainer) &&
              !$(e.target).is(this.wrapper) && !$(e.target).parents(".e-colorpickerwidget").is(this.wrapper) && !$(e.target).parents('.e-presetWrapper').is(this._presetContainer)) {
                this.hide();
                this._isFocused = false;
                this.wrapper.removeClass('e-focus');
            }
        },
        _range: function (range, value) {
            if (value === "") return value = 0;
            else if (value > range) return range;
            else return value;
        },
        _hsvValue: function () {
            var colorCode, hsv;
            this._change = true;
            this._hsv.v = this._hsv.v >= 100 ? 100 : this._hsv.v;
            this._hsv.s = this._hsv.s >= 100 ? 100 : this._hsv.s;
            this.hsv = this._hsv;
            this.rgb = this.HSVToRGB(this.hsv);
            this._valueOperation();
            this._inputTagValue(this._selectedButton);
        },
        _formRGB: function (value) {
            if (!ej.isNullOrUndefined(value)) return "rgb(" + value.r + "," + value.g + "," + value.b + ")";
        },
        _formRGBA: function (value) {
            if (!ej.isNullOrUndefined(value)) return "rgba(" + value.r + "," + value.g + "," + value.b + "," + value.a + ")";
        },
        _rgbValue: function (e) {
            var rgbColor, colorCode;
            value = this._HexToRGB(this.value());
            if (!ej.isNullOrUndefined(value)) {
                this.rgb = value;
                this._change = true;
                this.HSVToRGB(this.RGBToHSV(this.rgb));
                this._colorSlider.option('value', parseInt(this._hsv.h));
                this._opacity.option('value', this.rgb.a * 100);
            }
            this._valueOperation();
            this._inputTagValue(this._selectedButton);
        },
        _valueOperation: function () {
            this._handlePosition();
            this._alphaGradient(this.value());
            this._inputTag.removeClass("e-error");
            this._updateUI();
        },
        _HexToHSV: function (hex) {
            return this.HSVToRGB(this.RGBToHSV(this._HexToRGB(hex)));
        },
        _HexToRGB: function (hex) {
            if (!ej.isNullOrUndefined(hex)) {
                var reg = "^#([A-Fa-f0-9]{6}|[A-Fa-f0-9]{3})$", hex, validate = hex.match(reg);
                if (ej.isNullOrUndefined(validate)) { this._change = false; return false; }
                if (validate[1].length == 3)
                    hex = "#" + validate[1][0] + validate[1][0] + validate[1][1] + validate[1][1] + validate[1][2] + validate[1][2];
                this._change = true;
                hex = parseInt(((hex.indexOf('#') > -1) ? hex.substring(1) : hex), 16);
                value = ej.isNullOrUndefined(this.rgb) ? this.model.opacityValue / 100 : this.rgb.a;
                return this.rgb = { r: hex >> 16, g: (hex & 0x00FF00) >> 8, b: (hex & 0x0000FF), a: value };
            }
        },
        /**
       * Convert color value from RGB to HSV
       * @return jQuery
       
       * @example   
       * &lt;input type="text" id="colorPick"/&gt; <br> 
       * &lt;script&gt;
       * // Create Color picker
       * $('#colorPick').ejColorPicker({ value: "#278787" });
       * // Create ColorPicker instance
       * var colorObj = $("#colorPick").data("ejColorPicker");
       * var color=colorObj.RGBToHSV({r:39,g:135,b:135}); // Convert color value from RGB to HSV
       * alert("H="+color.r+", S="+color.g+", V="+color.b);
       * &lt;/script&gt; 
       
       * @example   
       * &lt;input type="text" id="colorPick"/&gt; <br> 
       * &lt;script&gt;
       * // Create Color picker
       * $('#colorPick').ejColorPicker({ value: "#278787" });
       * // Convert color value from RGB to HSV        
       * var color=$("#colorPick").ejColorPicker("RGBToHSV","{r:39,g:135,b:125}");
       * alert("H="+color.r+", S="+color.g+", V="+color.b);
       * &lt;/script&gt;       
       
       * @memberof ejColorPicker
       * @instance
       */
        RGBToHSV: function (rgb) {
            var hsv = { h: 0, s: 0, v: 0 };
            var min = Math.min(rgb.r, rgb.g, rgb.b);
            var max = Math.max(rgb.r, rgb.g, rgb.b);
            var differ = max - min;
            hsv.v = max;
            hsv.v *= 100 / 255;
            if (differ === 0) {
                this._hsv = hsv;
                return hsv;
            }
            hsv.s = max != 0 ? 255 * differ / max : 0;
            if (hsv.s != 0) {
                if (rgb.r == max) hsv.h = (rgb.g - rgb.b) / differ;
                else if (rgb.g == max) hsv.h = 2 + (rgb.b - rgb.r) / differ;
                else hsv.h = 4 + (rgb.r - rgb.g) / differ;
            } else hsv.h = -1;
            hsv.h *= 60;
            if (hsv.h < 0) hsv.h += 360;
            hsv.s *= 100 / 255;
            this._hsv = hsv;
            return hsv;
        },
        /**
        * Convert color value from HSV to RGB
		* @return jQuery
		
        * @example   
        * &lt;input type="text" id="colorPick"/&gt; <br> 
        * &lt;script&gt;
        * // Create Color picker
        * $('#colorPick').ejColorPicker({ value: "#278787" });
        * // Create ColorPicker instance
		* var colorObj = $("#colorPick").data("ejColorPicker");
		* var color=colorObj.HSVToRGB({h:230,s:98,v:98}); // Convert color value from HSV to RGB
        * alert("Red="+color.r+", Green="+color.g+", Blue="+color.b);
        * &lt;/script&gt; 
        
        * @example   
        * &lt;input type="text" id="colorPick"/&gt; <br> 
        * &lt;script&gt;
        * // Create Color picker
        * $('#colorPick').ejColorPicker({ value: "#278787" });
        * // Convert color value from HSV to RGB        
        * var color=$("#colorPick").ejColorPicker("HSVToRGB","{h:230,s:98,v:98}");
        * alert("Red="+color.r+", Green="+color.g+", Blue="+color.b);
        * &lt;/script&gt;       
		
        * @memberof ejColorPicker
	    * @instance
		*/
        HSVToRGB: function (hsv) {
            var rgb = {};
            var h = Math.round(hsv.h);
            var s = Math.round(hsv.s * 255 / 100);
            var v = Math.round(hsv.v * 255 / 100);
            if (s == 0) {
                rgb.r = rgb.g = rgb.b = v;
            } else {
                var t1 = v;
                var t2 = (255 - s) * v / 255;
                var t3 = (t1 - t2) * (h % 60) / 60;
                if (h == 360) h = 0;
                if (h < 60) { rgb.r = t1; rgb.b = t2; rgb.g = t2 + t3 }
                else if (h < 120) { rgb.g = t1; rgb.b = t2; rgb.r = t1 - t3 }
                else if (h < 180) { rgb.g = t1; rgb.r = t2; rgb.b = t2 + t3 }
                else if (h < 240) { rgb.b = t1; rgb.r = t2; rgb.g = t1 - t3 }
                else if (h < 300) { rgb.b = t1; rgb.g = t2; rgb.r = t2 + t3 }
                else if (h < 360) { rgb.r = t1; rgb.g = t2; rgb.b = t1 - t3 }
                else { rgb.r = 0; rgb.g = 0; rgb.b = 0 }
            }
            this._hsv = hsv;
            var value = ej.isNullOrUndefined(this.rgb) ? this.model.opacityValue / 100 : this.rgb.a;
            return { r: Math.round(rgb.r), g: Math.round(rgb.g), b: Math.round(rgb.b), a: value }
        },
        _HSVToHex: function (hsv) {
            return this.RGBToHEX(this.HSVToRGB(hsv));
        },
        _toHEX: function (rgb) {
            if (rgb.indexOf("#") !== -1) return rgb;
            rgb = rgb.match(/^rgb\((\d+),\s*(\d+),\s*(\d+)\)$/);
            return "#" + this._hex(rgb[1]) + this._hex(rgb[2]) + this._hex(rgb[3]);
        },

        //Process the rgb object values to color code
        /**
        * Convert color value from RGB to HEX
		* @return jQuery
		
        * @example   
        * &lt;input type="text" id="colorPick"/&gt; <br> 
        * &lt;script&gt;
        * // Create Color picker
        * $('#colorPick').ejColorPicker({ value: "#278787" });
        * // Create ColorPicker instance
		* var colorObj = $("#colorPick").data("ejColorPicker");
		* alert(colorObj.RGBToHEX(colorObj.getColor())); // Convert color value from RGB to HEX
        * &lt;/script&gt; 
        
        * @example   
        * &lt;input type="text" id="colorPick"/&gt; <br> 
        * &lt;script&gt;
        * // Create Color picker
        * $('#colorPick').ejColorPicker({ value: "#278787" });
        * // Create ColorPicker instance
		* var colorObj = $("#colorPick").data("ejColorPicker");
         * // Convert color value from RGB to HEX
        * alert($("#colorPick").ejColorPicker("RGBToHEX",colorObj.getColor()));
        * &lt;/script&gt;       
		
        * @memberof ejColorPicker
	    * @instance
		*/
        RGBToHEX: function (rgb) {
            if (!ej.isNullOrUndefined(rgb))
                return "#" + this._hex(rgb.r) + this._hex(rgb.g) + this._hex(rgb.b);
        },
        _hex: function (x) {
            return ("0" + parseInt(x).toString(16)).slice(-2);
        },
        _colorValue: function (value) {
            this._color = value.indexOf("#") != -1 ? this.hexCodeToRGB(value) : "";
            return "rgb(" + this._color.r + ", " + this._color.g + ", " + this._color.b + ")";
        },
        //Process the color code value to RGB
        /**
        * To Convert color value from hexCode to RGB
		* @return jQuery
		
        * @example   
        * &lt;input type="text" id="colorPick"/&gt; <br> 
        * &lt;script&gt;
        * // Create Color picker
        * $('#colorPick').ejColorPicker({ value: "#278787" });
        * // Create ColorPicker instance
		* var colorObj = $("#colorPick").data("ejColorPicker");
		* var color=colorObj.hexCodeToRGB("#278787"); // Convert color value from hexCode to RGB
        * alert("Red="+color.r+", Green="+color.g+", Blue="+color.b);
        * &lt;/script&gt; 
        
        * @example   
        * &lt;input type="text" id="colorPick"/&gt; <br> 
        * &lt;script&gt;
        * // Create Color picker
        * $('#colorPick').ejColorPicker({ value: "#278787" });
         * // Convert color value from hexCode to RGB
        * var color=$("#colorPick").ejColorPicker("hexCodeToRGB","#278787");
        * alert("Red="+color.r+", Green="+color.g+", Blue="+color.b);
        * &lt;/script&gt;       
		
        * @memberof ejColorPicker
	    * @instance
		*/
        hexCodeToRGB: function (colorCode) {
            var result = /^#?([a-f\d]{2})([a-f\d]{2})([a-f\d]{2})$/i.exec(colorCode);
            return result ? {
                r: parseInt(result[1], 16),
                g: parseInt(result[2], 16),
                b: parseInt(result[3], 16),
                a: this.rgb.a
            } : null;
        },

        _updatePreviewColor: function () {
            if (this._browser.name = "msie" && this._browser.version == "8.0")
                this._previousTag.css({ "background-color": this._formRGB(this.rgb), "filter": "alpha(opacity=" + this.rgb.a * 100 + ")" });
            else
                this._previousTag.css({ "background-color": this._formRGBA(this.rgb) });
            this._oldValue = this.rgb;
        },
        _updateUI: function () {
            var value = this._hsv;
            if (this._switch) {
                var hsv = { h: this._hsv.h, s: 100, v: 100 };
                this._gradientArea.css({ "background-color": this._colorValue(this._HSVToHex(hsv)) });
            } else this._cellSelect();
            if (this._browser.name = "msie" && this._browser.version == "8.0") {
                this._currentTag.css({ "background-color": this._formRGB(this.rgb), "filter": "alpha(opacity=" + this.rgb.a * 100 + ")" });
                this._previousTag.css({ "background-color": this._formRGB(this._oldValue), "filter": "alpha(opacity=" + this.rgb.a * 100+ ")" });
            }
            else {
                this._currentTag.css({ "background-color": this._formRGBA(this.rgb) });
                this._previousTag.css({ "background-color": this._formRGBA(this._oldValue) });
                this.popupList.find("#" + this._id + "alpha").children(".e-handle").css({ "background": this._formRGBA(this.rgb) });
            }
            this._hsv = value;
        },

        _targetFocus: function (e) {
            e.preventDefault();
            if (!this._isFocused) {
                this._isFocused = true;
                this.wrapper.addClass("e-focus");
            }
        },
        _targetBlur: function (e) {
            this._isFocused = false;
            if (!this.isPopupOpen) this.wrapper.removeClass("e-focus");
        },
        _switchModel: function () {
            this.value(this.RGBToHEX(this.rgb));
            var proxy = this;
            if (this._modelType == "palette") {
                this._modelType = "picker";
                this._switcher.removeClass("e-paletteModel").addClass("e-pickerModel");
                this.PaletteWrapper.fadeOut(300, function () {
                    proxy._presetTag.parents('.e-split.e-widget').addClass('e-hide');
                    proxy._gradient.fadeIn(300);
                });
                this._switch = true;
                this._rgbValue();
                this._hueGradient();
                this._templateWrapper.find('#' + this._id + "hsv").ejButton("enable");
            } else {
                this._modelType = "palette";
                this._switcher.removeClass("e-pickerModel").addClass("e-paletteModel");
                this._switch = false;
                this._gradient.fadeOut(300, function () {
                    proxy._presetTag.parents('.e-split.e-widget').removeClass('e-hide');
                    if (ej.isNullOrUndefined(proxy.PaletteWrapper)) {
                        proxy.PaletteWrapper = proxy._layoutType(proxy.model.palette);
                        proxy._splitObj.option('prefixIcon', 'e-color-image e-' + this.model.presetType);
                        proxy.popupList.prepend(proxy.PaletteWrapper);
                    }
                    proxy.PaletteWrapper.fadeIn(300);
                });
                this._cellSelect();
                this._disableHSVButton();
            }
            if (!this.model.displayInline || this.element.is(":input")) this.wrapper.focus();
            this._switchEvents();
            this._unSwitchEvents();
            if (this.isPopupOpen) {
                this._hideUnBindEvents();
                this._showBindEvents();
            }
        },
        _disableHSVButton: function () {
            if ($(this._groupTag.find('.e-click')).attr('id') == this._id + "hsv") {
                this._inputTagValue(this._templateWrapper.find("#" + this._id + "rgba"));
                this._templateWrapper.find("#" + this._id + "rgba").addClass('e-click');
                this._templateWrapper.find('#' + this._id + "hsv").removeClass('e-click');
            }
            this._templateWrapper.find('#' + this._id + "hsv").ejButton("disable");
        },
        //palette Block
        _cellSelect: function () {
            var code, element, proxy = this;
            this._removeClass();
            this._collection.find('.e-item').each(function () {
                code = $(this).css("background-color");
                if (code && code.replace(/ /g, '') === proxy._formRGB(proxy.rgb)) {
                    element = this;
                }
            });
            $(element).addClass("e-state-selected").attr("aria-selected", true);
        },
        _removeClass: function () {
            this._collection.find('.e-item').removeClass('e-state-selected').removeAttr("aria-selected");
        },
        _position: function (items, element, columns) {
            items = Array.prototype.slice.call(items);
            var n = items.length,
            index = items.indexOf(element);
            if (index < 0) return columns < 0 ? items[n - 1] : items[0];
            index += columns;
            return items[index < 0 ? index += n : index %= n];
        },
        _onSelect: function (e) {
            this._collection.find('.e-item').removeClass("e-state-selected").removeAttr('aria-selected');
            if (e.target.style.backgroundColor != "") {
                this._HexToRGB(this._toHEX(e.target.style.backgroundColor));
                this._updateUI();
                this._inputTagValue(this._selectedButton);
                if (!this.model.displayInline || this.element.is("input")) this.wrapper.focus();
            }
            this._changeEvent();
            e.preventDefault();
        },
        _keyDown: function (e) {
            this._change = true;
            if (!this.model.enabled) return false;
            var selected = "",
                key = e.keyCode,
                items = this._collection.find('.e-item'),
                element = items.filter(".e-state-selected").get(0),
                columnSize = this.model.columns;
            if (!e.altKey && (key == 37 || key == 38 || key == 39 || key == 40) && (e.target.className !== "e-color-code"))
                this._removeClass();
            if (e.keyCode == 9) return false;
            switch (!e.altKey && key) {
                case 40:
                    if (e.target.className !== "e-color-code") {
                        e.preventDefault();
                        selected = this._position(items, element, columnSize);
                    }
                    break;
                case 37:
                    if (e.target.className !== "e-color-code") {
                        e.preventDefault();
                        selected = this._position(items, element, -1);
                    }
                    break;
                case 38:
                    if (e.target.className !== "e-color-code") {
                        e.preventDefault();
                        selected = this._position(items, element, -columnSize);
                    }
                    break;
                case 39:
                    if (e.target.className !== "e-color-code") {
                        e.preventDefault();
                        selected = this._position(items, element, 1);
                    }
                    break;
                case 13: //Enter Key                    
                    this._collection.find('.e-item').removeClass('e-state-selected').removeAttr("aria-selected");
                    this._buttonClick(e);
                    this._updateUI();
                    this.hide();
                    if (this.model.displayInline || this.element.is("input")) this.wrapper.focus();
                    break;
                case 27:  //Esc Key
                    this.hide();
                    if (this.model.displayInline || this.element.is("input")) this.wrapper.focus();
                    break;
            }
            if (selected) {
                $(selected).addClass('e-state-selected').attr("aria-selected", true);
                this._currentTag.css({ "background-color": this._formRGB(this._HexToRGB(selected.attributes.value.value)) });
                this._inputTagValue(this._selectedButton);
                this._changeEvent();
            }
        },
    })
    /**
    * Enum for ColorPicker Palette	 
    * @enum {String}
    * @global 
    */
    ej.ColorPicker.Palette = {
        /**  Represents the basic Palette. This is default Type*/
        BasicPalette: "basicpalette",
        /**  Represents the custom Palette. User will customize the palette*/
        CustomPalette: "custompalette",
    }
    /**
    * Enum for ColorPicker ModelType	 
    * @enum {String}
    * @global 
    */
    ej.ColorPicker.ModelType = {
        /**  Color picker is a Default type*/
        Default: "default",
        /**  Represents Palette Type*/
        Palette: "palette",
        /** Represents Picker Type */
        Picker: "picker"
    }
    /**
   * Enum for ColorPicker PresetType	 
   * @enum {String}
   * @global 
   */
    ej.ColorPicker.PresetType = {
        Basic: "basic",
        MonoChrome: "monochrome",
        FlatColors: "flatcolors",
        SeaWolf: "seawolf",
        WebColors: "webcolors",
        Sandy: "sandy",
        PinkShades: "pinkshades",
        Misty: "misty",
        Citrus: "citrus",
        Vintage: "vintage",
        MoonLight: "moonlight",
        CandyCrush: "candycrush",
    }
    var Colors = {
        basic: ["ffffff", "facbcb", "fccb98", "faf39a", "fbf8cd", "a6d38b", "aadee8", "d1ecf2", "cdcae5", "eecde1", "cccbcb", "f16667", "f69668", "f8ee6b", "f7ec37", "89c987", "75cddd", "8bd3e1", "9494c8", "9494c8", "b3b2b3", "ec2024", "f7971d", "ffcb67", "f5ea14", "74bf44", "69c8c9", "46c7f4", "6666ad", "b76cab", "676767", "971b1e", "ca6828", "ca9732", "979937", "0d9948", "339898", "4857a6", "62449a", "973794", "000000", "2f1110", "973620", "663433", "343416", "183319", "023334", "22205f", "3b2f8d", "310e31"],
        monochrome: ["ffffff", "e3e3e3", "c6c6c6", "aaaaaa", "8e8e8e", "717171", "555555", "393939", "1c1c1c", "000000", "f9e6e7", "f4d0d2", "efbabc", "e9a4a7", "e48e92", "df787c", "da6267", "d44c52", "cf363c", "ca2027", "fff4ca", "ffeb9e", "fff0b4", "ffeb9e", "ffe788", "ffe272", "ffd947", "ffd531", "ffd01b", "ffcc05", "e4f4eb", "ccead9", "b4e0c7", "9cd6b5", "84cca3", "6dc190", "55b77e", "3dad6c", "25a35a", "0d9948", "e8f4f4", "d6e3eb", "c4d1e3", "b3c0da", "a1aed1", "8f9dc9", "7d8bc0", "6c7ab7", "5a68af", "4857a6"],
        flatcolors: ["7477b8", "488bca", "18b1d4", "1db369", "78c162", "acc063", "ffe84e", "f6b757", "f79853", "ed6346", "E87F3D", "E4C45D", "B7A575", "999999", "67809F", "002228", "00A578", "F9A41F", "F3770B", "D7401B", "FFCB36", "82CC2C", "36B595", "6370AD", "D4264E", "004D8E", "22A04B", "F3A414", "C77405", "F3420B", "1ABC9C", "3498DB", "9B59B6", "E67E22", "E74C3C", "3A738A", "EBD9A7", "89AD78", "FF766D", "C76160", "BF3542", "CDC5BA", "EBE3D6", "3C3C3C", "2E2E2E", "77A7FB", "E57368", "FBCB43", "34B67A", "FFFFFF"],
        seawolf: ["0EEAFF", "15A9FA", "1B76FF", "1C3FFD", "2C1DFF", "0B3C4C", "0E5066", "13647F", "127899", "1A8BB2", "74B8E8", "659EBB", "3C9FFF", "26466F", "2472FF", "0069A4", "009BF2", "004165", "49A0B4", "274C5F", "000000", "7A5848", "E0A088", "F9DEC6", "3A2A22", "DC3522", "D9CB9E", "374140", "2A2C2B", "1E1E20", "CB3937", "FE6B2C", "654E44", "6DD16F", "70FE2C", "275673", "4681A6", "FDDEC9", "F22816", "400101", "071C2F", "388494", "E6A934", "F3DB5F", "534329", "206956", "47683B", "E1BFA6", "BF7950", "903932"],
        webcolors: ["0066aa", "00bbdd", "338800", "77bb00", "ffcc99", "990c0c", "0303c9", "336699", "669933", "cccccc", "EEEEEE", "E7C36F", "F7B230", "E35B20", "000033", "7D7A74", "BD524A", "FCB200", "8CFCC2", "2ACD6B", "666666", "666553", "FFFEEC", "B2B2A4", "AAA4B2", "9CA5E3", "5A668C", "BBA469", "CFC295", "FFFFFF", "DBBF56", "2E94B3", "808080", "E96656", "14A168", "DE185B", "D8806F", "DBE186", "D8CC63", "DCC527", "4E6C89", "E2BDAD", "EC6053", "81BBAD", "DFCDA5", "453394", "66398A", "313E7D", "336694", "788E91"],
        sandy: ["c0a986", "ecd9c3", "dfc79b", "f6d58e", "ecdaad", "fff3e0", "7f6b4a", "ffd694", "7f7a70", "ccac76", "E6E2AF", "A79A71", "EFECCA", "806F4C", "2F2F2E", "997F1A", "CCB65F", "FFD291", "6B674A", "635F3A", "7F693A", "FFEBC1", "FFD275", "7F7561", "CCA85E", "D29854", "4A4034", "C9AD8D", "4A351D", "968169", "E6E39F", "9A9757", "FFFDC9", "94909A", "E2E0E6", "960010", "EB1517", "CD7C29", "9A571C", "1F7A94", "7F6826", "7F724C", "FFE499", "FFD04C", "CCA63D", "FFA669", "92FFB6", "FFF352", "E8C269", "D7E8CB"],
        pinkshades: ["F6B1C3", "F0788C", "DE264C", "BC0D35", "A20D1E", "E12256", "BB1C48", "7B132F", "3B0917", "FA2660", "FFB7B5", "9A423F", "FF6D68", "BB5855", "CC5753", "E88161", "D66C60", "C2646E", "996072", "705262", "FFA1BD", "FF8FB7", "FF82AE", "E9719B", "CC6882", "F250C7", "BF1774", "BF2696", "AC60AA", "BB90C5", "BF1553", "F20775", "F2F2F2", "A68F63", "261414", "FFFFFF", "7F3443", "FF6887", "7F3443", "CC536C", "D06AA9", "E65F41", "650017", "BC1620", "FA427E", "3B1132", "84476E", "B83D65", "E6E0E8", "FF6EE8"],
        misty: ["5C7A84", "3D5372", "7C9196", "50748A", "ADBFBF", "010735", "052159", "194073", "376B8C", "FFFFFF", "985999", "C811CC", "892EFF", "FF6852", "DBA211", "0A0D0C", "85A67C", "46593E", "BBD9AD", "202616", "BF8E63", "734327", "A66C4B", "593A2F", "BFBFBF", "8DB0B6", "1B778A", "F46C1B", "881801", "192129", "81808C", "ABAABF", "0C0E09", "6A7366", "37402F", "5D6663", "84867B", "A4A66A", "BABBB1", "20211C", "6B9695", "646E8C", "6B8196", "61787F", "648C80", "8E9FBA", "89A8C8", "799ED1", "7FAEE7", "849EBD"],
        citrus: ["FAEA41", "E7F03E", "E3C647", "FAC541", "F0AB3E", "CCCA1F", "FFF300", "FFCB0D", "FF9500", "804A00", "6A692A", "FFFCA0", "FFFFFF", "CF664E", "EFAC66", "EFF299", "F2DC6D", "F29727", "F2600C", "592202", "214001", "4F7302", "1A2601", "BCD97E", "C0D904", "AAFEFF", "359D6D", "E5FF45", "65FCCF", "ABDC4B", "42B200", "C6FF00", "F2E304", "FFB200", "FF8600", "52EC04", "04E206", "94D507", "ECE404", "E2C904", "DA321C", "FF7913", "FBD028", "C0D725", "9FC131", "547312", "ADBF26", "DEB329", "F1DB47", "E08214"],
        vintage: ["684132", "fdbe30", "eaac21", "87783c", "3e4028", "ffc706", "cd5648", "5bafa9", "828282", "363636", "424862", "fb9a63", "bfc4d5", "f6fbf4", "febc98", "657050", "FCF082", "D8D98B", "A2AB80", "4D584A", "5ADED4", "4DAAAB", "26596A", "163342", "6C98A1", "010A26", "28403B", "557359", "AEBF8A", "C7D9AD", "AFFCCB", "CB4243", "D2997E", "36857E", "4AC6BB", "28394B", "191313", "AF0A18", "DC373D", "122438", "43734A", "A6A26D", "D9B448", "BF8C2C", "734002", "26010F", "866F53", "ACBD91", "7BAB87", "546859"],
        moonlight: ["241D37", "2A233D", "322B45", "362F49", "D4BA73", "261225", "592040", "8C3063", "A64985", "73345D", "A3C8FF", "85B6FF", "000040", "213190", "050859", "FFFFFF", "6AAED9", "4184BF", "224573", "A3C8FF", "CFC496", "B3B391", "889486", "61797B", "366577", "123340", "436E73", "7B8C61", "D7D996", "F0EBB4", "CFC496", "B3B391", "889486", "61797B", "366577", "123340", "436E73", "7B8C61", "D7D996", "F0EBB4", "341F36", "D9B5E0", "9889AB", "4D4E66", "1B2129", "5CBBE3", "FCF1BC", "5C8182", "383A47", "B4F257"],
        candycrush: ["0779f4", "30da00", "fb8006", "f9d802", "a71df7", "f70200", "fd49ae", "682e07", "9b2424", "5e7693", "F9AB3B", "EF5627", "FF0000", "00A398", "803C2C", "DE5711", "FFF026", "FF0048", "14A0CC", "00B229", "FFFFBE", "F7CD99", "FF77A1", "9886E8", "97CACB", "EAEDE5", "FFD127", "FF870C", "EC4610", "9A1900", "993460", "CC1464", "C300FF", "FFFFBC", "CCB914", "FFFEE2", "B24C5F", "FF274F", "0A94CC", "679DB2", "C2FFE6", "16B271", "5FFFBC", "B2442F", "FFA190", "E89359", "FFFB75", "F36EFF", "5999E8", "73EB86"],
    }

})(jQuery, Syncfusion);;
});