/*!
*  filename: ej.listview.js
*  version : 12.3
*  Copyright Syncfusion Inc. 2001 - 2014. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
*/
(function (fn) {
    typeof define === 'function' && define.amd ? define(["./../common/ej.core","./../common/ej.touch","./../common/ej.listviewbase"], fn) : fn();
})
(function () {
	
/**
* @fileOverview Plugin to style the Html ListView elements
* @copyright Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/

(function ($, ej, undefined) {
    //ListView is the plugin name 
    //"ListView" is "namespace.className" will hold functions and properties
    /**
    * @namespace ej
    * @class ejListView
    * @requires jQuery
    * @requires ej.core
    * @requires ej.unobtrusive
    * @requires ej.data
    * @requires ej.touch
    * @requires ej.checkbox
    * @requires ej.listviewbase
    * @classdesc Custom Design for Html ListView control.      
    * @example 
    * //Set listview in obtrusive way.
    * &lt;div id="lb"&gt;
    *	 &lt;ul&gt;
    *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
    * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
    *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
    *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
    *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
    *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
    * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
    *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
    *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
    *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
    * 	&lt;/ul&gt;
    * &lt;/div&gt;
    * &lt;script&gt; 
    * // Create ListView
    * $("#lb").ejListView(); 
    * &lt;/script&gt;
    */

    ej.widget("ejListView", "ej.ListView", {
        _rootCSS: "e-lv",
        //Default model values
        _prefixClass: "e-",
        defaults: {

            /**    
            * Event triggers when mouse down happens on the item.
            * @event
            * @name ejListView#mouseDown
            * @param {Object} argument Event parameters from listview.
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @param {boolean} argument.hasChild If the child element exist return true; otherwise, false.
            * @param {string} argument.item  returns the current list item.
            * @param {string} argument.text returns the current text of item.
            * @param {number} argument.index returns the current Index of the item.
            * @param {boolean} argument.isChecked If checked return true; otherwise, false.
            * @param {number} argument.checkedItems returns the list of checked items.
            * @param {string} argument.checkedItemsText returns the current checked item text.      
            * @example 
            * //mouseDown event for ListView
            * &lt;div id="lb"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(document).ready(function(){
            * $("#lb").ejListView({
            *   	mouseDown: function (args) { //handle the event 
            * }
            *	});         
            * });
            * &lt;/script&gt;
            * @memberof ejListView
            * @instance
            */
            mouseDown: null,
            /**    
            * Event triggers when mouse up happens on the item.
            * @event
            * @name ejListView#mouseUP	
            * @param {Object} argument Event parameters from listview.
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @param {boolean} argument.hasChild If the child element exist return true; otherwise, false.
            * @param {string} argument.item  returns the current list item.
            * @param {string} argument.text returns the current text of item.
            * @param {number} argument.index returns the current Index of the item.
            * @param {boolean} argument.isChecked If checked return true; otherwise, false.
            * @param {number} argument.checkedItems returns the list of checked items.
            * @param {string} argument.checkedItemsText returns the current checked item text.        
            * @example 
            * //mouseUP event for ListView
            * &lt;div id="lb" &gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(document).ready(function(){
            * $("#lb").ejListView({
            *   	mouseUP: function (args) { //handle the event 
            * }
            *	});    
            * });
            * &lt;/script&gt;
            * @memberof ejListView
            * @instance
            */
            mouseUp: null

        },

        //Datatypes of model variables
        /**
        * Specify the data types for default properties 
        * @private
        */
        dataTypes: {
            dataSource: "data",
            fieldSettings: "data",
            renderMode: "enum",
            theme: "enum",
            enablePersistence: "boolean"
        },
        observables: ["selectedItemIndex", "dataSource"],
        selectedItemIndex: ej.util.valueFunction("selectedItemIndex"),
        dataSource: ej.util.valueFunction("dataSource"),
        //Constructor function
        /**
        * Create the ListView widget
        * @private
        */
        _init: function () {
            this._preventDefaultException = { tagName: /^(INPUT|TEXTAREA|BUTTON|SELECT)$/ };
            this._storedContent = [];
            this._storedTemplate = [];
            this._touchStart = this.model.mouseDown;
            this._touchEnd = this.model.mouseUp;
            this._load();
        },
        _updateContent: function (currentItem, backButton) {
            var proxy = this;
            var $curIte = $(currentItem), childid = $curIte.attr('data-childid'),
                 id = this.element.find($("#" + childid));
            if (id.length) {
                var hdr = this.element.find('#' + childid + '_header');
                if (this.model.enableFiltering)
                    this._initializeFiltering($(id));
                var title = $curIte.attr('data-childtitle') == undefined ? currentItem.text() : $curIte.attr('data-childtitle');
                if (hdr.hasClass('e-header')) {
                    this._setHeaderVal(childid, title, backButton);
                }
                id.attr("data-hdr-title", title).attr("data-hdr-bckbtn", backButton);
                $curIte.closest('.subpage').hide();
                this._initEJCheckBox(id);
                id.show();
                $(this.element.children()[0]).removeClass("e-slideright");
                id.addClass("e-slideleft");
            }
        },

        //To render header
        /**
        * Section for Render Header for Listbox control	
        * @private
        */
        _renderHeader: function (id, showbutton, title, backtext) {
            var header = ej.buildTag("div", "", {}, { "id": id + "_header", "class": "e-header" });
            if (showbutton) {
                header.append("<span class='e-hicon e-icon e-rarrowleft-2x'></span>");
                header.append("<div class='e-btn-text'>" + (backtext ? backtext : "Back") + "</div>");
            }
            else
                header.append("<div class='e-htitle'>" + title + "</div>");
            return header;
        },
        _setHeaderVal: function (id, title, backtext) {
            this._onBackButtonDelegate = $.proxy(this._onBackButtonClick, this);
            ej.listenTouchEvent($("#" + id + "_header"), ej.endEvent(), this._onBackButtonDelegate, false, this);
            $("#" + id + "_header").find(".e-btn-text").text(this.model.headerBackButtonText ? this.model.headerBackButtonText : "Back");
            $("#" + id + "_header").find(".e-htitle").text(title);
        },
        _onBackButtonClick: function (e) {
            this.element.find(".e-slideleft").removeClass("e-slideleft");
            this.element.children(":visible").hide();
            $(this.element.children()[0]).show();
            $(this.element.children()[0]).addClass("e-slideright");
        },
        //Return the data in event triggering to the user
        /**
        * Section for to return data in event triggering to the user.
        * @private
        */
        _returnData: function () {
            var checkedItem = this._currentItem.closest('ul.e-list-hdr').find('.e-chkbox-wrap[aria-checked="true"]').closest("li");
            return {
                hasChild: this._currentItem.attr("data-childid") && this._currentItem.attr('data-childid').length > 0 ? (this.element.find('#' + this._currentItem.attr('data-childid')).length ? true : false) : false,
                item: this._currentItem,
                text: this._currentItem.text(),
                index: this._currentItem.index(),
                isChecked: this._currentItem.find("input.e-lv-check").closest('.e-chkbox-wrap').attr('aria-checked') == "true" ? true : false,
                checkedItems: checkedItem.length ? checkedItem : null,
                checkedItemsText: $(checkedItem).map(function () { return $(this).text(); }).get()
            };
        },
        _initEJCheckBox: function (ul) {
            $(ul.find('.e-lv-check')).ejCheckBox();
            ul.find('.e-lv-checkdiv').removeClass("e-lv-checkdiv")
            ul.find('.e-lv-check').parent().addClass("e-lv-checkdiv")
        },
        _triggerStartEvent: function (data) {
            this.model.mouseDown = ej.getAttrVal(this._currentItem, 'data-mousedown', this._touchStart);
            if (this.model.mouseDown)
                this._trigger("mouseDown", data);
        },
        _triggerEndEvent: function (data) {
            this.model.mouseUp = ej.getAttrVal(this._currentItem, 'data-mouseup', this._touchEnd);
            this.selectedItemIndex(this._currentItem.index());
            if (this.model.mouseUp)
                this._trigger("mouseUp", data);
        },
        _createFilterDiv: function () {
            return ej.buildTag('div.e-lv-filter', ej.buildTag('input.e-lv-input', "", {}, { 'type': 'text', 'placeholder': 'search' }));
        },
        _emptyFilterTextValue: function (element) {
            element.find('.e-lv-input').val("");
        },
        _createListDiv: function () {
            this._div = ej.buildTag("div#" + childId + "." + this._rootCSS + " subpage e-childitem e-ajaxchild", this.model.showHeader ? this._renderHeader(childId, true, this._currentItem.text()) : "");
        },
        _createCheckBox: function () {
            return ej.buildTag("input.e-lv-check", "", {}, { "type": "checkbox" });
        },
        _toggleCheckboxValue: function (lbCheck) {
            lbCheck.ejCheckBox({ checked: $(lbCheck.closest('.e-chkbox-wrap')).attr('aria-checked') == "true" ? false : true });
        },
        _setCheckboxValue: function (element, val) {
            element.ejCheckBox({ checked: val });
        },
        _convertToRelativeUrl: function (url) {
            return url;
        }
    });
    $.extend(true, ej.ListView.prototype, ej.ListViewBase.prototype);
})(jQuery, Syncfusion);;
});