/**
* @fileOverview Plugin to style the Html AutoComplete elements
* @copyright Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/

(function ($, ej, undefined) {

    ej.widget("ejNavigationDrawerBase", "ej.NavigationDrawerBase", {

        defaults: {
            //Web
            /**		
            * Sets the Direction for the control. See {@link Direction}
            * @default left
            * @member direction {object}
            * @type {enum}            
            * @example
            * // Set Navigation Drawer direction on initialization. 
            * //To set direction API value 
            * &lt;div id="home" class="navsubpage"&gt;
            * &lt;div align="center" class="content"&gt;
            * &lt;h2 class="title"&gt;
            * Home&lt;/h2&gt;
            * &lt;p&gt;
            * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
            * &lt;/p&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;style&gt;
            * .list {
            *   border-bottom: 1px solid;
            *   line-height: 50px;
            *   text-align: center;
            *   width:200px;
            *   }
            * &lt;/style&gt;
            * &lt;div &gt;
            * &lt;div class="list"&gt; Home &lt;/div&gt;
            * &lt;div class="list"&gt; Communities &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function () {
            * $("#navpane").ejNavigationDrawer("direction","left");	
            * });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set the Navigation Drawer direction, after initialization:
            * $(function () {
            * // Gets the direction API value.		
            * $("#navpane").ejNavigationDrawer("option", "direction");	
            * // Sets the direction API	
            * $("#navpane").ejNavigationDrawer ("option", "direction", "left");  
            * });
            * &lt;/script&gt;  
            * @memberof ejNavigationDrawer
            * @instance
            */
            //Mobile
            /**		
            * Sets the Direction for the control. See {@link Direction}
            * @default left
            * @member direction {object}
            * @type {enum}
            * @example 
            * //Set the direction property in unobtrusive way.
            * &lt;div id="home" class="navsubpage"&gt;
            * &lt;div align="center" class="content"&gt;
            * &lt;h2 class="title"&gt;
            * Home&lt;/h2&gt;
            * &lt;p&gt;
            * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
            * &lt;/p&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;style&gt;
            * .list {
            *   border-bottom: 1px solid;
            *   line-height: 50px;
            *   text-align: center;
            *   width:200px;
            *   }
            * &lt;/style&gt;
            * &lt;div data-role="ejmnavigationdrawer" id="navpane" data-ej-direction="left" &gt;
            * &lt;div class="list"&gt; Home &lt;/div&gt;
            * &lt;div class="list"&gt; Communities &lt;/div&gt;
            * &lt;/div&gt;
            * @example
            * // Set Navigation Drawer direction on initialization. 
            * //To set direction API value 
            * &lt;div id="home" class="navsubpage"&gt;
            * &lt;div align="center" class="content"&gt;
            * &lt;h2 class="title"&gt;
            * Home&lt;/h2&gt;
            * &lt;p&gt;
            * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
            * &lt;/p&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;style&gt;
            * .list {
            *   border-bottom: 1px solid;
            *   line-height: 50px;
            *   text-align: center;
            *   width:200px;
            *   }
            * &lt;/style&gt;
            * &lt;div &gt;
            * &lt;div class="list"&gt; Home &lt;/div&gt;
            * &lt;div class="list"&gt; Communities &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function () {
            * $("#navpane").ejmNavigationDrawer("direction","left");	
            * });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set the Navigation Drawer direction, after initialization:
            * $(function () {
            * // Gets the direction API value.		
            * $("#navpane").ejNavigationDrawer("option", "direction");	
            * // Sets the direction API	
            * $("#navpane").ejNavigationDrawer ("option", "direction", "left");  
            * });
            * &lt;/script&gt;  
            * @memberof ejmNavigationDrawer
            * @instance
            */
            direction: "left",
            //Web
            /**		
            * Specifies the targetId for navigation drawer
            * @default ""
            * @member targetid {object}
            * @type {string}           
            * @example
            * // Set Navigation Drawer direction on initialization. 
            * //To set direction API value 
            * &lt;div id="home" class="navsubpage"&gt;
            * &lt;div align="center" class="content"&gt;
            * &lt;h2 class="title"&gt;
            * Home&lt;/h2&gt;
            * &lt;p&gt;
            * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
            * &lt;/p&gt;
            * &lt;/div&gt;            
            * &lt;input id="target" type="button" text="target"/&gt;
            * &lt;/div&gt;
            * &lt;style&gt;
            * .list {
            *   border-bottom: 1px solid;
            *   line-height: 50px;
            *   text-align: center;
            *   width:200px;
            *   }
            * &lt;/style&gt;
            * &lt;div &gt;
            * &lt;div class="list"&gt; Home &lt;/div&gt;
            * &lt;div class="list"&gt; Communities &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function () {
            * $("#navpane").ejNavigationDrawer("targetId","target");	
            * });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set the Navigation Drawer targetId, after initialization:
            * $(function () {
            * // Gets the targetId API value.		
            * $("#navpane").ejNavigationDrawer("option", "targetId");	
            * // Sets the targetId API	
            * $("#navpane").ejNavigationDrawer ("option", "targetId", "left");  
            * });
            * &lt;/script&gt;  
            * @memberof ejNavigationDrawer
            * @instance
            */
            //Mobile
            /**		
            * Specifies the targetId for navigation drawer
            * @default ""
            * @member targetid {object}
            * @type {string}
            * @example 
            * //Set the direction property in unobtrusive way.
            * &lt;div id="home" class="navsubpage"&gt;
            * &lt;div align="center" class="content"&gt;
            * &lt;h2 class="title"&gt;
            * Home&lt;/h2&gt;
            * &lt;p&gt;
            * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
            * &lt;/p&gt;
            * &lt;/div&gt;
            * &lt; input id="target" data-role="button" type="button" /&gt;
            * &lt;/div&gt;
            * &lt;style&gt;
            * .list {
            *   border-bottom: 1px solid;
            *   line-height: 50px;
            *   text-align: center;
            *   width:200px;
            *   }
            * &lt;/style&gt;
            * &lt;div data-role="ejmnavigationdrawer" id="navpane" data-ej-targetid="target" &gt;
            * &lt;div class="list"&gt; Home &lt;/div&gt;
            * &lt;div class="list"&gt; Communities &lt;/div&gt;
            * &lt;/div&gt;
            * @example
            * // Set Navigation Drawer direction on initialization. 
            * //To set direction API value 
            * &lt;div id="home" class="navsubpage"&gt;
            * &lt;div align="center" class="content"&gt;
            * &lt;h2 class="title"&gt;
            * Home&lt;/h2&gt;
            * &lt;p&gt;
            * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
            * &lt;/p&gt;
            * &lt;/div&gt;
            * &lt; input id="target" data-role="button" type="button" /&gt;
            * &lt;/div&gt;
            * &lt;style&gt;
            * .list {
            *   border-bottom: 1px solid;
            *   line-height: 50px;
            *   text-align: center;
            *   width:200px;
            *   }
            * &lt;/style&gt;
            * &lt;div &gt;
            * &lt;div class="list"&gt; Home &lt;/div&gt;
            * &lt;div class="list"&gt; Communities &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function () {
            * $("#navpane").ejmNavigationDrawer("targetId","left");	
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the Navigation Drawer targetId, after initialization:
            * &lt;script&gt;
            * // Gets the TargetId API value.		
            *  $("#navpane").ejmNavigationDrawer ("option", "targetId");		
            * // Sets the TargetId API
            * $("#navpane").ejmNavigationDrawer ("option", "targetId", "sample");   
            * &lt;/script&gt;
            * @memberof ejmNavigationDrawer
            * @instance
            */
            targetId: null,
            //Web
            /**		
            * Specifies position whether it is in fixed or relative to the page. See {@link Position}
            * @default normal
            * @member position {object}
            * @type {enum}            
            * @example
            * // Set Navigation Drawer position on initialization. 
            * //To set position API value 
            * &lt;div id="home" class="navsubpage"&gt;
            * &lt;div align="center" class="content"&gt;
            * &lt;h2 class="title"&gt;
            * Home&lt;/h2&gt;
            * &lt;p&gt;
            * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
            * &lt;/p&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;style&gt;
            * .list {
            *   border-bottom: 1px solid;
            *   line-height: 50px;
            *   text-align: center;
            *   width:200px;
            *   }
            * &lt;/style&gt;
            * &lt;div &gt;
            * &lt;div class="list"&gt; Home &lt;/div&gt;
            * &lt;div class="list"&gt; Communities &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function () {
            * $("#navpane").ejNavigationDrawer("position","normal");	
            * });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set the Navigation Drawer position, after initialization:
            * $(function () {
            * // Gets the position API value.		
            * $("#navpane").ejNavigationDrawer("option", "position");	
            * // Sets the position API	
            * $("#navpane").ejNavigationDrawer ("option", "position", "normal");  
            * });
            * &lt;/script&gt;  
            * @memberof ejNavigationDrawer
            * @instance
            */
            //Mobile
            /**		
            * Specifies position whether it is in fixed or relative to the page. See {@link Position}
            * @default normal
            * @member position {object}
            * @type {enum}
            * @example 
            * //Set the position property in unobtrusive way.
            * &lt;div id="home" class="navsubpage"&gt;
            * &lt;div align="center" class="content"&gt;
            * &lt;h2 class="title"&gt;
            * Home&lt;/h2&gt;
            * &lt;p&gt;
            * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
            * &lt;/p&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;style&gt;
            * .list {
            *   border-bottom: 1px solid;
            *   line-height: 50px;
            *   text-align: center;
            *   width:200px;
            *   }
            * &lt;/style&gt;
            * &lt;div data-role="ejmnavigationdrawer" id="navpane" data-ej-position="normal" &gt;
            * &lt;div class="list"&gt; Home &lt;/div&gt;
            * &lt;div class="list"&gt; Communities &lt;/div&gt;
            * &lt;/div&gt;
            * @example
            * // Set Navigation Drawer position on initialization. 
            * //To set position API value 
            * &lt;div id="home" class="navsubpage"&gt;
            * &lt;div align="center" class="content"&gt;
            * &lt;h2 class="title"&gt;
            * Home&lt;/h2&gt;
            * &lt;p&gt;
            * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
            * &lt;/p&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;style&gt;
            * .list {
            *   border-bottom: 1px solid;
            *   line-height: 50px;
            *   text-align: center;
            *   width:200px;
            *   }
            * &lt;/style&gt;
            * &lt;div &gt;
            * &lt;div class="list"&gt; Home &lt;/div&gt;
            * &lt;div class="list"&gt; Communities &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function () {
            * $("#navpane").ejmNavigationDrawer("position","normal");	
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the Navigation Drawer position, after initialization:
            * &lt;script&gt;
            * // Gets the position API value.		
            *  $("#navpane").ejmNavigationDrawer ("option", "position");		
            * // Sets the position API
            * $("#navpane").ejmNavigationDrawer ("option", "position", "normal");   
            * &lt;/script&gt;
            * @memberof ejmNavigationDrawer
            * @instance
            */
            position: "normal",
            //Web
            /**		
            * Sets the listview to be enabled or not
            * @default false
            * @member enablelistview {object}
            * @type {boolean}           
            * @example
            * // Set Navigation Drawer listview on initialization. 
            * //To set listview API value 
            * &lt;div id="home" class="navsubpage"&gt;
            * &lt;div align="center" class="content"&gt;
            * &lt;h2 class="title"&gt;
            * Home&lt;/h2&gt;
            * &lt;p&gt;
            * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
            * &lt;/p&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;style&gt;
            * .list {
            *   border-bottom: 1px solid;
            *   line-height: 50px;
            *   text-align: center;
            *   width:200px;
            *   }
            * &lt;/style&gt;
            * &lt;div &gt;
            * &lt;div class="list"&gt; Home &lt;/div&gt;
            * &lt;div class="list"&gt; Communities &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function () {
            * $("#navpane").ejNavigationDrawer("enableListView","false");	
            * });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set the Navigation Drawer listview, after initialization:
            * $(function () {
            * // Gets the listview API value.		
            * $("#navpane").ejNavigationDrawer("option", "enableListView");	
            * // Sets the listview API	
            * $("#navpane").ejNavigationDrawer ("option", "enableListView", "false");  
            * });
            * &lt;/script&gt;  
            * @memberof ejNavigationDrawer
            * @instance
            */
            //Mobile
            /**		
            * Sets the listview to be enabled or not
            * @default false
            * @member enablelistview {object}
            * @type {boolean}
            * @example 
            * //Set the listview property in unobtrusive way.
            * &lt;div id="home" class="navsubpage"&gt;
            * &lt;div align="center" class="content"&gt;
            * &lt;h2 class="title"&gt;
            * Home&lt;/h2&gt;
            * &lt;p&gt;
            * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
            * &lt;/p&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;style&gt;
            * .list {
            *   border-bottom: 1px solid;
            *   line-height: 50px;
            *   text-align: center;
            *   width:200px;
            *   }
            * &lt;/style&gt;
            * &lt;div data-role="ejmnavigationdrawer" id="navpane" data-ej-enablelistview="false" &gt;
            * &lt;div class="list"&gt; Home &lt;/div&gt;
            * &lt;div class="list"&gt; Communities &lt;/div&gt;
            * &lt;/div&gt;
            * @example
            * // Set Navigation Drawer listview on initialization. 
            * //To set listview API value 
            * &lt;div id="home" class="navsubpage"&gt;
            * &lt;div align="center" class="content"&gt;
            * &lt;h2 class="title"&gt;
            * Home&lt;/h2&gt;
            * &lt;p&gt;
            * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
            * &lt;/p&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;style&gt;
            * .list {
            *   border-bottom: 1px solid;
            *   line-height: 50px;
            *   text-align: center;
            *   width:200px;
            *   }
            * &lt;/style&gt;
            * &lt;div &gt;
            * &lt;div class="list"&gt; Home &lt;/div&gt;
            * &lt;div class="list"&gt; Communities &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function () {
            * $("#navpane").ejmNavigationDrawer("enableListView","false");	
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the Navigation Drawer listview, after initialization:
            * &lt;script&gt;
            * // Gets the listview API value.		
            *  $("#navpane").ejmNavigationDrawer ("option", "enableListView");		
            * // Sets the listview API
            * $("#navpane").ejmNavigationDrawer ("option", "enableListView", false);   
            * &lt;/script&gt;
            * @memberof ejmNavigationDrawer
            * @instance
            */
            enableListView: false,
            //Web
            /**		
            * Sets all the properties of listview to render in navigation drawer
            * @member listviewsettings {object}
            * @example
            * // Set Navigation Drawer listview on initialization. 
            * //To set listview API value 
            * &lt;div id="home" class="navsubpage"&gt;
            * &lt;div align="center" class="content"&gt;
            * &lt;h2 class="title"&gt;
            * Home&lt;/h2&gt;
            * &lt;p&gt;
            * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
            * &lt;/p&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;style&gt;
            * .list {
            *   border-bottom: 1px solid;
            *   line-height: 50px;
            *   text-align: center;
            *   width:200px;
            *   }
            * &lt;/style&gt;
            * &lt;div &gt;
            * &lt;div class="list"&gt; Home &lt;/div&gt;
            * &lt;div class="list"&gt; Communities &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function () {
            * $("#navpane").ejNavigationDrawer({model.listViewSettings{width:200});	
            * });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set the Navigation Drawer listViewSettings, after initialization:
            * $(function () {
            * // Gets the listViewSettings API value.		
            * $("#navpane").ejNavigationDrawer("option", "listViewSettings.width");	
            * // Sets the listViewSettings API	
            * $("#navpane").ejNavigationDrawer ("option", "listViewSettings.width", "200");  
            * });
            * &lt;/script&gt;  
            * @memberof ejNavigationDrawer
            * @instance
            */
            //Mobile
            /**		
            * Sets all the properties of listview to render in navigation drawer
            * @member listviewsettings {object}
            * @example 
            * //Set the listView Settings property in unobtrusive way.
            * &lt;div id="home" class="navsubpage"&gt;
            * &lt;div align="center" class="content"&gt;
            * &lt;h2 class="title"&gt;
            * Home&lt;/h2&gt;
            * &lt;p&gt;
            * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
            * &lt;/p&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;style&gt;
            * .list {
            *   border-bottom: 1px solid;
            *   line-height: 50px;
            *   text-align: center;
            *   width:200px;
            *   }
            * &lt;/style&gt;
            * &lt;div data-role="ejmnavigationdrawer" id="navpane" data-ej-listviewsettings-width="200" &gt;
            * &lt;div class="list"&gt; Home &lt;/div&gt;
            * &lt;div class="list"&gt; Communities &lt;/div&gt;
            * &lt;/div&gt;
            * @example
            * // Set Navigation Drawer listview settings on initialization. 
            * //To set listview settings API value 
            * &lt;div id="home" class="navsubpage"&gt;
            * &lt;div align="center" class="content"&gt;
            * &lt;h2 class="title"&gt;
            * Home&lt;/h2&gt;
            * &lt;p&gt;
            * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
            * &lt;/p&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;style&gt;
            * .list {
            *   border-bottom: 1px solid;
            *   line-height: 50px;
            *   text-align: center;
            *   width:200px;
            *   }
            * &lt;/style&gt;
            * &lt;div &gt;
            * &lt;div class="list"&gt; Home &lt;/div&gt;
            * &lt;div class="list"&gt; Communities &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function () {
            * $("#navpane").ejmNavigationDrawer({model.listViewSettings{width:200});	
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the Navigation Drawer listViewSettings, after initialization:
            * &lt;script&gt;
            * // Gets the listViewSettings API value.		
            *  $("#navpane").ejmNavigationDrawer ("option", "listViewSettings.width");	
            * // Sets the listViewSettings API
            * $("#navpane").ejmNavigationDrawer ("option", "listViewSettings.width", "200");   
            * &lt;/script&gt;
            * @memberof ejmNavigationDrawer
            * @instance
            */
            listViewSettings: {},
            //Web
            /**		
            * Sets the rendering type of the control.  See {@link Type}
            * @default overlay            
            * @member type {object}
            * @type {enum}
            * @example
            * // Set Navigation Drawer type on initialization. 
            * //To set type API value 
            * &lt;div id="home" class="navsubpage"&gt;
            * &lt;div align="center" class="content"&gt;
            * &lt;h2 class="title"&gt;
            * Home&lt;/h2&gt;
            * &lt;p&gt;
            * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
            * &lt;/p&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;style&gt;
            * .list {
            *   border-bottom: 1px solid;
            *   line-height: 50px;
            *   text-align: center;
            *   width:200px;
            *   }
            * &lt;/style&gt;
            * &lt;div &gt;
            * &lt;div class="list"&gt; Home &lt;/div&gt;
            * &lt;div class="list"&gt; Communities &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function () {
            * $("#navpane").ejNavigationDrawer("type","overlay");	
            * });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set the Navigation Drawer type, after initialization:
            * $(function () {
            * // Gets the type API value.		
            * $("#navpane").ejNavigationDrawer("option", "type");	
            * // Sets the type API	
            * $("#navpane").ejNavigationDrawer ("option", "type", "overlay");  
            * });
            * &lt;/script&gt;  
            * @memberof ejNavigationDrawer
            * @instance
            */
            //Mobile
            /**		
            * Sets the rendering type of the control.  See {@link Type}
            * @default overlay      
            * @member type {object}
            * @type {enum}
            * @example 
            * //Set the type property in unobtrusive way.
            * &lt;div id="home" class="navsubpage"&gt;
            * &lt;div align="center" class="content"&gt;
            * &lt;h2 class="title"&gt;
            * Home&lt;/h2&gt;
            * &lt;p&gt;
            * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
            * &lt;/p&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;style&gt;
            * .list {
            *   border-bottom: 1px solid;
            *   line-height: 50px;
            *   text-align: center;
            *   width:200px;
            *   }
            * &lt;/style&gt;
            * &lt;div data-role="ejmnavigationdrawer" id="navpane" data-ej-type="overlay" &gt;
            * &lt;div class="list"&gt; Home &lt;/div&gt;
            * &lt;div class="list"&gt; Communities &lt;/div&gt;
            * &lt;/div&gt;
            * @example
            * // Set Navigation Drawer type on initialization. 
            * //To set type API value 
            * &lt;div id="home" class="navsubpage"&gt;
            * &lt;div align="center" class="content"&gt;
            * &lt;h2 class="title"&gt;
            * Home&lt;/h2&gt;
            * &lt;p&gt;
            * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
            * &lt;/p&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;style&gt;
            * .list {
            *   border-bottom: 1px solid;
            *   line-height: 50px;
            *   text-align: center;
            *   width:200px;
            *   }
            * &lt;/style&gt;
            * &lt;div &gt;
            * &lt;div class="list"&gt; Home &lt;/div&gt;
            * &lt;div class="list"&gt; Communities &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function () {
            * $("#navpane").ejmNavigationDrawer("type","overlay");	
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the Navigation Drawer type, after initialization:
            * &lt;script&gt;
            * // Gets the type API value.		
            *  $("#navpane").ejmNavigationDrawer ("option", "type");		
            * // Sets the type API
            * $("#navpane").ejmNavigationDrawer ("option", "type", "overlay");   
            * &lt;/script&gt;
            * @memberof ejmNavigationDrawer
            * @instance
            */
            type: "overlay",
            /**		
            * Specifies the width of the control
            * @default auto      
            * @member width {object}
            * @type {int}            
            * @example
            * // Set Navigation Drawer width on initialization. 
            * //To set width API value 
            * &lt;div id="home" class="navsubpage"&gt;
            * &lt;div align="center" class="content"&gt;
            * &lt;h2 class="title"&gt;
            * Home&lt;/h2&gt;
            * &lt;p&gt;
            * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
            * &lt;/p&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;style&gt;
            * .list {
            *   border-bottom: 1px solid;
            *   line-height: 50px;
            *   text-align: center;
            *   width:200px;
            *   }
            * &lt;/style&gt;
            * &lt;div &gt;
            * &lt;div class="list"&gt; Home &lt;/div&gt;
            * &lt;div class="list"&gt; Communities &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function () {
            * $("#navpane").ejNavigationDrawer("width","200");	
            * });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set the Navigation Drawer width, after initialization:
            * $(function () {
            * // Gets the width API value.		
            * $("#navpane").ejNavigationDrawer("option", "width");	
            * // Sets the width API	
            * $("#navpane").ejNavigationDrawer ("option", "width", "overlay");  
            * });
            * &lt;/script&gt;  
            * @memberof ejNavigationDrawer
            * @instance
            */
            //Mobile
            /**		
            * Specifies the width of the control
            * @default auto 
            * @member width {object}
            * @type {int}
            * @example 
            * //Set the width property in unobtrusive way.
            * &lt;div id="home" class="navsubpage"&gt;
            * &lt;div align="center" class="content"&gt;
            * &lt;h2 class="title"&gt;
            * Home&lt;/h2&gt;
            * &lt;p&gt;
            * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
            * &lt;/p&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;style&gt;
            * .list {
            *   border-bottom: 1px solid;
            *   line-height: 50px;
            *   text-align: center;
            *   width:200px;
            *   }
            * &lt;/style&gt;
            * &lt;div data-role="ejmnavigationdrawer" id="navpane" data-ej-width="200" &gt;
            * &lt;div class="list"&gt; Home &lt;/div&gt;
            * &lt;div class="list"&gt; Communities &lt;/div&gt;
            * &lt;/div&gt;
            * @example
            * // Set Navigation Drawer width on initialization. 
            * //To set width API value 
            * &lt;div id="home" class="navsubpage"&gt;
            * &lt;div align="center" class="content"&gt;
            * &lt;h2 class="title"&gt;
            * Home&lt;/h2&gt;
            * &lt;p&gt;
            * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
            * &lt;/p&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;style&gt;
            * .list {
            *   border-bottom: 1px solid;
            *   line-height: 50px;
            *   text-align: center;
            *   width:200px;
            *   }
            * &lt;/style&gt;
            * &lt;div &gt;
            * &lt;div class="list"&gt; Home &lt;/div&gt;
            * &lt;div class="list"&gt; Communities &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function () {
            * $("#navpane").ejmNavigationDrawer("width","200");	
            * });
            * @example 
            * //Get or set the Navigation Drawer width, after initialization:
            * &lt;script&gt;
            * // Gets the type API value.		
            *  $("#navpane").ejmNavigationDrawer ("option", "width");		
            * // Sets the type API
            * $("#navpane").ejmNavigationDrawer ("option", "width", "auto");   
            * &lt;/script&gt;
            * @memberof ejmNavigationDrawer
            * @instance
            */
            width: "auto",
            //Web
            /**    
            * Event triggers when the Swipe happens.
            * @event
            * @name ejNavigationDrawer#swipe 	
            * @param {Object} argument Event parameters from Navigation Drawer     
            * @param {boolean} argument.cancel if the event should be canceled; otherwise, false.
            * @param {Object} argument.model returns the Navigation Drawer model
            * @param {string} argument.type returns the name of the event
            * @param {object} argument.item returns the item of element
            * @param {String} argument.itemName returns the name of item
            * @example 
            * //Swipe event for Navigation pane
            * &lt;div id="home" class="navsubpage"&gt;
            * &lt;div align="center" class="content"&gt;
            * &lt;h2 class="title"&gt;
            * Home&lt;/h2&gt;
            * &lt;p&gt;
            * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
            * &lt;/p&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;style&gt;
            * .list {
            *   border-bottom: 1px solid;
            *   line-height: 50px;
            *   text-align: center;
            *   width:200px;
            *   }
            * &lt;/style&gt;
            * &lt;div id="navpane" &gt;
            * &lt;div class="list"&gt; Home &lt;/div&gt;
            * &lt;div class="list"&gt; Communities &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $("#navpane").ejNavigationDrawer({
            *   swipe: function (args) { //handle the event
            * }
            * });   
            * &lt;/script&gt;
            * @memberof ejNavigationDrawer
            * @instance
            */
            //Mobile
            /**    
            * Event triggers when the Swipe happens.
            * @event
            * @name ejmNavigationDrawer#swipe 	
            * @param {Object} argument Event parameters from Navigation Drawer     
            * @param {boolean} argument.cancel if the event should be canceled; otherwise, false.
            * @param {Object} argument.model returns the Navigation Drawer model
            * @param {string} argument.type returns the name of the event
            * @param {object} argument.item returns the item of element
            * @param {String} argument.itemName returns the name of item
            * @example 
            * &lt;div id="home" class="navsubpage"&gt;
            * &lt;div align="center" class="content"&gt;
            * &lt;h2 class="title"&gt;
            * Home&lt;/h2&gt;
            * &lt;p&gt;
            * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
            * &lt;/p&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;style&gt;
            * .list {
            *   border-bottom: 1px solid;
            *   line-height: 50px;
            *   text-align: center;
            *   width:200px;
            *   }
            * &lt;/style&gt;
            * &lt;div data-role="ejmnavigationdrawer" id="navpane" data-ej-swipe="onSwipe" &gt;
            * &lt;div class="list"&gt; Home &lt;/div&gt;
            * &lt;div class="list"&gt; Communities &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script &gt;
            * function onSwipe(args)
            * { //handle the event
            * }
            * &lt;/script &gt;
            * @example 
            * //Swipe event for Navigation pane
            * &lt;div id="home" class="navsubpage"&gt;
            * &lt;div align="center" class="content"&gt;
            * &lt;h2 class="title"&gt;
            * Home&lt;/h2&gt;
            * &lt;p&gt;
            * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
            * &lt;/p&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;style&gt;
            * .list {
            *   border-bottom: 1px solid;
            *   line-height: 50px;
            *   text-align: center;
            *   width:200px;
            *   }
            * &lt;/style&gt;
            * &lt;div id="navpane" &gt;
            * &lt;div class="list"&gt; Home &lt;/div&gt;
            * &lt;div class="list"&gt; Communities &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $("#navpane").ejmNavigationDrawer({
            *   swipe: function (args) { //handle the event
            * }
            * });   
            * &lt;/script&gt;
            * @memberof ejmNavigationDrawer
            * @instance
            */
            swipe: null,
            //Web
            /**    
            * Event triggers when the control open.
            * @event
            * @name ejNavigationDrawer#open 	
            * @param {Object} argument Event parameters from Navigation Drawer     
            * @param {boolean} argument.cancel if the event should be canceled; otherwise, false.
            * @param {Object} argument.model returns the Navigation Drawer model
            * @param {string} argument.type returns the name of the event
            * @param {object} argument.item returns the item of element
            * @param {String} argument.itemName returns the name of item
            * @example 
            * //Open event for Navigation pane
            * &lt;div id="home" class="navsubpage"&gt;
            * &lt;div align="center" class="content"&gt;
            * &lt;h2 class="title"&gt;
            * Home&lt;/h2&gt;
            * &lt;p&gt;
            * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
            * &lt;/p&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;style&gt;
            * .list {
            *   border-bottom: 1px solid;
            *   line-height: 50px;
            *   text-align: center;
            *   width:200px;
            *   }
            * &lt;/style&gt;
            * &lt;div id="navpane" &gt;
            * &lt;div class="list"&gt; Home &lt;/div&gt;
            * &lt;div class="list"&gt; Communities &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $("#navpane").ejNavigationDrawer({
            *   open: function (args) { //handle the event
            * }
            * });   
            * $("#navpane").ejNavigationDrawer("open");   
            * &lt;/script&gt;
            * @memberof ejNavigationDrawer
            * @instance
            */
            //Mobile
            /**    
            * Event triggers when the control open.
            * @event
            * @name ejmNavigationDrawer#open 	
            * @param {Object} argument Event parameters from Navigation Drawer     
            * @param {boolean} argument.cancel if the event should be canceled; otherwise, false.
            * @param {Object} argument.model returns the Navigation Drawer model
            * @param {string} argument.type returns the name of the event
            * @param {object} argument.item returns the item of element
            * @param {String} argument.itemName returns the name of item
            * @example 
            * &lt;div id="home" class="navsubpage"&gt;
            * &lt;div align="center" class="content"&gt;
            * &lt;h2 class="title"&gt;
            * Home&lt;/h2&gt;
            * &lt;p&gt;
            * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
            * &lt;/p&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;style&gt;
            * .list {
            *   border-bottom: 1px solid;
            *   line-height: 50px;
            *   text-align: center;
            *   width:200px;
            *   }
            * &lt;/style&gt;
            * &lt;div data-role="ejmnavigationdrawer" id="navpane" data-ej-open="onOpen" &gt;
            * &lt;div class="list"&gt; Home &lt;/div&gt;
            * &lt;div class="list"&gt; Communities &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script &gt;
            * function onOpen(args)
            * { //handle the event
            * }
            * &lt;/script &gt;
            * @example 
            * //Open event for Navigation pane
            * &lt;div id="home" class="navsubpage"&gt;
            * &lt;div align="center" class="content"&gt;
            * &lt;h2 class="title"&gt;
            * Home&lt;/h2&gt;
            * &lt;p&gt;
            * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
            * &lt;/p&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;style&gt;
            * .list {
            *   border-bottom: 1px solid;
            *   line-height: 50px;
            *   text-align: center;
            *   width:200px;
            *   }
            * &lt;/style&gt;
            * &lt;div id="navpane" &gt;
            * &lt;div class="list"&gt; Home &lt;/div&gt;
            * &lt;div class="list"&gt; Communities &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $("#navpane").ejNavigationDrawer({
            *   open: function (args) { //handle the event
            * }
            * });   
            * $("#navpane").ejNavigationDrawer("open");
            * &lt;/script&gt;
            * @memberof ejmNavigationDrawer
            * @instance
            */
            open: null,
            //Web
            /**    
            * Event triggers before the control gets closed.
            * @event
            * @name ejNavigationDrawer#beforeclose 	
            * @param {Object} argument Event parameters from Navigation Drawer     
            * @param {boolean} argument.cancel if the event should be canceled; otherwise, false.
            * @param {Object} argument.model returns the Navigation Drawer model
            * @param {string} argument.type returns the name of the event
            * @param {object} argument.item returns the item of element
            * @param {String} argument.itemName returns the name of item
            * @example 
            * //BeforeClose event for Navigation pane
            * &lt;div id="home" class="navsubpage"&gt;
            * &lt;div align="center" class="content"&gt;
            * &lt;h2 class="title"&gt;
            * Home&lt;/h2&gt;
            * &lt;p&gt;
            * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
            * &lt;/p&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;style&gt;
            * .list {
            *   border-bottom: 1px solid;
            *   line-height: 50px;
            *   text-align: center;
            *   width:200px;
            *   }
            * &lt;/style&gt;
            * &lt;div id="navpane" &gt;
            * &lt;div class="list"&gt; Home &lt;/div&gt;
            * &lt;div class="list"&gt; Communities &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $("#navpane").ejNavigationDrawer({
            *   beforeClose: function (args) { //handle the event
            * }
            * });   
            * $("#navpane").ejNavigationDrawer("close");
            * &lt;/script&gt;
            * @memberof ejNavigationDrawer
            * @instance
            */
            //Mobile
            /**    
            * Event triggers before the control gets closed.
            * @event
            * @name ejmNavigationDrawer#beforeclose 	
            * @param {Object} argument Event parameters from Navigation Drawer     
            * @param {boolean} argument.cancel if the event should be canceled; otherwise, false.
            * @param {Object} argument.model returns the Navigation Drawer model
            * @param {string} argument.type returns the name of the event
            * @param {object} argument.item returns the item of element
            * @param {String} argument.itemName returns the name of item
            * @example  
            * &lt;div id="home" class="navsubpage"&gt;
            * &lt;div align="center" class="content"&gt;
            * &lt;h2 class="title"&gt;
            * Home&lt;/h2&gt;
            * &lt;p&gt;
            * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
            * &lt;/p&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;style&gt;
            * .list {
            *   border-bottom: 1px solid;
            *   line-height: 50px;
            *   text-align: center;
            *   width:200px;
            *   }
            * &lt;/style&gt;
            * &lt;div data-role="ejmnavigationdrawer" id="navpane" data-ej-beforeclose="onBeforeClose" &gt;
            * &lt;div class="list"&gt; Home &lt;/div&gt;
            * &lt;div class="list"&gt; Communities &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script &gt;
            * function onBeforeClose(args)
            * { //handle the event
            * }
            * &lt;/script &gt;
            * @example 
            * //BeforeClose event for Navigation pane
            * &lt;div id="home" class="navsubpage"&gt;
            * &lt;div align="center" class="content"&gt;
            * &lt;h2 class="title"&gt;
            * Home&lt;/h2&gt;
            * &lt;p&gt;
            * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
            * &lt;/p&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;style&gt;
            * .list {
            *   border-bottom: 1px solid;
            *   line-height: 50px;
            *   text-align: center;
            *   width:200px;
            *   }
            * &lt;/style&gt;
            * &lt;div id="navpane" &gt;
            * &lt;div class="list"&gt; Home &lt;/div&gt;
            * &lt;div class="list"&gt; Communities &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $("#navpane").ejmNavigationDrawer({
            *   beforeClose: function (args) { //handle the event
            * }
            * });   
            * $("#navpane").ejNavigationDrawer();   
            * &lt;/script&gt;
            * @memberof ejmNavigationDrawer
            * @instance
            */
            beforeClose: null
        },
        //datatype of model variables
        dataTypes: {
            direction: "enum",
            type: "enum"
        },
        //renders the control
        _renderControl: function () {
            this._elementOverlay = ej.buildTag("div#" + this._id + "_Overlay", {}, {}, { "class": this._rootCSS + " " + this._prefixClass + "nb-layout " + this._prefixClass + "nb-overlay" });
            this._elementShadow = ej.buildTag("div#" + this._id + "_shadow", {}, {}, { "class": this._rootCSS + " " + this._prefixClass + "nb-shadow " + "" + this._prefixClass + "nb-type-" + (this.model.type == "slide" ? "slide" : "overlay") });
            this.element.addClass(this._prefixClass + "user-select");
            this._nbHome.append(this._elementOverlay);
            this._elementOverlay.hide();
            this.element.hide();
            this.element.addClass(this._prefixClass + 'nb-layout ' + (this.model.direction.toLowerCase() == "left" ? this._prefixClass + 'nb-left' : this._prefixClass + 'nb-right'));
            this.element.addClass(this._prefixClass + 'nb-type-' + (this.model.type == "slide" ? "slide" : "overlay"));
            this.element.prepend(this._elementShadow);
            this._setWidth();
            this._setLayout();
        },
        /**
        * To configure the transform property for Navigation drawer control
        * @private
        */
        _transform: function (dist, time, element) {
            var translate = "-" + this._browser + "-transform",
                translateVal = "translate3d(" + dist + "px,0px,0px) scale(1)";
            var trans = "-" + this._browser + "-transition-property",
            transVal = "transform",
            transDur = "-" + this._browser + "-transition-duration",
            transDurVal = time + "ms";
            if (element) {
                this.element.addClass("" + this._prefixClass + "nb-animate");
                this.element.css(translate, translateVal).css(trans, transVal).css(transDur, transDurVal);
            }
            else {
                this._nbHome.addClass(this._rootCSS + " " + this._prefixClass + "nb-animate");
                this._nbHome.css(translate, translateVal).css(trans, transVal).css(transDur, transDurVal)
            }
        },
        /**
        * To configure the show property for Navigation drawer control
        * @private
        */
        _show: function () {            
            this.element.show();
            ej.listenTouchEvent((this._isTransitionElement() ? this.element : this._nbHome), ej.transitionEndEvent(), this._transitionOpenHandler, false, this);            
            this.element.addClass("" + this._prefixClass + "nb-opened");
            this._elementOverlay.css("z-index", ej.getMaxZindex() + 1);
            this.element.css("z-index", ej.getMaxZindex() + 2);
            if (!(ej.browserInfo().name == "msie" && ej.browserInfo().version <= 9)) {
                this.model.direction == "left" ? this._transform($(this.element).width(), 400, this._isTransitionElement()) : this._transform(-($(this.element).width()), 400, this._isTransitionElement());
            }
            else {
                $(this.element).show().animate({ "left": this.model.direction == "left" ? "0px" : -($(this.element).width()) }, 400);
            }
            this._data = { element: this.element };
            this.model.enableListView ? $.extend(this._data, { listview: this._lb }) : undefined;
            this._trigger("open", this._data);
        },
        /**
        * To configure the hide property for Navigation drawer control
        * @private
        */
        _hide: function () {
            this._elementOverlay.hide();
            ej.listenTouchEvent((this._isTransitionElement() ? this.element : this._nbHome), ej.transitionEndEvent(), this._transitionCloseHandler, false, this);
            this.element.removeClass("" + this._prefixClass + "nb-opened");
            if (!(ej.browserInfo().name == "msie" && ej.browserInfo().version <= 9))
                this._transform(0, 400, this._isTransitionElement());
            else
                $(this.element).animate({ "left": this.model.direction == "left" ? -($(this.element).width()) : "0px" }, 400).hide();
        },


        _isOpened: function () {
            return this.element.hasClass("" + this._prefixClass + "nb-opened");
        },
        _clearAppviewElement: function () {
            var translate = "-" + this._browser + "-transform";
            var trans = "-" + this._browser + "-transition-property";
            var transDur = "-" + this._browser + "-transition-duration";
            this._nbHome.css(translate, "");
            this._nbHome.css(transDur, "");
            this._nbHome.css(trans, "");
            this._nbHome.removeClass(this._rootCSS + " " + this._prefixClass + "nb-animate");
        },
        _isOtherOpened: function () {
            return $("." + this._prefixClass + "nb-opened").length;
        },

        _isTransitionElement: function () {
            return this.model.type == "overlay" ? true : false;
        },
        /**
        * To configure the width property for Navigation drawer control
        * @private
        */
        _setWidth: function () {
            $(this._nbHome).width() < 500 ? this.element.css("maxwidth", "80%") : this.element.css("maxwidth", "40%");
            this.element.height("100%");
        },

        _setLayout: function () {
            this.element.show();
            if (this.model.direction.toLowerCase() == "left") {
                this.element.offset({ left: this._nbHome.offset().left != 0 ? -((this.element.width() - this._nbHome.offset().left)) : -(this.element.width()) });
            }
            else {
                this.element.offset({ left: this._nbHome.offset().left != 0 ? ($(this._nbHome).width() + this._nbHome.offset().left) : $(this._nbHome).width() });
            }
            this.element.hide();
        },
        /**
        * To configure the destroy property for Navigation drawer control
        * @private
        */
        _destroy: function () {
            this._wireEvents(true);
            this._elementOverlay.remove();
            this._elementShadow.remove();
            if (this._elementWrapper) this.element.unwrap();
            this.element.removeAttr("class style");
            this.element.offset({ left: 0 });
            this._destroyEJMPlugin();
        },
        /**
        * To configure the refresh property for Navigation drawer control
        * @private
        */
        _refresh: function () {
            this._destroy();
            this._init();
        },

        /**
        * Creates Delegates for the functions 
        * @private
        */
        _createDelegate: function () {
            //Swipe Events Handler
            this._swipeStartHandler = $.proxy(this._swipeStart, this);
            this._swipeEndHandler = $.proxy(this._swipeEnd, this);
            this._swipeMoveHandler = $.proxy(this._swipeMove, this);

            //Touch Event Handler
            this._touchMoveHandler = $.proxy(this._touchMove, this);
            this._touchEndHandler = $.proxy(this._touchEnd, this);

            //Transition Event
            this._transitionOpenHandler = $.proxy(this._transitionOpenEnd, this);
            this._transitionCloseHandler = $.proxy(this._transitionCloseEnd, this);

            //Target Touch Event Handler
            this._overlayTapHandler = $.proxy(this._elementOverlayTap, this);

            //TargetButton Tap
            this._targetButtonTapHandler = $.proxy(this._targetButtonTap, this);

            // Size Event Handler
            this._onOrientationChangeHandler = $.proxy(this._onOrientationChangeEvent, this);
            this._onResizeEventHandler = $.proxy(this._onResizeEvent, this);
        },

        _wireEvents: function (remove) {
            //Event Binding
            if (this.model.targetId) {
                if (ej.getCurrentPage)
                    var ele = ej.getCurrentPage();
                else
                    var ele = $("body");

                ej.listenTouchEvent(ele.find("#" + this.model.targetId), ej.endEvent(), this._targetButtonTapHandler, remove, this);
            }
            else {
                ej.listenEvents([this._nbHome, this._nbHome], [ej.startEvent(), ej.endEvent()], [this._swipeStartHandler, this._swipeEndHandler], remove, this);
            }
            //Ovelay Binding
            ej.listenTouchEvent(this._elementOverlay, ej.endEvent(), this._overlayTapHandler, remove, this);

            //Resize Events
            if (ej.isTouchDevice())
                ej.listenEvents([window], ["orientationchange"], [this._onOrientationChangeHandler], remove, this);
            else
                ej.listenTouchEvent(window, "resize", this._onResizeEventHandler, remove, this);
        },

        _transitionCloseEnd: function () {
            this.element.hide();
            this._clearAppviewElement();
            ej.listenTouchEvent((this._isTransitionElement() ? this.element : this._nbHome), ej.transitionEndEvent(), this._transitionCloseHandler, true, this);
        },
        _transitionOpenEnd: function () {
            this._elementOverlay.show();
            if (this._scrollbar)
                this._scrollbar.ejmScrollPanel("refresh");
            if (this._lbscrollbar)
                this._lbscrollbar.ejmScrollPanel("refresh");
            ej.listenTouchEvent((this._isTransitionElement() ? this.element : this._nbHome), ej.transitionEndEvent(), this._transitionOpenHandler, true, this);
        },
        /**
        * Configure touchend on Navigation Drawer  
        * @private
        */
        _targetButtonTap: function (e) {
            e.preventDefault();
            if (!this._isOtherOpened()) this._show();
        },
        _elementOverlayTap: function (e) {
            e.preventDefault();
            this._data = { element: this.element };
            this.model.enableListView ? $.extend(this._data, { listview: this._lb }) : undefined;
            this._trigger("beforeclose", this._data);
            this._hide();
        },
        /**
        * Swipe start on Navigation drawer 
        * @private
        */
        _swipeStart: function (e) {
            var point = e.changedTouches ? e.changedTouches[0] : e;
            this._startSwipeOffsetX = point.clientX - this._nbHome.offset().left;
            this._startSwipeOffsetActualX = point.clientX;
            this._startSwipeOffsetY = point.clientY;
            this._containerX = this._isTransitionElement() ? this.element.offset().left : this._nbHome.offset().left;
            ej.listenTouchEvent(this._nbHome, ej.moveEvent(), this._swipeMoveHandler, false, this);
        },
        /**
        * Swipe Move on Navigation drawer  
        * @private
        */
        _swipeMove: function (e) {
            var point = e.changedTouches ? e.changedTouches[0] : e;
            var allowOpDirection = this._isOpened() ? (this._swipeDirection != this.model.direction.toLowerCase() ? true : false) : false;
            if (this._startSwipeOffsetX && this._startSwipeOffsetX > (e.clientX - this._nbHome.offset().left)) { this._swipeDirection = "right"; }
            else { this._swipeDirection = "left"; }
            if (!allowOpDirection) {
                if (this._swipeDirection == this.model.direction.toLowerCase() && !this._isOtherOpened()) {
                    ej.listenEvents([this._nbHome, this._nbHome, this._nbHome], [ej.moveEvent(), ej.endEvent()], [this._touchMoveHandler, this._touchEndHandler], false, this);
                }
                else {
                    ej.listenEvents([this._nbHome, this._nbHome, this._nbHome], [ej.moveEvent(), ej.endEvent()], [this._touchMoveHandler, this._touchEndHandler], true, this);
                }
            }
            else {
                if (this._startSwipeOffsetX && this._isOpened()) {
                    this._relativeX = point.clientX - this._startSwipeOffsetX;
                    this._relativeY = point.clientY - this._startSwipeOffsetY;
                    if ($(point.target).hasClass("" + this._prefixClass + "nb-overlay")) {
                        if (ej.getRenderMode && ej.getRenderMode() == "ios7") {
                            this._hide();
                            ej.listenTouchEvent(this._nbHome, ej.moveEvent(), this._swipeMoveHandler, true, this);
                        }
                        else
                            if (this.model.direction == "left" ? -(this._relativeX) < this.element.width() : this._relativeX < this.element.width())
                                this._transform((this.model.direction == "left" ? (this.element.width() + this._relativeX) - this._nbHome.offset().left : -((this.element.width() - this._relativeX) - this._nbHome.offset().left)), 0, this._isTransitionElement());
                    }

                }
            }
        },
        /**
        * Swipe end on Navigation drawer  
        * @private
        */
        _swipeEnd: function (e) {
            var point = e.changedTouches ? e.changedTouches[0] : e;
            ej.listenTouchEvent(this._nbHome, ej.moveEvent(), this._swipeMoveHandler, true, this);
        },
        /**
        * Touch move on Navigation drawer  
        * @private
        */
        _touchMove: function (e) {
            var point = e.changedTouches ? e.changedTouches[0] : e;
            ej.listenTouchEvent(this._nbHome, ej.moveEvent(), this._swipeMoveHandler, true, this);
            if (this._isTransitionElement()) { this._containerX = 0; }
            if (this._startSwipeOffsetX && !this._isOpened()) {
                this._relativeX = point.clientX - this._startSwipeOffsetX;
                this._relativeY = point.clientY - this._startSwipeOffsetY;
                if (this.model.direction == "left" ? this._startSwipeOffsetX < 50 : this._startSwipeOffsetX > this._nbHome.width() - 50 && !($.isFunction(ej.isIOS7) ? ej.isIOS7() : false)) {
                    this.element.show();
                    if (this.model.direction == "left" ? this._relativeX - this._nbHome.offset().left < this.element.width() : this._relativeX - this._nbHome.offset().left > -(this.element.width())) {
                        !this._containerX || this.model.targetHome ? this._transform((this._containerX + this._relativeX) - this._nbHome.offset().left, 0, this._isTransitionElement()) : undefined;
                    }
                }
                else {
                    if (ej.getRenderMode && ej.getRenderMode() == "ios7") {
                        if (Math.abs(this._relativeX) > 50)
                        this._show();
                    }
                }
            }
        },
        /**
        * Touch end on Navigation drawer  
        * @private
        */
        _touchEnd: function (e) {
            var point = e.changedTouches ? e.changedTouches[0] : e;
            ej.listenTouchEvent(this._nbHome, ej.moveEvent(), this._touchMoveHandler, true, this);
            if (!this._isOpened() && !($.isFunction(ej.isIOS7) ? ej.isIOS7() : false)) {
                if (!this._containerX) {
                    this._relativeX = point.clientX - this._startSwipeOffsetX;
                    this._relativeY = point.clientY - this._startSwipeOffsetY;
                    if (this.model.direction == "left" ? this._startSwipeOffsetX < 50 : this._startSwipeOffsetX > this._nbHome.width() - 50) {
                        if (this._relativeX > 30 || this._relativeX < -30)
                            this._show();
                        else
                            this._hide();
                    }
                }
                else {
                    this._hide();
                }
            }
            this._data = { targetElement: this._nbHome, element: this.element, direction: this._swipeDirection };
            this.model.enableListView ? $.extend(this._data, { listview: this._lb }) : undefined;
            this._trigger("swipe", this._data);
            ej.listenTouchEvent(this._nbHome, ej.endEvent(), this._touchEndHandler, true, this);
            ej.listenTouchEvent(this._nbHome, "mouseleave", this._touchEndHandler, true, this);
        },
        _onOrientationChangeEvent: function (e) {
            var state;
            if (this._isOpened()) { state = "opned"; } else { state = "clsed" }
            this.element.show();
            if (window.orientation == 0 || window.orientation == 180 || window.orientation == 90) { window.scrollTo(0, 0); }
            this._transform(0, 0, this._isTransitionElement());
            this.element.hide();
            this.element.removeClass("" + this._prefixClass + "nb-opened");
            this._setWidth();
            this._setLayout();
            if (state == "opned") { this._show(); }
        },

        _onResizeEvent: function (e) {
            var state;
            if (this._isOpened()) { state = "opned"; } else { state = "clsed" }
            this.element.show();
            this._transform(0, 0, this._isTransitionElement());
            this.element.hide();
            this.element.removeClass("" + this._prefixClass + "nb-opened");
            this._clearAppviewElement();
            this._setWidth();
            this._setLayout();
            if (state == "opned") { this._show(); }
        },
        /*---------------Public Methods---------------*/
        //Web
        /**
        * To open the navigation drawer control
        * @method open
        * @return jQuery
        * @example 
        * &lt;div id="home" class="navsubpage"&gt;
        * &lt;div align="center" class="content"&gt;
        * &lt;h2 class="title"&gt;
        * Home&lt;/h2&gt;
        * &lt;p&gt;
        * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
        * &lt;/p&gt;
        * &lt;/div&gt;
        * &lt;/div&gt;
        * &lt;style&gt;
        * .list {
        *   border-bottom: 1px solid;
        *   line-height: 50px;
        *   text-align: center;
        *   width:200px;
        *   }
        * &lt;/style&gt;
        * &lt;div id="navpane" &gt;
        * &lt;div class="list"&gt; Home &lt;/div&gt;
        * &lt;div class="list"&gt; Communities &lt;/div&gt;
        * &lt;/div&gt;
        * &lt;script &gt;
        * $(function(){
		*	$("#navpane").ejNavigationDrawer();
        *   $("#navpane").ejNavigationDrawer("open");
        * });
        * &lt;/script &gt;
        * @memberof ejNavigationDrawer
        * @instance
        */
        //Mobile
        /**
        * To open the navigation drawer control
        * @return jQuery
        * @method open
        * @example 
        * &lt;div id="home" class="navsubpage"&gt;
        * &lt;div align="center" class="content"&gt;
        * &lt;h2 class="title"&gt;
        * Home&lt;/h2&gt;
        * &lt;p&gt;
        * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
        * &lt;/p&gt;
        * &lt;/div&gt;
        * &lt;/div&gt;
        * &lt;style&gt;
        * .list {
        *   border-bottom: 1px solid;
        *   line-height: 50px;
        *   text-align: center;
        *   width:200px;
        *   }
        * &lt;/style&gt;
        * &lt;div data-role="ejmnavigationdrawer" id="navpane" &gt;
        * &lt;div class="list"&gt; Home &lt;/div&gt;
        * &lt;div class="list"&gt; Communities &lt;/div&gt;
        * &lt;/div&gt;
        * &lt;script &gt;
        * $(function()
        * { 
        * var lsm = $("#navpane").data("ejmNavigationDrawer");
        * lsm.open();
        * });
        * &lt;/script &gt;
        * @memberof ejmNavigationDrawer
        * @instance
        */
        open: function (e) {
            this._show();
        },
        //Web
        /**
        * To close the navigation drawer control
        * @method close
        * @return jQuery
        * @example 
        * &lt;div id="home" class="navsubpage"&gt;
        * &lt;div align="center" class="content"&gt;
        * &lt;h2 class="title"&gt;
        * Home&lt;/h2&gt;
        * &lt;p&gt;
        * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
        * &lt;/p&gt;
        * &lt;/div&gt;
        * &lt;/div&gt;
        * &lt;style&gt;
        * .list {
        *   border-bottom: 1px solid;
        *   line-height: 50px;
        *   text-align: center;
        *   width:200px;
        *   }
        * &lt;/style&gt;
        * &lt;div id="navpane" &gt;
        * &lt;div class="list"&gt; Home &lt;/div&gt;
        * &lt;div class="list"&gt; Communities &lt;/div&gt;
        * &lt;/div&gt;
        * &lt;script &gt;
        * $(function(){
		*   $("#navpane").ejNavigationDrawer();
        *   $("#navpane").ejNavigationDrawer("close");
        * });
        * &lt;/script &gt;
        * @memberof ejNavigationDrawer
        * @instance
        */
        //Mobile
        /**
        * To close the navigation drawer control
        * @method close
        * @return jQuery
        * @example 
        * &lt;div id="home" class="navsubpage"&gt;
        * &lt;div align="center" class="content"&gt;
        * &lt;h2 class="title"&gt;
        * Home&lt;/h2&gt;
        * &lt;p&gt;
        * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
        * &lt;/p&gt;
        * &lt;/div&gt;
        * &lt;/div&gt;
        * &lt;style&gt;
        * .list {
        *   border-bottom: 1px solid;
        *   line-height: 50px;
        *   text-align: center;
        *   width:200px;
        *   }
        * &lt;/style&gt;
        * &lt;div data-role="ejmnavigationdrawer" id="navpane" &gt;
        * &lt;div class="list"&gt; Home &lt;/div&gt;
        * &lt;div class="list"&gt; Communities &lt;/div&gt;
        * &lt;/div&gt;
        * &lt;script &gt;
        * $(function()
        * { 
        * var lsm = $("#navpane").data("ejmNavigationDrawer");
        * lsm.close();
        * });
        * &lt;/script &gt;
        * @memberof ejmNavigationDrawer
        * @instance
        */
        close: function (e) {
            this._data = { element: this.element };
            this.model.enableListView ? $.extend(this._data, { listview: this._lb }) : undefined;
            this._trigger("beforeClose", this._data);
            this._hide();
        },
        //Web
        /**
        * To Toggle the navigation drawer control
        * @method toggle
        * @return jQuery
        * @example 
        * &lt;div id="home" class="navsubpage"&gt;
        * &lt;div align="center" class="content"&gt;
        * &lt;h2 class="title"&gt;
        * Home&lt;/h2&gt;
        * &lt;p&gt;
        * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
        * &lt;/p&gt;
        * &lt;/div&gt;
        * &lt;/div&gt;
        * &lt;style&gt;
        * .list {
        *   border-bottom: 1px solid;
        *   line-height: 50px;
        *   text-align: center;
        *   width:200px;
        *   }
        * &lt;/style&gt;
        * &lt;div id="navpane" &gt;
        * &lt;div class="list"&gt; Home &lt;/div&gt;
        * &lt;div class="list"&gt; Communities &lt;/div&gt;
        * &lt;/div&gt;
        * &lt;script &gt;
        * $(function(){
		*	$("#navpane").ejNavigationDrawer();
        *   $("#navpane").ejNavigationDrawer("toggle");
        * });
        * &lt;/script &gt;
        * @memberof ejNavigationDrawer
        * @instance
        */
        //Mobile
        /**
        * To Toggle the navigation drawer control
        * @method toggle
        * @return jQuery
        * @example 
        * &lt;div id="home" class="navsubpage"&gt;
        * &lt;div align="center" class="content"&gt;
        * &lt;h2 class="title"&gt;
        * Home&lt;/h2&gt;
        * &lt;p&gt;
        * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
        * &lt;/p&gt;
        * &lt;/div&gt;
        * &lt;/div&gt;
        * &lt;style&gt;
        * .list {
        *   border-bottom: 1px solid;
        *   line-height: 50px;
        *   text-align: center;
        *   width:200px;
        *   }
        * &lt;/style&gt;
        * &lt;div data-role="ejmnavigationdrawer" id="navpane" &gt;
        * &lt;div class="list"&gt; Home &lt;/div&gt;
        * &lt;div class="list"&gt; Communities &lt;/div&gt;
        * &lt;/div&gt;
        * &lt;script &gt;
        * $(function()
        * { 
        * var lsm = $("#navpane").data("ejmNavigationDrawer");
        * lsm.toggle();
        * });
        * &lt;/script &gt;
        * @memberof ejmNavigationDrawer
        * @instance
        */
        toggle: function (e) {
            this._isOpened() ? this.close() : this.open();
        }
        /*---------------Public Methods End---------------*/
    });

})(jQuery, Syncfusion);