/**
* @fileOverview Plugin to style the Html Radial Menu elements
* @copyright Copyright Syncfusion Inc. 2001 - 2014. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/

(function ($, ej, undefined) {

    ej.widget("ejRadialMenuBase", "ej.RadialMenuBase", {
        _tags: [{
            tag: "items",
            attr: ["imageName", "imagePath", "imageUrl", "windows.text", "flat.text", "text", [{
                tag: "items", attr: ["imageName", "imagePath", "imageUrl", "windows.text", "flat.text", "text"]
            }]]
        }],

        defaults: {
            //Web
            /**		
            * Specifies the width of radial menu
            * @default 300
            * @type {int}
            * @example 
            * // Set Radialmenu width on initialization. 
            * //To set width API  
            * &lt;div &gt;
            * &lt;br /&gt;
            * &lt;p&gt;
            * Syncfusion is the enterprise technology partner of choice for Windows development
            * &lt;/p&gt;
            * &lt;/div&gt;  
            * &lt;div id="defaultradialmenu"&gt;
            * &lt;ul&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/social.png"
            * data-ej-text="social"&gt;&lt;/li&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/music.png" 
            * data-ej-text="music"&gt;&lt;/li&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/direction.png" 
            * data-ej-text="direction"&gt;&lt;/li&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/message.png" 
            * data-ej-text="message"&gt;&lt;/li&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/browser.png" 
            * data-ej-text="browser"&gt;&lt;/li&gt;
            * &lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function () {
            * $("#defaultradialmenu").ejRadialMenu({ "width":300});	
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the Radialmenu width, after initialization:
            * &lt;script&gt;
            * // Gets the width API.		
            *  $("#radialmenu").ejRadialMenu ("option", "width");			
            * // Sets the width API
            * $("#radialmenu").ejRadialMenu ("option", "width", 300);            
            * &lt;/script&gt;
            * @memberof ejRadialMenu
            * @instance
            */
            //Mobile
            /**		
            * Specifies the width of the radialmenu control.
            * @default 300
            * @type {int}
            * @example 
            * //Set the width property in unobtrusive way.
            * &lt;div &gt;
            * &lt;br /&gt;
            * &lt;p&gt;
            * Syncfusion is the enterprise technology partner of choice for Windows development
            * &lt;/p&gt;
            * &lt;/div&gt;  
            * &lt;div id="defaultradialmenu" data-role="ejmradialmenu" data-ej-width="300"
            * &gt;
            * &lt;ul&gt;
            * &lt;li data-ej-imagename="social.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="social"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="music.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="music"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="direction.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="direction"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="message.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="message"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="browser.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="browser"&gt;&lt;/li&gt;
            * &lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * // Set Radialmenu width on initialization. 
            * //To set width API value 
            * &lt;div &gt;
            * &lt;br /&gt;
            * &lt;p&gt;
            * Syncfusion is the enterprise technology partner of choice for Windows development
            * &lt;/p&gt;
            * &lt;/div&gt;  
            * &lt;div id="defaultradialmenu"&gt;
            * &lt;ul&gt;
            * &lt;li data-ej-imagename="social.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="social"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="music.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="music"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="direction.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="direction"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="message.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="message"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="browser.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="browser"&gt;&lt;/li&gt;
            * &lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function () {
            * $("#defaultradialmenu").ejmRadialMenu({ "width":300});	
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the Radialmenu width, after initialization:
            * &lt;script&gt;
            * // Gets the width API value.		
            *  $("#defaultradialmenu").ejmRadialMenu ("option", "width");			
            * // Sets the width API
            * $("#defaultradialmenu").ejmRadialMenu ("option", "width", 300);            
            * &lt;/script&gt;
            * @memberof ejmRadialMenu
            * @instance
            */
            width: 300,
            //Web
            /**		
            * To enable Animation for Radial Menu.
            * @default true
            * @type {boolean}
            * @example 
            * // Set Radialmenu enableAnimation on initialization. 
            * //To set enableAnimation API 
            * &lt;div &gt;
            * &lt;br /&gt;
            * &lt;p&gt;
            * Syncfusion is the enterprise technology partner of choice for Windows development
            * &lt;/p&gt;
            * &lt;/div&gt;  
            * &lt;div id="defaultradialmenu"&gt;
            * &lt;ul&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/social.png"
            * data-ej-text="social"&gt;&lt;/li&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/music.png" 
            * data-ej-text="music"&gt;&lt;/li&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/direction.png" 
            * data-ej-text="direction"&gt;&lt;/li&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/message.png" 
            * data-ej-text="message"&gt;&lt;/li&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/browser.png" 
            * data-ej-text="browser"&gt;&lt;/li&gt;
            * &lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function () {
            * $("#defaultradialmenu").ejRadialMenu({ "enableAnimation":true });	
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the Radialmenu enableAnimation, after initialization:
            * &lt;script&gt;
            * // Gets the enableAnimation API.		
            * $("#defaultradialmenu").ejRadialMenu ("option", "enableAnimation");			
            * // Sets the Width API
            * $("#defaultradialmenu").ejRadialMenu ("option", "enableAnimation", true);            
            * &lt;/script&gt;
            * @memberof ejRadialMenu
            * @instance
            */
            //Mobile
            /**		
            * To enable Animation for Radial Menu.
            * @default true
            * @type {boolean}
            * @example 
            * //Set the enableAnimation property in unobtrusive way.
            * &lt;div &gt;
            * &lt;br /&gt;
            * &lt;p&gt;
            * Syncfusion is the enterprise technology partner of choice for Windows development
            * &lt;/p&gt;
            * &lt;/div&gt;  
            * &lt;div id="defaultradialmenu" data-role="ejmradialmenu" data-ej-enableanimation="true" 
            * &gt;
            * &lt;ul&gt;
            * &lt;li data-ej-imagename="social.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="social"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="music.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="music"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="direction.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="direction"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="message.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="message"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="browser.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="browser"&gt;&lt;/li&gt;
            * &lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * // Set Radialmenu enableAnimation on initialization. 
            * //To set enableAnimation API  
            * &lt;div &gt;
            * &lt;br /&gt;
            * &lt;p&gt;
            * Syncfusion is the enterprise technology partner of choice for Windows development
            * &lt;/p&gt;
            * &lt;/div&gt;  
            * &lt;div id="defaultradialmenu"&gt;
            * &lt;ul&gt;
            * &lt;li data-ej-imagename="social.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="social"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="music.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="music"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="direction.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="direction"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="message.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="message"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="browser.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="browser"&gt;&lt;/li&gt;
            * &lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function () {
            * $("#defaultradialmenu").ejmRadialMenu({ "enableAnimation":true });	
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the Radialmenu enableAnimation, after initialization:
            * &lt;script&gt;
            * // Gets the enableAnimation API.		
            *  $("#radialmenu").ejmRadialMenu ("option", "enableAnimation");			
            * // Sets the Width API
            * $("#radialmenu").ejmRadialMenu ("option", "enableAnimation", true);            
            * &lt;/script&gt;
            * @memberof ejmRadialMenu
            * @instance
            */
            enableAnimation: true,
            items: []
        },
        dataTypes: {
            enableAnimation: "boolean",
            items: "array"
        },
        _initialization: function () {
            this._svgLink = "http://www.w3.org/2000/svg";
            if (this.model.items.length < 1) {
                this._radialItems = $(this.element.find(">ul").children());
                for (var i = 0; i < this._radialItems.length ; i++) {
                    this.model.items.push(this._itemsObjectCollection($(this._radialItems[i])));
                    if ($(this._radialItems[i]).find("ul").children().length > 0) {
                        this._nestedRadialItems = $(this._radialItems[i]).find("ul").children();
                        this.model.items[i].items = [];
                        for (var j = 0; j < this._nestedRadialItems.length; j++) {
                            this.model.items[i].items.push(this._itemsObjectCollection($(this._nestedRadialItems[j])));
                        }
                    }
                }
            }
            this._itemCount = this.model.items.length;
            $(this.element.children()).remove();
            this._startXY = (this.model.width / 2);
        },
        /**
        * To create item object	
        * @private
        */
        _itemsObjectCollection: function (element) {
            var item = {};
            item.windows = { text: element.attr("data-ej-windows-text") };
            item.flat = { text: element.attr("data-ej-flat-text") };
            item.text = element.attr("data-ej-text");
            item.imageName = element.attr("data-ej-imagename");
            item.imagePath = element.attr("data-ej-imagepath");
            item.imageUrl = element.attr("data-ej-imageUrl");
            return item;
        },
        /**
        * To create SVG element	
        * @private
        */
        _createSVGElement: function () {
            var svgObj = document.createElementNS(this._svgLink, 'svg');
            if (this.model.width != null) {
                svgObj.setAttribute("width", this.model.width);
                svgObj.setAttribute("height", this.model.width);
            }
            return $(svgObj);
        },
        /**
        * To create group element	
        * @private
        */
        _createGroupElement: function (id) {
            var group = document.createElementNS(this._svgLink, "g");
            if (id)
                group.setAttribute("id", id);
            return $(group);
        },
        /**
        * To create Image element	
        * @private
        */
        _createImageElement: function (width, height, currentEle, x, y) {
            imgLoc = currentEle["imageUrl"] ? currentEle["imageUrl"] : (this.model.renderMode.toLowerCase() != "flat" ? currentEle["imagePath"] + "/" + this.model.renderMode.toLowerCase() + "/" + this.model.theme.toLowerCase() + "/" + currentEle["imageName"] : currentEle["imagePath"] + "/" + this.model.renderMode.toLowerCase() + "/" + currentEle["imageName"]),
            image = document.createElementNS(this._svgLink, "image");
            image.setAttribute("width", width);
            image.setAttribute("height", height);
            image.setAttributeNS('http://www.w3.org/1999/xlink', 'href', imgLoc);
            image.setAttribute("x", x);
            image.setAttribute("y", y);
            return image;
        },
        /**
        * To create Text element	
        * @private
        */
        _createTextElement: function (x, y, style, content) {
            var text = document.createElementNS(this._svgLink, "text");
            text.setAttribute("x", x);
            text.setAttribute("y", y);
            text.setAttribute("class", style);
            text.textContent = content;
            return text;
        },
        /**
        * To create path element 	
        * @private
        */
        _createPathElement: function (index, direction, style) {
            var path = document.createElementNS(this._svgLink, "path");
            path.setAttribute("index", index);
            path.setAttribute("d", direction);
            path.setAttribute("class", style);
            return path;
        },
        /**
        * To create polygon element	
        * @private
        */
        _createPolygonElement: function (index, transform) {
            var polygon = document.createElementNS(this._svgLink, "polygon");
            polygon.setAttribute("points", "10,10 0,10 5,5");
            polygon.setAttribute("index", index);
            polygon.setAttribute("fill", "#FFFFFF");
            polygon.setAttribute("transform", transform);
            return polygon;
        },
        /**
        * To create circle element	
        * @private
        */
        _createCircleElement: function (x, y, r, style) {
            var circle = document.createElementNS(this._svgLink, "circle");
            circle.setAttribute("cx", x);
            circle.setAttribute("cy", y);
            circle.setAttribute("r", r);
            circle.setAttribute("class", style);
            return circle;
        },
        /**
        * To do Claculation for Radial Arc
        * @private
        */
        _calculateRadialArc: function (menuCount, size, mRadius, Arcdradius, polyRadius) {
            var itemCurrentPos = 0,
                startAngle = 2 * Math.PI * itemCurrentPos,
                endAngle = 2 * Math.PI * (itemCurrentPos + (10 / (menuCount * 10))),
                radius = 0.5 * size * Math.min(this.model.width, this.model.width),
                menuItemRadius = mRadius * size * Math.min(this.model.width, this.model.width),
                dradius = Arcdradius * radius,
                polygonRadius = polyRadius * radius,
                degPoint = 360 / menuCount,
                degree = degPoint / 2;
            var x1 = [], y1 = [], x2 = [], y2 = [], midx = [], midy = [], dStartX = [], dStartY = [], dEndX = [], dEndY = [], dmidx = [], dmidy = [], deg = [], longArc = [];
            for (var i = 0; i < menuCount; i++) {
                var pathStartAngle = -.5 * Math.PI;
                startAngle = startAngle + pathStartAngle;
                endAngle = endAngle + pathStartAngle - 0.000001;
                longArc[i] = endAngle - startAngle < Math.PI ? 0 : 1;
                var midAngle = (startAngle + endAngle) / 2;
                x1[i] = this._startXY + radius * Math.cos(startAngle);
                y1[i] = this._startXY + radius * Math.sin(startAngle);
                x2[i] = this._startXY + radius * Math.cos(endAngle);
                y2[i] = this._startXY + radius * Math.sin(endAngle);
                midx[i] = this._startXY + menuItemRadius * Math.cos(midAngle);
                midy[i] = this._startXY + menuItemRadius * Math.sin(midAngle);
                dStartX[i] = this._startXY + dradius * Math.cos(startAngle);
                dStartY[i] = this._startXY + dradius * Math.sin(startAngle);
                dEndX[i] = this._startXY + dradius * Math.cos(endAngle);
                dEndY[i] = this._startXY + dradius * Math.sin(endAngle);
                dmidx[i] = this._startXY + polygonRadius * Math.cos(midAngle);
                dmidy[i] = this._startXY + polygonRadius * Math.sin(midAngle);
                deg[i] = degree;
                itemCurrentPos += 10 / (menuCount * 10);
                startAngle = 2 * Math.PI * itemCurrentPos;
                endAngle = 2 * Math.PI * (itemCurrentPos + (10 / (menuCount * 10)));
                degree += degPoint;
            }
            return ({ x1: x1, y1: y1, x2: x2, y2: y2, midx: midx, midy: midy, dStartX: dStartX, dStartY: dStartY, dEndX: dEndX, dEndY: dEndY, dmidx: dmidx, dmidy: dmidy, deg: deg, longArc: longArc, radius: radius, dradius: dradius });
        },
        /**
        * Render the Radial Menu Item
        * @private
        */
        _renderRadialMenu: function () {
            this._radialSVG = this._createSVGElement();
            this._radialChildSVG = this._createSVGElement();
            this._childArcGroup = this._createGroupElement("childarcgroup");
            this._polygonGroup = this._createGroupElement("polygongroup");
            this._polygonGroup.attr("transform", "translate(-10,-10)");
            this._radialArcGroup = this._createGroupElement();
            this._menuItemsGroup = this._createGroupElement("menuitemsgroup");
            this._menuItemsGroup.attr("transform", "translate(-10,-10)");
            this._menuItemsArcPaths = this._createGroupElement("menuitemsarcpaths");
            this._menuItemsPaths = this._createGroupElement();
            this._radialSVGDiv = ej.buildTag("div#radialsvgdiv." + this._prefix + "abs").css("height", this.model.width);
            this._radialCircleSVGDiv = ej.buildTag("div#radialcirclesvgdiv." + this._prefix + "abs " + this._prefix + "displaynone");
            this._radialChildSVGDiv = ej.buildTag("div#radialchildsvgdiv." + this._prefix + "abs " + this._prefix + "displaynone");
            var pointsVal = this._calculateRadialArc(this._itemCount, 1, 0.28, 0.8, 0.95),
                pointsArcVal = this._calculateRadialArc(this._itemCount, 0.79, null, 0.97, null),
                pointsItemVal = this._calculateRadialArc(this._itemCount, 0.8, null, 0.3, null);
            for (var i = 0; i < this._itemCount; i++) {
                var direction = "M" + " " + pointsVal.x1[i] + " " + pointsVal.y1[i] + " " + "A" + " " + pointsVal.radius + " " + pointsVal.radius + " " + "0" + " " + pointsVal.longArc[i] + " " + "1" + " " + pointsVal.x2[i] + " " + pointsVal.y2[i] + " " + "L" + " " + pointsVal.dEndX[i] + " " + pointsVal.dEndY[i] + " " + "A" + " " + pointsVal.dradius + " " + pointsVal.dradius + " " + "1" + " " + pointsVal.longArc[i] + " " + "0" + " " + pointsVal.dStartX[i] + " " + pointsVal.dStartY[i] + " " + "z",
                    arcDirection = "M" + " " + pointsArcVal.x1[i] + " " + pointsArcVal.y1[i] + " " + "A" + " " + pointsArcVal.radius + " " + pointsArcVal.radius + " " + "0" + " " + pointsArcVal.longArc[i] + " " + "1" + " " + pointsArcVal.x2[i] + " " + pointsArcVal.y2[i] + " " + "L" + " " + pointsArcVal.dEndX[i] + " " + pointsArcVal.dEndY[i] + " " + "A" + " " + pointsArcVal.dradius + " " + pointsArcVal.dradius + " " + "1" + " " + pointsArcVal.longArc[i] + " " + "0" + " " + pointsArcVal.dStartX[i] + " " + pointsArcVal.dStartY[i] + " " + "z",
                    itemDirection = "M" + " " + pointsItemVal.x1[i] + " " + pointsItemVal.y1[i] + " " + "A" + " " + pointsItemVal.radius + " " + pointsItemVal.radius + " " + "0" + " " + pointsItemVal.longArc[i] + " " + "1" + " " + pointsItemVal.x2[i] + " " + pointsItemVal.y2[i] + " " + "L" + " " + pointsItemVal.dEndX[i] + " " + pointsItemVal.dEndY[i] + " " + "A" + " " + pointsItemVal.dradius + " " + pointsItemVal.dradius + " " + "1" + " " + pointsItemVal.longArc[i] + " " + "0" + " " + pointsItemVal.dStartX[i] + " " + pointsItemVal.dStartY[i] + " " + "z",
                    currentEle = this.model.items[i],
                    imgTextGroup = this._createGroupElement(),
                      dataText = this.model.renderMode ? currentEle[this.model.renderMode].text : currentEle.text;
                this._menuItemsArcPaths.append(this._createPathElement(i, arcDirection, "" + this._prefix + "arcbgcolor"));
                this._menuItemsPaths.append(this._createPathElement(i, itemDirection, "" + this._prefix + "itembgcolor"));
                this._radialArcGroup.append(this._createPathElement(i, direction, "" + this._prefix + "default"));
                imgTextGroup.attr({ "cursor": "context-menu", "index": i });
                imgTextGroup.append(this._createImageElement(20, 20, currentEle, pointsVal.midx[i], pointsVal.midy[i] - 10));
                imgTextGroup.append(this._createTextElement(pointsVal.midx[i] + 10, pointsVal.midy[i] + 25, "" + this._prefix + "textcolor", dataText));
                this._menuItemsGroup.append(imgTextGroup);
                if (currentEle["items"]) {
                    var transform = pointsVal.deg[i] > 270 ? "translate(" + (pointsVal.dmidx[i] + 5) + "," + (pointsVal.dmidy[i] + 15) + ")" + "rotate(" + pointsVal.deg[i] + ")" : "translate(" + (pointsVal.dmidx[i] + 10) + "," + (pointsVal.dmidy[i] + 10) + ")" + "rotate(" + pointsVal.deg[i] + ")";
                    this._childArcGroup.append(this._createPathElement(i, direction, "" + this._prefix + "childdefault"));
                    this._polygonGroup.append(this._createPolygonElement(i, transform));
                }
            }
            var circle = this._createCircleElement(this._startXY, this._startXY, this._startXY / 3.5, "" + this._prefix + "circlebgcolor");
            this._menuItemsArcGroup = this._radialArcGroup.clone();
            this._radialChildSVG.append(this._menuItemsPaths).append(this._menuItemsGroup).append(this._menuItemsArcGroup).append(this._childArcGroup).append(this._polygonGroup).append(this._menuItemsArcPaths).append(circle);
            this._radialContainer.append(this._radialSVGDiv.append(this._radialCircleSVGDiv.append(this._radialSVG.append(this._radialArcGroup))).append(this._radialChildSVGDiv.append(this._radialChildSVG)));

        },
        /**
        * Render the Radial Child Menu Item
        * @private
        */
        _renderRadialChildMenu: function (index) {
            this._menuChildSVG = this._createSVGElement();
            this._menuChildSVGDiv = ej.buildTag("div#menuchildsvgdiv." + this._prefix + "abs");
            if (this.model.enableAnimation) {
                this._radialChildSVGDiv.removeClass("" + this._prefix + "radialshow").addClass("" + this._prefix + "scalehide");
                this._radialChildAnimate();
                this._menuChildSVGDiv.addClass("" + this._prefix + "scaleshow");
            }
            else
                this._radialChildSVGDiv.addClass("" + this._prefix + "displaynone");
            this._radial.removeClass(this.model.imageClass).addClass("" + this._prefix + "backarrow " + this.model.backImageClass + "");
            this._childItemsGroup = this._createGroupElement("childitemsgroup");
            this._childItemsGroup.attr("transform", "translate(-10,-10)");
            this._childItemArcGroup = this._createGroupElement();
            this._childItemsArcPaths = this._createGroupElement("childitemsarcpaths");
            this._childItemsPaths = this._createGroupElement();
            var child = this.model.items[index].items;
            childcount = child.length,
            pointsVal = this._calculateRadialArc(childcount, 1, 0.28, 0.8, null),
            pointsArcVal = this._calculateRadialArc(childcount, 0.79, null, 0.97, null),
            pointsItemVal = this._calculateRadialArc(childcount, 0.8, null, 0.3, null);
            for (var i = 0; i < childcount; i++) {
                var direction = "M" + " " + pointsVal.x1[i] + " " + pointsVal.y1[i] + " " + "A" + " " + pointsVal.radius + " " + pointsVal.radius + " " + "0" + " " + pointsVal.longArc[i] + " " + "1" + " " + pointsVal.x2[i] + " " + pointsVal.y2[i] + " " + "L" + " " + pointsVal.dEndX[i] + " " + pointsVal.dEndY[i] + " " + "A" + " " + pointsVal.dradius + " " + pointsVal.dradius + " " + "1" + " " + pointsVal.longArc[i] + " " + "0" + " " + pointsVal.dStartX[i] + " " + pointsVal.dStartY[i] + " " + "z",
                    arcDirection = "M" + " " + pointsArcVal.x1[i] + " " + pointsArcVal.y1[i] + " " + "A" + " " + pointsArcVal.radius + " " + pointsArcVal.radius + " " + "0" + " " + pointsArcVal.longArc[i] + " " + "1" + " " + pointsArcVal.x2[i] + " " + pointsArcVal.y2[i] + " " + "L" + " " + pointsArcVal.dEndX[i] + " " + pointsArcVal.dEndY[i] + " " + "A" + " " + pointsArcVal.dradius + " " + pointsArcVal.dradius + " " + "1" + " " + pointsArcVal.longArc[i] + " " + "0" + " " + pointsArcVal.dStartX[i] + " " + pointsArcVal.dStartY[i] + " " + "z",
                    itemDirection = "M" + " " + pointsItemVal.x1[i] + " " + pointsItemVal.y1[i] + " " + "A" + " " + pointsItemVal.radius + " " + pointsItemVal.radius + " " + "0" + " " + pointsItemVal.longArc[i] + " " + "1" + " " + pointsItemVal.x2[i] + " " + pointsItemVal.y2[i] + " " + "L" + " " + pointsItemVal.dEndX[i] + " " + pointsItemVal.dEndY[i] + " " + "A" + " " + pointsItemVal.dradius + " " + pointsItemVal.dradius + " " + "1" + " " + pointsItemVal.longArc[i] + " " + "0" + " " + pointsItemVal.dStartX[i] + " " + pointsItemVal.dStartY[i] + " " + "z",
                    imgTextGroup = this._createGroupElement(),
                    currentEle = this.model.items[index].items[i],
                    dataText = this.model.renderMode ? currentEle[this.model.renderMode].text : currentEle.text;
                this._childItemArcGroup.append(this._createPathElement(i, direction, "" + this._prefix + "default"));
                this._childItemsArcPaths.append(this._createPathElement(i, arcDirection, "" + this._prefix + "arcbgcolor"));
                this._childItemsPaths.append(this._createPathElement(i, itemDirection, "" + this._prefix + "itembgcolor"));
                imgTextGroup.attr({ "cursor": "context-menu", "index": i });
                imgTextGroup.append(this._createImageElement(20, 20, currentEle, pointsVal.midx[i], pointsVal.midy[i] - 10));
                imgTextGroup.append(this._createTextElement(pointsVal.midx[i] + 10, pointsVal.midy[i] + 25, "" + this._prefix + "textcolor", dataText));
                this._childItemsGroup.append(imgTextGroup);
            }
            var circle = this._createCircleElement(this._startXY, this._startXY, this._startXY / 3.5, "" + this._prefix + "circlebgcolor");
            this._radialSVGDiv.append(this._menuChildSVGDiv.append(this._menuChildSVG.append(this._childItemsPaths).append(this._childItemsGroup).append(this._childItemArcGroup).append(this._childItemsArcPaths).append(circle)));
        },
        /**
        * To configure the properties at runtime	
        * @private
        */
        _setModel: function (options) {
            this._refresh();
        },
        /**
        * To refresh Radial Menu control		
        * @private
        */
        _refresh: function () {
            this._destroy();
            this._init();
        },
        /**
        * To destroy Radial Menu control		
        * @private
        */
        _destroy: function () {
            this.element.removeAttr("class style").children().remove();
        }
    });

})(jQuery, Syncfusion);