/**
* @fileOverview Plugin to style the Html TileView elements
* @copyright Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/


(function ($, ej, undefined) {
    ej.widget("ejTileBase", "ej.TileBase", {
        defaults: {
            /**		
            * Section for badge specific functionalities.                      
            * @memberof ejTile
            * @member badge {object}
            * @instance
            */

            /**		
            * Section for badge specific functionalities.                      
            * @memberof ejmTile
            * @member badge {object}
            * @instance
            */
            badge: {
                //Web
                /**	
                * Specifies whether to enable badge or not.
                * @default false
                * @member badge->enabled {object}
                * @type {boolean}
                * @alias ejTile#badge->enabled
                * @example 
                * // Set enabled on initialization. 
                * // To set enabled API value 
                * &lt;div id="tile" &gt;&lt;/div&gt;<br>
                * &lt;script&gt; 
                * // Create Tile control 
                * $("#tile").ejTile({ imageUrl: "themes/sample/tile/people.png", badge: { enabled: true } }); 
                * &lt;/script&gt;
                * @example 
                * //Get or set the enabled, after initialization:<br>
                * // Get the enabled API value.
                *  $("#tile").ejTile("option", "badge.enabled");			
                * // Set the enabled API
                * $("#tile").ejTile("option", "badge.enabled", true);            
                * @memberof ejTile
                * @instance
                */

                //Mobile
                /**	
                * Specifies whether to enable badge or not.
                * @default false
                * @member badge->enabled {object}
                * @type {boolean}
                * @alias ejmTile#badge->enabled
                * @example 
                * //Set the enabled property in unobtrusive way.
                * &lt;div id="tile" data-role="ejmtile" data-ej-imagepath="themes/sample/tile" data-ej-imageurl="people.png" data-ej-badge-enabled="true" &gt;
                * &lt;/div&gt;  
                * @example 
                * // Set enabled on initialization. 
                * // To set enabled API value 
                * &lt;div id="tile" &gt;&lt;/div&gt;<br>
                * &lt;script&gt; 
                * // Create Tile control 
                * $("#tile").ejmTile({ imageUrl: "people.png", badge: { enabled: true },imagePath:"themes/sample/tile" }); 
                * &lt;/script&gt;
                * @example 
                * //Get or set the enabled, after initialization:<br>
                * // Get the enabled API value.
                *  $("#tile").ejmTile("option", "badge.enabled");			
                * // Set the enabled API
                * $("#tile").ejmTile("option", "badge.enabled", true);            
                * @memberof ejmTile
                * @instance
                */
                enabled: false,
                //Web
                /**	
                * Sets value for tile badge.
                * @default 1
                * @member badge->value {object}
                * @type {number}
                * @alias ejTile#badge->value
                * @example 
                * // Set value on initialization. 
                * // To set value API value 
                * &lt;div id="tile" &gt;&lt;/div&gt;<br>
                * &lt;script&gt; 
                * // Create Tile control 
                * $("#tile").ejTile({ imageUrl: "themes/sample/tile/people.png", badge: { enabled: true, value:5 }}); 
                * &lt;/script&gt;
                * @example 
                * //Get or set the value, after initialization:<br>
                * // Get the value API value.
                *  $("#tile").ejTile("option", "badge.value");			
                * // Set the value API
                * $("#tile").ejTile("option", "badge.value", 5);            
                * @memberof ejTile
                * @instance
                */

                //Mobile
                /**	
                * Sets value for tile badge.
                * @default 1
                * @member badge->value {object}
                * @type {number}
                * @alias ejmTile#badge->value
                * @example 
                * //Set the value property in unobtrusive way.
                * &lt;div id="tile" data-role="ejmtile" data-ej-imagepath="themes/sample/tile" data-ej-imageurl="people.png" data-ej-badge-enabled="true" data-ej-badge-value="5"&gt;
                * &lt;/div&gt;  
                * @example 
                * // Set value on initialization. 
                * // To set value API value 
                * &lt;div id="tile" &gt;&lt;/div&gt;<br>
                * &lt;script&gt; 
                * // Create Tile control 
                * $("#tile").ejmTile({ imageUrl: "people.png", badge: { enabled: true, value:5 },imagePath:"themes/sample/tile" }); 
                * &lt;/script&gt;
                * @example 
                * //Get or set the value, after initialization:<br>
                * // Get the value API value.
                *  $("#tile").ejmTile("option", "badge.value");			
                * // Set the value API
                * $("#tile").ejmTile("option", "badge.value", 5);            
                * @memberof ejmTile
                * @instance
                */
                value: 1,
                //Web
                /**	
                * Specifies maximum value for tile badge.
                * @default 100
                * @member badge->maxValue {object}
                * @type {number}
                * @alias ejTile#badge->maxValue
                * @example 
                * // Set maxValue on initialization. 
                * // To set maxValue API value 
                * &lt;div id="tile" &gt;&lt;/div&gt;<br>
                * &lt;script&gt; 
                * // Create Tile control 
                * $("#tile").ejTile({ imageUrl: "themes/sample/tile/people.png", badge: { enabled: true, value:5, maxValue:3 } }); 
                * &lt;/script&gt;
                * @example 
                * //Get or set the maxValue, after initialization:<br>
                * // Get the maxValue API value.
                *  $("#tile").ejTile("option", "badge.maxValue");			
                * // Set the maxValue API
                * $("#tile").ejTile("option", "badge.maxValue", 3);            
                * @memberof ejTile
                * @instance
                */

                //Mobile
                /**	
                * Specifies maximum value for tile badge.
                * @default 100
                * @member badge->maxValue {object}
                * @type {number}
                * @alias ejmTile#badge->maxValue
                * @example 
                * //Set the maxValue property in unobtrusive way.
                * &lt;div id="tile" data-role="ejmtile" data-ej-imageurl="people.png" data-ej-imagepath="themes/sample/tile" data-ej-badge-enabled="true" data-ej-badge-value="5" data-ej-badge-maxvalue="3" &gt;
                * &lt;/div&gt;  
                * @example 
                * // Set maxValue on initialization. 
                * // To set maxValue API value 
                * &lt;div id="tile" &gt;&lt;/div&gt;<br>
                * &lt;script&gt; 
                * // Create Tile control 
                * $("#tile").ejmTile({ imageUrl: "people.png", badge: { enabled: true, value:5, maxValue:3 },imagePath:"themes/sample/tile"}); 
                * &lt;/script&gt;
                * @example 
                * //Get or set the maxValue, after initialization:<br>
                * // Get the maxValue API value.
                *  $("#tile").ejmTile("option", "badge.maxValue");			
                * // Set the maxValue API
                * $("#tile").ejmTile("option", "badge.maxValue", 3);            
                * @memberof ejmTile
                * @instance
                */
                maxValue: 100,
                //Web
                /**	
                * Specifies minimum value for tile badge.
                * @default 1
                * @member badge->minValue {object}
                * @type {number}
                * @alias ejTile#badge->minValue
                * @example 
                * // Set minValue on initialization. 
                * // To set minValue API value 
                * &lt;div id="tile" &gt;&lt;/div&gt;<br>
                * &lt;script&gt; 
                * // Create Tile control 
                * $("#tile").ejTile({ imageUrl: "themes/sample/tile/people.png", badge: { enabled: true, value:3, minValue:5 }}); 
                * &lt;/script&gt;
                * @example 
                * //Get or set the minValue, after initialization:<br>
                * // Get the minValue API value.
                *  $("#tile").ejTile("option", "badge.minValue");			
                * // Set the minValue API
                * $("#tile").ejTile("option", "badge.minValue", 5);            
                * @memberof ejTile
                * @instance
                */

                //Mobile
                /**	
                * Specifies minimum value for tile badge.
                * @default 1
                * @member badge->minValue {object}
                * @type {number}
                * @alias ejmTile#badge->minValue
                * @example 
                * //Set the minValue property in unobtrusive way.
                * &lt;div id="tile" data-role="ejmtile" data-ej-imageurl="people.png" data-ej-imagepath="themes/sample/tile" data-ej-badge-enabled="true" data-ej-badge-value="3" data-ej-badge-minvalue="5"&gt;
                * &lt;/div&gt;  
                * @example 
                * // Set minValue on initialization. 
                * // To set minValue API value 
                * &lt;div id="tile" &gt;&lt;/div&gt;<br>
                * &lt;script&gt; 
                * // Create Tile control 
                * $("#tile").ejmTile({ imageUrl: "people.png", badge: { enabled: true, value:3, minValue:5 } ,imagePath="themes/sample/tile"}); 
                * &lt;/script&gt;
                * @example 
                * //Get or set the minValue, after initialization:<br>
                * // Get the minValue API value.
                *  $("#tile").ejmTile("option", "badge.minValue");			
                * // Set the minValue API
                * $("#tile").ejmTile("option", "badge.minValue", 5);            
                * @memberof ejmTile
                * @instance
                */
                minValue: 1,
                //Web
                /**	
                * Specifies text instead of number for tile badge.
                * @default null
                * @member badge->text {object}
                * @type {string}
                * @alias ejTile#badge->text
                * @example 
                * // Set text on initialization. 
                * // To set text API value 
                * &lt;div id="tile" &gt;&lt;/div&gt;<br>
                * &lt;script&gt; 
                * // Create Tile control 
                * $("#tile").ejTile({imageUrl: "themes/sample/tile/people.png", badge: { enabled: true, text:"ten" } }); 
                * &lt;/script&gt;
                * @example 
                * //Get or set the badge text, after initialization:<br>
                * // Get the badge text API value.
                *  $("#tile").ejTile("option", "badge.text");			
                * // Set the badge text API
                * $("#tile").ejTile("option", "badge.text", "ten");            
                * @memberof ejTile
                * @instance
                */

                //Mobile
                /**	
                * Specifies text instead of number for tile badge.
                * @default null
                * @member badge->text {object}
                * @type {string}
                * @alias ejmTile#badge->text
                * @example 
                * //Set the text property in unobtrusive way.
                * &lt;div id="tile" data-role="ejmtile" data-ej-imageurl="people.png" data-ej-imagepath="themes/sample/tile" data-ej-badge-enabled="true" data-ej-badge-text="ten"&gt;
                * &lt;/div&gt;  
                * @example 
                * // Set text on initialization. 
                * // To set text API value 
                * &lt;div id="tile" &gt;&lt;/div&gt;<br>
                * &lt;script&gt; 
                * // Create Tile control 
                * $("#tile").ejmTile({ imageUrl: "people.png", badge: { enabled: true, text:"ten" } ,imagePath:"themes/sample/tile"}); 
                * &lt;/script&gt;
                * @example 
                * //Get or set the badge text, after initialization:<br>
                * // Get the badge text API value.
                *  $("#tile").ejmTile("option", "badge.text");			
                * // Set the badge text API
                * $("#tile").ejmTile("option", "badge.text", "ten");            
                * @memberof ejmTile
                * @instance
                */
                text: null
            },
            //Web
            /**		
            * Specifies the tile caption in outside template content.
            * @default null
            * @member captionTemplateId {object}
            * @type {string}
            * @example 
            * // Set captionTemplateId on initialization. 
            * // To set captionTemplateId API value 
            * &lt;div id="tile" &gt;&lt;/div&gt;<br>
            * &lt;div id="sample" &gt; Settings
            * &lt;/div&gt;
            * &lt;script&gt; 
            * // Create Tile control 
            * $("#tile").ejTile({ imageUrl: "themes/sample/tile/people.png", captionTemplateId: "sample"}); 
            * &lt;/script&gt;
            * @example 
            * //Get or set the captionTemplateId, after initialization:<br>
            * // Get the captionTemplateId API value.
            *  $("#tile").ejTile("option", "captionTemplateId");			
            * // Set the captionTemplateId API
            * $("#tile").ejTile("option", "captionTemplateId", "sample");            
            * @memberof ejTile
            * @instance
            */

            //Mobile
            /**		
            * Specifies the tile text in outside template content.
            * @default null
            * @member captionTemplateId {object}
            * @type {string}
            * @example 
            * //Set the captionTemplateId property in unobtrusive way.
            * &lt;div id="tile" data-role="ejmtile" data-ej-imageurl="people.png" data-ej-imagepath="themes/sample/tile" data-ej-captiontemplateid="sample" &gt;
            * &lt;/div&gt; 
            * &lt;div id="sample" &gt; Settings
            * &lt;/div&gt;
            * @example 
            * // Set captionTemplateId on initialization. 
            * // To set captionTemplateId API value 
            * &lt;div id="tile" &gt;&lt;/div&gt;<br>
            * &lt;div id="sample" &gt; Settings
            * &lt;/div&gt;
            * &lt;script&gt; 
            * // Create Tile control 
            * $("#tile").ejmTile({ imageUrl: "people.png", captionTemplateId: "sample",imagePath:"themes/sample/tile"}); 
            * &lt;/script&gt;
            * @example 
            * //Get or set the captionTemplateId, after initialization:<br>
            * // Get the captionTemplateId API value.
            *  $("#tile").ejmTile("option", "captionTemplateId");			
            * // Set the captionTemplateId API
            * $("#tile").ejmTile("option", "captionTemplateId", "sample");            
            * @memberof ejmTile
            * @instance
            */
            captionTemplateId: null,
            //Web
            /**		
            * Saves current model value to browser cookies for state maintains. While refreshing the page retains the model value applies from browser cookies.
            * @default false
            * @member enablePersistence {object}
            * @type {boolean}
            * @example 
            * // Set enablePersistence on initialization. 
            * // To set enablePersistence API value 
            * &lt;div id="tile" &gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // Create Tile control 
            * $("#tile").ejTile({ imageUrl: "themes/sample/tile/people.png", enablePersistence:true}); 
            * &lt;/script&gt;
            * @example 
            * //Get or set the enablePersistence, after initialization:<br>
            * // Get the enablePersistence API value.
            *  $("#tile").ejTile("option", "enablePersistence");			
            * // Set the enablePersistence API
            * $("#tile").ejTile("option", "enablePersistence", true);            
            * @memberof ejTile
            * @instance
            */

            //Mobile
            /**		
            * Saves current model value to browser cookies for state maintains. While refreshing the page retains the model value applies from browser cookies.
            * @default false
            * @member enablePersistence {object}
            * @type {boolean}
            * @example 
            * //Set the enablePersistence property in unobtrusive way.
            * &lt;div id="tile" data-role="ejmtile"  data-ej-imageurl="people.png" data-ej-imagepath="themes/sample/tile" data-ej-enablepersistence="true"&gt;
            * &lt;/div&gt;  
            * @example 
            * // Set enablePersistence on initialization. 
            * // To set enablePersistence API value 
            * &lt;div id="tile" &gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // Create Tile control 
            * $("#tile").ejmTile({ imageUrl: "people.png", enablePersistence:true,imagePath:"themes/sample/tile" }); 
            * &lt;/script&gt;
            * @example 
            * //Get or set the enablePersistence, after initialization:<br>
            * // Get the enablePersistence API value.
            *  $("#tile").ejmTile("option", "enablePersistence");			
            * // Set the enablePersistence API
            * $("#tile").ejmTile("option", "enablePersistence", true);            
            * @memberof ejmTile
            * @instance
            */
            enablePersistence: false,
            //Web
            /**		
            * Specifies Tile imageclass, using this property we can give images for each tile through css classes.
            * @default null
            * @member imageClass {object}
            * @type {string}
            * @example 
            * // Set imageClass on initialization. 
            * // To set imageClass API value 
            * &lt;div id="tile" &gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // Create Tile control 
            * $("#tile").ejTile({ imageClass: "sample"}); 
            * &lt;/script&gt;
            * &lt;style&gt;
            * .sample
            * {
            * background-image:url("themes/sample/tile/people.png");
            * }
            * &lt;/style&gt;
            * @example 
            * //Get or set the imageClass, after initialization:<br>
            * // Get the imageClass API value.
            *  $("#tile").ejTile("option", "imageClass");			
            * // Set the imageClass API
            * $("#tile").ejTile("option", "imageClass", "sample");            
            * @memberof ejTile
            * @instance
            */

            //Mobile
            /**		
            * Specifies Tile imageclass, using this property we can give images for each tile through css classes.
            * @default null
            * @member imageClass {object}
            * @type {string}
            * @example 
            * //Set the imageClass property in unobtrusive way.
            * &lt;div id="tile" data-role="ejmtile" data-ej-imageclass="sample"&gt;
            * &lt;/div&gt;  
            * &lt;style&gt;
            * .sample
            * {
            * background-image:url("themes/sample/tile/ios7/people.png");
            * }
            * &lt;/style&gt;
            * @example 
            * // Set imageClass on initialization. 
            * // To set imageClass API value 
            * &lt;div id="tile" &gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // Create Tile control 
            * $("#tile").ejmTile({ imageClass: "sample" }); 
            * &lt;/script&gt;
            * &lt;style&gt;
            * .sample
            * {
            * background-image:url("themes/sample/tile/ios7/people.png");
            * }
            * &lt;/style&gt;
            * @example 
            * //Get or set the imageClass, after initialization:<br>
            * // Get the imageClass API value.
            *  $("#tile").ejmTile("option", "imageClass");			
            * // Set the imageClass API
            * $("#tile").ejmTile("option", "imageClass", "sample");            
            * @memberof ejmTile
            * @instance
            */
            imageClass: null,
            //Web
            /**		
            * Specifies the position of tile image.
            * @default "center"
            * @member imagePosition {object}
            * @type {enum}
            * @example 
            * // Set imagePosition on initialization. 
            * // To set imagePosition API value 
            * &lt;div id="tile" &gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // Create Tile control 
            * $("#tile").ejTile({ imageUrl: "themes/sample/tile/people.png", imagePosition: "right"}); 
            * &lt;/script&gt;
            * @example 
            * //Get or set the imagePosition, after initialization:<br>
            * // Get the imagePosition API value.
            *  $("#tile").ejTile("option", "imagePosition");			
            * // Set the imagePosition API
            * $("#tile").ejTile("option", "imagePosition", "right");            
            * @memberof ejTile
            * @instance
            */

            //Mobile
            /**		
            * Specifies the position of tile image.
            * @default "center"
            * @member imagePosition {object}
            * @type {enum}
            * @example 
            * //Set the imagePosition property in unobtrusive way.
            * &lt;div id="tile" data-role="ejmtile" data-ej-imageurl="people.png" data-ej-imagepath="themes/sample/tile" data-ej-imageposition="right"&gt;
            * &lt;/div&gt;  
            * @example 
            * // Set imagePosition on initialization. 
            * // To set imagePosition API value 
            * &lt;div id="tile" &gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // Create Tile control 
            * $("#tile").ejmTile({ imageUrl: "people.png", imagePosition: "right" ,imagePath:"themes/sample/tile"}); 
            * &lt;/script&gt;
            * @example 
            * //Get or set the imagePosition, after initialization:<br>
            * // Get the imagePosition API value.
            *  $("#tile").ejmTile("option", "imagePosition");			
            * // Set the imagePosition API
            * $("#tile").ejmTile("option", "imagePosition", "right");            
            * @memberof ejmTile
            * @instance
            */
            imagePosition: "center",
            //Web
            /**		
            * Specifies the tile image in outside template content.
            * @default null
            * @member imageTemplateId {object}
            * @type {string}
            * @example 
            * // Set imageTemplateId on initialization. 
            * // To set imageTemplateId API value 
            * &lt;div id="tile" &gt;&lt;/div&gt;<br>
            * &lt;div id="sample" style="background-image: url('themes/sample/tile/people.png');height:100%;width:100%;"&gt;
            * &lt;/div&gt;
            * &lt;script&gt; 
            * // Create Tile control 
            * $("#tile").ejTile({ imageTemplateId: "sample" }); 
            * &lt;/script&gt;
            * @example 
            * //Get or set the imageTemplateId, after initialization:<br>
            * // Get the imageTemplateId API value.
            *  $("#tile").ejTile("option", "imageTemplateId");			
            * // Set the imageTemplateId API
            * $("#tile").ejTile("option", "imageTemplateId", "sample");            
            * @memberof ejTile
            * @instance
            */

            //Mobile
            /**		
            * Specifies the tile image in outside template content.
            * @default null
            * @member imageTemplateId {object}
            * @type {string}
            * @example 
            * //Set the imageTemplateId property in unobtrusive way.
            * &lt;div id="tile" data-role="ejmtile" data-ej-imagetemplateid="sample" &gt;
            * &lt;/div&gt; 
            * &lt;div id="sample" style="background-image: url('themes/sample/tile/ios7/people.png');height:100%;width:100%;"&gt;
            * &lt;/div&gt;
            * @example 
            * // Set imageTemplateId on initialization. 
            * // To set imageTemplateId API value 
            * &lt;div id="tile" &gt;&lt;/div&gt;<br>
            * &lt;div id="sample" style="background-image: url('themes/sample/tile/ios7/people.png');height:100%;width:100%;"&gt;
            * &lt;/div&gt;
            * &lt;script&gt; 
            * // Create Tile control 
            * $("#tile").ejmTile({ imageTemplateId: "sample" }); 
            * &lt;/script&gt;
            * @example 
            * //Get or set the imageTemplateId, after initialization:<br>
            * // Get the imageTemplateId API value.
            *  $("#tile").ejmTile("option", "imageTemplateId");			
            * // Set the imageTemplateId API
            * $("#tile").ejmTile("option", "imageTemplateId", "sample");            
            * @memberof ejmTile
            * @instance
            */
            imageTemplateId: null,
            //Web
            /**		
            * Specifies the file name of tile image.
            * @default null
            * @member imageUrl {object}
            * @type {string}
            * @example 
            * // Set imageUrl on initialization. 
            * // To set imageUrl API value 
            * &lt;div id="tile" &gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // Create Tile control 
            * $("#tile").ejTile({ imageUrl: "themes/sample/tile/people.png"}); 
            * &lt;/script&gt;
            * @example 
            * //Get or set the imageUrl, after initialization:<br>
            * // Get the imageUrl API value.
            *  $("#tile").ejTile("option", "imageUrl");			
            * // Set the imageUrl API
            * $("#tile").ejTile("option", "imageUrl", "themes/sample/tile/people.png");            
            * @memberof ejTile
            * @instance
            */

            //Mobile
            /**		
            * Specifies the file name of tile image.
            * @default null
            * @member imageUrl {object}
            * @type {string}
            * @example 
            * //Set the imageUrl property in unobtrusive way.
            * &lt;div id="tile" data-role="ejmtile" data-ej-imagepath="themes/sample/tile" data-ej-imageurl="people.png"&gt;
            * &lt;/div&gt;  
            * @example 
            * // Set imageUrl on initialization. 
            * // To set imageUrl API value 
            * &lt;div id="tile" &gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // Create Tile control 
            * $("#tile").ejmTile({ imageUrl: "people.png",imagePath:"themes/sample/tile" }); 
            * &lt;/script&gt;
            * @example 
            * //Get or set the imageUrl, after initialization:<br>
            * // Get the imageUrl API value.
            *  $("#tile").ejmTile("option", "imageUrl");			
            * // Set the imageUrl API
            * $("#tile").ejmTile("option", "imageUrl", "people.png");            
            * @memberof ejmTile
            * @instance
            */
            imageUrl: null,
            /**		
            * Section for livetile specific functionalities.                      
            * @memberof ejTile
            * @member livetile {object}
            * @instance
            */

            /**		
            * Section for livetile specific functionalities.                      
            * @memberof ejmTile
            * @member livetile {object}
            * @instance
            */
            liveTile: {
                //Web
                /**	
                * Specifies whether to enable livetile or not.
                * @default false
                * @member livetile->enabled {object}
                * @type {boolean}
                * @alias ejTile#livetile->enabled
                * @example 
                * // Set liveTile enabled on initialization. 
                * // To set liveTile enabled API value 
                * &lt;div id="tile" &gt;&lt;/div&gt;<br>
                * &lt;script&gt; 
                * // Create Tile control 
                * $("#tile").ejTile({ renderMode:"windows", liveTile: { enabled: true, imageUrl:['themes/sample/tile/people.png','themes/sample/tile/sports.png'] } }); 
                * &lt;/script&gt;
                * @example 
                * //Get or set the liveTile enabled, after initialization:<br>
                * // Get the liveTile enabled API value.
                *  $("#tile").ejTile("option", "liveTile.enabled");			
                * // Set the liveTile enabled API
                * $("#tile").ejTile("option", "liveTile.enabled", true);            
                * @memberof ejTile
                * @instance
                */

                //Mobile
                /**	
                * Specifies whether to enable livetile or not.
                * @default false
                * @member livetile->enabled {object}
                * @type {boolean}
                * @alias ejmTile#livetile->enabled
                * @example 
                * //Set the liveTile enabled property in unobtrusive way.
                * &lt;div id="tile" data-role="ejmtile" data-ej-rendermode="windows" data-ej-imagepath="themes/sample/tile" data-ej-livetile-imageurl="['people.png','sports.png']" data-ej-livetile-enabled="true" data-ej-backgroundcolor="blue" &gt;
                * &lt;/div&gt;  
                * @example 
                * // Set liveTile enabled on initialization. 
                * // To set liveTile enabled API value 
                * &lt;div id="tile" &gt;&lt;/div&gt;<br>
                * &lt;script&gt; 
                * // Create Tile control 
                * $("#tile").ejmTile({ renderMode:"windows", liveTile: { enabled: true, imageUrl:['people.png','sports.png'] },imagePath:"themes/sample/tile",backgroundColor:"blue" }); 
                * &lt;/script&gt;
                * @example 
                * //Get or set the liveTile enabled, after initialization:<br>
                * // Get the liveTile enabled API value.
                *  $("#tile").ejmTile("option", "liveTile.enabled");			
                * // Set the liveTile enabled API
                * $("#tile").ejmTile("option", "liveTile.enabled", true);            
                * @memberof ejmTile
                * @instance
                */
                enabled: false,
                //Web
                /**	
                * Specifies liveTile images in css classes.
                * @default null
                * @member livetile->imageClass {object}
                * @type {string}
                * @alias ejTile#liveTile->imageClass
                * @example 
                * // Set liveTile imageClass on initialization. 
                * // To set liveTile imageClass API value 
                * &lt;div id="tile" &gt;&lt;/div&gt;<br>
                * &lt;script&gt; 
                * // Create Tile control 
                * $("#tile").ejTile({ renderMode:"windows", liveTile: { enabled: true, imageClass: ['img1','img2','img3'] } }); 
                * &lt;/script&gt;
                * &lt;style&gt;
                * .img1
                * {
                * background-image:url("themes/sample/tile/people.png");
                * }
                * .img2
                * {
                * background-image:url("themes/sample/tile/sports.png");
                * }
                * .img3
                * {
                * background-image:url("themes/sample/tile/people_1.png");
                * }
                * &lt;/style&gt;
                * @example 
                * //Get or set the liveTile imageClass, after initialization:<br>
                * // Get the liveTile imageClass API value.
                *  $("#tile").ejTile("option", "liveTile.imageClass");			
                * // Set the liveTile imageClass API
                * $("#tile").ejTile("option", "liveTile.imageClass", ['img1','img2','img3']);            
                * @memberof ejTile
                * @instance
                */

                //Mobile
                /**	
                * Specifies liveTile images in css classes.
                * @default null
                * @member livetile->imageClass {object}
                * @type {string}
                * @alias ejmTile#liveTile->imageClass
                * @example 
                * //Set the liveTile imageClass property in unobtrusive way.
                * &lt;div id="tile" data-role="ejmtile" data-ej-rendermode="windows" data-ej-livetile-imageclass="['img1','img2','img3']" data-ej-livetile-enabled="true" data-ej-backgroundcolor="blue" &gt;
                * &lt;/div&gt;  
                * &lt;style&gt;
                * .img1
                * {
                * background-image:url("themes/sample/tile/windows/people.png");
                * }
                * .img2
                * {
                * background-image:url("themes/sample/tile/windows/sports.png");
                * }
                * .img3
                * {
                * background-image:url("themes/sample/tile/windows/people_1.png");
                * }
                * &lt;/style&gt;
                * @example 
                * // Set liveTile imageClass on initialization. 
                * // To set liveTile imageClass API value 
                * &lt;div id="tile" &gt;&lt;/div&gt;<br>
                * &lt;script&gt; 
                * // Create Tile control 
                * $("#tile").ejmTile({ renderMode:"windows", liveTile: { enabled: true, imageClass: ['img1','img2','img3'] },backgroundColor:"blue" }); 
                * &lt;/script&gt;
                * &lt;style&gt;
                * .img1
                * {
                * background-image:url("themes/sample/tile/windows/people.png");
                * }
                * .img2
                * {
                * background-image:url("themes/sample/tile/windows/sports.png");
                * }
                * .img3
                * {
                * background-image:url("themes/sample/tile/windows/people_1.png");
                * }
                * &lt;/style&gt;
                * @example 
                * //Get or set the liveTile imageClass, after initialization:<br>
                * // Get the liveTile imageClass API value.
                *  $("#tile").ejmTile("option", "liveTile.imageClass");			
                * // Set the liveTile imageClass API
                * $("#tile").ejmTile("option", "liveTile.imageClass", ['img1','img2','img3']);            
                * @memberof ejmTile
                * @instance
                */
                imageClass: null,
                //Web
                /**	
                * Specifies liveTile images in templates.
                * @default null
                * @member livetile->imageTemplateId {object}
                * @type {string}
                * @alias ejTile#liveTile->imageTemplateId
                * @example 
                * // Set liveTile imageTemplateId on initialization. 
                * // To set liveTile imageTemplateId API value 
                * &lt;div id="tile" &gt;&lt;/div&gt;<br>
                * &lt;div id="img1" style="background-image: url('themes/sample/tile/people.png');height:100%;width:100%;"&gt;
                * &lt;/div&gt;
                * &lt;div id="img2" style="background-image: url('themes/sample/tile/sports.png');height:100%;width:100%;"&gt;
                * &lt;/div&gt;
                * &lt;div id="img3" style="background-image: url('themes/sample/tile/settings.png');height:100%;width:100%;"&gt;
                * &lt;/div&gt;
                * &lt;script&gt; 
                * // Create Tile control 
                * $("#tile").ejTile({ renderMode:"windows", liveTile: { enabled: true, imageTemplateId: ['img1','img2','img3'] } }); 
                * &lt;/script&gt;
                * @example 
                * //Get or set the liveTile imageTemplateId, after initialization:<br>
                * // Get the liveTile imageTemplateId API value.
                *  $("#tile").ejTile("option", "liveTile.imageTemplateId");			
                * // Set the liveTile imageTemplateId API
                * $("#tile").ejTile("option", "liveTile.imageTemplateId", ['img1','img2','img3']);            
                * @memberof ejTile
                * @instance
                */

                //Mobile
                /**	
                * Specifies liveTile images in templates.
                * @default null
                * @member livetile->imageTemplateId {object}
                * @type {string}
                * @alias ejmTile#liveTile->imageTemplateId
                * @example 
                * //Set the liveTile imageTemplateId property in unobtrusive way.
                * &lt;div id="tile" data-role="ejmtile" data-ej-rendermode="windows" data-ej-livetile-imagetemplateid="['img1','img2','img3']" data-ej-livetile-enabled="true" data-ej-backgroundcolor="blue" &gt;
                * &lt;/div&gt;
                * &lt;div id="img1" style="background-image: url('themes/sample/tile/windows/people.png');height:100%;width:100%;"&gt;
                * &lt;/div&gt;
                * &lt;div id="img2" style="background-image: url('themes/sample/tile/windows/sports.png');height:100%;width:100%;"&gt;
                * &lt;/div&gt;
                * &lt;div id="img3" style="background-image: url('themes/sample/tile/windows/settings.png');height:100%;width:100%;"&gt;
                * &lt;/div&gt;                
                * @example 
                * // Set liveTile imageTemplateId on initialization. 
                * // To set liveTile imageTemplateId API value 
                * &lt;div id="tile" &gt;&lt;/div&gt;<br>
                * &lt;div id="img1" style="background-image: url('themes/sample/tile/windows/people.png');height:100%;width:100%;"&gt;
                * &lt;/div&gt;
                * &lt;div id="img2" style="background-image: url('themes/sample/tile/windows/sports.png');height:100%;width:100%;"&gt;
                * &lt;/div&gt;
                * &lt;div id="img3" style="background-image: url('themes/sample/tile/windows/settings.png');height:100%;width:100%;"&gt;
                * &lt;/div&gt;
                * &lt;script&gt; 
                * // Create Tile control 
                * $("#tile").ejmTile({ renderMode:"windows", liveTile: { enabled: true, imageTemplateId: ['img1','img2','img3'] },backgroundColor:"blue" }); 
                * &lt;/script&gt;
                * @example 
                * //Get or set the liveTile imageTemplateId, after initialization:<br>
                * // Get the liveTile imageTemplateId API value.
                *  $("#tile").ejmTile("option", "liveTile.imageTemplateId");			
                * // Set the liveTile imageTemplateId API
                * $("#tile").ejmTile("option", "liveTile.imageTemplateId", ['img1','img2','img3']);            
                * @memberof ejmTile
                * @instance
                */
                imageTemplateId: null,
                //Web
                /**	
                * Specifies liveTile images in css classes.
                * @default null
                * @member livetile->imageUrl {object}
                * @type {string}
                * @alias ejTile#liveTile->imageUrl               
                * @example 
                * // Set liveTile imageUrl on initialization. 
                * // To set liveTile imageUrl API value 
                * &lt;div id="tile" &gt;&lt;/div&gt;<br>
                * &lt;script&gt; 
                * // Create Tile control 
                * $("#tile").ejTile({ renderMode: "windows", livetile: { enabled: true, imageUrl: ['themes/sample/tile/people.png','themes/sample/tile/sports.png','themes/sample/tile/settings.png'] } }); 
                * &lt;/script&gt;
                * @example 
                * //Get or set the liveTile imageUrl, after initialization:<br>
                * // Get the liveTile imageUrl API value.
                *  $("#tile").ejTile("option", "liveTile.imageUrl");			
                * // Set the liveTile imageUrl API
                * $("#tile").ejTile("option", "liveTile.imageUrl", ['themes/sample/tile/people.png','themes/sample/tile/sports.png','themes/sample/tile/settings.png']);            
                * @memberof ejTile
                * @instance
                */

                //Mobile
                /**	
                * Specifies liveTile images in css classes.
                * @default null
                * @member livetile->imageUrl {object}
                * @type {string}
                * @alias ejmTile#liveTile->imageUrl
                * @example 
                * //Set the liveTile imageUrl property in unobtrusive way.
                * &lt;div id="tile" data-role="ejmtile" data-ej-backgroundcolor="blue" data-ej-rendermode="windows" data-ej-livetile-enabled="true" data-ej-imagepath="themes/sample/tile" data-ej-livetile-imageurl="['people.png','sports.png','settings.png']"  &gt;
                * &lt;/div&gt;  
                * @example 
                * // Set liveTile imageUrl on initialization. 
                * // To set liveTile imageUrl API value 
                * &lt;div id="tile" &gt;&lt;/div&gt;<br>
                * &lt;script&gt; 
                * // Create Tile control 
                * $("#tile").ejmTile({ backgroundColor:"blue",renderMode: "windows", liveTile: { enabled: true, imageUrl: ['people.png','sports.png','settings.png'] },imagePath:"themes/sample/tile" }); 
                * &lt;/script&gt;
                * @example 
                * //Get or set the liveTile imageUrl, after initialization:<br>
                * // Get the liveTile imageUrl API value.
                *  $("#tile").ejmTile("option", "liveTile.imageUrl");			
                * // Set the liveTile imageUrl API
                * $("#tile").ejmTile("option", "liveTile.imageUrl", ['people.png','sports.png','settings.png']);            
                * @memberof ejmTile
                * @instance
                */
                imageUrl: null,
                //Web
                /**	
                * Specifies liveTile type for Tile. i.e flip, slide or carousel
                * @default "flip"
                * @member livetile->type {object}
                * @type {enum}
                * @alias ejTile#liveTile->type             
                * @example 
                * // Set liveTile type on initialization. 
                * // To set liveTile type API value 
                * &lt;div id="tile" &gt;&lt;/div&gt;<br>
                * &lt;script&gt; 
                * // Create Tile control 
                * $("#tile").ejTile({ renderMode: "windows", liveTile: { enabled: true, imageUrl: ['themes/sample/tile/people.png','themes/sample/tile/sports.png','themes/sample/tile/settings.png'], type:"carousel" } }); 
                * &lt;/script&gt;
                * @example 
                * //Get or set the liveTile type, after initialization:<br>
                * // Get the liveTile type API value.
                *  $("#tile").ejTile("option", "liveTile.type");			
                * // Set the liveTile type API
                * $("#tile").ejTile("option", "liveTile.type", "carousel");            
                * @memberof ejTile
                * @instance
                */

                //Mobile
                /**	
                * Specifies liveTile type for Tile. i.e flip, slide or carousel
                * @default "flip"
                * @member livetile->type {object}
                * @type {enum}
                * @alias ejmTile#liveTile->type
                * @example 
                * //Set the liveTile type property in unobtrusive way.
                * &lt;div id="tile" data-role="ejmtile" data-ej-rendermode="windows" data-ej-backgroundcolor="blue" data-ej-imagepath="themes/sample/tile" data-ej-livetile-enabled="true" data-ej-livetile-imageurl="['people.png','sports.png','settings.png']"  data-ej-livetile-type="carousel"&gt;
                * &lt;/div&gt;  
                * @example 
                * // Set liveTile type on initialization. 
                * // To set liveTile type API value 
                * &lt;div id="tile" &gt;&lt;/div&gt;<br>
                * &lt;script&gt; 
                * // Create Tile control 
                * $("#tile").ejmTile({backgroundColor:"blue", renderMode: "windows", liveTile: { enabled: true, imageUrl: ['people.png','sports.png','settings.png'], type:"carousel" },imagePath:"themes/sample/tile" }); 
                * &lt;/script&gt;
                * @example 
                * //Get or set the liveTile type, after initialization:<br>
                * // Get the liveTile type API value.
                *  $("#tile").ejmTile("option", "liveTile.type");			
                * // Set the liveTile type API
                * $("#tile").ejmTile("option", "liveTile.type", "carousel");            
                * @memberof ejmTile
                * @instance
                */
                type: "flip",
                //Web
                /**	
                * Specifies time interval between two successive livetile animation
                * @default 2000
                * @member livetile->updateInterval {object}
                * @type {number}
                * @alias ejTile#liveTile->updateInterval       
                * @example 
                * // Set liveTile updateInterval on initialization. 
                * // To set liveTile updateInterval API value 
                * &lt;div id="tile" &gt;&lt;/div&gt;<br>
                * &lt;script&gt; 
                * // Create Tile control 
                * $("#tile").ejTile({renderMode: "windows", liveTile: { enabled: true, imageUrl: ['themes/sample/tile/people.png','themes/sample/tile/sports.png','themes/sample/tile/settings.png'], updateInterval:1000 } }); 
                * &lt;/script&gt;
                * @example 
                * //Get or set the liveTile updateInterval, after initialization:<br>
                * // Get the liveTile updateInterval API value.
                *  $("#tile").ejTile("option", "liveTile.updateInterval");			
                * // Set the liveTile updateInterval API
                * $("#tile").ejTile("option", "liveTile.updateInterval", 1000);            
                * @memberof ejTile
                * @instance
                */

                //Mobile
                /**	
                * Specifies time interval between two successive livetile animation
                * @default 2000
                * @member livetile->updateInterval {object}
                * @type {number}
                * @alias ejmTile#liveTile->updateInterval
                * @example 
                * //Set the liveTile updateInterval property in unobtrusive way.
                * &lt;div id="tile" data-role="ejmtile" data-ej-rendermode="windows" data-ej-backgroundcolor="blue" data-ej-imagepath="themes/sample/tile" data-ej-livetile-enabled="true" data-ej-livetile-imageurl="['people.png','sports.png','settings.png']"  data-ej-livetile-updateinterval=1000&gt;
                * &lt;/div&gt;  
                * @example 
                * // Set liveTile updateInterval on initialization. 
                * // To set liveTile updateInterval API value 
                * &lt;div id="tile" &gt;&lt;/div&gt;<br>
                * &lt;script&gt; 
                * // Create Tile control 
                * $("#tile").ejmTile({ backgroundColor:"blue",renderMode: "windows", liveTile: { enabled: true, imageUrl: ['people.png','sports.png','settings.png'], updateInterval:1000 },imagePath:"themes/sample/tile" }); 
                * &lt;/script&gt;
                * @example 
                * //Get or set the liveTile updateInterval, after initialization:<br>
                * // Get the liveTile updateInterval API value.
                *  $("#tile").ejmTile("option", "liveTile.updateInterval");			
                * // Set the liveTile updateInterval API
                * $("#tile").ejmTile("option", "liveTile.updateInterval", 1000);            
                * @memberof ejmTile
                * @instance
                */
                updateInterval: 2000
            },
            //Web
            /**		
            * Specifies whether the tile text to be shown or hidden.
            * @default true
            * @member showText {object}
            * @type {boolean}        
            * @example 
            * // Set showText on initialization. 
            * // To set showText API value 
            * &lt;div id="tile" &gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // Create Tile control 
            * $("#tile").ejTile({ imageUrl: "themes/sample/tile/people.png", showText:false }); 
            * &lt;/script&gt;
            * @example 
            * //Get or set the showText, after initialization:<br>
            * // Get the showText API value.
            *  $("#tile").ejTile("option", "showText");			
            * // Set the showText API
            * $("#tile").ejTile("option", "showText", false);            
            * @memberof ejTile
            * @instance
            */

            //Mobile
            /**		
            * Specifies whether the tile text to be shown or hidden.
            * @default true
            * @member showText {object}
            * @type {boolean}
            * @example 
            * //Set the showText property in unobtrusive way.
            * &lt;div id="tile" data-role="ejmtile" data-ej-imagepath="themes/sample/tile"  data-ej-imageurl="people.png" data-ej-showtext=false&gt;
            * &lt;/div&gt;  
            * @example 
            * // Set showText on initialization. 
            * // To set showText API value 
            * &lt;div id="tile" &gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // Create Tile control 
            * $("#tile").ejmTile({ imageUrl: "people.png", showText:false,imagePath:"themes/sample/tile" }); 
            * &lt;/script&gt;
            * @example 
            * //Get or set the showText, after initialization:<br>
            * // Get the showText API value.
            *  $("#tile").ejmTile("option", "showText");			
            * // Set the showText API
            * $("#tile").ejmTile("option", "showText", false);            
            * @memberof ejmTile
            * @instance
            */
            showText: true,
            //Web
            /**		
            * Changes the text of a tile.
            * @default "Text"
            * @member text {object}
            * @type {string}           
            * @example 
            * // Set text on initialization. 
            * // To set text API value 
            * &lt;div id="tile" &gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // Create Tile control 
            * $("#tile").ejTile({ imageUrl: "themes/sample/tile/people.png", text:"Settings"}); 
            * &lt;/script&gt;
            * @example 
            * //Get or set the text, after initialization:<br>
            * // Get the text API value.
            *  $("#tile").ejTile("option", "text");			
            * // Set the text API
            * $("#tile").ejTile("option", "text", "Settings");            
            * @memberof ejTile
            * @instance
            */

            //Mobile
            /**		
            * Changes the text of a tile.
            * @default "Text"
            * @member text {object}
            * @type {string}
            * @example 
            * //Set the text property in unobtrusive way.
            * &lt;div id="tile" data-role="ejmtile" data-ej-imageurl="people.png" data-ej-imagepath="themes/sample/tile" data-ej-text="Settings"&gt;
            * &lt;/div&gt;  
            * @example 
            * // Set text on initialization. 
            * // To set text API value 
            * &lt;div id="tile" &gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // Create Tile control 
            * $("#tile").ejmTile({ imageUrl: "people.png", text:"Settings",imagePath:"themes/sample/tile" }); 
            * &lt;/script&gt;
            * @example 
            * //Get or set the text, after initialization:<br>
            * // Get the text API value.
            *  $("#tile").ejmTile("option", "text");			
            * // Set the text API
            * $("#tile").ejmTile("option", "text", "Settings");            
            * @memberof ejmTile
            * @instance
            */
            text: "Text",
            //Web
            /**		
            * Aligns the text of a tile. i.e left, right or center.
            * @default "normal"
            * @member textAlignment {object}
            * @type {enum}      
            * @example 
            * // Set textAlignment on initialization. 
            * // To set textAlignment API value 
            * &lt;div id="tile" &gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // Create Tile control 
            * $("#tile").ejTile({ imageUrl: "themes/sample/tile/people.png", textAlignment:"left" }); 
            * &lt;/script&gt;
            * @example 
            * //Get or set the textAlignment, after initialization:<br>
            * // Get the textAlignment API value.
            *  $("#tile").ejTile("option", "textAlignment");			
            * // Set the textAlignment API
            * $("#tile").ejTile("option", "textAlignment", "left");            
            * @memberof ejTile
            * @instance
            */

            //Mobile
            /**		
            * Aligns the text of a tile. i.e left, right or center.
            * @default "normal"
            * @member textAlignment {object}
            * @type {enum}
            * @example 
            * //Set the textAlignment property in unobtrusive way.
            * &lt;div id="tile" data-role="ejmtile" data-ej-imageurl="people.png" data-ej-imagepath="themes/sample/tile" data-ej-textalignment="left"&gt;
            * &lt;/div&gt;  
            * @example 
            * // Set textAlignment on initialization. 
            * // To set textAlignment API value 
            * &lt;div id="tile" &gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // Create Tile control 
            * $("#tile").ejmTile({ imageUrl: "people.png", textAlignment:"left",imagePath:"themes/sample/tile" }); 
            * &lt;/script&gt;
            * @example 
            * //Get or set the textAlignment, after initialization:<br>
            * // Get the textAlignment API value.
            *  $("#tile").ejmTile("option", "textAlignment");			
            * // Set the textAlignment API
            * $("#tile").ejmTile("option", "textAlignment", "left");            
            * @memberof ejmTile
            * @instance
            */
            textAlignment: "normal",
            //Web
            /**		
            * Specifies the size of a tile. i.e small, medium, large or wide.
            * @default "small"
            * @member tileSize {object}
            * @type {enum}    
            * @example 
            * // Set tileSize on initialization. 
            * // To set tileSize API value 
            * &lt;div id="tile" &gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // Create Tile control 
            * $("#tile").ejTile({ imageUrl: "themes/sample/tile/people.png", tileSize:"medium" }); 
            * &lt;/script&gt;
            * @example 
            * //Get or set the tileSize, after initialization:<br>
            * // Get the tileSize API value.
            *  $("#tile").ejTile("option", "tileSize");			
            * // Set the tileSize API
            * $("#tile").ejTile("option", "tileSize", "medium");            
            * @memberof ejTile
            * @instance
            */

            //Mobile
            /**		
            * Specifies the size of a tile. i.e small, medium, large or wide.
            * @default "small"
            * @member tileSize {object}
            * @type {enum}
            * @example 
            * //Set the tileSize property in unobtrusive way.
            * &lt;div id="tile" data-role="ejmtile" data-ej-imageurl="people.png" data-ej-imagepath="themes/sample/tile" data-ej-tilesize="medium" data-ej-backgroundcolor="blue"&gt;
            * &lt;/div&gt;  
            * @example 
            * // Set tileSize on initialization. 
            * // To set tileSize API value 
            * &lt;div id="tile" &gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // Create Tile control 
            * $("#tile").ejmTile({ imageUrl: "people.png", tileSize:"medium",imagePath:"themes/sample/tile",backgroundColor:"blue" }); 
            * &lt;/script&gt;
            * @example 
            * //Get or set the tileSize, after initialization:<br>
            * // Get the tileSize API value.
            *  $("#tile").ejmTile("option", "tileSize");			
            * // Set the tileSize API
            * $("#tile").ejmTile("option", "tileSize", "medium");            
            * @memberof ejmTile
            * @instance
            */
            tileSize: "small",
            //Web
            /**		
            * Customize the tile size width.
            * @default "null"
            * @member width {object}
            * @type {number}             
            * @example 
            * // Set width on initialization. 
            * // To set width API value 
            * &lt;div id="tile" &gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // Create Tile control 
            * $("#tile").ejTile({ imageUrl: "themes/sample/tile/people.png", width:300,height:300 }); 
            * &lt;/script&gt;
            * @example 
            * //Get or set the width, after initialization:<br>
            * // Get the width API value.
            *  $("#tile").ejTile("option", "width");			
            * // Set the width API
            * $("#tile").ejTile("option", "width", 300);            
            * @memberof ejTile
            * @instance
            */

            //Mobile
            /**		
            * Customize the tile size width.
            * @default "null"
            * @member width {object}
            * @type {number}
            * @example 
            * //Set the width property in unobtrusive way.
            * &lt;div id="tile" data-role="ejmtile" data-ej-imageurl="people.png" data-ej-imagepath="themes/sample/tile" data-ej-height=300 data-ej-width=300 data-ej-backgroundcolor="blue"&gt;
            * &lt;/div&gt;  
            * @example 
            * // Set width on initialization. 
            * // To set width API value 
            * &lt;div id="tile" &gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // Create Tile control 
            * $("#tile").ejmTile({ imageUrl: "people.png", width:300, height:300, imagePath:"themes/sample/tile",backgroundColor:"blue" }); 
            * &lt;/script&gt;
            * @example 
            * //Get or set the width, after initialization:<br>
            * // Get the width API value.
            *  $("#tile").ejmTile("option", "width");			
            * // Set the width API
            * $("#tile").ejmTile("option", "width", 300);            
            * @memberof ejmTile
            * @instance
            */
            width: null,
            //Web
            /**		
            * Customize the tile size height.
            * @default "null"
            * @member height {object}
            * @type {number}            
            * @example 
            * // Set height on initialization. 
            * // To set height API value 
            * &lt;div id="tile" &gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // Create Tile control 
            * $("#tile").ejTile({ imageUrl: "themes/sample/tile/people.png", width:300, height:300 }); 
            * &lt;/script&gt;
            * @example 
            * //Get or set the height, after initialization:<br>
            * // Get the height API value.
            *  $("#tile").ejTile("option", "height");			
            * // Set the width API
            * $("#tile").ejTile("option", "height", 300);            
            * @memberof ejTile
            * @instance
            */

            //Mobile
            /**		
            * Customize the tile size height.
            * @default "null"
            * @member height {object}
            * @type {number}
            * @example 
            * //Set the height property in unobtrusive way.
            * &lt;div id="tile" data-role="ejmtile" data-ej-imageurl="people.png" data-ej-imagepath="themes/sample/tile" data-ej-height=300 data-ej-width=300 data-ej-backgroundcolor="blue"&gt;
            * &lt;/div&gt;  
            * @example 
            * // Set height on initialization. 
            * // To set height API value 
            * &lt;div id="tile" &gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // Create Tile control 
            * $("#tile").ejmTile({ imageUrl: "people.png", width:300,height:300 imagePath:"themes/sample/tile",backgroundColor:"blue" }); 
            * &lt;/script&gt;
            * @example 
            * //Get or set the height, after initialization:<br>
            * // Get the height API value.
            *  $("#tile").ejmTile("option", "height");			
            * // Set the height API
            * $("#tile").ejmTile("option", "height", 300);            
            * @memberof ejmTile
            * @instance
            */
            height: null
        },
        dataTypes: {
            badge: { enabled: "boolean", value: "number", maxValue: "number", minValue: "number" },
            imagePosition: "enum",
            liveTile: {
                type: "enum",
                enabled: "boolean",
                updateInterval: "number",
                imageUrl: "array",
                imageClass: "array",
                imageTemplateId: "array"
            },
            showText: "boolean",
            textAlignment: "enum",
            tileSize: "enum",
            width: "number",
            height: "number"
        },
        //Common method to render tile control
        _tileRender: function () {
            this.element.addClass(this._prefix + "tile " + this._prefix + "tile-wrapper " + this._prefix + "tile-wrapper-" + this.model.tileSize);
            this._mainTile = ej.buildTag("div." + this._prefix + "child-tile " + this._prefix + "tile-image" + this.model.imagePosition);
            this.model.liveTile.enabled && this.model.liveTile.type == "flip" ? this.element.addClass(this._prefix + 'tile-' + this.model.liveTile.type) : this.element.addClass(this._prefix + 'tile-common');
            this.element.append(this._mainTile);
            this._image = ej.buildTag("div." + this._prefix + "fontimage " + this._prefix + "tile-image " + this._prefix + "tile-image" + this.model.imagePosition);
            this._layer = ej.buildTag("div." + this._prefix + "layer");
            if (this.model.showText) {
                this.element.addClass(this._prefix + "enabled-text");
                this._text = ej.buildTag("div").addClass(this._prefix + "tile-text " + this._prefix + "user-select " + this._prefix + "textalign-" + this.model.textAlignment);
            }
            else
                this.element.removeClass(this._prefix + "enabled-text").addClass(this._prefix + "disabled-text");
            //Live Tile implementation
            if ((!this._isAppView() || this.model.renderMode == "windows") && this.model.liveTile.enabled) {
                this.element.addClass(this._prefix + "live-type-" + this.model.liveTile.type);
                this._mainTile.addClass(this._prefix + "live-tile-enable");
                if (!this._liveImageWrapper) {
                    this._liveImageWrapper = ej.buildTag("div." + this._prefix + "live-image-wrapper");
                    if (this.model.liveTile.imageTemplateId) {
                        this._liveImageWrapper.addClass(this._prefix + "fontimage " + this._prefix + "tile-image " + this._prefix + "tile-image" + this.model.imagePosition);
                        for (var i = 0; i < this.model.liveTile.imageTemplateId.length; i++) {
                            var template = this._isAppView() ? ej.getCurrentPage().find('#' + this.model.liveTile.imageTemplateId[i]).addClass(this._prefix + "tile-template " + this._prefix + "live-tile " + this._prefix + "fontimage " + this._prefix + "tile-image " + this._prefix + "tile-image" + this.model.imagePosition + " " + this._prefix + "tile-" + this.model.liveTile.type) :
                                $('#' + this.model.liveTile.imageTemplateId[i]).addClass(this._prefix + "tile-template " + this._prefix + "live-tile " + this._prefix + "fontimage " + this._prefix + "tile-image " + this._prefix + "tile-image" + this.model.imagePosition + " " + this._prefix + "tile-" + this.model.liveTile.type);
                            this._liveImageWrapper.append(template);

                        }
						this._mainTile.addClass(this._prefix + "tile-template");
                    }
                    else {
                        if (this.model.liveTile.imageClass) {
                            for (var i = 0; i < this.model.liveTile.imageClass.length; i++)
                                this._liveImageWrapper.append(ej.buildTag("div").addClass(this.model.liveTile.imageClass[i] + " " + this._prefix + "live-tile " + this._prefix + "fontimage " + this._prefix + "tile-image " + this._prefix + "tile-image" + this.model.imagePosition + " " + this._prefix + "tile-" + this.model.liveTile.type));
                        }
                        else {
                            for (var i = 0; i < this.model.liveTile.imageUrl.length; i++) {
                                var url = this._isAppView() && this.model.imagePath ? this._getAbsolutePath(this.model.imagePath) + "/windows/" + this.model.liveTile.imageUrl[i] : this._getAbsolutePath(this.model.liveTile.imageUrl[i]);
                                this._liveImageWrapper.append(ej.buildTag("div." + this._prefix + "live-tile " + this._prefix + "fontimage " + this._prefix + "tile-image " + this._prefix + "tile-image" + this.model.imagePosition + " " + this._prefix + "tile-" + this.model.liveTile.type).css({ "background-image": "url('" + url + "')" }));
                            }
                        }
                    }
                    $(this._liveImageWrapper.children()[0]).addClass(this._prefix + "tile-" + this.model.liveTile.type + 'back').removeClass(this._prefix + "tile-" + this.model.liveTile.type);
                }
                this._mainTile.append(this._liveImageWrapper);
            }
            //Normal Tile implementation
            else {
                if (this.model.imageTemplateId) {
                    var imageTemp = this._isAppView() ? ej.getCurrentPage().find('#' + this.model.imageTemplateId).addClass(this._prefix + "tile-template") : $('#' + this.model.imageTemplateId).addClass(this._prefix + "tile-template");
                    this._image.append(imageTemp);
                }
                else {
                    this._image = ej.buildTag("div").addClass(this._prefix + "fontimage " + this._prefix + "tile-image " + this._prefix + "tile-image" + this.model.imagePosition);
                    if (this.model.imageClass)
                        this._image.addClass(this.model.imageClass);
                    else if (this.model.imageUrl) {
                        var url = this._isAppView() && this.model.imagePath ? (this._getAbsolutePath(this.model.imagePath) + "/" + this.model.renderMode.toLowerCase() + "/" + this.model.imageUrl) : this._getAbsolutePath(this.model.imageUrl);
                        this._image.css({ "background-image": "url('" + url + "')" });
                        if (ej.browserInfo().name == "msie" && ej.browserInfo().version < 9 && this.model.imagePosition == "fill")
                            this._image.css({ "filter": "progid:DXImageTransform.Microsoft.AlphaImageLoader(src='" + url + "',sizingMethod='scale')", "-ms-filter": "progid:DXImageTransform.Microsoft.AlphaImageLoader(src='" + url + "',sizingMethod='scale')" });
                    }
                }
                this._mainTile.append(this._image).addClass(this._prefix + "tile-image" + this.model.imagePosition);
            }
            //Badge wrapper creation
            if (this.model.badge.enabled)
                this._setBadgeValue();
            //Text Wrapper creation
            if (this._text) {
                if (this.model.captionTemplateId) {
                    this._isAppView() ? this._text.append(ej.getCurrentPage().find('#' + this.model.captionTemplateId)).addClass(this._prefix + "template-caption") :this._text.append($('#' + this.model.captionTemplateId)).addClass(this._prefix + "template-caption");                   
                    this._mainTile.addClass(this._prefix + "template-caption")
                }
                else
                    this._text.html(this.model.text);
                this._mainTile.append(this._text);
            }
            //customize the tile size
            if (this._isCustomizeSize()) {
                this.element.css({ "width": this.model.width, "height": this.model.height });
                if (this.model.imagePosition != "fill") {
                    if (this.model.renderMode == "windows" || this.model.renderMode == "flat" || !this._isAppView()) {
                        this.model.showText ? this.element.find("." + this._prefix + "tile-image").css({ "width": (this.model.width) - 20, "height": (this.model.height) - 45 }) : this.element.find("." + this._prefix + "tile-image").css({ "width": (this.model.width) - 20, "height": (this.model.height) - 20 });
                        this.model.textAlignment == "left" || ((this.model.renderMode == "windows" || this.model.renderMode == "flat" || !this._isAppView()) && this.model.textAlignment == "normal") ? this.element.find("." + this._prefix + "tile-text").css({ "width": this.model.width - 14 }) : "";
                    }
                    else
                        this.model.showText ? this.element.find("." + this._prefix + "tile-image").css({ "width": (this.model.width) - 14, "height": (this.model.height) - 39 }) : this.element.find("." + this._prefix + "tile-image").css({ "width": (this.model.width) - 14, "height": (this.model.height) - 14 });
                }
                else {
                    this.element.find("." + this._prefix + "tile-image").css({ "width": this.model.width, "height": this.model.height });
                    this.model.textAlignment == "left" || ((this.model.renderMode == "windows" || this.model.renderMode == "flat" || !this._isAppView()) && this.model.textAlignment == "normal") ? this.element.find("." + this._prefix + "tile-text").css({ "width": this.model.width - 14 }) : "";
                }
                if (this._isBelowSmallSize()) {
                    this.element.find("." + this._prefix + "tile-text").css("display", "none");
                    this.element.find("." + this._prefix + "tile-image").css({ "margin": 0, "width": this.model.width, "height": this.model.height });
                }
                else
                    this.element.find("." + this._prefix + "tile-text").css("display", "block");
                this.model.tileSize == "small" ? this.element.removeClass(this._prefix + "tile-wrapper-small").addClass(this._prefix + "tile-wrapper-medium") :
                this._isBelowSmallSize() ? (this.model.renderMode == "windows" || this.model.renderMode == "flat" || !this._isAppView()) ? this.element.removeClass(this._prefix + "tile-wrapper-" + this.model.tileSize).addClass(this._prefix + "tile-wrapper-small") : this.element.removeClass(this._prefix + "tile-wrapper-" + this.model.tileSize).addClass(this._prefix + "tile-wrapper-medium") : "";
            }
        },
        _isBelowSmallSize:function()
        {
            return ((this.model.width <= 70 && this.model.width != null) || (this.model.height <= 70 && this.model.height != null));
        },
        _isCustomizeSize:function()
        {
            return this.model.height && this.model.width;
        },
        //Delegates for Tile control
        _createDelegates: function () {
            this._onStartDelegate = $.proxy(this._isAppView() ? this._onTouchStartHandler : this._onMouseDownHandler, this);
            this._onEndDelegate = $.proxy(this._isAppView() ? this._onTouchEndHandler : this._onMouseUpHandler, this);
            this._onMoveDelegate = $.proxy(this._isAppView() ? this._onTouchMoveHandler : this._onMouseMoveHandler, this);
            this._onDocClickDelegate = $.proxy(this._onDocClickHandler, this);
            this._startAnimationDelegate = $.proxy(this["_" + this.model.liveTile.type + "Tile"], this);
        },
        //Wiring the events to Tile control	
        _wireEvents: function (remove) {
            this._createDelegates();
            ej.listenEvents([this.element,  $(document)], [ej.startEvent(), ej.endEvent()], [this._onStartDelegate, this._onDocClickDelegate], remove, this);
            if (this.model.liveTile.enabled && (!this._isAppView() || this.model.renderMode == "windows"))
                remove ? this._stopTileAnimation() : this._startTileAnimation();
        },
        //Section for handling the onDoc click
        _onDocClickHandler: function (evt) {
            this._removeActiveClass();
        },
        //Section for removing acive class for tile
        _removeActiveClass: function () {
            (!this._isAppView() || this.model.renderMode == "windows") ? ej._removeSkewClass(this.element) : $(this.element).removeClass(this._prefix + "state-active");
        },
        //Section for start tile animation
        _startTileAnimation: function () {
            this._intervalCounter = setInterval(this._startAnimationDelegate, this.model.liveTile.updateInterval);
        },
        //Section for stop tile animation
        _stopTileAnimation: function () {
            clearInterval(this._intervalCounter);
        },
        //Section for adding flip effect to windows live tile control
        _flipTile: function () {
            var front = this.element.find("." + this._prefix + "tile-flipback");
            var back = this.element.find("." + this._prefix + "tile-flip").first();
            front.addClass(this._prefix + "tile-flip").removeClass(this._prefix + "tile-flipback");
            back.addClass(this._prefix + "tile-flipback").removeClass(this._prefix + "tile-flip");
        },
        //Section for adding slide effect to windows live tile control
        _slideTile: function () {
            this._animateEffect();
        },
        //Section for adding carousel effect to windows live tile control
        _carouselTile: function () {
            this._animateEffect();
        },
        //Common method for slide and carousel effect
        _animateEffect: function () {
            var type = this.model.liveTile.type.toLowerCase();
            var items = this.element.find("." + this._prefix + "live-tile");
            var currentitem = this.element.find("." + this._prefix + "tile-" + type + "back");
            var nextitem = currentitem.next()[0] == null ? items.first() : currentitem.next();
            var previtem = currentitem.prev()[0] == null ? items.last() : currentitem.prev();
            previtem.addClass(this._prefix + "tile-" + type).removeClass(this._prefix + "tile-" + type + "up");
            currentitem.addClass(this._prefix + "tile-" + type + "up").removeClass(this._prefix + "tile-" + type + "back");
            nextitem.removeClass(this._prefix + "tile-" + type).addClass(this._prefix + "tile-" + type + "back");
        },
        //To get the absolute path for image url
        _getAbsolutePath: function (path) {
            return this._isAppView() ? App.route.makeUrlAbsolute(path, true).toString() : path;
        },
        _isAppView: function () {
            return this._prefix == "e-m-" ? true : false;
        },
        //Public method for template update
        //Web
        /**		
        * Update the image template to another one.
        * @method updateTemplate
        * @return jQuery
        * @example 
        * &lt;div id="tile" &gt;
        * &lt;/div&gt; 
        * &lt;div id="sample1" style="background-image: url('themes/sample/tile/people.png');height:100%;width:100%;"&gt;
        * &lt;/div&gt;
        * &lt;div id="sample2" style="background-image: url('themes/sample/tile/sports.png');height:100%;width:100%;"&gt;
        * &lt;/div&gt;
        * &lt;script&gt; 
        * $(function () {
        * $("#tile").ejTile({ imageTemplateId: "sample1" }); 
        * var value = $("#tile").data("ejTile");
        * value.updateTemplate("sample2");
        * });
        * &lt;/script&gt;
        * @memberof ejTile
        * @instance
        */

        //Mobile
        /**		
        * Update the image template to another one.
        * @method updateTemplate
        * @return jQuery
        * @example 
        * &lt;div id="tile" data-role="ejmtile" data-ej-imagetemplateid="sample1" &gt;
        * &lt;/div&gt; 
        * &lt;div id="sample1" style="background-image: url('themes/sample/tile/ios7/people.png');height:100%;width:100%;"&gt;
        * &lt;/div&gt;
        * &lt;div id="sample2" style="background-image: url('themes/sample/tile/ios7/sports.png');height:100%;width:100%;"&gt;
        * &lt;/div&gt;
        * &lt;script&gt; 
        * $(function () {
        * var value = $("#tile").data("ejmTile");
        * value.updateTemplate("sample2");
        * });
        * &lt;/script&gt;
        * @memberof ejmTile
        * @instance
        */
        updateTemplate: function (id, index) {
            if (this.model.liveTile.enabled) {
                $(this._liveImageWrapper).children()[index].remove();
                var tempLive = this._isAppView()?ej.getCurrentPage().find('#' + id).addClass(this._prefix + "tile-template " + this._prefix + "live-tile " + this._prefix + "fontimage " + this._prefix + "tile-image " + this._prefix + "tile-image" + this.model.imagePosition + " " + this._prefix + "tile-" + this.model.liveTile.type):
                    $('#' + id).addClass(this._prefix + "tile-template " + this._prefix + "live-tile " + this._prefix + "fontimage " + this._prefix + "tile-image " + this._prefix + "tile-image" + this.model.imagePosition + " " + this._prefix + "tile-" + this.model.liveTile.type);
                if ($(this._liveImageWrapper).children()[index - 1])
                    $($(this._liveImageWrapper).children()[index - 1]).after(tempLive);
                else
                    $($(this._liveImageWrapper).children()[index + 1]).before(tempLive);
            }
            else
            {
                var template=this._isAppView()?ej.getCurrentPage().find('#' + id).addClass(this._prefix + "tile-template"):$('#' + id).addClass(this._prefix + "tile-template");
                this._image.empty().append(template);
                
            }
        },
        //SetModel
        _setModel: function (options) {
            var refresh = false;
            for (var property in options) {
                var setModel = "_set" + property.charAt(0).toUpperCase() + property.slice(1);
                if (this[setModel])
                    this[setModel](options[property]);
                else
                    refresh = true
            }
            if (refresh)
                this._refresh();
        },
        //To set image position
        _setImagePosition: function (value) {
            if (this.model.liveTile.enabled && $($(this._mainTile.children()[0]).children()).hasClass(this._prefix + "tile-image")) {
                $($(this._mainTile.children()[0]).children()).removeClass(this._prefix + "tile-imagecenter " + this._prefix + "tile-imagetop " + this._prefix + "tile-imagebottom " + this._prefix + "tile-imageright " + this._prefix + "tile-imageleft " + this._prefix + "tile-imagetopleft " + this._prefix + "tile-imagetopright " + this._prefix + "tile-imagebottomright " + this._prefix + "tile-imagebottomleft " + this._prefix + "tile-imagefill").addClass(this._prefix + "tile-image" + value);
                this._mainTile.removeClass(this._prefix + "tile-imagecenter " + this._prefix + "tile-imagetop " + this._prefix + "tile-imagebottom " + this._prefix + "tile-imageright " + this._prefix + "tile-imageleft " + this._prefix + "tile-imagetopleft " + this._prefix + "tile-imagetopright " + this._prefix + "tile-imagebottomright " + this._prefix + "tile-imagebottomleft " + this._prefix + "tile-imagefill").addClass(this._prefix + "tile-image" + value);
                this.model.imagePosition = value;
            }
            else {
                $(this._mainTile.children()[0]).removeClass(this._prefix + "tile-imagecenter " + this._prefix + "tile-imagetop " + this._prefix + "tile-imagebottom " + this._prefix + "tile-imageright " + this._prefix + "tile-imageleft " + this._prefix + "tile-imagetopleft " + this._prefix + "tile-imagetopright " + this._prefix + "tile-imagebottomright " + this._prefix + "tile-imagebottomleft " + this._prefix + "tile-imagefill").addClass(this._prefix + "tile-image" + value);
                this._mainTile.removeClass(this._prefix + "tile-imagecenter " + this._prefix + "tile-imagetop " + this._prefix + "tile-imagebottom " + this._prefix + "tile-imageright " + this._prefix + "tile-imageleft " + this._prefix + "tile-imagetopleft " + this._prefix + "tile-imagetopright " + this._prefix + "tile-imagebottomright " + this._prefix + "tile-imagebottomleft " + this._prefix + "tile-imagefill").addClass(this._prefix + "tile-image" + value);
                this.model.imagePosition = value;
            }
        },
        //To show text
        _setShowText: function (showtext) {
            this.model.showText = showtext;
            if (showtext) {
                this.element.removeClass(this._prefix + "disabled-text").addClass(this._prefix + "enabled-text");
                this._setText(this.model.text);
                this._isAppView() && this.model.renderMode != "windows" && this.model.renderMode != "flat" && this.model[this.model.renderMode].textPosition == "outer" ? this.element.removeClass(this._prefix + "text-inner").addClass(this._prefix + "text-outer") : "";
            }
            else {
                this.element.removeClass(this._prefix + "enabled-text").addClass(this._prefix + "disabled-text");
                this._isAppView() && this.model.renderMode != "windows" && this.model.renderMode != "flat" && this.model[this.model.renderMode].textPosition == "outer" ? this.element.removeClass(this._prefix + "text-outer").addClass(this._prefix + "text-inner") : "";
            }
        },
        //To set text
        _setText: function (text) {
            if (this.model.showText) {
                if (this.element.find('.' + this._prefix + "tile-text").length)
                    this.element.find('.' + this._prefix + "tile-text").html(text);
                else
                    this.element.prepend(ej.buildTag("div." + this._prefix + "tile-text", text));
            }
        },
        //To set text position
        _setTextPosition: function (position) {
            if (position == "outer")
                this.element.removeClass(this._prefix + "text-inner").addClass(this._prefix + "text-outer")
            else
                this.element.removeClass(this._prefix + "text-outer").addClass(this._prefix + "text-inner").find("." + this._prefix + "child-tile");
        },
        //To set text alignment
        _setTextAlignment: function (value) {
            $(this.element.find("." + this._prefix + "tile-text")).removeClass(this._prefix + "textalign-left " + this._prefix + "textalign-right " + this._prefix + "textalign-normal " + this._prefix + "textalign-center").addClass(this._prefix + "textalign-" + value);
            this.model.textAlignment = value;
        },
        //To modify badge
        _setBadge: function (options) {
            if (this.model.badge.enabled) {
                this._setBadgeEnabled(true);
                for (var property in options) {
                    var setModel = "_setBadge" + property.charAt(0).toUpperCase() + property.slice(1);
                    if (this[setModel])
                        this[setModel](options[property]);
                }
            }
            else
                this._setBadgeEnabled(false);
        },
        //To set badge value
        _setBadgeValue: function () {
            var badgeValue = this.model.badge.text ? this.model.badge.text : ((this.model.badge.value <= this.model.badge.maxValue && this.model.badge.value >= this.model.badge.minValue) ? this.model.badge.value.toString() : (this.model.badge.value > this.model.badge.maxValue ? this.model.badge.maxValue.toString() + "+" : this.model.badge.minValue.toString()));
            if (this.element.find('.' + this._prefix + "tile-badge").length)
                this.element.find('.' + this._prefix + "tile-badge").html(badgeValue);
            else
                this.element.prepend(ej.buildTag("div." + this._prefix + "tile-badge", badgeValue));
        },
        //To enable or disable badge
        _setBadgeEnabled: function (enabled) {
            this.element.find("." + this._prefix + "tile-badge")[enabled ? "show" : "hide"]();
        },
        //To clear element
        _clearElement: function () {
            this.element.removeAttr("class");
            this.element.html(this._orgEle.html());
        },
        //To destroy element
        _destroy: function () {
            this._wireEvents(true);
            this._clearElement();
        }
    });
})(jQuery, Syncfusion);