﻿(function ($, ej) {
    "use strict";

    /**
    * Enum for LayoutTypes in diagram	
    * @enum {String}
    * @global 
    */
    ej.datavisualization.Diagram.LayoutTypes = {
        /** Used not to set any specific layout  */
        None: "none",
        /** Used to set layout type as hierarchical layout */
        HierarchicalTree: "hierarchicaltree",
        /** Used to set layout type as organnizational chart */
        OrganizationalChart: "organizationalchart"
    };

    /**
   * Enum for ChartOrientations in diagram	
   * @enum {String}
   * @global 
   */
    ej.datavisualization.Diagram.ChartOrientations = {
        /** Used to set horizontal organizational chart orientation */
        Horizontal: "horizontal",
        /** Used to set vertical organizational chart orientation */
        Vertical: "vertical"
    };

    /**
   * Enum for ChartTypes in diagram	
   * @enum {String}
   * @global 
   */
    ej.datavisualization.Diagram.ChartTypes = {
        /** Used to arrange the children at left side of parent */
        Left: "left",
        /** Used to arrange the children at right side of parent */
        Right: "right",
        /** Used to arrange the children at alternative sides(left,right) of parent */
        Alternate: "alternate",
        /** Used to arrange the children with respect to the middle of parent */
        Center: "center"
    };

    ej.datavisualization.Diagram.Layout = {
        doLayout: function (diagram) {
            ej.datavisualization.Diagram.HierarchicalLayout.doLayout(diagram);
        }
    };

    //region Hierarchical layout
    ej.datavisualization.Diagram.HierarchicalLayout = {
        doLayout: function (diagram) {
            var layout, model, node, layoutInfo, i;
            model = diagram.model;
            //Initialize layout properties
            layout = {
                diagram: diagram, _anchorX: 0, _anchorY: 0,
                _graphNodes: {}, _firstLevelNodes: [], levels: [], maxLevel: 0
            };
            layout = $.extend(true, {}, layout, model.layout);
            if (model.nodes.length > 0) {
                //Initialize graph nodes
                for (i = 0; i < model.nodes.length; i++) {
                    node = model.nodes[i];
                    layoutInfo = layout._graphNodes[node.name] = this._setUpLayoutInfo(layout, node);
                    layoutInfo.tree.hasSubTree = false;
                    if (!node.inEdges || !node.inEdges.length) { layout._firstLevelNodes.push(node); }
                }

                //Update relationship(parent and children)
                for (i = 0; i < layout._firstLevelNodes.length; i++) {
                    node = layout._firstLevelNodes[i];
                    this._updateEdges(layout, node, 1);
                }

                if (layout._firstLevelNodes.length > 0) {
                    layout._rootNode = layout._firstLevelNodes[0];
                    var bounds, x = 0, y = 0;
                    for (i = 0; i < layout._firstLevelNodes.length; i++) {
                        bounds = this._updateTree(layout, x, y, layout._firstLevelNodes[i], 0, layout._firstLevelNodes[i - 1]);
                        if (layout.orientation == "lefttoright" || layout.orientation == "righttoleft") y = bounds.right + layout.horizontalSpacing;
                        else x = bounds.right + layout.horizontalSpacing;
                    }
                    this._updateAnchor(layout);
                    for (i = 0; i < layout._firstLevelNodes.length; i++) {
                        this._updateNodes(layout, layout._firstLevelNodes[i], 0);
                        this._updateConnectors(layout, layout._firstLevelNodes[i], 1);
                    }
                }
            }
        },

        _updateTree: function (layout, x, y, shape, level, prev, dontupdate) {
            var dimensions, info, lev, obj, hasChild;
            dimensions = this._getDimensions(layout, shape, x, y, level);
            info = layout._graphNodes[shape.name];
            //Set maximum level of layout
            layout.maxLevel = Math.max(layout.maxLevel, level);
            lev = level;
            hasChild = this._hasChild(layout, shape);
            if (!hasChild && !info.tree.assistants.length)
                //update leaf nodes
                return this._updateLeafNode(layout, shape, prev, dimensions, level, dontupdate);
            else {
                var treeBounds, shapeBounds, levelBounds, d, asstBounds, space;
                var bottom = dimensions.y + dimensions.height + layout.verticalSpacing;
                if (info.tree.assistants.length) {
                    //Vertically place assistants
                    obj = this._setDepthSpaceForAssistants(layout, shape, bottom, dimensions.height, level, layout.verticalSpacing);
                    lev = obj.level;
                    bottom = obj.bottom;
                }
                if (!info.tree.assistants.length && info.tree.orientation != "horizontal") bottom = dimensions.y + dimensions.height + layout.verticalSpacing / 2;

                if (info.tree.orientation == "horizontal")
                    treeBounds = this._updateHorizontalTree(layout, shape, prev, dimensions.x, bottom, lev);
                else
                    treeBounds = this._updateVerticalTree(layout, shape, dimensions.x, bottom, lev, dontupdate);

                info.y = dimensions.y;
                x = info.mid;
                if (info.tree.assistants.length) {
                    //Set breadth space for assistants
                    space = x !== undefined ? x : dimensions.x;
                    asstBounds = this._setBreadthSpaceForAssistants(layout, shape, dimensions, space, bottom, level);
                    if (!hasChild) {
                        levelBounds = treeBounds = asstBounds;
                        x = (levelBounds.x + levelBounds.right) / 2 - dimensions.width / 2;
                        treeBounds = levelBounds;
                    }
                    d = asstBounds ? asstBounds.canMoveBy : undefined;
                }
                info.x = x;
                shapeBounds = { x: x, y: dimensions.y, right: x + dimensions.width, bottom: dimensions.y + dimensions.height };
                this._translateSubTree(layout, shape, shapeBounds, treeBounds, dimensions, level, d, prev != undefined, dontupdate);
                return treeBounds;
            }
        },

        _updateLeafNode: function (layout, shape, prev, dimensions, level, dontupdate) {
            var info, bounds;
            info = layout._graphNodes[shape.name];
            info.x = dimensions.x;
            info.y = dimensions.y;
            info.maxLevel = Math.max(level, info.maxLevel || 0);
            bounds = { x: dimensions.x, y: dimensions.y, right: dimensions.x + dimensions.width, bottom: dimensions.y + dimensions.height };
            info.maxLevel = Math.max(info.maxLevel || 0, level);
            this._translateSubTree(layout, shape, bounds, bounds, dimensions, level, undefined, prev != undefined, dontupdate);
            return { x: info.x, y: info.y, right: info.x + dimensions.width, bottom: info.y + dimensions.height };
        },

        _translateSubTree: function (layout, shape, shapeBounds, treeBounds, dimensions, level, assistDiff, translate, dontupdate) {
            var info = layout._graphNodes[shape.name];
            var firstChild = layout.diagram.nameTable[info.tree.children[0]];
            var firstChildInfo = firstChild ? layout._graphNodes[firstChild.name] : null;
            var hasChild = this._hasChild(layout, shape);
            var intersect = this._findIntersectingLevels(layout, shapeBounds, level);
            var treeIntersect = this._findIntersectingLevels(layout, treeBounds, level);
            var levelBounds = [], diff;
            if (intersect.length) {
                info.intersect = intersect;
                this._spaceLeftFromPrevSubTree(layout, shape, shapeBounds);
                info.canMoveBy = info.diff;
                info.fchildList = [];
                if (assistDiff !== undefined)
                    info.canMoveBy = Math.min(assistDiff, info.canMoveBy);
                if (firstChild && firstChildInfo.canMoveBy !== undefined) {
                    info.canMoveBy = Math.min(info.canMoveBy, firstChildInfo.canMoveBy);
                    if (firstChildInfo.fchildList) info.fchildList = firstChildInfo.fchildList;
                }
                info.fchildList[level] = shape.name;
                if (translate) {
                    info.x -= info.canMoveBy;
                    info.subTreeTranslation -= info.canMoveBy;
                    if (hasChild) {
                        this._shiftSubordinates(layout, treeIntersect, info.canMoveBy);
                        treeBounds.x = Math.min(treeBounds.x, info.x);
                        treeBounds.right = Math.max(treeBounds.right, info.x + dimensions.width);
                        treeBounds.bottom = Math.max(treeBounds.bottom, info.y + dimensions.height);
                        treeBounds.x -= info.canMoveBy;
                        treeBounds.right -= info.canMoveBy;
                    }
                }
            }
            else {
                if (hasChild) {
                    treeBounds.x = Math.min(treeBounds.x, shapeBounds.x);
                    treeBounds.right = Math.max(treeBounds.right, shapeBounds.x + dimensions.width);
                    treeBounds.bottom = Math.max(treeBounds.bottom, info.y + dimensions.height);
                }
            }
            if (!dontupdate) {
                shapeBounds = { x: info.x, y: dimensions.y, right: info.x + dimensions.width, bottom: dimensions.y + dimensions.height };
                levelBounds.push({ rBounds: shapeBounds });
                this._updateRearBounds(layout, shape, levelBounds, level);
            }
        },

        _updateRearBounds: function (layout, shape, levelBounds, level, intersect) {
            var bnds, index, intersect, firstLevel, lastLevel, isLastLeaf = true;
            if (shape) {
                var info = layout._graphNodes[shape.name];
                intersect = info.intersect;
                isLastLeaf = !info.tree.children.length && !info.tree.assistants.length;
            }
            firstLevel = levelBounds[0].rBounds;
            lastLevel = levelBounds[levelBounds.length - 1].rBounds;
            if (intersect && intersect.length) {
                bnds = layout.levels[intersect[0]].rBounds;
                if (bnds.y < firstLevel.y) {
                    bnds.bottom = firstLevel.y;
                    levelBounds.splice(0, 0, { rBounds: bnds });
                }
                bnds = layout.levels[intersect[intersect.length - 1]].rBounds;
                if (isLastLeaf && bnds.bottom > lastLevel.bottom) {
                    bnds.y = lastLevel.bottom;
                    levelBounds.push({ rBounds: bnds });
                }
                index = intersect[0];
                for (var i = levelBounds.length - 1; i >= 0; i--)
                    layout.levels.splice(index, 0, levelBounds[i]);
                index += levelBounds.length;
                layout.levels.splice(index, intersect.length);
            }
            else {
                index = this._findLevel(layout, levelBounds[levelBounds.length - 1].rBounds, level);
                for (var i = levelBounds.length - 1; i >= 0; i--)
                    layout.levels.splice(index, 0, levelBounds[i]);
            }
        },

        _shiftSubordinates: function (layout, intersect, diff) {
            var i;
            //Shift the sublevels by the distance diff
            if (diff != 0) {
                for (i = 0; i < intersect.length; i++) {
                    if (layout.levels[intersect[i]].rBounds) {
                        layout.levels[intersect[i]].rBounds.x -= diff;
                        layout.levels[intersect[i]].rBounds.right -= diff;
                    }
                }
            }
        },

        _setDepthSpaceForAssistants: function (layout, shape, bottom, height, lev, verticalSpacing) {
            var info = layout._graphNodes[shape.name];
            var asst, asstHeight, i;
            var max = bottom;
            //Vertically place the assistants as alternate layout(alternatively at both right and left sides of parent)
            for (i = 0; i < info.tree.assistants.length; i++) {
                asst = layout._graphNodes[info.tree.assistants[i]];
                if (asst) {
                    asst.tree.children = asst.tree.assistants = [];
                    asst.y = bottom;
                    asstHeight = layout.diagram.nameTable[info.tree.assistants[i]].height;
                    if (layout.orientation == "lefttoright" || layout.orientation == "righttoleft")
                        asstHeight = layout.diagram.nameTable[info.tree.assistants[i]].width;
                    max = bottom + asstHeight + verticalSpacing / 2;
                    layout.maxLevel = lev + 1;
                    if (i % 2 == 1 && i != info.tree.assistants.length - 1) {
                        bottom = max;
                        lev++;
                    }
                }
            }
            return { level: layout.maxLevel, bottom: bottom + asstHeight + verticalSpacing };
        },

        _setBreadthSpaceForAssistants: function (layout, shape, dimensions, space, bottom, level) {
            var asst, asstWidth, prevBounds, bounds;
            var info = layout._graphNodes[shape.name];
            var max = bottom;
            var lev = level;
            var left, diff, levelBounds, intersect, i;
            for (i = 0; i < info.tree.assistants.length; i++) {
                asst = layout._graphNodes[info.tree.assistants[i]];
                //Arrange assistants at both left and right sides of parent(like alternate layout)
                //Check - By default, distance to be left between parent and child nodes is assumed as 20. It can be modified/customized later.
                if (asst) {
                    asstWidth = layout.diagram.nameTable[info.tree.assistants[i]].width;
                    if (layout.orientation == "lefttoright" || layout.orientation == "righttoleft")
                        asstWidth = layout.diagram.nameTable[info.tree.assistants[i]].height;
                    if (i % 2 == 0) left = space + dimensions.width / 2 - 20 - asstWidth;
                    else left = space + dimensions.width / 2 + 20;
                    //Check - What will happen if update leaf node is called? Since assistants don't have children
                    bounds = this._updateTree(layout, left, asst.y, layout.diagram.nameTable[info.tree.assistants[i]], lev + 1);
                    if (!this._hasChild(layout, shape))
                        if (i == 0) levelBounds = bounds;
                        else this._uniteRects(levelBounds, bounds);
                    if (i % 2 == 0 && asst.prevBounds) {
                        if (diff === undefined) diff = asst.canMoveBy;
                        else diff = Math.min(diff, asst.canMoveBy);
                    }
                    if (i % 2 == 1 || i == info.tree.assistants.length - 1) {
                        intersect = this._findIntersectingLevels(layout, bounds, lev + 1);
                        //Update rightmost positions of known layout levels
                        this._updateRearBounds(layout, null, [{ rBounds: bounds }], lev + 1, intersect);
                        lev++;
                    }
                }
            }
            if (levelBounds)
                levelBounds.canMoveBy = diff;
            return levelBounds;
        },

        _updateHorizontalTree: function (layout, shape, prev, x, y, level) {
            var child, childInfo, childBounds, childWidth, childHeight, firstChildInfo;
            var prevBounds, bounds, actBounds, maxLevel, translateSibilingsBy;
            //Get dimensions with respect to layout orientations
            var dimensions = this._getDimensions(layout, shape, x, y, level);
            var info = layout._graphNodes[shape.name];
            var side = info.tree.type;
            var lev = level;
            var right = x;
            var bottom = y;
            var width, height;
            var prevLayoutLevels = layout.levels.slice(0, layout.levels.length);
            if (this._hasChild(layout, shape)) {
                var h = layout.orientation == "lefttoright" || layout.orientation == "righttoleft" ? true : false;
                for (var i = 0; i < info.tree.children.length; i++) {
                    child = layout.diagram.nameTable[info.tree.children[i]];
                    width = child.width ? child.width : child._width;
                    height = child.height ? child.height : child._height;
                    childWidth = h ? height : width;
                    childHeight = h ? width : height;
                    prevBounds = layout.levels[lev + 1] ? layout.levels[lev + 1].rBounds : null;
                    //Update sub tree
                    childBounds = this._updateTree(layout, right, bottom, child, lev + 1, layout.diagram.nameTable[info.tree.children[i - 1]]);
                    childInfo = layout._graphNodes[child.name];
                    actBounds = { x: childInfo.x, y: childInfo.y, right: childInfo.x + childWidth, bottom: childInfo.y + childHeight };
                    if (i == 0) {
                        //Compare with previous(right most) subtree
                        bounds = { x: Math.min(childInfo.x, childBounds.x), y: Math.min(childInfo.y, childBounds.y), right: childBounds.right, bottom: childBounds.bottom };
                        firstChildInfo = childInfo;
                    }
                        //Compare with previous subtree if level of the child is greater than the level of previous sub tree
                        //Check - what will happen if level of second child is greater than current child
                    else if (firstChildInfo && firstChildInfo.canMoveBy != undefined && childInfo.fchildList && childInfo.fchildList.length - 1 > maxLevel) {
                        var subChildInfo = layout._graphNodes[childInfo.fchildList[maxLevel]];
                        var diff;
                        while (maxLevel < childInfo.fchildList.length - 1) {
                            if (subChildInfo.canMoveBy && prevLayoutLevels.indexOf(subChildInfo.prevBounds) < 0) {
                                subChildInfo = layout._graphNodes[childInfo.fchildList[maxLevel + 1]];
                                maxLevel++;
                            }
                            else break;
                            diff = subChildInfo.canMoveBy - childInfo.canMoveBy;
                        }
                        if (diff != undefined && diff <= firstChildInfo.canMoveBy) {
                            translateSibilingsBy = translateSibilingsBy ? Math.min(translateSibilingsBy, diff) : diff;
                            if (prevLayoutLevels.indexOf(subChildInfo.prevBounds) >= 0)
                                this._translateSiblings(layout, shape, child);
                        }
                    }
                    maxLevel = maxLevel ? Math.max(childInfo.maxLevel, maxLevel) : childInfo.maxLevel;
                    this._uniteRects(bounds, childBounds);
                    info.maxLevel = Math.max(info.maxLevel || 0, childInfo.maxLevel || 0);
                    right = childBounds.right + layout.horizontalSpacing;
                }
                if (!isNaN(translateSibilingsBy)) firstChildInfo.canMoveBy = translateSibilingsBy;
                info.mid = (firstChildInfo.x + actBounds.right) / 2 - dimensions.width / 2;
                //Set parent based on the chart type
                if (side == "left") info.mid = actBounds.right - dimensions.width; else if (side == "right") info.mid = dimensions.x;
            }
            return bounds;
        },

        _updateVerticalTree: function (layout, shape, x, y, level, dontupdate) {
            //declare local variables
            var child, childInfo, childBounds, childWidth, childHeight, prevBounds, bounds, actBounds, oddBounds;
            var dimensions, info, firstChild, h, factor, right, bottom, lev, i;
            var diff, type, canMoveBy, levels = [], oddLevels = [], intersect;
            var width, height;
            //Get dimensions with respect to layout orientations
            dimensions = this._getDimensions(layout, shape, x, y, level);
            info = layout._graphNodes[shape.name];
            firstChild = layout.diagram.nameTable[info.tree.children[0]];
            h = layout.orientation == "lefttoright" || layout.orientation == "righttoleft" ? true : false;
            factor = info.tree.type == "left" || info.tree.type == "leftoffset" ? -1 : 0;
            right = x;
            bottom = y;
            lev = level;
            for (i = 0; i < info.tree.children.length; i++) {
                if (info.tree.type == "alternate") {
                    //arrange at both left and right
                    type = (i % 2 == 0 && info.tree.children.length > 2) ? "left" : "right";
                    factor = (i % 2 == 0 && info.tree.children.length > 2) ? -1 : 0;
                }
                right = x + this._findOffset(layout, shape, info, type);
                child = layout.diagram.nameTable[info.tree.children[i]];
                width = child.width ? child.width : child._width;
                height = child.height ? child.height : child._height;
                childWidth = h ? height : width;
                childHeight = h ? width : height;
                //Update sub tree
                childBounds = this._updateTree(layout, right + factor * childWidth, bottom, child, level + 1, undefined, true);
                childInfo = layout._graphNodes[child.name];
                actBounds = { x: childInfo.x, y: childInfo.y, right: childInfo.x + childWidth, bottom: childInfo.y + childHeight };
                if (i == 0) {
                    this._uniteRects(childBounds, actBounds);
                    bounds = childBounds;
                }
                else
                    this._uniteRects(bounds, childBounds);
                //Check and adjust the space left from previous subtree/sibling
                if (childInfo.prevBounds && !(info.tree.type == "alternate" && i % 2 == 1 && info.tree.children.length > 2)) {
                    canMoveBy = canMoveBy !== undefined ? Math.min(childInfo.canMoveBy, canMoveBy) : childInfo.canMoveBy;
                }
                //Max level of the subtree node
                info.maxLevel = Math.max(info.maxLevel || 0, childInfo.maxLevel || 0);
                if (!(info.tree.type == "alternate" && info.tree.children.length > 2 && i % 2 == 0)) {
                    if (info.tree.type == "alternate" && info.tree.children.length > 2)
                        //alternate - arrange children with even index(0,2,4,6,..) at the next level
                        bottom = Math.max(childBounds.bottom, prevBounds.bottom) + layout.verticalSpacing / 2;
                    else
                        // left/right - arrange next child at the nect level(bottom)
                        bottom = childBounds.bottom + layout.verticalSpacing / 2;

                    level = info.maxLevel;
                    levels.push({ rBounds: actBounds });
                    if (childInfo.levelBounds) levels = levels.concat(childInfo.levelBounds);
                }
                else {
                    if (i != 0) bottom = prevBounds.bottom + layout.verticalSpacing / 2;
                    oddLevels.push({ rBounds: actBounds });
                    if (childInfo.levelBounds) oddLevels = oddLevels.concat(childInfo.levelBounds);
                }
                prevBounds = actBounds;
            }
            //To set level bounds(right most position of levels)
            if (!dontupdate) {
                if (info.tree.type == "alternate" && info.tree.children.length > 2) {
                    oddBounds = { x: oddLevels[0].rBounds.x, y: oddLevels[0].rBounds.y, right: oddLevels[oddLevels.length - 1].rBounds.right, bottom: oddLevels[oddLevels.length - 1].rBounds.bottom };
                    intersect = this._findIntersectingLevels(layout, oddBounds, lev + 1);
                    this._updateRearBounds(layout, null, oddLevels, lev + 1, intersect);
                }
                intersect = this._findIntersectingLevels(layout, bounds, lev + 1);
                this._updateRearBounds(layout, null, levels, lev + 1, intersect);
            }
            else info.levelBounds = levels;

            if (!isNaN(canMoveBy))
                layout._graphNodes[firstChild.name].canMoveBy = canMoveBy;
            info.childBounds = bounds;
            info.mid = x;
            return bounds;
        },

        _findOffset: function (layout, shape, info, type) {
            var offset = 0;
            var space = (layout.orientation == "lefttoright" || layout.orientation == "righttoleft") ? shape.height : shape.width;
            var ch = type ? type : info.tree.type;
            offset = info.tree.offset || 20;
            if (info.tree.type == "alternate")
                if (offset >= layout.horizontalSpacing) offset = layout.horizontalSpacing / 2;
            switch (ch) {
                case "left":
                    offset = space / 2 - offset;
                    break;
                case "right":
                    offset = offset + space / 2;
                    break;
            }
            return offset;
        },

        _translateSiblings: function (layout, shape, child) {
            var i, childInfo, info, diff;
            info = layout._graphNodes[shape.name];
            diff = layout._graphNodes[child.name].diff - layout._graphNodes[child.name].canMoveBy;
            for (i = 0; i < info.tree.children.length; i++) {
                if (child.name == info.tree.children[i])
                    break;
                childInfo = layout._graphNodes[info.tree.children[i]];
                childInfo.x += diff;
            }
        },

        _uniteRects: function (rect1, rect2) {
            //Unite two rects
            rect1.x = Math.min(rect1.x, rect2.x);
            rect1.right = Math.max(rect1.right, rect2.right);
            rect1.bottom = Math.max(rect1.bottom, rect2.bottom);
        },

        _spaceLeftFromPrevSubTree: function (layout, shape, bounds) {
            var info = layout._graphNodes[shape.name];
            var dif, prevBounds, intersect, k;
            var space = layout.horizontalSpacing;
            //Find the minimum distance to move towards previous sub tree
            for (k = 0; k < info.intersect.length; k++) {
                prevBounds = layout.levels[info.intersect[k]].rBounds;
                dif = bounds.x - (prevBounds.right + space);
                if (info.diff == undefined || dif < info.diff) {
                    info.diff = dif;
                    info.prevBounds = layout.levels[info.intersect[k]];
                }
            }
        },

        _findIntersectingLevels: function (layout, bounds, level) {
            //intersecting with exact Level
            var bnds = { x: bounds.x, y: bounds.y, right: bounds.right, bottom: bounds.bottom };
            bnds.y -= layout.verticalSpacing / 2;
            bnds.bottom += layout.verticalSpacing / 2;
            var intersectingLevels = [];
            var rBounds;
            var l = level;
            rBounds = layout.levels[l] ? layout.levels[l].rBounds : null;
            //Performance - We can consider only the intersecting levels
            do {
                if (rBounds && ((bnds.y < rBounds.y && bnds.bottom > rBounds.y) || (bnds.y < rBounds.bottom && rBounds.bottom < bnds.bottom) ||
                    bnds.y > rBounds.y && bnds.bottom < rBounds.bottom || bnds.y < rBounds.y && bnds.bottom > rBounds.bottom)) {
                    intersectingLevels.splice(0, 0, l);
                }
                else if (rBounds && rBounds.bottom < bnds.y) break;
                l--;
                rBounds = layout.levels[l] ? layout.levels[l].rBounds : null;
            } while (l >= 0);

            l = level + 1;
            rBounds = layout.levels[l] ? layout.levels[l].rBounds : null;
            do {
                if (rBounds && ((bnds.y < rBounds.y && bnds.bottom > rBounds.y) || (bnds.y < rBounds.bottom && rBounds.bottom < bnds.bottom) ||
                    bnds.y > rBounds.y && bnds.bottom < rBounds.bottom || bnds.y < rBounds.y && bnds.bottom > rBounds.bottom)) {
                    intersectingLevels.push(l);
                }
                else if (rBounds && rBounds.y > bnds.bottom) break;
                l++;
                rBounds = layout.levels[l] ? layout.levels[l].rBounds : null;
            } while (l <= layout.levels.length);

            return intersectingLevels;
        },

        _findLevel: function (layout, bounds, level) {
            var bnds = bounds;
            var l = 0;
            var rBounds = layout.levels[l] ? layout.levels[l].rBounds : null;
            do {
                if (rBounds && bnds.bottom < rBounds.y) {
                    return l;
                }
                else l++;
                rBounds = layout.levels[l] ? layout.levels[l].rBounds : null;
            } while (l <= layout.levels.length);
            return level;
        },

        _updateEdges: function (layout, node, depth) {
            var layoutInfo = layout._graphNodes[node.name];
            //Update children collection
            if (node.outEdges && node.outEdges.length && node.isExpanded) {
                for (var j = 0; j < node.outEdges.length; j++) {
                    var edge = layout.diagram.nameTable[layout.diagram.nameTable[node.outEdges[j]].targetNode];
                    if (!edge.excludeFromLayout) {
                        layoutInfo.tree.children.push(edge.name);
                        if (edge.outEdges && edge.outEdges.length && edge.isExpanded) {
                            layoutInfo.tree.hasSubTree = true;
                        }
                        this._updateEdges(layout, edge, depth + 1);
                    }
                }
            }
            //set level info
            layoutInfo.tree.level = depth;

            //By default, orientation is horizontal for nested trees
            if (layoutInfo.tree.hasSubTree) layoutInfo.tree.orientation = "horizontal";

            //Customizing assistants and children collection
            //Performance-Instead of reading the method everytime, we can set once and can reuse that
            if (layout.getLayoutInfo && layout.type == "organizationalchart" && layoutInfo.tree.children.length) {
                if (typeof layout.getLayoutInfo === "string") {
                    layout.getLayoutInfo = ej.util.getObject(layout.getLayoutInfo, window);
                }
                if ($.isFunction(layout.getLayoutInfo)) {
                    layout.getLayoutInfo(layout.diagram, node, layoutInfo.tree);
                }
            }
            if (layout.level && layoutInfo.tree.type != "alternate" && depth >= layout.level)
                layoutInfo.tree.hasSubTree = false;
        },

        _updateAnchor: function (layout) {
            var node, rootNodeInfo, viewPort, fixedNode, width, height, mod;
            //Update anchor based on viewport
            rootNodeInfo = layout._graphNodes[layout._rootNode.name];
            viewPort = ej.datavisualization.Diagram.ScrollUtil._viewPort(layout.diagram);
            width = layout._rootNode.width ? layout._rootNode.width : layout._rootNode._width;
            height = layout._rootNode.height ? layout._rootNode.height : layout._rootNode._height;
            if (layout.orientation == "toptobottom") {
                layout._anchorX = viewPort.width / 2 - (rootNodeInfo.x + width / 2) + layout.marginX;
                layout._anchorY = layout.marginY;
            }
            else if (layout.orientation == "bottomtotop") {
                layout._anchorX = viewPort.width / 2 - (rootNodeInfo.x + width / 2) + layout.marginX;
                layout._anchorY = viewPort.height - (rootNodeInfo.y + layout.marginY);
            }
            else if (layout.orientation == "lefttoright") {
                layout._anchorX = layout.marginX;
                layout._anchorY = viewPort.height / 2 - (rootNodeInfo.x + height / 2) + layout.marginY;
            }
            else if (layout.orientation == "righttoleft") {
                layout._anchorX = viewPort.width - (rootNodeInfo.y + layout.marginX);
                layout._anchorY = viewPort.height / 2 - (rootNodeInfo.x + height / 2) + layout.marginY;
            }
            //Anchor based on fixed nodes
            if (layout.fixedNode) {
                fixedNode = layout.diagram.nameTable[layout.fixedNode];
                width = fixedNode.width ? fixedNode.width : fixedNode._width;
                height = fixedNode.height ? fixedNode.height : fixedNode._height;
                layout._anchorX = fixedNode.offsetX
                layout._anchorY = fixedNode.offsetY;
                layout._anchorX += layout.orientation == "righttoleft" ? width / 2 : -width / 2;
                layout._anchorY += layout.orientation == "bottomtotop" ? height / 2 : -height / 2;
                node = fixedNode, mod = 0;
                while (node.inEdges.length) {
                    node = this._getParentNode(layout, node);
                    mod += layout._graphNodes[node.name].subTreeTranslation || 0;
                }
                if (layout.orientation == "lefttoright" || layout.orientation == "righttoleft") {
                    layout._anchorX -= layout._graphNodes[fixedNode.name].y;
                    layout._anchorY -= layout._graphNodes[fixedNode.name].x + mod;
                } else {
                    layout._anchorX -= layout._graphNodes[fixedNode.name].x + mod;
                    layout._anchorY -= layout._graphNodes[fixedNode.name].y;
                }
            }
        },

        _updateConnectors: function (layout, node, level) {
            var i, conn, target, info, direction, offsetDir, segments;
            var nodeWidth = 0, nodeHeight = 0, targetWidth = 0, targetHeight = 0, length = 0, offsetLen = 0;
            //Route out edges
            info = layout._graphNodes[node.name];
            for (i = 0; i < node.outEdges.length; i++) {
                conn = layout.diagram.nameTable[node.outEdges[i]];
                target = layout.diagram.nameTable[conn.targetNode];
                var nwidth = node.width ? node.width : node._width;
                var nheight = node.height ? node.height : node._height;
                var twidth = target.width ? target.width : target._width;
                var theight = target.height ? target.height : target._height;
                if (layout.type == "organizationalchart") {
                    //Connector routing - vertical layouts
                    if (layout.orientation == "toptobottom" || layout.orientation == "bottomtotop") {
                        nodeHeight = layout.orientation == "toptobottom" ? nheight : -nheight;
                        targetHeight = layout.orientation == "toptobottom" ? -theight : theight;
                        direction = layout.orientation == "toptobottom" ? "bottom" : "top";
                        if (info.tree.assistants.length) {
                            //Route the in-edges of assistants
                            length = Math.abs((target.offsetY + targetHeight / 2) - (node.offsetY + nodeHeight / 2)) - layout.verticalSpacing / 2;
                            if (!info.tree.hasSubTree || info.tree.assistants.indexOf(target.name) >= 0)
                                length = Math.abs(target.offsetY - (node.offsetY + nodeHeight / 2));
                        }
                        else {
                            //Route the in-edges child nodes 
                            length = Math.abs(((target.offsetY + targetHeight / 2) - (node.offsetY + nodeHeight / 2)) / 2);
                            if (!info.tree.hasSubTree && info.tree.children.length && info.tree.orientation == "vertical" && info.tree.enableRouting)
                                length = Math.abs(target.offsetY - (node.offsetY + nodeHeight / 2));
                            //For vertical orientation with negative offsets
                            if (!info.tree.hasSubTree && info.tree.offset < 5 && info.tree.type != "alternate") {
                                offsetDir = info.tree.type == "left" ? "right" : "left";
                                length = layout.verticalSpacing / 4;
                                offsetLen = Math.abs(info.tree.offset) + layout.horizontalSpacing / 2;
                            }
                        }
                    } else {
                        //Connector routing - Horizontal layout orientation
                        nodeWidth = layout.orientation == "lefttoright" ? nwidth : -nwidth;
                        targetWidth = layout.orientation == "lefttoright" ? -twidth : twidth;
                        direction = layout.orientation == "lefttoright" ? "right" : "left";
                        //Route the in-edges of assistants
                        if (info.tree.assistants.length) {
                            length = Math.abs((target.offsetX + targetWidth / 2) - (node.offsetX + nodeWidth / 2)) - layout.verticalSpacing / 2;
                            if (!info.tree.hasSubTree || info.tree.assistants.indexOf(target.name) >= 0)
                                length = Math.abs(target.offsetX - (node.offsetX + nodeWidth / 2));
                        }
                        else {
                            //Route the in-edges of child nodes
                            length = Math.abs(((target.offsetX + targetWidth / 2) - (node.offsetX + nodeWidth / 2)) / 2);
                            if (!info.tree.hasSubTree && info.tree.children.length && info.tree.orientation == "vertical" && info.tree.enableRouting)
                                length = Math.abs(target.offsetX - (node.offsetX + nodeWidth / 2));
                            //For vertical orientation with negative offset
                            if (!info.tree.hasSubTree && info.tree.offset < 5 && info.tree.type != "alternate") {
                                offsetDir = info.tree.type == "left" ? "bottom" : "top";
                                length = layout.verticalSpacing / 4;
                                offsetLen = Math.abs(info.tree.offset) + 10;
                            }
                        }
                    }
                    conn.sourcePoint = { x: node.offsetX + nodeWidth / 2, y: node.offsetY + nodeHeight / 2 };
                    conn.targetPoint = { x: target.offsetX + targetWidth / 2, y: target.offsetY + targetHeight / 2 };
                    if (!info.tree.hasSubTree && info.tree.offset < 5 && info.tree.type != "alternate") {
                        segments = [{ type: "orthogonal", length: length, direction: direction },
                                        { type: "orthogonal", length: offsetLen, direction: offsetDir }];
                    } else {
                        segments = [{ type: "orthogonal", length: length, direction: direction },
                                        { type: "orthogonal" }];
                    }
                    layout.diagram.updateConnector(conn.name, { segments: segments });
                }
                layout.diagram._dock(conn, layout.diagram.nameTable);
                if (layout.diagram._svg)
                    ej.datavisualization.Diagram.DiagramContext.update(conn, layout.diagram);
                if (target.isExpanded || this._hasChild(layout, target))
                    this._updateConnectors(layout, target, level + 1);
            }
        },

        _updateNodes: function (layout, node, mod) {
            var child, i;
            var width = node.width ? node.width : node._width;
            var height = node.height ? node.height : node._height;
            if (!node.excludeFromLayout) {
                node.offsetX = layout._anchorX;
                node.offsetY = layout._anchorY;
                //Performance - instead of checking conditions for every node, we can make the layout related conditions once and we can reuse them
                if (layout.orientation == "lefttoright") {
                    node.offsetX += layout._graphNodes[node.name].y + width / 2;
                    node.offsetY += layout._graphNodes[node.name].x + mod + height / 2;
                }
                else if (layout.orientation == "righttoleft") {
                    node.offsetX -= layout._graphNodes[node.name].y + width / 2;
                    node.offsetY += layout._graphNodes[node.name].x + mod + height / 2;
                }
                else if (layout.orientation == "toptobottom") {
                    node.offsetX += layout._graphNodes[node.name].x + mod + width / 2;
                    node.offsetY += layout._graphNodes[node.name].y + height / 2;
                }
                else {
                    node.offsetX += layout._graphNodes[node.name].x + mod + width / 2;
                    node.offsetY -= layout._graphNodes[node.name].y + height / 2;
                }
            }
            if (this._hasChild(layout, node)) {
                for (i = 0; i < layout._graphNodes[node.name].tree.children.length; i++) {
                    child = layout.diagram.nameTable[layout._graphNodes[node.name].tree.children[i]];
                    this._updateNodes(layout, child, mod + (layout._graphNodes[node.name].subTreeTranslation || 0));
                }
            }
            if (layout._graphNodes[node.name].tree.assistants.length) {
                for (i = 0; i < layout._graphNodes[node.name].tree.assistants.length; i++) {
                    child = layout.diagram.nameTable[layout._graphNodes[node.name].tree.assistants[i]];
                    this._updateNodes(layout, child, mod + (layout._graphNodes[node.name].subTreeTranslation || 0));
                }
            }
            ej.datavisualization.Diagram.SpatialUtil._updateQuad(layout.diagram, layout.diagram._spatialSearch, node);
            if (layout.diagram._svg)
                ej.datavisualization.Diagram.DiagramContext.update(node, layout.diagram);
        },

        _getDimensions: function (layout, shape, x, y, level) {
            var width = shape.width ? shape.width : shape._width;
            var height = shape.height ? shape.height : shape._height;
            if (layout.orientation == "lefttoright" || layout.orientation == "righttoleft") {
                if (!level) {
                    var temp = x;
                    x = y;
                    y = temp;
                }
                height = shape.width ? shape.width : shape._width;
                width = shape.height ? shape.height : shape._height;
            }
            return { x: x, y: y, width: width, height: height };
        },

        _getParentNode: function (layout, node) {
            //Return the first parent node
            if (node.inEdges && node.inEdges.length) {
                return layout.diagram.nameTable[layout.diagram.nameTable[node.inEdges[0]].sourceNode];
            }
        },

        _hasChild: function (layout, shape) {
            //Check whether the node has children
            var shape = layout._graphNodes[shape.name];
            return shape.tree.children && shape.tree.children.length;
        },

        _setUpLayoutInfo: function (layout, item) {
            //Initialize graph node info
            var info = {};
            info.subTreeTranslation = 0;
            if (layout.type == "organizationalchart")
                info.tree = { orientation: "vertical", type: "alternate", offset: 20, enableRouting: true };
            else if (layout.type == "hierarchicaltree")
                info.tree = { orientation: "horizontal", type: "center", enableRouting: true };
            info.tree.children = [];
            info.tree.assistants = [];
            info.tree.level = 0;
            return info;
        }


    };
    //end region
})(jQuery, Syncfusion);