/**
* @fileOverview Plugin to style the Html Accordion elements
* @copyright Copyright Syncfusion Inc. 2001 - 2014. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/
(function ($, ej, undefined) {
    // ejmAccordion is the plugin name 
    // "ej.mobile.Accordion" is "namespace.className" will hold functions and properties
    /**
    * @namespace ej
    * @class ejmAccordion
    * @requires jQuery
    * @requires ej.mobile.application
    * @requires ej.core
    * @requires ej.unobtrusive
    * @requires ej.mobile.core
    * @requires ej.data
    * @requires ej.touch  
    * @classdesc Custom Design for Html Accordion control.
    * @example 
    * &lt;div id="accordion"&gt;
    *	 &lt;ul&gt;
    * 		&lt;li data-ej-text="Orubase"&gt;
    * 			&lt;div&gt;
    *				Orubase is the only mobile application development framework built especially for developing complex line-of-business mobile applications targeting iOS, Android, and Windows Phone platforms in the shortest possible timeframe.
    *			 &lt;/div&gt;
    *		 &lt;/li&gt;
    *		 &lt;li data-ej-text="WinRT XAML"&gt;
    * 			&lt;div&gt;
    *				Essential Studio for WinRT contains all the controls you need to build line-of-business tablet applications including grid, chart, map, tree map, SSRS report viewer, rich-text editor, PDF viewer, gauges, barcode, editors, and much more. It also includes a unique set of controls for reading and writing Excel, Word, and PDF documents in Windows store apps.
    * 			&lt;/div&gt;
    * 		&lt;/li&gt;
    *		&lt;li data-ej-text="Metro Studio"&gt;
    * 			&lt;div&gt;
    *				Syncfusion Metro Studio is a collection of over 2500 Metro-style icon templates that can be easily customized to create thousands of unique Metro icons.
    * 			&lt;/div&gt;
    * 		&lt;/li&gt;
    * 	&lt;/ul&gt;
    * &lt;/div&gt;
    * &lt;script&gt; 
    * // Create Accordion
    * $("#accordion").ejmAccordion(); 
    * &lt;/script&gt;
    */
    ej.widget("ejmAccordion", "ej.mobile.Accordion", {
        _setFirst: true,
        _rootCSS: "e-m-acc",
        validTags: ["div", "span"],
        _tags: [{
            tag: "items",
            attr: ["ajaxUrl", "logoClass"],
            content: "content"
        }],
        // default model
        defaults: {
            /// <summary>This Contains default property of Sycnfusion Accordion </summary>
            /**		
            * Specifies the rendering mode of the control. See {@link RenderMode}
            * @default auto 
            * @type {enum}
            * @example 
            * //Set the renderMode property in Unobtrusive way.
            * &lt;div id="accordion" data-role="ejmaccordion" data-ej-rendermode="auto"&gt;
            *	 &lt;ul&gt;
            * 		&lt;li data-ej-text="Grid Web"&gt;
            * 			&lt;div&gt;
            *				Work with ASP.NET AJAX's UpdatePanel. Essential Grid provides built-in support for hierarchical viewing, grouping, multicolumn sorting, filtering, summaries, and various data editors.
            *			 &lt;/div&gt;
            *		 &lt;/li&gt;
            *		 &lt;li data-ej-text="Diagram Web"&gt;
            * 			&lt;div&gt;
            *				Essential Diagram is an extensible, high-performance .NET diagramming framework for ASP.NET applications.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            *		&lt;li data-ej-text="DocIO Web"&gt;
            * 			&lt;div&gt;
            *				Essential DOCIO is a .NET library that can read, write, and modify Microsoft Word files.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * // Set accordion rendermode on initialization. 
            * //To set renderMode API value 
            * &lt;div id="accordion"&gt;
            *	 &lt;ul&gt;
            * 		&lt;li data-ej-text="Grid Web"&gt;
            * 			&lt;div&gt;
            *				Work with ASP.NET AJAX's UpdatePanel. Essential Grid provides built-in support for hierarchical viewing, grouping, multicolumn sorting, filtering, summaries, and various data editors.
            *			 &lt;/div&gt;
            *		 &lt;/li&gt;
            *		 &lt;li data-ej-text="Diagram Web"&gt;
            * 			&lt;div&gt;
            *				Essential Diagram is an extensible, high-performance .NET diagramming framework for ASP.NET applications.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            *		&lt;li data-ej-text="DocIO Web"&gt;
            * 			&lt;div&gt;
            *				Essential DOCIO is a .NET library that can read, write, and modify Microsoft Word files.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#accordion").ejmAccordion ({ renderMode: ej.mobile.RenderMode.Auto});
            * });
            * &lt;/script&gt;
            * @example
            * //Get or set the rendermode, after initialization:<br>
            * // Gets the renderMode API value.		
            *  $("#accordion").ejmAccordion ("option", "renderMode");			
            * // Sets the renderMode API
            * $("#accordion").ejmAccordion ("option", "renderMode", ej.mobile.RenderMode.Auto);
            * @memberof ejmAccordion
            * @instance
            */
            renderMode: "auto",
            /**		
            * Specifies whether the panels to be collapsible.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the collapsible property in Unobtrusive way.
            * &lt;div id="accordion" data-role="ejmaccordion" data-ej-collapsible="true"&gt;
            *	 &lt;ul&gt;
            * 		&lt;li data-ej-text="Grid Web"&gt;
            * 			&lt;div&gt;
            *				Work with ASP.NET AJAX's UpdatePanel. Essential Grid provides built-in support for hierarchical viewing, grouping, multicolumn sorting, filtering, summaries, and various data editors.
            *			 &lt;/div&gt;
            *		 &lt;/li&gt;
            *		 &lt;li data-ej-text="Diagram Web"&gt;
            * 			&lt;div&gt;
            *				Essential Diagram is an extensible, high-performance .NET diagramming framework for ASP.NET applications.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            *		&lt;li data-ej-text="DocIO Web"&gt;
            * 			&lt;div&gt;
            *				Essential DOCIO is a .NET library that can read, write, and modify Microsoft Word files.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * //To set collapsible API on intialization 
            * &lt;div id="accordion"&gt;
            *	 &lt;ul&gt;
            * 		&lt;li data-ej-text="Grid Web"&gt;
            * 			&lt;div&gt;
            *				Work with ASP.NET AJAX's UpdatePanel. Essential Grid provides built-in support for hierarchical viewing, grouping, multicolumn sorting, filtering, summaries, and various data editors.
            *			 &lt;/div&gt;
            *		 &lt;/li&gt;
            *		 &lt;li data-ej-text="Diagram Web"&gt;
            * 			&lt;div&gt;
            *				Essential Diagram is an extensible, high-performance .NET diagramming framework for ASP.NET applications.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            *		&lt;li data-ej-text="DocIO Web"&gt;
            * 			&lt;div&gt;
            *				Essential DOCIO is a .NET library that can read, write, and modify Microsoft Word files.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#accordion").ejmAccordion ({ collapsible: true });
            * });
            * &lt;/script&gt;
            * @example
            * //Get or set the accordion collapsible, after initialization:<br>
            * // Gets the collapsible API value.		
            *  $("#accordion").ejmAccordion ("option", "collapsible");			
            * // Sets the collapsible API
            * $("#accordion").ejmAccordion ("option", "collapsible", true);
            * @memberof ejmAccordion
            * @instance
            */
            collapsible: false,
            /**		
            * Specifies the indices of items that need to be in active state on initalization.
            * @default [0]
            * @type {integerarray}
            * @example 
            * //Set the selectedItems property in Unobtrusive way.
            * &lt;div id="accordion" data-role="ejmaccordion" data-ej-selecteditems="[1]"&gt;
            *	 &lt;ul&gt;
            * 		&lt;li data-ej-text="Grid Web"&gt;
            * 			&lt;div&gt;
            *				Work with ASP.NET AJAX's UpdatePanel. Essential Grid provides built-in support for hierarchical viewing, grouping, multicolumn sorting, filtering, summaries, and various data editors.
            *			 &lt;/div&gt;
            *		 &lt;/li&gt;
            *		 &lt;li data-ej-text="Diagram Web"&gt;
            * 			&lt;div&gt;
            *				Essential Diagram is an extensible, high-performance .NET diagramming framework for ASP.NET applications.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            *		&lt;li data-ej-text="DocIO Web"&gt;
            * 			&lt;div&gt;
            *				Essential DOCIO is a .NET library that can read, write, and modify Microsoft Word files.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * // Set selectedItems on initialization. 
            * &lt;div id="accordion"&gt;
            *	 &lt;ul&gt;
            * 		&lt;li data-ej-text="Grid Web"&gt;
            * 			&lt;div&gt;
            *				Work with ASP.NET AJAX's UpdatePanel. Essential Grid provides built-in support for hierarchical viewing, grouping, multicolumn sorting, filtering, summaries, and various data editors.
            *			 &lt;/div&gt;
            *		 &lt;/li&gt;
            *		 &lt;li data-ej-text="Diagram Web"&gt;
            * 			&lt;div&gt;
            *				Essential Diagram is an extensible, high-performance .NET diagramming framework for ASP.NET applications.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            *		&lt;li data-ej-text="DocIO Web"&gt;
            * 			&lt;div&gt;
            *				Essential DOCIO is a .NET library that can read, write, and modify Microsoft Word files.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#accordion").ejmAccordion ({ selectedItems: [1]});
            * });
            * &lt;/script&gt;
            * @example
            * //Get or set the selectedItems, after initialization:<br>
            * // Gets the selectedItems API value.		
            *  $("#accordion").ejmAccordion ("option", "selectedItems");			
            * // Sets the selectedItems API
            * $("#accordion").ejmAccordion ("option", "selectedItems", [1]);
            * @memberof ejmAccordion
            * @instance
            */
            selectedItems: [0],
            /**		
            * Specifies the indices of item to be disabled.
            * @default []
            * @type {integerarray}
            * @example 
            * //Set the disabledItems property in Unobtrusive way.
            * &lt;div id="accordion" data-role="ejmaccordion" data-ej-disableditems="[1]"&gt;
            *	 &lt;ul&gt;
            * 		&lt;li data-ej-text="Grid Web"&gt;
            * 			&lt;div&gt;
            *				Work with ASP.NET AJAX's UpdatePanel. Essential Grid provides built-in support for hierarchical viewing, grouping, multicolumn sorting, filtering, summaries, and various data editors.
            *			 &lt;/div&gt;
            *		 &lt;/li&gt;
            *		 &lt;li data-ej-text="Diagram Web"&gt;
            * 			&lt;div&gt;
            *				Essential Diagram is an extensible, high-performance .NET diagramming framework for ASP.NET applications.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            *		&lt;li data-ej-text="DocIO Web"&gt;
            * 			&lt;div&gt;
            *				Essential DOCIO is a .NET library that can read, write, and modify Microsoft Word files.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * // Set accordion disabledItems on initialization. 
            * &lt;div id="accordion"&gt;
            *	 &lt;ul&gt;
            * 		&lt;li data-ej-text="Grid Web"&gt;
            * 			&lt;div&gt;
            *				Work with ASP.NET AJAX's UpdatePanel. Essential Grid provides built-in support for hierarchical viewing, grouping, multicolumn sorting, filtering, summaries, and various data editors.
            *			 &lt;/div&gt;
            *		 &lt;/li&gt;
            *		 &lt;li data-ej-text="Diagram Web"&gt;
            * 			&lt;div&gt;
            *				Essential Diagram is an extensible, high-performance .NET diagramming framework for ASP.NET applications.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            *		&lt;li data-ej-text="DocIO Web"&gt;
            * 			&lt;div&gt;
            *				Essential DOCIO is a .NET library that can read, write, and modify Microsoft Word files.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#accordion").ejmAccordion ({ disabledItems: [1]});
            * });
            * &lt;/script&gt;
            * @example
            * //Get or set the disabledItems, after initialization:<br>
            * // Gets the disabledItems API value.		
            *  $("#accordion").ejmAccordion ("option", "disabledItems");			
            * // Sets the disabledItems API
            * $("#accordion").ejmAccordion ("option", "disabledItems", [1]);
            * @memberof ejmAccordion
            * @instance
            */
            disabledItems: [],
            /**		
            * Specifies the theme. See {@link Theme}
            * @default auto
            * @type {enum}
            * @example 
            * //Set the theme property in Unobtrusive way.
            * &lt;div id="accordion" data-role="ejmaccordion" data-ej-theme="auto"&gt;
            *	 &lt;ul&gt;
            * 		&lt;li data-ej-text="Grid Web"&gt;
            * 			&lt;div&gt;
            *				Work with ASP.NET AJAX's UpdatePanel. Essential Grid provides built-in support for hierarchical viewing, grouping, multicolumn sorting, filtering, summaries, and various data editors.
            *			 &lt;/div&gt;
            *		 &lt;/li&gt;
            *		 &lt;li data-ej-text="Diagram Web"&gt;
            * 			&lt;div&gt;
            *				Essential Diagram is an extensible, high-performance .NET diagramming framework for ASP.NET applications.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            *		&lt;li data-ej-text="DocIO Web"&gt;
            * 			&lt;div&gt;
            *				Essential DOCIO is a .NET library that can read, write, and modify Microsoft Word files.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * // Set accordion theme on initialization. 
            * &lt;div id="accordion"&gt;
            *	 &lt;ul&gt;
            * 		&lt;li data-ej-text="Grid Web"&gt;
            * 			&lt;div&gt;
            *				Work with ASP.NET AJAX's UpdatePanel. Essential Grid provides built-in support for hierarchical viewing, grouping, multicolumn sorting, filtering, summaries, and various data editors.
            *			 &lt;/div&gt;
            *		 &lt;/li&gt;
            *		 &lt;li data-ej-text="Diagram Web"&gt;
            * 			&lt;div&gt;
            *				Essential Diagram is an extensible, high-performance .NET diagramming framework for ASP.NET applications.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            *		&lt;li data-ej-text="DocIO Web"&gt;
            * 			&lt;div&gt;
            *				Essential DOCIO is a .NET library that can read, write, and modify Microsoft Word files.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#accordion").ejmAccordion ({ theme: ej.mobile.Theme.Auto});
            * });
            * &lt;/script&gt;
            * @example
            * //Get or set the theme, after initialization:<br>
            * // Gets the theme API value.		
            *  $("#accordion").ejmAccordion ("option", "theme");			
            * // Sets the theme API
            * $("#accordion").ejmAccordion ("option", "theme", ej.mobile.Theme.Auto);
            * @memberof ejmAccordion
            * @instance
            */
            theme: "auto",
            /**		
            * Specifies the height style of the control.  See {@link HeightAdjustMode}
            * @default ej.mobile.Accordion.HeightAdjustMode.Content.
            * @type {enum}
            * @example 
            * //Set the heightAdjustMode property in Unobtrusive way.
            * &lt;div id="accordion" data-role="ejmaccordion" data-ej-heightadjustmode="content"&gt;
            *	 &lt;ul&gt;
            * 		&lt;li data-ej-text="Grid Web"&gt;
            * 			&lt;div&gt;
            *				Work with ASP.NET AJAX's UpdatePanel. Essential Grid provides built-in support for hierarchical viewing, grouping, multicolumn sorting, filtering, summaries, and various data editors.
            *			 &lt;/div&gt;
            *		 &lt;/li&gt;
            *		 &lt;li data-ej-text="Diagram Web"&gt;
            * 			&lt;div&gt;
            *				Essential Diagram is an extensible, high-performance .NET diagramming framework for ASP.NET applications.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            *		&lt;li data-ej-text="DocIO Web"&gt;
            * 			&lt;div&gt;
            *				Essential DOCIO is a .NET library that can read, write, and modify Microsoft Word files.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * // Set accordion heightAdjustMode on initialization. 
            * &lt;div id="accordion"&gt;
            *	 &lt;ul&gt;
            * 		&lt;li data-ej-text="Grid Web"&gt;
            * 			&lt;div&gt;
            *				Work with ASP.NET AJAX's UpdatePanel. Essential Grid provides built-in support for hierarchical viewing, grouping, multicolumn sorting, filtering, summaries, and various data editors.
            *			 &lt;/div&gt;
            *		 &lt;/li&gt;
            *		 &lt;li data-ej-text="Diagram Web"&gt;
            * 			&lt;div&gt;
            *				Essential Diagram is an extensible, high-performance .NET diagramming framework for ASP.NET applications.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            *		&lt;li data-ej-text="DocIO Web"&gt;
            * 			&lt;div&gt;
            *				Essential DOCIO is a .NET library that can read, write, and modify Microsoft Word files.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#accordion").ejmAccordion ({ heightAdjustMode: ej.mobile.Accordion.heightAdjustMode.Content});
            * });
            * &lt;/script&gt;
            * @example
            * //Get or set the accordion heightAdjustMode, after initialization:<br>
            * // Gets the heightAdjustMode API value.		
            *  $("#accordion").ejmAccordion ("option", "heightAdjustMode");			
            * // Sets the heightAdjustMode API
            * $("#accordion").ejmAccordion ("option", "heightAdjustMode", ej.mobile.Accordion.heightAdjustMode.Content);
            * @memberof ejmAccordion
            * @instance
            */
            heightAdjustMode: "content",
            /**		
            * Specifies whether to show the header icon in the panel.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the showHeaderIcon property in Unobtrusive way.
            * &lt;div id="accordion" data-role="ejmaccordion" data-ej-showheadericon="true"&gt;
            *	 &lt;ul&gt;
            * 		&lt;li data-ej-text="Grid Web"&gt;
            * 			&lt;div&gt;
            *				Work with ASP.NET AJAX's UpdatePanel. Essential Grid provides built-in support for hierarchical viewing, grouping, multicolumn sorting, filtering, summaries, and various data editors.
            *			 &lt;/div&gt;
            *		 &lt;/li&gt;
            *		 &lt;li data-ej-text="Diagram Web"&gt;
            * 			&lt;div&gt;
            *				Essential Diagram is an extensible, high-performance .NET diagramming framework for ASP.NET applications.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            *		&lt;li data-ej-text="DocIO Web"&gt;
            * 			&lt;div&gt;
            *				Essential DOCIO is a .NET library that can read, write, and modify Microsoft Word files.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * // Set accordion showHeaderIcon on initialization. 
            * &lt;div id="accordion"&gt;
            *	 &lt;ul&gt;
            * 		&lt;li data-ej-text="Grid Web"&gt;
            * 			&lt;div&gt;
            *				Work with ASP.NET AJAX's UpdatePanel. Essential Grid provides built-in support for hierarchical viewing, grouping, multicolumn sorting, filtering, summaries, and various data editors.
            *			 &lt;/div&gt;
            *		 &lt;/li&gt;
            *		 &lt;li data-ej-text="Diagram Web"&gt;
            * 			&lt;div&gt;
            *				Essential Diagram is an extensible, high-performance .NET diagramming framework for ASP.NET applications.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            *		&lt;li data-ej-text="DocIO Web"&gt;
            * 			&lt;div&gt;
            *				Essential DOCIO is a .NET library that can read, write, and modify Microsoft Word files.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#accordion").ejmAccordion ({ showHeaderIcon: true});
            * });
            * &lt;/script&gt;
            * @example
            * //Get or set the accordion showHeaderIcon, after initialization:<br>
            * // Gets the showHeaderIcon API value.		
            *  $("#accordion").ejmAccordion ("option", "showHeaderIcon");			
            * // Sets the showHeaderIcon API
            * $("#accordion").ejmAccordion ("option", "showHeaderIcon", true);
            * @memberof ejmAccordion
            * @instance
            */
            showHeaderIcon: false,
            /**
            * Specifies whether to enable caching the content.
            * @default true
            * @type {boolean}
            * @example 
            * //Set the enableCache property in Unobtrusive way.
            * &lt;div id="accordion" data-role="ejmaccordion" data-ej-enableCache="false"&gt;
            *	 &lt;ul&gt;
            * 		&lt;li data-ej-text="Grid Web" data-ej-ajaxurl="text1.html"&gt;
            *		&lt;/li&gt;
            *		&lt;li data-ej-text="Diagram Web" data-ej-ajaxurl="text2.html"&gt;
            * 		&lt;/li&gt;
            *		&lt;li data-ej-text="DocIO Web" data-ej-ajaxurl="text3.html"&gt;
            * 		&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example
            * //Create the text1.html file with following content.
            *    Work with ASP.NET AJAX's UpdatePanel. Essential Grid provides built-in support for hierarchical viewing, grouping, multicolumn sorting, filtering, summaries, and various data editors.
            *
            * //Create the text2.html file with following content.
            *     Essential Diagram is an extensible, high-performance .NET diagramming framework for ASP.NET applications.
            *
            * //Create the text3.html file with following content.
            *     Essential DOCIO is a .NET library that can read, write, and modify Microsoft Word files.
            *
            * @example 
            * // Set enableCache on initialization. 
            * //To set enableCache API value 
            * &lt;div id="accordion"&gt;
            *	 &lt;ul&gt;
            * 		&lt;li data-ej-text="Grid Web" data-ej-ajaxurl="text1.html"&gt;
            *		&lt;/li&gt;
            *		&lt;li data-ej-text="Diagram Web" data-ej-ajaxurl="text2.html"&gt;
            * 		&lt;/li&gt;
            *		&lt;li data-ej-text="DocIO Web" data-ej-ajaxurl="text3.html"&gt;
            * 		&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#accordion").ejmAccordion ({ enableCache: false });
            * });
            * &lt;/script&gt;
            * @example
            * //Get or set the enableCache, after initialization:<br>
            * // Gets the enableCache API value.		
            *  $("#accordion").ejmAccordion ("option", "enableCache");			
            * // Sets the enableCache API
            * $("#accordion").ejmAccordion ("option", "enableCache", false);
            * @memberof ejmAccordion
            * @instance
            */
            enableCache: true,
            /**
            * Specifies whether to activate multiple content panels at a time.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the enableMultipleOpen property in Unobtrusive way.
            * &lt;div id="accordion" data-role="ejmaccordion" data-ej-enablemultipleopen="true" data-ej-selectedItems="[0,1]"&gt;
            *	 &lt;ul&gt;
            * 		&lt;li data-ej-text="Grid Web"&gt;
            * 			&lt;div&gt;
            *				Work with ASP.NET AJAX's UpdatePanel. Essential Grid provides built-in support for hierarchical viewing, grouping, multicolumn sorting, filtering, summaries, and various data editors.
            *			 &lt;/div&gt;
            *		 &lt;/li&gt;
            *		 &lt;li data-ej-text="Diagram Web"&gt;
            * 			&lt;div&gt;
            *				Essential Diagram is an extensible, high-performance .NET diagramming framework for ASP.NET applications.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            *		&lt;li data-ej-text="DocIO Web"&gt;
            * 			&lt;div&gt;
            *				Essential DOCIO is a .NET library that can read, write, and modify Microsoft Word files.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * // Set enableMultipleOpen on initialization. 
            * &lt;div id="accordion"&gt;
            *	 &lt;ul&gt;
            * 		&lt;li data-ej-text="Grid Web"&gt;
            * 			&lt;div&gt;
            *				Work with ASP.NET AJAX's UpdatePanel. Essential Grid provides built-in support for hierarchical viewing, grouping, multicolumn sorting, filtering, summaries, and various data editors.
            *			 &lt;/div&gt;
            *		 &lt;/li&gt;
            *		 &lt;li data-ej-text="Diagram Web"&gt;
            * 			&lt;div&gt;
            *				Essential Diagram is an extensible, high-performance .NET diagramming framework for ASP.NET applications.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            *		&lt;li data-ej-text="DocIO Web"&gt;
            * 			&lt;div&gt;
            *				Essential DOCIO is a .NET library that can read, write, and modify Microsoft Word files.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#accordion").ejmAccordion ({ enableMultipleOpen: true});
            * });
            * &lt;/script&gt;
            * @example
            * //Get or set the enableMultipleOpen, after initialization:<br>
            * // Gets the enableMultipleOpen API value.		
            *  $("#accordion").ejmAccordion ("option", "enableMultipleOpen");			
            * // Sets the enableMultipleOpen API
            * $("#accordion").ejmAccordion ("option", "enableMultipleOpen", true);
            * @memberof ejmAccordion
            * @instance
            */
            enableMultipleOpen: false,
            /**
            * Specifies to maintain the current model value to browser cookies for state maintenance. While refresh the page, the model value will get apply to the control from browser cookies.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the enablePersistence property in Unobtrusive way.
            * &lt;div id="accordion" data-role="ejmaccordion" data-ej-enablepersistence="true"&gt;
            *	 &lt;ul&gt;
            * 		&lt;li data-ej-text="Grid Web"&gt;
            * 			&lt;div&gt;
            *				Work with ASP.NET AJAX's UpdatePanel. Essential Grid provides built-in support for hierarchical viewing, grouping, multicolumn sorting, filtering, summaries, and various data editors.
            *			 &lt;/div&gt;
            *		 &lt;/li&gt;
            *		 &lt;li data-ej-text="Diagram Web"&gt;
            * 			&lt;div&gt;
            *				Essential Diagram is an extensible, high-performance .NET diagramming framework for ASP.NET applications.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            *		&lt;li data-ej-text="DocIO Web"&gt;
            * 			&lt;div&gt;
            *				Essential DOCIO is a .NET library that can read, write, and modify Microsoft Word files.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * // Set enablePersistence on initialization.  
            * &lt;div id="accordion"&gt;
            *	 &lt;ul&gt;
            * 		&lt;li data-ej-text="Grid Web"&gt;
            * 			&lt;div&gt;
            *				Work with ASP.NET AJAX's UpdatePanel. Essential Grid provides built-in support for hierarchical viewing, grouping, multicolumn sorting, filtering, summaries, and various data editors.
            *			 &lt;/div&gt;
            *		 &lt;/li&gt;
            *		 &lt;li data-ej-text="Diagram Web"&gt;
            * 			&lt;div&gt;
            *				Essential Diagram is an extensible, high-performance .NET diagramming framework for ASP.NET applications.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            *		&lt;li data-ej-text="DocIO Web"&gt;
            * 			&lt;div&gt;
            *				Essential DOCIO is a .NET library that can read, write, and modify Microsoft Word files.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#accordion").ejmAccordion ({ enablePersistence: true});
            * });
            * &lt;/script&gt;
            * @example
            * //Get or set the enablePersistence, after initialization:<br>
            * // Gets the persist API value.		
            *  $("#accordion").ejmAccordion ("option", "enablePersistence");			
            * // Sets the persist API
            * $("#accordion").ejmAccordion ("option", "enablePersistence", true);
            * @memberof ejmAccordion
            * @instance
            */
            enablePersistence: false,
            /**
            * Specifies whether to enable or disable the control.
            * @default true
            * @type {boolean}
            * @example 
            * //Set the enabled property in Unobtrusive way.
            * &lt;div id="accordion" data-role="ejmaccordion" data-ej-enabled="false"&gt;
            *	 &lt;ul&gt;
            * 		&lt;li data-ej-text="Grid Web"&gt;
            * 			&lt;div&gt;
            *				Work with ASP.NET AJAX's UpdatePanel. Essential Grid provides built-in support for hierarchical viewing, grouping, multicolumn sorting, filtering, summaries, and various data editors.
            *			 &lt;/div&gt;
            *		 &lt;/li&gt;
            *		 &lt;li data-ej-text="Diagram Web"&gt;
            * 			&lt;div&gt;
            *				Essential Diagram is an extensible, high-performance .NET diagramming framework for ASP.NET applications.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            *		&lt;li data-ej-text="DocIO Web"&gt;
            * 			&lt;div&gt;
            *				Essential DOCIO is a .NET library that can read, write, and modify Microsoft Word files.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * // Set enabled property on initialization. 
            * &lt;div id="accordion"&gt;
            *	 &lt;ul&gt;
            * 		&lt;li data-ej-text="Grid Web"&gt;
            * 			&lt;div&gt;
            *				Work with ASP.NET AJAX's UpdatePanel. Essential Grid provides built-in support for hierarchical viewing, grouping, multicolumn sorting, filtering, summaries, and various data editors.
            *			 &lt;/div&gt;
            *		 &lt;/li&gt;
            *		 &lt;li data-ej-text="Diagram Web"&gt;
            * 			&lt;div&gt;
            *				Essential Diagram is an extensible, high-performance .NET diagramming framework for ASP.NET applications.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            *		&lt;li data-ej-text="DocIO Web"&gt;
            * 			&lt;div&gt;
            *				Essential DOCIO is a .NET library that can read, write, and modify Microsoft Word files.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#accordion").ejmAccordion ({ enabled: false});
            * });
            * &lt;/script&gt;
            * @example
            * //Get or set the enabled, after initialization:<br>
            * // Gets the enabled API value.		
            *  $("#accordion").ejmAccordion ("option", "enabled");			
            * // Sets the enabled API
            * $("#accordion").ejmAccordion ("option", "enabled", false);
            * @memberof ejmAccordion
            * @instance
            */
            enabled: true,
            /**
            * Specifies the spinner text.
            * @default loading...
            * @type String
            * @example 
            * // Set the Accordion spinnerText property in Unobtrusive way.
            * &lt;div id="accordion" data-role="ejmaccordion" data-ej-spinnerText="loading..."&gt;
            *	 &lt;ul&gt;
            * 		&lt;li data-ej-text="Grid Web" data-ej-ajaxurl="text1.html"&gt;
            *		&lt;/li&gt;
            *		&lt;li data-ej-text="Diagram Web" data-ej-ajaxurl="text2.html"&gt;
            * 		&lt;/li&gt;
            *		&lt;li data-ej-text="DocIO Web" data-ej-ajaxurl="text3.html"&gt;
            * 		&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example
            * //Create the text1.html file with following content.
            *    Work with ASP.NET AJAX's UpdatePanel. Essential Grid provides built-in support for hierarchical viewing, grouping, multicolumn sorting, filtering, summaries, and various data editors.
            *
            * //Create the text2.html file with following content.
            *     Essential Diagram is an extensible, high-performance .NET diagramming framework for ASP.NET applications.
            *
            * //Create the text3.html file with following content.
            *     Essential DOCIO is a .NET library that can read, write, and modify Microsoft Word files.
            *
            * @example 
            * // Set spinnerText property on initialization. 
            * &lt;div id="accordion"&gt;
            *	 &lt;ul&gt;
            * 		&lt;li data-ej-text="Grid Web" data-ej-ajaxurl="text1.html"&gt;
            *		&lt;/li&gt;
            *		&lt;li data-ej-text="Diagram Web" data-ej-ajaxurl="text2.html"&gt;
            * 		&lt;/li&gt;
            *		&lt;li data-ej-text="DocIO Web" data-ej-ajaxurl="text3.html"&gt;
            * 		&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#accordion").ejmAccordion ({ spinnerText: "loading..."});
            * });
            * &lt;/script&gt;
            * @example
            * //Get or set the spinnerText, after initialization:<br>
            * // Gets the spinnerText API value.		
            *  $("#accordion").ejmAccordion ("option", "spinnerText");			
            * // Sets the spinnerText API
            * $("#accordion").ejmAccordion ("option", "spinnerText", "loading...");
            * @memberof ejmAccordion
            * @instance
            */
            spinnerText: "loading...",
            /**     
            * Section for windows mode specific functionalities.                      
            * @memberof ejmAccordion
            * @instance
            */
            windows: {
                /**  
                * Specifies whether to render control based on the windowsphone's current accent color and device theme.
                * @default false
                * @type {boolean}
                * @alias ejmAccordion#windows->renderDefault
                * @example 
                * // Set the windows mode renderDefault property in Unobtrusive way.
                * &lt;div id="accordion" data-role="ejmaccordion" data-ej-rendermode="windows" data-ej-windows-renderdefault="true"&gt;
                *	 &lt;ul&gt;
                * 		&lt;li data-ej-text="Grid Web"&gt;
                * 			&lt;div&gt;
                *				Work with ASP.NET AJAX's UpdatePanel. Essential Grid provides built-in support for hierarchical viewing, grouping, multicolumn sorting, filtering, summaries, and various data editors.
                *			 &lt;/div&gt;
                *		 &lt;/li&gt;
                *		 &lt;li data-ej-text="Diagram Web"&gt;
                * 			&lt;div&gt;
                *				Essential Diagram is an extensible, high-performance .NET diagramming framework for ASP.NET applications.
                * 			&lt;/div&gt;
                * 		&lt;/li&gt;
                *		&lt;li data-ej-text="DocIO Web"&gt;
                * 			&lt;div&gt;
                *				Essential DOCIO is a .NET library that can read, write, and modify Microsoft Word files.
                * 			&lt;/div&gt;
                * 		&lt;/li&gt;
                * 	&lt;/ul&gt;
                * &lt;/div&gt;
                * @example 
                * // To set windows mode renderDefault property API value on initialization
                * &lt;div id="accordion"&gt;
                *	 &lt;ul&gt;
                * 		&lt;li data-ej-text="Grid Web"&gt;
                * 			&lt;div&gt;
                *				Work with ASP.NET AJAX's UpdatePanel. Essential Grid provides built-in support for hierarchical viewing, grouping, multicolumn sorting, filtering, summaries, and various data editors.
                *			 &lt;/div&gt;
                *		 &lt;/li&gt;
                *		 &lt;li data-ej-text="Diagram Web"&gt;
                * 			&lt;div&gt;
                *				Essential Diagram is an extensible, high-performance .NET diagramming framework for ASP.NET applications.
                * 			&lt;/div&gt;
                * 		&lt;/li&gt;
                *		&lt;li data-ej-text="DocIO Web"&gt;
                * 			&lt;div&gt;
                *				Essential DOCIO is a .NET library that can read, write, and modify Microsoft Word files.
                * 			&lt;/div&gt;
                * 		&lt;/li&gt;
                * 	&lt;/ul&gt;
                * &lt;/div&gt;
                * &lt;script&gt;
                * $(function(){
                * $("#accordion").ejmAccordion ({ renderMode:"windows", windows:{renderDefault: true}});
                * });
                * &lt;/script&gt;
                * @example 
                * // Get or set the windows mode renderDefault API, after initialization:
                * // Gets the windows mode renderDefault value  
                * $("#accordion").ejmAccordion("option", "windows.renderDefault");   
                * // Sets the windows mode renderDefault value 
                *$("#accordion").ejmAccordion("option", "windows.renderDefault", true); 
                * @memberof ejmAccordion
                * @instance
                */
                "renderDefault": false
            },
            items: [],
            //Events
            /**    
            * Event triggers after the panel item gets activated.
            * @event
            * @name ejmAccordion#active 	
            * @param {Object} argument Event parameters from Accordion.
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @param {number} argument.selectedItemIndices returns active panel index.
            * @param {number} argument.lastSelectedItemIndices returns previous active panel index.
            * @param {number} argument.items returns all the panel items.
            * @example 
            * // Bind the active event using Unobtrusive way.
            * &lt;div id="accordion" data-role="ejmaccordion" data-ej-active="active"&gt;
            *	 &lt;ul&gt;
            * 		&lt;li data-ej-text="Grid Web"&gt;
            * 			&lt;div&gt;
            *				Work with ASP.NET AJAX's UpdatePanel. Essential Grid provides built-in support for hierarchical viewing, grouping, multicolumn sorting, filtering, summaries, and various data editors.
            *			 &lt;/div&gt;
            *		 &lt;/li&gt;
            *		 &lt;li data-ej-text="Diagram Web"&gt;
            * 			&lt;div&gt;
            *				Essential Diagram is an extensible, high-performance .NET diagramming framework for ASP.NET applications.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            *		&lt;li data-ej-text="DocIO Web"&gt;
            * 			&lt;div&gt;
            *				Essential DOCIO is a .NET library that can read, write, and modify Microsoft Word files.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
			* // Bind the active event using Obtrusive way.
            * &lt;div id="accordion" data-role="ejmaccordion" &gt;
            *	 &lt;ul&gt;
            * 		&lt;li data-ej-text="Grid Web"&gt;
            * 			&lt;div&gt;
            *				Work with ASP.NET AJAX's UpdatePanel. Essential Grid provides built-in support for hierarchical viewing, grouping, multicolumn sorting, filtering, summaries, and various data editors.
            *			 &lt;/div&gt;
            *		 &lt;/li&gt;
            *		 &lt;li data-ej-text="Diagram Web"&gt;
            * 			&lt;div&gt;
            *				Essential Diagram is an extensible, high-performance .NET diagramming framework for ASP.NET applications.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            *		&lt;li data-ej-text="DocIO Web"&gt;
            * 			&lt;div&gt;
            *				Essential DOCIO is a .NET library that can read, write, and modify Microsoft Word files.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * //Active event for Accordion
            * &lt;script&gt;
            * $("#accordion").ejmAccordion({
            *   	active: function (args) { //handle the event 
            * }
            *	});         
            * &lt;/script&gt; 
            * @memberof ejmAccordion
            * @instance
            */
            active: null,
            /**    
            * Event triggers before the panel item gets activated.
            * @event
            * @name ejmAccordion#beforeActive
            * @param {Object} argument Event parameters from Accordion.
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @param {Object} argument.activeItemIndex returns the active panel index.
            * @example 
            * // Bind the beforeActive event using Unobtrusive way.
            * &lt;div id="accordion" data-role="ejmaccordion" data-ej-beforeactive="beforeActive"&gt;
            *	 &lt;ul&gt;
            * 		&lt;li data-ej-text="Grid Web"&gt;
            * 			&lt;div&gt;
            *				Work with ASP.NET AJAX's UpdatePanel. Essential Grid provides built-in support for hierarchical viewing, grouping, multicolumn sorting, filtering, summaries, and various data editors.
            *			 &lt;/div&gt;
            *		 &lt;/li&gt;
            *		 &lt;li data-ej-text="Diagram Web"&gt;
            * 			&lt;div&gt;
            *				Essential Diagram is an extensible, high-performance .NET diagramming framework for ASP.NET applications.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            *		&lt;li data-ej-text="DocIO Web"&gt;
            * 			&lt;div&gt;
            *				Essential DOCIO is a .NET library that can read, write, and modify Microsoft Word files.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * //BeforeActive event for Accordion
			* // Bind the BeforeActive event using obtrusive way.
            * &lt;div id="accordion" data-role="ejmaccordion" &gt;
            *	 &lt;ul&gt;
            * 		&lt;li data-ej-text="Grid Web"&gt;
            * 			&lt;div&gt;
            *				Work with ASP.NET AJAX's UpdatePanel. Essential Grid provides built-in support for hierarchical viewing, grouping, multicolumn sorting, filtering, summaries, and various data editors.
            *			 &lt;/div&gt;
            *		 &lt;/li&gt;
            *		 &lt;li data-ej-text="Diagram Web"&gt;
            * 			&lt;div&gt;
            *				Essential Diagram is an extensible, high-performance .NET diagramming framework for ASP.NET applications.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            *		&lt;li data-ej-text="DocIO Web"&gt;
            * 			&lt;div&gt;
            *				Essential DOCIO is a .NET library that can read, write, and modify Microsoft Word files.
            * 			&lt;/div&gt;
            * 		&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt; 
            * $("#accordion").ejmAccordion({
            *   	beforeActive: function (args) { //handle the event 
            * }
            *	});  
            * &lt;/script&gt; 
            * @memberof ejmAccordion
            * @instance
            */
            beforeActive: null,
            /**     
            * Event triggers after the ajax content is loaded.
            * @event
            * @name ejmAccordion#ajaxLoad		
            * @param {Object} argument Event parameters from Accordion.
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @example 
            * // Bind the ajaxLoad event using Unobtrusive way.
            * &lt;div id="accordion" data-role="ejmaccordion" data-ej-ajaxload="ajaxLoad"&gt;
            *	 &lt;ul&gt;
            * 		&lt;li data-ej-text="Grid Web" data-ej-ajaxurl="text1.html"&gt;
            *		&lt;/li&gt;
            *		&lt;li data-ej-text="Diagram Web" data-ej-ajaxurl="text2.html"&gt;
            * 		&lt;/li&gt;
            *		&lt;li data-ej-text="DocIO Web" data-ej-ajaxurl="text3.html"&gt;
            * 		&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example
            * //Create the text1.html file with following content.
            *    Work with ASP.NET AJAX's UpdatePanel. Essential Grid provides built-in support for hierarchical viewing, grouping, multicolumn sorting, filtering, summaries, and various data editors.
            *
            * //Create the text2.html file with following content.
            *     Essential Diagram is an extensible, high-performance .NET diagramming framework for ASP.NET applications.
            *
            * //Create the text3.html file with following content.
            *     Essential DOCIO is a .NET library that can read, write, and modify Microsoft Word files.
            *
            * @example 
            * // Bind the ajaxLoad event using Obtrusive way.
            * &lt;div id="accordion" data-role="ejmaccordion" &gt;
            *	 &lt;ul&gt;
            * 		&lt;li data-ej-text="Grid Web" data-ej-ajaxurl="text1.html"&gt;
            *		&lt;/li&gt;
            *		&lt;li data-ej-text="Diagram Web" data-ej-ajaxurl="text2.html"&gt;
            * 		&lt;/li&gt;
            *		&lt;li data-ej-text="DocIO Web" data-ej-ajaxurl="text3.html"&gt;
            * 		&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * //initial ajaxLoad event
            * &lt;script&gt; 
            *	$("#accordion").ejmAccordion({ 
            *		ajaxLoad: function (args) { //handle the event
            * }
            * 	});
            * &lt;/script&gt; 
            * @memberof ejmAccordion
            * @instance
            */
            ajaxLoad: null,
            /**     
            * Event triggers before the ajax content loads.
            * @event
            * @name ejmAccordion#ajaxBeforeLoad	
            * @param {Object} argument Event parameters from Accordion.
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @param {string}  argument.url returns current ajax content location.
            * @example 
            * // Bind the ajaxBeforeLoad event using Unobtrusive way.
            * &lt;div id="accordion" data-role="ejmaccordion" data-ej-ajaxbeforeload="ajaxBeforeLoad"&gt;
            *	 &lt;ul&gt;
            * 		&lt;li data-ej-text="Grid Web" data-ej-ajaxurl="text1.html"&gt;
            *		&lt;/li&gt;
            *		&lt;li data-ej-text="Diagram Web" data-ej-ajaxurl="text2.html"&gt;
            * 		&lt;/li&gt;
            *		&lt;li data-ej-text="DocIO Web" data-ej-ajaxurl="text3.html"&gt;
            * 		&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example
            * //Create the text1.html file with following content.
            *    Work with ASP.NET AJAX's UpdatePanel. Essential Grid provides built-in support for hierarchical viewing, grouping, multicolumn sorting, filtering, summaries, and various data editors.
            *
            * //Create the text2.html file with following content.
            *     Essential Diagram is an extensible, high-performance .NET diagramming framework for ASP.NET applications.
            *
            * //Create the text3.html file with following content.
            *     Essential DOCIO is a .NET library that can read, write, and modify Microsoft Word files.
            *
            * @example 
            * // Bind the ajaxBeforeLoad event using Obtrusive way.
            * &lt;div id="accordion" data-role="ejmaccordion" &gt;
            *	 &lt;ul&gt;
            * 		&lt;li data-ej-text="Grid Web" data-ej-ajaxurl="text1.html"&gt;
            *		&lt;/li&gt;
            *		&lt;li data-ej-text="Diagram Web" data-ej-ajaxurl="text2.html"&gt;
            * 		&lt;/li&gt;
            *		&lt;li data-ej-text="DocIO Web" data-ej-ajaxurl="text3.html"&gt;
            * 		&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * //initial ajaxBeforeLoad event
            * &lt;script&gt; 
            *	$("#accordion").ejmAccordion({ 
            *		ajaxBeforeLoad: function (args) {//handle the event
            * }
            * 	});
            * &lt;/script&gt; 
            * @memberof ejmAccordion
            * @instance
            */
            ajaxBeforeLoad: null,
            /**     
            * Event triggers after the ajax content loaded successfully.
            * @event
            * @name ejmAccordion#ajaxSuccess		
            * @param {Object} argument Event parameters from Accordion.
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @param {string}  argument.url returns current ajax content location.
            * @param {string}  argument.data returns the succesfull data sent.
            * @param {string}  argument.content returns the ajax content.
            * @example 
            * // Bind the ajaxSuccess event using Unobtrusive way.
            * &lt;div id="accordion" data-role="ejmaccordion" data-ej-ajaxsuccess="ajaxSuccess"&gt;
            *	 &lt;ul&gt;
            * 		&lt;li data-ej-text="Grid Web" data-ej-ajaxurl="text1.html"&gt;
            *		&lt;/li&gt;
            *		&lt;li data-ej-text="Diagram Web" data-ej-ajaxurl="text2.html"&gt;
            * 		&lt;/li&gt;
            *		&lt;li data-ej-text="DocIO Web" data-ej-ajaxurl="text3.html"&gt;
            * 		&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example
            * //Create the text1.html file with following content.
            *    Work with ASP.NET AJAX's UpdatePanel. Essential Grid provides built-in support for hierarchical viewing, grouping, multicolumn sorting, filtering, summaries, and various data editors.
            *
            * //Create the text2.html file with following content.
            *     Essential Diagram is an extensible, high-performance .NET diagramming framework for ASP.NET applications.
            *
            * //Create the text3.html file with following content.
            *     Essential DOCIO is a .NET library that can read, write, and modify Microsoft Word files.
            *
            * @example 
            * // Bind the ajaxSuccess event using Obtrusive way.
            * &lt;div id="accordion" data-role="ejmaccordion"&gt;
            *	 &lt;ul&gt;
            * 		&lt;li data-ej-text="Grid Web" data-ej-ajaxurl="text1.html"&gt;
            *		&lt;/li&gt;
            *		&lt;li data-ej-text="Diagram Web" data-ej-ajaxurl="text2.html"&gt;
            * 		&lt;/li&gt;
            *		&lt;li data-ej-text="DocIO Web" data-ej-ajaxurl="text3.html"&gt;
            * 		&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt; 
            * //initial ajaxSuccess event
            *	$("#accordion").ejmAccordion({ 
            *		ajaxSuccess: function (args) {}
            * 	});
            * &lt;/script&gt; 
            * @memberof ejmAccordion
            * @instance
            */
            ajaxSuccess: null,
            /**     
            * Event triggers when the ajax request failed.
            * @event
            * @name ejmAccordion#ajaxError		
            * @param {Object} argument Event parameters from Accordion.
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @param {string} argument.url returns current ajax content location.
            * @param {string} argument.data returns the failed data sent.
            * @param {string} argument.title returns the title of the panel.
            * @example 
            * // Bind the ajaxError event using Unobtrusive way.
            * &lt;div id="accordion" data-role="ejmaccordion" data-ej-ajaxerror="ajaxError"&gt;
            *	 &lt;ul&gt;
            * 		&lt;li data-ej-text="Grid Web" data-ej-ajaxurl="text1.html"&gt;
            *		&lt;/li&gt;
            *		&lt;li data-ej-text="Diagram Web" data-ej-ajaxurl="text2.html"&gt;
            * 		&lt;/li&gt;
            *		&lt;li data-ej-text="DocIO Web" data-ej-ajaxurl="text3.html"&gt;
            * 		&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example
            * //Create the text1.html file with following content.
            *    Work with ASP.NET AJAX's UpdatePanel. Essential Grid provides built-in support for hierarchical viewing, grouping, multicolumn sorting, filtering, summaries, and various data editors.
            *
            * //Create the text2.html file with following content.
            *     Essential Diagram is an extensible, high-performance .NET diagramming framework for ASP.NET applications.
            *
            * @example 
            * // Bind the ajaxError event using Obtrusive way.
            * //initial ajaxError event
            * &lt;div id="accordion" data-role="ejmaccordion"&gt;
            *	 &lt;ul&gt;
            * 		&lt;li data-ej-text="Grid Web" data-ej-ajaxurl="text1.html"&gt;
            *		&lt;/li&gt;
            *		&lt;li data-ej-text="Diagram Web" data-ej-ajaxurl="text2.html"&gt;
            * 		&lt;/li&gt;
            *		&lt;li data-ej-text="DocIO Web" data-ej-ajaxurl="text3.html"&gt;
            * 		&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt; 
            *	$("#accordion").ejmAccordion({ 
            *		ajaxError: function (args) {//handle the event
            * }
            * 	});
            * &lt;/script&gt; 
            * @memberof ejmAccordion
            * @instance
            */
            ajaxError: null
        },
        /**
        * Specify the data types for default properties 
        * @private
        */
        dataTypes: {
            renderMode: "enum",
            collapsible: "boolean",
            theme: "enum",
            showHeaderIcon: "boolean",
            enableCache: "boolean",
            heightAdjustMode: "enum",
            enableMultipleOpen: "boolean",
            selectedItems: "array",
            enabled: "boolean",
            disabledItems: "array"
        },
        observableArray: ["selectedItems"],
        selectedItems: ej.util.valueFunction("selectedItems"),
        // constructor function
        /**
        * Create the Accordion widget
        * @private
        */
        _init: function () {
            this._cloneElement = $(this.element).clone();
            this._renderControl();
            this._icons = this.element.find(".e-m-acc-img");
            this._contentElements = this.element.find('> .e-m-acc-content');
            this._items = this.element.find('>.e-m-acc-header');
            this._anchors = this._items.find(".e-m-acc-link");
            this._maxAutoHeight = 0;
            this._createDelegates();
            this._wireEvents(false);
            this.show();
            this._displayHeaderIcon(this.model.showHeaderIcon);
            this._load();
            this._enabledAction(this.model.enabled);
            this.disableItems(this.model.disabledItems);
        },
        /**
        * Render Section For Accordion control		
        * @private
        */
        _renderControl: function () {
            ej.setRenderMode(this);
            ej.setTheme(this);
            if (this.model.renderMode == "windows" && this.model.windows.renderDefault)
                this.model.theme = "default";
            var proxy = this;
            this.element.addClass("e-m-user-select");
            this.element.addClass("e-m-acc e-m-" + this.model.renderMode);
            this.element.addClass("e-m-" + this.model.theme);
            var temp = ej.buildTag("div");
            temp.append(this.element.html());
            this.element.empty();

            if (proxy.model.items.length < 1) {
                var list = temp.find(">ul >li");
                $.each(list, function (index, element) {
                    var item = {};
                    item.ajaxUrl = ej.getAttrVal(element, 'data-ej-ajaxurl', '#');
                    item.text = ej.getAttrVal(element, 'data-ej-text');
                    item.logoClass = ej.getAttrVal(element, 'data-ej-logoclass');
                    item.content = $(element).html();
                    proxy.model.items.push(item);
                });
            }

            $.each(proxy.model.items, function (index) {
                var headerdiv = ej.buildTag("div.e-m-acc-header e-m-acc-innerdiv");
                var header = ej.buildTag("h3.e-m-acc-header e-m-acc-item");
                var content = ej.buildTag("div.e-m-acc e-m-acc-content");
                headerdiv.append(ej.buildTag("div.e-m-acc-link", proxy.model.items[index].text));
                headerdiv.append(ej.buildTag("a.e-m-acc-linkhref", "", "", { href: proxy.model.items[index].ajaxUrl || "#" }));
                content.html(proxy.model.items[index].content.trim());
                headerdiv.append(ej.buildTag("div.e-m-fontimage e-m-acc-img"));
                if (proxy.model.items[index].logoClass != undefined)
                    headerdiv.append(ej.buildTag("div.e-m-acc-logourl " + proxy.model.items[index].logoClass));
                header = header.append(headerdiv);
                proxy.element.append(header).append(content);
                header.attr('tabindex', index);
                content.attr('id', 'header-content-' + (index + 1));

                if ((!proxy.model.enableMultipleOpen) && (proxy.selectedItems().length > 1)) {
                    proxy.selectedItems().splice(1, proxy.selectedItems().length);
                }

                if ($.inArray(index, proxy.selectedItems()) > -1) {
                    header.addClass("e-m-acc-state-active");
                }
                else {
                    header.addClass("e-m-acc-state-default");
                    content.hide();
                }

                if (index == 0) {
                    header.addClass("e-m-acc-border-top");
                }

                if (index == proxy.model.items.length - 1) {
                    header.addClass("e-m-acc-border-bottom");
                    content.addClass("e-m-acc-content-border-bottom");
                }
            });
        },
        /**
        * Creating the delegates to the Accordion control		
        * @private
        */
        _createDelegates: function () {
            this._onResizeEventHandler = $.proxy(this._onResizeEventHandler, this);
            this._onClickHandler = $.proxy(this._onClickHandler, this);
            this._onStartHandler = $.proxy(this._onStartHandler, this);
            this._onTouchMoveHandler = $.proxy(this._onTouchMoveHandler, this);
        },
        /**
        * Wiring and UnWiring the events to the Accordion control		
        * @private
        */
        _wireEvents: function (remove) {
            ej.listenEvents([window, this._items, this._items],
							[!ej.isTouchDevice() ? "resize" : "orientationchange", ej.endEvent(), ej.startEvent()],
							[this._onResizeEventHandler, this._onClickHandler, this._onStartHandler], remove);
        },
        /**
        * Configure to handle the header click event
        * @private
        */
        _onClickHandler: function (event) {
            ej.blockDefaultActions(event);
            if (!this._scroll) {
                var clickedItem = $(event.currentTarget);
                this._select(clickedItem, event);
            }
        },
        /**
        * Configure to handle the resize event
        * @private
        */
        _onResizeEventHandler: function (event) {
            event.preventDefault();
            this._setHeightAdjustMode(this.model.heightAdjustMode);
        },
        /**
        * Configure to handle the on touch start event
        * @private
        */
        _onStartHandler: function (event) {
            event.preventDefault();
            this._scroll = false;
            ej._touchStartPoints(event, this);
            ej.listenTouchEvent(this._items, ej.moveEvent(), this._onTouchMoveHandler);
        },
        /**
        * Configure to handle the on touch move event
        * @private
        */
        _onTouchMoveHandler: function (event) {
            if (ej._isTouchMoved(event, this)) {
                event.preventDefault();
                this._scroll = true;
            }
        },
        /**
        * Configure in the initial load
        * @private
        */
        _load: function () {
            var proxy = this;
            proxy._setHeightAdjustMode(this.model.heightAdjustMode);
            this._items.filter('.e-m-acc-state-default').next().hide();
            for (var i = 0; i < this.selectedItems().length; i++) {
                var content = $(this._getContentElement(this.selectedItems()[i]));
                var link = $($(content).prev()).find('.e-m-acc-link');
                var linkhref = $($(content).prev()).find('.e-m-acc-linkhref');
                var ajaxUrl = $(link).attr("href");
                if (content.is(':empty') && ajaxUrl != "#")
                    this._sendAjaxRequest(content, link, linkhref);   //Loading Ajax Content
            }
        },
        /**
        * Configure to get the content elements
        * @private
        */
        _getContentElement: function (itemIndex) {
            if (isNaN(itemIndex - 0)) return;
            var contentElements = this._contentElements,
                idTest = new RegExp('-' + (itemIndex + 1) + '$');
            for (var i = 0, len = contentElements.length; i < len; i++) {
                if (idTest.test(contentElements[i].id))
                    return contentElements[i];
            }
        },
        /**
        * Configure to handle the Ajax success load event
        * @private
        */
        _ajaxSuccessHandler: function (data, content, span, link, curTabTitle, linkhref) {
            if (curTabTitle != null)
                link.html(curTabTitle);
            $(content).html(data);
            $(content).addClass("e-m-acc-ajax"); //to indicate the content is already loaded
            $(span).remove(); //removing waiting popup
            //triggering on ajaxLoad event
            if (this.model.ajaxLoad)
                this._trigger("ajaxLoad");
            var data = { data: data, url: linkhref.attr("href"), content: content };
            //triggering on ajaxSuccess event
            if (this.model.ajaxSuccess)
                this._trigger("ajaxSuccess", data);
            if (this.model.heightAdjustMode == "auto")
                this._enableAutoHeight();
        },
        /**
        * Configure to handle the Ajax failed load event
        * @private
        */
        _ajaxErrorHandler: function (data, linkhref, curTabTitle) {
            var data = { data: data, url: linkhref.attr("href"), title: curTabTitle };
            //triggering on ajaxError event
            if (this.model.ajaxError) {
                this._trigger("ajaxError", data);
            }
        },

        //handling the ajax request
        /**
        * To handle the ajax request for the Accordion control		
        * @private
        */
        _sendAjaxRequest: function (content, link, linkhref) {
            var span = ej.buildTag("span.e-m-acc-ajax-loading"); //load waiting popup
            if (this.model.spinnerText != null && this.model.spinnerText != "") {
                var curTabTitle = link.html();
                link.html(this.model.spinnerText);
            }
            var linkUrl = linkhref.attr('href');
            if (!$.support.pushstate || ej.isWindowsWebView())
                linkUrl = App.route.makeUrlAbsolute(linkhref.attr('href'));
            var ajaxSpinner = $($(link).parent()).find('span.e-m-acc-ajax-loading');
            if (!$(ajaxSpinner).is(":empty"))
                link.parent().append(span);
            var data = { url: linkhref.attr("href") };
            //trigggering on ajaxBeforeLoad event
            if (this.model.ajaxBeforeLoad)
                this._trigger("ajaxBeforeLoad", data);
            var proxy = this;
            var ajaxOptions = {
                type: 'GET', cache: true, url: linkUrl, data: {}, dataType: "html",
                "successHandler": function (data) {
                    proxy._ajaxSuccessHandler(data, content, span, link, curTabTitle, linkhref);
                },
                "errorHandler": function (data) {
                    proxy._ajaxErrorHandler(data, linkhref, curTabTitle);
                }
            };
            ej.sendAjaxRequest(ajaxOptions);
        },
        /**
        * To handle the content panel auto type height style
        * @private
        */
        _enableAutoHeight: function () {
            for (i = 0; i < this.selectedItems().length; i++) {
                var isAjax = false;
                var content = this._contentElements, isAjax = $(content[this.selectedItems()[i]]).is(":empty");
                var maxHeight = 0;
                content.each(function () {
                    // $(this).css("height", "");
                    maxHeight = Math.max(maxHeight, $(this).outerHeight() - 20);
                });

                if (!isAjax) {
                    content.height(maxHeight);
                }
            }
        },
        /**
        * To handle the content panel fill type height style
        * @private
        */
        _enableFillSpace: function () {
            var proxy = this;
            var maxHeight = this.element.parent().height();
            this.element.parent().css({ "overflow": "auto" });
            proxy._items.each(function () {
                maxHeight -= $(this).outerHeight();
            });
            var maxPadding = 0;
            proxy._items.next().each(function () {
                maxPadding = Math.max(maxPadding, $(this).innerHeight() - $(this).height());
            }).height(maxHeight - maxPadding).css({ "overflow": "auto" });
        },
        /**
        * Configure to handle the select items
        * @private
        */
        _select: function (item, event) {
            if (!$(item).hasClass("e-m-acc-state-disabled")) {
                //triggering the on beforeActive Event
                var data = { activeItemIndex: item };
                if (this.model.beforeActive) {
                    this._trigger("beforeActive", data);
                }
                var content = this._getContentElement(this._items.index(item));
                var link = item.find('.e-m-acc-link');
                var linkhref = item.find('.e-m-acc-linkhref');
                var ajaxUrl = linkhref.attr("href");
                var isAjaxContent = $(content).is(':empty');
                var prevItem = this.element.find(".e-m-acc-header.e-m-acc-state-active")[0];
                var prevIndex = $(prevItem).attr("tabindex");
                var prevContentElement = this._getContentElement(parseInt(prevIndex));

                if (!this.model.enableMultipleOpen) {
                    if (prevItem == item[0]) {
                        if (this.model.collapsible) {
                            this._hideTab(this._items.index(item));
                        }
                    }
                    else {
                        this._hideTab(prevIndex);
                        this._showTab(this._items.index(item));
                    }
                }
                else {
                    if ($(item[0]).hasClass('e-m-acc-state-active')) {
                        this._hideTab(this._items.index(item));
                    }
                    else {
                        this._showTab(this._items.index(item));
                    }
                }

                //trigger on active event
                var data = { selectedItemIndices: this.selectedItems(), lastSelectedItemIndices: $(prevItem).index('.e-m-acc-header'), items: this._items };
                if (this.model.active)
                    this._trigger("active", data);

                ej.blockDefaultActions(event);
            }
            else {
                ej.blockDefaultActions(event);
            }
        },
        /**
        * Configure to show the selected active item of the Accordion control		
        * @private
        */
        _showTab: function (index) {
            if (index == null) return false;
            this._isAjaxContent(parseInt(index));
            var content = this._getContentElement(parseInt(index));
            var active = $(content.previousSibling).hasClass("e-m-state-disabled");
            if (active) return false;
            $(content.previousSibling).addClass("e-m-acc-state-active").removeClass("e-m-acc-state-default");
            if (this.model.renderMode == "android") {
                $(content).slideDown("fast");
            }
            else {
                $(content).slideDown(300, "linear");
            }
            this._addSelectedItems(parseInt(index));
        },
        /**
        * To handle whether it is ajax content or not
        * @private
        */
        _isAjaxContent: function (index) {
            var content = $(this._getContentElement(index));
            var link = $($(content).prev()).find('.e-m-acc-link');
            var linkhref = $($(content).prev()).find('.e-m-acc-linkhref');
            var ajaxUrl = $(linkhref).attr("href");
            if ((content.is(':empty') && ajaxUrl != "#") || (!this.model.enableCache && ajaxUrl != "#"))
                this._sendAjaxRequest(content, link, linkhref);   //Loading Ajax Content
        },
        /**
        * Configure to hide the previous active item of the Accordion control		
        * @private
        */
        _hideTab: function (index) {
            if (index == null) return false;
            var content = this._getContentElement(parseInt(index));
            $(content.previousSibling).removeClass("e-m-acc-state-active").addClass("e-m-acc-state-default");
            if (this.model.renderMode == "android") {
                $(content).slideUp("fast");
            }
            else {
                $(content).slideUp(300, "linear");
            }
            this._deleteSelectedItems(parseInt(index));
        },
        /**
        * Configure to add selected items based on index
        * @private
        */
        _addSelectedItems: function (index) {
            if ($.inArray(index, this.selectedItems()) < 0)
                this.selectedItems().push(index);
        },
        /**
        * Configure to delete selected items based on index
        * @private
        */
        _deleteSelectedItems: function (index) {
            if ($.inArray(index, this.selectedItems()) > -1) {
                position = $.inArray(index, this.selectedItems());
                this.selectedItems().splice(position, 1);
            }
        },
        /**
        * Configure to set the renderMode to the Accordion
        * @private
        */
        _setRenderMode: function (mode) {
            (mode == "auto") ? ej.setRenderMode(this) : this.model.renderMode = mode;
            this.element.removeClass("e-m-ios7 e-m-android e-m-windows e-m-flat").addClass("e-m-" + this.model.renderMode);
        },
        /**
        * Configure to set the theme to the Accordion
        * @private
        */
        _setTheme: function (theme) {
            this.element.removeClass("e-m-dark e-m-light").addClass("e-m-" + theme);
        },
        /**
        * Configure to enable the items based on index
        * @private
        */
        _enabledAction: function (value) {
            value ? (this._enableAll(), this._wireEvents(false)) : (this._disableAll(), this._wireEvents(true));
        },

        /**
        * Configure to handle the headerIcons visibility
        * @private
        */
        _displayHeaderIcon: function (show) {
            this.model.showHeaderIcon = show;
            var display = show ? "inline-block" : "none";
            this._icons.css("display", display);
        },
        /**
        * Configure to set the content panels height based on the height style
        * @private
        */
        _setHeightAdjustMode: function (option) {
            if (option == "fill")
                this._enableFillSpace();
            else if (option == "auto")
                this._enableAutoHeight();
            else
                this._contentElements.css({ "height": "auto", "overflow": "hidden" });
        },
        /**
        * Configure to handle the multipleopen
        * @private
        */
        _setMultipleOpen: function (value) {
            this.model.enableMultipleOpen = value;
            this.collapseAll();
        },
        enableItems: function (itemIndexes) {
            if (!this.model.enabled) return false;
            if ($.isArray(itemIndexes)) {
                var proxy = this;
                $.each(itemIndexes, function (i, itemIndx) {
                    $(proxy._items[itemIndx]).removeClass("e-m-state-disabled");
                });
            }
            else
                $(this._items[itemIndexes]).removeClass("e-m-state-disabled");
        },
        disableItems: function (itemIndexes) {
            if (!this.model.enabled) return false;
            if ($.isArray(itemIndexes)) {
                var proxy = this;
                $.each(itemIndexes, function (i, itemIndx) {
                    $(proxy._items[itemIndx]).addClass("e-m-state-disabled");
                });
            }
            else
                $(this._items[itemIndexes]).addClass("e-m-state-disabled");
        },
        _enableAll: function () {
            var itemIndexes = new Array();
            $.each(this._items, function (indx, item) {
                $(item).removeClass("e-m-state-disabled");
                itemIndexes.push(indx);
            });
        },
        _disableAll: function () {
            var itemIndexes = new Array();
            $.each(this._items, function (indx, item) {
                $(item).addClass("e-m-state-disabled");
                itemIndexes.push(indx);
            });
        },
        /**
        * To configure the properties at runtime using SetModel		
        * @private
        */
        _setModel: function (options) {
            for (var key in options) {
                switch (key) {
                    case "renderMode": this._setRenderMode(options.renderMode); break;
                    case "theme": this._setTheme(options.theme); break;
                    case "selectedItems": this.selectItems(options.selectedItems); break;
                    case "disabledItems": this.disableItems(options.disabledItems); break;
                    case "showHeaderIcon": this._displayHeaderIcon(options.showHeaderIcon); break;
                    case "heightAdjustMode": this._setHeightAdjustMode(options.heightAdjustMode); break;
                    case "collapsible": this.model.collapsible = options.collapsible; break;
                    case "enableMultipleOpen": this._setMultipleOpen(options.enableMultipleOpen); break;
                    case "enabled": this._enabledAction(options.enabled); break;
                    case "spinnerText": this.model.spinnerText = options.spinnerText; break;
                }
            }
        },
        /**
        * Destroy the Accordion widget		
        * @private
        */
        _destroy: function () {
            this._wireEvents(true);
            this._cloneElement.insertBefore(this.element);
            this.element.remove();
        },
        /*---------------Public Methods---------------*/
        /**
        * To show the accordion.
        * @return jQuery
        * @example 
        * &lt;div id="accordion" data-role="ejmaccordion"&gt;
        *	 &lt;ul&gt;
        * 		&lt;li data-ej-text="Grid Web"&gt;
        * 			&lt;div&gt;
        *				Work with ASP.NET AJAX's UpdatePanel. Essential Grid provides built-in support for hierarchical viewing, grouping, multicolumn sorting, filtering, summaries, and various data editors.
        *			 &lt;/div&gt;
        *		 &lt;/li&gt;
        *		 &lt;li data-ej-text="Diagram Web"&gt;
        * 			&lt;div&gt;
        *				Essential Diagram is an extensible, high-performance .NET diagramming framework for ASP.NET applications.
        * 			&lt;/div&gt;
        * 		&lt;/li&gt;
        *		&lt;li data-ej-text="DocIO Web"&gt;
        * 			&lt;div&gt;
        *				Essential DOCIO is a .NET library that can read, write, and modify Microsoft Word files.
        * 			&lt;/div&gt;
        * 		&lt;/li&gt;
        * 	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call show method.
        * $(function(){
        * $("#accordion").ejmAccordion("show");	
        * });
        * &lt;/script&gt; 
        * @memberof ejmAccordion
        * @instance
        */
        show: function () {
            $(this.element).css("display", "block");
        },
        /**
        * To hide the accordion.
        * @return jQuery
        * @example 
        * &lt;div id="accordion" data-role="ejmaccordion"&gt;
        *	 &lt;ul&gt;
        * 		&lt;li data-ej-text="Grid Web"&gt;
        * 			&lt;div&gt;
        *				Work with ASP.NET AJAX's UpdatePanel. Essential Grid provides built-in support for hierarchical viewing, grouping, multicolumn sorting, filtering, summaries, and various data editors.
        *			 &lt;/div&gt;
        *		 &lt;/li&gt;
        *		 &lt;li data-ej-text="Diagram Web"&gt;
        * 			&lt;div&gt;
        *				Essential Diagram is an extensible, high-performance .NET diagramming framework for ASP.NET applications.
        * 			&lt;/div&gt;
        * 		&lt;/li&gt;
        *		&lt;li data-ej-text="DocIO Web"&gt;
        * 			&lt;div&gt;
        *				Essential DOCIO is a .NET library that can read, write, and modify Microsoft Word files.
        * 			&lt;/div&gt;
        * 		&lt;/li&gt;
        * 	&lt;/ul&gt;
        * &lt;/div&gt;
        * // Call hide method.
        * &lt;script&gt;
        * $(function(){
        * $("#accordion").ejmAccordion("hide");	
        * });
        * &lt;/script&gt;
        * @memberof ejmAccordion
        * @instance
        */
        hide: function () {
            $(this.element).css("display", "none");
        },

        /**
        * To select the panel item.
        * @return jQuery
        * @example 
        * &lt;div id="accordion" data-role="ejmaccordion"&gt;
        *	 &lt;ul&gt;
        * 		&lt;li data-ej-text="Grid Web"&gt;
        * 			&lt;div&gt;
        *				Work with ASP.NET AJAX's UpdatePanel. Essential Grid provides built-in support for hierarchical viewing, grouping, multicolumn sorting, filtering, summaries, and various data editors.
        *			 &lt;/div&gt;
        *		 &lt;/li&gt;
        *		 &lt;li data-ej-text="Diagram Web"&gt;
        * 			&lt;div&gt;
        *				Essential Diagram is an extensible, high-performance .NET diagramming framework for ASP.NET applications.
        * 			&lt;/div&gt;
        * 		&lt;/li&gt;
        *		&lt;li data-ej-text="DocIO Web"&gt;
        * 			&lt;div&gt;
        *				Essential DOCIO is a .NET library that can read, write, and modify Microsoft Word files.
        * 			&lt;/div&gt;
        * 		&lt;/li&gt;
        * 	&lt;/ul&gt;
        * &lt;/div&gt;
        * // Call selectItems method.
        * &lt;script&gt;
        * $(function(){
        * $("#accordion").ejmAccordion("selectItems", [1]);	
        * });
        * &lt;/script&gt;
        * @memberof ejmAccordion
        * @instance
        */
        selectItems: function (activeList) {
            if (!this.model.enabled) return false;
            var prevActive, prevItem, prevContent, item;
            if (this.model.enableMultipleOpen) {
                for (var seletedindex = 0; seletedindex < activeList.length; seletedindex++) {
                    this._showTab(activeList[seletedindex]);
                }
            }
            else if ((!$.isArray(activeList)) || (($.isArray(activeList)) && (activeList.length == 1))) {
                prevActive = parseInt(this.element.find(".e-m-acc-header.e-m-acc-state-active").attr("tabindex"));
                item = this.element.find(".e-m-acc-header.e-m-acc-state-active")[0];
                prevContent = this._getContentElement(parseInt(activeList));
                prevItem = prevContent.previousSibling;
                if (prevItem == item) {
                    if (this.model.collapsible) {
                        this._hideTab(parseInt($(prevItem).attr("tabindex")));
                    }
                }
                else {
                    if (!isNaN(prevActive))
                        this._hideTab(parseInt(prevActive));
                    this._showTab(activeList);
                }
            }
        },
        /**
        * To deselect the panel item.
        * @return jQuery
        * @example 
        * &lt;div id="accordion" data-role="ejmaccordion"&gt;
        *	 &lt;ul&gt;
        * 		&lt;li data-ej-text="Grid Web"&gt;
        * 			&lt;div&gt;
        *				Work with ASP.NET AJAX's UpdatePanel. Essential Grid provides built-in support for hierarchical viewing, grouping, multicolumn sorting, filtering, summaries, and various data editors.
        *			 &lt;/div&gt;
        *		 &lt;/li&gt;
        *		 &lt;li data-ej-text="Diagram Web"&gt;
        * 			&lt;div&gt;
        *				Essential Diagram is an extensible, high-performance .NET diagramming framework for ASP.NET applications.
        * 			&lt;/div&gt;
        * 		&lt;/li&gt;
        *		&lt;li data-ej-text="DocIO Web"&gt;
        * 			&lt;div&gt;
        *				Essential DOCIO is a .NET library that can read, write, and modify Microsoft Word files.
        * 			&lt;/div&gt;
        * 		&lt;/li&gt;
        * 	&lt;/ul&gt;
        * &lt;/div&gt;
        * // Call deselectItems method.
        * &lt;script&gt;
        * $(function(){
        * $("#accordion").ejmAccordion("deselectItems", [1]);	
        * });
        * &lt;/script&gt;
        * @memberof ejmAccordion
        * @instance
        */
        deselectItems: function (activeList) {
            if (!this.model.enabled) return false;
            if (this.model.enableMultipleOpen) {
                for (var seletedindex = 0; seletedindex < activeList.length; seletedindex++) {
                    this._hideTab(activeList[seletedindex]);
                }
            }
            else if ((!$.isArray(activeList)) || (($.isArray(activeList)) && (activeList.length == 1)))
                this._hideTab(activeList);
        },
        /**
        * To collapse all the panel item.
        * @return jQuery
        * @example 
        * &lt;div id="accordion" data-role="ejmaccordion"&gt;
        *	 &lt;ul&gt;
        * 		&lt;li data-ej-text="Grid Web"&gt;
        * 			&lt;div&gt;
        *				Work with ASP.NET AJAX's UpdatePanel. Essential Grid provides built-in support for hierarchical viewing, grouping, multicolumn sorting, filtering, summaries, and various data editors.
        *			 &lt;/div&gt;
        *		 &lt;/li&gt;
        *		 &lt;li data-ej-text="Diagram Web"&gt;
        * 			&lt;div&gt;
        *				Essential Diagram is an extensible, high-performance .NET diagramming framework for ASP.NET applications.
        * 			&lt;/div&gt;
        * 		&lt;/li&gt;
        *		&lt;li data-ej-text="DocIO Web"&gt;
        * 			&lt;div&gt;
        *				Essential DOCIO is a .NET library that can read, write, and modify Microsoft Word files.
        * 			&lt;/div&gt;
        * 		&lt;/li&gt;
        * 	&lt;/ul&gt;
        * &lt;/div&gt;
        * // Call collapseAll method.
        * &lt;script&gt;
        * $(function(){
        * $("#accordion").ejmAccordion("collapseAll");	
        * });
        * &lt;/script&gt;
        * @memberof ejmAccordion
        * @instance
        */
        collapseAll: function () {
            if (!this.model.enabled) return false;
            this.deselectItems($.makeArray(this.selectedItems()));
        },
        /**
        * To expand all the panel item.
        * @return jQuery
        * @example 
        * &lt;div id="accordion" data-role="ejmaccordion" data-ej-enableMultipleOpen="true"&gt;
        *	 &lt;ul&gt;
        * 		&lt;li data-ej-text="Grid Web"&gt;
        * 			&lt;div&gt;
        *				Work with ASP.NET AJAX's UpdatePanel. Essential Grid provides built-in support for hierarchical viewing, grouping, multicolumn sorting, filtering, summaries, and various data editors.
        *			 &lt;/div&gt;
        *		 &lt;/li&gt;
        *		 &lt;li data-ej-text="Diagram Web"&gt;
        * 			&lt;div&gt;
        *				Essential Diagram is an extensible, high-performance .NET diagramming framework for ASP.NET applications.
        * 			&lt;/div&gt;
        * 		&lt;/li&gt;
        *		&lt;li data-ej-text="DocIO Web"&gt;
        * 			&lt;div&gt;
        *				Essential DOCIO is a .NET library that can read, write, and modify Microsoft Word files.
        * 			&lt;/div&gt;
        * 		&lt;/li&gt;
        * 	&lt;/ul&gt;
        * &lt;/div&gt;
        * // Call expandAll method.
        * &lt;script&gt;
        * $(function(){
        * $("#accordion").ejmAccordion("expandAll");	
        * });
        * &lt;/script&gt;
        * @memberof ejmAccordion
        * @instance
        */
        expandAll: function () {
            if (!this.model.enabled) return false;
            var proxy = this;
            if (!this.model.enableMultipleOpen) return false;
            $.each(proxy._items, function (i, element) {
                if (!($.inArray(i, proxy.selectedItems()) > -1))
                    proxy._showTab(i);
            });
        },
        /**
        * To get the total panel item count.
        * @return jQuery
        * @example 
        * &lt;div id="accordion" data-role="ejmaccordion"&gt;
        *	 &lt;ul&gt;
        * 		&lt;li data-ej-text="Grid Web"&gt;
        * 			&lt;div&gt;
        *				Work with ASP.NET AJAX's UpdatePanel. Essential Grid provides built-in support for hierarchical viewing, grouping, multicolumn sorting, filtering, summaries, and various data editors.
        *			 &lt;/div&gt;
        *		 &lt;/li&gt;
        *		 &lt;li data-ej-text="Diagram Web"&gt;
        * 			&lt;div&gt;
        *				Essential Diagram is an extensible, high-performance .NET diagramming framework for ASP.NET applications.
        * 			&lt;/div&gt;
        * 		&lt;/li&gt;
        *		&lt;li data-ej-text="DocIO Web"&gt;
        * 			&lt;div&gt;
        *				Essential DOCIO is a .NET library that can read, write, and modify Microsoft Word files.
        * 			&lt;/div&gt;
        * 		&lt;/li&gt;
        * 	&lt;/ul&gt;
        * &lt;/div&gt;
        *&lt;script&gt;
        * // Call getItemsCount  method.
        * $(function(){
        *    $("#accordion").ejmAccordion("getItemsCount ");	
        * });
        * &lt;/script&gt;
        * @memberof ejmAccordion
        * @instance
        */
        getItemsCount: function () {
            /// <summary>This function get the number of panel rendered</summary>
            if (this._items)
                return this._items.length;
        }
        /*---------------Public Methods End---------------*/
    });
    /**
    * Enum for accordion height style	 
    * @enum {string}
    * @global 
    */
    //Content height style enum
    ej.mobile.Accordion.HeightAdjustMode = {
        /**  Height fit to the content in the panel */
        Content: "content",
        /**  Height set to the largest content in the panel */
        Auto: "auto",
        /**  Height filled to the content of the panel */
        Fill: "fill"
    };
})(jQuery, Syncfusion);