﻿/**
* @fileOverview Plugin to style the Html AppView elements
* @copyright Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/

(function () {
    // App is the plugin name 
    // "App" will hold functions and properties
    /**
    * @namespace ej
    * @class AppView
    * @requires jQuery    
    * @requires ej.core
    * @requires ej.unobtrusive
    * @requires ej.mobile.core
    * @classdesc Custom Design for Html Appview.
    * @example 
    * &lt;div data-role="appview"&gt;&lt;/div&gt;<br>   
    */

    App = {
        /*---------------Public Properties---------------*/
        window: $(window),
        document: $(document),
        html: $("html"),
        /**		
        * Specifies the Appview addMetaTags property to disable the meta description in the page
        * @default true
        * @type {boolean}
            			
        * @example 
        * //To set addMetaTags API value
        * &lt;script&gt;
        *       App.addMetaTags=false;
        * &lt;/script&gt         
        * @memberof AppView
        * @instance
        */
        addMetaTags: true,
        preventWindowsAccentColor: true,
        head: $("head"),
        /**		
        * Specifies the Appview renderEJMControlsByDef property to disable modifying nomar style controls
        * @default true
        * @type {boolean}
            			
        * @example 
        * //To set renderEJMControlsByDef API value
        * &lt;script&gt;
        *       App.renderEJMControlsByDef=false;
        * &lt;/script&gt         
        * @memberof AppView
        * @instance
        */
        renderEJMControlsByDef: true,
        /**		
        * Specifies the Appview renderEJMControlsByDef property to disable modifying nomar style controls
        * @default slide
        * @type {enum}
                       
        * @example 
        * //To set renderEJMControlsByDef API value
        * &lt;div data-role="appview"&gt;<br>
        * &lt;a href="page2.html" data-ej-apptransition="pop"&gt; Move To Page2 &lt;/a&gt;
        * &lt;/div&gt;
        * @memberof AppView
        * @instance
        */
        pageTransition: "auto",
        hashMonitoring: true,
        allowPushState: true,
        allowPopState: false,
        transferWithinSamePage: false,
        applyMobileStyles: true,
        enableAjax: true,
        enableFormSubmission: true,
        enableSwipe: true,
        loadHashPage: false,
        /*---------------Public Properties End---------------*/

        /*---------------Public Methods---------------*/
        setClass: function (target, classname) {
            target.addClass("e-m-" + classname);
        },
        /**		
        * To get the URL location of current page
         
        * @example             
        * &lt;script&gt;
        *       App.getLocation();//return current url location
        * &lt;/script&gt         
        * @memberof AppView
        * @instance
        */
        getLocation: function (url) {
            var uri = url ? this.route.splitUrl(url) : location,
					hash = this.route.splitUrl(url || location.href).hash;
            hash = hash === "#" ? "" : hash;
            return uri.protocol + "//" + uri.host + uri.pathname + uri.search + hash;
        },
        /**		
        * To transfer one page to another page
        * @example 
        * //Transfer Page
        * &lt;script&gt;
        *  function loadpage(){
        *       App.transferPage(App.activePage,"page2.html");
        *  }
        * &lt;/script&gt  
        * @example
        * &lt;body&gt;
        * &lt;a href="#" onClick="loadpage()" &gt; Move to Page2  &lt;/a&gt;
        * &lt;/body&gt;
        * @remark
        * App.activePage is refers the current page of the Appview.
        * @memberof AppView
        * @instance
        */
        transferPage: function (fromPage, toPage, options, isFromAjax) {
            App.waitingPopUp.show();
            var subPageUrl;
            App._parentSubPage = false;
            var curOptions = $.extend({}, App.transferPage.defaults, options);
            if (curOptions.transition == "auto")
                curOptions.transition = ej.setTransition();
            if (curOptions.hashMonitoring === undefined)
                curOptions.hashMonitoring = true;
            curOptions.pageContainer = $("body");
            curOptions.fromPage = fromPage ? typeof fromPage === "string" ? $("#" + App.route._stripHash(fromPage)) : fromPage : App.activePage;
            data = { toPage: toPage, fromPage: curOptions.fromPage, options: curOptions };
            isTargetString = typeof toPage === "string";
            if (isTargetString) {
                App.loadView(toPage, curOptions).done(function (absUrl, options, newPage, isFromAjax) {
                    App.transferPage(fromPage, newPage, options, isFromAjax);
                }).fail(function (url, options) {
                    data.url = url;
                    data.options = options;
                    App.container.trigger("viewtransferfailed", data);
                });
                return;
            }
            else if (curOptions.loadHashPage && !App.allowPopState)
                toPage = App.container.find("[data-url='" + window.location.hash.replace('#', '') + "']").length > 0 ? App.container.find("[data-url='" + window.location.hash.replace('#', '') + "']") : App.container.find(window.location.hash);
            if (toPage || App.allowPopState) {
                App.createPage($(toPage));
                if (App.allowPopState)
                    App.activeSubPage = null;
                if ((fromPage && fromPage.hasClass("subpage") && curOptions.hashMonitoring && window.location.hash == "" && curOptions.direction != "back") || curOptions.parentSubPage)
                    App._parentSubPage = true;
                if (!App.allowPopState && toPage.hasClass("subpage")) {
                    App.activePage = toPage.parents(".appview");
                    App.activeSubPage = toPage;
                    toPage.addClass("subview");
                }
                else if (toPage) {
                    App.activePage = toPage;
                    App.activeSubPage = null;
                    App._parentSubPage = false;
                }
                App.allowPopState = false;
                App.setPageRenderMode(toPage);

            }
            if (toPage && toPage.hasClass("subpage") && App._parentSubPage && !curOptions.loadHashPage) {
                App.fromUrl = curOptions.fromPage.attr("id") ? curOptions.fromPage.attr("id") : "page" + parseInt((Math.random() * 100).toFixed(2));
                curOptions.fromPage.attr("data-url", App.fromUrl);
                pageUrl = "#" + App.fromUrl;
                data = { transition: curOptions.transition, title: document.title, pageUrl: pageUrl, parentSubPage: App._parentSubPage };
                if (App.hashMonitoring && curOptions.hashMonitoring && !curOptions.fromHashChange)
                    App.urlRouter.change(data, true);
                App._parentSubPage = false;
            }

            if (($.support.pushstate && App.route.baseUrl.hrefNoHash != App.route.splitUrl(App.getLocation()).hrefNoHash) || (!$.support.pushstate && App.directorychanged))
                if (fromPage && fromPage.hasClass("subpage")) {
                    curOptions.fromPage = fromPage = fromPage.parents(".appview");
                    App.activeSubPage = null;
                }
            curOptions.fromPage.addClass(curOptions.transition + (curOptions.reverse ? " reverse" : ""));
            var pageUrl = toPage ? toPage.attr("data-url") : "";
            if (pageUrl && !App.route._isPath(pageUrl) && pageUrl.indexOf("#") < 0)
                pageUrl = "#" + pageUrl;
            if (!curOptions.fromHashChange) {
                data = { transition: curOptions.transition, pageUrl: pageUrl, title: document.title };
                if (App.hashMonitoring && curOptions.hashMonitoring)
                    App.urlRouter.change(data, true);
            }
            var triggerData = { transition: curOptions.transition, options: curOptions, title: document.title, toPage: toPage, fromPage: curOptions.fromPage, pageUrl: pageUrl };
            if (toPage && toPage[0] !== curOptions.fromPage[0] && curOptions.reloadSamePage) {
                if (!$.support.hasTransition)
                    curOptions.transition = "none";
                App._transitionView(toPage, curOptions, isFromAjax, triggerData);
            }
            App.waitingPopUp.hide();
        },
        /**		
        * To load a specific view page
        * @example 
        * //Load Page
        * &lt;script&gt;            
        *       App.loadView("page2.html");            
        * &lt;/script&gt           
        * @memberof AppView
        * @instance
        */
        loadView: function (toPage, options) {
            App.transferWithinSamePage = false;
            var deferred = $.Deferred(),
            curOptions = $.extend({}, App.loadView.defaults, options),
            page = null;
            absUrl = this.route.makeUrlAbsolute(toPage);
            relUrl = this.route.convertToRelativeUrl(absUrl);
            if (ej.isWindowsWebView())
                relUrl = relUrl.replace(/x-wmapp\d+\W?([\/])?([\/])?([w][w][w])/g, "");
            page = App.container.children("[data-url ='" + relUrl + "']");
            if (page.length == 0 && relUrl && !App.route._isPath(relUrl) || page.length == 0 && options.direction == "back") {
                page = App.container.children("#" + relUrl);
                if (page.length == 0 && App.activePage.find("[data-url ='" + relUrl + "']").length) {
                    page = App.activePage.find("[data-url ='" + relUrl + "']");
                    page.attr("data-appcache", true);
                    if (page.length > 0)
                        App.transferWithinSamePage = true;
                }
                else if (App.activePage.find("#" + relUrl).length) {
                    page = App.activePage.find("#" + relUrl);
                    page.attr("data-appcache", true);
                    if (page.length > 0)
                        App.transferWithinSamePage = true;
                }
                if (page.length)
                    return deferred.resolve(absUrl, options, page, false);
                else
                    return deferred.reject(absUrl, options, page, false);
            }
            if (page.length)
                return deferred.resolve(absUrl, options, page, false);
            data = { toPage: toPage, options: curOptions, absUrl: absUrl, relUrl: App.route.convertToRelativeUrl(absUrl) };
            App.container.trigger("viewbeforeload", data);
            $.ajax({
                url: absUrl,
                type: curOptions.type,
                data: curOptions.data,
                contentType: curOptions.contentType,
                dataType: "html",
                success: function (html, textStatus, xhr) {
                    page = $("<div></div>");
                    document.title = html.match(/<title[^>]*>([^<]*)/) && RegExp.$1,
                    page[0].innerHTML = html;
                    curPage = page.find("*[data-role='appview']").first();
                    relUrl = App.route.convertToRelativeUrl(absUrl);
                    if (!curPage.length) {
                        curPage = $("<div>" + ((/<\/?body[^>]*>/gmi).test(html) ? html.split(/<\/?body[^>]*>/gmi)[1] : html || "") + "</div>");
                    }
                    curPage.attr("data-apptransition", curOptions.transition).attr("data-url", ej.isWindowsWebView() ? relUrl.replace(/x-wmapp\d+\W?([\/])?([\/])?([w][w][w])/g, "") : relUrl).hide();
                    App._ios7WebviewContent(curPage);
                    App._renderingPage = curPage;
                    curPage.appendTo($("body"));
                    App.setPageRenderMode(curPage);
                    App._renderingPage = undefined;
                    data.xhr = xhr, data.textStatus = textStatus, data.currentPage = curPage, data.options = options;
                    App.container.trigger("viewload", data);
                    deferred.resolve(absUrl, options, curPage, true);
                },
                error: function (xhr, textStatus, errorThrown) {
                    data.xhr = xhr, data.textStatus = textStatus, data.options = options, data.errorThrown = errorThrown;
                    App.container.trigger("viewloadfailed", data);
                    deferred.reject(absUrl, options);
                }
            });
            return deferred.promise();
        },
        /**		
        * To create a Appview Page
        * @example 
        * //Create AppView
        * &lt;script&gt;            
        *       App.createPage($("#AppPage"));            
        * &lt;/script&gt           
        * @memberof AppView
        * @instance
        */
        createPage: function (page) {
            if (!App.firstPage)
                App.firstPage = page;
            if (!page.hasClass("subpage"))
                page.addClass("appview");
            if (!page.attr("data-url"))
                page.attr("data-url", !page.hasClass("subpage") ? location.pathname + location.search : page.attr("id") || location.pathname + location.search);
            page.attr("data-role", "appview");
        },

        /**
        * Render Windows Themes
        * @private
        */
        setWindowsTheme: function () {
            if (ej.isWindows() && ej.isMobile() && ej.isDevice() && !App.preventWindowsAccentColor) {
                if (($("<div style='background: Background' />").css("background-color")) != "background") {
                    if (Number($("<div style='background: Background' />").css("background-color").split(",")[1]) == 0)
                        $('.appview').removeClass("e-m-light e-m-dark").addClass("e-m-dark");
                    else
                        $('.appview').removeClass("e-m-light e-m-dark").addClass("e-m-light");
                }
            }
        },

        /**		
        * To set page rendermode
        * @example 
        * //set page render mode
        * &lt;script&gt;            
        *       App.route.setPageRenderMode($("#page2"));            
        * &lt;/script&gt           
        * @memberof AppView
        * @instance
        */
        setPageRenderMode: function (element) {
            var target = element ? element : App.activePage;
            if (!ej.hasRenderMode(target)) {
                App.transferPage.defaults.transition = ej.isAndroid() ? "pop" : (ej.isWindows() && ej.isMobile()) ? "turn" : "slide";
                var classname = ej.getRenderMode();
                if (App.applyMobileStyles) {
                    App.setClass(target, classname);
                    App.container.addClass("e-m-" + classname);
                }
            }
            if (!ej.hasTheme(target)) {
                var appTheme = ej.getAttrVal($('head'), "data-ej-theme", "auto");
                var pageRenderMode = ej.getRenderMode();
                var classname = appTheme == "auto" ? ((pageRenderMode == "ios7" || ((pageRenderMode == "android" || pageRenderMode == "windows") && !ej.isMobile())) ? "light" : "dark") : appTheme;
                if (App.applyMobileStyles) {
                    target.addClass("e-m-" + classname);
                    App.container.addClass("e-m-" + classname);
                }
            }
            if (App.applyMobileStyles)
                target.addClass(ej.isMobile() ? "e-m-mobile" : "e-m-tablet");
        },
        /**
        * To render EJM Controls
        * @private
        */
        renderEJMControls: function (element) {
            var target = element ? element : App.activePage;
            if (App.renderEJMControlsByDef) {
                target.find("input[type='button']:not([data-role]),input[type='submit']:not([data-role]),input[type='reset']:not([data-role])").attr("data-role", "ejmbutton");
                target.find("a:not([data-role])").attr("data-role", "ejmactionlink");
                target.find("input:not([data-role]):not([type]),input[type='text']:not([data-role]),input[type='tel']:not([data-role]),input[type='email']:not([data-role]),input[type='password']:not([data-role])").attr("data-role", "ejmtextbox");
                target.find("input[type='checkbox']:not([data-role])").filter(function () { if (!$(this).closest("[data-role='ejmgroupbutton']").length) return this; }).attr("data-role", "ejmcheckbox");
                target.find("input[type='radio']:not([data-role])").filter(function () { if (!$(this).closest("[data-role='ejmgroupbutton']").length) return this; }).attr("data-role", "ejmradiobutton");
                target.find("input[type='date']:not([data-role])").attr("data-role", "ejmdatepicker");
                target.find("input[type='time']:not([data-role])").attr("data-role", "ejmtimepicker");
            }
        },

        /**		
        * To Initalize the dynamically created appview
        * @example 
        * //Initalize AppView
        * &lt;script&gt;            
        *       App.initPage();            
        * &lt;/script&gt           
        * @memberof AppView
        * @instance
        */
        initPage: function () {
            var $appViews = $("[data-role ='appview']");
            if (!$appViews.length) {
                $appViews = $("body").wrapInner("<div data-role='appview' class ='appview'></div>").children(0);
            }
            $appViews.each(function () {
                var $ele = $(this);
                if (!$ele.attr("data-url")) {
                    var $dataUrl = (!$ele.hasClass("subpage") ? location.pathname + location.search : $ele.attr("id") || location.pathname + location.search);
                    $ele.attr("data-url", ej.isWindowsWebView() ? $dataUrl.replace(/([w][w][w])/g, "") : $dataUrl);
                }
                if (!$ele.hasClass("appview"))
                    $ele.addClass("appview");
                if (!$ele.attr("data-apptransition"))
                    $ele.attr("data-apptransition", App.pageTransition);
            });
            App.activePage = App.firstPage = $appViews.first();
            $appViews.not(App.activePage).hide();
            App._ios7WebviewContent($appViews);
            App.container = $("body");
            if ($.support.pushstate && App.allowPushState && !App.preventHashAssignPopState)
                App.urlRouter.clean(App._parseLocation().href);
            if (App.enableAjax) {
                App.activePage.addClass("none");
                App.transferPage(null, App.activePage, { transition: "none", reverse: false, changeHash: false, fromHashChange: true, loadHashPage: App.loadHashPage && window.location.hash != "" ? true : false });
                App.activePage.removeClass("none");
            } 
            setTimeout(function () {
                App.container.trigger("viewtransfer", { currentPage: App.activeSubPage ? App.activeSubPage : App.activePage, initialLoading: true });
                App._refreshScrollPanel();
            });
        },


        /*---------------Public Methods End---------------*/

        /*---------------Private Methods---------------*/
        _ios7WebviewContent: function (ele) {
            ele.each(function () {
                var $currentEle = $(this);
                if (ej.isIOSWebView())
                    $currentEle.addClass("e-m-webview-content");
            });
        },

        _onFormSubmission: function (options) {
            options = $.extend(options, { transition: "auto", reverse: false, changeHash: false, fromHashChange: true });
            if (App.enableAjax)
                App.transferPage(options.fromPage, options.url, { transition: "none", reverse: false, changeHash: false, fromHashChange: true });
        },

        _reloadPage: function (fromPage, toPage) {
            if (toPage.hasClass("subpage")) {
                toPage.parents(".appview").show();
                //toPage.siblings(".subpage").hide();
            }
        },
        /**		
        * To get the URL location of current page as object        
        * @private
        */
        _parseLocation: function () {
            return this.route.splitUrl(this.getLocation());
        },
        /**
        * To check Anchor tag in page
        * @private
        */
        _lookForLink: function (ele) {
            while (ele) {
                if ((typeof ele.nodeName === "string") && ele.nodeName.toLowerCase() === "a") {
                    break;
                }
                ele = ele.parentNode;
            }
            return ele;
        },
        /**		
        * To identify weather the page object or not         
        * @private
        */
        _isPage: function (page) {
            return page.attr("data-url") !== undefined;
        },
        /**
        * To animate view transfer
        * @private
        */
        _transitionView: function (toPage, options, isFromAjax, triggerData) {
            if (options.transition != "pop")
                toPage.addClass(options.transition + " out" + (options.reverse ? " reverse" : "")).show();
            if (isFromAjax || options.isFromAjax) {
                App.renderEJMControls(toPage);
                ej.widget.init(toPage);
            }
            App.container.trigger("viewbeforetransfer", triggerData);
            setTimeout(function () {
                if (options.transition == "pop")
                    toPage.addClass(options.transition + " out" + (options.reverse ? " reverse" : "")).show();
                toPage.attr("data-apptransition", options.transition);
                var deferred = $.Deferred();
                options.deferred = deferred;
                App._setInPageTransition(toPage, options);
                App._setOutPageTransition(toPage, options);
                App._removeNones(toPage, options);
                deferred.promise();
            });
        },
        /**
        * To set inpage transition
        * @private
        */
        _setInPageTransition: function (toPage, options) {
            setTimeout(function () {
                options.toPage = toPage;
                if (options.transition == "none")
                    App._transitionIn(options);
                else
                    options.fromPage.bind(ej.transitionEndEvent(), $.proxy(App._transitionIn, options))
                .addClass(options.transition + " in");
            });
        },
        /**
        * TO set Outpage transition
        * @private
        */
        _setOutPageTransition: function (toPage, options) {
            setTimeout(function () {
                if (options.transition == "none")
                    App._transitionOut(options, toPage);
                else if (options.transition != "turn")
                    toPage.bind(ej.transitionEndEvent(), $.proxy(App._transitionOut, toPage))
                .removeClass("out");
            });
        },
        /**
        * To remove nones
        * @private
        */
        _removeNones: function (toPage, options) {
            options.fromPage.removeClass("none");
            toPage.removeClass("none");
        },
        /**
        * Transition in effect
        * @private
        */
        _transitionIn: function (options) {
            options = options.fromPage === undefined ? this : options;
            if (options.fromPage.attr("data-appcache") == "true" || options.appCache || options.fromPage[0] == App.firstPage[0] || !App.route._isPath(options.fromPage.attr("data-url")))
                options.fromPage.hide().removeClass(options.transition + " in reverse none");
            else if (App.activePage[0] != options.fromPage[0])
                options.fromPage.remove();
            if (options.loadHashPage)
                App._reloadPage(options.fromPage, options.toPage);
            options.fromPage.trigger("appfrompageanimationend", options);
            options.fromPage.unbind(ej.transitionEndEvent(), App._transitionIn);
            if ($.support.pushstate)
                App.route.baseUrl = App.route.splitUrl(App.getLocation());
            if (options.transition == "turn") {
                options.toPage.bind(ej.transitionEndEvent(), $.proxy(App._transitionOut, options.toPage))
                .removeClass("out");
            }
        },
        /**
        * Transition Out effect
        * @private
        */
        _transitionOut: function (options, toPage) {
            App.activePage.unbind(ej.transitionEndEvent(), App._transitionOut);
            if (App.activeSubPage)
                App.activeSubPage.unbind(ej.transitionEndEvent(), App._transitionOut);
            options = options.fromPage === undefined ? this : toPage;
            $(options).removeClass($(options).attr("data-apptransition") + " out reverse none");
            $(options).trigger("apptopageanimationend", options);
            if (options.hasClass("subpage"))
                App.container.trigger("subviewtransfer", options);
            else
                App.container.trigger("viewtransfer", options);
            App._refreshScrollPanel();

        },
        _refreshScrollPanel: function () {
            $(".e-m-scroll:visible").each(function () {
                $(this).ejmScrollPanel("refresh");
            });
        },
        /**
        * To handle the Popstate
        * @private
        */
        _popState: function (event) {
            if (!App._preventNavigate) {
                var state = event.originalEvent.state || {}, url,
            href = location.href;
                if (event.historyState)
                    $.extend(state, event.historyState);
                if (event.originalEvent.type == "hashchange")
                    $.extend(state, event.hashchangeState);
                if (App.enableAjax)
                    App._handleNavigate(state, event, "back");
                if ($(document.activeElement).length && document.activeElement.tagName.toLowerCase() == "input")
                    document.activeElement.blur();
            }
            App._preventNavigate = false;
        },
        /**
        * To handle the navigation
        * @private
        */
        _handleNavigate: function (state, event, direction) {
            var to = App.route._stripHash(state.url),
        transition = (App.pageHistory.heap.length === 0 ? "none" : undefined),
        transferPageOptions = {
            fromHashChange: true,
            reverse: state.direction === "back" || direction == "back",
            loadHashPage: (state.direction === "back" || direction == "back") && window.location.hash != "" ? true : false
        };
            $.extend(transferPageOptions, state, { transition: (App.pageHistory.lastHistory() || {}).transition || transition });
            if (to) {
                if (state.title)
                    document.title = state.title;
                if (App.currentDirectory)
                    App.currentDirectory = App.route.splitUrl(to).directory;
                to = !App.route._isPath(to) ? (App.route.makeUrlAbsolute("#" + to)) : to;
                if (!App.allowPopState) {
                    data = { toPage: to, state: state };
                    App.container.trigger("viewpopstate", data);
                }
                App.transferPage((App.activeSubPage && App.activeSubPage.length) ? App.activeSubPage : undefined, App.allowPopState ? undefined : to, transferPageOptions);
                if (state.parentSubPage) {
                    App.allowPopState = true;
                    window.history.back();
                }
            }
        }
        /*---------------Private Methods End---------------*/

    };

    App.transferPage.defaults = {
        transition: $.support.hasTransition ? "auto" : "none",
        reverse: false,
        changeHash: true,
        reloadSamePage: true,
        samePage: false
    },
    App.route = {
        urlSplitReg: /^\s*(((([^:\/#\?]+:)?(?:(\/\/)((?:(([^:@\/#\?]+)(?:\:([^:@\/#\?]+))?)@)?(([^:\/#\?\]\[]+|\[[^\/\]@#?]+\])(?:\:([0-9]+))?))?)?)?((\/?(?:[^\/\?#]+\/+)*)([^\?#]*)))?(\?[^#]+)?)(#.*)?/,
        /*---------------Public Methods---------------*/
        /**		
        * To Split URL
        * @example 
        * //Get Url Sections
        * &lt;script&gt;            
        *       App.route.splitUrl("http://js.syncfusion.com/demos/mobile/");            
        * &lt;/script&gt           
        * @memberof AppView
        * @instance
        */
        splitUrl: function (url) {
            if ($.type(url) === "object") {
                return url;
            }
            var matches = this.urlSplitReg.exec(url || "") || [];
            return {
                href: matches[0] || "",
                hrefNoHash: matches[1] || "",
                hrefNoSearch: matches[2] || "",
                domain: matches[3] || "",
                protocol: matches[4] || "",
                doubleSlash: matches[5] || "",
                authority: matches[6] || "",
                username: matches[8] || "",
                password: matches[9] || "",
                host: matches[10] || "",
                hostname: matches[11] || "",
                port: matches[12] || "",
                pathname: matches[13] || "",
                directory: matches[14] || "",
                filename: matches[15] || "",
                search: matches[16] || "",
                hash: matches[17] || ""
            };
        },
        /**
        * Add search parameter to URL
        * @private
        */
        addSearchParams: function (url, params) {
            var u = path.parseUrl(url),
					p = (typeof params === "object") ? $.param(params) : params,
					s = u.search || "?";
            return u.hrefNoSearch + s + (s.charAt(s.length - 1) !== "?" ? "&" : "") + p + (u.hash || "");
        },
        /**		
        * To Get Compelete Url
        * @example 
        * //get absolute url
        * &lt;script&gt;            
        *       App.route.makeUrlAbsolute("#default");            
        * &lt;/script&gt           
        * @memberof AppView
        * @instance
        */
        makeUrlAbsolute: function (relUrl, notLink) {
            var link = $("<a href ='" + relUrl + "'></a>")[0];
            $("body").append(link);
            var pathname;
            if (App.currentDirectory && relUrl.indexOf(App.currentDirectory) == -1)
                pathname = App.currentDirectory + relUrl;
            else if (link.pathname.indexOf('/') != 0)
                pathname = '/' + link.pathname;
            else
                pathname = link.pathname;
            var newLink = (link.protocol + "//" + (ej.isWindowsWebView() ? "www" : link.host) + pathname + link.search + link.hash);
            if (App._parentSubPage)
                newLink = App.route.baseUrl.hrefNoHash + relUrl;
            $(link).remove();
            if (!$.support.pushstate && App.route._isDirectoryChanged(newLink) && !notLink) {
                App.directorychanged = true;
                App.currentDirectory = App.route.splitUrl(newLink).directory;
                App.route.baseUrl = App.route.splitUrl(newLink);
            }
            else
                App.directorychanged = false;
            return newLink;
        },
        /**
        * Remove the Domain name in the URL
        * @private
        */
        clean: function (url) {
            return url.replace(this.documentBase.domain, "");
        },
        /**
        * To remove the hashURL
        * @private
        */
        cleanHash: function (hash) {
            return path.stripHash(hash.replace(/\?.*$/, "").replace(dialogHashKey, ""));
        },
        /**		
        * To check url has protocol
        * @example 
        * //check for hash
        * &lt;script&gt;            
        *       App.route.hasProtocol("http://js.syncfusion.com/demos/mobile/default.html");            
        * &lt;/script&gt           
        * @memberof AppView
        * @instance
        */
        hasProtocol: function (url) {
            return (/^(:?\w+:)/).test(url);
        },
        /**		
        * To convert absolute url to relative url
        * @example 
        * //check for hash
        * &lt;script&gt;            
        *       App.route.convertToRelativeUrl("http://js.syncfusion.com/demos/mobile/default.html");            
        * &lt;/script&gt           
        * @memberof AppView
        * @instance
        */
        convertToRelativeUrl: function (absUrl) {
            var url = this.splitUrl(absUrl)
            if (this._isSamePage(url)) {
                return url.hash
						.replace(/^#/, "")
						.replace(/\?.*$/, "");
            }
            if (this._isSameDomain(url, this.baseUrl))
                return url.hrefNoHash.replace(this.baseUrl.domain, "");
            return window.decodeURIComponent(absUrl);
        },
        /**
        * To clean the URL
        * @private
        */
        cleanUrl: function (url, targetUrl) {
            var state, href, cleanedUrl, search, stateIndex,
        isPath = this._isPath(url),
        splitUrl = this.splitUrl(url),
        hash = splitUrl.hash;
            cleanedUrl = isPath ? this._stripHash(url) : url;
            cleanedUrl = this._isPath(splitUrl.hash) ? this._stripHash(splitUrl.hash) : cleanedUrl;
            return this.makeUrlAbsolute(cleanedUrl);

        },
        /*---------------Public Methods End---------------*/

        /*---------------Private Methods---------------*/
        /**		
        * To Find 2 URL is Same domain
        * @private
        */
        _isSameDomain: function (url1, url2) {
            return this.splitUrl(url1).domain === this.splitUrl(url2).domain;
        },
        /**		
        * To Find 2 URL are Same
        * @private
        */
        _isSamePage: function (url) {
            var tmp = App.route.splitUrl(url);
            if (tmp.protocol !== "") {
                return (!App.route._isPath(tmp.hash) && tmp.hash && tmp.hrefNoHash === App.route.baseUrl.hrefNoHash);
            }
            return (/^#/).test(tmp.href);
        },
        /**		
        * To check directory of new url changed
        * @private
        */
        _isDirectoryChanged: function (newUrl) {
            return (App.route.baseUrl.directory != App.route.splitUrl(newUrl).directory)
        },
        /**		
        * To check is valid path
        * @private
        */
        _isPath: function (url) {
            return (/\//).test(url);
        },
        /**		
        * To remove hash in url string
        * @private
        */
        _stripHash: function (url) {
            return url ? url.replace(/^#/, "") : "";
        },
        /**		
        * To remove query string in url
        * @private
        */
        _stripQueryParams: function (url) {
            return url.replace(/\?.*$/, "");
        },
        /**		
        * To check hash string has hash
        * @private
        */
        _isHashValid: function (hash) {
            return (/^#[^#]+$/).test(hash);
        },
        /**
        * Check Weather the Url in same domain or not.
        * @private
        */
        _isExternal: function (url) {
            var u = path.parseUrl(url);
            return u.protocol && u.domain !== this.documentUrl.domain ? true : false;
        }
        /*---------------Private Methods End---------------*/
    },

    // URL Route and History
    $.extend(App.route, {
        baseUrl: App.route.splitUrl(App.getLocation())
    });
    App.documentUrl = function (history) {
        this.history = history;
        this.ignoreInitialHashChange = true;

        App.window.bind({
            "popstate.history": $.proxy(this._popState, this),
            "hashchange.history": $.proxy(this._hashChange, this)
        });
    },
    $.extend(App.documentUrl.prototype, {
        /*---------------Public Methods---------------*/
        /**
        * Clean the Document URL
        * @private
        */
        clean: function (url, data) {
            var state, href, hash = App.route._isPath(url) ? App.route._stripHash(url) : url;
            href = App.route.cleanUrl(url);
            state = $.extend({
                hash: hash, url: href
            }, data);
            if (App.route._isSameDomain(App.route.makeUrlAbsolute(url), window.location.href))
                window.history.replaceState(state, state.title || document.title, href);
            return state;
        },
        /**
        * TO get the HashValue
        * @private
        */
        hash: function (url, href) {
            var parsed, loc, hash;
            parsed = App.route.splitUrl(url);
            loc = App.getLocation();
            if (loc.pathname + loc.search == parsed.pathname + parsed.seach) {
                hash = parsed.hash ? parsed.hash : parsed.pathname + parsed.search;
            } else if (App.route._isPath(url)) {
                var resolved = App.route.splitUrl(href);

                hash = resolved.pathname + resolved.search;
            } else {
                hash = url;
            }

            return hash;
        },
        /**
        * To redirect the URL
        * @private
        */
        change: function (data, events) {
            var state, href, hash, popstateEvent;
            href = App.route.cleanUrl(data.pageUrl);
            hash = this.hash(data.pageUrl, href);
            App.preventHashAssignPopState = true;
            if (events && hash !== App.route._stripHash(App._parseLocation().hash)) {
                this.preventNextHashChange = events;
            }
            var url = App.route.splitUrl(href);
            window.location.hash = hash;
            App.preventHashAssignPopState = false;
            state = $.extend({
                url: href, hash: hash, title: document.title
            }, data);
            if ($.support.pushstate && App.allowPushState) {
                popstateEvent = new $.Event("popstate");
                popstateEvent.originalEvent = { type: "popstate", state: null };
                this.clean(data.pageUrl, state);
                if (!events)
                    App.window.trigger(popstateEvent);
            }
            this.history.add(state.url, state);
        },
        /*---------------Public Methods End---------------*/

        /*---------------Private Methods---------------*/
        /**
        * To remove the hash URl
        * @private
        */
        _popState: function (event) {
            var active, hash, state, closestIndex;
            if (App.preventHashAssignPopState) {
                App.preventHashAssignPopState = false;
                event.stopImmediatePropagation();
                return;
            }
            if (this.ignorePopState) {
                this.ignorePopState = false;
                return;
            }
            if (!event.originalEvent.state &&
				this.history.heap.length === 1 &&
				this.ignoreInitialHashChange) {
                this.ignoreInitialHashChange = false;
            }
            hash = App._parseLocation().hash;
            if (!event.originalEvent.state && hash) {
                state = this.clean(hash);

                this.history.add(state.url, state);

                event.historyState = state;

                return;
            }
            this.history.direct({
                url: (event.originalEvent.state || {}).url || hash,
                present: function (historyEntry, direction) {
                    event.historyState = $.extend({}, historyEntry);
                    event.historyState.direction = direction;
                }
            });
        },
        /**
        * TO get Hash value
        * @private
        */
        _hashchange: function (event) {
            var history, hash;
            if (($.support.pushstate && App.allowPushState))
                return;
            if (this.preventNextHashChange) {
                this.preventNextHashChange = false;
                event.stopImmediatePropagation();
                return;
            }

            history = this.history;
            hash = App._parseLocation().hash;
            this.history.direct({
                url: hash,
                present: function (historyEntry, direction) {
                    event.hashchangeState = $.extend({}, historyEntry);
                    event.hashchangeState.direction = direction;
                },
                missing: function () {
                    history.add(hash, {
                        hash: hash,
                        title: document.title
                    });
                }
            });
        }
        /*---------------Private Methods End---------------*/
    });
    App.History = function (heap, index) {
        this.heap = heap || [];
        this.activeIndex = index || 0;
    };

    $.extend(App.History.prototype, {
        /*---------------Public Methods---------------*/
        /**		
        * To return the Current Page History
        * @example 
        * //Get History about Current Page
        * &lt;script&gt;            
        *       App.pageHistory.activeHistory();            
        * &lt;/script&gt           
        * @memberof AppView
        * @instance
        */
        activeHistory: function () {
            return this.heap[this.activeIndex];
        },
        /**		
        * To return the Last Page History
        * @example 
        * //Get History about Last Page
        * &lt;script&gt;            
        *       App.pageHistory.lastHistory();            
        * &lt;/script&gt           
        * @memberof AppView
        * @instance
        */
        lastHistory: function () {
            return this.heap[this.previousIndex];
        },
        /**		
        * To return the Current Next History
        * @example 
        * //Get History about Next Page
        * &lt;script&gt;            
        *       App.pageHistory.nextHistory();            
        * &lt;/script&gt           
        * @memberof AppView
        * @instance
        */
        nextHistory: function () {
            return this.heap[this.activeIndex + 1];
        },
        /**		
        * To return the Current Previous History
        * @example 
        * //Get History about Next Page
        * &lt;script&gt;            
        *       App.pageHistory.prevHistory();            
        * &lt;/script&gt           
        * @memberof AppView
        * @instance
        */
        prevHistory: function () {
            return this.heap[this.activeIndex - 1];
        },
        /**		
        * To Add the Page History
        * @example 
        * //Set History about Page
        * &lt;script&gt;            
        *       App.pageHistory.add("http://js.syncfusion.com/demos/mobile/",{title:"Mobile Demo"});            
        * &lt;/script&gt           
        * @memberof AppView
        * @instance
        */
        add: function (url, data) {
            data = data || {};
            if (this.nextHistory()) {
                this.clearForward();
            }
            if (data.hash && data.hash.indexOf("#") === -1) {
                data.hash = "#" + data.hash;
            }
            data.url = url;
            this.heap.push(data);
            this.activeIndex = this.heap.length - 1;
        },
        /**		
        * To Replace the Page History
        * @example 
        * //Set History about Page
        * &lt;script&gt;            
        *       App.pageHistory.replace("#sample");            
        * &lt;/script&gt           
        * @memberof AppView
        * @instance
        */
        replace: function (url) {
            App.preventHashAssignPopState = true;
            location.replace(url);
            App.preventHashAssignPopState = false;
        },
        /**		
        * To Clear the Forward History
        * @example 
        * //Clear Forward History
        * &lt;script&gt;            
        *       App.pageHistory.clearForward();            
        * &lt;/script&gt           
        * @memberof AppView
        * @instance
        */
        clearForward: function () {
            this.heap = this.heap.slice(0, this.activeIndex + 1);
        },
        /**		
        * To find url in History
        * @example 
        * //find the url in history
        * &lt;script&gt;            
        *       App.pageHistory.find("http://js.syncfusion.com/demos/mobile/");            
        * &lt;/script&gt           
        * @memberof AppView
        * @instance
        */
        find: function (url, heap, earlyReturn) {
            heap = heap || this.heap;

            var entry, i, length = heap.length, index;

            for (i = 0; i < length; i++) {
                entry = heap[i];

                if (decodeURIComponent(url) === decodeURIComponent(entry.url) ||
					decodeURIComponent(url) === decodeURIComponent(entry.hash)) {
                    index = i;

                    if (earlyReturn) {
                        return index;
                    }
                }
            }

            return index;
        },
        /**
        * Clean the Document URL
        * @private
        */
        direct: function (opts) {
            var newActiveIndex = this.closest(opts.url), a = this.activeIndex;
            if (newActiveIndex !== undefined) {
                this.activeIndex = newActiveIndex;
                this.previousIndex = a;
            }
            if (newActiveIndex < a) {
                (opts.present || opts.back || $.noop)(this.activeHistory(), 'back');
            } else if (newActiveIndex > a) {
                (opts.present || opts.forward || $.noop)(this.activeHistory(), 'forward');
            } else if (newActiveIndex === undefined && opts.missing) {
                opts.missing(this.activeHistory());
            }
        },
        /**
        * To return Closest URL Index in History
        * @private
        */
        closest: function (url) {
            var closest, a = this.activeIndex;

            closest = this.find(url, this.heap.slice(0, a));
            if (closest === undefined) {
                closest = this.find(url, this.heap.slice(a), true);
                closest = closest === undefined ? closest : closest + a;
            }

            return closest;
        },
        clearHistory: function (index) {
            index = index ? index : this.activeIndex;
            App._preventNavigate = true;
            window.history.go(-(index));
        }
        /*---------------Public Methods End---------------*/
    });
    App.document.bind("click", function (event) {

        var fromPage = null;
        if (event.isDefaultPrevented()) {
            return;
        }
        var anchor = App._lookForLink(event.target),
            $anchor = $(anchor);

        if (!anchor || event.which > 1) {
            return;
        }
        if ($anchor.attr("data-ej-apprelation") == "back") {
            history.back();
            event.preventDefault();
            return;
        }
        href = $anchor.attr("href") || "#";
        if (href.indexOf("#") != -1) {
            href = href.replace(/[^#]*#/, "");
            if (!href) {
                event.preventDefault();
                return;
            }
            else if (App.route._isPath(href)) {
                href = App.route.makeUrlAbsolute(href);
            }
            else {
                fromPage = $anchor.closest(".subpage").length > 0 ? $anchor.closest(".subpage") : $anchor.closest(".appview");
                href = App.route.makeUrlAbsolute("#" + href);

            }
        }
        //use ajax
        var transition = $anchor.attr("data-ej-apptransition"),
				reverse = $anchor.attr("data-ej-appdirection") === "reverse",
                isAjax = $anchor.attr("data-ej-appajax") === "false"
        if (App.enableAjax && !isAjax) {
            App.transferPage(fromPage, href, { transition: transition, reverse: reverse, loadHashPage: false });
            event.preventDefault();
        }
    });
    App.window.on("focusin", function () {
        App.setWindowsTheme();
    });
    $.extend($.support, {
        has3d: ej.addPrefix('perspective') in ej.styles,
        hasTouch: 'ontouchstart' in window,
        hasPointer: navigator.msPointerEnabled,
        hasTransform: ej.userAgent() !== false,
        pushstate: "pushState" in history &&
		"replaceState" in history,
        hasTransition: ej.addPrefix('transition') in ej.styles
    });

})();
if (App.addMetaTags) {
    $("meta[name='description'],meta[name='author'],meta[name='viewport'],meta[name='apple-mobile-web-app-capable'],meta[charset='UTF-8'],meta[http-equiv='X-UA-Compatible']").remove();
    App.head.prepend("<meta charset='UTF-8'><meta http-equiv='X-UA-Compatible' content='IE=edge,chrome=1' /><meta name='apple-mobile-web-app-capable' content='yes' /><meta name='description' content='syncfusion' /><meta name='author' content='syncfusion' /><meta name='viewport' content='width=device-width, initial-scale=1, maximum-scale=1, user-scalable=0' />");
}
$(function () {
    if (App.applyMobileStyles && $("body").find("[data-role*='ejm']").length > 0 || App.applyMobileStyles) {
        $("body").addClass("e-m-user-select e-m-viewport");
    }
    $(window).bind('touchmove', function (e) {
        if ($(e.target).closest('.e-m-scroll-native').length == 0 && ej.isTouchDevice())
            ej.blockDefaultActions(e);
    });
    if ((/(ipad|iphone|ipod touch);.*os 7_\d/i).test(navigator.userAgent.toLowerCase())) {
        $(document).on('blur', 'input, select, textarea', function () {
            window.setTimeout(function () {
                if (document.activeElement.nodeName && document.activeElement.nodeName.toLowerCase() != "input")
                    window.scrollTo(0, 0);
            });
        });
    }
    $(window).bind('orientationchange', function (e) {
        window.setTimeout(function () {
            if (ej.getRenderMode() == "ios7")
                window.scrollTo(0, 0);
        });
    });
    if (!App.waitingPopUp) {
        var devName = ej.isMobile() ? 'mobile' : 'tablet';
        App.waitingPopUp = ej.buildTag('div.e-m-waitingpopup e-m-' + ej.getRenderMode() + ' e-m-' + devName, "<div class='e-m-image'>Loading...</div>");
        App.waitingPopUpImage = App.waitingPopUp.find('.e-m-image');
    }
    App.setWindowsTheme();
    var path = App._parseLocation();
    App.pageHistory = new App.History();
    App.urlRouter = new App.documentUrl(App.pageHistory);
    App.pageHistory.add(path.href, { hash: path.hash, title: document.title });
    App.initPage();
    App.renderEJMControls(App.activePage);
    App.window.bind("popstate", App._popState);
    if (!$.support.pushstate)
        App.window.bind("hashchange", App._popState);
    App.container.append(App.waitingPopUp);
    App.setPageRenderMode();
    if (App.enableFormSubmission) {
        App.document.find("form").bind("submit", function (evt, data) {
            App._onFormSubmission({ fromPage: $(evt.currentTarget).closest(".appview"), url: $(evt.currentTarget).attr("action"), method: $(evt.currentTarget).attr("method"), formData: $(evt.currentTarget).serialize() });
        });
    }
    App.container.on("swipeleft swiperight", function (evt) {
        var data = $.extend(evt, { direction: evt.handleObj.type });
        App.container.trigger("appviewSwipe", data);
    });
});