/**
* @fileOverview Plugin to style the Html AutoComplete elements
* @copyright Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/

(function ($, ej, undefined) {
    /**
    * @namespace ej
    * @class ejmAutocomplete
    * @requires jQuery
    * @requires ej.mobile.application
    * @requires ej.core
    * @requires ej.unobtrusive
    * @requires ej.mobile.core
    * @requires ej.mobile.listview
    * @requires ej.mobile.scrollpanel
    * @requires ej.mobile.menu
    * @requires ej.data
    * @requires ej.touch
    * @classdesc Custom Design for Html Autocomplete control.
    * @example 
    * // Create the autocomplete control in unobtrusive way.
    * &lt;input id="autocomplete" data-role="ejmautocomplete" data-ej-datasource="window.datasrc" data-ej-field="name" /&gt;<br>
    * @example 
    * // Create autocomplete on initialization.
    * &lt;input id="autocomplete" /&gt;<br>
    * &lt;script&gt; 
    * // Create autocomplete  
    * $("#autocomplete").ejmAutocomplete({ dataSource:"window.datasrc", field:"name" }); 
    * &lt;/script&gt;
    */

    ej.widget("ejmAutocomplete", "ej.mobile.Autocomplete", {
        _setFirst: true,
        // default model
        _rootCSS: "e-m-acc-wrapper",
        defaults: {
            /**		
            * Specifies whether to be allow the scrolling in suggestion list.
            * @default true
            * @type {boolean}
            * @example 
            * //Set the allowScrolling property in unobtrusive way.
            * &lt;input id="autocomplete" data-role="ejmautocomplete" data-ej-allowscrolling=true data-ej-datasource="window.datasrc" data-ej-field="name" /&gt;<br>
            * @example 
            * // Set the allowScrolling on initialization. 
            * &lt;input id="autocomplete" /&gt;<br>
            * &lt;script&gt; 
            * //To set allowscrolling API value 
            * $("#autocomplete").ejmAutocomplete ({ allowScrolling:true, dataSource:"window.datasrc", field:"name" });			
            * &lt;/script&gt;
            * @example 
            * //Get or set the  allowScrolling, after initialization:<br>
            * // Get the allowScrolling API value.		
            *  $("#autocomplete").ejmAutocomplete ("option", "allowScrolling");			
            * // Set the allowScrolling API
            * $("#autocomplete").ejmAutocomplete ("option", "allowScrolling", true);            
            * @memberof ejmAutocomplete
            * @instance
            */
            allowScrolling: true,
            /**     
            * Section for windows rendermode specific functionalities.                      
            * @memberof ejmAutocomplete
            * @instance
            */
            windows: {
                /**  
                * Specifies whether to render the autocomplete based on the windowsphone's current accent color and device theme
                * @default false
                * @type {boolean}
                * @alias ejmAutocomplete#windows->renderDefault
                * @example 
                * // Set the windows mode renderDefault property in unobtrusive way.
                * &lt;input id="autocomplete" data-role="ejmautocomplete" data-ej-rendermode="windows" data-ej-windows-renderdefault=true data-ej-datasource="window.datasrc" data-ej-field="name" /&gt<br>
                * @example 
                * // To set the windows mode renderDefault property API value 
                * &lt;input id="autocomplete" /&gt;<br>
                * &lt;script&gt; 
                * //To set the windows mode renderDefault API value 
                * $("#autocomplete").ejmAutocomplete({renderMode:"windows", windows:{ renderDefault: true }, dataSource:"window.datasrc", field:"name" });   
                * &lt;/script&gt;
                * @example 
                * // Get or set the windows mode renderDefault API, after initialization:
                * // Get the windows mode renderDefault value  
                * $("#autocomplete").ejmAutocomplete("option", "windows.renderDefault");   
                * // Set the windows mode renderDefault value 
                * $("#autocomplete").ejmAutocomplete("option", "renderMode", "windows"); 
                * $("#autocomplete").ejmAutocomplete("option", "windows.renderDefault", true); 
                * @memberof ejmAutocomplete
                * @instance
                */
                "renderDefault": false
            },
            /**		
            * Specifies the type of the filter by which the filtering occurs.See {@link FilterType}
            * @default contains
            * @type {enum}
            * @example 
            * //Set the filterType property in unobtrusive way.
            * &lt;input id="autocomplete" data-role="ejmautocomplete" data-ej-filtertype="contains" data-ej-datasource="window.datasrc" data-ej-field="name" /&gt;<br>
            * @example 
            * // Set the filterType on initialization. 
            * &lt;input id="autocomplete" /&gt;<br>
            * &lt;script&gt; 
            * //To set the filterType API value 
            * $("#autocomplete").ejmAutocomplete ({ filterType:"ej.mobile.FilterType.Contains", dataSource:"window.datasrc", field:"name" });			
            * &lt;/script&gt;
            * @example 
            * //Get or set the filterType, after initialization:<br>
            * // Get the filterType API value.		
            *  $("#autocomplete").ejmAutocomplete ("option", "filterType");			
            * // Set the filterType API
            * $("#autocomplete").ejmAutocomplete ("option", "filterType", ej.mobile.FilterType.Contains);            
            * @memberof ejmAutocomplete
            * @instance
            */
            filterType: "contains",
            /**		
            * Specifies whether to search key is case sensitive or not on initialization.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the caseSensitiveSearch property in unobtrusive way.
            * &lt;input id="autocomplete" data-role="ejmautocomplete" data-ej-casesensitivesearch=false data-ej-datasource="window.datasrc" data-ej-field="name" /&gt;<br>
            * @example 
            * // Set the caseSensitiveSearch on initialization. 
            * &lt;input id="autocomplete" /&gt;<br>
            * &lt;script&gt; 
            * //To set the caseSensitiveSearch API value 
            * $("#autocomplete").ejmAutocomplete ({ caseSensitiveSearch:false, dataSource:"window.datasrc", field:"name" });			
            * &lt;/script&gt;
            * @example 
            * //Get or set the caseSensitiveSearch, after initialization:<br>
            * // Get the caseSensitiveSearch API value.		
            *  $("#autocomplete").ejmAutocomplete ("option", "caseSensitiveSearch");			
            * // Set the caseSensitiveSearch API
            * $("#autocomplete").ejmAutocomplete ("option", "caseSensitiveSearch", false);            
            * @memberof ejmAutocomplete
            * @instance
            */
            caseSensitiveSearch: false,
            /**		
            * Specifies whether to auto fill option by which we can select and show up the first search result in textbox on initialization.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the enableAutoFill property in unobtrusive way.
            * &lt;input id="autocomplete" data-role="ejmautocomplete" data-ej-enableautofill=false data-ej-datasource="window.datasrc" data-ej-field="name" /&gt;<br>
            * @example 
            * // Set the enableAutoFill on initialization. 
            * &lt;input id="autocomplete" /&gt;<br>
            * &lt;script&gt; 
            * //To set the enableAutoFill API value 
            * $("#autocomplete").ejmAutocomplete ({ enableAutoFill:false, dataSource:"window.datasrc", field:"name" });			
            * &lt;/script&gt;
            * @example 
            * //Get or set the enableAutoFill, after initialization:<br>
            * // Get the enableAutoFill API value.		
            *  $("#autocomplete").ejmAutocomplete ("option", "enableAutoFill");			
            * // Set the enableAutoFill API
            * $("#autocomplete").ejmAutocomplete ("option", "enableAutoFill", false);            
            * @memberof ejmAutocomplete
            * @instance
            */
            enableAutoFill: false,
            /**		
            * Specifies the delimiterChar string for Multivalue mode that separates two items.  
            * @default ","
            * @type {string}
            * @example 
            * //Set the delimiterChar property in unobtrusive way.
            * &lt;input id="autocomplete" data-role="ejmautocomplete" data-ej-enablemultiselect="true" data-ej-delimiterchar="," data-ej-datasource="window.datasrc" data-ej-field="name" /&gt;<br>
            * @example 
            * // Set the delimiterChar on initialization. 
            * &lt;input id="autocomplete" /&gt;<br>
            * &lt;script&gt; 
            * //To set the delimiterChar API value 
            * $("#autocomplete").ejmAutocomplete ({ enableMultiSelect:true, delimiterChar:",", dataSource:"window.datasrc", field:"name"  });			
            * &lt;/script&gt;
            * @example 
            * //Get or set the delimiterChar, after initialization:<br>
            * // Get the delimiterChar API value.		
            *  $("#autocomplete").ejmAutocomplete ("option", "delimiterChar");			
            * // Set the delimiterChar API
            * $("#autocomplete").ejmAutocomplete ("option", "delimiterChar", ",");            
            * @memberof ejmAutocomplete
            * @instance
            */
            delimiterChar: ",",
            /**		
            * Specifies whether to accept multiple values or not.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the enableMultiSelect property in unobtrusive way.
            * &lt;input id="autocomplete" data-role="ejmautocomplete" data-ej-enablemultiselect=false data-ej-datasource="window.datasrc" data-ej-field="name" /&gt;<br>
            * @example 
            * // Set the enableMultiSelect on initialization. 
            * &lt;input id="autocomplete" /&gt;<br>
            * &lt;script&gt; 
            * //To set the enableMultiSelect API value 
            * $("#autocomplete").ejmAutocomplete ({ enableMultiSelect:false, dataSource:"window.datasrc", field:"name" });			
            * &lt;/script&gt;
            * @example 
            * //Get or set the enableMultiSelect, after initialization:<br>
            * // Get the enableMultiSelect API value.		
            *  $("#autocomplete").ejmAutocomplete ("option", "enableMultiSelect");			
            * // Set the enableMultiSelect API
            * $("#autocomplete").ejmAutocomplete ("option", "enableMultiSelect", false);            
            * @memberof ejmAutocomplete
            * @instance
            */
            enableMultiSelect: false,
            /**		
            * Specifies whether to show checkbox in suggestion item list in Multivalue mode.
            * @default true
            * @type {boolean}
            * @example 
            * //Set the enableCheckbox property in unobtrusive way.
            * &lt;input id="autocomplete" data-role="ejmautocomplete" data-ej-multivalue=true data-ej-enablecheckbox=true data-ej-datasource="window.datasrc" data-ej-field="name" /&gt;<br>
            * @example 
            * // Set the enableCheckbox on initialization. 
            * &lt;input id="autocomplete" /&gt;<br>
            * &lt;script&gt; 
            * //To set the enableCheckbox API value 
            * $("#autocomplete").ejmAutocomplete ({ enableCheckbox:true, dataSource:"window.datasrc", field:"name" });			
            * &lt;/script&gt;
            * @example 
            * //Get or set the autocomplete enableCheckbox, after initialization:<br>
            * // Get the enableCheckbox API value.		
            *  $("#autocomplete").ejmAutocomplete ("option", "enableCheckbox");			
            * // Set the enableCheckbox API
            * $("#autocomplete").ejmAutocomplete ("option", "enableCheckbox", true);            
            * @memberof ejmAutocomplete
            * @instance
            */
            enableCheckbox: true,
            /**		
            * Specifies the datasource for items.
            * @default null
            * @type {data}
            * @example 
            * //Set the dataSource property in unobtrusive way.
            * &lt;input id="autocomplete" data-role="ejmautocomplete" data-ej-datasource="window.datasrc" data-ej-field="name" /&gt;<br>
            * @example 
            * // Set the dataSource on initialization. 
            * &lt;input id="autocomplete" /&gt;<br>
            * &lt;script&gt; 
            * //To set the dataSource API value 
            * $("#autocomplete").ejmAutocomplete ({ dataSource:"window.datasrc", field:"name" });			
            * &lt;/script&gt;
            * @example 
            * //Get or set the dataSource, after initialization:<br>
            * // Get the dataSource API value.		
            *  $("#autocomplete").ejmAutocomplete ("option", "dataSource");			
            * // Set the dataSource API
            * $("#autocomplete").ejmAutocomplete ("option", "dataSource", "window.datasrc");            
            * @memberof ejmAutocomplete
            * @instance
            */
            dataSource: null,
            /**		
            * Changes the rendering mode of the autocomplete . See {@link RenderMode}
            * @default auto
            * @type {enum}
            * @example 
            * //Set the renderMode property in unobtrusive way.
            * &lt;input id="autocomplete" data-role="ejmautocomplete" data-ej-rendermode="auto" data-ej-datasource="window.datasrc" data-ej-field="name" /&gt;<br>
            * @example 
            * // Set the renderMode on initialization. 
            * &lt;input id="autocomplete" /&gt;<br>
            * &lt;script&gt; 
            * //To set the renderMode API value 
            * $("#autocomplete").ejmAutocomplete ({ renderMode: ej.mobile.RenderMode.Auto, dataSource:"window.datasrc", field:"name" });			
            * &lt;/script&gt;
            * @example 
            * //Get or set the  renderMode, after initialization:<br>
            * // Get the renderMode API value.		
            *  $("#autocomplete").ejmAutocomplete ("option", "renderMode");			
            * // Set the renderMode API
            * $("#autocomplete").ejmAutocomplete ("option", "renderMode", ej.mobile.RenderMode.Auto);            
            * @memberof ejmAutocomplete
            * @instance
            */
            renderMode: "auto",
            /**		
            * Specifies the number of items shown in the suggestion list.
            * @default 5
            * @type {number}
            * @example 
            * //Set the itemsCount property in unobtrusive way.
            * &lt;input id="autocomplete" data-role="ejmautocomplete" data-ej-itemscount=5 data-ej-datasource="window.datasrc" data-ej-field="name" /&gt;<br>
            * @example 
            * // Set the itemsCount on initialization. 
            * &lt;input id="autocomplete" /&gt;<br>
            * &lt;script&gt; 
            * //To set the itemsCount API value 
            * $("#autocomplete").ejmAutocomplete ({ itemsCount:5, dataSource:"window.datasrc", field:"name" });			
            * &lt;/script&gt;
            * @example 
            * //Get or set the itemsCount, after initialization:<br>
            * // Get the itemsCount API value.		
            *  $("#autocomplete").ejmAutocomplete ("option", "itemsCount");			
            * // Set the itemsCount API
            * $("#autocomplete").ejmAutocomplete ("option", "itemsCount", 5);            
            * @memberof ejmAutocomplete
            * @instance
            */
            itemsCount: 5,
            /**		
            * Specifies the  datasource text field that to be queried by search key on initialization.
            * @default "text"
            * @type {string}
            * @example 
            * //Set the field property in unobtrusive way.
            * &lt;input id="autocomplete" data-role="ejmautocomplete" data-ej-datasource="window.datasrc" data-ej-field="name" /&gt;<br>
            * @example 
            * // Set the field on initialization. 
            * &lt;input id="autocomplete" /&gt;<br>
            * &lt;script&gt; 
            * //To set the field API value 
            * $("#autocomplete").ejmAutocomplete ({ dataSource:"window.datasrc", field:"name" });			
            * &lt;/script&gt;
            * @example 
            * //Get or set the field, after initialization:<br>
            * // Get the field API value.		
            *  $("#autocomplete").ejmAutocomplete ("option", "field");			
            * // Set the field API
            * $("#autocomplete").ejmAutocomplete ("option", "field", "name");            
            * @memberof ejmAutocomplete
            * @instance
            */
            field: "text",
            /**		
            * Specifies the datasource image field as URL.
            * @default null
            * @type {string}
            * @example 
            * //Set the imageField property in unobtrusive way.
            * &lt;input id="autocomplete" data-role="ejmautocomplete" data-ej-datasource="window.datasrc" data-ej-imagefield="image" data-ej-field="name" /&gt;<br>
            * @example 
            * // Set the imageField on initialization. 
            * &lt;input id="autocomplete" /&gt;<br>
            * &lt;script&gt; 
            * //To set the imageField API value 
            * $("#autocomplete").ejmAutocomplete ({ imageField:"image", dataSource:"window.datasrc", field:"name" });			
            * &lt;/script&gt;
            * @example 
            * //Get or set the imageField, after initialization:<br>
            * // Get the imageField API value.		
            *  $("#autocomplete").ejmAutocomplete ("option", "imageField");			
            * // Set the imageField API
            * $("#autocomplete").ejmAutocomplete ("option", "imageField", "image");            
            * @memberof ejmAutocomplete
            * @instance
            */
            imageField: null,
            /**		
            * Changes the theme of the autocomplete . See {@link Theme}
            * @default auto
            * @type {enum}
            * @example 
            * //Set the theme property in unobtrusive way.
            * &lt;input id="autocomplete" data-role="ejmautocomplete" data-ej-theme="auto" data-ej-datasource="window.datasrc" data-ej-field="name" /&gt;<br>
            * @example 
            * // Set the theme on initialization. 
            * &lt;input id="autocomplete" /&gt;<br>
            * &lt;script&gt; 
            * //To set the theme API value 
            * $("#autocomplete").ejmAutocomplete ({ theme: ej.mobile.Theme.Auto, dataSource:"window.datasrc", field:"name" });			
            * &lt;/script&gt;
            * @example 
            * //Get or set the autocomplete theme, after initialization:<br>
            * // Get the theme API value.		
            *  $("#autocomplete").ejmAutocomplete ("option", "theme");			
            * // Set the theme API
            * $("#autocomplete").ejmAutocomplete ("option", "theme", ej.mobile.Theme.Auto);            
            * @memberof ejmAutocomplete
            * @instance
            */
            theme: "auto",
            /**		
            * Specifies the remote url that to be used as a datasource for autocomplete
            * @default null
            * @type {string}
            * @example 
            * //Set the mapper property in unobtrusive way.
            * &lt;input id="autocomplete" data-role="ejmautocomplete" data-ej-mapper="http://mvc.syncfusion.com/Services/Northwnd.svc/Suppliers" data-ej-datasource="window.datasrc" data-ej-field="name" /&gt;<br>
            * @example 
            * // Set the mapper on initialization. 
            * &lt;input id="autocomplete" /&gt;<br>
            * &lt;script&gt; 
            * //To set the mapper API value 
            * $("#autocomplete").ejmAutocomplete ({ mapper: "http://mvc.syncfusion.com/Services/Northwnd.svc/Suppliers", dataSource:"window.datasrc", field:"name" });			
            * &lt;/script&gt;
            * @example 
            * //Get or set the mapper, after initialization:<br>
            * // Get the mapper API value.		
            *  $("#autocomplete").ejmAutocomplete ("option", "mapper");			
            * // Set the mapper API
            * $("#autocomplete").ejmAutocomplete ("option", "mapper", "http://mvc.syncfusion.com/Services/Northwnd.svc/Suppliers");            
            * @memberof ejmAutocomplete
            * @instance
            */
            mapper: null,
            /**		
            * Specifies the autocomplete watermark text that to be shown on autocomplete text box when it is empty
            * @default "Search"
            * @type {string}
            * @example 
            * //Set the watermarkText property in unobtrusive way.
            * &lt;input id="autocomplete" data-role="ejmautocomplete" data-ej-watermarktext="Search" data-ej-datasource="window.datasrc" data-ej-field="name" /&gt;<br>
            * @example 
            * // Set the watermarkText on initialization. 
            * &lt;input id="autocomplete" /&gt;<br>
            * &lt;script&gt; 
            * //To set the watermarkText API value 
            * $("#autocomplete").ejmAutocomplete ({ watermarkText: "Search", dataSource:"window.datasrc", field:"name" });			
            * &lt;/script&gt;
            * @example 
            * //Get or set the watermarkText, after initialization:<br>
            * // Get the watermarkText API value.		
            *  $("#autocomplete").ejmAutocomplete ("option", "watermarkText");			
            * // Set the watermarkText API
            * $("#autocomplete").ejmAutocomplete ("option", "watermarkText", "Search");            
            * @memberof ejmAutocomplete
            * @instance
            */
            watermarkText: "Search",
            /**		
            * Specifies the autocomplete image field of the datasource as Class
            * @default null
            * @type {string}
            * @example 
            * //Set the imageClass property in unobtrusive way.
            * &lt;input id="autocomplete" data-role="ejmautocomplete" data-ej-datasource="window.datasrc" data-ej-imageclass="image" data-ej-field="name" /&gt;<br>
            * @example 
            * // Set the imageClass on initialization. 
            * &lt;input id="autocomplete" /&gt;<br>
            * &lt;script&gt; 
            * //To set the imageClass API value 
            * $("#autocomplete").ejmAutocomplete ({ imageClass:"image", dataSource:"window.datasrc", field:"name" });			
            * &lt;/script&gt;
            * @example 
            * //Get or set the imageClass, after initialization:<br>
            * // Get the imageClass API value.		
            *  $("#autocomplete").ejmAutocomplete ("option", "imageClass");			
            * // Set the imageClass API
            * $("#autocomplete").ejmAutocomplete ("option", "imageClass", "image");            
            * @memberof ejmAutocomplete
            * @instance
            */
            imageClass: null,
            /**		
            * Specifies the whether allowSorting to be allowed or not in suggestion list on initialization
            * @default true
            * @type {boolean}
            * @example 
            * //Set the allowSorting property in unobtrusive way.
            * &lt;input id="autocomplete" data-role="ejmautocomplete" data-ej-allowsorting=true data-ej-datasource="window.datasrc" data-ej-field="name" /&gt;<br>
            * @example 
            * // Set the allowSorting on initialization. 
            * &lt;input id="autocomplete" /&gt;<br>
            * &lt;script&gt; 
            * //To set the allowSorting API value 
            * $("#autocomplete").ejmAutocomplete ({ allowSorting:true, dataSource:"window.datasrc", field:"name" });			
            * &lt;/script&gt;
            * @example 
            * //Get or set the allowSorting, after initialization:<br>
            * // Get the allowSorting API value.		
            *  $("#autocomplete").ejmAutocomplete ("option", "allowSorting");			
            * // Set the allowSorting API
            * $("#autocomplete").ejmAutocomplete ("option", "allowSorting", true);            
            * @memberof ejmAutocomplete
            * @instance
            */
            allowSorting: true,
            /**		
            * Specifies the suggestion list sorting order. See {@link SortOrder}
            * @default ascending
            * @type {enum}
            * @example 
            * //Set the sortOrder property in unobtrusive way.
            * &lt;input id="autocomplete" data-role="ejmautocomplete" data-ej-sortorder="ascending" data-ej-datasource="window.datasrc" data-ej-field="name" /&gt;<br>
            * @example 
            * // Set the sortOrder on initialization. 
            * &lt;input id="autocomplete" /&gt;<br>
            * &lt;script&gt; 
            * //To set the sortOrder API value 
            * $("#autocomplete").ejmAutocomplete ({ sortOrder:ej.mobile.SortOrder.Ascending, dataSource:"window.datasrc", field:"name" });			
            * &lt;/script&gt;
            * @example 
            * //Get or set the sortOrder, after initialization:<br>
            * // Get the sortOrder API value.		
            *  $("#autocomplete").ejmAutocomplete ("option", "sortOrder");			
            * // Set the sortOrder API
            * $("#autocomplete").ejmAutocomplete ("option", "sortOrder", ej.mobile.SortOrder.Ascending);            
            * @memberof ejmAutocomplete
            * @instance
            */
            sortOrder: "ascending",
            /**		
            * Specifies the  textbox value on initialization
            * @default ""
            * @type {string}
            * @example 
            * //Set the value property in unobtrusive way.
            * &lt;input id="autocomplete" data-role="ejmautocomplete" data-ej-value="Text" data-ej-datasource="window.datasrc" data-ej-field="name" /&gt;<br>
            * @example 
            * // Set the value on initialization. 
            * &lt;input id="autocomplete" /&gt;<br>
            * &lt;script&gt; 
            * //To set the value API value 
            * $("#autocomplete").ejmAutocomplete ({ value:"Text", dataSource:"window.datasrc", field:"name" });			
            * &lt;/script&gt;
            * @example 
            * //Get or set the value, after initialization:<br>
            * // Get the value API value.		
            *  $("#autocomplete").ejmAutocomplete ("option", "value");			
            * // Set the value API
            * $("#autocomplete").ejmAutocomplete ("option", "value", "Text");            
            * @memberof ejmAutocomplete
            * @instance
            */
            value: "",
            /**		
            * Specifies the text that to be displayed while there is no suggestion for AutoComplete search key
            * @default "No suggestions"
            * @type {string}
            * @example 
            * //Set the emptyResultText property in unobtrusive way.
            * &lt;input id="autocomplete" data-role="ejmautocomplete" data-ej-emptyresulttext="No suggestions" data-ej-datasource="window.datasrc" data-ej-field="name" /&gt;<br>
            * @example 
            * // Set the emptyResultText on initialization. 
            * &lt;input id="autocomplete" /&gt;<br>
            * &lt;script&gt; 
            * //To set the emptyResultText API value 
            * $("#autocomplete").ejmAutocomplete ({ emptyResultText:"No suggestions", dataSource:"window.datasrc", field:"name" });			
            * &lt;/script&gt;
            * @example 
            * //Get or set the  emptyResultText, after initialization:<br>
            * // Get the emptyResultText API value.		
            *  $("#autocomplete").ejmAutocomplete ("option", "emptyResultText");			
            * // Set the emptyResultText API
            * $("#autocomplete").ejmAutocomplete ("option", "emptyResultText", "No suggestions");            
            * @memberof ejmAutocomplete
            * @instance
            */
            emptyResultText: "No suggestions",
            /**		
            * Specifies the search result to be shown or not while there is no suggestion for AutoComplete search key
            * @default true
            * @type {boolean}
            * @example 
            * //Set the showEmptyResultText property in unobtrusive way.
            * &lt;input id="autocomplete" data-role="ejmautocomplete" data-ej-showemptyresulttext=true data-ej-datasource="window.datasrc" data-ej-field="name" /&gt;<br>
            * @example 
            * // Set the showEmptyResultText on initialization. 
            * &lt;input id="autocomplete" /&gt;<br>
            * &lt;script&gt; 
            * //To set the showEmptyResultText API value 
            * $("#autocomplete").ejmAutocomplete ({ showEmptyResultText:true, dataSource:"window.datasrc", field:"name" });			
            * &lt;/script&gt;
            * @example 
            * //Get or set the showEmptyResultText, after initialization:<br>
            * // Get the showEmptyResultText API value.		
            *  $("#autocomplete").ejmAutocomplete ("option", "showEmptyResultText");			
            * // Set the showEmptyResultText API
            * $("#autocomplete").ejmAutocomplete ("option", "showEmptyResultText", true);            
            * @memberof ejmAutocomplete
            * @instance
            */
            showEmptyResultText: true,
            /**		
            * Specifies the minimum search key length after which only autocomplete querying the datasource
            * @default 1
            * @type {number}
            * @example 
            * //Set the minCharacter property in unobtrusive way.
            * &lt;input id="autocomplete" data-role="ejmautocomplete" data-ej-mincharacter=1 data-ej-datasource="window.datasrc" data-ej-field="name" /&gt;<br>
            * @example 
            * // Set the minCharacter on initialization. 
            * &lt;input id="autocomplete" /&gt;<br>
            * &lt;script&gt; 
            * //To set the minCharacter API value 
            * $("#autocomplete").ejmAutocomplete ({ minCharacter:1 });			
            * &lt;/script&gt;
            * @example 
            * //Get or set the minCharacter, after initialization:<br>
            * // Get the minCharacter API value.		
            *  $("#autocomplete").ejmAutocomplete ("option", "minCharacter");			
            * // Set the minCharacter API
            * $("#autocomplete").ejmAutocomplete ("option", "minCharacter", 1);            
            * @memberof ejmAutocomplete
            * @instance
            */
            minCharacter: 1,
            /**		
            * Specifies whether the duplicate results to be shown or not in search results
            * @default false
            * @type {boolean}
            * @example 
            * //Set the enableDistinct property in unobtrusive way.
            * &lt;input id="autocomplete" data-role="ejmautocomplete" data-ej-enabledistinct=false data-ej-datasource="window.datasrc" data-ej-field="name" /&gt;<br>
            * @example 
            * // Set the enableDistinct on initialization. 
            * &lt;input id="autocomplete" /&gt;<br>
            * &lt;script&gt; 
            * //To set the enableDistinct API value 
            * $("#autocomplete").ejmAutocomplete ({ enableDistinct:false, dataSource:"window.datasrc", field:"name" });			
            * &lt;/script&gt;
            * @example 
            * //Get or set the enableDistinct, after initialization:<br>
            * // Get the enableDistinct API value.		
            *  $("#autocomplete").ejmAutocomplete ("option", "enableDistinct");			
            * // Set the enableDistinct API
            * $("#autocomplete").ejmAutocomplete ("option", "enableDistinct", false);            
            * @memberof ejmAutocomplete
            * @instance
            */
            enableDistinct: false,
            /**		
            * Current model value to browser cookies for state maintains. While refresh the Autocomplete control page retains the model value apply from browser cookies.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the enablePersistence property in unobtrusive way.
            * &lt;input id="autocomplete" data-role="ejmautocomplete" data-ej-enablepersistence=false data-ej-datasource="window.datasrc" data-ej-field="name" /&gt;<br>
            * @example 
            * // Set the enablePersistence on initialization. 
            * &lt;input id="autocomplete" /&gt;<br>
            * &lt;script&gt; 
            * //To set the enablePersistence API value 
            * $("#autocomplete").ejmAutocomplete ({ enablePersistence:false, dataSource:"window.datasrc", field:"name" });			
            * &lt;/script&gt;
            * @example 
            * //Get or set the enablePersistence, after initialization:<br>
            * // Get the persist API value.		
            *  $("#autocomplete").ejmAutocomplete ("option", "enablePersistence");			
            * // Set the persist API
            * $("#autocomplete").ejmAutocomplete ("option", "enablePersistence", false);            
            * @memberof ejmAutocomplete
            * @instance
            */
            enablePersistence: false,
            /**		
            * Specifies whether to enable the autoComplete on initialization.
            * @default true
            * @type {boolean}
            * @example 
            * //Set the enabled property in unobtrusive way.
            * &lt;input id="autocomplete" data-role="ejmautocomplete" data-ej-enabled=true data-ej-datasource="window.datasrc" data-ej-field="name" /&gt;<br>
            * @example 
            * // Set the enabled on initialization. 
            * &lt;input id="autocomplete" /&gt;<br>
            * &lt;script&gt; 
            * //To set the enabled API value 
            * $("#autocomplete").ejmAutocomplete ({ enabled:true, dataSource:"window.datasrc", field:"name" });			
            * &lt;/script&gt;
            * @example 
            * //Get or set the  enabled, after initialization:<br>
            * // Get the enabled API value.		
            *  $("#autocomplete").ejmAutocomplete ("option", "enabled");			
            * // Set the enabled API
            * $("#autocomplete").ejmAutocomplete ("option", "enabled", true);            
            * @memberof ejmAutocomplete
            * @instance
            */
            enabled: true,
            /**		
            * Specifies the AutoComplete mode. See {@link Mode}
            * @default default
            * @type {enum}
            * @example 
            * //Set the mode property in unobtrusive way.
            * &lt;input id="autocomplete" data-role="ejmautocomplete" data-ej-mode="default" data-ej-datasource="window.datasrc" data-ej-field="name" /&gt;<br>
            * @example 
            * // Set the mode on initialization. 
            * &lt;input id="autocomplete" /&gt;<br>
            * &lt;script&gt; 
            * //To set the mode API value 
            * $("#autocomplete").ejmAutocomplete ({ mode:ej.mobile.Mode.Default, dataSource:"window.datasrc", field:"name" });			
            * &lt;/script&gt;
            * @example 
            * //Get or set the mode, after initialization:<br>
            * // Get the mode API value.		
            *  $("#autocomplete").ejmAutocomplete ("option", "mode");			
            * // Set the mode API
            * $("#autocomplete").ejmAutocomplete ("option", "mode", ej.mobile.Mode.Default);            
            * @memberof ejmAutocomplete
            * @instance
            */
            mode: "default",
            /**    
            * Event triggers when the touch end happens in the AutoComplete suggestion list.
            * @event
            * @name ejmAutocomplete#touchEnd 	
            * @param {Object} argument Event parameters from autocomplete     
            * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
            * @param {string} argument.model returns the autocomplete model
            * @param {string} argument.type returns the name of the event
            * @param {Object} argument.element returns the current element
            * @param {string} argument.currentText returns the current item text
            * @param {boolean} argument.isChecked returns whether the current item is checked or not
            * @param {object} argument.checkedItemsText returns all checked item's text
            * @example 
            * &lt;input id="autocomplete" data-role="ejmautocomplete" data-ej-datasource="window.datasrc" data-ej-field="name" data-ej-touchend="onTouchEnd" /&gt;<br>
            * &lt;script&gt; 
            * // touchEnd event for autocomplete  
            * function onTouchEnd(args){
            * //handle the event
            * }
            * &lt;/script&gt;
            * @example 
            * //touchEnd event for autocomplete
            * &lt;input id="autocomplete" /&gt;<br>
            * &lt;script&gt; 
            * $("#autocomplete").ejmAutocomplete({ dataSource:"window.datasrc", field:"name",
            *   touchEnd: function (args) { 
            * //handle the event 
            * }
            * });           
            * &lt;/script&gt;
            * @memberof ejmAutocomplete
            * @instance
            */
            touchEnd: null,
            /**    
            * Event triggers when pressed a key
            * @event
            * @name ejmAutocomplete#keyPress 	
            * @param {Object} argument Event parameters from autocomplete     
            * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
            * @param {string} argument.model returns the autocomplete model
            * @param {string} argument.type returns the name of the event
            * @example 
            * &lt;input id="autocomplete" data-role="ejmautocomplete" data-ej-datasource="window.datasrc" data-ej-field="name" data-ej-keypress="onkeyPress" /&gt;<br>
            * &lt;script&gt; 
            * // keyPress event for autocomplete  
            * function onkeyPress(args){ 
            * //handle the event
            * }
            * &lt;/script&gt;
            * @example 
            * //keyPress event for autocomplete
            * &lt;input id="autocomplete" /&gt;<br>
            * &lt;script&gt; 
            * $("#autocomplete").ejmAutocomplete({ dataSource:"window.datasrc", field:"name",
            *   keyPress: function (args) { 
            * //handle the event 
            * }
            * });           
            * &lt;/script&gt;
            * @memberof ejmAutocomplete
            * @instance
            */
            keyPress: null,
            /**    
            * Event triggers when we select a element from AutoComplete suggestion list.
            * @event
            * @name ejmAutocomplete#select 	
            * @param {Object} argument Event parameters from autocomplete     
            * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
            * @param {string} argument.model returns the autocomplete model
            * @param {string} argument.type returns the name of the event
            * @param {Object} argument.element returns the current element
            * @param {string} argument.currentText returns the current item text
            * @param {boolean} argument.isChecked returns whether the current item is checked or not
            * @param {object} argument.checkedItemsText returns all checked item's text
            * @example 
            * &lt;input id="autocomplete" data-role="ejmautocomplete" data-ej-datasource="window.datasrc" data-ej-field="name" data-ej-select="onSelect" /&gt;<br>
            * &lt;script&gt; 
            * // select event for autocomplete  
            * function onSelect(args){ 
            * //handle the event
            * }
            * &lt;/script&gt;
            * @example 
            * //select event for autocomplete
            * &lt;input id="autocomplete" /&gt;<br>
            * &lt;script&gt; 
            * $("#autocomplete").ejmAutocomplete({ dataSource:"window.datasrc", field:"name",
            *   select: function (args) { 
            * //handle the event 
            * }
            * });           
            * &lt;/script&gt;
            * @memberof ejmAutocomplete
            * @instance
            */
            select: null,
            /**    
            * Event triggers when the AutoComplete text box content changed.
            * @event
            * @name ejmAutocomplete#change 	
            * @param {Object} argument Event parameters from autocomplete     
            * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
            * @param {string} argument.model returns the autocomplete model
            * @param {string} argument.type returns the name of the event
            * @param {Object} argument.element returns the current element
            * @param {string} argument.currentText returns the current item text
            * @param {boolean} argument.isChecked returns whether the current item is checked or not
            * @param {object} argument.checkedItemsText returns all checked item's text
            * @example 
            * &lt;input id="autocomplete" data-role="ejmautocomplete" data-ej-datasource="window.datasrc" data-ej-field="name" data-ej-change="onChange" /&gt;<br>
            * &lt;script&gt; 
            * // change event for autocomplete  
            * function onChange(args){ 
            * //handle the event
            * }
            * &lt;/script&gt;
            * @example 
            * //change event for autocomplete
            * &lt;input id="autocomplete" /&gt;<br>
            * &lt;script&gt; 
            * $("#autocomplete").ejmAutocomplete({ dataSource:"window.datasrc", field:"name",
            *   change: function (args) { 
            * //handle the event 
            * }
            * });           
            * &lt;/script&gt;
            * @memberof ejmAutocomplete
            * @instance
            */
            change: null,
            /**    
            * Event triggers when focused in to the Autocomplete text box
            * @event
            * @name ejmAutocomplete#focusIn 	
            * @param {Object} argument Event parameters from autocomplete     
            * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
            * @param {string} argument.model returns the autocomplete model
            * @param {string} argument.type returns the name of the event
            * @example 
            * &lt;input id="autocomplete" data-role="ejmautocomplete" data-ej-datasource="window.datasrc" data-ej-field="name" data-ej-focusin="onfocusIn" /&gt;<br>
            * &lt;script&gt; 
            * // focusIn event for autocomplete  
            * function onfocusIn(args){ 
            * //handle the event
            * }
            * &lt;/script&gt;
            * @example 
            * //focusIn event for autocomplete
            * &lt;input id="autocomplete" /&gt;<br>
            * &lt;script&gt; 
            * $("#autocomplete").ejmAutocomplete({ dataSource:"window.datasrc", field:"name",
            *   focusIn: function (args) { 
            * //handle the event 
            * }
            * });           
            * &lt;/script&gt;
            * @memberof ejmAutocomplete
            * @instance
            */
            focusIn: null,
            /**    
            * Event triggers when focused out from the Autocomplete text box
            * @event
            * @name ejmAutocomplete#focusOut 	
            * @param {Object} argument Event parameters from autocomplete     
            * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
            * @param {string} argument.model returns the autocomplete model
            * @param {string} argument.type returns the name of the event
            * @example 
            * &lt;input id="autocomplete" data-role="ejmautocomplete" data-ej-datasource="window.datasrc" data-ej-field="name" data-ej-focusout="onfocusOut" /&gt;<br>
            * &lt;script&gt; 
            * // focusOut event for autocomplete  
            * function onfocusOut(args){ 
            * //handle the event
            * }
            * &lt;/script&gt;
            * @example 
            * //focusOut event for autocomplete
            * &lt;input id="autocomplete" /&gt;<br>
            * &lt;script&gt; 
            * $("#autocomplete").ejmAutocomplete({ dataSource:"window.datasrc", field:"name",
            *   focusOut: function (args) { 
            * //handle the event 
            * }
            * });           
            * &lt;/script&gt;
            * @memberof ejmAutocomplete
            * @instance
            */
            focusOut: null
        },
        dataTypes: {
            filterType: "enum",
            renderMode: "enum",
            caseSensitiveSearch: "boolean",
            theme: "enum",
            enableAutoFill: "boolean",
            enableMultiSelect: "boolean",
            enableCheckbox: "boolean",
            dataSource: "data",
            allowSorting: "boolean",
            sortOrder: "enum",
            emptyResultText: "string",
            delimiterChar: "string",
            showEmptyResultText: "boolean",
            minCharacter: "number",
            enableDistinct: "boolean",
            enablePersistence: "boolean",
            enable: "boolean",
            mode: "enum",
            field: "string"
        },
        /**
        * Constructor function	
        * @private
        */
        _init: function () {
            this._cloneElement = this.element.clone();
            this._initialize();
            this._renderControl();
            ej._setScroller(this);
            this._wireEvents();
        },

        /**
        * Initialize the autocomplete control	
        * @private
        */
        _initialize: function () {
            this._queryString = "";
            this._filterMode = "server";
            if (typeof (this.model.mapper) != "string")
                this._filterMode = "client";
            window.accFields = {
                "text": this.model.field,
                "imageClass": this.model.imageClass,
                "imageUrl": this.model.imageField
            };
            window.noresult = {
                "text": "emptyResultText"
            };
            window.noSuggSource = [{}];
            window.noSuggSource[0][this.model.field] = this.model.emptyResultText;
            this.model.delimiterChar = this.model.delimiterChar + " ";
        },
        /**
        * Renders the autocomplete control
        * @private
        */
        _renderControl: function () {
            ej.setRenderMode(this);
            ej.setTheme(this);
            if (this.model.renderMode == "windows" && this.model.windows.renderDefault && ej.isMobile())
                this.model.theme = "default";
            this._id = this.element[0].id;
            this.element.addClass("e-m-acc-input").attr("placeholder", this.model.watermarkText).addClass("e-m-acc-" + this.model.mode);
            this._accwrapper = ej.buildTag("div#" + this._id + "_wrapper.e-m-acc-wrapper").addClass("e-m-" + this.model.renderMode + " e-m-" + this.model.theme).addClass("e-m-acc-" + this.model.mode);
            this._accwrapper = this.element.wrap(this._accwrapper).parent();
            this._search = ej.buildTag('div.e-m-acc-searchicon').addClass('e-m-fontimage').appendTo(this._accwrapper);
            this._custAnd = ej.buildTag("div.e-m-acc-custand").appendTo(this._accwrapper);
            this._clrElement = ej.buildTag("div.e-m-acc-clear").addClass('e-m-fontimage').appendTo(this._accwrapper);
            this._accList = ej.buildTag('div#' + this._id + 'list.e-m-acc-list').appendTo(this._accwrapper);
            this._accList.ejmListView({ 'adjustFixedPosition': false, 'renderMode': this.model.renderMode, 'theme': this.model.theme, 'showHeader': false, 'allowScrolling': this.model.allowScrolling, 'dataBinding': true, 'fieldSettings': window.accFields, "touchEnd": $.proxy(this._touchEnd, this), "enableCheckMark": (this.model.enableCheckbox && this.model.enableMultiSelect) ? true : false, "windows": { "renderDefault": this.model.windows.renderDefault} });
            if (this.model.renderMode == "ios7" && !ej.isMobile()) {
                this._accMenu = ej.buildTag('div#' + this._id + 'menu.e-m-acc-menu');
                this._accMenu.ejmMenu({ "renderTemplate": true, 'renderMode': this.model.renderMode, 'theme': this.model.theme, 'allowScrolling': false, "showOn": "", "targetId": "" + this._id + "", "templateId": '' + this._id + 'list', 'onShow': $.proxy(this._onMenuShow, this), "ios7": { "title": "Results" }, "windows": { "renderDefault": this.model.windows.renderDefault} });
                $('#' + this._id + "menu_overlay").css("pointer-events", "none");
            }
            this._accList.hide();
            if (this.model.value)
                this.element.val(this.model.value);
            this._clear();
            if (!this.model.enabled)
                this._setEnabled(false);
        },
        /**
        * Touch start on autocomplete suggestion list 
        * @private
        */
        _touchStart: function (evt) {
            ej._inputTouchStart(evt, this);
            ej.listenEvents([window, window, window],
                                [ej.moveEvent(), ej.cancelEvent(), ej.endEvent()],
                                [this._touchMoveProxy, this._touchEndProxy, this._touchEndProxy],
                                false);
        },
        /**
        * Touch move on autocomplete suggestion list 
        * @private
        */
        _touchMove: function (evt) {
            ej._inputTouchMove(evt, this);
        },
        /**
        * Touch end on autocomplete textbox  
        * @private
        */
        _touchInputEnd: function (evt) {
            ej._inputTouchEnd(evt, this);
            ej.listenEvents([window, window, window],
                                [ej.moveEvent(), ej.cancelEvent(), ej.endEvent()],
                                [this._touchMoveProxy, this._touchEndProxy, this._touchEndProxy],
                                true);
        },
        /**
        * Creates Delegates for the functions 
        * @private
        */
        _createDelegates: function () {
            this._onFocusDelegate = $.proxy(this._onFocusHandler, this);
            this._onBlurDelegate = $.proxy(this._onBlurHandler, this);
            this._onDocClickDelegate = $.proxy(this._docClick, this);
            this._onKeypressDelegate = $.proxy(this._onKeypressHandler, this);
            this._onClearClickDelegate = $.proxy(this._onClearClickHandler, this);
            this._touchStartProxy = $.proxy(this._touchStart, this);
            this._touchMoveProxy = $.proxy(this._touchMove, this);
            this._touchEndProxy = $.proxy(this._touchInputEnd, this);
        },
        /**
        * Wire events for autocomplete    
        * @private
        */
        _wireEvents: function (remove) {
            this._createDelegates();
            ej.listenEvents([this.element, this.element, this.element], ["focus", "blur", "keyup"], [this._onFocusDelegate, this._onBlurDelegate, this._onKeypressDelegate], remove);
            if (ej.isDevice())
                ej.listenTouchEvent(this.element, ej.startEvent(), this._touchStartProxy, remove);
            ej.listenEvents([App.document, this._accwrapper.find(".e-m-acc-clear")], [ej.tapEvent(), ej.endEvent()], [this._onDocClickDelegate, this._onClearClickDelegate], remove);
        },
        /**
        * On focus in to the autocomplete textbox 
        * @private
        */
        _onFocusHandler: function (evt) {
            var proxy = this;
            var chars = this.element.val().substring(this.element.val().length - 2, this.element.val().length);
            if (chars == this.model.delimiterChar)
                this.element.val(this.element.val().replace(this.element.val().lastIndexOf(this.model.delimiterChar), ""));
            this._temptext = this.element.val();
            this._tempobj = this.element;
            if (this.model.enableMultiSelect && !this._accList.is(':visible') && this.element.val() != ""
                          && !this._focus && this.element.val()[this.element.val().length - 1] != this.model.delimiterChar.trim()) {
                this.element.val(this.element.val() + this.model.delimiterChar);
                this._focus = true;
            }
            if (this.model.renderMode == 'android')
                this._custAnd.addClass('e-m-acc-focus');
            else
                this.element.addClass('e-m-acc-focus');
            var tempstr = this.element.val();
            this.element.val(tempstr);
            proxy.element[0].scrollLeft = proxy.element[0].scrollWidth;
            window.setTimeout(function () {
                ej.setCaretToPos(proxy.element[0], proxy.element.val().length, proxy.element.val().length);
            });
            var data = { value: this.element.val() != "" ? this.element.val().substring(0, this.element.val().length - 2) : this.element.val() };
            if (this.model.focusIn) this._trigger("focusIn", data);
        },
        /**
        * On blur to the autocomplete textbox 
        * @private
        */
        _onBlurHandler: function (evt) {
            if (this.model.renderMode == 'android')
                this._custAnd.removeClass('e-m-acc-focus');
            else
                this.element.removeClass('e-m-acc-focus');
            this.element[0].scrollLeft = 0;
            var data = { value: this.element.val() != "" ? this.element.val().substring(0, this.element.val().length - 2) : this.element.val() };
            if (this.model.focusOut) this._trigger("focusOut", data);
        },
        /**
        * On click of clear icon in autocomplete textbox 
        * @private
        */
        _onClearClickHandler: function (evt) {
            this.element.val("");
            this.element.attr("placeholder", this.model.watermarkText);
            if (this.model.renderMode == "ios7") {
                this._clrElement.css("display", "none");
                if (this._accList)
                    this._accList.css("display", "none");
            }
        },
        /**
        * Touch end on autocomplete suggestion list 
        * @private
        */
        _touchEnd: function (data) {
            this._checkflag = data.isChecked;
            this._selectedVal = data.text;
            this._checkeditems = data.checkedItemsText ? data.checkedItemsText.toString() : "";
            if (this._selectedVal != this.model.emptyResultText) {
                if (this.model.enableMultiSelect) {
                    this._tempword = this._selectedVal;
                    this._setMultiValueText(this._selectedVal);
                }
                else {
                    this.element.val(this._selectedVal);
                    this._hideSuggestions();
                }
            }
            data.value = this.element.val() != "" ? this.element.val().substring(0, this.element.val().length - 2) : this.element.val();
            this._selectedItems = data.checkedItemsText;
            if (this._selectedVal != this.model.emptyResultText) {
                if (this.model.touchEnd) this._trigger("touchEnd", data);
                if (this.model.select) this._trigger("select", data);
                if (this.model.change) this._trigger("change", data);
            }
        },
        /**
        * Setting multivalue text to the autocomplete textbox 
        * @private
        */
        _setMultiValueText: function (data) {
            var proxy = this;
            var delimiterIndex = (this._getDelimiterIndex() == -1) ? this._getDelimiterIndex() + 1 : this._getDelimiterIndex() + 2;
            var currentVal = this.element.val();
            var contains = (this.element.val().indexOf(data) > -1);
            if (this.model.enableMultiSelect) {
                contains = false;
                var values = currentVal.split(this.model.delimiterChar);
                var inputvalues = this._checkeditems.split(this.model.delimiterChar);
                for (var i = 0; i < values.length; i++) {
                    if (values[i] == this._tempword)
                        contains = true;
                }
            }
            if (contains) {
                if (!this._checkflag)
                    this.element.val(this.element.val().replace(this._tempword + this.model.delimiterChar, ""));
            }
            else {
                if (this._checkflag)
                    this.element.val(currentVal.substring(0, delimiterIndex) + data + this.model.delimiterChar);
            }
            window.setTimeout(function () {
                proxy.element[0].scrollLeft = proxy.element[0].scrollWidth;
            });
        },
        /**
        * Getting delimiterChar index value 
        * @private
        */
        _getDelimiterIndex: function () {
            return this.element.val().lastIndexOf(this.model.delimiterChar);
        },
        /**
        * Define visibility of the clear icon in autocomplete textbox 
        * @private
        */
        _clear: function () {
            if (this.model.renderMode == "ios7") {
                if (this.element.val() == "")
                    this._clrElement.css("display", "none");
                else
                    this._clrElement.css("display", "inline");
            }
        },
        /**
        * To show suggestion list 
        * @private
        */
        _showSuggestions: function (evt) {
            var proxy = this;
            proxy._accList.show();
            if (proxy.model.renderMode == "ios7" && !ej.isMobile() && this.element.val().length)
                $('#' + proxy._id + 'menu').ejmMenu('show', evt);
            this._hideNoResults();
        },
        /**
        * To hide suggestion list 
        * @private
        */
        _hideSuggestions: function () {
            var proxy = this;
            if (proxy.model.renderMode == "ios7" && !ej.isMobile())
                $('#' + proxy._id + 'menu').ejmMenu('hide');
            proxy._accList.hide();
        },
        /**
        * On key press while focus in to the autocomplete textbox  
        * @private
        */
        _onKeypressHandler: function (evt) {
            if (evt.keycode == 8 || evt.keycode == 46)
                this._focus = true;
            this._keycode = evt.keyCode;
            var proxy = this;
            this._clear();
            var data = { value: this.element.val() };
            if (this.model.keyPress)
                this._trigger("keyPress", data);
            this._textValue = evt.target.value;
            if (evt.keyCode == 13)
                evt.preventDefault();
            else {
                this.model.value = this.element.val();
                if (this._textValue == "") {
                    this._hideSuggestions();
                    return;
                }
                if (this.model.enableMultiSelect) {
                    var delimiterIndex = (this._getDelimiterIndex() == -1) ? this._getDelimiterIndex() + 1 : this._getDelimiterIndex() + 2;
                    this._queryString = this._textValue.substring(delimiterIndex);
                }
                else
                    this._queryString = this._textValue;
                if (this._queryString.length >= this.model.minCharacter) {
                    if (this._filterMode == "client") {
                        this._resultData = this._filterResult();
                        this._renderSuggestionList(this._resultData);
                        if (this.model.enableAutoFill && evt.keyCode != 8 && this.model.filterType == 'startswith') {
                            if (this._resultData.length == 0) {
                                proxy._accList.ejmListView({ "dataSource": window.noSuggSource });
                                proxy._accList.find('.e-m-lv-checkdiv').remove();
                            }
                            else
                                this._setInputText(this._resultData[0]);
                        }
                        this._showSuggestions(evt);
                        ej.getCurrentPage().find("#" + this._id + "list_scroll").ejmScrollPanel("refresh")
                        this._setListHeight(this._resultData);
                        this._checkSelectedItems();
                    }
                    else
                        this._sendAjaxRequest(evt);
                }
                else
                    this._hideSuggestions();
            }
            if (this._accList.text() == this.model.emptyResultText)
                this._accList.ejmListView('removeCheckMark');
            ej._setScroller(this);
            this._x = this.element[0].scrollLeft;
        },
        /**
        * Setting autocomplete suggestion list height
        * @private
        */
        _setListHeight: function (data) {
            if (data.length > this.model.itemsCount)
                this._accList.ejmListView({ "height": (this._accList.find('li.e-m-list').outerHeight() * (this.model.itemsCount)) + ((this.model.renderMode == 'windows') ? 10 : 0) });
            else {
                if (this._accList.text() == this.model.emptyResultText)
                    this._accList.ejmListView({ "height": (this._accList.find('li.e-m-list').outerHeight()) + ((this.model.renderMode == 'windows') ? 10 : 0) });
                else
                    this._accList.ejmListView({ "height": (this._accList.find('li.e-m-list').outerHeight() * (data.length)) + ((this.model.renderMode == 'windows') ? 10 : 0) });
            }
            if (this.model.renderMode == "ios7" && !ej.isMobile()) {
                this._accMenu.height((this._accList.find('.e-m-list-container').outerHeight()) + 49);
                this._accMenu.find('.e-m-menu-container').height((this._accList.find('.e-m-list-container').outerHeight()));
                this._accMenu.find('.e-m-menu-container .e-m-lv').height((this._accList.find('.e-m-list-container').outerHeight()));
            }
        },
        /**
        * Send ajax request to get result from remote url 
        * @private
        */
        _sendAjaxRequest: function (testevent) {
            var tempEvt = {};
            $.extend(true, tempEvt, testevent);
            var dataManager = ej.DataManager({
                url: this.model.mapper,
                crossDomain: true
            });
            var proxy = this;
            var query = ej.Query().where(this.model.field, this.model.filterType, this._queryString, !this.model.caseSensitiveSearch);
            dataManager.executeQuery(query).done(function (data) {
                proxy._renderSuggestionList(data.result);
                proxy.model.dataSource = data.result;
                proxy._resultData = data.result;
                if (proxy.model.enableAutoFill && proxy._keycode != 8 && proxy.model.filterType == 'startswith')
                    proxy._setInputText(proxy._resultData[0]);
                proxy._showSuggestions(tempEvt);
                proxy._setListHeight(data.result);
                proxy._checkSelectedItems();
                if (proxy.element.val() == "")
                    proxy._hideSuggestions();
            });
        },
        /**
        * To check selected items
        * @private
        */
        _checkSelectedItems: function () {
            var proxy = this;
            if (proxy.model.enableMultiSelect && proxy.model.enableCheckbox) {
                proxy._accList.find('.e-m-list ').each(function (index, element) {
                    var str = $(element).text();
                    if (proxy._tempobj.val().indexOf(str) > -1)
                        proxy._accList.ejmListView("checkItem", $(element).index());
                });
            }
        },
        /**
        * Rendering suggestion list for autocomplete control 
        * @private
        */
        _renderSuggestionList: function (data) {
            data.value = this.element.val() != "" ? this.element.val().substring(0, this.element.val().length - 2) : this.element.val();
            if (this.element.val() != this._temptext) {
                if (this.model.change)
                    this._trigger("change", data);
            }
            if (this.model.enableDistinct) {
                var mapper = this.model.field, mapFld = { _name: null };
                mapFld._name = (mapper && mapper.name) ? mapper["name"] : "name";
                this._resultData = ej.dataUtil.distinct(data, mapFld._name, true);
            }

            else {
                this._resultData = data;
            }
            if (this._resultData.length == 0 && this._accList.ejmListView('getItemText', 0) != this.model.emptyResultText) {
                this._accList.ejmListView({ "dataSource": window.noSuggSource });
                this._accList.find('.e-m-lv-checkdiv').remove();
            }
            else if (this._resultData.length)
                this._accList.ejmListView({ "dataSource": this._resultData });
            ej.listenEvents([this._accList, this._accList], [ej.startEvent(), ej.endEvent()], [this._onTouchStartDelegate, this._onTouchEndDelegate], false);
        },
        /**
        * To perform sorting on search results 
        * @private
        */
        _addSortingQuery: function (query, key) {
            if (this.model.allowSorting) {
                var order = (this.model.sortOrder == "descending") ? true : false;
                query.sortBy(key, order);
            }
        },
        /**
        * Set input element text for autofill feature 
        * @private
        */
        _setInputText: function (data) {
            var delimiterIndex = this._getDelimiterIndex() + 1;
            var currentVal = this.element.val();
            var x = this.element[0].selectionStart;
            var contains = (this.element.val().indexOf(data.name) > -1);
            if (!contains)
                this.element.val(currentVal.substring(0, delimiterIndex) + data[this.model.field]);
            this.element[0].selectionStart = x;
            var y = this.element[0].selectionEnd;
            this.element[0].selectionEnd = y;
        },
        /**
        * To filter result  
        * @private
        */
        _filterResult: function () {
            datasource = eval(this.model.dataSource);
            var dataManager = ej.DataManager(datasource);
            var field = !this._isJson(datasource) ? "" : this.model.field;
            var query = ej.Query().where(field, this.model.filterType, this._queryString, !this.model.caseSensitiveSearch);
            this._addSortingQuery(query, field);
            return dataManager.executeLocal(query);
        },
        /**
        * To check the datasource whether it is Json data or not 
        * @private
        */
        _isJson: function (data) {
            return typeof (data[0]) == "object";
        },
        /**
        * On document click event
        * @private
        */
        _docClick: function (evt) {
            if (this.model.enableMultiSelect) {
                if ($(evt.target).closest('.e-m-list').length != true && (!$(evt.target).hasClass('e-m-acc-input'))) {
                    if (this.element.val().substring(this.element.val().length - 2, this.element.val().length) == this.model.delimiterChar)
                        this.element.val(this.element.val().substring(0, this.element.val().length - 2));
                    this._focus = false;
                }
            }
            if ($(evt.target).closest('.e-m-list').length != true && evt.target.id != this._id)
                this._hideSuggestions();
            if (this.model.renderMode == "ios7") {
                if (!ej.isMobile() && $(evt.target).closest('.e-m-menu').length != true && (!$(evt.target).hasClass('e-m-acc-input')))
                    this._hideSuggestions();
            }
            if (!$(evt.target).hasClass('e-m-acc-input'))
                this.element.blur();
        },
        /**
        * To set model values to the autocomplete control 
        * @private
        */
        _setModel: function (options) {
            if (!this.model.enabled && ej.isNullOrUndefined(options["enabled"])) return false;
            for (var key in options)
                switch (key) {
                case "theme": this._setTheme(options.theme); break;
                case "renderMode": this._setRenderMode(options.renderMode); break;
                case "showEmptyResultText": this._setShowEmptyResultText(options.showEmptyResultText); break;
                case "value": this._setValue(options.value); break;
                case "watermarkText": this.model.watermarkText = options.watermarkText; this._setWatermarkText(options.watermarkText); break;
                case "enabled": this._setEnabled(options.enabled); break;
                case "mode": this._setMode(options.mode); break;
            }
        },
        /**
        * To set rendermode to AutoComplete Control 
        * @private
        */
        _setRenderMode: function (mode) {
            this.model.renderMode = mode;
            if (mode == "auto")
                ej.setRenderMode(this);
            var tempmode = this.model.renderMode;
            this._accwrapper.removeClass("e-m-android e-m-ios7 e-m-windows e-m-flat").addClass("e-m-" + this.model.renderMode);
        },
        /**
        * To set theme to AutoComplete Control 
        * @private
        */
        _setTheme: function (theme) {
            this.model.theme = theme;
            if (this.model.theme == "auto")
                ej.setTheme(this);
            this._accwrapper.removeClass("e-m-light e-m-dark").addClass("e-m-" + this.model.theme);
        },
        /**
        * To change showEmptyResult property for AutoComplete  
        * @private
        */
        _setShowEmptyResultText: function (noresults) {
            this.model.showEmptyResultText = noresults;
            this._hideNoResults();
        },
        /**
        * To hide suggestion list in case of no results  
        * @private
        */
        _hideNoResults: function () {
            if (!this.model.showEmptyResultText && ((this._resultData && this._resultData.length == 0) || !this._resultData) && this._accList.ejmListView('getItemText', 0) == this.model.emptyResultText)
                this._hideSuggestions();
        },
        /**
        * To set input value to autocomplete textbox
        * @private
        */
        _setValue: function (value) {
            if (typeof value === "object" || (typeof value === "number" && isNaN(value))) value = "";
            this.model.value = value = $.trim(value);
            this.element.val("");
            if (value) this.element.val(value);
        },
        /**
        * To set watermarktext to AutoComplete textbox 
        * @private
        */
        _setWatermarkText: function (text) {
            if (this.model.watermarkText) this.element.attr("placeholder", text);
            else if (this.element.val() == "") this.element.val(text);
        },
        /**
        * To set mode to AutoComplete textbox 
        * @private
        */
        _setMode: function (mode) {
            if (mode) {
                this.model.mode = mode;
                this._accwrapper.removeClass("e-m-acc-default e-m-acc-search").addClass("e-m-acc-" + this.model.mode);
                this.element.removeClass("e-m-acc-default e-m-acc-search").addClass("e-m-acc-" + this.model.mode);
            }
        },
        /**
        * To refresh AutoComplete Control 
        * @private
        */
        _refresh: function () {
            this._destroy();
            this._renderControl();
            this._wireEvents();
        },
        /**
        * To destroy AutoComplete Control 
        * @private
        */
        _destroy: function () {
            this.element.html(this._cloneElement.html())
            if (this._accList) {
                this._accList.ejmListView('destroy');
                this._accList.remove();
            }
            if (this._accMenu) {
                this._accMenu.ejmMenu('destroy');
                this._accMenu.remove();
            }
        },
        /**
        * To change enable property to AutoComplete textbox 
        * @private
        */
        _setEnabled: function (boolean) {
            if (boolean) {
                this.model.enabled = true;
                this.enable();
            }
            else {
                this.model.enabled = false;
                this.disable();
            }
        },

        /*---------------Public Methods---------------*/

        /**
        * To enable AutoComplete 
        * @return jQuery
        * @example 
        * &lt;input id="autocomplete"/&gt;<br>
        * &lt;script&gt;
        * $(function(){
        * // Create the autocomplete
        * $("#autocomplete").ejmAutocomplete({ dataSource:"window.datasrc", field:"name" });
        * var auto = $("#autocomplete").data("ejmAutocomplete");
        * auto.enable(); // Enables the autocomplete
        * });
        * &lt;/script&gt;
        * @example 
        * &lt;input id="autocomplete"/&gt;<br>
        * &lt;script&gt;
        * $(function(){
        * // Enable the autocomplete
        * $("#autocomplete").ejmAutocomplete({ dataSource:"window.datasrc", field:"name" });
        * $("#autocomplete").ejmAutocomplete("enable");
        * });
        * &lt;/script&gt;
        * @memberof ejmAutocomplete
        * @instance
        */
        enable: function () {
            this.element.removeClass("e-m-state-disabled");
        },
        /**
        * To disable AutoComplete 
        * @return jQuery
        * @example 
        * &lt;input id="autocomplete" /&gt;<br>
        * &lt;script&gt;
        * $(function(){
        * // Create the autocomplete
        * $("#autocomplete").ejmAutocomplete({ dataSource:"window.datasrc", field:"name" });
        * var auto = $("#autocomplete").data("ejmAutocomplete");
        * auto.disable(); // Disables the autocomplete
        * });
        * &lt;/script&gt;
        * @example 
        * &lt;input id="autocomplete" /&gt;<br>
        * &lt;script&gt;
        * $(function(){
        * // Disable autocomplete
        * $("#autocomplete").ejmAutocomplete({ dataSource:"window.datasrc", field:"name" });
        * $("#autocomplete").ejmAutocomplete("disable");
        * });
        * &lt;/script&gt;
        * @memberof ejmAutocomplete
        * @instance
        */
        disable: function () {
            this._accList.hide();
            this.element.addClass("e-m-state-disabled");
        },

        /**
        * To get the value of AutoComplete 
        * @return jQuery
        * @example 
        * &lt;input id="autocomplete" /&gt;<br>
        * &lt;script&gt;
        * $(function(){
        * // Create the autocomplete
        * $("#autocomplete").ejmAutocomplete({ dataSource:"window.datasrc", field:"name" });
        * var auto = $("#autocomplete").data("ejmAutocomplete");
        * auto.getValue(); // Get the value of autocomplete
        * });
        * &lt;/script&gt;
        * @example 
        * &lt;input id="autocomplete" /&gt;<br>
        * &lt;script&gt;
        * $(function(){
        * // Getvalue of  autocomplete
        * $("#autocomplete").ejmAutocomplete({ dataSource:"window.datasrc", field:"name" });
        * $("#autocomplete").ejmAutocomplete("getValue");
        * });
        * &lt;/script&gt;
        * @memberof ejmAutocomplete
        * @instance
        */
        getValue: function () {
            return this.element.val();
        },
        /**
        * To get the list of items selected in AutoComplete 
        * @return jQuery
        * @example 
        * &lt;input id="autocomplete" /&gt;<br>
        * &lt;script&gt;
        * $(function(){
        * // Create the autocomplete
        * $("#autocomplete").ejmAutocomplete({ dataSource:"window.datasrc", field:"name" });
        * var auto = $("#autocomplete").data("ejmAutocomplete");
        * auto.getSelectedItems(); // Get the value of autocomplete
        * });
        * &lt;/script&gt;
        * @example 
        * &lt;input id="autocomplete" /&gt;<br>
        * &lt;script&gt;
        * $(function(){
        * // GetSelectedItems of  autocomplete
        * $("#autocomplete").ejmAutocomplete({ dataSource:"window.datasrc", field:"name" });
        * $("#autocomplete").ejmAutocomplete("getSelectedItems");
        * });
        * &lt;/script&gt;
        * @memberof ejmAutocomplete
        * @instance
        */
        getSelectedItems: function () {
            return this._selectedItems;
        },
        /**
        * Clears the selected items in AutoComplete 
        * @return jQuery
        * @example 
        * &lt;input id="autocomplete" /&gt;<br>
        * &lt;script&gt;
        * $(function(){
        * // Create the autocomplete
        * $("#autocomplete").ejmAutocomplete({ dataSource:"window.datasrc", field:"name" });
        * var auto = $("#autocomplete").data("ejmAutocomplete");
        * auto.clearText(); // Get the value of autocomplete
        * });
        * &lt;/script&gt;
        * @example 
        * &lt;input id="autocomplete" /&gt;<br>
        * &lt;script&gt;
        * $(function(){
        * // Clears text of autocomplete
        * $("#autocomplete").ejmAutocomplete({ dataSource:"window.datasrc", field:"name" });
        * $("#autocomplete").ejmAutocomplete("clearText");
        * });
        * &lt;/script&gt;
        * @memberof ejmAutocomplete
        * @instance
        */
        clearText: function () {
            if (this.model.enabled) {
                this.element.val("");
                if (this._isFocused) this.element.blur();
                else this._onBlurHandler();
            }
        }

        /*---------------Public Methods End---------------*/
    });
    /**
    * Enum for filtertype
    * @enum {string}
    * @global
    */
    ej.mobile.Autocomplete.FilterType = {
        /**
        Enum for filter type startswith*/
        StartsWith: "startswith",
        /**
        Enum for filter type contains*/
        Contains: "contains"
    };

    /**
    * Enum for mode
    * @enum {string}
    * @global
    */
    ej.mobile.Autocomplete.Mode = {
        /**
        Enum for Search mode*/
        Search: "search",
        /**
        Enum for Default mode*/
        Default: "default"
    };
    /**
    * Enum for sortorder
    * @enum {string}
    * @global
    */
    ej.mobile.Autocomplete.SortOrder = {
        /**
        Enum for Ascending sort order*/
        Ascending: "ascending",
        /**
        Enum for Descending sort order*/
        Descending: "descending"
    };
})(jQuery, Syncfusion);