/**
* @fileOverview Plugin to style the Html Button elements
* @copyright Copyright Syncfusion Inc. 2001 - 2014. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/
(function ($, ej, undefined) {
    /**
    * @namespace ej
    * @class ejmButton
    * @requires jQuery
    * @requires ej.mobile.application
    * @requires ej.core
    * @requires ej.unobtrusive
    * @requires ej.mobile.core
    * @requires ej.data
    * @requires ej.touch   
    * @classdesc Custom Design for Html Button control.
    * @example 
    * &lt;input  id="button" type="button" /&gt;<br>
    * &lt;script&gt; 
    * // Create Button  
    * $("#button").ejmButton(); 
    * $("#button").ejmButton({text:"button"}); 
    * &lt;/script&gt;
    * @example 
    * &lt;input id="button"  type="button" data-role="ejmbutton"  data-ej-text="button"/&gt;<br>
    */
    ej.widget({ "ejmButton": "ej.mobile.Button", "ejmActionlink": "ej.mobile.Actionlink" },
        {
            _setFirst: true,
            //Root Css Class
            _rootCSS: "e-m-btn",
            // default model
            defaults: {
                /**     
                * Event triggers when touch start happens on the control.
                * @event
                * @name ejmButton#touchStart 	
                * @param {Object} argument Event parameters from Button.     
                * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
                * @param {object}  argument.model returns the button model.
                * @param {string}  argument.type returns the name of the event.
                * @param {boolean}  argument.status return the button state.
                * @example 
                * //Bind the touchStart event using Unobtrusive way.
                * &lt;input id="button"  type="button"  data-role="ejmbutton" data-ej-touchstart="touchstart" data-ej-text="button"/&gt;<br>
                * &lt;script&gt; 
                * // touchStart event for Button
                * function touchstart(args){ 
                * //handle the event
                * }
                * @example 
                * &lt;input  id="button" type="button" /&gt;<br>
                * &lt;script&gt;  
                * //touchStart event for button
                * $("#button").ejmButton({text:"button"});
                * $("#button").ejmButton({
                *    touchStart: function (args) {}
                * });       
                * &lt;/script&gt;
                * @memberof ejmButton
                * @instance
                */
                touchStart: null,
                /**     
                * Event triggers when touch end happens on the control.
                * @event
                * @name ejmButton#touchEnd 	
                * @param {Object} argument Event parameters from Button.     
                * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
                * @param {object}  argument.model returns the button model.
                * @param {string}  argument.type returns the name of the event.
                * @param {boolean}  argument.status return the button state.
                * @example 
                * //Bind the touchEnd event using Unobtrusive way.
                * &lt;input id="button" type="button" data-role="ejmbutton" data-ej-text="button" data-ej-touchEnd="touchEnd" /&gt;<br>
                * &lt;script&gt; 
                * // touchEnd event for Button
                * function touchEnd(args){ 
                * //handle the event
                * }
                * @example 
                * &lt;input  id="button" type="button" /&gt;<br>
                * &lt;script&gt; 
                * //touchEnd event for button
                * $("#button").ejmButton({text:"button"});
                * $("#button").ejmButton({
                * touchEnd: function (args) {}
                * });  
                * &lt;/script&gt;
                * @memberof ejmButton
                * @instance
                */
                touchEnd: null,
                /**		
                * Specifies whether to enable or disable the control.
                * @default true
                * @type {boolean}
                * @example 
                * //Set the enabled property in Unobtrusive way.
                * &lt;input id="button"  type="button" data-role="ejmbutton" data-ej-text="button" data-ej-enabled=false /&gt;<br>
                * @example 
                * // Set enabled property on initialization. 
                * //To set enabled API value 
                * &lt;input  id="button" type="button" /&gt;<br>
                * &lt;script&gt; 
                * $("#button").ejmButton(); 
                * $("#button").ejmButton({text:"button"});
                * $("#button").ejmButton({ enabled: false });	
                * &lt;/script&gt;
                * @example 
                * //Get or set the enabled, after initialization:<br>
                * // Gets the enabled API value.		
                *  $("#button").ejmButton("option", "enabled");	
                * // Sets the enabled API
                * $("#button").ejmButton("option", "enabled", false);            
                * @memberof ejmButton
                * @instance
                */
                enabled: true,
                /**		
                * Specifies the rendering mode of the control.See {@link RenderMode}
                * @default auto
                * @type {enum}
                * @example 
                * //Set the renderMode property in Unobtrusive way.
                * &lt;input id="button" type="button" data-role="ejmbutton" data-ej-text="button" data-ej-rendermode="auto" /&gt;<br>
                * @example 
                * // Set rendermode property on initialization. 
                * //To set renderMode API value 
                * &lt;input  id="button" type="button" /&gt;<br>
                * &lt;script&gt; 
                * $("#button").ejmButton(); 
                * $("#button").ejmButton({text:"button"});
                * $("#button").ejmButton({ renderMode: ej.mobile.RenderMode.Auto });	
                * &lt;/script&gt;
                * @example 
                * //Get or set the Button rendermode, after initialization:<br>
                * // Gets the renderMode API value.		
                *  $("#button").ejmButton("option", "renderMode");			
                * // Sets the renderMode API
                * $("#button").ejmButton("option", "renderMode", ej.mobile.RenderMode.Auto);            
                * @memberof ejmButton
                * @instance
                */
                renderMode: "auto",
                /**		
                * Specifies the text.
                * @default ""
                * @type {string}
                * @example 
                * //Set the text property in Unobtrusive way.
                * &lt;input id="button" type="button" data-role="ejmbutton" data-ej-text="button"  /&gt;<br>
                * @example 
                * // Set text property on initialization. 
                * //To set text API value 
                * &lt;input  id="button" type="button" /&gt;<br>
                * &lt;script&gt; 
                * $("#button").ejmButton(); 
                * $("#button").ejmButton({ text: "button" });
                * &lt;/script&gt;
                * @example 
                * //Get or set the text, after initialization:<br>
                * // Gets the text API value.		
                *  $("#button").ejmButton("option", "text");			
                * // Sets the text API
                * $("#button").ejmButton("option", "text", "button");            
                * @memberof ejmButton
                * @instance
                */
                text: "button",                
                /**		
                * Specifies the theme. See {@link Theme}
                * @default auto
                * @type {enum}
                * @example 
                * //Set the theme property in Unobtrusive way.
                * &lt;input id="button" type="button" data-role="ejmbutton" data-ej-text="button" data-ej-theme="auto" /&gt;<br>
                * @example 
                * // Set theme on initialization. 
                * //To set theme API value
                * &lt;input  id="button" type="button" /&gt;<br>
                * &lt;script&gt; 
                * $("#button").ejmButton();
                * $("#button").ejmButton({text:"button"});
                * $("#button").ejmButton({ theme: ej.mobile.Theme.Auto });	
                * &lt;/script&gt;
                * @example 
                * //Get or set the theme, after initialization:<br>
                * // Gets the theme API value.		
                *  $("#button").ejmButton("option", "theme");			
                * // Sets the theme API
                * $("#button").ejmButton("option", "theme", "button");            
                * @memberof ejmButton
                * @instance
                */
                theme: "auto",
                /**		
                * Specifies the css class of image.
                * @default null
                * @type {string}
                * @example 
                * //Set the imageClass property in Unobtrusive way.
                * &lt;input id="button" type="button" data-role="ejmbutton" data-ej-contenttype="image" data-ej-imageClass="imageclass" /&gt;<br>
                * @example 
                * // Set imageClass property on initialization. 
                * //To set imageClass API value 
                * &lt;input  id="button" type="button" /&gt;<br>
                * &lt;script&gt; 
                * $("#button").ejmButton();
                * $("#button").ejmButton({ contentType:"image" });
                * $("#button").ejmButton({ imageClass: "imageclass" });
                * &lt;/script&gt;
                * @example 
                * //Get or set the imageClass, after initialization:<br>
                * // Gets the imageClass API value.		
                *  $("#button").ejmButton("option", "imageClass");			
                * // Sets the imageClass API
                * $("#button").ejmButton("option", "imageClass", "imageclass");            
                * @memberof ejmButton
                * @instance
                */
                imageClass: null,
                /**		
                * Specifies the position of image. See {@link ImagePosition}
                * @default ej.mobile.Button.ImagePosition.Left 
                * @type {enum}
                * @example 
                * //Set the imagePosition property in Unobtrusive way.
                * &lt;input id="button" type="button"  data-role="ejmbutton" data-ej-contenttype="both" data-ej-imageclass="imageclass" data-ej-text="button" data-ej-imagePosition="right" /&gt;<br>
                * @example 
                * // Set imagePosition property on initialization. 
                * //To set imagePosition API value 
                * &lt;input  id="button" type="button" /&gt;<br>
                * &lt;script&gt; 
                * $("#button").ejmButton();
                * $("#button").ejmButton({ text:"submit" });
                * $("#button").ejmButton({ contentType:"both" });
                * $("#button").ejmButton({ imageClass: "imageclass" });	
                * &lt;/script&gt;
                * @example 
                * //Get or set the imagePosition, after initialization:<br>
                * // Gets the imagePosition API value.		
                *  $("#button").ejmButton("option", "imagePosition");			
                * // Sets the imagePosition API
                * $("#button").ejmButton("option", "imagePosition", ej.mobile.Button.ImagePosition.Right);            
                * @memberof ejmButton
                * @instance
                */
                imagePosition: "left",
                /**		
                * Specifies the type of the content. See {@link ContentType}
                * @default ej.mobile.Button.ContentType.Text
                * @type {enum}
                * @example 
                * //Set the contentType property in Unobtrusive way.
                * &lt;input id="button" type="button" data-role="ejmbutton" data-ej-text="button" data-ej-contentType="text" /&gt;<br>
                * @example 
                * // Set contentType property on initialization. 
                * //To set contentType API value 
                * &lt;input  id="button" type="button" /&gt;<br>
                * &lt;script&gt; 
                * $("#button").ejmButton();
                * $("#button").ejmButton({text:"button"});
                * $("#button").ejmButton({ contentType: "text" });
                * &lt;/script&gt;
                * @example 
                * //Get or set the contentType, after initialization:<br>
                * // Gets the contentType API value.		
                *  $("#button").ejmButton("option", "contentType");			
                * // Sets the contentType API
                * $("#button").ejmButton("option", "contentType", ej.mobile.Button.ContentType.Text);            
                * @memberof ejmButton
                * @instance
                */
                contentType: "text",
                /**		
                * Specifies to maintain the current model value to browser cookies for state maintenance. While refresh the page, the model value will get apply to the control from browser cookies.
                * @default false
                * @type {boolean}
                * @example 
                * //Set the enablePersistence property in Unobtrusive way.
                * &lt;input id="button" type="button" data-role="ejmbutton" data-ej-text="button" data-ej-enablepersistence="true" /&gt;<br>
                * @example 
                * // Set enablePersistence property on initialization. 
                * //To set enablePersistence API value 
                * &lt;input type="button" id="button" /&gt;<br>
                * &lt;script&gt; 
                * $("#button").ejmButton();
                * $("#button").ejmButton({text:"button"});
                * $("#button").ejmButton({ enablePersistence: true });
                * &lt;/script&gt;
                * @example 
                * //Get or set the enablePersistence, after initialization:<br>
                * // Gets the enablePersistence API value.		
                *  $("#button").ejmButton("option", "enablePersistence");			
                * // Sets the enablePersistence API
                * $("#button").ejmButton("option", "enablePersistence", true);            
                * @memberof ejmButton
                * @instance
                */
                enablePersistence: false,
                /**     
                * Section for ios7 mode specific functionalities.                      
                * @memberof ejmButton
                * @instance
                */
                ios7: {
                    /**		
                    * Specifies the style of the control in ios7 mode. 
                    * @default ej.mobile.Button.IOS7.Style.Normal. 
                    * @type {enum}
                    * @alias ejmButton#ios7->style
                    * @example 
                    * // Set the ios7 mode style property in Unobtrusive way.
                    * &lt;input id="button" type="button"  data-role="ejmbutton" data-ej-text="button" data-ej-rendermode="ios7" data-ej-ios7-style="normal"  /&gt;<br>
                    * @example 
                    * // To set ios7 mode style property API value 
                    * &lt;input  id="button" type="button" /&gt;<br>
                    * &lt;script&gt; 
                    * $("#button").ejmButton();
                    * $("#button").ejmButton({text:"button"});
                    * $("#button").ejmButton({ renderMode: "ios7" });
                    * $("#button").ejmButton({ "model.ios7.style": ej.mobile.Button.IOS7.Style.Normal});
                    * &lt;/script&gt;
                    * @example 
                    * // Get or set the ios7 mode style API, after initialization:
                    * // Gets the ios7 mode style value  
                    * $("#button").ejmButton("option", "model.ios7.style");			
                    * // Sets the ios7 mode style value 
                    *$("#button").ejmButton("option", "model.ios7.style", ej.mobile.Button.IOS7.Style.Normal); 
                    * @memberof ejmButton
                    * @instance
                    */
                    "style": "normal",
                    /**		
                    * Specifies the color of the control in ios7 mode.
                    * @default ej.mobile.Button.IOS7.Color.Blue. 
                    * @type {enum}
                    * @alias ejmButton#ios7->color
                    * @example 
                    * // Set the ios7 mode buttonColor property in Unobtrusive way.
                    * &lt;a id="button"type="button" data-role="ejmbutton" data-ej-text="button" data-ej-rendermode="ios7" data-ej-ios7-color="blue" &gt; &lt;/a&gt;<br>
                    * @example 
                    * // To set ios7 mode buttonColor property API value 
                    * &lt;input  id="button" type="button" /&gt;<br>
                    * &lt;script&gt; 
                    * $("#button").ejmButton(); 
                    * $("#button").ejmButton({text:"button"});
                    * $("#button").ejmButton({ renderMode: "ios7" });
                    * $("#button").ejmButton({ "model.ios7.color": ej.mobile.Button.IOS7.Color.Blue });		 
                    * &lt;/script&gt;
                    * @example 
                    * // Get or set the ios7 mode buttonColor API, after initialization:
                    * // Gets the ios7 mode buttonColor value  
                    * $("#button").ejmButton("option", "model.ios7.color");			
                    * // Sets the ios7 mode buttonColor value 
                    *$("#button").ejmButton("option", "model.ios7.color", ej.mobile.Button.IOS7.Color.Blue); 
                    * @memberof ejmButton
                    * @instance
                    */
                    "color": ""
                },
                /**     
                * Section for android mode specific functionalities.            
                * @memberof ejmButton
                * @instance
                */
                android: {
                    /**		
                    * Specifies the style of the control in android mode.
                    * @default ej.mobile.Button.Android.Style.Normal. 
                    * @type {enum}
                    * @alias ejmButton#android->style
                    * @example 
                    * // Set the android mode style property in Unobtrusive way.<br>
                    * &lt;input id="button" type="button"  data-role="ejmbutton" data-ej-rendermode="android" data-ej-android-style="normal" data-ej-text="button"  /&gt;<br>
                    * @example 
                    * // To set android mode style property API value 
                    * &lt;input  id="button" type="button" /&gt;<br>
                    * &lt;script&gt; 
                    * $("#button").ejmButton(); 
                    * $("#button").ejmButton({text:"button"});
                    * $("#button").ejmButton({ renderMode: "android" });
                    * $("#button").ejmButton({ "model.android.style":ej.mobile.Button.Android.Style.Normal });		 
                    * &lt;/script&gt;
                    * @example 
                    * // Get or set the android mode style API, after initialization:
                    * // Gets the android mode style value  
                    * $("#button").ejmButton("option", "model.android.style");			
                    * // Sets the android mode style value 
                    *$("#button").ejmButton("option", "model.android.style", ej.mobile.Button.Android.Style.Normal); 
                    * @memberof ejmButton
                    * @instance
                    */
                    "style": "normal"
                },
                /**     
                * Section for windows mode specific functionalities.                      
                * @memberof ejmButton
                * @instance
                */
                windows: {
                    /**		
                    * Specifies the style of the control in windows mode.
                    * @default ej.mobile.Button.Windows.Style.Normal. 
                    * @type {enum}
                    * @alias ejmButton#windows->style
                    * @example 
                    * // Set the windows mode style property in Unobtrusive way.
                    * &lt;input id="button" type="button" data-role="ejmbutton" data-ej-text="button" data-ej-rendermode="windows" data-ej-windows-style="normal" /&gt;<br>
                    * @example 
                    * // To set windows mode style property API value 
                    * &lt;input  id="button" type="button" /&gt;<br>
                    * &lt;script&gt; 
                    * $("#button").ejmButton();
                    * $("#button").ejmButton({text:"button"});
                    * $("#button").ejmButton({ renderMode: "windows" });
                    * $("#button").ejmButton({ "model.windows.style": ej.mobile.Button.Windows.Style.Normal });		 
                    * &lt;/script&gt;
                    * @example 
                    * // Get or set the windows mode style API, after initialization:
                    * // Gets the windows mode style value  
                    * $("#button").ejmButton("option", "model.windows.style");			
                    * // Sets the windows mode style value 
                    *$("#button").ejmButton("option", "model.windows.style", ej.mobile.Button.Windows.Style.Normal); 
                    * @memberof ejmButton
                    * @instance
                    */
                    "style": "normal",
                    /**		
                    * Specifies whether to render control based on the windowsphone's current accent color and device theme.
                    * @default false
                    * @type {boolean}
                    * @alias ejmButton#windows->renderDefault
                    * @example 
                    * // Set the windows mode renderDefault property in Unobtrusive way.
                    * &lt;input id="button" type="button" data-role="ejmbutton" data-ej-text="button" data-ej-rendermode="windows" data-ej-windows-renderDefault=true /&gt;<br>
                    * @example 
                    * // To set windows mode renderDefault property API value 
                    * &lt;input  id="button" type="button" /&gt;<br>
                    * &lt;script&gt; 
                    * $("#button").ejmButton();
                    * $("#button").ejmButton({text:"button"});
                    * $("#button").ejmButton({ renderMode: "windows" });
                    * $("#button").ejmButton({ "windows.renderDefault": "true" });		 
                    * &lt;/script&gt;
                    * @example 
                    * // Get or set the windows mode renderDefault API, after initialization:
                    * // Gets the windows mode renderDefault value  
                    * $("#button").ejmButton("option", "windows.renderDefault");			
                    * // Sets the windows mode renderDefault value 
                    *$("#button").ejmButton("option", "windows.renderDefault", false); 
                    * @memberof ejmButton
                    * @instance
                    */
                    "renderDefault": false
                },
                /**     
                * Section for flat mode specific functionalities.                      
                * @memberof ejmButton
                * @instance
                */
                flat: {
                    /**		
                    * Specifies the style of the control in flat mode.
                    * @default ej.mobile.Button.Flat.Style.Normal. 
                    * @type {enum}
                    * @alias ejmButton#flat->style
                    * @example 
                    * // Set the flat mode style property in Unobtrusive way.
                    * &lt;input id="button" type="button" data-role="ejmbutton" data-ej-text="button" data-ej-rendermode="flat" data-ej-flat-style="normal" /&gt;<br>
                    * @example 
                    * // To set flat mode style property API value 
                    * &lt;input  id="button" type="button" /&gt;<br>
                    * &lt;script&gt; 
                    * $("#button").ejmButton(); 
                    * $("#button").ejmButton({text:"button"});
                    * $("#button").ejmButton({renderMode: "flat"});
                    * $("#button").ejmButton({ "model.flat.style": ej.mobile.Button.Flat.Style.Normal });		 
                    * &lt;/script&gt;
                    * @example 
                    * // Get or set the flat mode style API, after initialization:
                    * // Gets the flat mode style value  
                    * $("#button").ejmButton("option", "model.flat.style");			
                    * // Sets the flat mode style value 
                    *$("#button").ejmButton({"option", "model.flat.style", ej.mobile.Button.Flat.Style.Normal}); 
                    * @memberof ejmButton
                    * @instance
                    */
                    "style": "normal"
                }
            },
            //datatypes to the default model values 
            dataTypes: {
                enabled: "boolean",
                theme: "enum",
                renderMode: "enum",
                imagePoisition: "enum",
                contentType: "enum",
                enablePersistence: "boolean",
                android: { "style": "enum" },
                windows: { "style": "enum", "renderDefault": "boolean" },
                ios7: { "style": "enum", "color": "enum" },
                flat: { "style": "enum" }
            },
            /**
            * Create the Button widget
            * @private
            */
            _init: function () {
                this._renderControl();
            },
            /**
            * Render Section For Button control	
            * @private
            */
            _renderControl: function () {
                ej.setRenderMode(this);
                ej.setTheme(this);
                if (this.model.renderMode == "windows" && this.model.windows.renderDefault && ej.isMobile())
                    this.model.theme = "default";
                this._isLinkButton = this.element[0].nodeName == "A";
                this._wrapper = ej.buildTag("div.e-m-btnwrapper e-m-" + this.model.renderMode + " e-m-" + this.model.theme, "", {}, { style: this.model.style });
                if (this._isLinkButton)
                    this._wrapper.addClass("e-m-actionlink " + this.element.attr("class"));
                this.element.addClass("e-m-clearall e-m-btn-tag e-m-font-normal e-m-state-default e-m-user-select");
                this._setImagePosition();
                this.model.text = this.element.html() != "" ? this.element.html() : !ej.isNullOrUndefined(this.element.attr("value")) ? this.element.attr("value") : this.model.text;
                this._setText(this.model.text);
                if (this.model[this.model.renderMode].style == "back")
                    this.element.addClass("e-m-fontimage");
                if (this["_" + this.model.renderMode + "Properties"])
                    this["_" + this.model.renderMode + "Properties"]();
                this.element.wrap(this._wrapper);
                this._wrapper = this.element.parent();
                this._createDelegates();
                this._controlStatus(this.model.enabled);
                this._ios7ImageClass();
            },
            /**
            * Render Section For ios7 specific api's Button control	
            * @private
            */
            _ios7Properties: function () {
                if (this.model.ios7.style == "back") {
                    if (this._isLinkButton)
                        this._wrapper.addClass("e-m-btn-" + this.model.ios7.style);
                }
                else
                    this._wrapper.addClass("e-m-btn-" + this.model.ios7.style);
                if (this._isLinkButton && this.model.ios7.color != "")
                    this._wrapper.removeClass("e-m-" + this.model.theme).addClass("e-m-" + this.model.ios7.color);
            },
            /**
            * ios7 ImageClass style
            * @private
            */
            _ios7ImageClass:function(){
                if (this.model.renderMode == "ios7" && this.model.imageClass )
                    this._wrapper.removeClass("e-m-btn-normal");
            },
            /**
            * Render Section For android specific api's Button control	
            * @private
            */
            _androidProperties: function () {
                this._wrapper.addClass(" e-m-" + this.model.theme + " e-m-btn-" + this.model.android.style);
                this.element.removeClass("e-m-font-normal").addClass("e-m-font-" + this.model.android.style);
            },
            /**
            * Render Section For windows specific api's Button control	
            * @private
            */
            _windowsProperties: function () {
                this._wrapper.addClass("e-m-btn-" + this.model.windows.style);
                if (this.model.windows.style == "back") {
                    if (this._isLinkButton)
                        this.element.empty();
                    else
                        this.element.attr("value", "");
                }
            },
            /**
            * Render Section For flat specific api's Button control	
            * @private
            */
            _flatProperties: function () {
                this._wrapper.addClass(" e-m-btn-" + this.model.flat.style);
            },
            /**
            * To configure the delegates for Button control		
            * @private
            */
            _createDelegates: function () {
                this._touchStartHandler = $.proxy(this._touchStart, this);
                this._touchEndHandler = $.proxy(this._touchEnd, this);
                this._touchMoveHandler = $.proxy(this._touchMove, this);
            },
            /**
            * Wiring the events to Button control		
            * @private
            */
            _wireEvents: function (remove) {
                ej.listenEvents([this._wrapper, this._wrapper, this._wrapper], [ej.startEvent(), ej.endEvent(), ej.cancelEvent()], [this._touchStartHandler, this._touchEndHandler, this._touchEndHandler], remove);
            },
            /**
            * Section for handling the touchstart event
            * @private
            */
            _touchStart: function (evt) {
                this._start = true;
                this._move = false;
                if (ej.isWindows())
                    ej._touchStartPoints(evt, this);
                this._wrapper.addClass("e-m-state-active").removeClass("e-m-state-default");
                if (this.model.touchStart)
                    this._trigger("touchStart", data = { text: this.model.text });
                ej.listenTouchEvent(window, ej.moveEvent(), this._touchMoveHandler, false);
            },
            /**
            * Section for handling the touchmove event
            * @private
            */
            _touchMove: function (evt) {
             if (!ej.isWindows() || ( ej.isWindows() && ej._isTouchMoved(evt, this))) 
                this._move = true;
            },
            /**
            * Section for handling the touchend event
            * @private
            */
            _touchEnd: function (evt) {
                ej.listenTouchEvent(window, ej.moveEvent(), this._touchMoveHandler, true);
                this._wrapper.addClass("e-m-state-default").removeClass("e-m-state-active");
                if (!this._start || this._move) {
                    this._start = false;
                    this._move = false;
                    return;
                }
                if (this.model[this.model.renderMode].style == "back" && !this.model.touchEnd)
                    history.back();
                else if (this.model.touchEnd) // triggers the user given function for the touchend function
                    this._trigger("touchEnd", data = { text: this.model.text });
            },
            /**
            * To configure the control status of the Button		
            * @private
            */
            _controlStatus: function (enabled) {
                var tempclass = enabled ? "removeClass" : "addClass";
                this.element[tempclass]("e-m-state-disabled");
                this._wrapper[tempclass]("e-m-state-disabled");
                this._wireEvents(!enabled);
            },
            /**
            * To configure the Image for the Button		
            * @private
            */
            _setImagePosition: function () {
                if (this.model.imageClass) {
                    this._ios7ImageClass();
                    this._wrapper.addClass(" e-m-btn-image");
                    if (this.model.contentType != "text")
                        this.element.addClass(this.model.imageClass);
                    if (this.model.contentType == "both")
                        this.element.removeClass("e-m-image-left e-m-image-right").addClass("e-m-image-" + this.model.imagePosition);
                    if (this.model.contentType == "image") {
                        this.model.text = "";
                        this._wrapper.addClass("e-m-btn-imageonly");
                        this.element.attr("value", "");
                    }
                }
            },
            /**
            * setModel section for Button control		
            * @private
            */
            _setModel: function (options) {
                for (var prop in options) {
                    setprop = "_set" + prop.charAt(0).toUpperCase() + prop.slice(1);
                    if (this[setprop])
                        this[setprop](options[prop])
                }
            },
            /**
            * To configure the renderMode of the Button		
            * @private
            */
            _setRenderMode: function (rendermode) {
                this.model.renderMode = rendermode;
                this._wrapper.removeClass("e-m-ios7 e-m-android e-m-windows e-m-flat e-m-corner-all").addClass("e-m-" + this.model.renderMode);
                this._wrapper.addClass("e-m-btn-" + this.model[this.model.renderMode].style);
            },
            /**
            * To configure the theme of the Button		
            * @private
            */
            _setTheme: function (theme) {
                this._wrapper.removeClass("e-m-dark e-m-light e-m-default").addClass("e-m-" + this.model.theme);
            }, /**
            * To configure the IOS7 Button style properties		
            * @private
            */
            _setIos7: function (param) {
                if (param["style"])
                    this._setButtonStyle(param["style"]);
                if (param["color"])
                    this._setColor(param["color"])

            },
            /**
            * To configure the Android Button style properties		
            * @private
            */
            _setAndroid: function (param) {
                this._setButtonStyle(param["style"]);
            },
            /**
            * To configure the Flat Button style properties		
            * @private
            */
            _setFlat: function (param) {
                this._setButtonStyle(param["style"]);
            },
            /**
            * To configure the Windows Button style properties		
            * @private
            */
            _setWindows: function (param) {
                this._setButtonStyle(param["style"]);
            },
            /**
            * To configure the style for Button
            * @private
            */
            _setButtonStyle: function (style) {
                this.model[this.model.renderMode].style = style;
                this._wrapper.removeClass("e-m-btn-normal e-m-btn-back e-m-btn-header e-m-btn-dialog").addClass("e-m-btn-" + this.model[this.model.renderMode].style);
                this._setText(this.model.text);
                if (this.model[this.model.renderMode].style == "back")
                    this.element.addClass("e-m-fontimage");
            },
            /**
            * To configure the buttonColor for Button
            * @private
            */
            _setColor: function (color) {
                if (this.model.ios7.style == "normal") {
                    this.model[this.model.renderMode].color = color;
                    this._wrapper.removeClass("e-m-red e-m-black e-m-green e-m-blue e-m-gray e-m-" + this.model.theme).addClass("e-m-" + this.model[this.model.renderMode].color);
                }
            },
            /**
            * To configure the enabled state of the Button		
            * @private
            */
            _setEnabled: function (enabled) {
                this._controlStatus(this.model.enabled);
            },
            /**
            * To configure the text for Button control		
            * @private
            */
            _setText: function (text) {
                this.element[0].nodeName == "INPUT" ? this.element.attr("value", this.model.text) : (this.model.renderMode == "windows" && this.model.windows.style == "back" ? this.element.empty() : this.element.html(this.model.text));
            },
            /**
            * To configure the contenttype for Button control		
            * @private
            */
            _setContentType: function (param) {
                this._setImagePosition();
            },

            /**
            * To configure the imageclass for Button control		
            * @private
            */
            _setImageClass: function (param) {
                this._setImagePosition();
            },

            /**
            * Clear Element section for Button control		
            * @private
            */
            _clearElement: function () {
                this.element.insertAfter(this._wrapper);
                this._wrapper.remove();
                this.element.removeAttr("class");
                this.element.addClass("e-m-btn");
            },
            /**
            * destroy the Button widget
            * all events bound using this._on will be unbind automatically and bring the control to pre-init state.
            * @alias destroy
            * @return jQuery
            * @example 
            * &lt;inputid="button" type="Button" data-role="ejmbutton" data-ej-text="button"/&gt;<br>
            * &lt;script&gt; 
            * var btnObj = $("#button").data("ejmButton");
            * btnObj.destroy();
            * &lt;/script&gt;
            * @example 
            * &lt;inputid="button" type="button"  /&gt;<br>
            * &lt;script&gt;
            * // enabled the Button
            * $("#button").ejmButton({text:"button"});
            * $("#button").ejmButton("destroy");	
            * &lt;/script&gt;
            * @memberof ejmButton
            * @instance
            */
            _destroy: function () {
                this._wireEvents(true);
                this._clearElement();
            },

            /*---------------Public Methods---------------*/

            /**
            * To enable the button.
            * @return jQuery
            * @example 
            * &lt;input id="button" type="button" data-role="ejmbutton" data-ej-text="button"/&gt;<br>
            * &lt;script&gt;
            * $(document).ready(function () {
            * var btnObj = $("#button").data("ejmButton");
            * btnObj.enable(); // changes the button control state
            *});
            * &lt;/script&gt;
            * @example 
            * &lt;inputid="button" type="button"  /&gt;<br>
            * &lt;script&gt;
            * // change the button current state
            * $("#button").ejmButton({text:"button"});
            * $("#button").ejmButton(); 
            * $("#button").ejmButton("enable");	
            * &lt;/script&gt;
            *@memberof ejmButton
            * @instance
            */
            enable: function () {
                this.model.enabled = true;
                this._controlStatus(true);
            },
            /**
            * To disable the button.
            * @return jQuery
            * @example 
            * &lt;input id="button" type="button" data-role="ejmbutton" data-ej-text="button"/&gt;<br>
            * &lt;script&gt;
            * $(document).ready(function () {
            * var button = $("#button").data("ejmButton");
            * button.disable(); // Disables the toggle button
            * });
            * &lt;/script&gt;
            * @example 
            * &lt;inputid="button" type="button"  /&gt;<br>
            * &lt;script&gt;
            * // change the button current state
            * $("#button").ejmButton({text:"button"});
            * $("#button").ejmButton(); 
            * $("#button").ejmButton("disable");	
            * &lt;/script&gt;
            *@memberof ejmButton
            * @instance
            */
            disable: function () {
                this.model.enable = false;
                this._controlStatus(false);
            }

            /*---------------Public Methods End---------------*/
        });
    ej.mobile.Button.IOS7 = {};
    /**
    * Enum for IOS7style
    * @enum {string}
    * @global
    */
    ej.mobile.Button.IOS7.Style = {
        /**
        Enum for normal ios7 button style*/
        Normal: "normal",
        /**
        Enum for back ios7 button style*/
        Back: "back",
        /**
        Enum for header ios7 button style*/
        Header: "header",
        /**
        Enum for dialog ios7 button style*/
        Dialog: "dialog"
    };
    /**
    * Enum for IOS7Color
    * @enum {string}
    * @global
    */
    ej.mobile.Button.IOS7.Color = {
        /**
        Enum for gray ios7 button color*/
        Gray: "gray",
        /**
        Enum for black ios7 button color*/
        Black: "black",
        /**
        Enum for black ios7 buttonColor*/
        Blue: "blue",
        /**
        Enum for green ios7 button color*/
        Green: "green",
        /**
        Enum for red ios7 button color*/
        Red: "red"
    };
    ej.mobile.Button.Android = {};
    /**
    * Enum for AndroidStyle
    * @enum {string}
    * @global
    */
    ej.mobile.Button.Android.Style = {
        /**
        Enum for normal anroid button style */
        Normal: "normal",
        /**
        Enum for small android button style */
        Small: "small",
        /**
        Enum for dialog android button style */
        Dialog: "dialog"
    };
    ej.mobile.Button.Windows = {};
    /**
    * Enum for windowsstyle
    * @enum {string}
    * @global
    */
    ej.mobile.Button.Windows.Style = {
        /**
        Enum for normal windows button style */
        Normal: "normal",
        /**
        Enum for back windows button style */
        Back: "back"
    };
    ej.mobile.Button.Flat = {};
    /**
    * Enum for FlatStyle
    * @enum {string}
    * @global
    */
    ej.mobile.Button.Flat.Style = {
        /**
        Enum for normal flat button style */
        Normal: "normal",
        /**
        Enum for back flat button style */
        Back: "back",
        /**
        Enum for header flat button style */
        Header: "header"
    };
    /**
    * Enum for ImagePosition
    * @enum {string}
    * @global
    */
    ej.mobile.Button.ImagePosition = {
        /**
        Enum for image at left position */
        Left: "left",
        /**
        Enum for image at right position*/
        Right: "right"
    };
    /**
    * Enum for ContentType
    * @enum {string}
    * @global
    */
    ej.mobile.Button.ContentType = {
        /**
        Enum for text content type*/
        Text: "text",
        /**
        Enum for image content type*/
        Image: "image",
        /**
        Enum for displaying both text and image content type*/
        Both: "both"
    };
})(jQuery, Syncfusion);