﻿/**
* @fileOverview Plugin to style the Html CheckBox elements
* @copyright Copyright Syncfusion Inc. 2001 - 2014. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/

(function ($, ej, undefined) {
    // ejmCheckBox is the plugin name 
    // "ej.mobile.CheckBox" is "namespace.className" will hold functions and properties

    /**
    * @namespace ej
    * @class ejmCheckBox
    * @requires jQuery
    * @requires ej.mobile.application
    * @requires ej.core
    * @requires ej.unobtrusive
    * @requires ej.mobile.core
    * @requires ej.data
    * @requires ej.touch
    * @classdesc Custom Design for Html CheckBox control.
    * @example 
    * // Create checkbox control in unobtrusive way.
    * &lt;input type="checkbox" id="chkbox" data-role="ejmcheckbox" /&gt;<br>
    * @example 
    * // Render checkbox on initialization
    * &lt;input type="checkbox" id="chkbox" /&gt;<br>
    * &lt;script&gt;  
    * $("#chkbox").ejmCheckBox(); 
    * &lt;/script&gt;
    */

    ej.widget("ejmCheckBox", "ej.mobile.CheckBox", {
        _setFirst: true,
        _rootCSS: "e-m-chkbox",
        // default model
        defaults: {
            /**    
            * Event triggers when touch start happens on the control.
            * @event
            * @name ejmCheckBox#touchStart 	
            * @param {Object} argument Event parameters from CheckBox.    
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @param {boolean} argument.value returns the current element associated value.
            * @param {boolean} argument.isChecked returns the status of the control.
            * @example 
            * // Define the touchstart event in unobtrusive way.
            * &lt;input type="checkbox" id="chkbox" data-role="ejmcheckbox" data-ej-touchstart="touchstart" /&gt;<br>
            * &lt;script&gt; 
            * // touchStart event for checkbox 
            * function touchstart(args){ 
            * //handle the event 
            * }
            * &lt;/script&gt;
            * @example  
            * &lt;input type="checkbox" id="chkbox" data-role="ejmcheckbox" /&gt;<br>
            * // touchStart event for checkbox
            * * &lt;script&gt;
            * $("#chkbox").ejmCheckBox({
            *   touchStart: function (args) { 
            * //handle the event 
            * }
            * });           
            * &lt;/script&gt;
            * @memberof ejmCheckBox
            * @instance
            */
            touchStart: null,

            /**    
            * Event triggers when touch end happens on the control.
            * @event
            * @name ejmCheckBox#touchEnd 	
            * @param {Object} argument Event parameters from CheckBox.    
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @param {boolean} argument.value returns the current element associated value.
            * @param {boolean} argument.isChecked returns the status of the control.
            * @example 
            * // Define the touchend event in unobtrusive way.
            * &lt;input type="checkbox" id="chkbox" data-role="ejmcheckbox" data-ej-touchend="touchend" /&gt;<br>
            * &lt;script&gt; 
            * // touchEnd event for checkbox 
            * function touchend(args){ 
            * //handle the event
            * }
            * &lt;/script&gt;
            * @example  
            * &lt;input type="checkbox" id="chkbox" data-role="ejmcheckbox" /&gt;<br>
            * // touchEnd event for checkbox
            * * &lt;script&gt;
            * $("#chkbox").ejmCheckBox({
            *   touchEnd: function (args) { 
            * //handle the event 
            * }
            * });           
            * * &lt;/script&gt;
            * @memberof ejmCheckBox
            * @instance
            */
            touchEnd: null,

            /**		
            * Specifies the rendering mode of the control.See {@link RenderMode}
            * @default auto
            * @type {enum}
            * @example 
            * // Set the renderMode property in unobtrusive way.
            * &lt;input type="checkbox" id="chkbox" data-role="ejmcheckbox" data-ej-rendermode="auto" /&gt;<br>
            * @example
            * // Set checkbox rendermode on initialization. 
            * &lt;input type="checkbox" id="chkbox" /&gt;<br>
            * &lt;script&gt;  
            * // To set renderMode API value 
            * $("#chkbox").ejmCheckBox ({ renderMode: ej.mobile.RenderMode.Auto});			
            * &lt;/script&gt;
            * @example 
            * // Get or set the checkbox rendermode, after initialization:<br>
            * // Get the renderMode API value.		
            *  $("#chkbox").ejmCheckBox ("option", "renderMode");			
            * // Set the renderMode API
            * $("#chkbox").ejmCheckBox ("option", "renderMode", ej.mobile.RenderMode.Auto);            
            * @memberof ejmCheckBox
            * @instance
            */
            renderMode: "auto",

            /**		
            * Specifies whether to prevent default actions in the control.
            * @default false
            * @type {boolean}
            * @example 
            * // Set the preventDefault property in unobtrusive way.
            * &lt;input type="checkbox" id="chkbox" data-role="ejmcheckbox" data-ej-preventdefault="false" /&gt;<br>
            * @example 
            * // Set checkbox prevent default on initialization. 
            * &lt;input type="checkbox" id="chkbox" /&gt;<br>
            * &lt;script&gt;  
            * // To set preventDefault API value 
            * $("#chkbox").ejmCheckBox ({ preventDefault: false });			
            * &lt;/script&gt;
            * @example 
            * // Get or set the checkbox prevent default, after initialization:<br>
            * // Get the preventDefault API value.		
            *  $("#chkbox").ejmCheckBox ("option", "preventDefault");			
            * // Set the preventDefault API
            * $("#chkbox").ejmCheckBox ("option", "preventDefault", false);
            * @memberof ejmCheckBox
            * @instance
            */
            preventDefault: false,

            /**		
            * Specifies the theme.See {@link Theme}
            * @default auto
            * @type {enum}
            * @example 
            * //Set the theme property in unobtrusive way.
            * &lt;input type="checkbox" id="chkbox" data-role="ejmcheckbox" data-ej-theme="auto" /&gt;<br>
            * @example 
            * // Set checkbox theme on initialization. 
            * &lt;input type="checkbox" id="chkbox" /&gt;<br>
            * &lt;script&gt; 
            * // To set Theme API value 
            *   $("#chkbox").ejmCheckBox ({ theme: ej.mobile.Theme.Auto });			
            * &lt;/script&gt;
            * @example 
            * // Get or set the checkbox prevent default, after initialization:<br>
            * // Get the theme API value.		
            *   $("#chkbox").ejmCheckBox ("option", "theme");			
            * // Set the theme API
            *   $("#chkbox").ejmCheckBox ("option", "theme", ej.mobile.Theme.Auto);
            * @memberof ejmCheckBox
            * @instance
            */
            theme: "auto",

            /**		
            * Specifies whether to enable or disable the control.
            * @default true
            * @type {boolean}
            * @example 
            * //Set the enabled property in unobtrusive way.
            * &lt;input type="checkbox" id="chkbox" data-role="ejmcheckbox" data-ej-enabled=true /&gt;<br>
            * @example 
            * //Set enabled property checkbox on initialization. 
            * &lt;input type="checkbox" id="chkbox" /&gt;<br>
            * &lt;script&gt;  
            * // To set enabled API value 
            * 	$("#chkbox").ejmCheckBox ({ enabled: true });			
            * &lt;/script&gt;
            * @example 
            * // Get or set the checkbox state, after initialization:<br>
            * // Get the enabled API value.		
            *	$("#chkbox").ejmCheckBox ("option", "enabled");			
            * // Set the enabled API
            *	$("#chkbox").ejmCheckBox ("option", "enabled", true);
            * @memberof ejmCheckBox
            * @instance
            */
            enabled: true,

            /**		
            * Specifies whether to check the control.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the checked property in unobtrusive way.
            * &lt;input type="checkbox" id="chkbox" data-role="ejmcheckbox" data-ej-checked=false /&gt;<br>
            * @example 
            * // To set checked API value during initialization  
            * &lt;input type="checkbox" id="chkbox" /&gt;<br>
            * &lt;script&gt;  
            *  $("#chkbox").ejmCheckBox({ checked:  true });					
            * &lt;/script&gt;
            * @example 
            * // Get or set the check API, after initialization:<br>
            * //Get the checked value  
            *	$("#chkbox").ejmCheckBox("option", "checked");<br>			
            *	//Set the checked value 
            *	$("#chkbox").ejmCheckBox("option", "checked",  false );  
            * @memberof ejmCheckBox
            * @instance
            */
            checked: false,

            /**		
            * Specifies whether to render the control with tri state behaviour.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the enableTriState property in unobtrusive way.
            * &lt;input type="checkbox" id="chkbox" data-role="ejmcheckbox" data-ej-enabletristate="true" data-ej-checkstate="indeterminate" /&gt;<br>
            * @example 
            * //Set the enableTriState property on initialization.
            * &lt;input type="checkbox" id="chkbox" /&gt;<br>
            * &lt;script&gt;  
            * // To set enableTriState  API value 
            *   $("#chkbox").ejmCheckBox({ enableTriState : true, checkState:"indeterminate" });		
            * &lt;/script&gt;
            * @example 
            * // Get or set the enableTriState  API, after initialization
            * //Get the  enableTriState  value 
            *   $("#chkbox").ejmCheckBox("option", "enableTriState");	
            * // Set the  enableTriState  value 
            *   $("#chkbox").ejmCheckBox("option", "enableTriState", false  ); 
            * @memberof ejmCheckBox
            * @instance
            */
            enableTriState: false,

            /**		
            * Specifies the check CheckState of the control. See {@link CheckState}
            * @default ej.mobile.CheckBox.CheckState.Uncheck
            * @type {enum}
            * @example 
            * //Set the Checkstate property in unobtrusive way.
            * &lt;input type="checkbox" id="chkbox" data-role="ejmcheckbox" data-ej-enabletristate=true data-ej-checkstate="indeterminate" /&gt;<br>
            * @example 
            * //Set the Checkstate property on initialization.
            * &lt;input type="checkbox" id="chkbox" /&gt;<br>
            * &lt;script&gt;  
            * // To set Checkstate API value 
            *   $("#chkbox").ejmCheckBox({ enableTriState : true,checkState: ej.mobile.CheckBox.CheckState.Indeterminate });		
            * &lt;/script&gt;
            * @example 
            * // Get or set the CheckState  API, after initialization
            * //Get the CheckState  value 
            *   $("#chkbox").ejmCheckBox("option", "checkState");	
            * // Set the CheckState  value 
            *   $("#chkbox").ejmCheckBox("option", "checkState", ej.mobile.CheckBox.CheckState.Indeterminate  ); 
            * @memberof ejmCheckBox
            * @instance
            */
            checkState: "uncheck",

            /**		
            * Specifies the text.
            * @default ""
            * @type {string}
            * @example 
            * // Set the text property in unobtrusive way.
            * &lt;input type="checkbox" id="chkbox" data-role="ejmcheckbox" data-ej-text="Checkbox" /&gt;<br>
            * @example 
            * // To set text API value 
            * &lt;input type="checkbox" id="chkbox" /&gt;<br>
            * &lt;script&gt;  
            *   $("#chkbox").ejmCheckBox({ text: "Hello World"});		 
            * &lt;/script&gt;
            * @example 
            * // Get or set the text API, after initialization:
            * // Get the text value  
            *   $("#chkbox").ejmCheckBox("option", "text");			
            * // Set the text value 
            *   $("#chkbox").ejmCheckBox("option", "text", "Hello World" ); 
            * @memberof ejmCheckBox
            * @instance
            */
            text: "",

            /**
            * Specifies to maintain the current model value to browser cookies for state maintenance. While refresh the page, the model value will get apply to the control from browser cookies.
            * @default false
            * @type {boolean}
            * @example 
            * // Set the enablePersistence property in unobtrusive way.
            * &lt;input type="checkbox" id="chkbox" data-role="ejmcheckbox" data-ej-enablepersistence=true /&gt;<br>
            * @example 
            * // To set enablePersistence API value 
            * &lt;input type="checkbox" id="chkbox" /&gt;<br>
            * &lt;script&gt;  
            *   $("#chkbox").ejmCheckBox({ enablePersistence: true});		 
            * &lt;/script&gt;
            * @example 
            * // Get or set the enablePersistence API, after initialization:
            * // Get the enablePersistence value  
            *   $("#chkbox").ejmCheckBox("option", "enablePersistence");			
            * // Set the enablePersistence value 
            *   $("#chkbox").ejmCheckBox("option", "enablePersistence", true ); 
            * @memberof ejmCheckBox
            * @instance
            */
            enablePersistence: false,
            /**		   
            * Section for windows mode specific functionalities.                      
            * @memberof ejmCheckBox
            * @instance
            */
            windows: {

                /**		
                * Specifies whether to render control based on the windowsphone's current accent color and device theme.
                * @default false
                * @type {boolean}
                * @alias ejmCheckBox#windows->renderDefault
                * @example 
                * // Set the windows mode renderDefault property in unobtrusive way.
                * &lt;input type="checkbox" id="chkbox" data-role="ejmcheckbox" data-ej-windows-renderDefault=false /&gt;<br>
                * @example 
                * // To set windows mode renderDefault property API value 
                * &lt;input type="checkbox" id="chkbox" /&gt;<br>
                * &lt;script&gt;  
                * $("#chkbox").ejmCheckBox({ windows:{renderDefault: false}});		 
                * &lt;/script&gt;
                * @example 
                * // Get or set the windows mode renderDefault API, after initialization:
                * // Get the windows mode renderDefault value  
                * $("#chkbox").ejmCheckBox("option", "windows.renderDefault");			
                * // Set the windows mode renderDefault value 
                *$("#chkbox").ejmCheckBox("option", "windows.renderDefault", false); 
                * @memberof ejmCheckBox
                * @instance
                */
                "renderDefault": false
            }
        },

        dataTypes: {
            renderMode: "enum",
            theme: "enum",
            enabled: "boolean",
            checked: "boolean",
            checkState: "enum",
            enableTriState: "boolean",
            enablePersistence: "boolean"
        },

        /**
        * Create the CheckBox widget
        * @private
        */

        // constructor function
        _init: function () {
            this._renderControl();
            this._wireEvents(false);
        },

        /**
        * Render Section For checkbox control	
        * @private
        */
        //To render the checkbox control
        _renderControl: function () {
            ej.setRenderMode(this);
            ej.setTheme(this);
            if (this.model.renderMode == "windows" && this.model.windows.renderDefault && ej.isMobile())
                this.model.theme = "default";
            this.isChkboxChecked = (this.model.checked || (this.model.enableTriState && this.model.checkState == "check")) ? true : false;

            this._wrapper = ej.buildTag("div.e-m-chkbox e-m-" + this.model.renderMode + " e-m-" + this.model.theme, "", {}, {});
            $(this.element).attr("style", "display:none");
            this.element.wrap(this._wrapper);
            this._wrapper = this.element.parent();
            var div = ej.buildTag("div.e-m-rootel");
            this.innerDiv = ej.buildTag("div.e-m-chk-innerel e-m-inact e-m-fontimage", "", "", {}, {});
            if (this.isChkboxChecked) {
                this.element.prop("checked", true);
                this.innerDiv.removeClass("e-m-inact").addClass("e-m-active");
            }
            div.append(this.innerDiv);
            this._wrapper.append(div);
            this._setEnabled(this.model.enabled);
            if (this.model.checkState == "indeterminate" && this.model.enableTriState == true)
                this._setAllowIndeterminate(this.model.enableTriState);
            this._setTextWrapper(this.model.text);
        },

        /**
        * Delegate for checkbox control		
        * @private
        */
        _createDelegates: function () {
            this._touchStartHandler = $.proxy(this._touchStart, this);
            this._touchStopHandler = $.proxy(this._touchEnd, this);
            this._activeHandler = $.proxy(this._active, this);
            this._touchMoveHandler = $.proxy(this._removeActive, this);
        },

        /**
        * Wiring the events to checkbox control		
        * @private
        */
        _wireEvents: function (remove) {
            this._createDelegates();
            ej.listenEvents([this._wrapper, this._wrapper, this._wrapper, this._wrapper, this._wrapper, this._wrapper], ["click", "click", ej.startEvent(), ej.endEvent(), ej.cancelEvent(), "mouseleave"], [this._touchStartHandler, this._touchStopHandler, this._activeHandler, this._touchMoveHandler, this._touchMoveHandler, this._touchMoveHandler], remove);
        },

        /**
        * To configure checkbox tri-state type		
        * @private
        */
        _setAllowIndeterminate: function (indeter) {
            if (indeter) {
                this.innerDiv.removeClass("e-m-inact e-m-active").addClass("e-chk-indeter");
                $(this.element).attr("indeterminate", true);
            }
            else {
                this._wrapper.find(".e-chk-indeter").removeClass("e-chk-indeter");
                this.element.removeAttr('indeterminate');
                $(this.element).attr("indeterminate", false);
                this.model.checkState == "check" ? this._checked() : this._unChecked();
            }
        },

        /**
        * To configure checkbox android mode glow effect		
        * @private
        */
        _addAndroidGlow: function () {
            if (this.model.renderMode == "android")
                this._wrapper.find(".e-m-rootel ").addClass("e-m-state-glow");
        },

        /**
        * Section For handling the Check event handler
        * @private
        */
        _checked: function () {
            this._wrapper.find(".e-m-chk-innerel").removeClass("e-m-inact e-chk-indeter").addClass("e-m-active");
            this.element.prop("checked", true);
        },

        /**
        * Section For handling the Uncheck event handler
        * @private
        */
        _unChecked: function () {
            this._wrapper.find(".e-m-chk-innerel").removeClass("e-chk-indeter e-m-active").addClass("e-m-inact");
            this.element.prop("checked", false);
        },

        /**
        * Section For handling the check and uncheck event handler
        * @private
        */
        _checkedStateHandler: function () {
            if (this._wrapper.find(".e-m-rootel").children().hasClass("e-m-inact")) {
                this._checked();
                this.model.checked = this.isChkboxChecked = true;
                if (this.model.checkState == "indeterminate")
                    this.model.enableTriState = true;
            }
            else if (this._wrapper.find(".e-m-rootel").children().hasClass("e-m-active")) {
                if (this.model.enableTriState) {
                    if (this.model.checkState == "indeterminate") {
                        this._setAllowIndeterminate(true);
                        this.isChkboxChecked = true;
                    }
                    else {
                        this._setAllowIndeterminate(false);
                        this._unChecked();
                    }
                } else {
                    this._unChecked();
                    this.isChkboxChecked = false;
                }
            }
            else if (this._wrapper.find(".e-m-rootel").children().hasClass("e-chk-indeter")) {
                this.model.checked = this.isChkboxChecked = false;
                this._setAllowIndeterminate(false);
                this.model.enableTriState = false;
            }
        },

        _triStateHandler: function () {
            if (this.model.enableTriState) {
                if (this.model.checkState == "indeterminate")
                    this._setAllowIndeterminate(true);
                else
                    this._setAllowIndeterminate(false);

            }
            else {
                if (this._wrapper.find(".e-m-rootel").children().hasClass("e-m-inact")) {
                    this._checked();
                    this.model.checked = this.isChkboxChecked = true;
                }
                else if (this._wrapper.find(".e-m-rootel").children().hasClass("e-m-active")) {
                    this._unChecked();
                    this.model.checked = this.isChkboxChecked = false;
                }
            }
        },

        /**
        * Section for handling the touchstart event
        * @private
        */
        _touchStart: function (evt) {
            if (!this.model.preventDefault) {
                var data = { value: this.element.val(), isChecked: this.model.checked };
                if (this.model.touchStart)
                    this._trigger("touchStart", data);
            }
        },

        /**
        * Section for handling the touchend event
        * @private
        */
        _touchEnd: function (evt) {
            if (!this.model.preventDefault) {
                this._checkedStateHandler();
                var data = { value: this.element.val(), isChecked: this.model.checked };
                if (this.model.touchEnd)
                    this._trigger("touchEnd", data);
            }
        },

        /**
        * To configure checkbox active state		
        * @private
        */
        _active: function () {
            if (this.model.renderMode == "windows")
                this._wrapper.find(".e-m-rootel").addClass("e-m-windowsaccent");
            if (this.model.renderMode == "android" && !this.model.preventDefault);
            this._addAndroidGlow();
        },

        /**
        * To remove checkbox active state		
        * @private
        */
        _removeActive: function () {
            if (this.model.renderMode == "windows")
                this._wrapper.find(".e-m-rootel").removeClass("e-m-windowsaccent");
            if (this.model.renderMode == "android")
                this._wrapper.find(".e-m-rootel").removeClass("e-m-state-glow");
        },

        /**
        * To configure checkbox textwrapper		
        * @private
        */
        _setTextWrapper: function (val) {
            if (val != "") {
                this.txtSpan = ej.buildTag("div.e-m-chktext", val);
                this._wrapper.append(this.txtSpan);
            }
        },

        /**
        * To configure checkbox text	
        * @private
        */
        _setText: function (val) {
            if (!this.txtSpan) {
                this._setTextWrapper(val);
            } else {
                this.txtSpan.html(val);
            }
        },

        /**
        * To configure the Enable status of the CheckBox		
        * @private
        */
        _setEnabled: function (val) {
            this.model.enabled = val;
            this._wrapper[val ? "removeClass" : "addClass"]("e-m-state-disabled");
        },

        /**
        * To configure the theme of the CheckBox		
        * @private
        */
        _setTheme: function (theme) {
            this.model.theme = theme;
            this._wrapper.removeClass("e-m-light e-m-dark").addClass("e-m-" + theme.toLowerCase());
        },

        /**
        * To configure the checked state of the CheckBox		
        * @private
        */
        _setChecked: function (val) {
            this._wrapper.find(".e-m-chk-innerel")[val ? "addClass" : "removeClass"]("e-m-active");
            this._wrapper.find(".e-m-chk-innerel")[val ? "removeClass" : "addClass"]("e-m-inact");
            this.element.prop("checked", val);
            this.model.checked = this.isChkboxChecked = val;
        },

        /**
        * To configure the rendermode of the CheckBox		
        * @private
        */
        _setRenderMode: function (renderMode) {
            ej.setRenderMode(this);
            this._wrapper.removeClass("e-m-ios7 e-m-android e-m-windows e-m-flat").addClass("e-m-" + this.model.renderMode);
        },
        _setState: function (state) {
            this.model.checkState = state;
            this._triStateHandler();
        },
        /**
        * To configure the properties at runtime using SetModel		
        * @private
        */
        _setModel: function (options) {
            for (var prop in options) {
                var setModel = "_set" + prop.charAt(0).toUpperCase() + prop.slice(1);
                if (this[setModel])
                    this[setModel](options[prop]);
            }
        },
        _refresh: function () {
            this._destroy();
            this.element.find("input").addClass("e-m-chkbox");
            this._renderControl();
        },
        _clearElement: function () {
            this.element.insertAfter(this._wrapper);
            this._wrapper.remove();
            this.element.removeAttr("class");
        },

        /**
        * To destroy the CheckBox widget	
        * @private
        */
        // all events bound using this._on will be unbind automatically
        _destroy: function () {
            this._wireEvents(true);
            this._clearElement();
        },

        /*---------------Public Methods---------------*/
        /**
        * To change the checked state.
        * @return jQuery
        * @example 
        * &lt;input type="checkbox" id="chkbox"/&gt;<br>
        * &lt;script&gt;
        * // Create checkbox
        * $("#chkbox").ejmCheckBox();
        * var chkObj = $("#chkbox").data("ejmCheckBox");
        * chkObj.isChecked(); // returns the checkbox current state
        * &lt;/script&gt;
        * @example 
        * &lt;input type="checkbox" id="chkbox" /&gt;<br>
        * &lt;script&gt;
        * // get the checkbox current state
        * $("#chkbox").ejmCheckBox();
        * $("#chkbox").ejmCheckBox("isChecked");	
        * &lt;/script&gt;
        * @memberof ejmCheckBox
        * @instance
        */
        isChecked: function () {
            if ((this.isChkboxChecked != null) && (this.isChkboxChecked != undefined))
                return this.isChkboxChecked;
        }
        /*---------------Public Methods End---------------*/
    });
    /**
    * Enum for CheckboxState
    * @enum {string}
    * @global
    */
    ej.mobile.CheckBox.CheckState = {
        /**
        Enum for Uncheck state checkbox*/
        Uncheck: "uncheck",
        /**
        Enum for Check state checkbox*/
        Check: "check",
        /**
        Enum for Indeterminate state checkbox*/
        Indeterminate: "indeterminate"
    }
})(jQuery, Syncfusion);