﻿/**
* @fileOverview Plugin to style the Html Datepicker elements
* @copyright Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/
(function ($, ej, undefined) {
    /**
    * @namespace ej
    * @class ejmDatePicker
    * @requires jQuery
    * @requires ej.mobile.application
    * @requires ej.core
    * @requires ej.unobtrusive
    * @requires ej.mobile.core
    * @requires ej.data
    * @requires ej.touch
    * @requires ej.mobile.menu
    * @requires ej.mobile.header
    * @requires ej.mobile.dialog
    * @requires ej.mobile.button
    * @requires ej.mobile.toolbar
    * @requires ej.mobile.scrollpanel
    * @requires ej.mobile.scrollbar
    * @classdesc Custom Design for Html DatePicker control.
    * @example 
    * &lt;input id="datepicker" data-role="none"/&gt;<br>
    * &lt;script&gt; 
    * // Create DatePicker  
    * $("#datepicker").ejmDatePicker(); 
    * &lt;/script&gt;
    */
    ej.widget("ejmDatePicker", "ej.mobile.DatePicker", {
        _setFirst: true,
        // default model
        _rootCSS: "e-m-datepicker",
        defaults: {
            /**		
            * Specifies the date format.
            * @default null
            * @type {string}
            * @example 
            * //Set the dateFormat property in Unobtrusive way.
            * &lt;input id="datepicker" data-role="ejmdatepicker" data-ej-dateformat="MMMM dd, yyyy" /&gt;<br>
            * @example 
            * // Set the dateFormat on initialization. 
            * //To set dateFormat API value 
            * &lt;input id="datepicker" data-role="none"/&gt;<br>          	
            * &lt;script&gt;
            * $(function(){
            * $("#datepicker").ejmDatePicker({ dateFormat: "MMMM dd, yyyy" });		
            * });
            * &lt;/script&gt; 	
            * @example 
            * //Get or set the dateFormat, after initialization:<br>
            * // Get the dateFormat API value.		
            *  $("#datepicker").ejmDatePicker("option", "dateFormat");			
            * // Set the dateFormat API
            * $("#datepicker").ejmDatePicker("option", "dateFormat", "MM/dd/yyyy");            
            * @memberof ejmDatePicker
            * @instance
            */
            dateFormat: null,
            /**		
            * Specifies the rendering mode of the control. See {@link RenderMode}
            * @default auto
            * @type {enum}
            * @example 
            * //Set the renderMode property in Unobtrusive way.
            * &lt;input  id="datepicker" type="date" data-role="ejmdatepicker" data-ej-rendermode="android" /&gt;<br>
            * @example 
            * // Set the renderMode on initialization. 
            * //To set renderMode API value 
            * &lt;input  id="datepicker" type="date"/&gt;<br>          	
            * &lt;script&gt;
            * $(function(){
            * $("#datepicker").ejmDatePicker({ renderMode: "android" });		
            * });
            * &lt;/script&gt; 				
            * @example 
            * //Get or set the renderMode, after initialization:<br>
            * // Get the renderMode API value.		
            *  $("#datepicker").ejmDatePicker("option", "renderMode");			
            * // Set the renderMode API
            * $("#datepicker").ejmDatePicker("option", "renderMode", "android" );            
            * @memberof ejmDatePicker
            * @instance
            */
            renderMode: "auto",
            /**		
            * Specifies the minimum selectable date.
            * @default "01/01/2000"
            * @type {string}
            * @example 
            * //Set the minDate property in Unobtrusive way.
            * &lt;input id="datepicker" data-role="ejmdatepicker" data-ej-mindate="01/01/2000" /&gt;<br>
            * @example 
            * // Set the minDate on initialization. 
            * //To set minDate API value 
            * &lt;input id="datepicker" data-role="none"/&gt;<br>          	
            * &lt;script&gt;
            * $(function(){
            * $("#datepicker").ejmDatePicker({ minDate: "01/01/2000" });		
            * });
            * &lt;/script&gt; 				
            * @example 
            * //Get or set the minDate, after initialization:<br>
            * // Get the minDate API value.		
            *  $("#datepicker").ejmDatePicker("option", "minDate");			
            * // Set the minDate API
            * $("#datepicker").ejmDatePicker("option", "minDate", "01/01/2000");            
            * @memberof ejmDatePicker
            * @instance
            */
            minDate: "01/01/2000",
            /**		
            * Specifies the maximum selectable date.
            * @default "12/31/2030"
            * @type {string}
            * @example 
            * //Set the maxDate property in Unobtrusive way.
            * &lt;input id="datepicker" data-role="ejmdatepicker" data-ej-maxdate="12/31/2030" /&gt;<br>
            * @example 
            * // Set the maxDtae on initialization. 
            * //To set maxDate API value 
            * &lt;input id="datepicker" data-role="none"/&gt;<br>          	
            * &lt;script&gt;
            * $(function(){
            * $("#datepicker").ejmDatePicker({ maxDate: "12/31/2030" });		
            * });
            * &lt;/script&gt; 				
            * @example 
            * //Get or set the maxDate, after initialization:<br>
            * // Get the maxDate API value.		
            *  $("#datepicker").ejmDatePicker("option", "maxDate");			
            * // Set the maxDate API
            * $("#datepicker").ejmDatePicker("option", "maxDate", "31/12/2030");            
            * @memberof ejmDatePicker
            * @instance
            */
            maxDate: "12/31/2030",
            /**		
            * Specifies the theme. See {@link Theme}
            * @default auto
            * @type {enum}
            * @example 
            * //Set the theme property in Unobtrusive way.
            * &lt;input  id="datepicker" type="date" data-role="ejmdatepicker" data-ej-theme="auto" /&gt;<br>
            * @example 
            * // Set the theme on initialization. 
            * //To set theme API value 
            * &lt;input  id="datepicker" type="date"/&gt;<br>          	
            * &lt;script&gt;
            * $(function(){
            * $("#datepicker").ejmDatePicker({ theme: "auto" });		
            * });
            * &lt;/script&gt; 				
            * @example 
            * //Get or set the theme, after initialization:<br>
            * // Get the theme API value.		
            *  $("#datepicker").ejmDatePicker("option", "theme");			
            * // Set the theme API
            * $("#datepicker").ejmDatePicker("option", "theme", "auto" );            
            * @memberof ejmDatePicker
            * @instance
            */
            theme: "auto",
            /**		
            * Specifies the localization culture to be used.
            * @default "en-US"
            * @type {string}
            * @example 
            * //Set the culture property in Unobtrusive way.
            * &lt;input id="datepicker" data-role="ejmdatepicker" data-ej-culture="en-US" /&gt;<br>
            * @example 
            * // Set the culture on initialization. 
            * //To set culture API value 
            * &lt;input id="datepicker" data-role="none"/&gt;<br>          	
            * &lt;script&gt;
            * $(function(){
            * $("#datepicker").ejmDatePicker({ culture: "en-US" });		
            * });
            * &lt;/script&gt; 			
            * @example 
            * //Get or set the culture, after initialization:<br>
            * // Get the culture API value.		
            *  $("#datepicker").ejmDatePicker("option", "culture");			
            * // Set the culture API
            * $("#datepicker").ejmDatePicker("option", "culture", "en-US");            
            * @memberof ejmDatePicker
            * @instance
            */
            culture: "en-US",
            /**		
            * Specifies the value.
            * @default new Date().toString()
            * @type {string}
            * @example 
            * //Set the value property in Unobtrusive way.
            * &lt;input id="datepicker" data-role="ejmdatepicker" data-ej-value="04/23/2010" /&gt;<br>
            * @example 
            * // Set the value on initialization. 
            * //To set value API value 
            * &lt;input id="datepicker" data-role="none"/&gt;<br>          	
            * &lt;script&gt;
            * $(function(){
            * $("#datepicker").ejmDatePicker({ value: "04/23/2010" });		
            * });
            * &lt;/script&gt; 			
            * @example 
            * //Get or set the value, after initialization:<br>
            * // Get the value API value.		
            *  $("#datepicker").ejmDatePicker("option", "value");			
            * // Set the value API
            * $("#datepicker").ejmDatePicker("option", "value", "04/23/2010");            
            * @memberof ejmDatePicker
            * @instance
            */
            value: new Date(),
            /**		
            * Specifies whether to enable or disbale the control.
            * @default true
            * @type {boolean}
            * @example 
            * //Set the enabled property in Unobtrusive way.
            * &lt;input id="datepicker" data-role="ejmdatepicker" data-ej-enabled=false /&gt;<br>
            * @example 
            * // Set the enabled on initialization. 
            * //To set enabled API value 
            * &lt;input id="datepicker" data-role="none"/&gt;<br>          	
            * &lt;script&gt;
            * $(function(){
            * $("#datepicker").ejmDatePicker({ enabled: false });		
            * });
            * &lt;/script&gt; 				
            * @example 
            * //Get or set the enabled, after initialization:<br>
            * // Get the enabled API value.		
            *  $("#datepicker").ejmDatePicker("option", "enabled");			
            * // Set the enabled API
            * $("#datepicker").ejmDatePicker("option", "enabled", false);            
            * @memberof ejmDatePicker
            * @instance
            */
            enabled: true,
            /**		
            * Specifies to maintain the current model value to browser cookies for state maintenance. While refresh the page, the model value will get apply to the control from browser cookies.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the enablePersistence property in Unobtrusive way.
            * &lt;input id="datepicker" data-role="ejmdatepicker" data-ej-enablepersistence=true /&gt;<br>
            * @example 
            * // Set the enablePersistence on initialization. 
            * //To set enablePersistence API value 
            * &lt;input id="datepicker" data-role="none"/&gt;<br>          	
            * &lt;script&gt;
            * $(function(){
            * $("#datepicker").ejmDatePicker({ enablePersistence: true });		
            * });
            * &lt;/script&gt; 				
            * @example 
            * //Get or set the enablePersistence, after initialization:<br>
            * // Get the enablePersistence API value.		
            *  $("#datepicker").ejmDatePicker("option", "enablePersistence");			
            * // Set the enablePersistence API
            * $("#datepicker").ejmDatePicker("option", "enablePersistence", true);            
            * @memberof ejmDatePicker
            * @instance
            */
            enablePersistence: false,
            /**     
            * Event triggers when date value is selected.
            * @event
            * @name ejmDatePicker#select 	
            * @param {Object} argument Event parameters from datepicker     
            * @param {boolean} argument.cancel if the event should be canceled; otherwise, false.
            * @param {object} argument.model returns the datepicker model
            * @param {string} argument.type returns the name of the event
            * @param {string} argument.value return the datepicker value
            * @example 
            * //Bind the select event using Unobtrusive way.
            * &lt;input id="datepicker" data-role="ejmdatepicker" data-ej-select="select" /&gt;<br>
            * &lt;script&gt;
            * function select(){}
            * &lt;/script&gt;
            * @example 
            * &lt;input id="datepicker" data-role="none"/&gt;<br>
            * &lt;script&gt;
            * //select event for DatePicker
            * $("#datepicker").ejmDatePicker({
            *    select: function (args) { * //handle the event 
            * }
            * }); 
            * &lt;/script&gt;			
            * @memberof ejmDatePicker
            * @instance
            */
            select: null,
            /**     
            * Event triggers when the control is loaded.
            * @event
            * @name ejmDatePicker#load 	
            * @param {Object} argument Event parameters from datepicker     
            * @param {boolean} argument.cancel if the event should be canceled; otherwise, false.
            * @param {object} argument.model returns the datepicker model
            * @param {string} argument.type returns the name of the event
            * @param {string} argument.value return the datepicker value
            * @example 
            * //Bind the load event using Unobtrusive way.
            * &lt;input id="datepicker" data-role="ejmdatepicker" data-ej-load="load" /&gt;<br>
            * &lt;script&gt;
            * function load(){}
            * &lt;/script&gt;
            * @example 
            * &lt;input id="datepicker" data-role="none"/&gt;<br>
            * &lt;script&gt;
            * //load event for DatePicker
            * $("#datepicker").ejmDatePicker({
            *    load: function (args) {* //handle the event 
            * }
            * }); 
            * &lt;/script&gt;			
            * @memberof ejmDatePicker
            * @instance
            */
            load: null,
            /**     
            * Event triggers when the input element is focused.
            * @event
            * @name ejmDatePicker#focusIn 	
            * @param {Object} argument Event parameters from datepicker     
            * @param {boolean} argument.cancel if the event should be canceled; otherwise, false.
            * @param {object} argument.model returns the datepicker model
            * @param {string} argument.type returns the name of the event
            * @param {string} argument.value return the datepicker value
            * @example 
            * //Bind the focusin event using Unobtrusive way.
            * &lt;input id="datepicker" data-role="ejmdatepicker" data-ej-focusin="focusin" /&gt;<br>
            * &lt;script&gt;
            * function focusin(){}
            * &lt;/script&gt;
            * @example 
            * &lt;input id="datepicker" data-role="none"/&gt;<br>
            * &lt;script&gt;
            * //focusIn event for DatePicker
            * $("#datepicker").ejmDatePicker({
            *    focusIn: function (args) { * //handle the event 
            * }
            * });
            * &lt;/script&gt;			
            * @memberof ejmDatePicker
            * @instance
            */
            focusIn: null,
            /**     
            * Event triggers when the input element is focusedout or blurred.
            * @event
            * @name ejmDatePicker#focusOut 	
            * @param {Object} argument Event parameters from datepicker     
            * @param {boolean} argument.cancel if the event should be canceled; otherwise, false.
            * @param {object} argument.model returns the datepicker model
            * @param {string} argument.type returns the name of the event
            * @param {string} argument.value return the datepicker value
            * @example 
            * //Bind the focusout event using Unobtrusive way.
            * &lt;input id="datepicker" data-role="ejmdatepicker" data-ej-focusout="focusout" /&gt;<br>
            * &lt;script&gt;
            * function focusout(){}
            * &lt;/script&gt;
            * @example 
            * &lt;input id="datepicker" data-role="none"/&gt;<br>
            * &lt;script&gt;
            * //focusOut event for DatePicker
            * $("#datepicker").ejmDatePicker({
            *    focusOut: function (args) {* //handle the event 
            * }
            * }); 
            * &lt;/script&gt;			
            * @memberof ejmDatePicker
            * @instance
            */
            focusOut: null,
            /**     
            * Event triggers when the control is opened for selection.
            * @event
            * @name ejmDatePicker#open 	
            * @param {Object} argument Event parameters from datepicker     
            * @param {boolean} argument.cancel if the event should be canceled; otherwise, false.
            * @param {object} argument.model returns the datepicker model
            * @param {string} argument.type returns the name of the event
            * @param {string} argument.value return the datepicker value
            * @example 
            * //Bind the open event using Unobtrusive way.
            * &lt;input id="datepicker" data-role="ejmdatepicker" data-ej-open="open" /&gt;<br>
            * &lt;script&gt;
            * function open(){}
            * &lt;/script&gt;
            * @example 
            * &lt;input id="datepicker" data-role="none"/&gt;<br>
            * &lt;script&gt;
            * //open event for DatePicker
            * $("#datepicker").ejmDatePicker({
            *    open: function (args) {* //handle the event 
            * }
            * });
            * &lt;/script&gt;			
            * @memberof ejmDatePicker
            * @instance
            */
            open: null,
            /**     
            * Event triggers when the control is closed after interaction.
            * @event
            * @name ejmDatePicker#close 	
            * @param {Object} argument Event parameters from datepicker     
            * @param {boolean} argument.cancel if the event should be canceled; otherwise, false.
            * @param {object} argument.model returns the datepicker model
            * @param {string} argument.type returns the name of the event
            * @param {string} argument.value return the datepicker value
            * @example 
            * //Bind the close event using Unobtrusive way.
            * &lt;input id="datepicker" data-role="ejmdatepicker" data-ej-close="close" /&gt;<br>
            * &lt;script&gt;
            * function close(){}
            * &lt;/script&gt;
            * @example 
            * &lt;input id="datepicker" data-role="none"/&gt;<br>
            * &lt;script&gt;
            * //close event for DatePicker
            * $("#datepicker").ejmDatePicker({
            *    close: function (args) {* //handle the event 
            * }
            * });
            * &lt;/script&gt;			
            * @memberof ejmDatePicker
            * @instance
            */
            close: null,
            /**     
            * Event triggers when the value is changed while interaction.
            * @event
            * @name ejmDatePicker#change 	
            * @param {Object} argument Event parameters from datepicker     
            * @param {boolean} argument.cancel if the event should be canceled; otherwise, false.
            * @param {object} argument.model returns the datepicker model
            * @param {string} argument.type returns the name of the event
            * @param {string} argument.value return the datepicker value
            * @example 
            * //Bind the change event using Unobtrusive way.
            * &lt;input id="datepicker" data-role="ejmdatepicker" data-ej-change="change" /&gt;<br>
            * &lt;script&gt;
            * function change(){}
            * &lt;/script&gt;
            * @example 
            * &lt;input id="datepicker" data-role="none"/&gt;<br>
            * &lt;script&gt;
            * //change event for DatePicker
            * $("#datepicker").ejmDatePicker({
            *    change: function (args) {* //handle the event 
            * }
            * });
            * &lt;/script&gt;			
            * @memberof ejmDatePicker
            * @instance
            */
            change: null,
            /**     
            * Section for ios7 rendermode specific functionalities.                      
            * @memberof ejmDatePicker
            * @instance
            */
            ios7: {
                /**		
                * Specifies whether to use ios7 native datepicker or not.
                * @default false
                * @type {boolean}
                * @alias ejmDatePicker#ios7->renderDefault
                * @example 
                * // Set the ios7 mode renderDefault property in Unobtrusive way.
                * &lt;input id="datepicker" data-role="ejmdatepicker" data-ej-rendermode="ios7" data-ej-ios7-renderdefault=true /&gt;<br>
                * @example 
                * // To set ios7 mode renderDefault property API value
                * &lt;input id="datepicker" data-role="none"/&gt;<br>          	
                * &lt;script&gt;
                * $(function(){
                * $("#datepicker").ejmDatePicker({ renderMode:"ios7", ios: {renderDefault: true }});		
                * });
                * &lt;/script&gt; 		 
                * @example
                * // Get or set the ios7 mode renderDefault API, after initialization:
                * // Get the ios7 mode renderDefault value  
                * $("#datepicker").ejmDatePicker("option", "ios7.renderDefault");			
                * // Set the ios7 mode renderDefault value 
                * $("#datepicker").ejmDatePicker("option", "ios7.renderDefault", true); 
                * @memberof ejmDatePicker
                * @instance
                */
                "renderDefault": false
            },
            /**     
            * Section for windows rendermode specific functionalities.                      
            * @memberof ejmDatePicker
            * @instance
            */
            windows: {
                /**		
                * Specifies whether to render the DatePicker based on the windowsphone's current theme or not.
                * @default false
                * @type {boolean}
                * @alias ejmDatePicker#windows->renderDefault
                * @example 
                * // Set the windows mode renderDefault property in Unobtrusive way.
                * &lt;input id="datepicker" data-role="ejmdatepicker" data-ej-rendermode="windows" data-ej-windows-renderdefault=true /&gt;<br>
                * @example 
                * // To set windows mode renderDefault property API value
                * &lt;input id="datepicker" data-role="none"/&gt;<br>          	
                * &lt;script&gt;
                * $(function(){
                * $("#datepicker").ejmDatePicker({ renderMode:"windows", windows: { renderDefault: true }});		
                * });
                * &lt;/script&gt; 			 
                * @example 
                * // Get or set the windows mode renderDefault API, after initialization:
                * // Get the windows mode renderDefault value  
                * $("#datepicker").ejmDatePicker("option", "windows.renderDefault");			
                * // Set the windows mode renderDefault value 
                *$("#datepicker").ejmDatePicker("option", "windows.renderDefault", true); 
                * @memberof ejmDatePicker
                * @instance
                */
                "renderDefault": false
            }
        },
        /**
        *datatypes to the default model values 
        */
        dataTypes: {
            renderMode: "enum",
            theme: "enum",
            enabled: "boolean",
            ios7: { "renderDefault": "boolean" },
            windows: { "renderDefault": "boolean" },
            enablePersistence: "boolean"
        },
        /**
        * Create the DatePicker widget
        * @private
        */
        _init: function () {
            this._createDelegates();
            this._renderControl();
            this._wireEvents();
        },
        /**
        * To configure the values for datepicker control rendering 
        * @private
        */
        _datepickerInitialize: function () {
            this._winrt = this.model.renderMode == "windows" && !ej.isMobile();
            if (this.model.renderMode == "windows" && this.model.windows.renderDefault && ej.isMobile())
                this.model.theme = "default";
            this._id = $(this.element).attr('name') ? $(this.element).attr('name') : $(this.element).attr('id');
            $(this.element).attr('id', $(this.element).attr('id') ? $(this.element).attr('id') : this._id);
            this._menuTargetId = $(this.element).attr('id');
            this._setCulture(this.model.culture);
            this.model.dateFormat = this.model.dateFormat == null ? Date.format : this.model.dateFormat;
            this.model.minDate = Globalize.format(new Date(this.model.minDate), this.model.dateFormat);
            this.model.maxDate = Globalize.format(new Date(this.model.maxDate), this.model.dateFormat);
            this.model.value = Globalize.format(new Date(this.model.value), this.model.dateFormat);
            this._currentDate = new Date(this.model.minDate) > new Date(this.model.value) ? this.model.minDate : new Date(this.model.maxDate) < new Date(this.model.value) ? this.model.maxDate : new Date(this.model.value) != new Date() ? this.model.value : new Date();
        },
        /**
        * To configure the localization culture value given for datepicker control 
        * @private
        */
        _setCulture: function (culture) {
            this.culture = Globalize.culture(culture);
            if (this.culture) {
                Date.dayNames = this.culture.calendar.days.names;
                Date.abbrDayNames = this.culture.calendar.days.namesAbbr;
                Date.monthNames = this.culture.calendar.months.names;
                Date.abbrMonthNames = this.culture.calendar.months.namesAbbr;
                Date.format = this.culture.calendar.patterns.d;
            }
        },
        /**
        * Render Section For DatePicker control	
        * @private
        */
        _renderControl: function () {
            ej.setRenderMode(this);
            ej.setTheme(this);
            this._datepickerInitialize();
            this._datepickerwrapper = ej.buildTag("div.e-m-datepickerwrapper e-m-" + this.model.renderMode + " e-m-" + this.model.theme + " e-m-user-select#" + this._id + "_Wrapper", "", {}, {});
            this.element.width("99%").attr({ "name": this._id }).wrap(this._datepickerwrapper);
            this._datepickerwrapper = this.element.parent();
            if (ej.isDevice() && this.model.renderMode == "ios7" && this.model.ios7.renderDefault) {
                this.element.attr({ "type": "date" });
            }
            else {
                this.element.attr({ "readonly": true });
                this._outerdiv = ej.buildTag("div.e-m-" + this.model.renderMode + " e-m-" + this.model.theme + " e-m-dp e-m-user-select #" + this._id + "_dp", "", {}, {});
                this._innerdiv = ej.buildTag("div.e-m-dpinner", "", {}, {});
                this._wrapdiv = ej.buildTag("div.e-m-dpwrap", "", {}, {});
                this._visibletexthtml = this._winrt ? "" : "<div class='col-fill'></div>";
                this._months = ej.buildTag("div.e-m-dp e-m-dpmonth e-m-left", "<div class='e-m-datewrapper'><div id=" + this._id + "_dpmonth><div class='e-m-dpouter'>" + this._visibletexthtml + "</div></div></div><div class='e-m-dp-overlay'></div></div>", {}, {});
                this._days = ej.buildTag("div.e-m-dp e-m-dpdate e-m-center", "<div class='e-m-datewrapper'><div id=" + this._id + "_dpdate><div class='e-m-dpouter'>" + this._visibletexthtml + "</div></div></div><div class='e-m-dp-overlay'></div></div>", {}, {});
                this._years = ej.buildTag("div.e-m-dp e-m-dpyear e-m-right", "<div class='e-m-datewrapper'><div id=" + this._id + "_dpyear><div class='e-m-dpouter'>" + this._visibletexthtml + "</div></div></div><div class='e-m-dp-overlay'></div></div>", {}, {});
                this["_" + this.model.renderMode + "Rendering"]();
                this._scrollInitialize();
                this._minDateInitialize();
                this._maxDateInitialize();
                this._setInitialDate();
            }
            if (this.model.load)
                this._trigger("load", this._argsValue());
            this._controlStatus(this.model.enabled);
            this._datepickerwrapper.width(this.element.outerWidth());
            this._initscroll = false;
            this._setcurrent = false;
        },
        /**
        * Render Section For scrollpanel for individual scoller column.
        * @private
        */
        _scrollPanel: function (e) {
            this["_" + e] = ej.buildTag("div#'" + this._id + "'dp'" + e + "'_scrollpanel", "", {}, {});
            this._outerdiv.find("#" + this._id + "_dp" + e).append(this["_" + e]);
            this["_" + e].ejmScrollPanel({
                "enableNativeScrolling": false, "enableTransition": false, "enableTransform": false, "showScrollbars": false, "target": this._id + "_dp" + e, "targetHeight": this._targetHeight, "renderMode": this.model.renderMode,
                "scrollEnd": $.proxy(this._onScrollStop, this), "enableBounce": false, "scrollStart": $.proxy(this._onScrollStart, this), "enableDisplacement": true, "displacementValue": this._displacement, "displacementTime": ej.isWindows() ? 800 : 350
            });
        },
        /**
        * Render Section For initialize the scrollpanel input values and scrollpanel rendering for the columns.
        * @private
        */
        _scrollInitialize: function () {
            this._displacement = this.model.renderMode == "ios7" ? 40 : (this.model.renderMode == "android" ? 45 : 94);
            this._targetHeight = this.model.renderMode == "ios7" ? 200 : (this.model.renderMode == "android" ? 135 : !this._winrt ? this._appHeight : 0);
            if (!this._winrt) {
                this._scrollPanel("date");
                this._scrollPanel("month");
                this._scrollPanel("year");
                if (this.model.renderMode == "windows" || this.model.renderMode == "flat") {
                    $(this._outerdiv).css("top", -this._appHeight + "px").addClass("flip");
                    $(this._toolbar).css("visibility", "hidden");
                }
                this._domElements();
            }
            this._initscroll = true;
        },
        _minDateInitialize: function () {
            if (!this._winrt) {
                this._minDate = new Date(this.model.minDate);
                var d = this._minDate.getDate(), m = this._minDate.getMonth();
                this._minMonths = this._monthtext.slice(0, m);
                this._minDates = this._datetext.slice(0, d - 1);
            }
        },
        _maxDateInitialize: function () {
            if (!this._winrt) {
                this._maxDate = new Date(this.model.maxDate);
                var d = this._maxDate.getDate(), m = this._maxDate.getMonth();
                this._maxMonths = this._monthtext.slice(m + 1, 12);
                this._maxDates = this._datetext.slice(d, 31);
            }
        },
        /**
        * Render Section For jsrender templates in datepicker content .
        * @private
        */
        _renderTemplate: function () {
            var template = {};
            template["default"] = "<div class='e-m-text {{:class}}'>{{:value}}</div>";
            template["monthtemplate"] = "<div class='e-m-text'>{{:secondvalue}}</div>";
            template["windows"] = "<div class='e-m-text {{:class}}'><div class='e-m-text-inner'>{{:value}}</div><div class='e-m-text-val e-m-dp-dayweek'>{{:secondvalue}}</div></div>";
            template["winrt"] = "<option value='{{:value}}'>{{:value}}</option>";
            template["winrtmonths"] = "<option value='{{:value}}'>{{:secondvalue}}</option>";
            $.templates(template);
        },
        /**
        * Render Section For datepicker content .
        * @private
        */
        _renderDateContent: function () {
            this._renderTemplate();
            this._monthsRendering();
            this._daysRendering();
            this._yearsRendering();
            this._innerdiv.append(this._wrapdiv);
            this._outerdiv.append(this._innerdiv);
        },
        /**
        * Render Section For ios7 specific api's datepicker control	
        * @private
        */
        _ios7Rendering: function () {
            this._renderDateContent();
            this._innerdiv.append("<div class='e-m-ios7-overlay'></div>");
            this._menu = ej.buildTag('div#' + this._id + '_menu.e-m-dp-menu');
            this._menu.append(this._outerdiv);
            this._menu.ejmMenu({ "renderTemplate": true, "allowScrolling": false, "targetId": this._menuTargetId, "height": 205, "width": this._outerdiv.width(), "theme": this.model.theme, "renderMode": this.model.renderMode, "ios7": { "showTitle": false, "showCancelButton": false } });
        },
        /**
        * Render Section For android specific api's Datepicker control	
        * @private
        */
        _androidRendering: function () {
            this._datepickerwrapper.append("<span class='e-m-textspan'></div>");
            this._renderDateContent();
            this._dialog = ej.buildTag("div.e-m-dp-dialog#" + this._id + "_dialog");
            this._dialog.ejmDialog({ "allowScrolling": false, "theme": this.model.theme, "title": "Set Date", "leftButtonCaption": "Done", "mode": "alert", "renderMode": this.model.renderMode, "enableAnimation": false });
            this._dialog.find("#" + this._id + "_dialogcontent").append(this._outerdiv);
        },
        /**
        * Render Section For windows specific api's Datepicker control	
        * @private
        */
        _windowsRendering: function () {
            this._outerdiv.append("<div class='e-m-dp-header'>CHOOSE DATE</div>");
            if (this.model.renderMode == "windows" && !ej.isMobile()) {
                this._renderDateContent();
                this._dialog = ej.buildTag("div.e-m-dp-dialog#" + this._id + "_dialog");
                this._dialog.ejmDialog({ "showModal": true, "allowScrolling": false, "theme": this.model.theme, "title": "Set Date", "leftButtonCaption": "Done", "rightButtonCaption": "Cancel", "mode": "confirm", "renderMode": this.model.renderMode, "enableModal": true, "windows": { "renderDefault": this.model.windows.renderDefault } });
                this._dialog.find("#" + this._id + "_dialogcontent").append(this._outerdiv);
            }
            else {
                this._renderDateContent();
                this._toolbar = ej.buildTag("div#" + this._id + "_toolbar.e-m-dp-tb", "<ul><li data-ej-iconname='done'></li><li data-ej-iconname='close'></li></ul>");
                App.activePage.append(this._outerdiv);
                this._appHeight = App.activePage.innerHeight();
                this._outerdiv.find(".col-fill").css("height", (((this._appHeight - 94) / 2) + 1) + "px");
                this._toolbar.ejmToolbar({ "theme": this.model.theme, "renderMode": this.model.renderMode, "touchEnd": $.proxy(this._winToolbarItem, this), "windows": { "renderDefault": this.model.windows.renderDefault } });
            }
        },
        /**
        * Render Section For flat specific api's Datepicker control	
        * @private
        */
        _flatRendering: function () {
            this._windowsRendering();
        },
        /**
        * Render Section For days column content in datepicker	
        * @private
        */
        _daysRendering: function () {
            var daysdata = [];
            this._daysofmonth = this._getDaysInMonth(new Date(this.model.value));
            for (i = 1; i <= 31; i++) {
                var dayofweek = Date.dayNames[(new Date(new Date(this.model.value).getMonth() + 1 + '/' + (i) + "/" + new Date(this.model.value).getFullYear()).getDay())];
                if (i <= this._daysofmonth)
                    daysdata.push({ "value": i, "secondvalue": dayofweek, "class": "" });
                else
                    daysdata.push({ "value": i, "secondvalue": dayofweek, "class": "e-m-state-disabled" });
            }
            this._columnRendering("days", daysdata);
        },
        /**
        * Render Section For winrt native appearance content in datepicker	
        * @private
        */
        _winrtContent: function (column, data) {
            this._select = ej.buildTag("select");
            data = $.render[column == "months" ? "winrtmonths" : "winrt"](data);
            this["_" + column].find(".e-m-dpouter").html(this._select.append(data));
            this._wrapdiv.append(this["_" + column]);
        },
        /**
        * Render Section For months column content in datepicker	
        * @private
        */
        _monthsRendering: function () {
            var monthsdata = [];
            var monthnames = this.model.renderMode == "android" ? "abbrMonthNames" : "monthNames";
            for (i = 0; i < 12; i++)
                monthsdata.push({ "secondvalue": Date[monthnames][i], "value": (i + 1) });
            this._columnRendering("months", monthsdata);
        },
        /**
        * Render Section For years column content in datepicker	
        * @private
        */
        _yearsRendering: function () {
            var yeardata = [];
            for (i = new Date(this.model.minDate).getFullYear() ; i <= new Date(this.model.maxDate).getFullYear() ; i++)
                yeardata.push({ "value": i });
            this._columnRendering("years", yeardata);
        },
        /**
        * Render Section For column content with specific templates defined in datepicker.
        * @private
        */
        _columnRendering: function (column, data) {
            if (this._winrt)
                this._winrtContent(column, data);
            else {
                var templateval = this.model.renderMode == "windows" || this.model.renderMode == "flat" ? "windows" : column == "years" ? "default" : (column == "months" ? "monthtemplate" : "default");
                data = $.render[templateval](data) + this._visibletexthtml;
                this["_" + column].find(".e-m-dpouter").html(this["_" + column].find(".e-m-dpouter").html() + data);
                this._wrapdiv.append(this["_" + column]);
            }
        },
        /**
        * To configure the delegates for Datepicker control		
        * @private
        */
        _createDelegates: function () {
            this._winScrlHndlr = $.proxy(this._outerScroll, this);
            this._focusHndlr = $.proxy(this._showDatePicker, this);
            this._blurHndlr = $.proxy(this._blurEventHandler, this);
            this._andBtnClkHndlr = $.proxy(this._androidDialogButtonClick, this);
            this._winrtBtnClkHndlr = $.proxy(this._winrtDialogButtonClick, this);
        },
        /**
        * Wiring the events to Datepicker control		
        * @private
        */
        _wireEvents: function (remove) {
            if (this.model.renderMode == "android")
                ej.listenTouchEvent($(this._dialog).find(".e-m-btn"), ej.tapEvent(), this._andBtnClkHndlr, remove);
            else if (this._winrt)
                ej.listenTouchEvent($(this._dialog).find(".e-m-btn"), ej.tapEvent(), this._winrtBtnClkHndlr, remove);
            else if (this.model.renderMode == "windows" || this.model.renderMode == "flat")
                ej.listenTouchEvent($(this._outerdiv).find(".e-m-dpwrap .e-m-dp"), ej.startEvent(), this._winScrlHndlr, remove);
            ej.listenEvents([$(this.element), $(this.element)], ["focus", "blur"], [this._focusHndlr, this._blurHndlr], remove);
        },
        /**
        * To get the scroll coordinates of the scroller at the runtime in datepicker
        * @private
        */
        _scrollCoordinates: function () {
            var day = {};
            day.Scrolldate = Math.round(this._date.ejmScrollPanel("getScrollPosition").y / this._displacement);
            day.Scrollmonth = Math.round(this._month.ejmScrollPanel("getScrollPosition").y / this._displacement);
            day.Scrollyear = Math.round(this._year.ejmScrollPanel("getScrollPosition").y / this._displacement);
            day.date = -(day.Scrolldate) + 1;
            day.month = -(day.Scrollmonth) + 1;
            day.year = -(day.Scrollyear) + new Date(this.model.minDate).getFullYear();
            return day;
        },
        /**
        * To manipulate the domelements that are accessed in the control functionality
        * @private
        */
        _domElements: function () {
            this._datetext = this._outerdiv.find("#" + this._id + "_dpdate .e-m-text");
            this._monthtext = this._outerdiv.find("#" + this._id + "_dpmonth .e-m-text");
            this._yeartext = this._outerdiv.find("#" + this._id + "_dpyear .e-m-text");
        },
        /**
        * To set the active date after currentDate is successfully calculated.
        * @private
        */
        _activeText: function (date, month, year, target) {
            if ((target && target == "dpdate") || target == null) {
                $(this._datetext).removeClass("e-m-text-active");
                $(this._datetext[date - 1]).addClass("e-m-text-active");
            }
            if (target && target == "dpmonth" || target == null) {
                $(this._monthtext).removeClass("e-m-text-active");
                $(this._monthtext[month - 1]).addClass("e-m-text-active");
            }
            if (target && target == "dpyear" || target == null) {
                $(this._yeartext).removeClass("e-m-text-active");
                $(this._yeartext[(year - new Date(this.model.minDate).getFullYear())]).addClass("e-m-text-active");
            }
        },
        /**
        * To configure the datevalue in the input area in the datepicker control.
        * @private
        */
        _setDateInput: function () {
            $(this.element).val(Globalize.format(new Date(this._currentDate), this.model.dateFormat));
            this._dateSelect();
        },
        /**
        * To configure the current date in the winrt datepicker control.
        * @private
        */
        _winrtInitialDate: function (date) {
            var date = new Date(this._currentDate);
            $("#" + this._id + "_dpdate").find("select option[value='" + date.getDate() + "']").attr("selected", true);
            $("#" + this._id + "_dpmonth").find("select option[value='" + (date.getMonth() + 1) + "']").attr("selected", true);
            $("#" + this._id + "_dpyear").find("select option[value='" + date.getFullYear() + "']").attr("selected", true);
        },
        /**
        * To configure the current date in the datepicker control.
        * @private
        */
        _setInitialDate: function () {
            if (this._winrt)
                this._winrtInitialDate(this._currentDate);
            else {
                this._setValue(this._currentDate);
                var proxy = this;
                setTimeout(function () {
                    proxy._setProperDate(100);
                }, 200);
            }
            $(this.element).val(Globalize.format(new Date(this._currentDate), this.model.dateFormat));
            this._previousDate = $(this.element).val();
        },
        /**
        * To configure the current date in the picker element.
        * @private
        */
        _setValue: function (date) {
            var date = new Date(date);
            this._time = ej.isAndroid() || ej.isWindows() ? 0 : (!this._initscroll && !this._setcurrent) ? 200 : 0;
            this._date.ejmScrollPanel("scrollTo", 0, -this._displacement * (date.getDate() - 1), this._time);
            this._month.ejmScrollPanel("scrollTo", 0, -this._displacement * (date.getMonth()), this._time);
            this._year.ejmScrollPanel("scrollTo", 0, -this._displacement * (date.getFullYear() - new Date(this.model.minDate).getFullYear()), this._time);
        },
        /**
        * To check whether the selected date is above maxdate or below mindate.
        * @private
        */
        _checkMinMax: function (day) {
            this._outerdiv.find(".e-m-state-disabled").removeClass("e-m-state-disabled");
            if (day.year == this._minDate.getFullYear() || day.year == this._maxDate.getFullYear()) {
                var m = day.year == this._minDate.getFullYear() ? "min" : "max";
                this["_" + m + "Months"].addClass("e-m-state-disabled");
                if (m == "min" ? day.month < this._minDate.getMonth() + 1 : day.month > this._maxDate.getMonth() + 1) {
                    day.month = this["_" + m + "Date"].getMonth() + 1;
                    this._month.ejmScrollPanel("scrollTo", 0, -this._displacement * (this["_" + m + "Date"].getMonth()), this._time);
                }
                else if (m == "min" ? day.month == this._minDate.getMonth() + 1 : day.month == this._maxDate.getMonth() + 1) {
                    this["_" + m + "Dates"].addClass("e-m-state-disabled");
                    if (m == "min" ? day.date < this._minDate.getDate() : day.date > this._maxDate.getDate()) {
                        day.date = this["_" + m + "Date"].getDate();
                        this._date.ejmScrollPanel("scrollTo", 0, -this._displacement * (this["_" + m + "Date"].getDate() - 1), this._time);
                    }
                }
            }
            return day;
        },
        /**
        * To set proper date after the date selection process is over .
        * @private
        */
        _setProperDate: function (duration, target) {
            var day = this._scrollCoordinates();
            if (!this._initscroll)
                day = this._checkMinMax(day);
            var proxy = this;
            if (target == "dpmonth")
                this._daysofmonth = this._getDaysInMonth(new Date(day.month + "/1/" + day.year));
            for (var i = 27; i <= 30; i++) {
                if (i + 1 > this._daysofmonth)
                    $(this._datetext[i]).addClass("e-m-state-disabled");
            }
            if (this._daysofmonth < day.date) {
                day.date = this._daysofmonth;
                this._date.ejmScrollPanel("scrollTo", 0, -this._displacement * (this._daysofmonth - 1), this._time);
            }
            if (this.model.renderMode == "ios7" && !this._initscroll) {
                setTimeout(function () {
                    $(proxy.element).val(Globalize.format(new Date(day.month + "/" + day.date + "/" + day.year), proxy.model.dateFormat));
                }, duration);
            }
            else if (this.model.renderMode == "android")
                this._dialog.ejmDialog({ "title": Globalize.format(new Date(day.month + "/" + day.date + "/" + day.year), this.model.dateFormat) });
            this._currentDate = day.month + "/" + day.date + "/" + day.year;
            this._activeText(day.date, day.month, day.year, target);
            if (this.model.change)
                this._trigger("change", this._argsValue());
        },
        /**
        * To configure the args value to the events in the datepicker
        * @private
        */
        _argsValue: function () {
            return { value: Globalize.format(this._currentDate, this.model.dateFormat) };
        },
        /**
        * To configure the scrollend event for the scroller in the datepicker
        * @private
        */
        _onScrollStop: function (e) {
            if (!e.object._moved) {
                var target = e.model.target.replace(this._id + "_", '');
                this._setProperDate(this.model.renderMode == "windows" ? 700 : 200, target);
                if (this["_" + this.model.renderMode + "ScrollStop"])
                    this["_" + this.model.renderMode + "ScrollStop"](e.model.target, target, e);
            }
        },
        /**
        * To configure the scrollend event for the windows mode datepicker
        * @private
        */
        _windowsScrollStop: function (e, target, scrollModel) {
            var day = this._scrollCoordinates();
            for (var i = 0; i < this._getDaysInMonth(new Date(day.month + "/" + day.date + "/" + day.year)) ; i++) {
                var dayofweek = Date.dayNames[(new Date(day.month + '/' + (i + 1) + "/" + day.year)).getDay()];
                $(this._datetext[i]).find(".e-m-dp-dayweek").html(dayofweek);
            }
            var startTarget = this._id + "_" + this._target;
            this._hideWrapper(target);
        },
        /**
        * To configure the scrollend event for the flat mode datepicker
        * @private
        */
        _flatScrollStop: function (e, target, scrollModel) {
            this._windowsScrollStop(e, target, scrollModel);
        },
        /**
        * To configure the scrollstart event for the scroller in the datepicker
        * @private
        */
        _onScrollStart: function (e) {
            this._target = e.model.target.replace(this._id + "_", '');
            if (this["_" + this.model.renderMode + "ScrollStart"])
                this["_" + this.model.renderMode + "ScrollStart"](e.model.target, this._target);
        },
        /**
        * To configure the scrollstart event for the windows mode datepicker
        * @private
        */
        _windowsScrollStart: function (e, target) {
            $("#" + e + "").find(".e-m-text.e-m-text-active").removeClass("e-m-text-active");
            this._hideWrapper(target);
        },
        /**
        * To configure the scrollstart event for the flat mode datepicker
        * @private
        */
        _flatScrollStart: function (e, target) {
            this._windowsScrollStart(e, target);
        },
        /**
        * To hide the column wrapper in windows mode datepicker when the scrolling animation in over.
        * @private
        */
        _hideWrapper: function (target) {
            if (target && target == "dpdate") {
                if (!this._year.ejmScrollPanel("instance")._moved)
                    $("#" + this._id + "_dpyear").closest(".e-m-datewrapper").removeClass("e-m-scrollstart");
                if (!this._month.ejmScrollPanel("instance")._moved)
                    $("#" + this._id + "_dpmonth").closest(".e-m-datewrapper").removeClass("e-m-scrollstart");
            }
            if (target && target == "dpmonth") {
                if (!this._year.ejmScrollPanel("instance")._moved)
                    $("#" + this._id + "_dpyear").closest(".e-m-datewrapper").removeClass("e-m-scrollstart");
                if (!this._date.ejmScrollPanel("instance")._moved)
                    $("#" + this._id + "_dpdate").closest(".e-m-datewrapper").removeClass("e-m-scrollstart");
            }
            if (target && target == "dpyear") {
                if (!this._month.ejmScrollPanel("instance")._moved)
                    $("#" + this._id + "_dpmonth").closest(".e-m-datewrapper").removeClass("e-m-scrollstart");
                if (!this._date.ejmScrollPanel("instance")._moved)
                    $("#" + this._id + "_dpdate").closest(".e-m-datewrapper").removeClass("e-m-scrollstart");
            }
        },
        /**
        * To configure the blur event for the control.
        * @private
        */
        _blurEventHandler: function () {
            if (this.model.focusOut) {
                this._trigger("focusOut", this._argsValue());
            }
            if (this.model.renderMode == "ios7") {
                if (this.model.select) {
                    if (this._previousDate != $(this.element).val())
                        this._trigger("select", this._argsValue());
                }
                if (this.model.close)
                    this._trigger("close", this._argsValue());
            }
        },
        /**
        * To configure the select event trigger for the control when the control is hided.
        * @private
        */
        _dateSelect: function (e) {
            if (this._previousDate != $(this.element).val()) {
                if (this.model.select)
                    this._trigger("select", this._argsValue());
            }
            this._previousDate = $(this.element).val();
            this._hideDatePicker();
        },
        /**
        * To configure the toolbar item click action in windows phone mode datepicker .
        * @private
        */
        _winToolbarItem: function (e) {
            if (e.itemname == "done")
                this._setDateInput();
            else if (e.itemname == "close")
                this._hideDatePicker();
        },
        /**
        * To configure the diloag button click action in windows tablet mode datepicker .
        * @private
        */
        _winrtDialogButtonClick: function (e) {
            if ($(e.target).val() == "Done") {
                this._currentDate = $("#" + this._id + "_dpmonth").find("select option:selected").val() + "/" + $("#" + this._id + "_dpdate").find("select option:selected").val() + "/" + $("#" + this._id + "_dpyear").find("select option:selected").val();
                this._setDateInput();
            }
            else
                this._showHidePicker(true);
        },
        /**
        * To configure the diloag button click action in android mode datepicker .
        * @private
        */
        _androidDialogButtonClick: function (e) {
            this._setDateInput();
        },
        /**
        * To configure the outerscrolling in windows mode datepicker .
        * @private
        */
        _outerScroll: function (e) {
            $(e.target).closest(".e-m-dp").find(".e-m-datewrapper").addClass("e-m-scrollstart");
        },
        /**
        * To configure the datepicker control to either to hide or show based on arguments. 
        * @private
        */
        _showHidePicker: function (remove) {
            var e = { currentTarget: this._datepickerwrapper };
            var visibility = remove ? "hidden" : "visible";
            var flipclass = remove ? "out" : "in";
            var zindex = ej.getMaxZindex();
            this.element.next("span")[remove ? "removeClass" : "addClass"]("e-m-focusin");
            if (this._winrt)
                this._dialog.ejmDialog(remove ? "close" : "open");
            else if (this.model.renderMode == "android")
                this._dialog.css("visibility", remove ? "hidden" : "visible").css("z-index", zindex + 1);
            else if (this.model.renderMode == "windows" || this.model.renderMode == "flat") {
                this._outerdiv.css({ "top": remove ? "" : "0px", "bottom": remove ? this._appHeight + "px" : "0px", "z-index": zindex + 1, "visibility ": visibility }).removeClass("in out").addClass(flipclass);
                this._outerdiv.find(".e-m-dp-header").css({ "z-index": zindex + 2 });
                this._toolbar.css({ "z-index": zindex + 2, "visibility": visibility });
            }
        },
        /**
        * To configure the datepicker control to show 
        * @private
        */
        _showDatePicker: function (e) {
            if (this.model.focusIn)
                this._trigger("focusIn", this._argsValue());
            this._showHidePicker();
            this._outerdiv.find(".e-m-datewrapper").removeClass("e-m-scrollstart");
            if (this.model.open)
                this._trigger("open", this._argsValue());
        },
        /**
        * To configure the datepicker control to hide 
        * @private
        */
        _hideDatePicker: function (e) {
            this._showHidePicker(true);
            if (this.model.close)
                this._trigger("close", this._argsValue());
        },
        /**
        * To return the number of days in the given month.
        * @private
        */
        _getDaysInMonth: function (date) {
            return [31, (this._isLeapYear(date.getFullYear()) ? 29 : 28), 31, 30, 31, 30, 31, 31, 30, 31, 30, 31][date.getMonth()];
        },
        /**
        * To check whether the given year is Leap year or not .
        * @private
        */
        _isLeapYear: function (year) {
            return (year % 4 == 0 && year % 100 != 0) || year % 400 == 0;
        },
        /**
        * To refresh the scrollers in the Datepicker control		
        * @private
        */
        _refreshScroller: function (e) {
            this._date.ejmScrollPanel("refresh");
            this._month.ejmScrollPanel("refresh");
            this._year.ejmScrollPanel("refresh");
        },
        /**
        * SetModel section for Datepicker control		
        * @private
        */
        _setModel: function (options) {
            var refresh;
            for (var prop in options) {
                if (prop == "renderMode" || prop == "minDate" || prop == "maxDate" || prop == "culture" || (this.model.renderMode == "ios7" && prop == "renderDefault"))
                    refresh = true;
                else {
                    setprop = "_set" + prop.charAt(0).toUpperCase() + prop.slice(1);
                    if (this[setprop])
                        this[setprop](options[prop])
                }
            }
            if (refresh)
                this._refresh();
        },
        /**
        * To configure the theme of the Datepicker		
        * @private
        */
        _setTheme: function (theme) {
            this.model.theme = theme;
            this._datepickerwrapper.removeClass("e-m-dark e-m-light e-m-default").addClass("e-m-" + this.model.theme);
            if (this.model.renderMode == "ios7" && !ej.isMobile())
                this._menu.ejmMenu({ "theme": this.model.theme });
            if (this.model.renderMode == "android")
                this._dialog.ejmDialog({ "theme": this.model.theme });
            else if (this.model.renderMode == "windows")
                this._toolbar.ejmToolbar({ "theme": this.model.theme });
        },
        /**
        * To configure the Enabling of the Datepicker		
        * @private
        */
        _setEnabled: function (enabled) {
            this._controlStatus(enabled);
        },
        /**
        * To configure the DateFormat of the Datepicker		
        * @private
        */
        _setDateFormat: function (dateformat) {
            this.model.dateFormat = dateformat;
            $(this.element).val(Globalize.format(new Date(this._currentDate), dateformat));
        },
        /**
        * To configure the control status of the Datepicker		
        * @private
        */
        _controlStatus: function (enabled) {
            this._datepickerwrapper[!enabled ? "addClass" : "removeClass"]("e-m-state-disabled");
        },
        /**
        * Refresh section for to refresh the DOM elements back to original input element.		
        * @private
        */
        _refresh: function () {
            this._destroy();
            this.element.addClass("e-m-datepicker");
            this._renderControl();
            this._wireEvents();
        },
        /**
        * Clear Element section for Datepicker control		
        * @private
        */
        _clearElement: function () {
            this.element.insertAfter(this._datepickerwrapper);
            this._datepickerwrapper.remove();
            if (this._dialog) {
                this._dialog.ejmDialog("instance")._destroy();
                this._dialog.remove();
                this._dialog = null;
            }
            else if (this._toolbar) {
                this._toolbar.ejmToolbar("instance")._destroy();
                this._toolbar.remove();
                this._toolbar = null;
            }
            else if (this._menu) {
                this._menu.ejmMenu("instance")._destroy();
                this._menu.remove();
                this._menu = null;
            }
            this.element = $(this.element);
            this._outerdiv.remove();
        },
        /**
        * Destroy Element section for Datepicker control		
        * @private
        */
        _destroy: function () {
            this._wireEvents(true);
            this._clearElement();
        },

        /*---------------Public Methods---------------*/
        /**
        * To show the DatePicker control 
        * @return jQuery
        * @example 
        * &lt;input id="datepicker" data-role="ejmdatepicker"/&gt;<br>
        * &lt;script&gt;
        * $(function(){
        * // Create DatePicker
        * var dpObj = $("#datepicker").data("ejmDatePicker");
        * dpObj.show();
        * });
        * &lt;/script&gt;
        * @example 
        * &lt;input id="datepicker" data-role="ejmdatepicker"/&gt;<br>
        * &lt;script&gt;
        * $(function(){
        * $("#datepicker").ejmDatePicker("show");	
        * });
        * &lt;/script&gt;
        * @memberof ejmDatePicker
        * @instance
        */
        show: function (e) {
            var e = { currentTarget: this._datepickerwrapper };
            if (this.model.renderMode == "ios7")
                this._menu.ejmMenu("show", e);
            else
                this._showHidePicker();
        },
        /**
        * To hide the DatePicker control
        * @return jQuery
        * @example 
        * &lt;input id="datepicker" data-role="ejmdatepicker"/&gt;<br>
        * &lt;script&gt;
        * $(function(){
        * // Create DatePicker
        * var dpObj = $("#datepicker").data("ejmDatePicker");
        * dpObj.hide();
        * });
        * &lt;/script&gt;
        * @example 
        * &lt;input id="datepicker" data-role="ejmdatepicker"/&gt;<br>
        * &lt;script&gt;
        * $(function(){
        * $("#datepicker").ejmDatePicker("hide");
        * });
        * &lt;/script&gt;
        * @memberof ejmDatePicker
        * @instance
        */
        hide: function (e) {
            var e = { currentTarget: this._datepickerwrapper };
            if (this.model.renderMode == "ios7")
                this._menu.ejmMenu("hide", e);
            else
                this._showHidePicker(true);
        },
        /**
        * To enable the datepicker
        * @return jQuery
        * @example 
        * &lt;input id="datepicker" data-role="ejmdatepicker"/&gt;<br>
        * &lt;script&gt;
        * $(function(){
        * // Create DatePicker
        * var dpObj = $("#datepicker").data("ejmDatePicker");
        * dpObj.enable();
        * });
        * &lt;/script&gt;
        * @example 
        * &lt;input id="datepicker" data-role="ejmdatepicker"/&gt;<br>
        * &lt;script&gt;
        * $(function(){
        * // change the DatePicker current state to enabled	
        * $("#datepicker").ejmDatePicker("enable");
        * });
        * &lt;/script&gt;
        * @memberof ejmDatePicker
        * @instance
        */
        enable: function (e) {
            this.model.enabled = true;
            this._controlStatus(this.model.enabled);
            this._showHidePicker(true);
        },
        /**
        * To disable the datpicker
        * @return jQuery
        * @example 
        * &lt;input id="datepicker" data-role="ejmdatepicker"/&gt;<br>
        * &lt;script&gt;
        * $(function(){
        * // Create DatePicker
        * var dpObj = $("#datepicker").data("ejmDatePicker");
        * dpObj.disable();
        * });
        * &lt;/script&gt;
        * @example 
        * &lt;input id="datepicker" data-role="ejmdatepicker"/&gt;<br>
        * &lt;script&gt;
        * // changes the DatePicker current state to disabled	
        * $(function(){
        * $("#datepicker").ejmDatePicker("disable");	
        * });
        * &lt;/script&gt;
        * @memberof ejmDatePicker
        * @instance
        */
        disable: function (e) {
            this.model.enabled = false;
            this._controlStatus(this.model.enabled);
            this._showHidePicker(true);
        },
        /**
        * Get the current value.
        * @return jQuery
        * @example 
        * &lt;input id="datepicker" data-role="ejmdatepicker"/&gt;<br>
        * &lt;script&gt;
        * $(function(){
        * // Create DatePicker
        * var dpObj = $("#datepicker").data("ejmDatePicker");
        * dpObj.getValue();
        * });
        * &lt;/script&gt;
        * @example 
        * &lt;input id="datepicker" data-role="ejmdatepicker"/&gt;<br>
        * &lt;script&gt;
        * // get the DatePicker current value		
        * $(function(){
        * $("#datepicker").ejmDatePicker("getValue");	
        * });
        * &lt;/script&gt;
        * @memberof ejmDatePicker
        * @instance
        */
        getValue: function () {
            return $(this.element).val();
        },
        /**
        * Set the given date.
        * @return jQuery
        * @example 
        * &lt;input id="datepicker" data-role="ejmdatepicker"/&gt;<br>
        * &lt;script&gt;
        * $(function(){
        * // Create DatePicker
        * var dpObj = $("#datepicker").data("ejmDatePicker");
        * dpObj.setCurrentDate("12/31/2000");
        * });
        * &lt;/script&gt;
        * @example 
        * &lt;input id="datepicker" data-role="ejmdatepicker"/&gt;<br>
        * &lt;script&gt;
        * // get the DatePicker current value		
        * $(function(){
        * $("#datepicker").ejmDatePicker("setCurrentDate", "12/31/2000");
        * });
        * &lt;/script&gt;		
        * @memberof ejmDatePicker
        * @instance
        */
        setCurrentDate: function (date) {
            this._setcurrent = true;
            this._currentDate = date;
            this._daysofmonth = this._getDaysInMonth(new Date(date));
            this._setInitialDate();
            this._setcurrent = false;
        }

        /*---------------Public Methods End---------------*/
    });
})(jQuery, Syncfusion);