/**
* @fileOverview Plugin to style the Html CheckBox elements
* @copyright Copyright Syncfusion Inc. 2001 - 2014. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/
(function ($, ej, undefined) {
    // ejmDialog is the plugin name 
    // "ej.mobile.Dialog" is "namespace.className" will hold functions and properties
    /**
    * @namespace ej
    * @class ejmDialog
    * @requires jQuery
    * @requires ej.mobile.application
    * @requires ej.core
    * @requires ej.unobtrusive
    * @requires ej.mobile.core
    * @requires ej.data
    * @requires ej.touch
    * @requires ej.mobile.button
    * @requires ej.mobile.header
    * @requires ej.mobile.scrollbar
    * @requires ej.mobile.scrollpanel
    * @classdesc Custom Design for Html Dialog control.
    * @example 
    * &lt;div id="dlg" data-role="ejmdialog" data-ej-enableautoopen="true" data-ej-title="Low Battery" &gt;
    *   &lt;div&gt;
    *       10% of battery remaining
    *   &lt;/div&gt;
    * &lt;/div&gt;   
    */
    ej.widget("ejmDialog", "ej.mobile.Dialog", {
        _setFirst: true,
        _rootCSS: "e-m-dialog",
        // Default model values
        defaults: {
            /**		
            * Specifies whether to open the dialog on initial loading.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the enableAutoOpen property in unobtrusive way.
            * &lt;div id="dlg" data-role="ejmdialog" data-ej-enableautoopen="true" &gt;
            *   &lt;div&gt;
            *       10% of battery remaining
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * @example 
            * // Set enableAutoOpen on initialization. 
            *   //To set enableAutoOpen API value 
            * &lt;div id="dlg"&gt;
            *   &lt;div&gt;
            *       10% of battery remaining
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function(){
            *   $("#dlg").ejmDialog({ enableAutoOpen: true });
            * });
            * &lt;/script&gt;			
            * @example 
            * &lt;script&gt;
            * //Get or set the Dialog enableAutoOpen, after initialization:<br>
            *   // Get the enableAutoOpen API value.	
            *   $("#dlg").ejmDialog ("option", "enableAutoOpen");			
            *   // Set the enableAutoOpen API
            *   $("#dlg").ejmDialog ("option", "enableAutoOpen", true);   
            * &lt;/script&gt;
            * @memberof ejmDialog
            * @instance          
            */
            enableAutoOpen: false,

            /**		
            * Specifies the title text.
            * @default null
            * @type {string}
            * @example 
            * //Set the title property in unobtrusive way.
            * &lt;div id="dlg" data-role="ejmdialog" data-ej-title="Low Battery" data-ej-enableautoopen="true" &gt;
            *   &lt;div&gt;
            *       10% of battery remaining
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * @example 
            * // Set title on initialization. 
            *   //To set title API value 
            * &lt;div id="dlg"&gt;
            *   &lt;div&gt;
            *       10% of battery remaining
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function(){
            *   $("#dlg").ejmDialog({ enableAutoOpen: true, title: "Low Battery" });
            * });
            * &lt;/script&gt;	
            * @example 
            * &lt;script&gt;
            * //Get or set the Dialog title, after initialization:<br>
            *   // Get the title API value.
            *   $("#dlg").ejmDialog ("option", "title");			
            *   // Set the title API
            *   $("#dlg").ejmDialog ("option", "title", "Low Battery");        
            * &lt;/script&gt;
            * @memberof ejmDialog
            * @instance			
            */
            title: null,

            /**    
            * Event triggers before dialog window get closed.
            * @event
            * @name ejmDialog#beforeClose
            * @param {Object} argument Event parameters from dialog.
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @param {string} argument.title returns the title of the dialog.
            * @example 
            * //beforeClose event for Dialog
            * &lt;div id="dlg" data-role="ejmdialog" data-ej-beforeclose="beforeClose" data-ej-buttontap="alertClose" data-ej-enableautoopen="true" &gt;
            *  &lt;div&gt;
            *      10% of battery remaining
            *  &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt; 
            * function alertClose(){
            * $("#dlg").ejmDialog("close");
            * }
            * function beforeClose(){}
            * &lt;/script&gt;
            * @example 
            * //beforeClose event for Dialog
            * &lt;div id="dlg" &gt; 
            * &lt;div&gt;
            *    10% of battery remaining
            *  &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt; 
            * $("#dlg").ejmDialog({
            * enableAutoOpen: true,
            * buttonTap: function (args) {
            *    $("#dlg").ejmDialog("close");
            * },
            * beforeClose: function (args) {
            *    //handle the event 
            * }
            * });
            * &lt;/script&gt;
            * @memberof ejmDialog
            * @instance
            */

            beforeClose: null,
            /**    
            * Event triggers after dialog window get opened.
            * @event
            * @name ejmDialog#open 
            * @param {Object} argument Event parameters from dialog.
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @param {string} argument.title returns the title of the dialog.
            * @example 
            * //Open event for Dialog
            * &lt;div &gt; 
            * &lt;input data-role="ejmbutton" id="btn" data-ej-text="Click here to open dialog" data-ej-enableautoopen="true" data-ej-touchend="openDlg"&gt;
            * &lt;/div&gt;
            * &lt;div id="dlg" data-role="ejmdialog" data-ej-open="open" &gt;
            * &lt;div&gt;
            *     10% of battery remaining
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt; 
            * function openDlg(args) {
            * $("#dlg").ejmDialog("open");
            * }
            *   function open(args) {
            *        //handle the event
            * }
            * &lt;/script&gt;
            * @example 
            * //open event for Dialog
            * &lt;div&gt; 
            *   &lt;input data-role="ejmbutton" id="btn" data-ej-text="Click here to open dialog" data-ej-enableautoopen="true" data-ej-touchend="openDlg"&gt; 
            *  &lt;/div&gt; 
            * &lt;div id="dlg"&gt; 
            * &lt;div&gt; 
            * 10% of battery remaining
            * &lt;/div&gt; 
            * &lt;/div&gt; 
            * &lt;script&gt; 
            * $(function () {
            * $("#dlg").ejmDialog({ open: "open" });
            * });
            * function openDlg(args) {
            * $("#dlg").ejmDialog("open");
            * }
            * function open(args) {
            *     //handle the event
            *   }
            * &lt;/script&gt; 
            * @memberof ejmDialog
            * @instance
            */
            open: null,

            /**    
            * Event triggers after dialog window get closed.
            * @event
            * @name ejmDialog#close
            * @param {Object} argument Event parameters from dialog.
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @param {string} argument.title returns the title of the dialog.
            * @example 
            * //Close event for Dialog
            * &lt;div id="dlg" data-role="ejmdialog" data-ej-close="close" data-ej-buttontap="buttontap" data-ej-enableautoopen="true" &gt;
            * &lt;div&gt;
            * 10% of battery remaining
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt; 
            * function buttontap(args)
            * {
            * $("#dlg").ejmDialog("close");
            * }
            * function close(){}
            * &lt;/script&gt;
            * @example 
            * //Close event for Dialog
            * &lt;div id="dlg"&gt;
            * &lt;div&gt;
            * 10% of battery remaining
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt; 
            * $(function(){
            * $("#dlg").ejmDialog({ enableAutoOpen : true , buttonTap:"buttonTap" , close:"close" });
            * });
            * function buttonTap(args) { 
            * $("#dlg").ejmDialog("close");
            * } 
            * function close() { //handle the event 
            * }               
            * @memberof ejmDialog
            * @instance
            */
            close: null,

            /**    
            * Event triggers when tap happens on the button.
            * @event
            * @name ejmDialog#buttonTap 
            * @param {Object} argument Event parameters from dialog.
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @param {Object} argument.text returns the text of the button.
            * @example 
            * //buttonTap event for Dialog
            * &lt;div id="dlg" data-role="ejmdialog" data-ej-buttontap="buttonTap" data-ej-enableautoopen=true &gt;
            *   &lt;div&gt;
            *       10% of battery remaining
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt; 
            * function buttonTap(){}
            * &lt;/script&gt;
            * @example 
            * //buttonTap event for Dialog
            * &lt;div id="dlg"&gt;
            * &lt;div&gt;
            *   10% of battery remaining
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function () {
            * $("#dlg").ejmDialog({ enableAutoOpen: true, buttonTap: "buttonTap" });
            * });
            * function buttonTap(args) { //handle the event
            * }
            * &lt;/script&gt;
            * @memberof ejmDialog
            * @instance
            */
            buttonTap: null,
            /**		
            * Specifies the rendering mode of the control. See {@link RenderMode}
            * @default auto
            * @type {enum}
            * @example 
            * //Set the rendermode property in unobtrusive way.
            * &lt;div id="dlg" data-role="ejmdialog" data-ej-rendermode="auto" data-ej-enableautoopen="true" &gt;
            * &lt;div&gt;
            * 10% of battery remaining
            * &lt;/div&gt;
            * &lt;/div&gt;
            * @example 
            * // Set rendermode on initialization. 
            * //To set rendermode API value 
            * &lt;div id="dlg"&gt;
            *   &lt;div&gt;
            *       10% of battery remaining
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function(){
            *   $("#dlg").ejmDialog({ enableAutoOpen: true, renderMode: ej.mobile.RenderMode.Auto });
            * });
            * &lt;/script&gt;			
            * @example 
            * &lt;script&gt;
            * //Get or set the Dialog rendermode, after initialization:<br>
            * // Get the rendermode API value.	
            *  $("#dlg").ejmDialog ("option", "renderMode");			
            * // Set the renderMode API
            * $("#dlg").ejmDialog ("option", "renderMode", ej.mobile.RenderMode.Auto);           
            * &lt;/script&gt;
            * @memberof ejmDialog
            * @instance	
            */
            renderMode: "auto",
            /**		
            * Specifies the theme.See {@link Theme}
            * @default auto
            * @type {enum}
            * @example 
            * //Set the theme property in unobtrusive way.
            * &lt;div id="dlg" data-role="ejmdialog" data-ej-theme="auto" data-ej-enableautoopen="true" &gt;
            * &lt;div&gt;
            * 10% of battery remaining
            * &lt;/div&gt;
            * &lt;/div&gt;
            * @example 
            * // Set theme on initialization. 
            * //To set theme API value 
            * &lt;div id="dlg"&gt;
            *   &lt;div&gt;
            *       10% of battery remaining
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function(){
            *   $("#dlg").ejmDialog({ enableAutoOpen: true, theme: ej.mobile.Theme.Auto });
            * });
            * &lt;/script&gt;		
            * @example 
            * &lt;script&gt;
            * //Get or set the Dialog theme, after initialization:<br>
            * // Get the theme API value.
            *  $("#dlg").ejmDialog ("option", "theme");			
            * // Set the theme API
            * $("#dlg").ejmDialog ("option", "theme", ej.mobile.Theme.Auto);          
            * &lt;/script&gt;
            * @memberof ejmDialog
            * @instance				
            */
            theme: "auto",
            /**		
            * Specifies whether to enable modal dialog.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the enableModal property in unobtrusive way.
            * &lt;div id="dlg" data-role="ejmdialog" data-ej-enableModal="true" data-ej-enableautoopen="true" &gt;
            * &lt;div&gt;
            * 10% of battery remaining
            * &lt;/div&gt;
            * &lt;/div&gt;
            * @example 
            * // Set enableModal property on initialization. 
            *   //To set enableModal API value 
            * &lt;div id="dlg"&gt;
            *   &lt;div&gt;
            *       10% of battery remaining
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function(){
            *   $("#dlg").ejmDialog({ enableAutoOpen: true, enableModal: true });
            * });
            * &lt;/script&gt;		
            * @example 
            * &lt;script&gt;
            * //Get or set the Dialog enableModal, after initialization:<br>
            * // Get the enableModal API value.
            *  $("#dlg").ejmDialog ("option", "enableModal");			
            * // Set the enableModal API
            * $("#dlg").ejmDialog ("option", "enableModal", true);    
            * &lt;/script&gt;
            * @memberof ejmDialog
            * @instance			
            */
            enableModal: false,
            /**		
            * Specifies whether to show the buttons in the dialog.
            * @default true
            * @type {boolean}
            * @example 
            * //Set the showButtons property in unobtrusive way.
            * &lt;div id="dlg" data-role="ejmdialog" data-ej-showbuttons="true" data-ej-enableautoopen="true" &gt;
            * &lt;div&gt;
            * 10% of battery remaining
            * &lt;/div&gt;
            * &lt;/div&gt;
            * @example 
            * // Set showButtons property on initialization. 
            *   //To set showButtons API value 
            * &lt;div id="dlg"&gt;
            *   &lt;div&gt;
            *       10% of battery remaining
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function(){
            *   $("#dlg").ejmDialog({ enableAutoOpen: true, showButtons: false });
            * });
            * &lt;/script&gt;		
            * @example 
            * &lt;script&gt;
            * //Get or set the Dialog showButtons, after initialization:<br>
            * // Get the showButtons API value.	
            *  $("#dlg").ejmDialog ("option", "showButtons");			
            * // Set the showButtons API
            * $("#dlg").ejmDialog ("option", "showButtons", false);     
            * &lt;/script&gt;
            * @memberof ejmDialog
            * @instance	
            */
            showButtons: true,
            /**		
            * Specifies whether to allow scrolling behaviour for the contents.
            * @default true
            * @type {boolean}
            * @example 
            * //Set the allowScrolling property in unobtrusive way.
            * &lt;div id="dlg" data-role="ejmdialog" data-ej-allowscrolling="true" data-ej-enableautoopen="true" &gt;
            * &lt;div&gt;
            * 10% of battery remaining
            * &lt;/div&gt;
            * &lt;/div&gt;
            * @example 
            * // Set allowScrolling on initialization. 
            * //To set allowScrolling API value 
            * &lt;div id="dlg"&gt;
            *   &lt;div&gt;
            *       10% of battery remaining
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function(){
            *   $("#dlg").ejmDialog({ enableAutoOpen: true, allowScrolling: true });
            * });
            * &lt;/script&gt;		
            * @example 
            * &lt;script&gt;
            * //Get or set the Dialog allowScrolling, after initialization:<br>
            * // Get the allowScrolling API value.	
            *  $("#dlg").ejmDialog ("option", "allowScrolling");			
            * // Set the allowScrolling API
            * $("#dlg").ejmDialog ("option", "allowScrolling", true);       
            * &lt;/script&gt;
            * @memberof ejmDialog
            * @instance
            */
            allowScrolling: true,
            /**		
            * Specifies whether to enable device's native scroll behaviour when scrolling is allowed.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the enableNativeScrolling property in unobtrusive way.
            * &lt;div id="dlg" data-role="ejmdialog" data-ej-enablenativescrolling="true" data-ej-enableautoopen="true" &gt;
            * &lt;div&gt;
            * 10% of battery remaining
            * &lt;/div&gt;
            * &lt;/div&gt;
            * @example 
            * // Set enableNativeScrolling on initialization. 
            * //To set enableNativeScrolling API value 
            * &lt;div id="dlg"&gt;
            *   &lt;div&gt;
            *       10% of battery remaining
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function(){
            *   $("#dlg").ejmDialog({ enableAutoOpen: true, enableNativeScrolling: true });
            * });
            * &lt;/script&gt;		
            * @example 
            * &lt;script&gt;
            * //Get or set the Dialog enableNativeScrolling, after initialization:<br>
            * // Get the enableNativeScrolling API value.
            *  $("#dlg").ejmDialog ("option", "enableNativeScrolling");			
            * // Set the enableNativeScrolling API
            * $("#dlg").ejmDialog ("option", "enableNativeScrolling", true);   
            * &lt;/script&gt;
            * @memberof ejmDialog
            * @instance			
            */
            enableNativeScrolling: (ej.isAndroid() || ej.isIOS()) ? false : ej.isDevice() ? true : false,
            /**		
            * Specifies the dialog mode to render.See {@link Mode}
            * @default ej.mobile.Rating.Mode.Alert. 
            * @type {enum}
            * @example 
            * //Set the mode property in unobtrusive way.
            * &lt;div id="dlg" data-role="ejmdialog" data-ej-mode="confirm" data-ej-enableautoopen="true" &gt;
            * &lt;div&gt;
            * 10% of battery remaining
            * &lt;/div&gt;
            * &lt;/div&gt;
            * @example 
            * // Set mode on initialization. 
            * //To set mode API value 
            * &lt;div id="dlg"&gt;
            *   &lt;div&gt;
            *       10% of battery remaining
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function(){
            *   $("#dlg").ejmDialog({ enableAutoOpen: true, mode: ej.mobile.Dialog.Mode.Confirm });
            * });
            * &lt;/script&gt;		
            * @example 
            * &lt;script&gt;
            * //Get or set the Dialog mode, after initialization:<br>
            * // Get the mode API value.	
            *  $("#dlg").ejmDialog ("option", "mode");			
            * // Set the mode API
            * $("#dlg").ejmDialog ("option", "mode", ej.mobile.Dialog.Mode.Confirm);   
            * &lt;/script&gt;
            * @memberof ejmDialog
            * @instance	
            */
            mode: "alert",
            /**		
            * Specifies the text of left button.
            * @default Cancel
            * @type {string}
            * @example 
            * //Set the leftButtonCaption property in unobtrusive way.
            * &lt;div id="dlg" data-role="ejmdialog" data-ej-leftbuttoncaption="Close" data-ej-enableautoopen="true" &gt;
            * &lt;div&gt;
            * 10% of battery remaining
            * &lt;/div&gt;
            * &lt;/div&gt;
            * @example 
            * // Set leftButtonCaption on initialization. 
            * //To set leftButtonCaption API value 
            * &lt;div id="dlg"&gt;
            *   &lt;div&gt;
            *       10% of battery remaining
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function(){
            *   $("#dlg").ejmDialog({ enableAutoOpen: true, leftButtonCaption: "Close" });
            * });
            * &lt;/script&gt;	
            * @example 
            * &lt;script&gt;
            * //Get or set the Dialog leftButtonCaption, after initialization:<br>
            * // Get the leftButtonCaption API value.
            *  $("#dlg").ejmDialog ("option", "leftButtonCaption");			
            * // Set the leftButtonCaption API
            * $("#dlg").ejmDialog ("option", "leftButtonCaption", "Close");          
            * &lt;/script&gt;
            * @memberof ejmDialog
            * @instance				
            */
            leftButtonCaption: "Cancel",
            /**		
            * Specifies the text of right button.
            * @default Continue
            * @type {string}
            * @example 
            * //Set the rightButtonCaption property in unobtrusive way.
            * &lt;div id="dlg" data-role="ejmdialog" data-ej-mode="confirm" data-ej-rightbuttoncaption="Ok" data-ej-enableautoopen="true" &gt;
            * &lt;div&gt;
            * 10% of battery remaining
            * &lt;/div&gt;
            * &lt;/div&gt;
            * @example 
            * // Set rightButtonCaption on initialization. 
            * //To set rightButtonCaption API value 
            * &lt;div id="dlg"&gt;
            *   &lt;div&gt;
            *       10% of battery remaining
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function(){
            *   $("#dlg").ejmDialog({ enableAutoOpen: true, mode:"confirm", rightButtonCaption: "Ok" });
            * });
            * &lt;/script&gt;		
            * @example 
            * &lt;script&gt;
            * //Get or set the Dialog rightButtonCaption, after initialization:<br>
            * // Get the rightButtonCaption API value.	
            *  $("#dlg").ejmDialog ("option", "rightButtonCaption");			
            * // Set the rightButtonCaption API
            * $("#dlg").ejmDialog ("option", "rightButtonCaption", "Ok");  
            * &lt;/script&gt;
            * @memberof ejmDialog
            * @instance
            */
            rightButtonCaption: "Continue",
            /**		
            * Specifies whether need to refresh scrollpanel rendered in the control when elements are added dynamically.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the checkDOMChanges property in unobtrusive way.
            * &lt;div id="dlg" data-role="ejmdialog" data-ej-checkdomchanges="true" data-ej-enableautoopen="true" &gt;
            * &lt;div&gt;
            * 10% of battery remaining
            * &lt;/div&gt;
            * &lt;/div&gt;
            * @example 
            * // Set checkDOMChanges on initialization. 
            * //To set checkDOMChanges API value 
            * &lt;div id="dlg"&gt;
            *   &lt;div&gt;
            *       10% of battery remaining
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function(){
            *   $("#dlg").ejmDialog({ enableAutoOpen: true, checkDOMChanges: true });
            * });
            * &lt;/script&gt;	
            * @example 
            * &lt;script&gt;
            * //Get or set the Dialog checkDOMChanges, after initialization:<br>
            * // Get the checkDOMChanges API value.	
            *  $("#dlg").ejmDialog ("option", "checkDOMChanges");			
            * // Set the checkDOMChanges API
            * $("#dlg").ejmDialog ("option", "checkDOMChanges", true); 
            * &lt;/script&gt;
            * @memberof ejmDialog
            * @instance
            */
            checkDOMChanges: false,
            /**		
            * Specifies ID of the element contains template contents.
            * @default null
            * @type {string}
            * @example 
            * //Set the templateId property in unobtrusive way.
            * &lt;div id="dlg" data-role="ejmdialog" data-ej-templateid="temp" data-ej-enableautoopen="true" &gt;
            * &lt;/div&gt;
            * &lt;div id="temp" &gt;
            * 10% of battery remaining
            * &lt;/div&gt;
            * @example 
            * // Set templateId on initialization. 
            * //To set templateId API value '
            * &lt;div id="dlg" &gt;
            * &lt;script&gt;
            * $(function(){
            * $("#dlg").ejmDialog({ enableAutoOpen:true, templateId: "temp" });
            * });
            * &lt;/script&gt;	
            * &lt;div id="temp" &gt;
            * 10% of battery remaining
            * &lt;/div&gt;			
            * @example 
            * &lt;script&gt;
            * //Get or set the Dialog templateId, after initialization:<br>
            * // Get the templateId API value.	
            *  $("#dlg").ejmDialog ("option", "templateId");			
            * // Set the templateId API
            * $("#dlg").ejmDialog ("option", "templateId", "temp");       
            * &lt;/script&gt;
            * @memberof ejmDialog
            * @instance
            */
            templateId: null,
            /**		
            * Specifies the target height.
            * @default null
            * @type {string}
            * @example 
            * //Set the targetHeight property in unobtrusive way.
            * &lt;div id="dlg" data-role="ejmdialog" data-ej-targetheight="500" data-ej-enableautoopen="true" &gt;
            * &lt;div&gt;
            * 10% of battery remaining
            * &lt;/div&gt;
            * &lt;/div&gt;
            * @example 
            * // Set targetHeight on initialization. 
            * //To set targetHeight API value 
            * &lt;div id="dlg"&gt;
            *   &lt;div&gt;
            *       10% of battery remaining
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function(){
            *   $("#dlg").ejmDialog({ enableAutoOpen: true, targetHeight: 500 });
            * });
            * &lt;/script&gt;		
            * @example 
            * &lt;script&gt;
            * //Get or set the Dialog targetHeight, after initialization:<br>
            * // Get the targetHeight API value.	
            *  $("#dlg").ejmDialog ("option", "targetHeight");			
            * // Set the targetHeight API
            * $("#dlg").ejmDialog ("option", "targetHeight", 500);   
            * &lt;/script&gt;
            * @memberof ejmDialog
            * @instance
            */
            targetHeight: null,
            /**		
            * Specifies to maintain the current model value to browser cookies for state maintenance. While refresh the page, the model value will get apply to the control from browser cookies.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the enablePersistence property in unobtrusive way.
            * &lt;div id="dlg" data-role="ejmdialog" data-ej-enablepersistence="true" data-ej-enableautoopen="true" &gt;
            * &lt;div&gt;
            * 10% of battery remaining
            * &lt;/div&gt;
            * &lt;/div&gt;
            * @example 
            * // Set enablePersistence on initialization. 
            * //To set enablePersistence API value 
            * &lt;div id="dlg"&gt;
            *   &lt;div&gt;
            *       10% of battery remaining
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function(){
            *   $("#dlg").ejmDialog({ enableAutoOpen: true, enablePersistence: true });
            * });
            * &lt;/script&gt;		
            * @example 
            * &lt;script&gt;
            * //Get or set the Dialog enablePersistence, after initialization:<br>
            * // Get the enablePersistence API value.	
            *  $("#dlg").ejmDialog ("option", "enablePersistence");			
            * // Set the enablePersistence API
            * $("#dlg").ejmDialog ("option", "enablePersistence", true);    
            * &lt;/script&gt;
            * @memberof ejmDialog
            * @instance
            */
            enablePersistence: false,
            /**		
            * Enables or Disables animation effect on opening or closing the dialog.
            * @default true
            * @type {boolean}
            * @example 
            * //Set the enableAnimation property in unobtrusive way.
            * &lt;div id="dlg" data-role="ejmdialog" data-ej-enableanimation="false" &gt;
            * &lt;div&gt;
            * 10% of battery remaining
            * &lt;/div&gt;
            * &lt;/div&gt;
            * @example 
            * // Set enableAnimation on initialization. 
            * //To set enableAnimation API value 
            * &lt;div id="dlg"&gt;
            *   &lt;div&gt;
            *       10% of battery remaining
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function(){
            *   $("#dlg").ejmDialog({ enableAnimation: false });
            * });
            * &lt;/script&gt;		
            * @example 
            * &lt;script&gt;
            * //Get or set the Dialog enableAnimation, after initialization:<br>
            * // Get the enableAnimation API value.	
            *  $("#dlg").ejmDialog ("option", "enableAnimation");			
            * // Set the enableAnimation API
            * $("#dlg").ejmDialog ("option", "enableAnimation", true);    
            * &lt;/script&gt;
            * @memberof ejmDialog
            * @instance
            */
            enableAnimation: true,
            /**     
            * Section for windows mode specific functionalities.                      
            * @memberof ejmDialog
            * @instance
            */
            windows: {
                /**  
                * Specifies whether to render control based on the windowsphone's current accent color and device theme.
                * @default false
                * @type {boolean}
                * @alias ejmDialog#windows->renderDefault
                * @example 
                * // Set the windows mode renderDefault property in unobtrusive way.
                * &lt;div id="dlg" data-role="ejmdialog" data-ej-rendermode="windows" data-ej-windows-renderDefault=true data-ej-enableautoopen="true" &gt;
                * &lt;div&gt;
                * 10% of battery remaining
                * &lt;/div&gt;
                * &lt;/div&gt;            
                * @example 
                * // To set windows mode renderDefault property API value 
                * &lt;div id="dlg"&gt;
                *   &lt;div&gt;
                *       10% of battery remaining
                *   &lt;/div&gt;
                * &lt;/div&gt;
                * &lt;script&gt;
                * $(function(){
                *   $("#dlg").ejmDialog({ renderMode:"windows", enableAutoOpen: true, windows:{renderDefault: true}});
                * });
                * &lt;/script&gt;
                * @example 
                * &lt;script&gt;
                * // Get or set the windows mode renderDefault API, after initialization:
                * // Get the windows mode renderDefault value  
                * $("#dlg").ejmDialog("option", "windows.renderDefault");   
                * // Set the windows mode renderDefault value 
                * $("#dlg").ejmDialog("option", "windows.renderDefault", true); 
                * &lt;/script&gt;
                * @memberof ejmDialog
                * @instance
                */
                "renderDefault": false
            }
        },
        // Datatypes of model variables
        dataTypes: {
            enableAutoOpen: "boolean",
            renderMode: "enum",
            enableModal: "boolean",
            allowScrolling: "boolean",
            showButtons: "boolean",
            checkDOMChanges: "boolean",
            mode: "enum",
            enablePersistence: "boolean",
            enableAnimation: "boolean"
        },
        // constructor function
        /**
        * Create the dialog widget
        * @private
        */
        _init: function () {
            this.id = this.element.attr("id");
            this._browser = ej.browser();
            this._body = App.activePage;
            ej.setRenderMode(this);
            ej.setTheme(this);
            if (this.model.renderMode == "windows" && this.model.windows.renderDefault && ej.isMobile())
                this.model.theme = "default";
            this._orgEle = this.element.clone();
            this._renderControl();
            this._createDelegates();
            this._wireEvents();
        },
        // To render Dialog control
        /**
        * To render Dialog control
        * @private
        */
        _renderControl: function () {
            this.element.addClass("e-m-" + this.model.renderMode + " e-m-dialog e-m-user-select e-m-" + this.model.theme + "");
            if (this.model.templateId && ej.getCurrentPage().find("#" + this.model.templateId).length) {
                var templateContent = ej.getCurrentPage().find("#" + this.model.templateId);
                this._template = templateContent;
                ej.destroyWidgets(this._template);
                this._html = templateContent[0].nodeName && templateContent[0].nodeName.toLowerCase() == "script" ? ej.getClearString(templateContent[0].innerHTML) : templateContent;
            }
            else
                this._html = this.model.templateId ? this._template : this.element.html();
            this.element.empty();
            if (this.model.buttonTap && this.model.buttonTap.name)
                this.model.buttonTap = this.model.buttonTap.name;
            this["_" + this.model.mode + "Type"]();
            this._dialogInit();
        },
        /**
        * To render confirm type Dialog control
        * @private
        */
        _confirmType: function () {
            this._renderConfirmAlertDialog();
        },
        /**
        * To render alert type Dialog control
        * @private
        */
        _alertType: function () {
            this._renderConfirmAlertDialog();
        },
        /**
        * To render normal type Dialog control
        * @private
        */
        _normalType: function () {
            this._renderNormalDialog();
        },
        /**
        * To render fullview type Dialog control
        * @private
        */
        _fullviewType: function () {
            this._renderFullViewDialog();
        },
        // To render confirm and alert Dialog control
        /**
        * To render Confirm and Alert mode Dialog control
        * @private
        */
        _renderConfirmAlertDialog: function () {
            this.element.addClass("e-m-dlg-table");
            this._outerDiv = ej.buildTag("div.e-m-dlg-table-cell");
            this._innerDiv = ej.buildTag("div.e-m-dlg e-m-dlg-inner e-m-dlg-alert e-m-" + this.model.theme + "");
            if (this.model.enableAnimation)
                this.model.enableAutoOpen ? this._innerDiv.addClass("e-m-dlg-showanimate e-m-dlg-open") : this._innerDiv.addClass("e-m-dlg-hideanimate");
            else if (this.model.enableAutoOpen)
                this._innerDiv.addClass("e-m-dlg-open");
            this._contDiv = ej.buildTag("div.e-m-dlg-content");
            var hdr = ej.buildTag("div.e-m-dlg-title", this.model.title);
            this._contDiv.append(hdr);
            this._templateDiv = ej.buildTag("div#" + this.id + "content.e-m-dlg-desc");
            this._contDiv.append(this._templateDiv.html(this._html));
            if (this.model.showButtons)
                this._renderDialogButton();
            else
                this._innerDiv.append(this._contDiv);
            ej.widget.init(this._innerDiv);
            this.element.append(this._outerDiv.append(this._innerDiv));
            if (this.model.allowScrolling)
                this._scroll();
        },
        // To render normal Dialog control        
        /**
        * To render Normal mode Dialog control
        * @private
        */
        _renderNormalDialog: function () {
            this.element.addClass("e-m-dlg-table");
            this._outerDiv = ej.buildTag("div").css({ "display": "table-cell" });
            this._innerDiv = ej.buildTag("div.e-m-dlg-inner e-m-" + this.model.theme + " e-m-dlg e-m-dlg-normal");
            if (this.model.mode == "fullview")
                this._innerDiv.addClass("e-m-dlgfullview");
            if (this.model.enableAutoOpen)
                this._innerDiv.addClass("e-m-dlg-open");
            this.header = ej.buildTag("div#" + this.id + "header", {}, {}, {
                "data-role": "ejmheader", "data-ej-title": this.model.title,
                "data-ej-rendermode": this.model.renderMode, "data-ej-theme": this.model.theme, "data-ej-position": "normal"
            });
            if (this.model.showButtons)
                this.model.renderMode == "ios7" ? this._header() : this._headerTemplate();
            this._innerDiv.append(this.header);
            this._content = ej.buildTag("div#" + this.id + "content.e-m-dlg-content");
            this._content.html(this._html);
            this._innerDiv.append(this._content);
            ej.widget.init(this._innerDiv);
            this.element.append(this._outerDiv.append(this._innerDiv));
            this._headerHeight = this.element.find(".e-m-header").outerHeight();
            this._height = window.innerHeight - (this._headerHeight + 20);
            this._content.height(this._height);
            this._scrollWrapper = ej.buildTag("div#" + this.id + "_scroll");
            this._content.append(this._scrollWrapper);
            this._scrollPanel();
        },
        /**
        * To render FullView Dialog control
        * @private
        */
        _renderFullViewDialog: function () {
            this.model.renderMode == "ios7" ? this._renderNormalDialog() : this._fullViewDialog();
        },
        /**
        * To add scrolling behaviour for Dialog content
        * @private
        */
        _scroll: function () {
            this._scrollWrapper = ej.buildTag("div#" + this.id + "_scroll");
            this._templateDiv.append(this._scrollWrapper);
            this._height = ej.getDimension(this._templateDiv, "outerHeight");
            this._titHeight = ej.getDimension(this.element.find(".e-m-dlg-title"), "outerHeight");
            this._btnHeight = ej.getDimension(this.element.find(".e-m-dlg-btn"), "outerHeight");
            this._dlgScrollHeight = this.model.targetHeight ? this.model.targetHeight : window.innerHeight - (this._titHeight + this._btnHeight + 50);
            if (this._height > this._dlgScrollHeight) {
                this._templateDiv.height(this._dlgScrollHeight);
                this._scrollPanel();
            }
        },
        /**
        * To render scrollPanel for dialog contents
        * @private
        */
        _scrollPanel: function () {
            this._scrollWrapper.ejmScrollPanel({ "target": this.id + "content", "targetHeight": this._dlgScrollHeight, "checkDOMChanges": this.model.checkDOMChanges, "enableHrScroll": false, "enableVerScroll": true, "renderMode": this.model.renderMode, "enableNativeScrolling": this.model.enableNativeScrolling });
        },
        /**
        * To render header
        * @private
        */
        _header: function () {
            this.header.attr({
                "data-ej-leftbuttoncaption": this.model.leftButtonCaption, "data-ej-rightbuttoncaption": this.model.rightButtonCaption,
                "data-ej-leftbuttonstyle": "header", "data-ej-showleftbutton": "true", "data-ej-showrightbutton": "true"
            });
            if (this.model.buttonTap)
                this.header.attr({ "data-ej-leftbuttontap": this.model.buttonTap, "data-ej-rightbuttontap": this.model.buttonTap });
        },
        /**
        * To render header template 
        * @private
        */
        _headerTemplate: function () {
            var divOk = ej.buildTag("div.e-m-norbtnok");
            var divCancel = ej.buildTag("div.e-m-norbtncancel");
            var btnOk = ej.buildTag("input#btnok", {}, {}, {
                "type": "button",
                "data-role": "ejmbutton", "data-ej-text": this.model.leftButtonCaption,
                "data-ej-rendermode": this.model.renderMode, "data-ej-inline": "true", "data-ej-theme": this.model.theme, "windows": { "renderDefault": this.model.windows.renderDefault }
            });
            var btnCancel = ej.buildTag("input#btncancel", {}, {}, {
                "type": "button",
                "data-role": "ejmbutton", "data-ej-text": this.model.rightButtonCaption,
                "data-ej-rendermode": this.model.renderMode, "data-ej-inline": "true", "data-ej-theme": this.model.theme, "windows": { "renderDefault": this.model.windows.renderDefault }
            });
            if (this.model.buttonTap) {
                btnOk.attr({ "data-ej-touchend": this.model.buttonTap });
                btnCancel.attr({ "data-ej-touchend": this.model.buttonTap });
            }
            divOk.append(btnOk);
            divCancel.append(btnCancel);
            this.header.append(divOk).append(divCancel);
        },
        /**
        * To render Fullview Dialog Control 
        * @private
        */
        _fullViewDialog: function () {
            this._innerDiv = ej.buildTag("div.e-m-dlg e-m-" + this.model.theme + " e-m-dlg-open e-m-dlgfullview");
            this._contDiv = ej.buildTag("div.e-m-dlg-content");
            var hdr = ej.buildTag("div.e-m-dlg-title", this.model.title);
            this._contDiv.append(hdr);
            this._templateDiv = ej.buildTag("div#" + this.id + "content.e-m-dlg-desc");
            this._contDiv.append(this._templateDiv.html(this._html));
            if (this.model.showButtons) {
                var btn = ej.buildTag("div.e-m-dlg-btn");
                var btnCtrl = ej.buildTag("input", {}, {}, { "type": "button" });
                btn.append(btnCtrl);
                var style = (this.model.renderMode == "windows") ? "normal" : "dialog";
                this._renderButton(btnCtrl, this.model.leftButtonCaption, this.id + "_left", style);
                var btnBCtrl = ej.buildTag("input", {}, {}, { "type": "button" });
                btn.append(btnBCtrl);
                this._renderButton(btnBCtrl, this.model.rightButtonCaption, this.id + "_right", style);
                this._innerDiv.append(this._contDiv.append(btn));
            }
            this._innerDiv.append(this._contDiv);
            ej.widget.init(this._innerDiv);
            this.element.append(this._innerDiv);
            this._scrollWrapper = ej.buildTag("div#" + this.id + "_scroll");
            this._templateDiv.append(this._scrollWrapper);
            this._fullTitHeight = this.element.find(".e-m-dlg-title").outerHeight();
            this._fullBtnHeight = this.element.find(".e-m-dlg-btn").outerHeight();
            var height = this.model.targetHeight ? this.model.targetHeight : window.innerHeight - (this._fullTitHeight + this._fullBtnHeight + 20);
            this._templateDiv.height(height);
            this._scrollPanel();
            this._scrollWrapper.ejmScrollPanel({ "targetHeight": height });
        },
        /**
        * To render Dialog Buttons 
        * @private
        */
        _renderDialogButton: function () {
            var btn = ej.buildTag("div.e-m-dlg-btn");
            if (this.model.mode == "alert")
                btn.addClass("e-m-alert");
            var btnCtrl = ej.buildTag("input", {}, {}, { "type": "button" });
            btn.append(btnCtrl);
            var style = (this.model.renderMode == "windows") ? "normal" : "dialog";
            this._renderButton(btnCtrl, this.model.leftButtonCaption, this.id + "_left", style);
            if (this.model.mode == "confirm") {
                var btnBCtrl = ej.buildTag("input", {}, {}, { "type": "button" });
                btn.append(btnBCtrl);
                this._renderButton(btnBCtrl, this.model.rightButtonCaption, this.id + "_right", style);
            }
            this._innerDiv.append(this._contDiv.append(btn));
        },
        // To render Dialog button 
        /**
        * To render Buttons 
        * @private
        */
        _renderButton: function (ctrl, text, id, style) {
            if (this.model.renderMode != "flat")
                ctrl.attr("data-ej-theme", this.model.theme);
            ctrl.attr({
                "data-role": "ejmbutton", "data-ej-text": text, "id": id + "_btn", "data-ej-rendermode": this.model.renderMode, "data-ej-touchend": this.model.buttonTap, "windows": { "renderDefault": this.model.windows.renderDefault }
            }).attr("data-ej-" + this.model.renderMode + "-style", style);
        },
        /**
        * To init Dialog control
        * @private
        */
        _dialogInit: function () {
            if (this.element.parents("form").length > 0)
                this.element.appendTo(this.element.parents("form"));
            else
                this.element.appendTo(App.activePage);
            if (this.model.enableModal && this.model.mode != "fullview")
                this._setModal();
            if (!this.model.enableAutoOpen) {
                this.element.css("display", "none");
                this._body.find("#" + this.id + "_dialog_overlay").css("display", "none");
            }
            this._setDialogPosition();
        },
        // Dialog control events
        /**
        * To wire Dialog events 
        * @private
        */
        _createDelegates: function () {
            this._resizeHandler = $.proxy(this._onResize, this);
        },
        _wireEvents: function (remove) {
            var evt = !ej.isTouchDevice() ? "resize" : "orientationchange";
            ej.listenEvents([window], [evt], [this._resizeHandler], remove);
        },
        /**
        * Dialog resize events 
        * @private
        */
        _onResize: function () {
            var proxy = this;
            window.setTimeout(function () {
                proxy._setDialogPosition();
                proxy.element.css({ "z-index": ej.getMaxZindex() + 1 });
            }, ej.isAndroid() ? 250 : 0);
        },
        /**
        * To set Dialog Position
        * @private
        */
        _setDialogPosition: function () {
            if (!$(this.element).is(":visible"))
                return;
            if (this.model.mode == "normal" || (this.model.mode == "fullview" && this.model.renderMode == "ios7")) {
                this._height = window.innerHeight - (this._headerHeight + 20);
                this._content.height(this._height);
            }
            else if (this.model.mode == "fullview" && this.model.renderMode != "ios7") {
                var height = this.model.targetHeight ? this.model.targetHeight : window.innerHeight - (this._fullTitHeight + this._fullBtnHeight + 20);
                this.element.find(".e-m-dlg-desc").height(height);
                this._scrollWrapper.ejmScrollPanel({ "targetHeight": height });
            }
            else {
                var height = this.model.targetHeight ? this.model.targetHeight : window.innerHeight - (this._titHeight + this._btnHeight + 50);
                if (this._height > height) {
                    this._templateDiv.height(height);
                    this._scrollPanel();
                    this._scrollWrapper.ejmScrollPanel({ "targetHeight": height });
                }
            }
        },
        /**
        * To render enableModal Dialog 
        * @private
        */
        _setModal: function () {
            var overlayDiv = this._body.find("#" + this.id + "_dialog_overlay");
            if (overlayDiv == null || overlayDiv.length <= 0)
                overlayDiv = ej.buildTag("div#" + this.id + "_dialog_overlay.e-m-" + this.model.renderMode + " e-m-overlay");
            this._body.append(overlayDiv);
        },
        /**
        * To refresh Dialog control		
        * @private
        */
        _refresh: function () {
            this._destroy();
            this._renderControl();
            this._wireEvents(false);
        },
        /**
        * To destroy Dialog control		
        * @private
        */
        _destroy: function () {
            this.element.removeAttr("class");
            if (this.model.enableModal)
                this._body.find("#" + this.id + "_dialog_overlay").remove();
            this.element.html(this._orgEle.html());
        },
        /**
        * To configure the properties at runtime using SetModel		
        * @private
        */
        _setModel: function (options) {
            var refresh = false;
            for (var prop in options) {
                var setModel = "_set" + prop.charAt(0).toUpperCase() + prop.slice(1);
                if (this[setModel])
                    this[setModel]();
                else
                    refresh = true;
            }
            if (refresh)
                this._refresh();
        },
        /**
        * To configure the RenderMode properties at runtime using SetModel		
        * @private
        */
        _setRenderMode: function () {
            this._refresh();
        },
        /**
        * To configure the Theme properties at runtime using SetModel		
        * @private
        */
        _setTheme: function () {
            this.element.removeClass("e-m-dark e-m-light").addClass("e-m-" + this.model.theme + "");
            this.element.find(".e-m-dlg-open").removeClass("e-m-dark e-m-light").addClass("e-m-" + this.model.theme + "");
            this.element.find(".e-m-dlg-btn").find(".e-m-btn").ejmButton({ "theme": this.model.theme });
            this.element.find(".e-m-header").ejmHeader({ "theme": this.model.theme });
            this.element.find(".e-m-header").find(".e-m-btn").ejmButton({ "theme": this.model.theme });
            this.element.find(".e-m-scrollpanel").ejmScrollPanel({ "theme": this.model.theme });
        },
        /**
        * To configure the Mode properties at runtime using SetModel		
        * @private
        */
        _setMode: function () {
            this._refresh();
        },
        /**
        * To configure the Title properties at runtime using SetModel		
        * @private
        */
        _setTitle: function () {
            if (this.element.children().hasClass("e-m-header"))
                this.element.find(".e-m-header").ejmHeader({ "title": this.model.title });
            else
                this.element.find(".e-m-dlg-title").html(this.model.title);
        },
        /**
        * To configure the Modal properties at runtime using SetModel		
        * @private
        */
        _setEnableModal: function () {
            if (this.model.enableModal && this.model.enableAutoOpen && this.model.mode != "fullview")
                this._setModal();
            else
                this._body.find("#" + this.id + "_dialog_overlay").remove();
        },
        /**
        * To configure the ShowButton properties at runtime using SetModel		
        * @private
        */
        _setShowButtons: function () {
            this._refresh();
        },
        /**
        * To configure the ButtonTap properties at runtime using SetModel		
        * @private
        */
        _setButtonTap: function () {
            this.element.find(".e-m-btn").ejmButton({ "touchEnd": this.model.buttonTap });
        },
        /**
        * To configure the BeforeClose properties at runtime using SetModel		
        * @private
        */
        _setBeforeClose: function () {
        },
        /**
        * To configure the Close properties at runtime using SetModel		
        * @private
        */
        _setClose: function () {
        },
        /**
        * To configure the Open properties at runtime using SetModel		
        * @private
        */
        _setOpen: function () {
        },


        /*---------------Public Methods---------------*/
        /**
        * To open the dialog
        * @return jQuery       
        * @example 
        * &lt;div id="dlg" data-role="ejmdialog" data-ej-enableautoopen="true"&gt;
        * &lt;div&gt;
        * 10% of battery remaining
        * &lt;/div&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // To check whether the dialog is opened or not
        *   $(function(){
        *   var dialog = $("#dlg").data("ejmDialog");
        *   dialog.open(); 
        * });
        * &lt;/script&gt;
        * @example 
        * &lt;div id="dlg" data-role="ejmdialog" &gt;
        * &lt;div&gt;
        * 10% of battery remaining
        * &lt;/div&gt;
        * &lt;/div&gt;
        * // To open dialog control
        * &lt;script&gt;
        * $(function(){
        * $("#dlg").ejmDialog("open");
        * });
        * &lt;/script&gt;
        * @memberof ejmDialog
        * @instance
        */
        open: function () {
            var proxy = this;
            this.element.css("display", "table");
            this.element.css({ "z-index": ej.getMaxZindex() + 1 });
            if (this.model.enableModal && this.model.mode != "fullview")
                this._body.find("#" + this.id + "_dialog_overlay").css("display", "block");
            this.model.enableAnimation ? this._innerDiv.removeClass("e-m-dlg-hideanimate").addClass("e-m-dlg-showanimate e-m-dlg-open") : this._innerDiv.addClass("e-m-dlg-open");
            var data = { "title": this.model.title };
            if (this._templateDiv) {
                this._templateDiv[0].scrollTop = 0;
                this._templateDiv[0].scrollLeft = 0;
            }
            if (this.model.allowScrolling && this._scrollWrapper.length > 0 && this._scrollWrapper.data("ejmScrollPanel")) {
                setTimeout(function () {
                    proxy._scrollWrapper.ejmScrollPanel('refresh');
                }, 350);
            }
            if (this.model.open)
                this._trigger("open", data);
        },

        /**
        * To close the dialog.
        * @return jQuery       
        * @example 
        * &lt;div id="dlg" data-role="ejmdialog" data-ej-enableautoopen="true"&gt;
        * &lt;div&gt;
        * 10% of battery remaining
        * &lt;/div&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // To check whether the dialog is opened or not
        *   $(function(){
        *   var dialog = $("#dlg").data("ejmDialog");
        *   dialog.close(); 
        * });
		* &lt;/script&gt;
        * @example 
        * &lt;div id="dlg" data-role="ejmdialog" data-ej-enableautoopen="true"&gt;
        * &lt;div&gt;
        * 10% of battery remaining
        * &lt;/div&gt;
        * &lt;/div&gt;
        * // To close dialog control
        * &lt;script&gt;
        * $(function(){
        * $("#dlg").ejmDialog("close");
        * });
        * &lt;/script&gt;
        * @memberof ejmDialog
        * @instance
        */
        close: function () {
            var data = { "title": this.model.title };
            if (this.model.beforeClose)
                this._trigger("beforeClose", data);
            if (this.model.enableModal && this.model.mode != "fullview")
                this._body.find("#" + this.id + "_dialog_overlay").css("display", "none");
            this.model.enableAnimation ? this._innerDiv.removeClass("e-m-dlg-showanimate e-m-dlg-open").addClass("e-m-dlg-hideanimate") : this._innerDiv.removeClass("e-m-dlg-open");
            this.element.css("display", "none");
            if (this.model.close)
                this._trigger("close", data);
        },
        /**
        * To check whether the dialog is opened.
        * @return jQuery       
        * @example 
        * &lt;div id="dlg" data-role="ejmdialog" data-ej-enableautoopen="true"&gt;
        * &lt;div&gt;
        * 10% of battery remaining
        * &lt;/div&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // To check whether the dialog is opened or not
        *   $(function(){
        *   var dialog = $("#dlg").data("ejmDialog");
        *   dialog.isOpened(); 
        * });
		* &lt;/script&gt;
        * @example 
        * &lt;div id="dlg" data-role="ejmdialog" data-ej-enableautoopen="true"&gt;
        * &lt;div&gt;
        * 10% of battery remaining
        * &lt;/div&gt;
        * &lt;/div&gt;
        * // To check whether the dialog is opened or not
        * &lt;script&gt;
        * $(function(){
        * $("#dlg").ejmDialog("isOpened");
        * });
        * &lt;/script&gt;
        * @memberof ejmDialog
        * @instance
        */
        isOpened: function () {
            return $(this.element).is(":visible") ? true : false;
        }
        /*---------------Public Methods End---------------*/
    });
    /**
    * Enum for mode
    * @enum {string}
    * @global
    */
    ej.mobile.Dialog.Mode = {
        /**
        Enum for alert mode dialog*/
        Alert: "alert",
        /**
        Enum for confirm mode dialog*/
        Confirm: "confirm",
        /**
        Enum for normal mode dialog*/
        Normal: "normal",
        /**
        Enum for fullview mode dialog*/
        FullView: "fullview"
    }
})(jQuery, Syncfusion);