/**
* @fileOverview Plugin to style the Html Editor elements
* @copyright Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/

(function ($, ej, undefined) {
    // ejmEditor is the plugin name 
    // "ej.mobile.Editor" is "namespace.className" will hold functions and properties
    /**
    * @namespace ej
    * @class ejmNumeric
    * @requires jQuery
    * @requires ej.mobile.application
    * @requires ej.core
    * @requires ej.unobtrusive
    * @requires ej.mobile.core
    * @requires ej.data
    * @requires ej.touch
    * @classdesc Custom Design for Html Editor control.
    * @example 
    * // Create editor control in unobtrusive way.
    * &lt;input type="number" id="editor" data-role="ejmnumeric" /&gt;<br>
    * @example 
    * // Create editor control in obtrusive way.
    * &lt;input id="editor" type="number"/&gt;<br>
    * &lt;script&gt;
    * $("#editor").ejmNumeric();
    * &lt;/script&gt;
    */
    ej.widget({ "ejmNumeric": "ej.mobile.Numeric" }, {
        _setFirst: true,
        _rootCSS: "e-m-editor-input",
        type: "editor",
        // default model
        defaults: {
            /**		
            * Specifies the rendering mode of the control. See {@link RenderMode}
            * @default auto
            * @type {enum}
            * @example 
            * //Set the renderMode property in unobtrusive way.
            * &lt;input type="number" id="editor" data-role="ejmnumeric" data-ej-renderMode="auto" /&gt;<br>
            * @example 
            * // Set rendermode on initialization. 
            * //To set renderMode API value 
            * &lt;input type="number" id="editor" /&gt;<br>
            * &lt;script&gt;<br>
            * $(document).ready(function(){
            * $("#editor").ejmNumeric ({ renderMode: "auto" });
            * });
            * &lt;/script&gt;<br>
            * @example
            * &lt;script&gt;
            * //Get or set the rendermode after initialization:<br>
            * // Get the renderMode API value.		
            *  $("#editor").ejmNumeric ("option", "renderMode");			
            * // Set the renderMode API
            * $("#editor").ejmNumeric ("option", "renderMode", ej.mobile.RenderMode.Auto);
            * &lt;/script&gt;
            * @memberof ejmNumeric
            * @instance
            */
            renderMode: "auto",
            /**		
            * Specifies whether to show the spin button for incremention and decremention of the value.
            * @default true
            * @type {boolean}
            * @example 
            * //Set the showSpinButton property in unobtrusive way.
            * &lt;input type="number" id="editor" data-role="ejmnumeric" data-ej-showSpinButton="true" /&gt;<br>
            * @example 
            * // Set showSpinButton on initialization. 
            * //To set showSpinButton API value 
            * &lt;input type="number" id="editor" /&gt;<br>
            * &lt;script&gt;<br>
            * $(document).ready(function(){
            * $("#editor").ejmNumeric ({ showSpinButton: false });
            * });
            * &lt;/script&gt;<br>
            * @example 
            * &lt;script&gt;
            * //Get or set the showSpinButton, after initialization:<br>
            * // Get the showSpinButton API value.		
            *  $("#editor").ejmNumeric ("option", "showSpinButton");			
            * // Set the showSpinButton API
            * $("#editor").ejmNumeric ("option", "showSpinButton", true);
            * &lt;/script&gt;
            * @memberof ejmNumeric
            * @instance
            */
            showSpinButton: true,
            /**		
            * Specifies whether to show the border in the control.
            * @default true
            * @type {boolean}
            * @example 
            * //Set the showBorder property in unobtrusive way.
            * &lt;input type="number" id="editor" data-role="ejmnumeric" data-ej-showborder="true" /&gt;<br>
            * @example 
            * // Set showBorder on initialization. 
            * //To set showBorder API value 
            * &lt;input type="number" id="editor" /&gt;<br>
            * &lt;script&gt;<br>
            * $(document).ready(function(){
            * $("#editor").ejmNumeric ({ showBorder: false });
            * });
            * &lt;/script&gt;<br>
            * @example 
            * &lt;script&gt;
            * //Get or set the showBorder, after initialization:<br>
            * // Get the showBorder API value.		
            *  $("#editor").ejmNumeric ("option", "showBorder");			
            * // Set the showBorder API
            * $("#editor").ejmNumeric ("option", "showBorder", true);
            * &lt;/script&gt;
            * @memberof ejmNumeric
            * @instance
            */
            showBorder: true,
            /**		
            * Specifies the decimal places to set the decimal(floating point) numbers.
            * @default 0
            * @type {number}
            * @example 
            * //Set the decimalPlaces property in unobtrusive way.
            * &lt;input type="number" id="editor" data-role="ejmnumeric" data-ej-decimalPlaces="2" /&gt;<br>
            * @example 
            * // Set decimalPlaces on initialization. 
            * //To set decimalPlaces API value 
            * &lt;input type="number" id="editor" /&gt;<br>
            * &lt;script&gt;<br>
            * $(document).ready(function(){
            * $("#editor").ejmNumeric ({ decimalPlaces: 2 });
            * });
            * &lt;/script&gt;<br>
            * @example 
            * &lt;script&gt;
            * //Get or set the decimalPlaces, after initialization:<br>
            * // Get the decimalPlaces API value.		
            *  $("#editor").ejmNumeric ("option", "decimalPlaces");			
            * // Set the decimalPlaces API
            * $("#editor").ejmNumeric ("option", " ", 2);     
            * &lt;/script&gt;
            * @memberof ejmNumeric
            * @instance
            */
            decimalPlaces: 0,
            /**		
            * Specifies whether to restrict entering the values outside the defined range.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the enableStrictMode property in unobtrusive way.
            * &lt;input type="number" id="editor" data-role="ejmnumeric" data-ej-minValue=0 data-ej-maxValue=100 data-ej-enableStrictMode="true" /&gt;<br>
            * @example 
            * // Set enableStrictMode on initialization. 
            * //To set enableStrictMode API value 
            * &lt;input type="number" id="editor" /&gt;<br>
            * &lt;script&gt;<br>
            * $(document).ready(function(){
            * $("#editor").ejmNumeric ({ maxValue: 100 , minValue: 0 , enableStrictMode: true });
            * });
            * &lt;/script&gt;<br>
            * @example 
            * &lt;script&gt;
            * //Get or set the enableStrictMode, after initialization:<br>
            * // Get the enableStrictMode API value.		
            *  $("#editor").ejmNumeric ("option", "enableStrictMode");			
            * // Set the enableStrictMode API
            * $("#editor").ejmNumeric ("option", "enableStrictMode", true);
            * &lt;/script&gt;
            * @memberof ejmNumeric
            * @instance
            */
            enableStrictMode: false,
            /**		
            * Specifies the step value for incrementation.
            * @default 1
            * @type {number}
            * @example 
            * //Set the incrementStep property in unobtrusive way.
            * &lt;input type="number" id="editor" data-role="ejmnumeric" data-ej-incrementStep="3" /&gt;<br>
            * @example 
            * // Set incrementStep on initialization. 
            * //To set incrementStep API value 
            * &lt;input type="number" id="editor" /&gt;<br>
            * &lt;script&gt;<br>
            * $(document).ready(function(){
            * $("#editor").ejmNumeric ({ incrementStep: 3 });
            * });
            * &lt;/script&gt;<br>
            * @example
            * &lt;script&gt;
            * //Get or set the incrementStep, after initialization:<br>
            * // Get the incrementStep API value.		
            *  $("#editor").ejmNumeric ("option", "incrementStep");			
            * // Set the incrementStep API
            * $("#editor").ejmNumeric ("option", "incrementStep", 3);
            * &lt;/script&gt;
            * @memberof ejmNumeric
            * @instance
            */
            incrementStep: 1,
            /**		
            * Specifies the value of the editor.
            * @default 0
            * @type {number}
            * @example 
            * //Set the value property in unobtrusive way.
            * &lt;input type="number" id="editor" data-role="ejmnumeric" data-ej-value="100" /&gt;<br>
            * @example 
            * // Set value on initialization. 
            * //To set value API value 
            * &lt;input type="number" id="editor" /&gt;<br>
            * &lt;script&gt;<br>
            * $(document).ready(function(){
            * $("#editor").ejmNumeric ({ value: 100 });
            * });
            * &lt;/script&gt;<br>
            * @example
            * &lt;script&gt;
            * //Get or set the value, after initialization:<br>
            * // Get the value API value.		
            *  $("#editor").ejmNumeric ("option", "value");			
            * // Set the value API
            * $("#editor").ejmNumeric ("option", "value", 100);
            * &lt;/script&gt;
            * @memberof ejmNumeric
            * @instance
            */
            value: null,
            /**		
            * Specifies the name of the control.
            * @default Sets id as name if it is null.
            * @type {string}
            * @example 
            * //Set the name property in unobtrusive way.
            * &lt;input type="number" id="editor" data-role="ejmnumeric" data-ej-name="numeric" /&gt;<br>
            * @example 
            * // Set name on initialization. 
            * //To set name API value 
            * &lt;input type="number" id="editor" /&gt;<br>
            * &lt;script&gt;<br>
            * $(document).ready(function(){
            * $("#editor").ejmNumeric ({ name: "numeric" });
            * });
            * &lt;/script&gt;<br>
            * @example
            * &lt;script&gt;
            * //Get or set the name, after initialization:<br>
            * // Get the name API value.		
            *  $("#editor").ejmNumeric ("option", "name");			
            * // Set the name API
            * $("#editor").ejmNumeric ("option", "name", "numeric");
            * &lt;/script&gt;
            * @memberof ejmNumeric
            * @instance
            */
            name: null,
            /**		
            * Specifies to maintain the current model value to browser cookies for state maintenance. While refresh the page, the model value will get apply to the control from browser cookies.
            * @default fasle
            * @type {boolean}
            * @example 
            * //Set the enablePersistence property in unobtrusive way.
            * &lt;input type="number" id="editor" data-role="ejmnumeric" data-ej-value=100 data-ej-enablepersistence="true" /&gt;<br>
            * @example 
            * // Set persist on initialization. 
            * //To set persist API value 
            * &lt;input type="number" id="editor" /&gt;<br>
            * &lt;script&gt;<br>
            * $(document).ready(function(){
            * $("#editor").ejmNumeric ({ value: 100});
            * $("#editor").ejmNumeric ({ enablePersistence: true });
            * });
            * &lt;/script&gt;<br>
            * @example
            * &lt;script&gt;
            * //Get or set the persist, after initialization:<br>
            * // Get the enablePersistence API value.		
            *  $("#editor").ejmNumeric ("option", "enablePersistence");			
            * // Set the enablePersistence API
            * $("#editor").ejmNumeric ("option", "enablePersistence", true);
            * @memberof ejmNumeric
            * &lt;/script&gt;
            * @instance
            */
            enablePersistence: false,
            /**		
            * Specifies whether to enable or disable the control.
            * @default true
            * @type {boolean}
            * @example 
            * //Set the enabled property in unobtrusive way.
            * &lt;input type="number" id="editor" data-role="ejmnumeric" data-ej-enabled="true" /&gt;<br>
            * @example 
            * // Set enabled on initialization. 
            * //To set enabled API value 
            * &lt;input type="number" id="editor" /&gt;<br>
            * &lt;script&gt;<br>
            * $(document).ready(function(){
            * $("#editor").ejmNumeric ({ enabled: false });
            * });
            * &lt;/script&gt;<br>
            * @example
            * &lt;script&gt;
            * //Get or set the enabled, after initialization:<br>
            * // Get the enabled API value.		
            *  $("#editor").ejmNumeric ("option", "enabled");			
            * // Set the enabled API
            * $("#editor").ejmNumeric ("option", "enabled", true);
            * &lt;/script&gt;
            * @memberof ejmNumeric
            * @instance
            */
            enabled: true,
            /**		
            * Specifies whether the control is read only to disable typing the value manually rather than updating by spin button.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the readOnly property in unobtrusive way.
            * &lt;input type="number" id="editor" data-role="ejmnumeric" data-ej-readOnly="true" /&gt;<br>
            * @example 
            * // Set readOnly on initialization. 
            * //To set readOnly API value 
            * &lt;input type="number" id="editor" /&gt;<br>
            * &lt;script&gt;<br>
            * $(document).ready(function(){
            * $("#editor").ejmNumeric ({ readOnly: false });
            * });
            * &lt;/script&gt;<br>
            * @example
            * &lt;script&gt;
            * //Get or set the readOnly, after initialization:<br>
            * // Get the readOnly API value.		
            *  $("#editor").ejmNumeric ("option", "readOnly");			
            * // Set the readOnly API
            * $("#editor").ejmNumeric ("option", "readOnly", true);
            * &lt;/script&gt;
            * @memberof ejmNumeric
            * @instance
            */
            readOnly: false,
            /**		
            * Specify the minimum value.
            * @default 0
            * @type {number}
            * @example 
            * //Set the minValue property in unobtrusive way.
            * &lt;input type="number" id="editor" data-role="ejmnumeric" data-ej-minValue=50 /&gt;<br>
            * @example 
            * // Set minValue on initialization. 
            * //To set minValue API value 
            * &lt;input type="number" id="editor" /&gt;<br>
            * &lt;script&gt;<br>
            * $(document).ready(function(){
            * $("#editor").ejmNumeric ({ minValue: 50 });
            * });
            * &lt;/script&gt;<br>
            * @example
            * &lt;script&gt;
            * //Get or set the minValue, after initialization:<br>
            * // Get the minValue API value.		
            *  $("#editor").ejmNumeric ("option", "minValue");			
            * // Set the minValue API
            * $("#editor").ejmNumeric ("option", "minValue", 50);
            * &lt;/script&gt;
            * @memberof ejmNumeric
            * @instance
            */
            minValue: -(Number.MAX_VALUE),
            /**		
            * Specify the maximum value of the editor.
            * @default 0
            * @type {number}
            * @example 
            * //Set the maxValue property in unobtrusive way.
            * &lt;input type="number" id="editor" data-role="ejmnumeric" data-ej-maxValue=500 /&gt;<br>
            * @example 
            * // Set maxValue on initialization. 
            * //To setmaxValue API value 
            * &lt;input type="number" id="editor" /&gt;<br>
            * &lt;script&gt;<br>
            * $(document).ready(function(){
            * $("#editor").ejmNumeric ({ maxValue: 500 });
            * });
            * &lt;/script&gt;<br>
            * @example
            * &lt;script&gt;
            * //Get or set the maxValue, after initialization:<br>
            * // Get the maxValue API value.		
            *  $("#editor").ejmNumeric ("option", "maxValue");			
            * // Set the maxValue API
            * $("#editor").ejmNumeric ("option", "maxValue", 500);
            * &lt;/script&gt;
            * @memberof ejmNumeric
            * @instance
            */
            maxValue: Number.MAX_VALUE,
            /**		
            * Specifies the theme. See {@link Theme}
            * @default auto
            * @type {enum}
            * @example 
            * //Set the theme property in unobtrusive way.
            * &lt;input type="number" id="editor" data-role="ejmnumeric" data-ej-theme="auto" /&gt;<br>
            * @example 
            * // Set theme on initialization. 
            * //To set theme API value 
            * &lt;input type="number" id="editor" /&gt;<br>
            * &lt;script&gt;<br>
            * $(document).ready(function(){
            * $("#editor").ejmNumeric ({ theme: ej.mobile.Theme.Auto });
            * });
            * &lt;/script&gt;<br>
            * @example
            * &lt;script&gt;
            * //Get or set the theme, after initialization:<br>
            * // Get the theme API value.		
            *  $("#editor").ejmNumeric ("option", "theme");			
            * // Set the theme API
            * $("#editor").ejmNumeric ("option", "theme", ej.mobile.Theme.Auto);
            * &lt;/script&gt;
            * @memberof ejmNumeric
            * @instance
            */
            theme: "auto",
            /**		
            * Specifies the watermark text of the control.
            * @default ""
            * @type {string}
            * @example 
            * //Set the watermarkText property in unobtrusive way.
            * &lt;input type="number" id="editor" data-role="ejmnumeric" data-ej-watermarkText="Enter the age" /&gt;<br>
            * @example 
            * // Set watermarkText on initialization. 
            * //To set watermarkText API value 
            * &lt;input type="number" id="editor" /&gt;<br>
            * &lt;script&gt;<br>
            * $(document).ready(function(){
            * $("#editor").ejmNumeric ({ watermarkText: "Enter the age" });
            * //Get or set the watermarkText, after initialization:<br>
            * // Get the watermarkText API value.		
            *  $("#editor").ejmNumeric ("option", "watermarkText");		
            * });
            * &lt;/script&gt;<br>
            * @example
            * &lt;script&gt;
            * // Set the watermarkText API
            * $("#editor").ejmNumeric ("option", "watermarkText", "Enter the age");
            * &lt;/script&gt;
            * @memberof ejmNumeric
            * @instance
            */
            watermarkText: "",
            /**     
            * Section for windows mode specific functionalities.                      
            * @memberof ejmNumeric
            * @instance
            */
            windows: {
                /**		
                * Specifies whether to render control based on the windowsphone's current accent color and device theme.
                * @default false
                * @type {boolean}
                * @alias ejmNumeric#windows->renderDefault
                * @example 
                * //Set the windows mode renderDefault property in unobtrusive way.
                * &lt;input type="number" id="editor" data-role="ejmnumeric" data-ej-renderMode="windows" data-ej-windows-renderDefault="true" /&gt;<br>
                * @example 
                * // Set windows mode renderDefault on initialization. 
                * //To set windows mode renderDefault API value 
                * &lt;input type="number" id="editor" /&gt;<br>
                * &lt;script&gt;<br>
                * $(document).ready(function(){
                * $("#editor").ejmNumeric({ renderMode:"windows",windows: { renderDefault: true } });
                * });
                * &lt;/script&gt;<br>
                * @example
                * &lt;script&gt;
                * //Get or set the windows mode renderDefault, after initialization:<br>
                * // Get the windows mode renderDefault API value.		
                *  $("#editor").ejmNumeric ("option", "windows.renderDefault");			
                * // Set the windows mode renderDefault API
                * $("#editor").ejmNumeric ("option", "windows.renderDefault", true);
                * &lt;/script&gt;
                * @memberof ejmNumeric
                * @instance
                */
                "renderDefault": false
            },
            //Events
            /**    
            * Event triggers after the control value gets changed.
            * @event
            * @name ejmNumeric#change 	
            * @param {Object} argument Event parameters from editors.    			 
            * @param {boolean}  argument.cancel if the event should be cancelled; otherwise, false.
            * @param {object}  argument.model returns the corresponding editor model.
            * @param {string}  argument.type returns the name of the event.	
            * @param {number}  argument.value returns the corresponding editor control value.	
            * @example 
            * //Set the windows mode renderDefault property in unobtrusive way.
            * &lt;input type="number" id="editor" data-role="ejmnumeric" data-ej-change="change" /&gt;<br>
            * @example 
            * //Change event for editor
            * &lt;input type="number" id="editor" /&gt;<br>
            * &lt;script&gt;<br>
            * $(document).ready(function(){
            * $("#editor").ejmNumeric({
            * change: function (args) { //handle the event
            * }
            * });           
            * &lt;/script&gt;
            * @memberof ejmNumeric
            * @instance
            */
            change: null,
            /**    
            * Event triggers after the control gets focused.
            * @event
            * @name ejmNumeric#focusIn 	
            * @param {Object} argument Event parameters from editors.    			 
            * @param {boolean}  argument.cancel if the event should be cancelled; otherwise, false.
            * @param {object}  argument.model returns the corresponding editor model.
            * @param {string}  argument.type returns the name of the event.	
            * @param {value}  argument.value returns the corresponding editor control value.	
            * @example 
            * //Set the focusin property in unobtrusive way.
            * &lt;input type="number" id="editor" data-role="ejmnumeric" data-ej-focusin="focusIn" /&gt;<br>
            * @example 
            * //focusIn event for editor
            * &lt;input type="number" id="editor" /&gt;<br>
            * &lt;script&gt;<br>
            * $(document).ready(function(){
            * $("#editor").ejmNumeric({
            * focusIn: function (args) { //handle the event
            * }
            * }); 
            * &lt;/script&gt;
            * @memberof ejmNumeric
            * @instance
            */
            focusIn: null,
            /**    
            * Event triggers after the control gets focus out.
            * @event
            * @name ejmNumeric#focusOut 	
            * @param {Object} argument Event parameters from editors.    			 
            * @param {boolean}  argument.cancel if the event should be cancelled; otherwise, false.
            * @param {object}  argument.model returns the corresponding editor model.
            * @param {string}  argument.type returns the name of the event.	
            * @param {value}  argument.value returns the corresponding editor control value.	
            * @example 
            * //Set the focusin property in unobtrusive way.
            * &lt;input type="number" id="editor" data-role="ejmnumeric" data-ej-focusout="focusOut" /&gt;<br>
            * @example 
            * //focusOut event for editor
            * &lt;input type="number" id="editor" /&gt;<br>
            * &lt;script&gt;<br>
            * $(document).ready(function(){
            * $("#editor").ejmNumeric({
            * focusOut: function (args) { //handle the event
            * }
            * });   
            * &lt;/script&gt;
            * @memberof ejmNumeric
            * @instance
            */
            focusOut: null
        },
        observables: ["value"],

        value: ej.util.valueFunction("value"),
        /**
        * Specify the data types for default properties 
        * @private
        */
        dataTypes: {
            renderMode: "enum",
            showSpinButton: "boolean",
            showBorder: "boolean",
            decimalPlaces: "number",
            enableStrictMode: "boolean",
            enablePersistence: "boolean",
            enabled: "boolean",
            readOnly: "boolean",
            incrementStep: "number",
            minValue: "number",
            maxValue: "number",
            theme: "enum"
        },
        // constructor function
        /**
        * Initialize the editors widget
        * @private
        */
        _init: function () {
            this._dataInit();
            this._renderControl();
            this._validateMinMaxValue();
            this._wireEvents(false);
            this.model.enabled ? this.enable() : (this.disable(), this._wireEvents(true));
        },
        /**
        * Initialize the editors widget
        * @private
        */
        _dataInit: function () {
            var element = this.element;
            var obj = this.model;
            this._startValue = 0;
            this._inputTextBox = element[0];
            this._keypressFlag = true;
            this._incrementFlag = true;
            this._isleftspinner = true;
        },
        /**
        * Render Section For Editor	
        * @private
        */
        _renderControl: function () {
            ej.setRenderMode(this);
            ej.setTheme(this);
            if (this.model.renderMode == "windows" && this.model.windows.renderDefault)
                this.model.theme = "default";
            var element = this.element;
            var obj = this.model
            obj.name = obj.name != null ? obj.name : element[0].id;
            this.element.attr('name', this.model.name);
            this._wrapper = ej.buildTag("div.e-m-editor" + " e-m-" + obj.renderMode + " e-m-" + obj.theme);
            element.addClass("e-m-editor-input").after(this._wrapper);
            var spandiv = ej.buildTag("span.e-m-textspan");
            this._inputdiv = ej.buildTag("div.e-m-inputspan");
            this._inputdiv.append(element).append(spandiv);
            this._wrapper.append(this._inputdiv);
            if (obj.showSpinButton) {
                this._spinner = ej.buildTag("div.e-m-spinner");
                this._spinButtonDown = ej.buildTag("div.e-m-spinner-left");
                this._spinButtonUp = ej.buildTag("div.e-m-spinner-right");
                this._spinLeft = ej.buildTag("span.e-m-spin-left e-m-fontimage");
                this._spinRight = ej.buildTag("span.e-m-spin-right e-m-fontimage");
                this._spinButtonDown.append(this._spinLeft);
                this._spinButtonUp.append(this._spinRight);
                this._spinner.append(this._spinButtonDown).append(this._spinButtonUp);
                this._wrapper.append(this._spinner);
            }
            if (!obj.showBorder)
                this._showBorder(false);
            this._inputTextBox = element[0];
            if ((this.value() === null) && (this.model.watermarkText !== ""))
                this._setWaterMark();
            if (this.model.readOnly) this._setReadOnly(this.model.readOnly);
        },
        /**
        * Creating the delegates of the Editor control		
        * @private
        */
        _createDelegate: function () {
            this._spinnerHanlder = $.proxy(this._onSpinnerClick, this);
            this._spinnerHanlder = $.proxy(this._onSpinnerClick, this);
            this._keyDownProxy = $.proxy(this._keyDown, this);
            this._keyPressProxy = $.proxy(this._keyPress, this);
            this._keyUpProxy = $.proxy(this._keyUp, this);
            this._focusInProxy = $.proxy(this._focusIn, this);
            this._focusOutProxy = $.proxy(this._focusOut, this);
            this._clear = $.proxy(this._clearText, this);
            this._showClear = $.proxy(this._showClear, this);
            this._mouseMoveHandler = $.proxy(this._onMouseMove, this);
        },
        /**
        * Wiring and UnWiring the events of the Editor control		
        * @private
        */
        _wireEvents: function (remove) {
            var element = this.element;
            var obj = this.model;
            this._createDelegate();
            if (obj.showSpinButton)
                ej.listenEvents([this._spinner, this._spinner], [ej.startEvent(), ej.endEvent()], [this._spinnerHanlder, this._spinnerHanlder], remove);
            ej.listenEvents([element, element, element, element, element], ['focus', 'blur', 'keydown', 'keypress', 'keyup'], [this._focusInProxy, this._focusOutProxy, this._keyDownProxy, this._keyPressProxy, this._keyUpProxy], remove);
        },
        /**
        * Configure to handle the mousemove event
        * @private
        */
        _onMouseMove: function (e) {
            var spinner = !this._isLeftSpinner ? (this._isRightSpinner ? "_spinButtonUp" : "") : "_spinButtonDown";
            var spin = !this._isLeftSpinner ? (this._isRightSpinner ? "_spinRight" : "") : "_spinLeft";
            if (this._isRightSpinner || this._isLeftSpinner) {
            this._errorClass(false);
            clearTimeout(this._timeout);
                this[spinner].removeClass("e-m-state-active");
                this[spin].removeClass("e-m-state-active");
                this._inputTextBox.value = this._inputTextBox.value === this.model.watermarkText ? "" : this._inputTextBox.value;
                ej.listenEvents([this._spinner, this._spinner], [ej.moveEvent(), "mouseleave"], [this._mouseMoveHandler, this._mouseMoveHandler], true);
            }
        },
        /**
        * Configure to handle the spinner click event
        * @private
        */
        _onSpinnerClick: function (e) {
            if (!this.model.enabled)
                return;
            this._removeWaterMark();
            this._isLeftSpinner = $(e.target).hasClass('e-m-spin-left');
            this._isRightSpinner = $(e.target).hasClass('e-m-spin-right');
            e.preventDefault();
            var self = this;
            this._incrementFlag = this._isRightSpinner;
            var spinner = !this._isLeftSpinner ? (this._isRightSpinner ? "_spinButtonUp" : "") : "_spinButtonDown";
            var spin = !this._isLeftSpinner ? (this._isRightSpinner ? "_spinRight" : "") : "_spinLeft";
            if (this._isRightSpinner || this._isLeftSpinner) {
            if (e.type === ej.endEvent() || e.type == "MSPointerUp" || e.type == "pointerup") {
                this._errorClass(false);
                clearTimeout(this._timeout);
                this[spinner].removeClass("e-m-state-active");
                this[spin].removeClass("e-m-state-active");
                this._inputTextBox.value = this._inputTextBox.value === this.model.watermarkText ? "" : this._inputTextBox.value;
                this._updateValue(e);
            }
            else if (e.type == ej.startEvent() || e.type == "MSPointerDown" || e.type == "pointerdown") {
                this[spinner].addClass("e-m-state-active");
                this[spin].addClass("e-m-state-active");
                this._timeout = setInterval(function () { self._updateValue(e); }, 150);
                ej.listenEvents([this._spinner, this._spinner], [ej.moveEvent(), "mouseleave"], [this._mouseMoveHandler, this._mouseMoveHandler], false);
            }
            var data = { value: this.element.val() };
            if (this.model.change && (e.type == ej.endEvent() || e.type == "MSPointerUp" || e.type == "pointerup"))
                this._trigger("change", data);
            }
        },
        /**
        * Configure to handle the mouse wheel event
        * @private
        */
        _mouseWheel: function (event) {
            var delta = 0;
            if (!event) event = window.event;
            delta = (event.wheelDelta) ? event.wheelDelta / 60 : -event.detail / 2;
            this._incrementFlag = (delta > 0) ? true : ((delta < 0) ? false : this._incrementFlag);
            if (delta != 0)
                this._updateValue(e);
            this._cancelEvent(event);
        },
        /**
        * Configure to handle error class 
        * @private
        */
        _errorClass: function (obj) {
            if (obj) {
                this.element.addClass("error");
            }
            else {
                this.element.removeClass("error");
            }
        },
        /**
        * To handle show border of the editor
        * @private
        */
        _showBorder: function (obj) {
            if (obj) {
                this.element.removeClass("e-m-noborder");
                this.element.parent().find(".e-m-noborder").addClass("e-m-textspan").removeClass("e-m-noborder");
            }
            else {
                this.element.addClass("e-m-noborder");
                this.element.parent().find(".e-m-textspan").addClass("e-m-noborder").removeClass("e-m-textspan");
            }
        },
        /* Show alert when user press Wrong key*/
        /**
        * Configure to handle the alert when user press wrong key
        * @private
        */
        _showAlert: function () {
            var ptr = this;
            this.element.addClass("error").animate({ Opacity: 1 }, 700, null, function () {
                $(ptr._inputTextBox).removeClass("error");
            });
        },
        /* Increment the Value */
        /**
        * To handle the Increment value of the editor
        * @private
        */
        _updateValue: function (e) {
            if (this._inputTextBox.value == "")
                this.value(this._startValue);
            else
                this.value(parseFloat(this._inputTextBox.value));
            if (setFlag = (this._incrementFlag && this.value() < this.model.maxValue))
                this.value(this.value() + this.model.incrementStep);
            else if (setFlag = (!this._incrementFlag && this.value() > this.model.minValue))
                this.value(this.value() - this.model.incrementStep);
            else
                this._showAlert();
            if (setFlag)
                this.setValue(this.value());
            this._validateMinMaxValue();
        },
        /* Set Water Mark Text */
        /**
        * To handle the water mark text of the editor
        * @private
        */
        _setWaterMark: function () {
            $(this._inputTextBox).addClass("e-m-watermarktext");
            if ((this.model.watermarkText != "") && (this.value() === "") || (this.value() === null)) {
                $(this._inputTextBox).attr("placeholder", this.model.watermarkText);
            }
        },
        _removeWaterMark: function () {
            $(this._inputTextBox).removeClass("e-m-watermarktext");
        },
        //common for both
        _raiseChangeEvent: function () {
            var currVal = this._numberValue();
            if (this._preVal && (this._preVal.toString() != currVal)) {
                this._preVal = currVal;
                this._raiseChangeEvent();
                if (this.model.change)
                    this._trigger("change", { value: this.value() });
            }
        },
        /**
        * Configure to handle the key up event
        * @private
        */
        _keyUp: function (e) {                 
            var data = { value: this.element.val() };
            if (this.model.change)
                this._trigger("change", data);
        },
        /**
        * Configure to handle the key press event
        * @private
        */
        _keyPress: function (e) {
            if (!this._keypressFlag) {
                this._keypressFlag = true;
                this._cancelEvent(e);
                return false;
            }
        },
        /**
        * Configure to handle the key down event
        * @private
        */
        _keyDown: function (e) {
            var obj = this.model;
            if (this.model.maxValue && Number(this.element.val() + String.fromCharCode(e.keyCode)) > this.model.maxValue)
                this._cancelEvent(e);
            var numKey = e.keyCode >= 48 && e.keyCode <= 57, numPad = e.keyCode >= 96 && e.keyCode <= 105,
                    delKey = e.keyCode == 46 || e.keyCode == 127, backKey = e.keyCode == 8;
            if (numKey || numPad || this._allowKeyCodes(e)) {
                if ((e.shiftKey == true || e.ctrlKey == true) && e.keyCode != 9) { //Prevent Shift + Tab event
                    this._keypressFlag = false;
                    this._cancelEvent(e);
                    return false;
                }
                if ((numKey || numPad) || backKey || delKey) {
                    var _cursor = this._inputTextBox.type == "number" ? 0 : this._caretPosition();
                    var _beforeCursor = this._inputTextBox.value.substring(0, _cursor);
                    var _afterCursor = this._inputTextBox.value.substring(_cursor);
                    var _sel = this._inputTextBox.type == "number" ? 0 : this._getSelection(this._inputTextBox.value);
                    // For Numpad issue
                    if (numPad)
                        e.keyCode -= 48;
                    if (numKey || numPad) {
                        _sel.length == 0
                        ? this.value(parseFloat(_beforeCursor + String.fromCharCode(e.keyCode) + _afterCursor))
                        : this.value(parseFloat(_beforeCursor.substring(0, _beforeCursor.length - _sel.length) + String.fromCharCode(e.keyCode) + _afterCursor));
                    }
                    else if (backKey) {
                        var length = _sel.length == 0 ? 1 : _sel.length;
                        this.value(_beforeCursor.substring(0, _beforeCursor.length - length) + _afterCursor);
                    }
                    else {
                        _sel.length == 0
                        ? this.value(_beforeCursor + _afterCursor.substring(1, _afterCursor.length))
                        : this.value(_beforeCursor.substring(0, _beforeCursor.length - _sel.length) + _afterCursor.substring(0, _afterCursor.length));
                    }
                    if (obj.change)
                        this._trigger("change", { value: this.value() });
                }
                if (e.keyCode == 38 || e.keyCode == 40) //Up or downArrow  
                {
                    e.preventDefault();
                    this._incrementFlag = e.keyCode == 38;
                    this._updateValue(e);
                }
                if ((e.keyCode == 190 && this.model.decimalPlaces != 0) || (e.keyCode == 110 && this.model.decimalPlaces != 0)) //'.' char key press
                {
                    var _dotSplit = this._inputTextBox.value.split('.');
                    if (_dotSplit[1] == undefined) {
                        var _curPosition = this._caretPosition();
                        var _strBeforeCursor = _dotSplit[0].substring(0, _curPosition);
                        var _strAfterCursor = _dotSplit[0].substring(_curPosition);
                        this.value(_strBeforeCursor + '.' + _strAfterCursor);
                        this._setSelectionRange(this.value().length, this.value().length);
                        this._inputTextBox.value = this.value();
                    } else
                        this.value(this._inputTextBox.value);
                    if (obj.change)
                        this._trigger("change", { value: this.value() });
                    this._cancelEvent(e);
                }
                if (e.keyCode == 190 || e.keyCode == 110 || (e.keyCode == 109 || e.keyCode == 189 && ((this._caretPosition() != 0 && this._getSelection() != this.value()) || this.model.minValue >= 0)))
                    this._cancelEvent(e);
            }
            else {
                this._keypressFlag = false;
                this._cancelEvent(e);
                this._showAlert();
            }
        },
        /**
        * Configure to handle the cancel event.
        * @private
        */
        _cancelEvent: function (e) {
            e.cancelBubble = true;
            e.returnValue = false;
            e.stopPropagation();
            e.preventDefault();
            return false;
        },
        /**
        * Configure to handle the Min and Max value validation
        * @private
        */
        _validateMinMaxValue: function () {
            if (this.model.minValue > this.model.maxValue) this.model.minValue = this.model.maxValue;
            if (this.value() !== "" && this.model.maxValue < this.value())
                if (this.model.enableStrictMode)
                    this.value(this.model.maxValue);
                else
                    this._showAlert();
            else if (this.value() !== "" && this.model.minValue > this.value())
                if (this.model.enableStrictMode)
                    this.value(this.model.minValue);
                else
                    this._showAlert();
            if (this.value() !== "") {
                this._inputTextBox.value = this.value();
            }
        },
        /**
        * Configure to handle the focusIn event
        * @private
        */
        _focusIn: function (event) {
            var proxy = this;
            this._removeWaterMark();
            if (this.model.renderMode == "android")
                this.element.parent().find(".e-m-textspan").addClass("e-m-active");
            else
                this.element.addClass("e-m-active");
            this._errorClass(false);
            if (this._inputTextBox.value === this.model.watermarkText)
                this._inputTextBox.value = "";
            this.value((this._inputTextBox.value !== this.model.watermarkText && this._inputTextBox.value === "") ? 0 : this._inputTextBox.value);
            proxy.element[0].scrollLeft = proxy.element[0].scrollWidth;
            window.setTimeout(function () {
                ej.setCaretToPos(proxy.element[0], proxy.element.val().length, proxy.element.val().length);
            });
            if (this.model.focusIn)
                this._trigger("focusIn", { value: this.model.value });
        },
        /**
        * Configure to handle the focusOut event
        * @private
        */
        _focusOut: function (event) {
            if (this.model.renderMode == "android")
                this.element.parent().find(".e-m-textspan").removeClass("e-m-active");
            else
                this.element.removeClass("e-m-active");
            this._errorClass(false);
            if (this._inputTextBox.value < this.model.minValue && this._inputTextBox.value !== "") {
                this._inputTextBox.value = this.model.minValue.toFixed(this.model.decimalPlaces);
                this.value(this._inputTextBox.value);
            }
            else if (this._inputTextBox.value > this.model.maxValue) {
                this._inputTextBox.value = this.model.maxValue.toFixed(this.model.decimalPlaces);
                this.value(this._inputTextBox.value);
            }
            if (this._inputTextBox.value != "NaN" && this._inputTextBox.value != "") {
                this.value(this._inputTextBox.value);
                this._validateMinMaxValue();
            }
            if (this._inputTextBox.value == "") {
                this._setWaterMark();
            }
            this.element[0].scrollLeft = 0;
            if (this.model.focusOut)
                this._trigger("focusOut", { value: this.model.value });
        },
        /**
        * To handle the get selection of the editor values.
        * @private
        */
        _getSelection: function (value) {
            var oSel = null;
            if (document.selection) {
                oSel = document.selection.createRange();
                return oSel.text;
            } else {
                oSel = value.substring(this._inputTextBox.selectionStart, this._inputTextBox.selectionEnd);
                return oSel;
            }
        },
        /**
        * To handle the set selection range of the editor values.
        * @private
        */
        _setSelectionRange: function (selectionStart, selectionEnd) {
            var input = this._inputTextBox;
            if (input.setSelectionRange) {
                input.focus();
                input.setSelectionRange(selectionStart, selectionEnd);
            } else if (input.createTextRange) {
                var range = input.createTextRange();
                range.collapse(true);
                range.moveEnd('character', selectionEnd);
                range.moveStart('character', selectionStart);
                range.select();
            }
        },
        /**
        * To handle the Caret position of the editor values.
        * @private
        */
        _caretPosition: function () {
            var oField = this._inputTextBox;
            var iCaretPos = 0;
            // IE Support
            if (document.selection) {
                oField.focus();
                var oSel = document.selection.createRange();
                oSel.moveStart('character', -oField.value.length);
                iCaretPos = oSel.text.length;
            }
                // Firefox support
            else if (oField.selectionStart || oField.selectionStart == '0')
                iCaretPos = oField.selectionEnd;
            return (iCaretPos);
        },
        /**
        * Configure to handle the allow key codes to validate.
        * @private
        */
        _allowKeyCodes: function (e) {
            var _keys = new Array(38, 40, 35, 36, 109, 189, 46, 8, 127, 37, 39, 190, 9, 13, 16, 17, 18, 20, 110);
            var i = 0;
            for (i = 0; i < 19; i++) {
                if (e.keyCode == _keys[i])
                    return true;
            }
            return false;
        },
        /**
        * Configure to set the renderMode to the editor
        * @private
        */
        _setRenderMode: function (mode) {
            this.model.renderMode = mode;
            this.element.closest(".e-m-editor").removeClass("e-m-ios7 e-m-android e-m-windows e-m-flat").addClass("e-m-" + mode);
        },
        /**
        * Configure to set the theme to the editor
        * @private
        */
        _setTheme: function (theme) {
            this.model.theme = theme;
            this.element.closest(".e-m-editor").removeClass("e-m-dark e-m-light").addClass("e-m-" + theme);
        },
        /**
        * Configure to set the showSpinButton to the editor
        * @private
        */
        _showSpinButton: function (showSpinButton) {
            if (this._spinner)
                this._spinner.css("display", showSpinButton ? "table-cell" : "none");
        },
        /**
        * Configure to set the Decimal to the editor
        * @private
        */
        _setDecimal: function (val) {
            this.model.decimalPlaces = val;
        },
        /**
        * Configure to set the Readonly to the editor
        * @private
        */
        _setReadOnly: function (bool) {
            if (bool) this.element.attr("readonly", true);
            else this.element.removeAttr("readonly");
        },
        /**
        * To configure the properties at runtime using SetModel		
        * @private
        */
        _setModel: function (options) {
            var refresh = false, validate = false;
            for (var prop in options) {
                switch (prop) {
                    case "renderMode": this._setRenderMode(options.renderMode); break;
                    case "theme": this._setTheme(options.theme); break;
                    case "value":
                        if (ej.isNullOrUndefined(options["minValue"]) && ej.isNullOrUndefined(options["maxValue"])) {
                            this.setValue(options[prop]);
                            options[prop] = this.value();
                        }
                        else
                            validate = true;
                        break;
                    case "showSpinButton": this._showSpinButton(options.showSpinButton); break;
                    case "showBorder": this._showBorder(options.showBorder); break;
                    case "enabled": options.enabled ? (this.enable(), this._wireEvents(false)) : (this.disable(), this._wireEvents(true)); break;
                    case "readOnly": this._setReadOnly(options.readOnly); break;
                    case "decimalPlaces": this._setDecimal(options.decimalPlaces); break;
                    case "incrementStep":
                        if (isNaN(options.incrementStep)) return;
                        this.model.incrementStep = parseFloat(options.incrementStep.toFixed(this.model.decimalPlaces));
                        break;
                    case "minValue":
                        if (isNaN(options.minValue)) return;
                        this.model.minValue = parseFloat(options.minValue.toFixed(this.model.decimalPlaces));
                        validate = true;
                        break;
                    case "maxValue":
                        if (isNaN(options.maxValue)) return;
                        this.model.maxValue = parseFloat(options.maxValue.toFixed(this.model.decimalPlaces));
                        validate = true;
                        break;
                    case "watermarkText": this.model.watermarkText = options.watermarkText; this._setWaterMark(); break;
                    case "enableStrictMode": this.model.enableStrictMode = options.enableStrictMode; break;
                }
            }
            if (validate) {
                this._validateMinMaxValue(true);
                options["value"] = this.value();
                options["maxValue"] = this.model.maxValue;
                options["minValue"] = this.model.minValue;
                if (this.model.minValue != -(Number.MAX_VALUE)) this._startValue = this.model.minValue;
            }
        },
        /**
        * Configure to handle the refresh of the editor
        * @private
        */
        _refresh: function () {
            this._clearElement();
            this._renderControl();
            this._wireEvents(false);
        },
        /**
        * Configure to clear the elements.
        * @private
        */
        _clearElement: function () {
            this._wireEvents(true);
            this.element.parent().removeAttr("class");
        },
        // all events bound using this._on will be unbind automatically
        /**
        * Destroy the Editor widget		
        * @private
        */
        _destroy: function () {
            this._cloneElement.insertBefore(this.element);
            this.element.remove();
        },

        /*---------------Public Methods---------------*/
        /**
        * To enable the numeric textbox.
        * @return jQuery
        * @example 
        * //Change the control status using enable method in unobtrusive way.
        * &lt;input type="number" id="editor" data-role="ejmnumeric" /&gt;<br>
        * &lt;script&gt;
        * // Call enable method.
        * $(document).ready(function(){
        * $("#editor").ejmNumeric("enable");
        * });
        * &lt;/script&gt;
        * @example
        * //Change the control status using enable method in obtrusive way.
        * &lt;input type="number" id="editor" /&gt;<br>
        * &lt;script&gt;<br>
        * $(document).ready(function(){
        * $("#editor").ejmNumeric("enable");
        * });
        * &lt;/script&gt;
        * @memberof ejmNumeric
        * @instance
        */
        enable: function () {
            this.model.enabled = true;
            $(".e-m-editor-input").prop('disabled', false);
            this.element.closest(".e-m-editor").removeClass("e-m-state-disabled");
        },
        /**
        * To disable the numeric textbox.
        * @return jQuery
        * @example 
        * //Change the control status using disable method in obtrusive way.
        * &lt;input type="number" id="editor" data-role="ejmnumeric" /&gt;<br>
        * &lt;script&gt;
        * // Call disable method.
        * $(document).ready(function(){
        * $("#editor").ejmNumeric("disable");
        * });
        * &lt;/script&gt;
        * @example
        * //Change the control status using disable method in obtrusive way.
        * &lt;input type="number" id="editor" /&gt;<br>
        * &lt;script&gt;<br>
        * $(document).ready(function(){
        * $("#editor").ejmNumeric("disable");
        * });
        * &lt;/script&gt;
        * @memberof ejmNumeric
        * @instance
        */
        disable: function () {
            this.model.enabled = false;
            $(".e-m-editor-input").prop('disabled', true);
            this.element.closest(".e-m-editor").addClass("e-m-state-disabled");
        },
        /**
        * To get the current value of the textbox.
        * @return jQuery
        * @example 
        * //Get the value using getValue function
        * &lt;input type="number" id="editor" data-role="ejmnumeric" /&gt;<br>
        * &lt;script&gt;
        * // Call getValue method.
        * $(document).ready(function(){
        * $("#editor").ejmNumeric("getValue");
        * });
        * &lt;/script&gt;
        * @memberof ejmNumeric
        * @instance
        */
        getValue: function () {
            return this._inputTextBox.value;
        },
        /**
        * Set value of the editor control.
        * @return jQuery
        * @example 
        * //Set the value using setValue function 
        * &lt;input type="number" id="editor" data-role="ejmnumeric" /&gt;<br>
        * &lt;script&gt;
        * $(document).ready(function(){
        * // Call setValue method.
        * $("#editor").ejmNumeric("setValue",50);
        * });
        * &lt;/script&gt;
        * @memberof ejmNumeric
        * @instance
        */
        setValue: function (value) {
            this.value(value);
            this._validateMinMaxValue();
            if (value == null && (this._inputTextBox.value == this.model.watermarkText || this._inputTextBox.value != ""))
                this._setWaterMark();
        }
        /*---------------Public Methods End---------------*/
    });
})(jQuery, Syncfusion);