/**
* @fileOverview Plugin to style the Html Footer elements
* @copyright Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/

(function ($, ej, undefined) {
    /**
    * @namespace ej
    * @class ejmFooter
    * @requires jQuery
    * @requires ej.mobile.application
    * @requires ej.core
    * @requires ej.unobtrusive
    * @requires ej.mobile.core
    * @requires ej.data
    * @requires ej.touch
    * @requires ej.mobile.button
    * @classdesc Custom Design for Html Footer control.
    * @example 
    * &lt;div id="footer" &gt;&lt;/div&gt;<br>
    * &lt;script&gt; 
    * // Create footer  
    * $("#footer").ejmFooter(); 
    * &lt;/script&gt;
    * @example 
    * &lt;div id="footer" data-role="ejmfooter" &gt;&lt;/div&gt;<br>
    */
    // ejmfooter is the plugin name 
    // "ej.mobile.footer" is "namespace.className" will hold functions and properties

    ej.widget("ejmFooter", "ej.mobile.Footer", {
        _setFirst: true,
        // default model
        _rootCSS: "e-m-footer",
        defaults: {
            /**		
            * If this property is set to true, footer will be visible for iOS7 rendermode alone.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the hideForUnSupportedDevice property in unobtrusive way.
            * &lt;div id="footer" data-role="ejmfooter" data-ej-hideforunsupporteddevice=true &gt;&lt;/div&gt;<br>
            * @example
            * //Set hideForUnSupportedDevice on initialization.             
            * &lt;div id="footer"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * //To set hideForUnSupportedDevice API value 
            * $(function(){
            * $("#footer").ejmFooter({ hideForUnSupportedDevice: true });	
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the hideForUnSupportedDevice, after initialization:<br>
            * // Get the hideForUnSupportedDevice API value.		
            *  $("#footer").ejmFooter ("option", "hideForUnSupportedDevice");			
            * // Set the hideForUnSupportedDevice  API
            * $("#footer").ejmFooter ("option", "hideForUnSupportedDevice", "footer");            
            * @memberof ejmFooter
            * @instance
            */
            hideForUnSupportedDevice: false,
            /**		
            * Specifies the navigation url, which the page should go while clicking the left button. {@link ejmFooter#showLeftButton}
            * @default null
            * @type {string}
            * @example 
            * //Set the leftButtonNavigationUrl property in unobtrusive way.
            * &lt;div id="footer" data-role="ejmfooter" data-ej-showleftbutton="true" data-ej-leftbuttonnavigationurl="" &gt;&lt;/div&gt;<br>
            * @example
            * //Set leftButtonNavigationUrl on initialization.             
            * &lt;div id="footer"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * //To set leftButtonNavigationUrl API value 
            * $(function(){
            * $("#footer").ejmFooter({ leftButtonNavigationUrl: "" });	
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the leftButtonNavigationUrl, after initialization:<br>
            * // Get the leftButtonNavigationUrl API value.		
            *  $("#footer").ejmFooter ("option", "leftButtonNavigationUrl");			
            * // Set the leftButtonNavigationUrl  API
            * $("#footer").ejmFooter ("option", "leftButtonNavigationUrl", "footer");            
            * @memberof ejmFooter
            * @instance
            */
            leftButtonNavigationUrl: null,
            /**		
            * Specifies the navigation url, which the page should go while clicking the right button. {@link ejmFooter#showRightButton}
            * @default null
            * @type {string}
            * @example 
            * //Set the rightButtonNavigationUrl property in unobtrusive way.
            * &lt;div id="footer" data-role="ejmfooter" data-ej-showrightbutton="true" data-ej-rightbuttonnavigationurl="" &gt;&lt;/div&gt;<br>
            * @example
            * //Set rightButtonNavigationUrl on initialization.             
            * &lt;div id="footer"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * //To set rightButtonNavigationUrl API value 
            * $(function(){
            * $("#footer").ejmFooter({ rightButtonNavigationUrl: "" });	
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the rightButtonNavigationUrl, after initialization:<br>
            * // Get the rightButtonNavigationUrl API value.		
            *  $("#footer").ejmFooter ("option", "rightButtonNavigationUrl");			
            * // Set the rightButtonNavigationUrl  API
            * $("#footer").ejmFooter ("option", "rightButtonNavigationUrl", "footer");
            * @memberof ejmFooter
            * @instance
            */
            rightButtonNavigationUrl: null,
            /**		
            * Specifies the title's text.
            * @default Title
            * @type {string}
            * @example 
            * //Set the title property in unobtrusive way.
            * &lt;div id="footer" data-role="ejmfooter" data-ej-title="Footer" &gt;&lt;/div&gt;<br>
            * @example 
            * &lt;div id="footer"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * //Set title on initialization. 
            * //To set title API value 
            * $("#footer").ejmFooter({ title: "Title" });	
            * &lt;/script&gt;
            * @example 
            * //Get or set the title, after initialization:<br>
            * //Get the title API value.		
            *  $("#footer").ejmFooter ("option", "title");			
            * //Set the title API
            * $("#footer").ejmFooter ("option", "title", "Footer");			
            * @memberof ejmFooter
            * @instance
            */
            title: "Title",
            /**		
            * Specifies whether to show the title or not. if this property is set to false, title will be hide.
            * @default true
            * @type {boolean}
            * @example 
            * //Set the showTitle property in unobtrusive way.
            * &lt;div id="footer" data-role="ejmfooter" data-ej-showtitle=false &gt;&lt;/div&gt;<br>
            * @example 
            * &lt;div id="footer"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * //Set showTitle on initialization. 
            * //To set showTitle API value 
            * $("#footer").ejmFooter({ showTitle: false });	
            * &lt;/script&gt;
            * @example 
            * //Get or set the showTitle, after initialization:<br>
            * //Get the showTitle API value.		
            *  $("#footer").ejmFooter ("option", "showTitle");			
            * //Set the showTitle API
            * $("#footer").ejmFooter ("option", "showTitle", false);   			
            * @memberof ejmFooter
            * @instance
            */
            showTitle: true,
            /**		
            * Specifies whether to keep the footer in fixed position i.e. bottom or in relative position depends on the other element's position. See {@link Position}
            * @default ej.mobile.Footer.Position.Fixed
            * @type {enum}
            * @example 
            * //Set the position property in unobtrusive way.
            * &lt;div id="footer" data-role="ejmfooter" data-ej-position="normal" &gt;&lt;/div&gt;<br>
            * @example 
            * &lt;div id="footer"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * //Set position on initialization. 
            * //To set position API value 
            * $(function(){
            * $("#footer").ejmFooter({ position: ej.mobile.Footer.Position.Fixed });	
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the position, after initialization:<br>
            * //Get the position API value.		
            *  $("#footer").ejmFooter ("option", "position");			
            * //Set the position API
            * $("#footer").ejmFooter ("option", "position", ej.mobile.Footer.Position.Fixed);			
            * @memberof ejmFooter
            * @instance
            */
            position: "fixed",
            /**		
            * Specifies the caption for the left button. {@link ejmFooter#showLeftButton}
            * @default Back
            * @type {string}
            * @example 
            * //Set the leftButtonCaption property in unobtrusive way.
            * &lt;div id="footer" data-role="ejmfooter" data-ej-showleftbutton="true" data-ej-leftbuttoncaption="Home" &gt;&lt;/div&gt;<br>
            * @example 
            * &lt;div id="footer"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * //Set leftButtonCaption on initialization. 
            * //To set leftButtonCaption API value 
            * $("#footer").ejmFooter({ showLeftButton: true });
            * $("#footer").ejmFooter({ leftButtonCaption: "Home" });
            * &lt;/script&gt;
            * @example 
            * //Get or set the leftButtonCaption, after initialization:<br>
            * //Get the leftButtonCaption API value.		
            *  $("#footer").ejmFooter ("option", "leftButtonCaption");			
            * //Set the leftButtonCaption API
            * $("#footer").ejmFooter ("option", "leftButtonCaption", "Home");			
            * @memberof ejmFooter
            * @instance
            */
            leftButtonCaption: "Left",
            /**		
            * Specifies the caption for the right button. {@link ejmFooter#showRightButton}
            * @default Right
            * @type {string}
            * @example 
            * //Set the rightButtonCaption property in unobtrusive way.
            * &lt;div id="footer" data-role="ejmfooter" data-ej-showrightbutton="true" data-ej-rightbuttoncaption="Next" &gt;&lt;/div&gt;<br>
            * @example 
            * &lt;div id="footer"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * //Set rightButtonCaption on initialization. 
            * //To set rightButtonCaption API value 
            * $("#footer").ejmFooter({ showRightButton: true });	
            * $("#footer").ejmFooter({ rightButtonCaption: "Next" });
            * &lt;/script&gt;
            * @example 
            * //Get or set the rightButtonCaption, after initialization:<br>
            * //Get the rightButtonCaption API value.		
            *  $("#footer").ejmFooter ("option", "rightButtonCaption");			
            * //Set the rightButtonCaption API
            * $("#footer").ejmFooter ("option", "rightButtonCaption", "Next");			
            * @memberof ejmFooter
            * @instance
            */
            rightButtonCaption: "Right",
            /**		
            * Changes the rendering mode of the footer. See {@link RenderMode}
            * @default auto
            * @type {enum}
            * @example 
            * //Set the renderMode property in unobtrusive way.
            * &lt;div id="footer" data-role="ejmfooter" data-ej-rendermode="auto" &gt;&lt;/div&gt;<br>
            * @example 
            * &lt;div id="footer"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * //Set rendermode on initialization. 
            * //To set renderMode API value 
            * $(function(){
            * $("#footer").ejmFooter({ renderMode: ej.mobile.RenderMode.Auto });	
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the renderMode, after initialization:<br>
            * //Get the renderMode API value.		
            *  $("#footer").ejmFooter ("option", "renderMode");			
            * //Set the renderMode API
            * $("#footer").ejmFooter ("option", "renderMode", ej.mobile.RenderMode.Auto);			
            * @memberof ejmFooter
            * @instance
            */
            renderMode: "auto",
            /**		
            * Changes the theme of the footer. See {@link Theme}
            * @default auto
            * @type {enum}
            * @example 
            * //Set the theme property in unobtrusive way.
            * &lt;div id="footer" data-role="ejmfooter" data-ej-theme="auto" &gt;&lt;/div&gt;<br>
            * @example 
            * &lt;div id="footer"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * // Set theme on initialization. 
            * //To set theme API value 
            * $(function(){
            * $("#footer").ejmFooter({ theme: ej.mobile.Theme.Auto  });	
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the theme, after initialization:<br>
            * //Get the theme API value.		
            *  $("#footer").ejmFooter ("option", "theme");			
            * //Set the leftButtonCaption API
            * $("#footer").ejmFooter ("option", "theme", ej.mobile.Theme.Auto );			
            * @memberof ejmFooter
            * @instance
            */
            theme: "auto",
            /**		
            * Specifies whether to show the left button or not.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the showLeftButton property in unobtrusive way.
            * &lt;div id="footer" data-role="ejmfooter" data-ej-showleftbutton=true &gt;&lt;/div&gt;<br>
            * @example 
            * &lt;div id="footer"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * //Set showLeftButton on initialization. 
            * //To set showLeftButton API value 
            * $("#footer").ejmFooter({ showLeftButton: true });	
            * &lt;/script&gt;
            * @example 
            * //Get or set the showLeftButton, after initialization:<br>
            * //Get the showLeftButton API value.		
            *  $("#footer").ejmFooter ("option", "showLeftButton");			
            * //Set the showLeftButton API
            * $("#footer").ejmFooter ("option", "showLeftButton", "true");			
            * @memberof ejmFooter
            * @instance
            */
            showLeftButton: false,
            /**		
            * Specifies whether to show the right button or not.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the showRightButton property in unobtrusive way.
            * &lt;div id="footer" data-role="ejmfooter" data-ej-showrightbutton=true &gt;&lt;/div&gt;<br>
            * @example 
            * &lt;div id="footer"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * //Set showRightButton on initialization. 
            * //To set showRightButton API value 
            * $("#footer").ejmFooter({ showRightButton: true });	
            * &lt;/script&gt;
            * @example 
            * //Get or set the showRightButton, after initialization:<br>
            * //Get the showRightButton API value.		
            *  $("#footer").ejmFooter ("option", "showRightButton");			
            * //Set the showRightButton API
            * $("#footer").ejmFooter ("option", "showRightButton", true);			
            * @memberof ejmFooter
            * @instance
            */
            showRightButton: false,
            /**		
            * Current model value to browser cookies for state maintenance. While refreshing the page, the model value applied from browser cookies retains.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the enablePersistence property in unobtrusive way.
            * &lt;div id="footer" data-role="ejmfooter" data-ej-enablepersistence=true &gt;&lt;/div&gt;<br>
            * @example 
            * &lt;div id="footer"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * //Set enablePersistence on initialization. 
            * //To set enablePersistence API value 
            * $("#footer").ejmFooter({ enablePersistence: true });	
            * &lt;/script&gt;
            * @example 
            * //Get or set the enablePersistence, after initialization:<br>
            * //Get the enablePersistence API value.		
            *  $("#footer").ejmFooter ("option", "enablePersistence");			
            * //Set the enablePersistence API
            * $("#footer").ejmFooter ("option", "enablePersistence", true);			
            * @memberof ejmFooter
            * @instance
            */
            enablePersistence: false,
            /**		
            * Specifies the id of the element which is to be given as template.
            * @default null
            * @type {string}
            * @example 
            * //Set the templateId property in unobtrusive way.
            * &lt;div id="footer" data-role="ejmfooter" data-ej-templateid="footertemplate" &gt;&lt;/div&gt;<br>		          
            * @memberof ejmFooter
            * @instance
            */
            templateId: null,
            /**    
            * Event triggers when the left button is tapped. {@link ejmFooter#showLeftButton}
            * @event
            * @name ejmFooter#leftButtonTap 	
            * @param {boolean} argument.cancel if the event should be canceled; otherwise, false.
            * @param {boolean} argument.model returns the groupbutton model
            * @param {boolean} argument.type returns the name of the event
            * @param {boolean} argument.text returns the current button text
            * @example 
            * &lt;div id="footer" data-role="ejmfooter" data-ej-showleftbutton="true" data-ej-leftbuttontap="onLeftButtonTap"&gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * //leftButtonTap event for footer  
            * function onLeftButtonTap(args){ //handle the event
            * }
            * &lt;/script&gt;
            * @example 
            * &lt;div id="footer"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * $("#footer").ejmFooter({showLeftButton:true, leftButtonTap:"test"});
            * //LeftButtonTap event for footer
            *   function test() { //handle the event 
            * }
            * &lt;/script&gt;			
            * @memberof ejmFooter
            * @instance
            */
            leftButtonTap: null,
            /**    
            * Event triggers when the right button is tapped. {@link ejmFooter#showRightButton}
            * @event
            * @name ejmFooter#rightButtonTap 	
            * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
            * @param {boolean} argument.model returns the groupbutton model
            * @param {boolean} argument.type returns the name of the event
            * @param {boolean} argument.text returns the current button text
            * @example 
            * &lt;div id="footer" data-role="ejmfooter" data-ej-showrightbutton="true" data-ej-rightbuttontap="onRightButtonTap"&gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * //rightButtonTap event for footer  
            * function onRightButtonTap(args){ //handle the event
            * }
            * &lt;/script&gt;
            * @example 
            * &lt;div id="footer"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * $("#footer").ejmFooter({showRightButton:true, rightButtonTap:"test"});
            * //rightButtonTap event for footer
            *   function test() { //handle the event 
            * }
            * &lt;/script&gt;			
            * @memberof ejmFooter
            * @instance
            */
            rightButtonTap: null,
            /**     
            * Section for windows rendermode specific functionalities.                      
            * @memberof ejmFooter
            * @instance
            */
            windows: {
                /**  
                * Specifies whether to render the footer based on the windowsphone's current theme or not
                * @default false
                * @type {boolean}
                * @alias ejmFooter#windows->renderDefault
                * @example 
                * //Set the windows mode renderDefault property in unobtrusive way.
                * &lt;div id="footer" data-role="ejmfooter" data-ej-rendermode="windows" data-ej-windows-renderdefault=true &gt;&lt;/div&gt;<br> 
                * @memberof ejmFooter
                * @instance
                */
                "renderDefault": false
            } 
        },
        dataTypes: {
            showTitle: "boolean",
            position: "enum",
            renderMode: "enum",
            theme: "enum",
            enablePersistence: "boolean",
            windows: { "renderDefault": "boolean" } 
        },
        // constructor function
        _init: function () {
            if (!this.model.hideForUnSupportedDevice || this.model.hideForUnSupportedDevice && (this.model.renderMode == "ios7"))
                this._renderControl();
        },
        //renderin footer template 
        _renderFooterTemplate: function () {
            this._templateContainer = ej.buildTag("div.e-m-footer-content");
            var templateContent = ej.getCurrentPage().find("#" + this.model.templateId);
            if (templateContent.length) {
                this.element.empty();
                ej.destroyWidgets(templateContent);
                this._template = templateContent[0].nodeName && templateContent[0].nodeName.toLowerCase() == "script" ? ej.getClearString(templateContent[0].innerHTML) : templateContent;
            }
            else {
                this._template = this.element[0].innerHTML.trim();
                this.element.empty();
            }
            this.element.append(this._templateContainer.append(this._template));
        },
        //rendering default header
        _renderDefaultFooter: function () {
            this._footerContainer = ej.buildTag("div.e-m-footer-content");
            if (this.element[0].innerHTML.trim() == "") {
                this.element.append(this._footerContainer);
                if (this["_" + this.model.renderMode + "ButtonProperties"])
                    this["_" + this.model.renderMode + "ButtonProperties"]();
            }
            else {
                this._template = this.element[0].innerHTML.trim();
                this.element.empty();
                this.element.append(this._footerContainer.append(this._template));
            }
        },
        _renderControl: function () {
            this._orgEle = $(this.element).clone();
            ej.setRenderMode(this);
            ej.setTheme(this); 
            if (this.model.renderMode == "windows" && this.model.windows.renderDefault && ej.isMobile())
                this.model.theme = "default";
            if (this.model.height > 0)
                $(this.element).css({ "height": this.model.height });
            if (this.model.width > 0)
                $(this.element).css({ "width": this.model.width });
            this.element.addClass("e-m-" + this.model.renderMode + " e-m-footer e-m-" + this.model.position + " e-m-" + this.model.theme);
            if (this.model.templateId == null) {
                this._renderDefaultFooter();
            }
            else
                this._renderFooterTemplate();
            var spanElemnt = this.element.find(".e-m-footer-text");
            if (spanElemnt.length == 0 && !this._template && this.model.showTitle) {
                this._showFooterTitle();
            }
        },
        _leftButtonCommon: function () {
            this._leftButton = ej.buildTag("div.e-m-footer-left");
            this._leftButtonAnchorTag = ej.buildTag("a", this.model.leftButtonCaption, "", { "data-role": "ejmactionlink", "data-ej-rendermode": this.model.renderMode, "data-ej-bindback": this.model.bindBack, "data-ej-theme": this.model.theme, "data-ej-text": this.model.leftButtonCaption });
            this._ios7Buttons(this._leftButton, this._leftButtonAnchorTag, this.model.leftButtonTap, "header", this.model.leftButtonNavigationUrl);
        },
        _rightButtonCommon: function () {
            this._rightButton = ej.buildTag("div.e-m-footer-right");
            this._rightButtonAnchorTag = ej.buildTag("a", this.model.rightButtonCaption, "", { "data-role": "ejmactionlink", "data-ej-rendermode": this.model.renderMode, "data-ej-theme": this.model.theme, "data-ej-text": this.model.rightButtonCaption });
            this._ios7Buttons(this._rightButton, this._rightButtonAnchorTag, this.model.rightButtonTap, "header", this.model.rightButtonNavigationUrl);
        },
        _ios7Buttons: function (rootdiv, buttonCtrl, buttonclick, style, navigateURL) {
            buttonclick != null ? ((!buttonclick.name) ? buttonCtrl.attr("data-ej-touchend", buttonclick) : buttonCtrl.attr("data-ej-touchend", buttonclick.name)) : "";
            buttonCtrl.attr("data-ej-" + this.model.renderMode + "-style", style);
            if (navigateURL != null)
                buttonCtrl.attr('href', navigateURL);
            rootdiv.append(buttonCtrl);
            rootdiv.hasClass("e-m-header-left") ? this.element.find(".e-m-footer-content").prepend(rootdiv) : this.element.find(".e-m-footer-content").append(rootdiv);
            ej.widget.init(rootdiv);
        },
        _showFooterTitle: function () {
            this._titleSpan = ej.buildTag("span.e-m-footer-text e-m-" + this.model.theme + " e-m-user-select", this.model.title, "", "");
            titleDiv = ej.buildTag("div.e-m-footer-title", "", "", "").append(this._titleSpan);
            this._footerContainer.append(titleDiv);
            if (this.model.renderMode == "ios7") {
                if (this._titleSpan.text().length > 18) {
                    if (this.model.showLeftButton)
                        this._titleSpan.css("margin-left", "65px");
                    if (this.model.showRightButton)
                        this._titleSpan.css("margin-right", "50px");
                }
            }
        },
        _ios7ButtonProperties: function () {
            if (this.model.showLeftButton)
                this._leftButtonCommon();
            if (this.model.showTitle)
                this._showFooterTitle()
            if (this.model.showRightButton)
                this._rightButtonCommon();
        },
        /**
        * To configure the showLeftButton of the Footer		
        * @private
        */
        _setShowLeftButton: function (showStatus) {
            this.model.showLeftButton = showStatus;
            if (!this._leftButton) {
                this._leftButtonCommon();
            }
            else {
                this._leftButton[showStatus ? "show" : "hide"]();
            }
        },
        /**
        * To configure the showRightButton of the Footer		
        * @private
        */
        _setShowRightButton: function (showStatus) {
            this.model.showRightButton = showStatus;
            if (!this._rightButton) {
                this._rightButtonCommon();
            }
            else {
                this._rightButton[showStatus ? "show" : "hide"]();
            }
        },
        /**
        * To configure the showTitle Property of the Footer		
        * @private
        */
        _setShowTitle: function (showStatus) {
            this.model.showTitle = showStatus;
            this._titleSpan[showStatus ? "show" : "hide"]();
        },
        /**
        * To configure the title of the Footer		
        * @private
        */
        _setTitle: function (title) {
            this.model.title = title;
            this._titleSpan.html(title);
        },
        /**
        * To configure the leftButtonCaption of the Footer		
        * @private
        */
        _setLeftButtonCaption: function (caption) {
            this.model.leftButtonCaption = caption;
            this.element.find(this._leftButtonAnchorTag).html(caption);
        },
        /**
        * To configure the rightButtonCaption of the Footer		
        * @private
        */
        _setRightButtonCaption: function (caption) {
            this.model.rightButtonCaption = caption;
            this.element.find(this._rightButtonAnchorTag).html(caption);
        },
        /**
        * To configure the leftButtonTap property of the Footer		
        * @private
        */
        _setLeftButtonTap: function (caption) {
            this.model.leftButtonTap = caption;
            this.element.find(this._leftButtonAnchorTag).ejmActionlink({ "touchEnd": caption });
        },
        /**
        * To configure the rightButtonTap property of the Footer		
        * @private
        */
        _setRightButtonTap: function (caption) {
            this.model.rightButtonTap = caption;
            this.element.find(this._rightButtonAnchorTag).ejmActionlink({ "touchEnd": caption });
        },
        _setModel: function (options) {
            var refresh = false;
            for (var prop in options) {
                var setModel = "_set" + prop.charAt(0).toUpperCase() + prop.slice(1);
                if (prop == "renderMode" || prop == "position")
                    refresh = true;
                else {
                    if (this[setModel])
                        this[setModel](options[prop]);
                }
            }
            if (refresh)
                this._refresh();
        },
        /**
        * To configure the theme of the Footer		
        * @private
        */
        _setTheme: function (theme) {
            this.model.theme = theme;
            this.element.removeClass("e-m-light e-m-dark").addClass("e-m-" + theme.toLowerCase());
            this.element.find(".e-m-footer-left .e-m-btn").ejmActionlink({ "theme": theme });
            this.element.find(".e-m-footer-right .e-m-btn").ejmActionlink({ "theme": theme });
        },
        _refresh: function () {
            this._destroy();
            this.element.addClass("ejm-footer");
            this._renderControl();
        },
        _clearElement: function () {
            this.element.removeAttr("class");
            this.element.html(this._orgEle.html());
        },
        _destroy: function () {
            this._clearElement();
        },

        /*---------------Public Methods---------------*/
        /**
        * To get the footer's text
        * @return jQuery
        * @example 
        * &lt;div id="footer" data-role="ejmfooter" &gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * $(function(){
        * //To get the instance of the footer
        * var footer = $("#footer").data("ejmFooter");
        * footer.getTitle(); //returns the footer's text
        * });
        * &lt;/script&gt;
        * @example 
        * &lt;div id="footer"&gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * $(function(){
        * $("#footer").ejmFooter();	
        * //get the footer's current value
        * $("#footer").ejmFooter("getTitle");	
        * });
        * &lt;/script&gt;
        *@memberof ejmFooter
        * @instance
        */
        getTitle: function () {
            return this._titleSpan.html();
        }
        /*---------------Public Methods End---------------*/
    });
    /**
    * Enum for Position
    * @enum {string}
    * @global
    */
    ej.mobile.Footer.Position = {
        /**
        Enum for relative position for Footer*/
        Normal: "normal",
        /**
        Enum for fixed position for Footer*/
        Fixed: "fixed"
    }
})(jQuery, Syncfusion);