﻿/**
* @fileOverview Plugin to style the Html groupbutton elements
* @copyright Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/

(function ($, ej, undefined) {
    // ejmGroupButton is the plugin name 
    // "ej.mobile.GroupButton" is "namespace.className" will hold functions and properties

    /**
    * @namespace ej
    * @class ejmGroupButton
    * @requires jQuery
    * @requires ej.mobile.application
    * @requires ej.core
    * @requires ej.unobtrusive
    * @requires ej.mobile.core
    * @requires ej.data
    * @requires ej.touch
    * @classdesc Custom Design for Html GroupButton control.
    
    * @example 
    * //Render groupbutton control by default with button behavior in unobtrusive way
    * &lt;div data-role="ejmgroupbutton"&gt;<br>
    * &lt;button&gt;ipad&lt;/button&gt;<br>
    * &lt;button&gt;ipod&lt;/button&gt;<br>
    * &lt;/div&gt;<br>

    * @example 
    * //Render groupbutton control by default with button behavior in obtrusive way
    * &lt;div id="grpbtn" &gt;
    * &lt;button&gt;ipad&lt;/button&gt;
    * &lt;button&gt;ipod&lt;/button&gt;
    * &lt;/div&gt;<br>
    * &lt;script &gt;
    * $("#grpbtn").ejmGroupButton();
    * &lt;/script &gt;
 
    * @example 
    * //Obtain radiobutton behavior for groupbutton control in unobtrusive way
    * &lt;div data-role="ejmgroupbutton"&gt;<br>
    * &lt;label&gt;<br>
    * &lt;input type="radio"/&gt;ipad<br>
    * &lt;/label&gt;<br>
    * &lt;label&gt;<br>
    * &lt;input type="radio"/&gt;ipod<br>
    * &lt;/label&gt;<br>
    * &lt;/div&gt;

    * @example 
    * //Render groupbutton control by default with radiobutton behavior in obtrusive way
    * &lt;div id="grpbtn" &gt;<br>
    * &lt;label &gt;
    * &lt;input type="radio" data-role="none" /&gt;
    * ipad
    * &lt;/label &gt;
    * &lt;label &gt;
    * &lt;input type="radio" data-role="none" /&gt;
    * ipod
    * &lt;/label &gt;
    * &lt;/div &gt;<br>
    * &lt;script &gt;
    * $("#grpbtn").ejmGroupButton();
    * &lt;/script &gt;


    * @example 
    * //Obtain checkbox behavior for groupbutton control in unobtrusive way
    * &lt;div data-role="ejmgroupbutton"&gt;<br>
    * &lt;label&gt;<br>
    * &lt;input type="checkbox"/&gt;ipad<br>
    * &lt;/label&gt;<br>
    * &lt;label&gt;<br>
    * &lt;input type="checkbox"/&gt;ipod
    * &lt;/label&gt;<br>
    * &lt;/div&gt;

    * @example 
    * //Obtain checkbox behavior for groupbutton control in obtrusive way
    * &lt;div id="grpbtn" &gt;<br>
    * &lt;label&gt;
    * &lt;input type="checkbox" data-role="none" /&gt;ipad
    * &lt;/label&gt;
    * &lt;label&gt;
    * &lt;input type="checkbox" data-role="none" /&gt;ipod
    * &lt;/label&gt;
    * &lt;/div&gt;
    * &lt;script &gt;
    * $("#grpbtn").ejmGroupButton();
    * &lt;/script &gt;
    */

    ej.widget("ejmGroupButton", "ej.mobile.GroupButton", {
        _setFirst: true,
        // default model
        _rootCSS: "e-m-grpbtn",
        _tags: [{
            tag: "items",
            attr: ["text", "imageClass", "imageUrl"],
            content: "content"
        }],
        defaults: {
            /**		
            * Specifies the item which one is to be selected initially.
            * @default -1
            * @type {number}
            * @example 
            * //Set the selectedItemIndex property in unobtrusive way.
            * &lt;div id="grpbtn" data-role="ejmgroupbutton" data-ej-selecteditemindex=1&gt;<br>
            * &lt;label&gt;<br>
            * &lt;input type="radio"/&gt;ipad<br>
            * &lt;/label&gt;<br>
            * &lt;label&gt;<br>
            * &lt;input type="radio"/&gt;ipod<br>
            * &lt;/label&gt;<br>
            * &lt;/div&gt;
            * @example 
            * // Set selectedItemIndex on initialization in obtrusive way
            * // To set selectedItemIndex API value in obtrusive way
            * &lt;div id="grpbtn"&gt;
            * &lt;label&gt;
            * &lt;input type="radio" data-role="none" /&gt;ipad
            * &lt;/label&gt;
            * &lt;label&gt;
            * &lt;input type="radio" data-role="none" /&gt;ipod
            * &lt;/label&gt;
            * &lt;/div&gt;<br>
            * &lt;script&gt;
            * $("#grpbtn").ejmGroupButton ({ selectedItemIndex: 1 });
            * &lt;/script&gt;<br>
            * @memberof ejmGroupButton
            * @instance
            */

            selectedItemIndex: 0,
            /**		
            * Changes the rendering mode of the groupbutton. See {@link RenderMode}
            * @default auto
            * @type {enum}
            * @example 
            * // Set the renderMode property in unobtrusive way.
            * &lt;div id="grpbtn" data-role="ejmgroupbutton" data-ej-rendermode="auto"&gt;<br>
            * &lt;label&gt;<br>
            * &lt;input type="radio"/&gt;ipad<br>
            * &lt;/label&gt;<br>
            * &lt;label&gt;<br>
            * &lt;input type="radio"/&gt;ipod<br>
            * &lt;/label&gt;<br>
            * &lt;/div&gt;
            * @example 
            * // Set rendermode on initialization. 
            * // To set renderMode API value 
            * &lt;div id="grpbtn"&gt;
            * &lt;label&gt;
            * &lt;input type="radio" data-role="none" /&gt;ipad
            * &lt;/label&gt;
            * &lt;label&gt;
            * &lt;input type="radio" data-role="none" /&gt;ipod
            * &lt;/label&gt;
            * &lt;/div&gt;<br>
            * &lt;script&gt;
            * $(function(){
            * $("#grpbtn").ejmGroupButton ({ renderMode: ej.mobile.RenderMode.Auto });	
            * });
            * &lt;/script&gt;<br>
            * @example 
            * // Get or set the rendermode, after initialization:<br>
            * // Get the renderMode API value.		
            *  $("#grpbtn").ejmGroupButton ("option", "renderMode");			
            * // Set the renderMode API
            * $("#grpbtn").ejmGroupButton ("option", "renderMode", ej.mobile.RenderMode.Auto);            
            * @memberof ejmGroupButton
            * @instance
            */
            renderMode: "auto",
            /**		
            * Changes the theme of the groupbutton. See {@link Theme}
            * @default auto
            * @type {enum}
            * @example 
            * //Set the theme property in unobtrusive way.
            * &lt;div id="grpbtn" data-role="ejmgroupbutton" data-ej-theme="auto"&gt;
            * &lt;label&gt;
            * &lt;input type="radio"/&gt;ipad
            * &lt;/label&gt;
            * &lt;label&gt;
            * &lt;input type="radio"/&gt;ipod
            * &lt;/label&gt;
            * &lt;/div&gt;
            * @example 
            * // Set theme on initialization. 
            * // To set theme API value 
            * &lt;div id="grpbtn"&gt;
            * &lt;label&gt;
            * &lt;input type="radio" data-role="none" /&gt;ipad
            * &lt;/label&gt;
            * &lt;label&gt;
            * &lt;input type="radio" data-role="none" /&gt;ipod
            * &lt;/label&gt;
            * &lt;/div&gt;<br>
            * &lt;script&gt;
            * $(function(){
            * $("#grpbtn").ejmGroupButton ({ theme: ej.mobile.Theme.Auto });
            * });
            * &lt;/script&gt;<br>
            * @example 
            * // Get or set the theme, after initialization:<br>
            * // Get the theme API value.		
            *   $("#grpbtn").ejmGroupButton ("option", "theme");			
            * // Set the theme API
            *   $("#grpbtn").ejmGroupButton ("option", "theme", ej.mobile.Theme.Auto);
            * @memberof ejmGroupButton
            * @instance
            */
            theme: "auto",
            /**		
            * Current model value to browser cookies for state maintenance. While refreshing the page, the model value applied from browser cookies retains.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the enablePersistence property in unobtrusive way.
            * &lt;div id="grpbtn" data-role="ejmgroupbutton" data-ej-enablepersistence=true &gt;<br>
            * &lt;label&gt;<br>
            * &lt;input type="radio"/&gt;ipad<br>
            * &lt;/label&gt;<br>
            * &lt;label&gt;<br>
            * &lt;input type="radio"/&gt;ipod<br>
            * &lt;/label&gt;<br>
            * &lt;/div&gt;
            * @example 
            * // Set enablePersistence on initialization. 
            * // To set enablePersistence API value 
            * &lt;div id="grpbtn"&gt;
            * &lt;label&gt;
            * &lt;input type="radio" data-role="none" /&gt;ipad
            * &lt;/label&gt;
            * &lt;label&gt;
            * &lt;input type="radio" data-role="none" /&gt;ipod
            * &lt;/label&gt;
            * &lt;/div&gt;<br>
            * &lt;script&gt;
            * $("#grpbtn").ejmGroupButton ({ enablePersistence: true });
            * &lt;/script&gt;<br>
            * @example 
            * // Get or set the enablePersistence, after initialization:<br>
            * // Get the enablePersistence API value.		
            *   $("#grpbtn").ejmGroupButton ("option", "enablePersistence");			
            * // Set the enablePersistence API
            *   $("#grpbtn").ejmGroupButton ("option", "enablePersistence", true);
            * @memberof ejmGroupButton
            * @instance
            */
            enablePersistence: false,
            /**     
            * Section for windows rendermode specific functionalities.                      
            * @memberof ejmGroupButton
            * @instance
            */
            windows: {
                /**  
                * Specifies whether to render the groupbutton based on the windowsphone's current accent color and device theme.
                * @default false
                * @type {boolean}
                * @alias ejmGroupButton#windows->renderDefault
                * @example 
                * // Set the windows mode renderDefault property in unobtrusive way.
                * &lt;div id="grpbtn" data-role="ejmgroupbutton" data-ej-windows-renderdefault=false&gt;<br>
                * &lt;label&gt;<br>
                * &lt;input type="radio"/&gt;ipad<br>
                * &lt;/label&gt;<br>
                * &lt;label&gt;<br>
                * &lt;input type="radio"/&gt;ipod<br>
                * &lt;/label&gt;<br>
                * &lt;/div&gt;
                * @example 
                * // To set windows mode renderDefault property API value 
                * &lt;div id="grpbtn"&gt;
                * &lt;label&gt;
                * &lt;input type="radio" data-role="none" /&gt;ipad
                * &lt;/label&gt;<br>
                * &lt;label&gt;
                * &lt;input type="radio" data-role="none" /&gt;ipod
                * &lt;/label&gt;
                * &lt;/div&gt;<br>
                * &lt;script&gt;
                * $("#grpbtn").ejmGroupButton({"windows.renderDefault": false});
                * &lt;/script&gt;<br>
                * @example 
                * // Get or set the windows mode renderDefault API, after initialization:
                * // Get the windows mode renderDefault value  
                * $("#grpbtn").ejmGroupButton("option", "windows.renderDefault");   
                * // Set the windows mode renderDefault value 
                *$("#grpbtn").ejmGroupButton("option", "windows.renderDefault", false); 
                * @memberof ejmGroupButton
                * @instance
                */
                "renderDefault": false
            },
            /**    
            * Event triggers when the touchstart happens in the groupbutton
            * @event
            * @name ejmGroupButton#touchStart 	
            * @param {Object} argument Event parameters from groupbutton     
            * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
            * @param {boolean} argument.model returns the groupbutton model
            * @param {boolean} argument.type returns the name of the event
            * @param {boolean} argument.text returns the current button text
            * @example 
            * // Define the touchStart event in unobtrusive way.
            * &lt;div id="grpbtn" data-role="ejmgroupbutton" data-ej-touchstart="touchstart"&gt;
            * &lt;label&gt;
            * &lt;input type="radio"/&gt;ipad
            * &lt;/label&gt;
            * &lt;label&gt;
            * &lt;input type="radio"/&gt;ipod
            * &lt;/label&gt;
            * &lt;/div&gt;<br>
            * &lt;script&gt;
            * // touchStart event for groupbutton 
            * function touchstart(args){ //handle the event
            * }
            * &lt;/script&gt;
            * @example 
            * // touchStart event for groupbutton
            * &lt;div id="grpbtn"&gt;
            * &lt;label&gt;
            * &lt;input type="radio" data-role="none" /&gt;ipad
            * &lt;/label&gt;
            * &lt;label&gt;
            * &lt;input type="radio" data-role="none" /&gt;ipod
            * &lt;/label&gt;
            * &lt;/div&gt;<br>
            * &lt;script&gt;
            * $("#grpbtn").ejmGroupButton({
            * touchStart: function (args) { //handle the event 
            * }
            * });     
            * &lt;/script&gt;<br>
            * @memberof ejmGroupButton
            * @instance
            */
            touchStart: null,

            /**    
            * Event triggers when the touchend happens in the groupbutton
            * @event
            * @name ejmGroupButton#touchEnd 	
            * @param {Object} argument Event parameters from groupbutton     
            * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
            * @param {boolean} argument.model returns the groupbutton model
            * @param {boolean} argument.type returns the name of the event
            * @param {boolean} argument.text returns the selected button text
            * @example 
            * // Define the touchend event in unobtrusive way.
            * &lt;div id="grpbtn" data-role="ejmgroupbutton" data-ej-touchend="touchend"&gt;
            * &lt;label&gt;
            * &lt;input type="radio" /&gt;ipad
            * &lt;/label&gt;
            * &lt;label&gt;
            * &lt;input type="radio" /&gt;ipod
            * &lt;/label&gt;
            * &lt;/div&gt;<br>
            * &lt;script&gt;
            * // touchEnd event for groupbutton 
            * function touchend(args){ //handle the event 
            * }
            * &lt;/script&gt;
            * @example 
            * // touchEnd event for groupbutton
            * &lt;div id="grpbtn"&gt;
            * &lt;label&gt;
            * &lt;input type="radio" data-role="none" /&gt;ipad<br>
            * &lt;/label&gt;
            * &lt;label&gt;
            * &lt;input type="radio" data-role="none" /&gt;ipod<br>
            * &lt;/label&gt;
            * &lt;/div&gt;<br>
            * &lt;script&gt;
            * $("#grpbtn").ejmGroupButton({
            * touchEnd: function (args) { //handle the event 
            * }
            * });           
            * &lt;/script&gt;<br>
            * @memberof ejmGroupButton
            * @instance
            */
            touchEnd: null
        },
        dataTypes: {
            renderMode: "enum",
            theme: "enum",
            enablePersistence: "boolean"
        },
        observables: ["selectedItemIndex"],
        selectedItemIndex: ej.util.valueFunction("selectedItemIndex"),
        /**
        * Create the GroupButton widget
        * @private
        */

        // constructor function
        _init: function () {
            this._orgEle = this.element.clone();
            this._renderControl();
            this._setWidth();
            this._setControlWidth();
            this._wireEvents(false);
        },

        /**
        * Render Section For groupbutton control	
        * @private
        */
        //To render the groupbutton control
        _renderControl: function () {
            ej.setRenderMode(this);
            ej.setTheme(this);

            if (!this.model.items) {
                this.model.items = [];
                btnelement = this.element.children();
                var buttoncount = this.element.children().length
                for (i = 0; i < buttoncount; i++) {
                    var item = {};
                    item.imageClass = ej.getAttrVal(btnelement[i], 'data-ej-imageclass');
                    item.imageUrl = ej.getAttrVal(btnelement[i], 'data-ej-imageurl');
                    this.model.items.push(item);
                }
            }
            else {
                for (i = 0; i < this.model.items.length; i++) {
                    var inner = ej.buildTag('button');
                    var btntext = this.model.items[i].text;
                    var contenttext = this.model.items[i].content;
                    this.element.append(inner.html(btntext || contenttext || "button"));
                }
            }


            if (this.model.renderMode == "windows" && this.model.windows.renderDefault && ej.isMobile())
                this.model.theme = "default";

            this._groupItems = this.element.children();
            this._count = this._groupItems.length;

            this.element.addClass("e-m-grpbtn e-m-" + this.model.renderMode + " e-m-" + this.model.theme);

            var activeState = false;


            var grpbtn = this.element.find("label").length > 0 ? this.element.find("label") : this.element.find("button");

            var proxy = this;
            $.each(this._groupItems, function (indx, val) {

                /**		
                * Specifies the groupbutton imageclass.
                * @name imageclass
                * @default null
                * @type {string}
                * @example 
                * // Set the imageclass property in unobtrusive way.
                * &lt;div id="grpbtn" data-role="ejmgroupbutton"&gt;
                * &lt;label data-ej-imageclass="class-ipad"&gt;
                * &lt;input type="radio"/&gt;ipad
                * &lt;/label&gt;
                * &lt;label data-ej-imageclass="class-ipod"&gt;
                * &lt;input type="radio"/&gt;ipod<br>
                * &lt;/label&gt;
                * &lt;/div&gt;		    
                * @memberof ejmGroupButton
                * @instance
                */
                imageClass = proxy.model.items[indx].imageClass;

                /**		
                * Specifies the groupbutton imageurl.
                * @name imageurl
                * @default null
                * @type {string}
                * @example 
                * // Set the imageurl property in unobtrusive way.
                * &lt;div id="grpbtn" data-role="ejmgroupbutton"&gt;
                * &lt;label data-ej-imageurl="ipad.png"&gt;
                * &lt;input type="radio"/&gt;ipad
                * &lt;/label&gt;
                * &lt;label data-ej-imageurl="ipod.png"&gt;
                * &lt;input type="radio"/&gt;ipod
                * &lt;/label&gt;
                * &lt;/div&gt;
                * @memberof ejmGroupButton
                * @instance
                */
                imagePath = proxy.model.items[indx].imageUrl;
                if (imageClass){
                    $(this).addClass(imageClass);
                    $(this).addClass("e-m-gbimage");
                }
                else if (imagePath) {
                    $(this).css({ "background-image": "url('" + imagePath + "')" });
                    $(this).addClass("e-m-gbimage");
                    if ($(this).text().trim() == "")
                        $(this).addClass("e-m-imageonly");
                }
                grpbtn.addClass("e-m-btn e-m-default");
            });

            if (this.model.renderMode == "ios7") {
                this.element.find(".e-m-btn:first").addClass("e-m-corner-left");
                this.element.find(".e-m-btn:last").addClass("e-m-corner-right");
            }
            this._selectItem(this.selectedItemIndex());
        },

        /**
        * Section for calculating width for equal buttons in iOS mode GroupButton control
        * @private
        */
        _setWidth: function () {
            var width = 0, ele;
            if (this.model.renderMode == "ios7") {
                ele = this.element.find('.e-m-btn');
                $.each(ele, function (indx, val) {
                    width = width > ej.getDimension(val, 'width') ? width : ej.getDimension(val, 'width');
                });
                width = width + 1;
                this._width = width;
                $(ele).css({ "min-width": width + "px" });
            }
        },

        /**
        * Section for calculating total width of GroupButton control		
        * @private
        */
        _setControlWidth: function () {
            var width = 0, ele = this.element.find('.e-m-btn'), renderModeTemp = this.model.renderMode, iosWidth = this._width;
            $.each(ele, function (indx, val) {
                width = width + ej.getDimension(val, 'outerWidth');
            });
            if (this.model.renderMode != "ios7")
                width = width + 1;
            $(this.element).css({ "min-width": width + "px" });
        },

        /**
        * Wiring the events to groupbutton control		
        * @private
        */
        _wireEvents: function (remove) {
            this._touchStartHandler = $.proxy(this._touchStartHandler, this);
            this._touchEndHandler = $.proxy(this._touchEndHandler, this);
            var selector = this.element.find(".e-m-btn");
            ej.listenEvents([selector, selector], [ej.startEvent(), ej.endEvent()], [this._touchStartHandler, this._touchEndHandler], remove);
        },

        /**
        * Section for handling the touchstart event
        * @private
        */
        _touchStartHandler: function (evt) {
            $(this.element.children()[this.model.selectedItemIndex]).removeClass("e-m-active").addClass("e-m-default")
            $(evt.target).addClass("e-m-state-glow");
            $(evt.target).removeClass('e-m-default').addClass('e-m-active');
            this.currentText = $(evt.target).text();
            this.data = { text: this.currentText.trim() };
            if (this.model.touchStart)
                this._trigger("touchStart", this.data);
        },

        /**
        * Section for handling the touchend event
        * @private
        */
        _touchEndHandler: function (evt) {
            var parent = $(evt.currentTarget);
            this.model.selectedItemIndex = parent.index();
            parent.removeClass("e-m-state-glow");
            if ((parent.find('input').length == 0) || (parent.find("input[type='groupbutton']").length == 0)) {
                this.element.find('.e-m-active').removeClass('e-m-active').addClass('e-m-default').find("input[type='radio']").attr("checked", false);
                parent.removeClass('e-m-default').addClass('e-m-active').find("input[type='radio']").attr("checked", true);
            }
            else {
                if (parent.find("input").is(":checked"))
                    parent.removeClass('e-m-active').addClass('e-m-default');
                else
                    parent.removeClass('e-m-default').addClass('e-m-active');
            }
            this.selectedItemIndex($(evt.currentTarget).index());
            if (this.model.touchEnd)
                this._trigger("touchEnd", this.data);
        },
        /**
        * Section for handling the selectedItemIndex property
        *@private
        */
        _selectItem: function (index) {
            if (index >= 0) {
                this.selectedItemIndex(index);
                this.element.find('.e-m-active').removeClass("e-m-active").addClass("e-m-default");
                $(this.element.find('.e-m-btn')[this.selectedItemIndex()]).removeClass("e-m-default").addClass("e-m-active");
                $(this.element.find("input")[this.selectedItemIndex()]).attr("checked", true);
                this.currentText = $(this.element.find('.e-m-btn')[this.selectedItemIndex()]).text();
                this.data = { text: this.currentText.trim() };
                if (this.model.touchend)
                    this._trigger("touchend", this.data);
            }
        },

        /**
        * To configure the properties at runtime using SetModel		
        * @private
        */
        _setModel: function (options) {
            var refresh = false;
            for (var prop in options) {
                var setModel = "_set" + prop.charAt(0).toUpperCase() + prop.slice(1);
                var tempProp = (typeof (options[prop]) == "function") ? this[prop]() : options[prop];
                if (this[setModel])
                    this[setModel](tempProp);
                else
                    refresh = true;
            }
            if (refresh)
                this._refresh();
        },
        /**
        * To configure the Theme property at runtime using SetModel	
        * @private
        */
        _setTheme: function (theme) {
            this.model.theme = theme;
            this.element.removeClass("e-m-dark e-m-light e-m-default").addClass("e-m-" + theme);
        },
        /**
        * To configure the selectedItemIndex property at runtime using SetModel	
        * @private
        */
        _setSelectedItemIndex: function (index) {
            this._selectItem(index);
        },
        _refresh: function () {
            this._destroy();
            this.element.addClass("ejm-groupbutton");
            this._renderControl();
            this._setWidth();
            this._setControlWidth();
            this._wireEvents(false);
        },

        _clearElement: function () {
            this.element.removeAttr("class")
            this.element.html(this._orgEle.html());
        },

        /**
        * destroy the GroupButton widget
        * all events bound using this._on will be unbind automatically and bring the control to pre-init state.
        * @alias destroy
        * @return jQuery
        * @example 
        * &lt;div id="grpbtn" &gt;<br>
        * &lt;label&gt;
        * &lt;input type="radio"/&gt;ipad
        * &lt;/label&gt;
        * &lt;label&gt;
        * &lt;input type="radio"/&gt;ipod
        * &lt;/label&gt;
        * &lt;/div&gt;<br>
        * &lt;script&gt; 
        * // Get the instance of the group button
        * var grpObj = $("#grpbtn").data("ejmGroupButton");
        * grpObj.destroy();
        * &lt;/script&gt;
        * @example 
        * &lt;div id="grpbtn" data-role="ejmgroupbutton"&gt;
        * &lt;label&gt;
        * &lt;input type="radio" /&gt;ipad<br>
        * &lt;/label&gt;
        * &lt;label&gt;
        * &lt;input type="radio" /&gt;ipod<br>
        * &lt;/label&gt;
        * &lt;/div&gt;<br>
        * &lt;script&gt;
        * // destroy the GroupButton
        * $("#grpbtn").ejmGroupButton("destroy");	
        * &lt;/script&gt;
        * @memberof ejmGroupButton
        * @instance
        */

        // all events bound using this._on will be unbind automatically
        _destroy: function () {
            this._wireEvents(true);
            this._clearElement();
        }

    });
})(jQuery, Syncfusion);