/**
* @fileOverview Plugin to style the Html Header elements
* @copyright Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/

(function ($, ej, undefined) {
    /**
    * @namespace ej
    * @class ejmHeader
    * @requires jQuery
    * @requires ej.mobile.application
    * @requires ej.core
    * @requires ej.unobtrusive
    * @requires ej.mobile.core
    * @requires ej.data
    * @requires ej.touch
    * @requires ej.mobile.button
    * @classdesc Custom Design for Html Header control.
    * @example 
    * &lt;div id="header" &gt;&lt;/div&gt;<br>
    * &lt;script&gt; 
    * // Create header  
    * $("#header").ejmHeader(); 
    * &lt;/script&gt;
    * @example 
    * &lt;div id="header" data-role="ejmheader" &gt;&lt;/div&gt;<br>
    */
    // ejmHeader is the plugin name 
    // "ej.mobile.Header" is "namespace.className" will hold functions and properties

    ej.widget("ejmHeader", "ej.mobile.Header", {
        _setFirst: true,
        _rootCSS: "e-m-header",
        // default model
        defaults: {
            /**		
            * If this property is set to true, header will be visible for iOS7 rendermode alone.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the hideForUnSupportedDevice property in unobtrusive way.
            * &lt;div id="header" data-role="ejmheader" data-ej-hideforunsupporteddevice=true &gt;&lt;/div&gt;<br>	
            * @example
            * //Set hideForUnSupportedDevice on initialization.             
            * &lt;div id="header"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * //To set hideForUnSupportedDevice API value 
            * $(function(){
            * $("#header").ejmHeader({ hideForUnSupportedDevice: true });	
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the hideForUnSupportedDevice, after initialization:<br>
            * // Get the hideForUnSupportedDevice API value.		
            *  $("#header").ejmHeader ("option", "hideForUnSupportedDevice");			
            * // Set the hideForUnSupportedDevice  API
            * $("#header").ejmHeader ("option", "hideForUnSupportedDevice", "Header");
            * @memberof ejmHeader
            * @instance
            */
            hideForUnSupportedDevice: false,
            /**		
            * Specifies the navigation url, which the page should go while clicking the left button. {@link ejmHeader#showLeftButton}
            * @default null
            * @type {string}
            * @example 
            * //Set the leftButtonNavigationUrl property in unobtrusive way.
            * &lt;div id="header" data-role="ejmheader" data-ej-showleftbutton="true" data-ej-leftbuttonnavigationurl="" &gt;&lt;/div&gt;<br>
            * @example
            * //Set leftButtonNavigationUrl on initialization.             
            * &lt;div id="header"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * //To set leftButtonNavigationUrl API value 
            * $(function(){
            * $("#header").ejmHeader({ leftButtonNavigationUrl: "" });	
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the leftButtonNavigationUrl, after initialization:<br>
            * // Get the leftButtonNavigationUrl API value.		
            *  $("#header").ejmHeader ("option", "leftButtonNavigationUrl");			
            * // Set the leftButtonNavigationUrl  API
            * $("#header").ejmHeader ("option", "leftButtonNavigationUrl", "Header");
            * @memberof ejmHeader
            * @instance
            */
            leftButtonNavigationUrl: null,
            leftButtonImageClass: null,
            leftButtonImageUrl: null,
            /**		
            * Specifies the navigation url, which the page should go while clicking the right button. {@link ejmHeader#showRightButton}
            * @default null
            * @type {string}
            * @example 
            * //Set the rightButtonNavigationUrl property in unobtrusive way.
            * &lt;div id="header" data-role="ejmheader" data-ej-showrightbutton="true" data-ej-rightbuttonnavigationurl="" &gt;&lt;/div&gt;<br>
            * @example
            * //Set rightButtonNavigationUrl on initialization.             
            * &lt;div id="header"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * //To set rightButtonNavigationUrl API value 
            * $(function(){
            * $("#header").ejmHeader({ rightButtonNavigationUrl: "" });	
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the rightButtonNavigationUrl, after initialization:<br>
            * // Get the rightButtonNavigationUrl API value.		
            *  $("#header").ejmHeader ("option", "rightButtonNavigationUrl");			
            * // Set the rightButtonNavigationUrl  API
            * $("#header").ejmHeader ("option", "rightButtonNavigationUrl", "Header");
            * @memberof ejmHeader
            * @instance
            */
            rightButtonNavigationUrl: null,
            rightButtonImageClass: null,
            rightButtonImageUrl: null,            /**		
            * Specifies the title's text.
            * @default Title
            * @type {string}
            * @example 
            * //Set the title property in unobtrusive way.
            * &lt;div id="header" data-role="ejmheader" data-ej-title="Header" &gt;&lt;/div&gt;<br>
            * @example
            * // Set title on initialization.             
            * &lt;div id="header"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * //To set title API value 
            * $(function(){
            * $("#header").ejmHeader({ title: "Title" });	
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the title, after initialization:<br>
            * // Get the title API value.		
            *  $("#header").ejmHeader ("option", "title");			
            * // Set the title  API
            * $("#header").ejmHeader ("option", "title", "Header");			
            * @memberof ejmHeader
            * @instance
            */
            title: "Title",
            /**		
            * Specifies whether to show the title or not. if this property is set to false, title will be hide.
            * @default true
            * @type {boolean}
            * @example 
            * //Set the showTitle property in unobtrusive way.
            * &lt;div id="header" data-role="ejmheader" data-ej-showtitle=false &gt;&lt;/div&gt;<br>
            * @example 
            * &lt;div id="header"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * // Set showTitle on initialization. 
            * //To set showTitle API value 
            * $("#header").ejmHeader({ showTitle: false });	
            * &lt;/script&gt;
            * @example 
            * //Get or set the showTitle, after initialization:<br>
            * // Get the showTitle API value.		
            *  $("#header").ejmHeader ("option", "showTitle");			
            * // Set the showTitle  API
            * $("#header").ejmHeader ("option", "showTitle", false);   			
            * @memberof ejmHeader
            * @instance
            */
            showTitle: true,
            /**		
            * Specifies whether to keep the header in fixed position. i.e. top or in relative position depends on the other element's position. See {@link Position}
            * @default ej.mobile.Header.Position.Fixed
            * @type {enum}
            * @example 
            * //Set the position property in unobtrusive way.
            * &lt;div id="header" data-role="ejmheader" data-ej-position="normal" &gt;&lt;/div&gt;<br>
            * @example 
            * &lt;div id="header"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * // Set position on initialization. 
            * //To set position API value 
            * $(function(){
            * $("#header").ejmHeader({ position: ej.mobile.Header.Position.Fixed });	
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the position, after initialization:<br>
            * // Get the position API value.		
            *  $("#header").ejmHeader ("option", "position");			
            * // Set the position  API
            * $("#header").ejmHeader ("option", "position", ej.mobile.Header.Position.Fixed);			
            * @memberof ejmHeader
            * @instance
            */
            position: "fixed",
            /**		
            * Specifies the caption of the left button. {@link ejmHeader#showLeftButton}
            * @default Back
            * @type {string}
            * @example 
            * //Set the leftButtonCaption property in unobtrusive way.
            * &lt;div id="header" data-role="ejmheader" data-ej-showLeftbutton="true" data-ej-leftbuttoncaption="Home" &gt;&lt;/div&gt;<br>
            * @example 
            * &lt;div id="header"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * // Set leftButtonCaption on initialization. 
            * //To set leftButtonCaption API value 
            * $("#header").ejmHeader({ showLeftButton:true});
            * $("#header").ejmHeader({ leftButtonCaption: "Home" });
            * &lt;/script&gt;
            * @example 
            * //Get or set the LeftButtonCaption, after initialization:<br>
            * // Get the leftButtonCaption API value.		
            *  $("#header").ejmHeader ("option", "leftButtonCaption");			
            * // Set the leftButtonCaption  API
            * $("#header").ejmHeader ("option", "leftButtonCaption", "Home");			
            * @memberof ejmHeader
            * @instance
            */
            leftButtonCaption: "Back",
            /**		
            * Specifies the caption of the right button. {@link ejmHeader#showRightButton}
            * @default Right
            * @type {string}
            * @example 
            * //Set the rightButtonCaption property in unobtrusive way.
            * &lt;div id="header" data-role="ejmheader" data-ej-showrightbutton="true" data-ej-rightbuttoncaption="Next" &gt;&lt;/div&gt;<br>
            * @example 
            * &lt;div id="header"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * // Set rightButtonCaption on initialization. 
            * //To set rightButtonCaption API value 
            * $("#header").ejmHeader({showRightButton:true});
            * $("#header").ejmHeader({ rightButtonCaption: "Next" });
            * &lt;/script&gt;
            * @example 
            * //Get or set the rightButtonCaption, after initialization:<br>
            * // Get the rightButtonCaption API value.		
            *  $("#header").ejmHeader ("option", "rightButtonCaption");			
            * // Set the rightButtonCaption  API
            * $("#header").ejmHeader ("option", "rightButtonCaption", "Next");			
            * @memberof ejmHeader
            * @instance
            */
            rightButtonCaption: "Right",
            /**		
            * Specifies the style for the left button i.e. back button or normal button. See {@link HeaderLeftButtonStyle}
            * @default ej.mobile.Button.IOS7.Style.Back
            * @type {enum}
            * @example 
            * //Set the leftButtonStyle property in unobtrusive way.
            * &lt;div id="header" data-role="ejmheader" data-ej-showleftbutton="true" data-ej-leftbuttonstyle="back" &gt;&lt;/div&gt;<br>
            * @example 
            * &lt;div id="header"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * // Set leftButtonStyle on initialization. 
            * //To set leftButtonStyle API value 
            * $(function(){
            * $("#header").ejmHeader({ showLeftButton:true});
            * $("#header").ejmHeader({ leftButtonStyle: ej.mobile.Button.IOS7Style.Back });
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the leftButtonStyle, after initialization:<br>
            * // Get the leftButtonStyle API value.		
            *  $("#header").ejmHeader ("option", "leftButtonStyle");			
            * // Set the leftButtonStyle  API
            * $("#header").ejmHeader ("option", "leftButtonStyle", ej.mobile.Button.IOS7.Style.Back);			
            * @memberof ejmHeader
            * @instance
            */
            leftButtonStyle: "back",
            /**		
            * Specifies the style for the right button i.e. back button or normal button. See {@link HeaderRightButtonStyle}
            * @default ej.mobile.Button.IOS7.Style.Header
            * @type {enum}
            * @example 
            * //Set the rightButtonStyle property in unobtrusive way.
            * &lt;div id="header" data-role="ejmheader" data-ej-showrightbutton="true" data-ej-rightbuttonstyle="normal" &gt;&lt;/div&gt;<br>
            * @example 
            * &lt;div id="header"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * // Set rightButtonStyle on initialization. 
            * //To set rightButtonStyle API value 
            * $(function(){
            * $("#header").ejmHeader({showRightButton:true});
            * $("#header").ejmHeader({ rightButtonStyle: ej.mobile.Button.IOS7.Style.Header });
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the rightButtonStyle, after initialization:<br>
            * // Get the rightButtonStyle API value.		
            *  $("#header").ejmHeader ("option", "rightButtonStyle");			
            * // Set the rightButtonStyle  API
            * $("#header").ejmHeader ("option", "rightButtonStyle", ej.mobile.Button.IOS7.Style.Header);			
            * @memberof ejmHeader
            * @instance
            */
            rightButtonStyle: "header",
            /**		
            * Changes the rendering mode of the header.See {@link RenderMode}
            * @default auto
            * @type {enum}
            * @example 
            * //Set the renderMode property in unobtrusive way.
            * &lt;div id="header" data-role="ejmheader" data-ej-rendermode="auto" &gt;&lt;/div&gt;<br>
            * @example 
            * &lt;div id="header"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * // Set rendermode on initialization. 
            * //To set renderMode API value 
            * $(function(){
            * $("#header").ejmHeader({ renderMode: ej.mobile.RenderMode.Auto });	
            * });	
            * &lt;/script&gt;
            * @example 
            * //Get or set the renderMode, after initialization:<br>
            * // Get the renderMode API value.		
            *  $("#header").ejmHeader ("option", "renderMode");			
            * // Set the renderMode  API
            * $("#header").ejmHeader ("option", "renderMode", ej.mobile.RenderMode.Auto);			
            * @memberof ejmHeader
            * @instance
            */
            renderMode: "auto",
            /**		
            * Changes the theme of the header. See {@link Theme}
            * @default auto 
            * @type {enum}
            * @example 
            * //Set the theme property in unobtrusive way.
            * &lt;div id="header" data-role="ejmheader" data-ej-theme="auto" &gt;&lt;/div&gt;<br>
            * @example 
            * &lt;div id="header"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * // Set theme on initialization. 
            * //To set theme API value 
            * $(function(){
            * $("#header").ejmHeader({ theme:  ej.mobile.Theme.Auto });	
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the theme, after initialization:<br>
            * // Get the theme API value.		
            *  $("#header").ejmHeader ("option", "theme");			
            * // Set the leftButtonCaption  API
            * $("#header").ejmHeader ("option", "theme",  ej.mobile.Theme.Auto);			
            * @memberof ejmHeader
            * @instance
            */
            theme: "auto",
            /**		
            * Specifies whether to show the left button or not.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the showLeftButton property in unobtrusive way.
            * &lt;div id="header" data-role="ejmheader" data-ej-showleftbutton=true &gt;&lt;/div&gt;<br>
            * @example 
            * &lt;div id="header"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * // Set showLeftButton on initialization. 
            * //To set showLeftButton API value 
            * $("#header").ejmHeader({ showLeftButton: true });	
            * &lt;/script&gt;
            * @example 
            * //Get or set the showLeftButton, after initialization:<br>
            * // Get the showLeftButton API value.		
            *  $("#header").ejmHeader ("option", "showLeftButton");			
            * // Set the showLeftButton  API
            * $("#header").ejmHeader ("option", "showLeftButton", "true");			
            * @memberof ejmHeader
            * @instance
            */
            showLeftButton: false,
            /**		
            * Specifies whether to show the right button or not.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the showRightButton property in unobtrusive way.
            * &lt;div id="header" data-role="ejmheader" data-ej-showrightbutton=true &gt;&lt;/div&gt;<br>
            * @example 
            * &lt;div id="header"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * // Set showRightButton on initialization. 
            * //To set showRightButton API value 
            * $("#header").ejmHeader({ showRightButton: true });	
            * &lt;/script&gt;
            * @example 
            * //Get or set the showRightButton, after initialization:<br>
            * // Get the showRightButton API value.		
            *  $("#header").ejmHeader ("option", "showRightButton");			
            * // Set the showRightButton  API
            * $("#header").ejmHeader ("option", "showRightButton", true);			
            * @memberof ejmHeader
            * @instance
            */
            showRightButton: false,
            /**		
            * Specifies the id of the element which is to be given as template.
            * @default null
            * @type {string}
            * @example 
            * //Set the templateId property in unobtrusive way.
            * &lt;div id="header" data-role="ejmheader" data-ej-templateid="headertemplate" &gt;&lt;/div&gt;<br>		          
            * @memberof ejmHeader
            * @instance
            */
            templateId: null,

            /**     
            * Section for android rendermode specific functionalities.                      
            * @memberof ejmHeader
            * @instance
            */
            android: {
                /**  
                * Specifies the class name in which URL for the back button image will be set.
                * @default null
                * @type {string}
                * @alias ejmHeader#android->backButtonImageClass
                * @example 
                * // Set the android mode backButtonImageClass property in unobtrusive way.
                * &lt;div id="header" data-role="ejmheader" data-ej-rendermode="android" data-ej-showleftbutton="true" data-ej-android-backbuttonimageclass="backimagecssclass" &gt;&lt;/div&gt;<br> 
                * @memberof ejmHeader
                * @instance
                */
                "backButtonImageClass": null
            },
            /**		
            * Current model value to browser cookies for state maintenance. While refreshing the page, the model value applied from browser cookies retains.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the enablePersistence property in unobtrusive way.
            * &lt;div id="header" data-role="ejmheader" data-ej-enablepersistence=true &gt;&lt;/div&gt;<br>
            * @example 
            * &lt;div id="header"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * // Set enablePersistence on initialization. 
            * //To set enablePersistence API value 
            * $("#header").ejmHeader({ enablePersistence:true });	
            * &lt;/script&gt;
            * @example 
            * //Get or set the header enablePersistence, after initialization:<br>
            * // Get the enablePersistence API value.		
            *  $("#header").ejmHeader ("option", "enablePersistence");			
            * // Set the enablePersistence API
            * $("#header").ejmHeader ("option", "enablePersistence", false);            
            * @memberof ejmHeader
            * @instance
            */
            enablePersistence: false,
            /**    
            * Event triggers when the left button is tapped. {@link ejmHeader#showLeftButton}
            * @event
            * @name ejmHeader#leftButtonTap 	
            * @param {boolean} argument.cancel if the event should be canceled; otherwise, false.
            * @param {boolean} argument.model returns the groupbutton model
            * @param {boolean} argument.type returns the name of the event
            * @param {boolean} argument.text returns the current button text
            * @example 
            * &lt;div id="header" data-role="ejmheader" data-ej-showleftbutton="true" data-ej-leftbuttontap="onLeftButtonTap"&gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // leftButtonTap event for header  
            * function onLeftButtonTap(args){ //handle the event
            * }
            * &lt;/script&gt;
            * @example 
            * &lt;div id="header"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * //LeftButtonTap event for header
            * $("#header").ejmHeader({showLeftButton:true, leftButtonTap:"test"});
            *     function test(){  //handle the event 
            * }
            * &lt;/script&gt;
            * @memberof ejmHeader
            * @instance
            */
            leftButtonTap: null,
            /**    
            * Event triggers when the right button is tapped. {@link ejmHeader#showRightButton}
            * @event
            * @name ejmHeader#rightButtonTap 	
            * @param {boolean} argument.cancel if the event should be canceled; otherwise, false.
            * @param {boolean} argument.model returns the groupbutton model
            * @param {boolean} argument.type returns the name of the event
            * @param {boolean} argument.text returns the current button text
            * @example
            * &lt;div id="header" data-role="ejmheader" data-ej-showrightbutton="true" data-ej-rightbuttontap="onRightButtonTap"&gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // rightButtonTap event for header  
            * function onRightButtonTap(args){ //handle the event
            * }
            * &lt;/script&gt;
            * @example 
            * &lt;div id="header"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * $("#header").ejmHeader({showRightButton:true, rightButtonTap:"test"});
            * function test(){ //handle the event 
            * }
            * &lt;/script&gt;			
            * @memberof ejmHeader
            * @instance
            */
            rightButtonTap: null,
            /**     
            * Section for windows rendermode specific functionalities.                      
            * @memberof ejmHeader
            * @instance
            */
            windows: {
                /**  
                * Specifies whether to render the header based on the windowsphone's current theme or not.
                * @default false
                * @type {boolean}
                * @alias ejmHeader#windows->renderDefault
                * @example 
                * // Set the windows mode renderDefault property in unobtrusive way.
                * &lt;div id="header" data-role="ejmheader" data-ej-rendermode="windows" data-ej-windows-renderdefault=true &gt;&lt;/div&gt;<br> 
                * @memberof ejmHeader
                * @instance
                */
                "renderDefault": false,
                /**  
                * By default windows title's text will be in small case. To override this behaviour, set this property to true.
                * @default false
                * @type {boolean}
                * @alias ejmHeader#windows->enableCustomText
                * @example 
                * // Set the windows mode enableCustomText property in unobtrusive way.
                * &lt;div id="header" data-role="ejmheader" data-ej-rendermode="windows" data-ej-windows-enablecustomtext=true data-ej-title="Windows Custom Text" &gt;&lt;/div&gt;<br> 
                * @memberof ejmHeader
                * @instance
                */
                "enableCustomText": false
            }
        },
        dataTypes: {
            showTitle: "boolean",
            position: "enum",
            leftButtonStyle: "enum",
            rightButtonStyle: "enum",
            renderMode: "enum",
            theme: "enum",
            windows: { "renderDefault": "boolean", "enableCustomText": "boolean" },
            enablePersistence: "boolean"
        },
        // constructor function
        _init: function () {
            ej.setRenderMode(this);
            ej.setTheme(this);
            if (this.model.renderMode == "windows" && this.model.windows.renderDefault && ej.isMobile())
                this.model.theme = "default";
            if (!this.model.hideForUnSupportedDevice || this.model.hideForUnSupportedDevice && (this.model.renderMode == "ios7")) {
                this._renderControl();
                if (ej.isIOSWebView() && ej.isIOS() && this.model.position == "fixed") {
                    this.element.addClass("e-m-webview");
                    ej.getCurrentPage().addClass("e-m-fixed-header");
                }
            }
        },
        //renderind header template 
        _renderHeaderTemplate: function () {
            this._templateContainer = ej.buildTag("div.e-m-header-content");
            var templateContent = ej.getCurrentPage().find("#" + this.model.templateId);
            if (templateContent.length) {
                this.element.empty();
                ej.destroyWidgets(templateContent);
                this._template = templateContent[0].nodeName && templateContent[0].nodeName.toLowerCase() == "script" ? ej.getClearString(templateContent[0].innerHTML) : templateContent;
            }
            else {
                this._template = this.element[0].innerHTML.trim();
                this.element.empty();
            }
            ej.widget.init(this._template);
            this.element.append(this._templateContainer.append(this._template));
        },
        //rendering default header
        _renderDefaultHeader: function () {
            this._headerContainer = ej.buildTag("div.e-m-header-content");
            if (this.element[0].innerHTML.trim() == "") {
                this.element.append(this._headerContainer);
                if (this["_" + this.model.renderMode + "ButtonProperties"])
                    this["_" + this.model.renderMode + "ButtonProperties"]();
            }
            else {
                this._template = this.element[0].innerHTML.trim();
                this.element.empty();
                this.element.append(this._headerContainer.append(this._template));
            }
        },
        _renderControl: function () {
            this._orgEle = $(this.element).clone();
            if (this.model.height > 0)
                $(this.element).css({ "height": this.model.height });
            if (this.model.width > 0)
                $(this.element).css({ "width": this.model.width });
            this.element.addClass("e-m-" + this.model.renderMode + " e-m-header e-m-" + this.model.position + " e-m-" + this.model.theme);
            if (this.model.templateId == null) {
                this._renderDefaultHeader();
            }
            else
                this._renderHeaderTemplate();
            var spanElemnt = this.element.find(".e-m-header-text");
            if (spanElemnt.length == 0 && !this._template && this.model.showTitle) {
                this._showHeaderTitle();
            }
        },
        _buttonProperties: function () {
            if (this.model.showLeftButton) {
                this._leftButtonCommon();
            }
            if (this.model.showTitle) {
                this._showHeaderTitle();
            }
            if (this.model.showRightButton) {
                this._rightButtonCommon();
            }
        },
        _leftButtonCommon: function () {
            this._leftButton = ej.buildTag("div.e-m-header-left");
            this._renderMode = this.model.renderMode;
            this._theme = this.model.theme;
            if (this.model.renderMode == "windows")
                this.model.leftButtonCaption = "";
            var buttonProp = { "data-role": "ejmactionlink", "data-ej-rendermode": this._renderMode, "data-ej-theme": this._theme };
            if (this.model.leftButtonImageClass) {
                buttonProp["data-ej-contenttype"] = "image";
                buttonProp["data-ej-imageposition"] = "center";
                buttonProp["data-ej-imageclass"] = this.model.leftButtonImageClass;
                this.model.leftButtonStyle = null;
                this.model.leftButtonCaption = "";
            }
            var backbtnTextLength = this.model.leftButtonCaption.length;
            var backbtnText = this.model.leftButtonCaption.substring(0, 8);
            if (backbtnTextLength > 8)
                backbtnText = backbtnText + "..";
            this.model.leftButtonCaption = backbtnText;
            this._leftButtonAnchorTag = ej.buildTag("a", this.model.leftButtonCaption, "", buttonProp);
            this._buttons(this._leftButton, this._leftButtonAnchorTag, this.model.leftButtonTap, this.model.leftButtonStyle, this.model.leftButtonNavigationUrl);
        },
        _rightButtonCommon: function () {
            this._rightButton = ej.buildTag("div.e-m-header-right");
            this._renderMode = this.model.renderMode;
            var buttonProp = { "data-role": "ejmactionlink", "data-ej-rendermode": this._renderMode, "data-ej-theme": this.model.theme };
            if (this.model.rightButtonImageClass) {
                buttonProp["data-ej-contenttype"] = "image";
                buttonProp["data-ej-imageposition"] = "center";
                buttonProp["data-ej-imageclass"] = this.model.rightButtonImageClass;
                this.model.rightButtonStyle = null;
                this.model.rightButtonCaption = "";
            }
            this._rightButtonAnchorTag = ej.buildTag("a", this.model.rightButtonCaption, "", buttonProp);
            this._buttons(this._rightButton, this._rightButtonAnchorTag, this.model.rightButtonTap, this.model.rightButtonStyle, this.model.rightButtonNavigationUrl);
        },
        _buttons: function (rootdiv, buttonCtrl, buttonclick, style, navigateURL) {
            buttonclick != null ? ((!buttonclick.name) ? buttonCtrl.attr("data-ej-touchend", buttonclick) : buttonCtrl.attr("data-ej-touchend", buttonclick.name)) : "";
            if (style)
                buttonCtrl.attr("data-ej-" + this._renderMode + "-style", style);
            if (navigateURL != null)
                buttonCtrl.attr('href', navigateURL);
            rootdiv.append(buttonCtrl);
            rootdiv.hasClass("e-m-header-left") ? this.element.find(".e-m-header-content").prepend(rootdiv) : this.element.find(".e-m-header-content").append(rootdiv);
            ej.widget.init(rootdiv);
        },
        _showHeaderTitle: function () {
            this._titleSpan = ej.buildTag("span.e-m-header-text e-m-" + this.model.theme + " e-m-user-select", this.model.renderMode == "windows" && ej.isMobile() ? this.model.windows.enableCustomText ? this.model.title : this.model.title.toLowerCase() : this.model.title, "", "");
            titleDiv = ej.buildTag("div.e-m-header-title", "", "", "").append(this._titleSpan);
            this._headerContainer.append(titleDiv);
            if (this.model.renderMode == "ios7" || this.model.renderMode == "flat") {
                if (this._titleSpan.text().length > 18) {
                    if (this.model.showLeftButton)
                        this._titleSpan.css("margin-left", "90px");
                    if (this.model.showRightButton)
                        this._titleSpan.css("margin-right", "70px");
                }
            }
            if (this.model.showLeftButton && this.model.showRightButton)
                this._headerContainer.find(".e-m-header-title");
        },
        _ios7ButtonProperties: function () {
            this._buttonProperties();
        },
        //To do android specific actions
        _androidButtonProperties: function () {
            if (this.model.showLeftButton && this.model.leftButtonImageClass == null) {
                this._leftDiv = ej.buildTag("div.e-m-header-left");
                this._spanTag = ej.buildTag("div.e-m-header-button e-m-fontimage");
                this._leftDiv.append(this._spanTag);
                this._headerContainer.prepend(this._leftDiv);
                if (this.model.android.backButtonImageClass) {
                    this._imageDiv = ej.buildTag("div." + this.model.android.backButtonImageClass, "", { 'display': 'table-cell', 'width': '43px', 'background-size':'35px 35px' ,'background-position': 'center', 'background-repeat': 'no-repeat' }, "");
                    this._imageDiv.insertAfter(this._leftDiv);
                }
                this._wireEvents(false);
            }
            if (this.model.showTitle)
                this._showHeaderTitle();
            if (this.model.showRightButton) {
                this._rightButtonCommon();

            }
        },
        _windowsButtonProperties: function () {
            this._buttonProperties();
        },
        _flatButtonProperties: function () {
            this._buttonProperties();
        },
        _wireEvents: function (remove) {
            this._touchStartHandler = $.proxy(this._onTouchStart, this);
            this._touchStopHandler = $.proxy(this._onTouchEnd, this);
            if (this.model.renderMode == "android" && this.model.showLeftButton) {
                ej.listenEvents([this._leftDiv, this._leftDiv, this._imageDiv, this._imageDiv], [ej.startEvent(), ej.endEvent(), ej.startEvent(), ej.endEvent()], [this._touchStartHandler, this._touchStopHandler, this._touchStartHandler, this._touchStopHandler], remove);
            }
        },
        _onTouchStart: function () {
            this.element.find(this._leftDiv).addClass("active");
            this.element.find(this._imageDiv).addClass("active");
        },
        _onTouchEnd: function () {
            this.element.find(this._leftDiv).removeClass("active");
            this.element.find(this._imageDiv).removeClass("active");
            history.back();
            if (this.model.leftButtonTap)
                this._trigger("leftButtonTap");
        },
        /**
        * To configure the showLeftButton of the Header		
        * @private
        */
        _setShowLeftButton: function (showStatus) {
            this.model.showLeftButton = showStatus;
            if (!this._leftButton) {
                if (this.model.renderMode == "android" || this.model.leftButtonImageClass != null) {
                    this._androidButtonProperties();
                }
                else {
                    this._leftButtonCommon();
                }
            }
            else {
                this._leftButton[showStatus ? "show" : "hide"]();
            }
        },
        /**
        * To configure the leftButtonStyle of the Header		
        * @private
        */
        _setLeftButtonStyle: function (style) {
            this.element.find(this._leftButtonAnchorTag).ejmActionlink({ 'style': style });
        },
        /**
        * To configure the showRightButton of the Header		
        * @private
        */
        _setShowRightButton: function (showStatus) {
            this.model.showRightButton = showStatus;
            if (!this._rightButton) {
                this._rightButtonCommon();
            }
            else {
                this._rightButton[showStatus ? "show" : "hide"]();
            }
        },
        /**
        * To configure the rightButtonStyle of the Header		
        * @private
        */
        _setRightButtonStyle: function (style) {
            this.element.find(this._rightButtonAnchorTag).ejmActionlink({ 'style': style });
        },
        /**
        * To configure the showTitleshowTitle Property of the Header		
        * @private
        */
        _setShowTitle: function (showStatus) {
            this.model.showTitle = showStatus;
            this._titleSpan[showStatus ? "show" : "hide"]();
        },
        /**
        * To configure the title of the Header		
        * @private
        */
        _setTitle: function (title) {
            if (this._titleSpan) {
                this.model.title = (this.model.renderMode != "windows" || this.model.windows.enableCustomText) ? title : title.toLowerCase();
                this._titleSpan.html(this.model.title);
            }
        },
        /**
        * To configure the leftButtonCaption of the Header		
        * @private
        */
        _setLeftButtonCaption: function (caption) {
            this.model.leftButtonCaption = caption;
            this.element.find(this._leftButtonAnchorTag).html(caption);
        },
        /**
        * To configure the rightButtonCaption of the Header		
        * @private
        */
        _setRightButtonCaption: function (caption) {
            this.model.rightButtonCaption = caption;
            this.element.find(this._rightButtonAnchorTag).html(caption);
        },
        /**
        * To configure the leftButtonTap property of the Header		
        * @private
        */
        _setLeftButtonTap: function (caption) {
            this.model.leftButtonTap = caption;
            this.element.find(this._leftButtonAnchorTag).ejmActionlink({ "touchEnd": caption });
        },
        /**
        * To configure the rightButtonTap property of the Header		
        * @private
        */
        _setRightButtonTap: function (caption) {
            this.model.rightButtonTap = caption;
            this.element.find(this._rightButtonAnchorTag).ejmActionlink({ "touchEnd": caption });
        },
        _setModel: function (options) {
            var refresh = false;
            for (var prop in options) {
                var setModel = "_set" + prop.charAt(0).toUpperCase() + prop.slice(1);
                if (prop == "renderMode" || prop == "position")
                    refresh = true;
                else {
                    if (this[setModel])
                        this[setModel](options[prop]);
                }
            }
            if (refresh)
                this._refresh();
        },
        /**
        * To configure the theme of the Header		
        * @private
        */
        _setTheme: function (theme) {
            this.model.theme = theme;
            this.element.removeClass("e-m-light e-m-dark").addClass("e-m-" + theme.toLowerCase());
            this.element.find(".e-m-header-left .e-m-btn").ejmActionlink({ "theme": theme });
            this.element.find(".e-m-header-right .e-m-btn").ejmActionlink({ "theme": theme });
        },
        _refresh: function () {
            this._destroy();
            this.element.addClass("e-m-header");
            this._renderControl();
            this._wireEvents(false);
        },
        _clearElement: function () {
            this.element.removeAttr("class");
            this.element.html(this._orgEle.html());
        },
        _destroy: function () {
            this._clearElement();
            this._wireEvents(true);
        },

        /*---------------Public Methods---------------*/
        /**
        * To get the header's text
        * @return jQuery
        * @example 
        * &lt;div id="header" data-role="ejmheader" &gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * $(function(){
        * // To get the instance of the Header
        * var header = $("#header").data("ejmHeader");
        * header.getTitle(); // returns the header's text
        * });
        * &lt;/script&gt;
        * @example 
        * &lt;div id="header"&gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * $(function(){
        * $("#header").ejmHeader();	
        * // get the header's current value
        * $("#header").ejmHeader("getTitle");	
        * });
        * &lt;/script&gt;
        *@memberof ejmHeader
        * @instance
        */
        getTitle: function () {
            if (this._titleSpan)
                return this._titleSpan.html();
        }
        /*---------------Public Methods End---------------*/

    });

    /**
    * Enum for Position
    * @enum {string}
    * @global
    */
    ej.mobile.Header.Position = {
        /**
        Enum for relative position for Header*/
        Normal: "normal",
        /**
        Enum for fixed position for Header*/
        Fixed: "fixed"
    }

    /**
    * Enum for HeaderLeftButtonStyle
    * @enum {string}
    * @global
    */
    ej.mobile.Header.HeaderLeftButtonStyle = {
        /**
        Enum for Back left button style for Header*/
        Back: "back",
        /**
        Enum for Header left button style for Header*/
        Header: "header",
        /**
        Enum for Normal left button style for Header*/
        Normal: "normal"
    }

    /**
    * Enum for HeaderRightButtonStyle
    * @enum {string}
    * @global
    */
    ej.mobile.Header.HeaderRightButtonStyle = {
        /**
        Enum for Header right button style for Header*/
        Header: "header",
        /**
        Enum for Normal right button style for Header*/
        Normal: "normal"
    }
})(jQuery, Syncfusion);