/**
* @fileOverview Plugin to style the Html ListView elements
* @copyright Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/

(function ($, ej, undefined) {
    //mListView is the plugin name 
    //"m.ListView" is "namespace.className" will hold functions and properties
    /**
    * @namespace ej
    * @class ejmListView
    * @requires jQuery
    * @requires ej.mobile.application
    * @requires ej.core
    * @requires ej.unobtrusive
    * @requires ej.mobile.core
    * @requires ej.data
    * @requires ej.touch
    * @requires ej.mobile.checkbox
    * @requires ej.mobile.button
    * @requires ej.mobile.header
    * @requires ej.mobile.scrollbar
    * @requires ej.mobile.scrollpanel
    * @requires ej.mobile.textbox
    * @requires ej.listviewbase
    * @classdesc Custom Design for Html ListView control.
    * @example 
    * //Set listbox in unobtrusive way.
    * &lt;div id="lb" data-role="ejmlistview"&gt;
    *	 &lt;ul&gt;
    *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
    * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
    *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
    *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
    *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
    *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
    * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
    *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
    *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
    *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
    * 	&lt;/ul&gt;
    * &lt;/div&gt;
    * @example 
    * //Set listbox in obtrusive way.
    * &lt;div id="lb"&gt;
    *	 &lt;ul&gt;
    *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
    * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
    *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
    *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
    *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
    *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
    * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
    *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
    *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
    *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
    * 	&lt;/ul&gt;
    * &lt;/div&gt;
    * &lt;script&gt; 
    * // Create ListView
    * $("#lb").ejmListView(); 
    * &lt;/script&gt;
    */
    ej.widget("ejmListView", "ej.mobile.ListView", {
        _setFirst: true,
        _rootCSS: "e-m-lv",
        //Default model values
        _prefixClass: "e-m-",
        defaults: {
            /**		
            * Specifies whether need to show the scroll bars when scrolling is allowed.
            * @default true
            * @type {boolean}
            * @example 
            * //Set the showScrollbars property in unobtrusive way.
            * &lt;div id="lb" data-role="ejmlistview" data-ej-showScrollbars="true"&gt;
            *	 &lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * //Set the showScrollbars property in obtrusive way.
            * &lt;div id="lb"&gt;
            *	 &lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * // Set showScrollbars on initialization. 
            * //To set showScrollbars API value 
            * $("#lb").ejmListView ({ showScrollbars: true });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set  showScrollbars, after initialization:<br>
            * // Get the showScrollbars API value.		
            *  $("#lb").ejmListView ("option", "showScrollbars");			
            * // Set the showScrollbars API
            * $("#lb").ejmListView ("option", "showScrollbars", true); 
            * &lt;/script&gt;           
            * @memberof ejmListView
            * @instance
            */
            showScrollbars: true,
            /**		
            * Specifies the title of the header.
            * @default Title
            * @type {string}
            * @example 
            * //Set the headerTitle property in unobtrusive way.
            * &lt;div id="lb" data-role="ejmlistview" data-ej-headerTitle="Title"&gt;
            *	 &lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * //Set the headerTitle property in obtrusive way.
            * &lt;div id="lb" &gt;
            *	 &lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * // Set headerTitle on initialization. 
            * //To set headerTitle API value 
            * $("#lb").ejmListView ({ headerTitle: "Title" });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set  headerTitle, after initialization:<br>
            * // Get the headerTitle API value.		
            *  $("#lb").ejmListView ("option", "headerTitle");			
            * // Set the headerTitle API
            * $("#lb").ejmListView ("option", "headerTitle", "Title");
            * &lt;/script&gt;
            * @memberof ejmListView
            * @instance
            */
            headerTitle: "Title",
            /**		
            * Specifies whether to show the back button in the header.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the showHeaderBackButton property in unobtrusive way.
            * &lt;div id="lb" data-role="ejmlistview" data-ej-showHeaderBackButton="true"&gt;
            *	 &lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * //Set the showHeaderBackButton property in obtrusive way.
            * &lt;div id="lb"&gt;
            *	 &lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * // Set showHeaderBackButton on initialization. 
            * //To set showHeaderBackButton API value 
            * $("#lb").ejmListView ({ showHeaderBackButton: true });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set  showHeaderBackButton, after initialization:<br>
            * // Get the showHeaderBackButton API value.		
            *  $("#lb").ejmListView ("option", "showHeaderBackButton");			
            * // Set the showHeaderBackButton API
            * $("#lb").ejmListView ("option", "showHeaderBackButton", true);   
            * &lt;/script&gt;         
            * @memberof ejmListView
            * @instance
            */
            showHeaderBackButton: false,
            /**		
            * Specifies whether to set the height as scroll height of the content automatically.
            * @default true
            * @type {boolean}
            * @example 
            * //Set the autoAdjustScrollHeight property in unobtrusive way.
            * &lt;div id="lb" data-role="ejmlistview" data-ej-autoAdjustScrollHeight="true"&gt;
            *	 &lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * //Set the autoAdjustScrollHeight property in obtrusive way.
            * &lt;div id="lb"&gt;
            *	 &lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * // Set autoAdjustScrollHeight on initialization. 
            * //To set autoAdjustScrollHeight API value 
            * $("#lb").ejmListView ({ autoAdjustScrollHeight: true });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set  autoAdjustScrollHeight, after initialization:<br>
            * // Get the autoAdjustScrollHeight API value.		
            *  $("#lb").ejmListView ("option", "autoAdjustScrollHeight");			
            * // Set the autoAdjustScrollHeight API
            * $("#lb").ejmListView ("option", "autoAdjustScrollHeight", true);
            * &lt;/script&gt;
            * @memberof ejmListView
            * @instance
            */
            autoAdjustScrollHeight: true,
            /**		
            * Specifies whether to set the height of the content automatically.
            * @default true
            * @type {boolean}
            * @example 
            * //Set the autoAdjustScrollHeight property in unobtrusive way.
            * &lt;div id="lb" data-role="ejmlistview" data-ej-autoAdjustHeight="true"&gt;
            *	 &lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * //Set the autoAdjustHeight property in obtrusive way.
            * &lt;div id="lb"&gt;
            *	 &lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * // Set autoAdjustHeight on initialization. 
            * //To set autoAdjustHeight API value 
            * $("#lb").ejmListView ({ autoAdjustHeight: true });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set  autoAdjustHeight, after initialization:<br>
            * // Get the autoAdjustHeight API value.		
            *  $("#lb").ejmListView ("option", "autoAdjustHeight");			
            * // Set the autoAdjustHeight API
            * $("#lb").ejmListView ("option", "autoAdjustHeight", true);
            * &lt;/script&gt;
            * @memberof ejmListView
            * @instance
            */
            autoAdjustHeight: false,
            /**    
            * Event triggers when touch end happens on the back button in the header.
            * @event
            * @name ejmListView#headerBackButtonTap	
            * @param {Object} argument Event parameters from listbox.
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @param {string} argument.text returns the text of the button.
            * @example 
            * // Set the headerBackButtonTap property in unobtrusive way.
            * &lt;div id="lb" data-role="ejmlistview" data-ej-showHeaderBackButton="true" data-ej-headerBackButtonTap="headerBackButtonTap"&gt;
            *	 &lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * //headerBackButtonTap event for ListView
            * &lt;div id="lb" data-role="ejmlistview" data-ej-showHeaderBackButton="true"&gt;
            *	 &lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $("#lb").ejmListView({
            *   	headerBackButtonTap: function (args) { //handle the event 
            * }
            *	});         
            * &lt;/script&gt;
            * @memberof ejmListView
            * @instance
            */
            headerBackButtonTap: null,
            /**		
            * Specifies whether need to adjust the scrolling content height for fixed position elements with the height of the control, when scrolling is allowed.
            * @default true
            * @type {boolean}
            * @example 
            * //Set the adjustFixedPosition property in unobtrusive way.
            * &lt;div id="lb" data-role="ejmlistview" data-ej-adjustFixedPosition="true"&gt;
            *	 &lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * //Set the adjustFixedPosition property in obtrusive way.
            * &lt;div id="lb"&gt;
            *	 &lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;            
            * // Set adjustFixedPosition on initialization. 
            * //To set adjustFixedPosition API value 
            * &lt;script&gt;
            * $("#lb").ejmListView ({ adjustFixedPosition: true });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set adjustFixedPosition, after initialization:<br>
            * // Get the adjustFixedPosition API value.		
            *  $("#lb").ejmListView ("option", "adjustFixedPosition");			
            * // Set the adjustFixedPosition API
            * $("#lb").ejmListView ("option", "adjustFixedPosition", true);     
            * &lt;/script&gt;       
            * @memberof ejmListView
            * @instance
            */
            adjustFixedPosition: true,
            /**		
            * Specifies whether to enable device's native scroll behaviour when scrolling is allowed.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the enableNativeScrolling property in unobtrusive way.
            * &lt;div id="lb" data-role="ejmlistview" data-ej-enableNativeScrolling="true"&gt;
            *	 &lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * //Set the enableNativeScrolling property in obtrusive way.
            * &lt;div id="lb"&gt;
            *	 &lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * // Set enableNativeScrolling on initialization. 
            * //To set enableNativeScrolling API value 
            * $("#lb").ejmListView ({ enableNativeScrolling: true });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set  enableNativeScrolling, after initialization:<br>
            * // Get the enableNativeScrolling API value.		
            *  $("#lb").ejmListView ("option", "enableNativeScrolling");			
            * // Set the enableNativeScrolling API
            * $("#lb").ejmListView ("option", "enableNativeScrolling", true); 
            * &lt;/script&gt;           
            * @memberof ejmListView
            * @instance
            */
            enableNativeScrolling: (ej.isAndroid() || ej.isIOS()) ? false : ej.isDevice() ? true : false,
            /**		
            * Specifies whether to hide the header for unsupported device.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the hideHeaderForUnsupportedDevice property in unobtrusive way.
            * &lt;div id="lb" data-role="ejmlistview" data-ej-hideHeaderForUnsupportedDevice="true"&gt;
            *	 &lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * //Set the hideHeaderForUnsupportedDevice property in obtrusive way.
            * &lt;div id="lb"&gt;
            *	 &lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * // Set hideHeaderForUnsupportedDevice on initialization. 
            * //To set hideHeaderForUnsupportedDevice API value 
            * $("#lb").ejmListView ({ hideHeaderForUnsupportedDevice: true });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set  hideHeaderForUnsupportedDevice, after initialization:<br>
            * // Get the hideHeaderForUnsupportedDevice API value.		
            *  $("#lb").ejmListView ("option", "hideHeaderForUnsupportedDevice");			
            * // Set the hideHeaderForUnsupportedDevice API
            * $("#lb").ejmListView ("option", "hideHeaderForUnsupportedDevice", true);
            * &lt;/script&gt;
            * @memberof ejmListView
            * @instance
            */
            hideHeaderForUnsupportedDevice: false,
            /**		   
            * Section for ios7 mode specific functionalities.  
            * @memberof ejmListView
            * @instance
            */
            ios7: {
                /**		
                * Specifies whether to show the control with inline style in ios7 mode.
                * @default false
                * @type {boolean}
                * @alias ejmListView#ios7->inline
                * @example 
                * //Set the inline property in unobtrusive way.
                * &lt;div id="lb" data-role="ejmlistview" data-ej-rendermode="ios7" data-ej-ios7-inline="true"&gt;
                * 	&lt;ul&gt;
                *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
                * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
                * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
                *	&lt;/ul&gt;
                * &lt;/div&gt;
                * @example 
                * //Set the inline property in obtrusive way.
                * &lt;div id="lb"&gt;
                * 	&lt;ul&gt;
                *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
                * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
                * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
                *	&lt;/ul&gt;
                * &lt;/div&gt;
                * &lt;script&gt;
                * // Setinline on initialization. 
                * //To set inline API value 
                * $("#lb").ejmListView ({ renderMode:"ios7", ios7:{inline: true} });
                * &lt;/script&gt;
                * @example 
                * &lt;script&gt;
                * //Get or set  inline, after initialization:<br>
                * // Get the inline API value.		
                * $("#lb").ejmListView ("option", "ios7.inline");			
                * // Set the inline API
                * $("#lb").ejmListView ("option", "ios7.inline", true);
                * &lt;/script&gt;
                * @memberof ejmListView
                * @instance
                */
                "inline": false
            },
            /**		   
            * Section for windows mode specific functionalities.  
            * @memberof ejmListView
            * @instance
            */
            windows: {
                /**		
                * Specifies whether to prevent skewing behaviour in windows mode.
                * @default false
                * @type {boolean}
                * @alias ejmListView#windows->preventSkew
                * @example 
                * //Set the preventSkew property in unobtrusive way.
                * &lt;div id="lb" data-role="ejmlistview" data-ej-rendermode="windows" data-ej-windows-preventSkew="true"&gt;
                * 	&lt;ul&gt;
                *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
                * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
                * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
                *	&lt;/ul&gt;
                * &lt;/div&gt;
                * @example 
                * //Set the preventSkew property in obtrusive way.
                * &lt;div id="lb" &gt;
                * 	&lt;ul&gt;
                *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
                * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
                * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
                *	&lt;/ul&gt;
                * &lt;/div&gt;
                * &lt;script&gt;
                * // Set preventSkew on initialization. 
                * //To set preventSkew API value
                * $("#lb").ejmListView ({ windows:{preventSkew: true} });
                * &lt;/script&gt;
                * @example 
                * &lt;script&gt;
                * //Get or set  preventSkew, after initialization:<br>
                * // Get the preventSkew API value.		
                * $("#lb").ejmListView ("option", "windows.preventSkew");			
                * // Set the preventSkew API
                * $("#lb").ejmListView ("option", "windows.preventSkew", true);
                * &lt;/script&gt;
                * @memberof ejmListView
                * @instance
                */
                "preventSkew": false,
                /**		
                * Specifies whether to render control based on the windowsphone's current accent color and device theme.
                * @default false
                * @type {boolean}
                * @alias ejmListView#windows->renderDefault
                * @example 
                * //Set the renderDefault property in unobtrusive way.
                * &lt;div id="lb" data-role="ejmlistview" data-ej-rendermode="windows" data-ej-windows-renderDefault="true"&gt;
                * 	&lt;ul&gt;
                *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
                * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
                * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
                *	&lt;/ul&gt;
                * &lt;/div&gt;
                * @example 
                * //Set the renderDefault property in obtrusive way.
                * &lt;div id="lb"&gt;
                * 	&lt;ul&gt;
                *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
                * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
                * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
                *	&lt;/ul&gt;
                * &lt;/div&gt;
                * &lt;script&gt;
                * // Set renderDefault on initialization. 
                * //To set renderDefault API value 
                * $("#lb").ejmListView ({ renderMode:"windows", windows:{renderDefault: true} });                
                * &lt;/script&gt;
                * @example 
                * &lt;script&gt;
                * //Get or set  renderDefault, after initialization:<br>
                * // Get the renderDefault API value.		
                * $("#lb").ejmListView ("option", "windows.renderDefault");			
                * // Set the renderDefault API
                * $("#lb").ejmListView ("option", "windows.renderDefault", true);
                * &lt;/script&gt;
                * @memberof ejmListView
                * @instance
                */
                "renderDefault": false,
                /**		
                * By default windows title's text will be in small case. To override this behaviour, set this property to true.
                * @default false
                * @type {boolean}
                * @alias ejmListView#windows->enableCustomText
                * @example 
                * // Set the windows mode enableCustomText property for header in unobtrusive way.
                * &lt;div id="lb" data-role="ejmlistview" data-ej-windows-enableheadercustomtext="true"&gt;
                *	 &lt;ul&gt;
                *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
                * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
                * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
                * 	&lt;/ul&gt;
                * &lt;/div&gt;
                * @example 
                * // Set the windows mode enableCustomText property for header in obtrusive way.
                * &lt;div id="lb"&gt;
                *	 &lt;ul&gt;
                *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
                * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
                * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
                *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
                * 	&lt;/ul&gt;
                * &lt;/div&gt;
                * &lt;script&gt;
                * // Set enableCustomText on initialization. 
                * //To set enableHeaderCustomText API value 
                * $("#lb").ejmListView ({ windows:{ enableHeaderCustomText: true });
                * &lt;/script&gt;
                * @example 
                * &lt;script&gt;
                * //Get or set  enableHeaderCustomText, after initialization:<br>
                * // Get the enableHeaderCustomText API value.		
                *  $("#lb").ejmListView ("option", "windows.enableHeaderCustomText");			
                * // Set the enableHeaderCustomText API
                * $("#lb").ejmListView ("option", "windows.enableHeaderCustomText", true);  
                * &lt;/script&gt;          
                * @memberof ejmListView
                * @instance
                */
                enableHeaderCustomText: false
            },
            /**		
            * Specifies whether to allow scrolling behaviour for the contents.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the allowScrolling property in unobtrusive way.
            * &lt;div id="lb" data-role="ejmlistview" data-ej-allowScrolling="true"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;            
            * @example 
            * //Set the allowScrolling property in obtrusive way.
            * &lt;div id="lb"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;            
            * // Set allowScrolling on initialization. 
            * //To set allowScrolling API value 
            * &lt;script&gt;
            * $("#lb").ejmListView ({ allowScrolling: true });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set  allowScrolling, after initialization:<br>
            * // Get the allowScrolling API value.		
            * $("#lb").ejmListView ("option", "allowScrolling");			
            * // Set the allowScrolling API
            * $("#lb").ejmListView ("option", "allowScrolling", true);  
            * &lt;/script&gt;          
            * @memberof ejmListView
            * @instance
            */
            allowScrolling: true,
            /**		
            * Specifies the rendering mode of the control. See {@link RenderMode}
            * @default auto
            * @type {enum}
            * @example 
            * //Set the renderMode property in unobtrusive way.
            * &lt;div id="lb" data-role="ejmlistview" data-ej-renderMode="auto"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * //Set the renderMode property in obtrusive way.
            * &lt;div id="lb"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * // Set renderMode on initialization. 
            * //To set renderMode API value 
            * $("#lb").ejmListView ({ renderMode: "auto" });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set  renderMode, after initialization:<br>
            * // Get the renderMode API value.		
            * $("#lb").ejmListView ("option", "renderMode");			
            * // Set the renderMode API
            * $("#lb").ejmListView ("option", "renderMode", "auto");
            * &lt;/script&gt;
            * @memberof ejmListView
            * @instance
            */
            renderMode: "auto",
            /**		
            * Specifies the theme. See {@link Theme}
            * @default auto 
            * @type {enum}
            * @example 
            * //Set the theme property in unobtrusive way.
            * &lt;div id="lb" data-role="ejmlistview" data-ej-theme="auto"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * //Set the theme property in obtrusive way.
            * &lt;div id="lb"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * // Set theme on initialization. 
            * //To set theme API value 
            * $("#lb").ejmListView ({ theme: "auto" });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set  theme, after initialization:<br>
            * // Get the theme API value.		
            * $("#lb").ejmListView ("option", "theme");			
            * // Set the theme API
            * $("#lb").ejmListView ("option", "theme", "auto");
            * &lt;/script&gt;
            * @memberof ejmListView
            * @instance
            */
            theme: "auto",
            /**    
            * Event triggers when touch start happens on the item.
            * @event
            * @name ejmListView#touchStart
            * @param {Object} argument Event parameters from listbox.
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @param {boolean} argument.hasChild If the child element exist return true; otherwise, false.
            * @param {string} argument.item  returns the current list item.
            * @param {string} argument.text returns the current text of item.
            * @param {number} argument.index returns the current Index of the item.
            * @param {boolean} argument.isChecked If checked return true; otherwise, false.
            * @param {number} argument.checkedItems returns the list of checked items.
            * @param {string} argument.checkedItemsText returns the current checked item text.
            * @example 
            * //Set the touchStart property in unobtrusive way.
            * &lt;div id="lb" data-role="ejmlistview" data-ej-touchStart="touchStart"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * //touchStart event for ListView
            * &lt;div id="lb" data-role="ejmlistview"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(document).ready(function(){
            * $("#lb").ejmListView({
            *   	touchStart: function (args) { //handle the event 
            * }
            *	});         
            * });
            * &lt;/script&gt;
            * @memberof ejmListView
            * @instance
            */
            touchStart: null,
            /**    
            * Event triggers when touch end happens on the item.
            * @event
            * @name ejmListView#touchEnd	
            * @param {Object} argument Event parameters from listbox.
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @param {boolean} argument.hasChild If the child element exist return true; otherwise, false.
            * @param {string} argument.item  returns the current list item.
            * @param {string} argument.text returns the current text of item.
            * @param {number} argument.index returns the current Index of the item.
            * @param {boolean} argument.isChecked If checked return true; otherwise, false.
            * @param {number} argument.checkedItems returns the list of checked items.
            * @param {string} argument.checkedItemsText returns the current checked item text.
            * @example 
            * //Set the touchEnd property in unobtrusive way.
            * &lt;div id="lb" data-role="ejmlistview" data-ej-touchEnd="touchEnd"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * //touchEnd event for ListView
            * &lt;div id="lb" data-role="ejmlistview"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(document).ready(function(){
            * $("#lb").ejmListView({
            *   	touchEnd: function (args) { //handle the event 
            * }
            *	});    
            * });
            * &lt;/script&gt;
            * @memberof ejmListView
            * @instance
            */
            touchEnd: null,
            /**		
            * Specifies the transition effect while navigation happens.
            * @default none
            * @type {string}
            * @example 
            * //Set the transition property in unobtrusive way.
            * &lt;div id="lb" data-role="ejmlistview" data-ej-transition="slide"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * //Set the transition property in obtrusive way.
            * &lt;div id="lb"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * // Set transition on initialization. 
            * //To set transition API value 
            * $("#lb").ejmListView ({ transition: "slide" });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set the ListView transition, after initialization:<br>
            * // Get the transition API value.		
            * $("#lb").ejmListView ("option", "transition");			
            * // Set the transition API
            * $("#lb").ejmListView ("option", "transition", "slide");
            * &lt;/script&gt;
            * @memberof ejmListView
            * @instance
            */
            transition: ej.isAndroid() ? "pop" : ej.isWindows() && ej.isMobile() ? "turn" : ej.isWindows() && !ej.isMobile() ? "none" : "slide",
            /**		
            * Specifies whether need to refresh scrollpanel rendered in the control when elements are added dynamically.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the checkDOMChanges property in unobtrusive way.
            * &lt;div id="lb" data-role="ejmlistview" data-ej-checkdomchanges=true&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * //Set the checkDOMChanges property in obtrusive way.
            * &lt;div id="lb"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * //Set the checkDOMChanges property on initialization. 
            * //To set checkDOMChanges API value
            * $("#lb").ejmListView ({ checkDOMChanges: true });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set  checkDOMChanges, after initialization:<br>
            * // Get the checkDOMChanges API value.		
            * $("#lb").ejmListView ("option", "checkDOMChanges");			
            * // Set the checkDOMChanges API
            * $("#lb").ejmListView ("option", "checkDOMChanges", true);
            * &lt;/script&gt;
            * @memberof ejmListView
            * @instance
            */
            checkDOMChanges: false
        },
        //Datatypes of model variables
        /**
        * Specify the data types for default properties 
        * @private
        */
        dataTypes: {
            dataSource: "data",
            fieldSettings: "data",
            renderMode: "enum",
            theme: "enum",
            enablePersistence: "boolean"
        },
        observables: ["selectedItemIndex", "dataSource"],
        selectedItemIndex: ej.util.valueFunction("selectedItemIndex"),
        dataSource: ej.util.valueFunction("dataSource"),
        //Constructor function
        /**
        * Create the ListView widget
        * @private
        */
        _init: function () {
            this._preventDefaultException = { tagName: /^(INPUT|TEXTAREA|BUTTON|SELECT)$/ };
            this._storedContent = [];
            this._storedTemplate = [];
            ej.setRenderMode(this);
            ej.setTheme(this);
            if (this.model.renderMode == "windows" && ej.isMobile() && this.model.windows.renderDefault)
                this.model.theme = "default";

            this._touchStart = this.model.touchStart;
            this._touchEnd = this.model.touchEnd;
            this._load();
        },

        _renderScrollPanel: function (parent, id, targetid) {
            this._scrollWrapper = ej.buildTag("div", "", {}, {
                "data-role": "ejmscrollpanel",
                "data-ej-rendermode": this.model.renderMode,
                "data-ej-target": targetid,
                "id": id,
                "data-ej-theme": this.model.theme,
                "data-ej-targetwidth": this.model.width,
                "data-ej-targetheight": this.model.height,
                "data-ej-setautoheight": this.model.autoAdjustScrollHeight,
                "data-ej-adjustfixedposition": this.model.adjustFixedPosition,
                "data-ej-enablenativescrolling": this.model.enableNativeScrolling,
                "data-ej-windows-renderdefault": this.model.windows.renderDefault,
                "data-ej-showscrollbars": this.model.showScrollbars,
                "data-ej-checkdomchanges": this.model.checkDOMChanges
            });
            parent.append(this._scrollWrapper);
        },
        //To update the content while clicking the list
        /**
        * Section for to update content.
        * @private
        */
        _updateContent: function (currentItem, backButton) {
            var proxy = this;
            var $curIte = $(currentItem), childid = $curIte.attr('data-childid'),
                  id = this.element.find($("#" + childid));
            if (id.length) {
                var hdr = this.element.find('#' + childid + '_header');
                var scroll = this.element.find('#' + childid + "_scroll");
                if (this.model.enableFiltering)
                    this._initializeFiltering($(id));
                var title = $curIte.attr('data-childtitle') == undefined ? currentItem.text() : $curIte.attr('data-childtitle');
                if (hdr.hasClass('e-m-header')) {
                    var instance = hdr.ejmHeader("instance");
                    instance.setModel({ title: title, leftButtonCaption: backButton });
                }
                id.attr("data-hdr-title", title).attr("data-hdr-bckbtn", backButton);
                App.transferPage($curIte.closest('.subpage'), id, { isFromAjax: this._isFromAjax, transition: this.model.transition, parentSubPage: $curIte.closest('.subpage').hasClass('e-m-childitem') ? false : true });
                this._transitionDelegate = $.proxy(this._transitionHandler, { "proxy": this, "idEle": id, "scrollEle": scroll, "delegate": this._transitionDelegate });
                id.bind(ej.transitionEndEvent(), this._transitionDelegate);
            }
        },
        _transitionHandler: function () {
            this.proxy._setHeightWidth();
            if (this.proxy.model.allowScrolling)
                this.scrollEle.ejmScrollPanel('refresh');
            this.idEle.unbind(ej.transitionEndEvent(), this.delegate);
        },
        //To render header
        /**
        * Section for Render Header for Listbox control	
        * @private
        */
        _renderHeader: function (id, showbutton, title, backtext) {
            var header = ej.buildTag("div", "", {}, {
                "data-role": "ejmheader",
                "data-ej-showLeftButton": showbutton,
                "data-ej-leftbuttoncaption": backtext ? backtext : "Back",
                "data-ej-title": title,
                "data-ej-leftbuttontap": this.model.headerBackButtonTap,
                "data-ej-righttbuttontap": this.model.headerBackButtonTap,
                "data-ej-rendermode": this.model.renderMode,
                "data-ej-theme": this.model.theme,
                "data-ej-position": "normal",
                "id": id + "_header",
                "data-ej-hideforunsupporteddevice": this.model.hideHeaderForUnsupportedDevice,
                "data-ej-windows-renderdefault": this.model.windows.renderDefault,
                "data-ej-windows-enablecustomtext": this.model.windows.enableHeaderCustomText
            });
            return header;
        },
        //Return the data in event triggering to the user
        /**
        * Section for to return data in event triggering to the user.
        * @private
        */
        _returnData: function () {
            var checkedItem = this._currentItem.closest('ul.e-m-list-hdr').find("input.e-m-lv-check:checked").closest("li");
            return {
                hasChild: this.element.find('#' + this._currentItem.attr('data-childid')).length ? true : false,
                item: this._currentItem,
                text: this._currentItem.find('.e-m-list-text').text(),
                index: this._currentItem.index(),
                isChecked: this._currentItem.find("input.e-m-lv-check").length ? this._currentItem.find("input.e-m-lv-check").prop('checked') : false,
                checkedItems: checkedItem.length ? checkedItem : null,
                checkedItemsText: checkedItem.length ? $(checkedItem).map(function () { return $(this).text(); }).get() : null
            };
        },
        _triggerStartEvent: function (data) {
            this.model.touchStart = ej.getAttrVal(this._currentItem, 'data-touchstart', this._touchStart);
            if (this.model.touchStart)
                this._trigger("touchStart", data);
        },
        _triggerEndEvent: function (data) {
            this.model.touchEnd = ej.getAttrVal(this._currentItem, 'data-touchend', this._touchEnd);
            this.selectedItemIndex(this._currentItem.index());
            if (this.model.touchEnd)
                this._trigger("touchEnd", data);
        },
        _createFilterDiv: function () {
            return ej.buildTag('div.e-m-lv-filter', ej.buildTag('input.e-m-lv-input', "", {}, { 'data-role': 'ejmtextbox', 'data-ej-rendermode': this.model.renderMode, 'data-ej-theme': this.model.theme, "data-ej-windows-renderdefault": this.model.windows.renderDefault }));
        },
        _emptyFilterTextValue: function (element) {
            element.find('.e-m-lv-input').ejmTextBox('model.value', '');
        },
        _createListDiv: function (childId) {
            this._div = ej.buildTag("div#" + childId + "." + this._rootCSS + " e-m-" + this.model.renderMode + " e-m-" + this.model.theme + " subpage e-m-childitem e-m-ajaxchild", this.model.showHeader ? this._renderHeader(childId, true, this._currentItem.text()) : "");
        },
        _createCheckBox: function () {
            return ej.buildTag("input.e-m-lv-check", "", {}, {
                'type': 'checkbox',
                'data-role': 'ejmcheckbox',
                'data-ej-preventdefault': true,
                'data-ej-theme': this.model.theme,
                'data-ej-rendermode': this.model.renderMode,
                'data-ej-checked': "{{:~_checkIsChecked()}}",
                'data-ej-windows-renderdefault': this.model.windows.renderDefault
            });
        },
        _toggleCheckboxValue: function (lbCheck) {
            lbCheck.ejmCheckBox('model.checked', !lbCheck.prop('checked'));
        },
        _setCheckboxValue: function (element, val) {
            element.ejmCheckBox({ checked: val });
        },
        _convertToRelativeUrl: function (url) {
            return App.route.convertToRelativeUrl(url)
        }
    });
    $.extend(true, ej.mobile.ListView.prototype, ej.ListViewBase.prototype);
})(jQuery, Syncfusion);