/**
* @fileOverview Plugin to style the Html Menu elements
* @copyright Copyright Syncfusion Inc. 2001 - 2014. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/
(function ($, ej, undefined) {
    //mMenu is the plugin name 
    //"m.Menu" is "namespace.className" will hold functions and properties

    /**
    * @namespace ej
    * @class ejmMenu
    * @requires jQuery
    * @requires ej.mobile.application
    * @requires ej.core
    * @requires ej.unobtrusive
    * @requires ej.mobile.core
    * @requires ej.data
    * @requires ej.touch
    * @requires ej.mobile.button
    * @requires ej.mobile.scrollbar
    * @requires ej.mobile.scrollpanel
    * @classdesc Custom Design for Html Menu control.
    * @example 
    * // Create Menu control in unobtrusive way.
    * &lt;div&gt;
    *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu" /&gt;
    * &lt;/div&gt; <br/>
    * &lt;div id="menu" data-role="ejmmenu" data-ej-targetid="menuitem"&gt;
    *   &lt;ul&gt; 
    *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
    *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
    *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
    *   &lt;/ul&gt;
    * &lt;/div&gt;
    * @example 
    * // Create Menu control in obtrusive way.
    * &lt;div&gt;
    *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu" /&gt;
    * &lt;/div&gt; <br/>
    * &lt;div id="menu" data-role="ejmmenu" data-ej-targetid="menuitem"&gt;
    *   &lt;ul&gt; 
    *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
    *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
    *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
    *   &lt;/ul&gt;
    * &lt;/div&gt;
    * &lt;script&gt;
    * $(function(){
    *       $("menu").ejmMenu({targetId:"menuitem"});
    * });
    * &lt;/script&gt;
    */
    ej.widget("ejmMenu", "ej.mobile.Menu", {
        _setFirst: true,
        _rootCSS: "e-m-menu",
        _tags: [{
            tag: "items",
            attr: ["text", "renderTemplate", "android.imageClass",
                "ios7.theme", "ios7.buttonColor", "ios7.buttonStyle",
                "href", "templateId", "touchStart", "touchend"],
            content: "template"
        }],
        //Default model values
        defaults: {

            /**		
            * Specifies the height.
            * @type {int}
            * @example   
            * // Set height in unobtrusive way.          
            * &lt;div&gt;
            *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu"/&gt;
            * &lt;/div&gt; <br/>
            * &lt;div id="menu" data-role="ejmmenu" data-ej-targetid="menuitem" data-ej-height="100"&gt;
            *   &lt;ul&gt; 
            *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
            *   &lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * &lt;div&gt;
            * // Set height in obtrusive way.
            *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu" /&gt;
            * &lt;/div&gt; <br/>
            * &lt;div id="menu"&gt;
            *   &lt;ul&gt; 
            *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
            *   &lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * 	// Set height on initialization. 
            * 	// To set height API value 
            * 	$("#menu").ejmMenu ({targetId : "menuitem" , height: 100 });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * // Get or set height, after initialization:<br>
            * // Get the height API value.		
            *  $("#menu").ejmMenu("option", "height");			
            * // Set the height API
            * $("#menu").ejmMenu("option", "height", 100);            
            * &lt;/script&gt;
            * @memberof ejmMenu
            * @instance
            */
            height: null,

            /**		
            * Specifies the width.
            * @type {int}
            * @example        
            * // Set width in unobtrusive way.     
            * &lt;div&gt;
            *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu"/&gt;
            * &lt;/div&gt; <br/>
            * &lt;div id="menu" data-role="ejmmenu" data-ej-targetid="menuitem" data-ej-width=200 &gt;
            *   &lt;ul&gt; 
            *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
            *   &lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * // Set width in obtrusive way.
            * &lt;div&gt;
            *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu" /&gt;
            * &lt;/div&gt; <br/>
            * &lt;div id="menu"&gt;
            *   &lt;ul&gt; 
            *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
            *   &lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * 	// Set width on initialization. 
            * 	// To set width API value 
            * 	$("#menu").ejmMenu ({ targetId : "menuitem" , width: 200 });	
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * // Get or set width, after initialization:<br>
            * // Get the width API value.		
            *  $("#menu").ejmMenu("option", "width");			
            * // Set the width API
            * $("#menu").ejmMenu("option", "width", 200);  
            * &lt;/script&gt;          
            * @memberof ejmMenu
            * @instance
            */
            width: null,

            /**		
            * Specifies whether to allow scrolling behaviour for the contents.
            * @default true
            * @type {boolean}
            * @example       
            * // Set allowScrolling property in unobtrusive way.      
            * &lt;div&gt;
            *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu"/&gt;
            * &lt;/div&gt; <br/>
            * &lt;div id="menu" data-role="ejmmenu" data-ej-targetid="menuitem"  data-ej-allowScrolling=true&gt;
            *   &lt;ul&gt; 
            *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
            *   &lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * // Set allowScrolling property in obtrusive way.
            * &lt;div&gt;
            *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu"/&gt;
            * &lt;/div&gt; <br/>
            * &lt;div id="menu"&gt;
            *   &lt;ul&gt; 
            *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
            *   &lt;/ul&gt;
            * &lt;/div&gt; <br/>
            * &lt;script&gt;
            * 	// Set allowScrolling on initialization. 
            * 	// To set allowScrolling API value 
            * 	$("#menu").ejmMenu ({targetId: "menuitem" , allowScrolling : true});
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * // Get or set allowScrolling, after initialization:<br>
            * // Get the allowScrolling API value.		
            *  $("#menu").ejmMenu("option", "allowScrolling");			
            * // Set the allowScrolling API
            * $("#menu").ejmMenu("option", "allowScrolling", true); 
            * &lt;/script&gt;           
            * @memberof ejmMenu
            * @instance
            */
            allowScrolling: true,

            /**		
            * Specifies ID of target element.            
            * @type {string}
            * @example             
            * // Set target element ID in unobtrusive way.
            * &lt;div&gt;
            *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu"/&gt;
            * &lt;/div&gt; <br/>
            * &lt;div id="menu" data-role="ejmmenu" data-ej-targetid="menuitem"&gt;
            *   &lt;ul&gt; 
            *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
            *   &lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * // Set target element ID in obtrusive way.
            * &lt;div&gt;
            *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu"/&gt;
            * &lt;/div&gt; <br/>
            * &lt;div id="menu"&gt;
            *   &lt;ul&gt; 
            *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
            *   &lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * 	// Set target element ID on initialization. 
            * 	// To set target element ID value 
            * 	$("#menu").ejmMenu ({ targetId: "menuitem" });	
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * // Get or set target element ID, after initialization:<br>
            * // Get the target element ID value.		
            *  $("#menu").ejmMenu("option", "targetId");			
            * // Set the target element ID
            * $("#menu").ejmMenu("option", "targetId", "menu");  
            * &lt;/script&gt;          
            * @memberof ejmMenu
            * @instance
            */
            targetId: null,
            /**		
            * Specifies in which action need to show the menu. See {@link ShowOn}
            * @default tap
            * @type {string}
            * @example       
            * // Set showOn property in unobtrusive way.      
            * &lt;div&gt;
            *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu"/&gt;
            * &lt;/div&gt; <br/>
            * &lt;div id="menu" data-role="ejmmenu" data-ej-targetid="menuitem" data-ej-showOn="taphold"&gt;
            *   &lt;ul&gt; 
            *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
            *   &lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * // Set showOn property in obtrusive way.
            * &lt;div&gt;
            *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu" /&gt;
            * &lt;/div&gt; <br/>
            * &lt;div id="menu"&gt;
            *   &lt;ul&gt; 
            *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
            *   &lt;/ul&gt;
            * &lt;/div&gt;
            * &ltscript&gt;
            * 	// Set showOn on initialization. 
            * 	// To set showOn API value 
            * 	$("#menu").ejmMenu ({targetId : "menuitem" , showOn: "taphold"});		
            * &lt/script&gt;
            * @example 
            * &ltscript&gt;
            * // Get or set showOn, after initialization:<br>
            * // Get the showOn API value.		
            *  $("#menu").ejmMenu("option", "showOn");			
            * // Set the showOn API
            * $("#menu").ejmMenu("option", "showOn", "taphold");  
            * &lt/script&gt;          
            * @memberof ejmMenu
            * @instance
            */
            showOn: "tap",

            /**		   
            * Section for ios7 mode specific functionalities.  
            * @memberof ejmMenu
            * @instance
            */
            ios7: {
                /**		
                * Specifies ios7 mode menu type. 
                * @default ej.mobile.Menu.IOS7.Type.Auto. 
                * @type {enum}
                * @alias ejmMenu#ios7->type
                * @example          
                * // Set type in unobtrusive way.   
                * &lt;div&gt;
                *    &lt;input id="menuitem" type="button" data-ej-rendermode="ios7" data-role="ejmbutton" data-ej-text="Menu"/&gt;
                * &lt;/div&gt; <br/>
                * &lt;div id="menuitem" data-role="ejmmenu" data-ej-targetid="menuitem" data-ej-rendermode="ios7" data-ej-ios7-type="animate" data-ej-ios7-type="auto"&gt;
                *   &lt;ul&gt; 
                *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
                *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
                *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
                *   &lt;/ul&gt;
                * &lt;/div&gt;
                * @example 
                * &lt;div&gt;
                * // Set type in obtrusive way.
                *    &lt;input id="menuitem" type="button" data-ej-rendermode="ios7" data-role="ejmbutton" data-ej-text="Menu" /&gt;
                * &lt;/div&gt; <br/>
                * &lt;div id="menu" &gt;
                *   &lt;ul&gt; 
                *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
                *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
                *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
                *   &lt;/ul&gt;
                * &lt;/div&gt;
                * &lt;script&gt;
                * // Set type on initialization. 
                * // To set type API value 
                * $(function(){
                * $("#menu").ejmMenu ({ targetId:"menuitem", renderMode:"ios7", ios7:{type : ej.mobile.Menu.IOS7.Type.Auto} });
                * });
                * &lt;/script&gt;		
                * @example 
                * &lt;script&gt;
                * // Get or set type, after initialization:<br>
                * // Get type API value.		
                *  $("#menu").ejmMenu("option", "ios7.type");			
                * // Set type API
                * $("#menu").ejmMenu("option", "ios7.type", ej.mobile.Menu.IOS7.Type.Auto);    
                * &lt;/script&gt;        
                * @memberof ejmMenu
                * @instance
                */
                "type": "auto",

                /**		
                * Specifies whether to show title in ios7 mode.
                * @default true
                * @type {boolean}
                * @alias ejmMenu#ios7->showTitle
                * @example             
                * // Set type in unobtrusive way.
                * &lt;div&gt;
                *    &lt;input id="menuitem" type="button" data-ej-rendermode="ios7" data-role="ejmbutton" data-ej-text="Menu"/&gt;
                * &lt;/div&gt; <br/>
                * &lt;div id="menuitem" data-role="ejmmenu" data-ej-rendermode="ios7" data-ej-targetid="menuitem" data-ej-ios7-type="animate" data-ej-ios7-showtitle=true&gt;
                *   &lt;ul&gt; 
                *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
                *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
                *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
                *   &lt;/ul&gt;
                * &lt;/div&gt;
                * @example 
                * // Set type in obtrusive way.
                * &lt;div&gt;
                *    &lt;input id="menuitem" type="button" data-ej-rendermode="ios7" data-role="ejmbutton" data-ej-text="Menu" /&gt;
                * &lt;/div&gt; <br/>
                * &lt;div id="menu" &gt;
                *   &lt;ul&gt; 
                *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
                *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
                *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
                *   &lt;/ul&gt;
                * &lt;/div&gt;
                * &lt;script&gt;
                * // Set showTitle property on initialization. 
                * // To set showTitle API value 
                * $("#menu").ejmMenu ({ targetId:"menuitem", renderMode:"ios7", ios7:{showTitle : true} });
                * &lt;/script&gt;
                * @example 
                * &lt;script&gt;
                * // Get or set the show menu title, after initialization:<br>
                * // Get the showTitle API value.		
                *  $("#menu").ejmMenu("option", "ios7.showTitle");			
                * // Set the showTitle API
                * $("#menu").ejmMenu("option", "ios7.showTitle", true);  
                * &lt;/script&gt;          
                * @memberof ejmMenu
                * @instance
                */
                "showTitle": true,

                /**		
                * Specifies title text in ios7 mode.
                * @default "Title"
                * @type {string}
                * @alias ejmMenu#ios7->title
                * @example      
                * // Set title for ios7 mode in unobtrusive way.       
                * &lt;div&gt;
                *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-rendermode="ios7" data-ej-text="Menu"/&gt;
                * &lt;/div&gt; <br/>
                * &lt;div id="menuitem" data-role="ejmmenu" data-ej-targetid="menuitem" data-ej-rendermode="ios7" data-ej-ios7-type="animate" data-ej-ios7-title="Title"&gt;
                *   &lt;ul&gt; 
                *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
                *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
                *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
                *   &lt;/ul&gt;
                * &lt;/div&gt;
                * @example 
                * // Set title for ios7 mode in obtrusive way.
                * &lt;div&gt;
                *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-rendermode="ios7" data-ej-text="Menu" /&gt;
                * &lt;/div&gt; <br/>
                * &lt;div id="menu"&gt;
                *   &lt;ul&gt; 
                *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
                *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
                *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
                *   &lt;/ul&gt;
                * &lt;/div&gt;
                * &lt;script&gt;
                * 	// Set menu title on initialization. 
                * 	// To set menu title API value 
                * 	$("#menu").ejmMenu ({ targetId : "menuitem" , renderMode : "ios7" , ios7:{title : "Title"} });			
                * &lt;/script&gt;
                * @example 
                * &lt;script&gt;
                * // Get or set title, after initialization:<br>
                * // Get title API value.		
                *  $("#menu").ejmMenu("option", "ios7.title");			
                * // Set title API
                * $("#menu").ejmMenu("option", "ios7.title", true);    
                * &lt;/script&gt;        
                * @memberof ejmMenu
                * @instance
                */
                "title": "Title",

                /**		
                * Specifies whether to show cancel button in ios7 mode.
                * @default true
                * @type {boolean}
                * @alias ejmMenu#ios7->showCancelButton
                * @example         
                * // Set showCancelButton in unobtrusive way.    
                * &lt;div&gt;
                *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-rendermode="ios7" data-ej-text="Menu"/&gt;
                * &lt;/div&gt; <br/>
                * &lt;div id="menuitem" data-role="ejmmenu" data-ej-rendermode="ios7" data-ej-targetid="menuitem" data-ej-ios7-type="animate" data-ej-ios7-showCancelButton=true&gt;
                *   &lt;ul&gt; 
                *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
                *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
                *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
                *   &lt;/ul&gt;
                * &lt;/div&gt;
                * @example 
                * // Set showCancelButton in obtrusive way.
                * &lt;div&gt;
                *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-rendermode="ios7" data-ej-text="Menu" /&gt;
                * &lt;/div&gt; <br/>
                * &lt;div id="menu" &gt;
                *   &lt;ul&gt; 
                *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
                *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
                *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
                *   &lt;/ul&gt;
                * &lt;/div&gt;
                * &lt;script&gt;
                * // Set show cancel button on initialization. 
                * // To set show cancel button  API value 
                * $("#menu").ejmMenu ({ targetId:"menuitem", renderMode:"ios7", ios7:{showCancelButton : true , type:"animate"}});	
                * &lt;/script&gt;
                * @example 
                * &lt;script&gt;
                * // Get or set the show cancel button after initialization:<br>
                * // Get the show cancel button API value.		
                *  $("#menu").ejmMenu("option", "ios7.showCancelButton");			
                * // Set the show cancel button API
                * $("#menu").ejmMenu("option", "ios7.showCancelButton", true);
                * &lt;/script&gt;            
                * @memberof ejmMenu
                * @instance
                */
                "showCancelButton": true,

                /**		
                * Specifies cancel button text in ios7 mode.
                * @default "Cancel"
                * @type {string}
                * @alias ejmMenu#ios7->cancelButtonText
                * @example      
                * // Set cancelButtonText in unobtrusive way.       
                * &lt;div&gt;
                *    &lt;input id="menuitem" type="button" data-ej-rendermode="ios7" data-role="ejmbutton" data-ej-text="Menu"/&gt;
                * &lt;/div&gt; <br/>
                * &lt;div id="menuitem" data-role="ejmmenu" data-ej-targetid="menuitem" data-ej-rendermode="ios7" data-ej-ios7-type="animate" data-ej-ios7-cancelButtonText="Cancel"&gt;
                *   &lt;ul&gt; 
                *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
                *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
                *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
                *   &lt;/ul&gt;
                * &lt;/div&gt;
                * @example 
                * // Set cancelButtonText in obtrusive way.
                * &lt;div&gt;
                *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-rendermode="ios7" data-ej-text="Menu" /&gt;
                * &lt;/div&gt; <br/>
                * &lt;div id="menu" &gt;
                *   &lt;ul&gt; 
                *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
                *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
                *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
                *   &lt;/ul&gt;
                * &lt;/div&gt;
                * &lt;script&gt;
                * // Set cancel button text on initialization. 
                * // To set cancel button text API value 
                * $("#menu").ejmMenu ({ targetId:"menuitem", renderMode:"ios7", ios7:{cancelButtonText : "Cancel", type:"animate"} });	
                * &lt;/script&gt;
                * @example 
                * &lt;script&gt;
                * // Get or set cancel button text, after initialization:<br>
                * // Get cancel button text API value.		
                *  $("#menu").ejmMenu("option", "ios7.cancelButtonText");			
                * // Set cancel button text API
                * $("#menu").ejmMenu("option", "ios7.cancelButtonText", true);  
                * &lt;/script&gt;          
                * @memberof ejmMenu
                * @instance
                */
                "cancelButtonText": "Cancel",

                /**		
                * Specifies cancel button color in ios7 mode. 
                * @default ej.mobile.Menu.IOS7.CancelButtonColor.Blue. 
                * @type {enum}
                * @alias ejmMenu#ios7->cancelButtonColor
                * @example            
                * // Set cancelButtonColor in unobtrusive way. 
                * &lt;div&gt;
                *    &lt;input id="menuitem" type="button" data-ej-rendermode="ios7" data-role="ejmbutton" data-ej-text="Menu"/&gt;
                * &lt;/div&gt; <br/>
                * &lt;div id="menu" data-role="ejmmenu" data-ej-targetid="menuitem" data-ej-rendermode="ios7" data-ej-ios7-cancelButtonColor="blue"&gt;
                *   &lt;ul&gt; 
                *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
                *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
                *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
                *   &lt;/ul&gt;
                * &lt;/div&gt;
                * @example 
                * // Set cancelButtonColor in obtrusive way.
                * &lt;div&gt;
                *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-rendermode="ios7" data-ej-text="Menu" /&gt;
                * &lt;/div&gt; <br/>
                * &lt;div id="menu"  &gt;
                *   &lt;ul&gt; 
                *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
                *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
                *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
                *   &lt;/ul&gt;
                * &lt;/div&gt;
                * &lt;script&gt;
                * // Set cancel button color on initialization. 
                * // To set cancel button color API value 
                * $(function() {
                * $("#menu").ejmMenu ({ targetId:"menuitem", renderMode:"ios7", ios7:{cancelButtonColor : ej.mobile.Menu.IOS7.CancelButtonColor.Blue} });
                * });
                * &lt;/script&gt;
                * @example 
                * &lt;script&gt;
                * // Get or set cancel button color, after initialization:<br>
                * // Get cancel button color API value.		
                *  $("#menu").ejmMenu("option", "ios7.cancelButtonColor");			
                * // Set cancel button color API
                * $("#menu").ejmMenu("option", "ios7.cancelButtonColor", ej.mobile.Menu.IOS7.CancelButtonColor.Blue); 
                * &lt;/script&gt;           
                * @memberof ejmMenu
                * @instance
                */
                "cancelButtonColor": "blue",

                /**    
                * Event triggers when touch end happens on the cancel button in ios7 mode.
                * @event
                * @name ejmMenu#cancelButtonTouchEnd 	
                * @param {Object} argument Event parameters from menu.
                * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
                * @param {string} argument.type returns the name of the event.
                * @param {Object} argument.model returns the model value of the control.
                * @param {Object} argument.item returns the current menu list element.
                * @param {string} argument.text returns the current menu list element associated text.                
                * @example 
                * // Set hide method in unobtrusive way.
                * &lt;div&gt;
                *    &lt;input id="menuitem" type="button" data-ej-rendermode="ios7" data-role="ejmbutton" data-ej-text="Menu"/&gt;
                * &lt;/div&gt; <br/>
                * &lt;div id="menu" data-role="ejmmenu" data-ej-targetid="menuitem" data-ej-rendermode="ios7" data-ej-ios7-type="animate" data-ej-ios7-cancelbuttontouchend="cancelbuttontouchend"&gt;
                *   &lt;ul&gt; 
                *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
                *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
                *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
                *   &lt;/ul&gt;
                * &lt;/div&gt;
                * &lt;script&gt; 
                * // hide event for menu
                * function cancelbuttontouchend(args){ //handle the event 
                * }
                * &lt;/script&gt;
                * @example 
                * // Set hide method in obtrusive way.
                * &lt;div&gt;
                *    &lt;input id="menuitem" type="button" data-ej-rendermode="ios7" data-role="ejmbutton" data-ej-text="Menu"/&gt;
                * &lt;/div&gt; <br/>
                * &lt;div id="menu" &gt;
                *   &lt;ul&gt; 
                *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
                *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
                *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
                *   &lt;/ul&gt;
                * &lt;/div&gt;
                * &lt;script&gt; 
                * // hide event for menu
                * $("#menu").ejmMenu({ targetId:"menuitem",renderMode:"ios7",ios7:{type:"animate",cancelButtonTouchEnd: function (args) { 
                * //handle the event
                * }}
                *});           
                * @memberof ejmMenu
                * @instance
                */
                "cancelButtonTouchEnd": null
            },

            /**		   
            * Section for android mode specific functionalities.                      
            * @memberof ejmMenu
            * @instance
            */
            android: {

                /**		
                * Specifies android mode menu type. 
                * @default ej.mobile.Menu.Android.Type.Contextual. 
                * @type {enum}
                * @alias ejmMenu#android->type
                * @example   
                * // Set type in unobtrusive way.          
                * &lt;div&gt;
                *    &lt;input id="menuitem" type="button" data-ej-rendermode="android" data-role="ejmbutton" data-ej-text="Menu"/&gt;
                * &lt;/div&gt; <br/>
                * &lt;div id="menu" data-role="ejmmenu" data-ej-targetid="menuitem" data-ej-rendermode ="android" data-ej-android-type="contextual"&gt;
                *   &lt;ul&gt; 
                *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
                *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
                *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
                *   &lt;/ul&gt;
                * &lt;/div&gt;
                * @example 
                * // Set type in obtrusive way.
                * &lt;div&gt;
                *    &lt;input id="menuitem" type="button" data-ej-rendermode="android" data-role="ejmbutton" data-ej-text="Menu" /&gt;
                * &lt;/div&gt; <br/>
                * &lt;div id="menu" &gt;
                *   &lt;ul&gt; 
                *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
                *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
                *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
                *   &lt;/ul&gt;
                * &lt;/div&gt;
                * &lt;script&gt;
                * // Set type on initialization. 
                * // To set menu type API value 
                * $(function() {
                * $("#menu").ejmMenu ({ android:{type : ej.mobile.Menu.Android.Type.Contextual}, renderMode:"android",targetId:"menuitem"});
                * });
                * &lt;/script&gt;
                * @example 
                * &lt;script&gt;
                * // Get or set type, after initialization:<br>
                * // Get type API value.		
                *  $("#menu").ejmMenu("option", "android.type");			
                * // Set type API
                * $("#menu").ejmMenu("option", "android.type", ej.mobile.Menu.Android.Type.Contextual);    
                * &lt;/script&gt;        
                * @memberof ejmMenu
                * @instance
                */
                "type": "contextual"
            },

            /**		   
            * Section for windows mode specific functionalities.                      
            * @memberof ejmMenu
            * @instance
            */
            windows: {
                /**
                * Specifies windows mode menu type. 
                * @default ej.mobile.Menu.windows.Contextual.
                * @type {enum}
                * @alias ejmMenu#windows->type
                * @example             
                * // Set type in unobtrusive way.
                * &lt;div&gt;
                *    &lt;input id="menuitem" type="button" data-ej-rendermode="windows" data-role="ejmbutton" data-ej-text="Menu"/&gt;
                * &lt;/div&gt; <br/>
                * &lt;div id="menu" data-role="ejmmenu" data-ej-targetid="menuitem" data-ej-rendermode ="windows" data-ej-windows-type="contextual"&gt;
                *   &lt;ul&gt; 
                *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
                *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
                *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
                *   &lt;/ul&gt;
                * &lt;/div&gt;
                * @example 
                * // Set type in obtrusive way.
                * &lt;div&gt;
                *    &lt;input id="menuitem" type="button" data-ej-rendermode="windows" data-role="ejmbutton" data-ej-text="Menu" /&gt;
                * &lt;/div&gt; <br/>
                * &lt;div id="menu" data-role="ejmmenu" data-ej-targetid="menuitem" data-ej-rendermode ="windows" &gt;
                *   &lt;ul&gt; 
                *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
                *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
                *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
                *   &lt;/ul&gt;
                * &lt;/div&gt;
                * &lt;script&gt;
                * // Set type on initialization. 
                * // To set menu type API value 
                * $function(){
                * $("#menu").ejmMenu ({ windows:{type : ej.mobile.Menu.Windows.Type.Contextual} });			
                * });
                * &lt;/script&gt;
                * @example 
                * &lt;script&gt;
                * // Get or set type, after initialization:<br>
                * // Get type API value.		
                *  $("#menu").ejmMenu("option", "windows.type");			
                * // Set type API
                * $("#menu").ejmMenu("option", "windows.type", ej.mobile.Menu.Windows.Type.Contextual);      	
                * &lt;/script&gt;      
                * @memberof ejmMenu
                * @instance
                */
                "type": "contextual",

                /**		
                * Specifies whether to render control based on the windowsphone's current accent color and device theme.
                * @default false
                * @type {boolean}
                * @alias ejmMenu#windows->renderDefault
                * @example             
                * // Set the windows mode renderDefault property in unobtrusive way.
                * &lt;div&gt;
                *    &lt;input id="menuitem" type="button" data-ej-rendermode="windows" data-role="ejmbutton" data-ej-text="Menu"/&gt;
                * &lt;/div&gt; <br/>
                * &lt;div id="menu" data-role="ejmmenu" data-ej-targetid="menuitem" data-ej-rendermode ="windows" data-ej-windows-renderDefault=false&gt;
                *   &lt;ul&gt; 
                *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
                *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
                *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
                *   &lt;/ul&gt;
                * &lt;/div&gt;
                * @example 
                * // Set the windows mode renderDefault property in obtrusive way.
                * &lt;div&gt;
                *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu" data-ej-rendermode="windows" /&gt;
                * &lt;/div&gt; <br/>
                * &lt;div id="menu"&gt;
                *   &lt;ul&gt; 
                *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
                *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
                *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
                *   &lt;/ul&gt;
                * &lt;/div&gt;
                * &lt;script&gt;
                * 	// Get or set the windows mode renderDefault API, after initialization:
                * 	// Get the windows mode renderDefault value  
                * 	$("#menu").ejmMenu ({ targetId : "menuitem" , renderMode : "windows" , windows:{renderDefault : false }});		
                * &lt;/script&gt;
                * @example 
                * &lt;script&gt;
                * // Get or set windows mode renderDefault, after initialization:<br>
                * // Get the windows mode renderDefault value 	
                *  $("#menu").ejmMenu("option", windows.renderDefault);			
                * // Set the windows mode renderDefault value 
                * $("#menu").ejmMenu("option", "windows.renderDefault", false);
                * &lt;/script&gt;            
                * @memberof ejmMenu
                * @instance
                */
                "renderDefault": false
            },

            /**		
            * Specifies whether need to render the control with the template contents.
            * @default false
            * @type {boolean}
            * @example             
            * // Set renderTemplate property in unobtrusive way.
            * &lt;div&gt;
            *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu"/&gt;
            * &lt;/div&gt; <br/>
            * &lt;div id="menu" data-role="ejmmenu" data-ej-targetid="menuitem" data-ej-renderTemplate=false&gt;
            *   &lt;ul&gt; 
            *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
            *   &lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * // Set renderTemplate property in obtrusive way.
            * &lt;div&gt;
            *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu" /&gt;
            * &lt;/div&gt; <br/>
            * &lt;div id="menu"&gt;
            *   &lt;ul&gt; 
            *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
            *   &lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * 	// Set renderTemplate property on initialization. 
            * 	// To set renderTemplate API value 
            * 	$("#menu").ejmMenu ({ targetId : "menuitem" , renderTemplate: false});	
            * &lt;/script&gt;			
            * @example 
            * &lt;script&gt;
            * // Get or set renderTemplate property, after initialization:<br>
            * // Get the renderTemplate API value.		
            *  $("#menu").ejmMenu("option", "renderTemplate");			
            * // Set the renderTemplate API
            * $("#menu").ejmMenu("option", "renderTemplate", false);  
            * &lt;/script&gt;	          
            * @memberof ejmMenu
            * @instance
            */
            renderTemplate: false,

            /**		
            * Specifies whether need to show the scroll bars when scrolling is allowed.
            * @default true
            * @type {boolean}
            * @example             
            * // Set showScrollbars in unobtrusive way.
            * &lt;div&gt;
            *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu"/&gt;
            * &lt;/div&gt; <br/>
            * &lt;div id="menu" data-role="ejmmenu" data-ej-targetid="menuitem" data-ej-allowScrolling=true data-ej-showScrollbars=true&gt;
            *   &lt;ul&gt; 
            *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
            *   &lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * // Set showScrollbars property in obtrusive way.
            * &lt;div&gt;
            *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu" /&gt;
            * &lt;/div&gt; <br/>
            * &lt;div id="menu"&gt;
            *   &lt;ul&gt; 
            *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
            *   &lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * 	// Set showScrollbars property on initialization. 
            * 	// To set showScrollbars API value 
            * 	$("#menu").ejmMenu ({ targetId : "menuitem" , allowScrolling : true , showScrollbars: true});	
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * // Get or set showScrollbars property, after initialization:<br>
            * // Get the showScrollbars API value.		
            *  $("#menu").ejmMenu("option", "showScrollbars");			
            * // Set the showScrollbars API
            * $("#menu").ejmMenu("option", "showScrollbars", true);   
            * &lt;/script&gt;         
            * @memberof ejmMenu
            * @instance
            */
            showScrollbars: true,

            /**		
            * Specifies ID of the element contains template contents.
            * @default null
            * @type {string}
            * @example             
            * // Set templateId property in unobtrusive way.
            * &lt;div&gt;
            *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu"/&gt;
            * &lt;/div&gt; <br/>
            * &lt;div id="menu" data-role="ejmmenu" data-ej-targetid="menuitem" data-ej-templateid="menuTemplate" data-ej-rendertemplate=true&gt;&lt;/div&gt;
            *   &lt;div id="menuTemplate"&gt; 
            *      &lt;li&gt;Get info&lt;/li&gt;
            *      &lt;li&gt;Show in folder&lt;/li&gt;
            *      &lt;li&gt;Delete&lt;/li&gt;
            *   &lt;/div&gt;
            * 
            * @example 
            * // Set templateId property in obtrusive way.
            * &lt;div&gt;
            *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu" /&gt;
            * &lt;/div&gt; <br/>
            * &lt;div id="menu"&gt;&lt;/div&gt;
            *   &lt;div id="menuTemplate"&gt; 
            *      &lt;li&gt;Get info&lt;/li&gt;
            *      &lt;li&gt;Show in folder&lt;/li&gt;
            *      &lt;li&gt;Delete&lt;/li&gt;
            *   &lt;/div&gt;
            * &lt;script&gt;
            * 	// Set templateId property on initialization. 
            * 	// To set templateId API value 
            * 	$("#menu").ejmMenu ({ targetId : "menuitem" , renderTemplate : true , templateId: "menuTemplate"});			
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * // Get or set templateId property, after initialization:<br>
            * // Get the templateId API value.		
            *  $("#menu").ejmMenu("option", "templateId");			
            * // Set the templateId API
            * $("#menu").ejmMenu("option", "templateId", "menuTemplate");   
            * &lt;/script&gt;         
            * @memberof ejmMenu
            * @instance
            */
            templateId: null,

            /**		
            * Specifies the theme. See {@link Theme}
            * @default auto 
            * @type {enum}
            * @example 
            * // Set theme in unobtrusive way.
            * &lt;div&gt;
            *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu" data-ej-theme="auto"/&gt;
            * &lt;/div&gt; <br/>
            * &lt;div id="menu" data-role="ejmmenu" data-ej-targetid="menuitem" data-ej-theme="auto"&gt;
            *   &lt;ul&gt; 
            *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
            *   &lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * // Set theme in obtrusive way.
            * &lt;div&gt;
            *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu" data-ej-theme="auto" /&gt;
            * &lt;/div&gt; <br/>
            * &lt;div id="menu"&gt;
            *   &lt;ul&gt; 
            *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
            *   &lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * 	// Set theme on initialization. 
            * 	// To set theme API value 
            * $(function(){
            * 	$("#menu").ejmMenu ({ targetId : "menuitem" , theme: ej.mobile.Theme.Auto });		
            * });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * // Get or set theme, after initialization:<br>
            * // Get theme API value.		
            *  $("#menu").ejmMenu("option", "theme");			
            * // Set theme API value.
            * $("#menu").ejmMenu("option", "theme", ej.mobile.Theme.Auto);    
            * &lt;/script&gt;        
            * @memberof ejmMenu
            * @instance
            */
            theme: "auto",

            /**		
            * Specifies the rendering mode of the control. See {@link RenderMode}
            * @default auto
            * @type {enum}
            * @example 
            * // Set renderMode in unobtrusive way.
            * &lt;div&gt;
            *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu" data-ej-rendermode="auto"/&gt;
            * &lt;/div&gt; <br/>
            * &lt;div id="menu" data-role="ejmmenu" data-ej-targetid="menuitem" data-ej-rendermode="auto"&gt;
            *   &lt;ul&gt; 
            *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
            *   &lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * // Set renderMode in obtrusive way.
            * &lt;div&gt;
            *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu" data-ej-rendermode="auto" /&gt;
            * &lt;/div&gt; <br/>
            * &lt;div id="menu"&gt;
            *   &lt;ul&gt; 
            *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
            *   &lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * 	// Set rendermode on initialization. 
            * 	// To set renderMode API value 
            * $(function(){
            * 	$("#menu").ejmMenu ({ targetId : "menuitem" , renderMode: ej.mobile.RenderMode.Auto });			
            * });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * // Get or set rendermode, after initialization:<br>
            * // Get renderMode API value.		
            *  $("#menu").ejmMenu("option", "renderMode");			
            * // Set renderMode API
            * $("#menu").ejmMenu("option", "renderMode", ej.mobile.RenderMode.Auto);   
            * &lt;/script&gt;         
            * @memberof ejmMenu
            * @instance
            */
            renderMode: "auto",

            /**		
            * Specifies to maintain the current model value to browser cookies for state maintenance. While refresh the page, the model value will get apply to the control from browser cookies.
            * @default false
            * @type {boolean}
            * @example 
            * // Set enablePersistence in unobtrusive way.
            * &lt;div&gt;
            *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu" data-ej-enablepersistence="true"/&gt;
            * &lt;/div&gt; <br/>
            * &lt;div id="menu" data-role="ejmmenu" data-ej-targetid="menuitem" data-ej-enablepersistence="true"&gt;
            *   &lt;ul&gt; 
            *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
            *   &lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * // Set enablePersistence in obtrusive way.
            * &lt;div&gt;
            *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu" data-ej-enablepersistence="true" /&gt;
            * &lt;/div&gt; <br/>
            * &lt;div id="menu"&gt;
            *   &lt;ul&gt; 
            *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
            *   &lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * 	// Set enablePersistence on initialization. 
            * 	// To set enablePersistence API value 
            * 	$("#menu").ejmMenu ({ targetId : "menuitem" , enablePersistence: true });			
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * // Get or set enablePersistence after initialization:<br>
            * // Get the enablePersistence API value.		
            *  $("#menu").ejmMenu("option", "enablePersistence");			
            * // Set the enablePersistence API
            * $("#menu").ejmMenu("option", "enablePersistence", false);
            * &lt;/script&gt;            
            * @memberof ejmMenu
            * @instance
            */
            enablePersistence: false,

            /**    
            * Event triggers before the items loaded.
            * @event
            * @name ejmMenu#load	
            * @param {Object} argument Event parameters from menu.
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @example 
            * // Set load event in unobtrusive way.
            * &lt;div&gt;
            *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu" data-ej-rendermode="auto"/&gt;
            * &lt;/div&gt; <br/>
            * &lt;div id="menu" data-role="ejmmenu" data-ej-targetid="menuitem" data-ej-load="load"&gt;
            *   &lt;ul&gt; 
            *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
            *   &lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt; 
            * // load event for menu
            * function load(args){ 
            *		//handle the event 
            * }
            * &lt;/script&gt;
            * @example  
            * // Set load event in obtrusive way.
            * &lt;div&gt;
            *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu" data-ej-rendermode="auto"/&gt;
            * &lt;/div&gt; <br/>
            * &lt;div id="menu" &gt;
            *   &lt;ul&gt; 
            *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
            *   &lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * // load event for menu
            * $("#menu").ejmMenu({ targetId:"menuitem",
            *   	load: function (args) { 
            *			//handle the event 
            *		}
            *  });         
            * &lt;/script&gt;  
            * @memberof ejmMenu
            * @instance
            */
            load: null,

            /**    
            * Event triggers after the items loaded.
            * @event
            * @name ejmMenu#loadComplete
            * @param {Object} argument Event parameters from menu.
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @example 
            * // Set loadcomplete event in unobtrusive way.
            * &lt;div&gt;
            *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu"/&gt;
            * &lt;/div&gt; <br/>
            * &lt;div id="menu" data-role="ejmmenu" data-ej-targetid="menuitem" data-ej-loadcomplete="loadcomplete"&gt;
            *   &lt;ul&gt; 
            *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
            *   &lt;/ul&gt;
            * &lt;/div&gt;
            *
            * &lt;script&gt; 
            * // loadcomplete event for menu
            * function loadcomplete(args){ 
            *	//handle the event 
            * }
            * &lt;/script&gt;
            * @example  
            * // Set loadcomplete event in obtrusive way.
            * &lt;div&gt;
            *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu"/&gt;
            * &lt;/div&gt; <br/>
            * &lt;div id="menu" &gt;
            *   &lt;ul&gt; 
            *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
            *   &lt;/ul&gt;
            * &lt;/div&gt;
            *
            * &lt;script&gt; 
            * // loadcomplete event for menu
            * $("#menu").ejmMenu({ targetId:"menuitem",
            *   loadComplete: function (args) { 
            * 		//handle the event 
            *	}
            *  });           
            * @memberof ejmMenu
            * @instance
            */
            loadComplete: null,

            /**    
            * Event triggers when touch start happens on the item.
            * @event
            * @name ejmMenu#touchStart 	
            * @param {Object} argument Event parameters from menu.
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @param {Object} argument.item returns the current menu list element
            * @param {string} argument.text returns the current menu list element associated text
            * @example 
            * // Set touchstart event in unobtrusive way.
            * &lt;div&gt;
            *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu"/&gt;
            * &lt;/div&gt; <br/>
            * &lt;div id="menu" data-role="ejmmenu" data-ej-targetid="menuitem" data-ej-touchstart="touchstart"&gt;
            *   &lt;ul&gt; 
            *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
            *   &lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt; 
            * // touchStart event for menu
            * function touchstart(args){ 
            *	//handle the event 
            * }
            * &lt;/script&gt;
            * @example 
            * // Set touchstart event in obtrusive way.
            * &lt;div&gt;
            *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu"/&gt;
            * &lt;/div&gt; <br/>
            * &lt;div id="menu" &gt;
            *   &lt;ul&gt; 
            *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
            *   &lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt; 
            * // touchStart event for menu
            * $("#menu").ejmMenu({targetId:"menuitem" ,
            *   touchStart: function (args) { 
            *      //handle the event 
            *    }
            *  });           
            * &lt;/script&gt;
            * @memberof ejmMenu
            * @instance
            */
            touchStart: null,

            /**    
            * Event triggers when touch end happens on the item.
            * @event
            * @name ejmMenu#touchEnd 	
            * @param {Object} argument Event parameters from menu.
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @param {Object} argument.item returns the current menu list element
            * @param {string} argument.text returns the current menu list element associated text
            * @example 
            * // Set touchend event in unobtrusive way.
            * &lt;div&gt;
            *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu"/&gt;
            * &lt;/div&gt; <br/>
            * &lt;div id="menu" data-role="ejmmenu" data-ej-targetid="menuitem" data-ej-touchend="touchend"&gt;
            *   &lt;ul&gt; 
            *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
            *   &lt;/ul&gt;
            * &lt;/div&gt;
            *
            * &lt;script&gt; 
            * // touchend event for menu
            * function touchend(args){ 
            * 	//handle the event 
            * }
            * &lt;/script&gt;
            * @example 
            * // Set touchend event in obtrusive way.
            * &lt;div&gt;
            *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu"/&gt;
            * &lt;/div&gt; <br/>
            * &lt;div id="menu" &gt;
            *   &lt;ul&gt; 
            *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
            *   &lt;/ul&gt;
            * &lt;/div&gt;
            *
            * &lt;script&gt; 
            * // touchend event for menu
            * $("#menu").ejmMenu({ targetId:"menuitem",
            *   touchEnd: function (args) { 
            *      //handle the event 
            *   }
            *  });      
            * &lt;/script&gt;     
            * @memberof ejmMenu
            * @instance
            */
            touchEnd: null,

            /**    
            * Event triggers when the control get hided.
            * @event
            * @name ejmMenu#hide 	
            * @param {Object} argument Event parameters from menu.
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @example 
            * // Set hide event in unobtrusive way.
            * &lt;div&gt;
            *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu"/&gt;
            * &lt;/div&gt; <br/>
            * &lt;div id="menu" data-role="ejmmenu" data-ej-targetid="menuitem" data-ej-hide="hide"&gt;
            *   &lt;ul&gt; 
            *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
            *   &lt;/ul&gt;
            * &lt;/div&gt;
			
            * &lt;script&gt; 
            * // hide event for menu
            * function hide(args){ 
            *        //handle the event 
            * }
            * &lt;/script&gt;
            * @example 
            * // Set hide event in obtrusive way.
            * &lt;div&gt;
            *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu"/&gt;
            * &lt;/div&gt; <br/>
            * &lt;div id="menu" &gt;
            *   &lt;ul&gt; 
            *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
            *   &lt;/ul&gt;
            * &lt;/div&gt;
			
            * &lt;script&gt; 
            * // hide event for menu
            * $("#menu").ejmMenu({ targetId:"menuitem", 
            * 	hide: function (args) { 
            *   	//handle the event 
            *   }
            *  });          
            * &lt;/script&gt; 
            * @memberof ejmMenu
            * @instance
            */
            hide: null,

            /**    
            * Event triggers when the control get shown.
            * @event
            * @name ejmMenu#show 
            * @param {Object} argument Event parameters from menu.	
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @example 
            * // Set show event in unobtrusive way.
            * &lt;div&gt;
            *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu"/&gt;
            * &lt;/div&gt; <br/>
            * &lt;div id="menu" data-role="ejmmenu" data-ej-targetid="menuitem" data-ej-show="show"&gt;
            *   &lt;ul&gt; 
            *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
            *   &lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt; 
            * // show event for menu
            * function show(args){ 
            *  	//handle the event 
            * }
            * &lt;/script&gt;
            * @example 
            * // Set show event in obtrusive way.
            * &lt;div&gt;
            *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu"/&gt;
            * &lt;/div&gt; <br/>
            * &lt;div id="menu" &gt;
            *   &lt;ul&gt; 
            *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
            *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
            *   &lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt; 
            * // show event for menu
            * $("#menu").ejmMenu({ targetId:"menuitem", 
            * 	show: function (args) { 
            *  		//handle the event 
            *   }
            *  });      
            * &lt;/script&gt;     
            * @memberof ejmMenu
            * @instance
            */
            show: null,
            items: []
        },
        //Datatypes of model variables
        dataTypes: {
            ios7: { "type": "enum", "cancelButtonColor": "enum" },
            android: { "type": "enum" },
            windows: { "type": "enum" },
            renderMode: "enum",
            theme: "enum",
            enablePersistence: "boolean"
        },

        /**
        * Create the Menu widget
        * @private
        */
        //Constructor function
        _init: function () {
            this._storedTemplate = [];
            this._renderControl();
            this._wireEvents();
        },

        /**
        * Section for Menu control before load
        * @private
        */
        //Before loading the menu
        _load: function () {
            ej.setRenderMode(this);
            ej.setTheme(this);
            this._touchStart = this.model.touchStart;
            this._touchEnd = this.model.touchEnd;
            if (this.model.renderMode == "windows" && ej.isMobile() && this.model.windows.renderDefault)
                this.model.theme = "default";
            if (this.model.enablePersistence)
                this.model.items = [];
            this._orgEle = this.element.clone();
            this._indexVal = 0;
            this.model.id = this.element[0].id;
            if (this.model.load)
                this._trigger("load");
        },
        _renderItems: function (proxy) {
            if (proxy.model.items.length < 1) {
                var elements = this.element.find("li");
                for (i = 0; i < this.element.find("li").length; i++) {
                    var item = {};
                    var element = elements[i];
                    item.text = ej.getAttrVal(element, 'data-ej-text', "Text")
                    item.android = ej.getAttrVal(element, 'data-ej-android-imageclass', "");
                    item.renderTemplate = ej.getAttrVal(element, 'data-ej-rendertemplate', false);
                    item.ios7 = {
                        theme: ej.getAttrVal(element, 'data-ej-theme', this.model.theme),
                        buttonColor: ej.getAttrVal(element, 'data-ej-ios7-buttoncolor', "blue"),
                        buttonStyle: ej.getAttrVal(element, 'data-ej-ios7-buttonstyle', "normal")
                    };
                    item.href = ej.getAttrVal(element, 'data-ej-href', "");
                    item.templateId = ej.getAttrVal(element, 'data-ej-templateid', undefined);
                    item.touchStart = ej.getAttrVal(element, 'data-ej-touchstart', undefined);
                    item.touchEnd = ej.getAttrVal(element, 'data-ej-touchend', undefined);
                    this.model.items.push(item);
                }
            }
            else {
                var ul = ej.buildTag('ul.e-m-menu-hdr e-m-clearall');
                var elements = this.model.items;
                for (i = 0; i < this.model.items.length; i++) {
                    var element = elements[i];
                    element.ios7 = (element.ios7 == undefined) ? { buttonColor: "blue", theme: this.model.theme, buttonStyle: "normal"} : {
                        buttonColor: element.ios7["buttonColor"] ? element.ios7["buttonColor"] : "blue",
                        theme: element.ios7["theme"] ? element.ios7["theme"] : this.model.theme,
                        buttonStyle: element.ios7["buttonStyle"] ? element.ios7["buttonStyle"] : "normal"
                    };
                    element.android = (element.android == undefined) ? { imageClass: ""} : { imageClass: element.android["imageClass"] };
                    element.renderTemplate = element.renderTemplate ? element.renderTemplate : false;
                    element.href = element.href ? element.href : "";
                    element.touchStart = element.touchStart ? element.touchStart : undefined;
                    element.touchEnd = element.touchEnd ? element.touchEnd : undefined;
                    element.templateId = element.templateId ? element.templateId : undefined;
                    var li = ej.buildTag('li');
                    this.element.append(ul.append(li));
                }
            }
        },
        /**
        * Render Section for Menu control	
        * @private
        */
        //To render the menu control
        _renderControl: function () {
            this._load();
            this.element.addClass("e-m-" + this.model.renderMode + " e-m-" + this.model.theme).addClass(!ej.isMobile() ? "e-m-tablet" : "e-m-mobile");
            var proxy = this;
            App.activePage.append(this.element);
            this._activePage = this.element.closest('.appview');
            this._mcontainer = ej.buildTag("div.e-m-menu-container");
            this._renderItems(proxy);
            if (this.model.renderTemplate) {
                var ul = ej.buildTag('ul.e-m-menu-hdr e-m-clearall');
                if (ej.getCurrentPage().find('#' + this.model.templateId).length) {
                    this._itemTemplate = ej.getCurrentPage().find('#' + this.model.templateId);
                    this._itemTemplate = this._itemTemplate[0].nodeName && this._itemTemplate[0].nodeName.toLowerCase() == "script" ? ej.getClearString(this._itemTemplate[0].innerHTML) : this._itemTemplate;
                }
                else if (!this._itemTemplate)
                    this._itemTemplate = this.element.children();
                this.element.empty();
                this._mcontainer.append(ul.append(this._itemTemplate));
                this.element.append(this._mcontainer);
                ej.widget.init(this._mcontainer);
            }
            if (this["_" + this.model.renderMode + "Properties"])
                this["_" + this.model.renderMode + "Properties"]();
            if (!this.model.renderTemplate) {
                var ul = this.element.find("ul").addClass("e-m-menu-hdr e-m-clearall");
                this.element.append(this._mcontainer.append(ul));
                this._menuLiItems = this.element.find("li").addClass("e-m-state-default e-m-user-select e-m-menuitem");
                this._menuLiItems.first().addClass("e-m-firstitem");
                this._menuLiItems.last().addClass("e-m-lastitem");
                this._menuLiItems.each(function (index, element) {
                    proxy["_" + proxy.model.renderMode + "RenderMenu"](element, index);
                });
                if (this.overFlowMenu && this._menuLiItems.length > 5) {
                    ul.append(this._renderMenuItems(ej.buildTag("li.e-m-state-default e-m-user-select e-m-menuitem e-m-lastitem e-m-text-center e-m-more", "More", {}, { "data-ej-android-imageclass": "e-m-menu-more e-m-fontimage" })[0]));
                    this._overFlowMenuUl.find('li').first().addClass("e-m-firstitem");
                }
            }
            if (this.model.renderMode == "ios7") {
                var containerWrap = ej.buildTag('div.e-m-menu-wrap');
                this.element.append(containerWrap.append(this._mcontainer));
                if (this.model.ios7.type == "animate")
                    this.element.append(this._ios7Container.append(containerWrap.append(this._mcontainer)));
                if (this.model.ios7.showTitle || this.model.ios7.showCancelButton) {
                    this.model.ios7.type == "animate" ? this._ios7Container.append(containerWrap) : containerWrap.insertBefore(this.element.find('.e-m-menu-iconimg.e-m-bottom'));
                    if (this.model.ios7.showTitle) {
                        var titleDiv = ej.buildTag("div.e-m-menu-title", this.model.ios7.title);
                        if (this.model.ios7.type == "animate")
                            containerWrap.prepend(titleDiv);
                        else
                            titleDiv.insertAfter(this.element.find('.e-m-menu-iconimg.e-m-top'));
                        this._mcontainer.addClass("e-m-title");
                    }
                    if (this.model.ios7.showCancelButton && this.model.ios7.type == "animate") {
                        var button = ej.buildTag("a.e-m-menu-btn", this.model.ios7.cancelButtonText, {}, { "type": "button" });
                        var cancel = ej.buildTag("div.e-m-menu-cancel", button);
                        this._ios7Container.append(cancel);
                        button.ejmActionlink({
                            theme: this.model.theme,
                            renderMode: this.model.renderMode,
                            ios7: { color: this.model.ios7.cancelButtonColor },
                            windows: { renderDefault: this.model.windows.renderDefault }
                        });
                        this._mcontainer.addClass("e-m-cancel");
                    }
                }
            }
            if (this.model.width)
                this.element.css("width", this.model.width);
            if (this.model.height) {
                var cHgt = this.element.outerHeight() - ej.getDimension(this.element.find('.e-m-menu-container'), 'outerHeight');
                this.element.css("height", this.model.height + cHgt).find('.e-m-menu-container').css("height", this.model.height);
            }
            this._eleHeight = ej.getDimension(this._getElement(), 'outerHeight');
            this._containerHeight = ej.getDimension(this._getElement().find('.e-m-menu-container'), 'outerHeight');
            this._shown = true;
            if (ej.isIOS() && this.model.ios7.type == "animate")
                this.element.css('visibility', 'hidden');
            this.hide();
            this.element.css({ "z-index": ej.getMaxZindex() + 1 });
            if (this.model.loadComplete)
                this._trigger("loadComplete");
        },
        //To get the element
        _getElement: function () {
            return this.overFlowMenu ? this.overFlowMenu : this.element;
        },

        /**
        * Section for Menu control IOS7 specific actions
        * @private
        */
        //To do iOS7 specific actions
        _ios7Properties: function () {
            if (this.model.ios7.type == "auto")
                this.model.ios7.type = ej.isMobile() ? "animate" : "normal";
            this.element.addClass("e-m-menu-" + this.model.ios7.type);
            if (this.model.ios7.type == "normal") {
                this.element.prepend(ej.buildTag("div.e-m-menu-iconimg e-m-top e-m-fontimage"));
                this.element.addClass("e-m-corner-all e-m-abs");
                this.element.append(ej.buildTag("div.e-m-menu-iconimg e-m-bottom e-m-fontimage"));
            }
            else {
                this.element.addClass("e-m-fixed");
                this._ios7Container = ej.buildTag('div.e-m-menu e-m-wrapper');
            }
            this._createOverlayDiv();
        },

        /**
        * Section for Menu control Android specific actions
        * @private
        */
        //To do android specific actions
        _androidProperties: function () {
            this.element.addClass("e-m-" + this.model.android.type + " e-m-margin-auto");
            if (this.model.android.type == "optionsmenu" && !this.model.renderTemplate) {
                this.overFlowMenu = ej.buildTag("div.e-m-menu e-m-android e-m-overflowmenu e-m-fixed e-m-" + this.model.theme + "#" + this.model.id + "_menu");
                var overFlowMenuContainer = ej.buildTag("div.e-m-menu-container");
                this._overFlowMenuUl = ej.buildTag("ul.e-m-menu-hdr e-m-clearall");
                App.activePage.append(this.overFlowMenu.append(overFlowMenuContainer.append(this._overFlowMenuUl)));
            }
            else if (this.model.android.type == "contextual")
                this._createOverlayDiv();
            this.element.addClass(this.model.android.type == "popup" ? "e-m-abs" : "e-m-fixed");
        },

        /**
        * Section for Menu control Windows specific actions
        * @private
        */
        //To do windows specific actions
        _windowsProperties: function () {
            this.element.addClass("e-m-" + this.model.windows.type + " e-m-fixed");
        },
        //To do flat specific actions
        _flatProperties: function () {
            this.element.addClass("e-m-abs");
        },

        /**
        * Render section for IOS7 Menu
        * @private
        */
        //To render iOS7 menu
        _ios7RenderMenu: function (element, index) {
            var ctrl;
            if (this.model.items[index].renderTemplate)
                this._appendTemplate(element, index, ctrl);
            else {
                ctrl = ej.buildTag("a.e-m-menu-btn#" + this.model.id + index, this.model.items[index].text);
                $(element).empty().append(ctrl);
                ctrl.ejmActionlink({
                    text: this.model.items[index].text,
                    theme: this.model.items[index].ios7["theme"],
                    renderMode: this.model.renderMode,
                    href: this.model.items[index].href,
                    ios7: {
                        color: this.model.items[index].ios7["buttonColor"],
                        style: this.model.items[index].ios7["buttonStyle"]
                    },
                    windows: { renderDefault: this.model.windows.renderDefault }
                });
            }
        },

        /**
        * Render section for Android Menu
        * @private
        */
        //To render android menu
        _androidRenderMenu: function (element, index) {
            if (this.overFlowMenu && index >= 4 && this._menuLiItems.length > 5)
                this._overFlowMenuUl.append(this._renderMenuItems(element, index));
            else {
                if (this.overFlowMenu)
                    $(element).addClass("e-m-text-center");
                this._renderMenuItems(element, index);
            }
        },

        /**
        * Render section for Windows Menu
        * @private
        */
        //To render windows menu
        _windowsRenderMenu: function (element, index) {
            this._renderMenuItems(element, index);
        },

        /**
        * Render section for Flat Menu
        * @private
        */
        //To render flat menu
        _flatRenderMenu: function (element, index) {
            this._renderMenuItems(element, index);
        },

        /**
        * Render section Menu control inner elements
        * @private
        */
        //To render the menu items for android and windows mode
        _renderMenuItems: function (element, index) {
            var tag;
            if (index) {
                if (this.model.items[index].renderTemplate)
                    this._appendTemplate(element, index, tag);
                else {
                    var tag = ej.buildTag("a.e-m-menuitem-anchor e-m-remove-shadow", this.model.renderMode == "android" ? "" : this.model.items[index].text,
                {}, { 'href': this.model.items[index].href });
                    if (this.model.renderMode == "android") {
                        var span = ej.buildTag("span.e-m-menuitem-span e-m-user-select", this.model.items[index].text);
                        var imageClass = this.model.items[index].android["imageClass"];
                        if (imageClass) {
                            tag.append(ej.buildTag("div", "", "", { "class": "menuimg e-m-margin-auto e-m-rel " + imageClass }));
                            span.addClass("e-m-texttop");
                        }
                        tag.append(span);
                        this.overFlowMenu ? this._menuLiItems.length > 5 && index >= 4 ? this._addClass(span, element) : ($(element).addClass("e-m-padding"), tag.addClass("e-m-auto-hgt")) : this._addClass(span, element);
                    }
                    $(element).empty().append(tag);
                }
            }
            else {
                if (ej.getAttrVal(element, 'data-ej-rendertemplate', false))
                    this._appendTemplate(element, tag);
                else {
                    var tag = ej.buildTag("a.e-m-menuitem-anchor e-m-remove-shadow", this.model.renderMode == "android" ? "" : ej.getAttrVal(element, 'data-ej-text'),
                {}, { 'href': ej.getAttrVal(element, 'data-ej-href', "") });
                    if (this.model.renderMode == "android") {
                        var span = ej.buildTag("span.e-m-menuitem-span e-m-user-select", ej.getAttrVal(element, 'data-ej-text'));
                        var imageClass = ej.getAttrVal(element, 'data-ej-android-imageclass');
                        if (imageClass) {
                            tag.append(ej.buildTag("div", "", "", { "class": "menuimg e-m-margin-auto e-m-rel " + imageClass }));
                            span.addClass("e-m-texttop");
                        }
                        tag.append(span);
                        this.overFlowMenu ? this._menuLiItems.length > 5 && index >= 4 ? this._addClass(span, element) : ($(element).addClass("e-m-padding"), tag.addClass("e-m-auto-hgt")) : this._addClass(span, element);
                    }
                    $(element).empty().append(tag);
                }
            }
            return element;
        },

        /**
        * Render section for Menu control template elements
        * @private
        */
        _appendTemplate: function (element, index, ctrl) {
            var ele = ej.getCurrentPage().find('#' + this.model.items[index].templateId);
            if (ele.length) {
                this._storedTemplate[this._indexVal] = ele[0].nodeName && ele[0].nodeName.toLowerCase() == "script" ? ej.getClearString(ele[0].innerHTML) : ele;
                $(element).empty().append(this._storedTemplate[this._indexVal]);
                this._indexVal = this._indexVal + 1;
            }
            else if (this._storedTemplate[this._indexVal]) {
                $(element).empty().append(this._storedTemplate[this._indexVal]);
                this._indexVal = this._indexVal + 1;
            }
            ej.widget.init(element);
        },
        //To add the class for span and list element
        _addClass: function (span, element) {
            span.addClass("e-m-rel");
            $(element).addClass("e-m-border-top");
        },
        //To position the menu based on its type
        _positionMenu: function (tar) {
            if (this.model.renderMode == "android" && this.overFlowMenu)
                this.overFlowMenu.css("left", (this._windowWidth - this.overFlowMenu.outerWidth()) / 2);
            else if (this["_" + this.model[this.model.renderMode].type + "Position"])
                this["_" + this.model[this.model.renderMode].type + "Position"](tar);
        },
        //To position normal mode menu for ios7 mode
        _normalPosition: function (tar) {
            if (tar.length) {
                var wid = this.element.width();
                var win_wid = this._windowWidth;
                var left = this._tarOffsetLeft + tar.outerWidth() / 2 - (wid / 2);
                if (left < 0)
                    left = 5;
                else if (win_wid - left < wid)
                    left = win_wid - wid;
                this.element.css({ "left": left + "px" });
                this.element.find('.e-m-menu-iconimg').css("left", this._tarOffsetLeft + ((tar.outerWidth() - 40) / 2) - left);
                var top = this._tarOffsetTop;
                var hgt = top + tar.outerHeight();
                if (this._windowHeight > top + this._targetHeight) {
                    this.element.css({ "top": hgt + 10, "bottom": "auto" });
                    this.element.find('.e-m-menu-iconimg.e-m-top').removeClass("e-m-state-hide").addClass("e-m-state-block");
                    this.element.find('.e-m-menu-iconimg.e-m-bottom').removeClass("e-m-state-block").addClass("e-m-state-hide");
                }
                else {
                    this.element.css({ "bottom": this._windowHeight - top + 10, "top": "auto" });
                    this.element.find('.e-m-menu-iconimg.e-m-bottom').removeClass("e-m-state-hide").addClass("e-m-state-block");
                    this.element.find('.e-m-menu-iconimg.e-m-top').removeClass("e-m-state-block").addClass("e-m-state-hide");
                }
            }
        },
        //To call set position for options list menu in android mode
        _optionslistPosition: function () {
            this._setPosition();
        },
        //To call set position for options menu in android mode
        _optionsmenuPosition: function () {
            this._setPosition();
        },
        //To position options list and options menu for android mode
        _setPosition: function (tar) {
            if (this.model.renderMode == "flat")
                this.element.css("top", this._tarOffsetTop + tar.outerHeight());
            else if (this.overFlowMenu)
                this.overFlowMenu.css("left", (this._windowWidth - this.overFlowMenu.outerWidth()) / 2);
            else
                this.element.css("left", (this._windowWidth - this.element.outerWidth()) / 2);
        },
        //To position popup menu for android and windows mode
        _popupPosition: function (tar) {
            var top = this._tarOffsetTop;
            var hgt = top + tar.outerHeight();
            if (this._windowWidth > this._tarOffsetLeft + this.element.outerWidth())
                this.element.css({ "left": this._tarOffsetLeft, "right": "auto" });
            else
                this.element.css({ "right": this._windowWidth - (this._tarOffsetLeft + tar.outerWidth()), "left": "auto" });
            if (this._windowHeight > top + this._targetHeight)
                this.element.css({ "top": hgt + 10, "bottom": "auto" });
            else
                this.element.css({ "bottom": this._windowHeight - top + 10, "top": "auto" });
        },
        _resetPosition: function () {
            if (this.model.renderMode == "windows" && this.model.windows.type == "contextual" && ej.isMobile())
                this.element.css({ "top": "auto", "bottom": "auto" }).removeClass('e-m-right e-m-left e-m-landscape');
            else if (this.overFlowMenu)
                this.overFlowMenu.css({ "left": "auto", "right": "auto" });
            else
                this.element.css({ "left": "auto", "right": "auto" });
        },
        //To position contextual menu for android and windows mode
        _contextualPosition: function (tar) {
            if (this.model.renderMode == "windows") {
                if (ej.isMobile()) {
                    var top = this._tarOffsetTop;
                    var hgt = top + tar.outerHeight();
                    if (this._windowHeight > top + this._eleHeight)
                        this.element.css({ "top": hgt + 5 });
                    else
                        this.element.css({ "bottom": this._windowHeight - top + 5 });
                }
            }
            else {
                this.element.css({ "top": (this._windowHeight - this._targetHeight) / 2 });
                if (this.model.renderMode == "android")
                    this.element.css({ "left": (this._windowWidth - this.element.outerWidth()) / 2 });
            }
        },
        _isPopUp: function () {
            return (this.model.renderMode == "ios7" && this.model.ios7.type == "normal") || (this.model.renderMode == "android" && this.model.android.type == "popup") || (this.model.renderMode == "windows" && this.model.windows.type == "popup") || this.model.renderMode == "flat";
        },
        //To render and update scroll panel
        _scrollPanel: function () {
            this._exceeded = false;
            var id = this._getElement();
            this._targetHeight = this._eleHeight;
            var containerHeight;
            if (this.model.height) {
                containerHeight = this.model.height;
                if (this.model.allowScrolling)
                    this._exceeded = true;
            }
            else {
                containerHeight = this._eleHeight - this._containerHeight;
                var chkHgt = this._targetHeight;
                if (this._isPopUp())
                    chkHgt = chkHgt + this._tarOffsetTop + this._tar.outerHeight();
                else if (this.model.renderMode == "windows" && this.model.windows.type == "contextual" && !ej.isMobile())
                    chkHgt = chkHgt + this._pageTop;
                if (chkHgt > this._windowHeight) {
                    this._exceeded = true;
                    if (this.model.renderMode == "windows" && this.model.windows.type == "contextual" && ej.isMobile())
                        this._targetHeight = this._windowHeight;
                    else
                        this._targetHeight = this._targetHeight > this._windowHeight ? this._windowHeight - 20 : this._targetHeight;
                    if (this._isPopUp()) {
                        if (this._tarOffsetTop + this._tar.outerHeight() > this._windowHeight / 2)
                            this._targetHeight = this._targetHeight > this._tarOffsetTop ? this._tarOffsetTop - 20 : this._targetHeight;
                        else
                            this._targetHeight = this._targetHeight - this._tar.outerHeight() - 10;
                    }
                    else if (this.model.renderMode == "windows" && this.model.windows.type == "contextual" && !ej.isMobile()) {
                        if (this._pageTop + this._targetHeight - 10 > this._windowHeight)
                            this._targetHeight = this._targetHeight - (this._windowHeight - this._pageTop);
                        else
                            this._targetHeight = this._targetHeight - this._pageTop;
                    }
                }
                else if (this.model.renderTemplate && this.model.allowScrolling)
                    this._exceeded = true;
                containerHeight = this._targetHeight - containerHeight;
            }
            if (this.model.renderMode == "windows" && this.model.windows.type == "contextual" && ej.isMobile())
                $(id).css('height', 'auto');
            else
                $(id).css('height', this._targetHeight);
            if (this._scroller) {
                this._scroller.model.targetHeight = containerHeight;
                this._scroller.refresh();
                if (!this._exceeded)
                    this._scroller.disable();
                else
                    this._scroller.enable();
            }
            else if (this._exceeded && this.model.allowScrolling) {
                var scrollWrapper = ej.buildTag('div#' + this.model.id + '_scroll');
                $(id).append(scrollWrapper);
                scrollWrapper.ejmScrollPanel({ theme: this.model.theme, renderMode: this.model.renderMode, target: $(id).find('.e-m-menu-container')[0], targetHeight: containerHeight, showScrollbars: this.model.showScrollbars, windows: { renderDefault: this.model.windows.renderDefault} });
                this._scroller = ej.getCurrentPage().find('#' + this.model.id + '_scroll').ejmScrollPanel("instance");
            }
        },
        _scrollRefresh: function () {
            if (this._scroller)
                this._scroller.refresh();
        },
        //To create overlay for contextual menu in android & windows and animate menu in ios7
        _createOverlayDiv: function () {
            this._createdOverlay = true;
            this._overlay = ej.buildTag("div#" + this.model.id + "_overlay", "", "", { "class": "e-m-overlay e-m-menu-overlay e-m-" + this.model.renderMode });
            this._overlay.addClass(this.model.renderMode == "ios7" && !ej.isMobile() ? "e-m-overlay-hide" : "e-m-state-hide");
            if (this.model.renderMode != "flat")
                this._overlay.addClass("e-m-menu-" + this.model[this.model.renderMode].type);
            this._overlay.css({ "z-index": ej.getMaxZindex() + 1 });
            App.activePage.append(this._overlay);
        },
        _poranimationEnd: function () {
            if (this.model.height)
                this._mcontainer.height(this.model.height);
            else
                this._mcontainer.height(this._mcontainer.find(".e-m-menu-hdr").height());
            this._mcontainer.unbind(ej.transitionEndEvent(), this._poranimationEndDelegate);
            this._mcontainer.bind(ej.transitionEndEvent(), this._animationCompleteDelegate);
        },
        _landanimationEnd: function () {
            if (this.model.width)
                this._mcontainer.width(this.model.width);
            else
                this._mcontainer.width("100%");
            this._mcontainer.unbind(ej.transitionEndEvent(), this._landanimationEndDelegate);
            this._mcontainer.bind(ej.transitionEndEvent(), this._animationCompleteDelegate);
        },
        _animationComplete: function () {
            this._scrollPanel();
            this._mcontainer.unbind(ej.transitionEndEvent(), this._animationCompleteDelegate);
        },
        //To handle event when clicking cancel button
        _cancelMenu: function (evt) {
            var currentMenu = evt.currentTarget;
            if (this.model.ios7.cancelButtonTouchEnd) {
                var data = { item: $(currentMenu), text: $(currentMenu).text() };
                this.model.cancelTouch = this.model.ios7.cancelButtonTouchEnd;
                this._trigger("cancelTouch", data);
            }
            else
                this.hide();
        },
        //To show the overflow menu items for android options menu
        _showOverFlowMenu: function () {
            this.hide();
            this._setPosition();
            if (this.model.renderMode == "android" && this.model.android.type == "optionsmenu")
                this.overFlowMenu.css(!ej.isPortrait() ? { 'right': '10px', 'left': 'auto'} : { 'right': 'auto' });
            this.overFlowMenu.css({ "display": "block" });
            this._scrollRefresh();
        },
        //Click event handler
        _docClick: function (e) {
            this._evt = e;
            if ($(e.target).closest('.e-m-menu').length || (this.model.targetId && (e.currentTarget.id == this.model.targetId || e.target.id == this.model.targetId)) ||
                (this.model.android.type == "optionsmenu" && ej.getCurrentPage().find("#" + this.model.id + "_menu").find("*").index(e.target) > 0))
                return;
            else
                this.hide();
        },
        _addSelection: function () {
            this._currentMenu.closest('.e-m-menu-container').find('.e-m-state-active').removeClass("e-m-state-active").addClass("e-m-state-default");
            this._currentMenu.removeClass("e-m-state-default").addClass("e-m-state-active");
        },
        _removeSelection: function () {
            this._currentMenu.removeClass("e-m-state-active").addClass("e-m-state-default");
            if (this.model.renderMode == "ios7")
                this._currentMenu.find('.e-m-btnwrapper').removeClass("e-m-state-active").addClass("e-m-state-default");
        },
        //Touch Start event handler for menu item
        _onTouchStartHandler: function (evt) {
            this._currentMenu = $(evt.currentTarget);
            var index = $(evt.currentTarget).index();
            this._addSelection();
            if (ej.isWindows())
                ej._touchStartPoints(evt, this);
            if (this.model.renderMode == "windows" && ej.isMobile())
                this._currentMenu.addClass(ej._getSkewClass($(this._currentMenu), evt.pageX, evt.pageY));
            var data = { item: this._currentMenu, text: this._currentMenu.text() };
            this.model.touchStart = (this.model.items[index].touchStart) ? this.model.items[index].touchStart : this._touchStart;
            if (this.model.touchStart)
                this._trigger("touchStart", data);
            this._scroll = false;
            ej.listenTouchEvent(this._li, ej.moveEvent(), this._touchMoveDelegate);
            if (this.overFlowMenu)
                ej.listenTouchEvent(this._overflowLi, ej.moveEvent(), this._touchMoveDelegate);
        },
        _onTouchMoveHandler: function (evt) {
            if (!ej.isWindows() || (ej.isWindows() && ej._isTouchMoved(evt, this))) {
                this._scroll = true;
                this._removeSelection();
                if (this.model.renderMode == "windows" && ej.isMobile())
                    ej._removeSkewClass(this._currentMenu);
            }
        },
        //Touch End event handler for menu item
        _onTouchEndHandler: function (evt) {
            this._removeSelection();
            var index = $(evt.currentTarget).index();
            if (this.model.renderMode == "windows" && ej.isMobile())
                ej._removeSkewClass(this._currentMenu);
            if (!this._scroll) {
                var data = { item: $(this._currentMenu), text: $(this._currentMenu).text() };
                if (this.model.android.type == "optionsmenu" && this.overFlowMenu && this.element.find("li").index(this._currentMenu) == 4)
                    this._showOverFlowMenu();
                this.model.touchEnd = (this.model.items[index].touchEnd) ? this.model.items[index].touchEnd : this._touchEnd;
                if (this.model.touchEnd)
                    this._trigger("touchEnd", data);
            }
            ej.listenTouchEvent(this._li, ej.moveEvent(), this._touchMoveDelegate, true);
            if (this.overFlowMenu)
                ej.listenTouchEvent(this._overflowLi, ej.moveEvent(), this._touchMoveDelegate, true);
        },
        _updateWindowHW: function () {
            this._windowWidth = this._activePage.outerWidth();
            this._windowHeight = this._activePage.outerHeight();
        },
        //Orientation change event handler
        _orientation: function (evt) {
            this._updateWindowHW();
            if (this.overFlowMenu && this.overFlowMenu.is(":visible")) {
                this._showOverFlowMenu();
                return;
            }
            if (this._shown) {
                if ((this.model.renderMode == "ios7" && ej.isMobile()) || (this.model.renderMode == "android" && this.model.android.type == "optionsmenu")) {
                    this._afterHide();
                    return;
                }
                this.hide();
                if (this.model.renderMode == "windows" && this.model.windows.type == "contextual" && !ej.isMobile())
                    return;
                this._afterHide();
            }
        },
        //Resize event handler
        _resize: function (evt) {
            if (this._shown) {
                this._updateWindowHW();
                this._positionMenu(this._tar);
                this._scrollPanel();
            }
        },
        _afterHide: function () {
            var proxy = this;
            setTimeout(function () {
                proxy.show(null, true);
            }, 350);
        },
        _displayMenu: function () {
            if (!this._shown) {
                if ($(this._overlay).hasClass(this.model.renderMode == "ios7" && !ej.isMobile() ? "e-m-overlay-hide" : "e-m-state-hide"))
                    $(this._overlay).css("pointer-events", "none");
                this.element.hide();
            }
            this.element.unbind(ej.transitionEndEvent(), this._displayMenuDelegate);
        },
        //To create delegates for event handling
        _createDelegates: function () {
            this._showDelegate = $.proxy(this.show, this);
            this._cancelMenuDelegate = $.proxy(this._cancelMenu, this);
            this._docClickDelegate = $.proxy(this._docClick, this);
            this._poranimationEndDelegate = $.proxy(this._poranimationEnd, this);
            this._landanimationEndDelegate = $.proxy(this._landanimationEnd, this);
            this._animationCompleteDelegate = $.proxy(this._animationComplete, this);
            this._orientationDelegate = $.proxy(this._orientation, this);
            this._resizeDelegate = $.proxy(this._resize, this);
            this._displayMenuDelegate = $.proxy(this._displayMenu, this);
            this._touchStartDelegate = $.proxy(this._onTouchStartHandler, this);
            this._touchMoveDelegate = $.proxy(this._onTouchMoveHandler, this);
            this._touchEndDelegate = $.proxy(this._onTouchEndHandler, this);
        },
        //To wire events for the menu
        _wireEvents: function (remove) {
            this._createDelegates();
            var eventType = remove ? "unbind" : "bind";
            if (!this.model.renderTemplate) {
                this._li = this.element.find("li");
                ej.listenEvents([this._li, this._li],
                           [ej.startEvent(), ej.endEvent()],
                           [this._touchStartDelegate, this._touchEndDelegate], remove);
            }
            this._tapEvent = this.model.showOn == "tap" ? ej.tapEvent() : this.model.showOn == "taphold" ? ej.tapHoldEvent() : this.model.showOn;
            ej.listenTouchEvent(ej.getCurrentPage().find("#" + this.model.targetId), this._tapEvent, this._showDelegate, remove);
            if (this.overFlowMenu) {
                this._overflowLi = $("#" + this.model.id + "_menu").find("li");
                ej.listenEvents([this._overflowLi, this._overflowLi],
                           [ej.startEvent(), ej.endEvent()],
                           [this._touchStartDelegate, this._touchEndDelegate], remove);
            }
            if (this.model.renderMode == "ios7" && this.model.ios7.showCancelButton)
                ej.listenTouchEvent(this.element.find('.e-m-menu-cancel'), ej.endEvent(), this._cancelMenuDelegate, remove);
            ej.listenTouchEvent($(document), ej.endEvent(), this._docClickDelegate, remove);
            $(window)[eventType]("orientationchange", this._orientationDelegate);
            if (!ej.isTouchDevice() && !ej.isMobile())
                $(window)[eventType]("resize", this._resizeDelegate);
        },
        //To set the model values
        _setModel: function (options) {
            var refresh = false;
            for (var prop in options) {
                var setModel = "_set" + prop.charAt(0).toUpperCase() + prop.slice(1);
                if (this[setModel])
                    this[setModel](options[prop]);
                else
                    refresh = true;
            }
            if (refresh)
                this._refresh();
        },
        _bindEvent: function (remove) {
            ej.listenTouchEvent(ej.getCurrentPage().find("#" + this.model.targetId), this._tapEvent, this._showDelegate, remove);
        },
        //To change the showOn property
        _setShowOn: function (value) {
            if (value) {
                this._bindEvent(true);
                this.model.showOn = value;
                this._tapEvent = this.model.showOn == "tap" ? ej.tapEvent() : this.model.showOn == "taphold" ? ej.tapHoldEvent() : this.model.showOn;
                this._bindEvent();
            }
        },
        //To change the Theme property
        _setTheme: function (value) {
            if (value) {
                this.model.theme = value;
                this.element.removeClass("e-m-dark e-m-light e-m-default").addClass("e-m-" + this.model.theme);
                if (this.model.renderMode == "ios7") {
                    if ($(this.element.find(".e-m-btnwrapper")).length > 0) {
                        var button = $(this.element.find("a.e-m-btn"));
                        var proxy = this;
                        button.each(function (index, element) {
                            $(element).ejmActionlink('model.theme', proxy.model.theme);
                        });
                    }
                }
                else if (this.model.renderMode == "android" && this.overFlowMenu)
                    this.overFlowMenu.removeClass("e-m-dark e-m-light e-m-default").addClass("e-m-" + this.model.theme);
            }
        },
        _enableDisable: function (index, val) {
            if (index)
                $(this.element.find('li.e-m-menuitem')[index - 1])[val ? "removeClass" : "addClass"]('e-m-state-disabled');
        },
        _enableDisableOverFlow: function (index, val) {
            if (this.overFlowMenu && index)
                $(this.overFlowMenu.find('li.e-m-menuitem')[index - 1])[val ? "removeClass" : "addClass"]('e-m-state-disabled');
        },
        _enabledisable: function (val) {
            this.element[val ? "removeClass" : "addClass"]('e-m-state-disabled');
        },
        _enabledisableOverflow: function (val) {
            if (this.overFlowMenu)
                this.overFlowMenu[val ? "removeClass" : "addClass"]('e-m-state-disabled');
        },
        //To refresh the control
        _refresh: function () {
            this._destroy();
            this.element.addClass("e-m-menu");
            this._renderControl();
            this._wireEvents();
        },
        //To clear the element
        _clearElement: function () {
            this.element.removeAttr("class").removeAttr("style");
            if (this.overFlowMenu)
                this.overFlowMenu.remove();
            if (this._overlay)
                this._overlay.remove();
            this.element.html(this._orgEle.html());
        },
        // all events bound using this._on will be unbind automatically
        _destroy: function () {
            this._wireEvents(true);
            this._clearElement();
        },

        /*---------------Public Methods---------------*/
        /**
        * To show the menu.
        * @return jQuery
        * @example     
        * // Create menu control        
        * &lt;div&gt;
        *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu"/&gt;
        * &lt;/div&gt; <br/>
        * &lt;div id="menu" data-ej-targetid="menuitem"&gt;
        *   &lt;ul&gt; 
        *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
        *   &lt;/ul&gt;
        * &lt;/div&gt;
        *
        * &lt;script&gt;
        * var menuObj = $("#menu").data("ejmMenu");
        * menuObj.show(); // Show/Open the menu which is in hide state.
        * &lt;/script&gt;
        * @example             
        * &lt;div&gt;
        *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu"/&gt;
        * &lt;/div&gt; <br/>        
        * &lt;div id="menu" data-role="ejmmenu" data-ej-targetid="menuitem"&gt;
        *   &lt;ul&gt; 
        *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
        *   &lt;/ul&gt;
        * &lt;/div&gt;
        *
        * &lt;script&gt;
        * // Show/Open the menu which is in hide state.
        * $("#menu").ejmMenu("show");	
        * &lt;/script&gt;
        *@memberof ejmMenu
        * @instance
        */
        //To show the menu
        show: function (e, existing) {
            this._updateWindowHW();
            if (this.model.renderMode == "windows" && this.model.windows.type == "contextual" && !ej.isMobile() && this._shown)
                this.hide();
            if ((this._isPopUp() || (this.model.renderMode == "windows" && ej.isMobile())) && !existing)
                this._tar = $(e.currentTarget);
            this._tarOffsetTop = this._tar ? this._tar.offset().top - this._activePage.offset().top : 0;
            this._tarOffsetLeft = this._tar ? this._tar.offset().left - this._activePage.offset().left : 0;
            this._e = e ? e : this._e ? this._e : this._evt;
            if (this._e) {
                this._pageLeft = this._e.pageX - this._activePage.offset().left;
                this._pageTop = this._e.pageY - this._activePage.offset().top;
            }
            if (!this._shown) {
                if (ej.isIOS() && this.model.ios7.type == "animate")
                    this.element.css('visibility', 'visible');
                this._resetPosition();
                if (this.model.renderMode == "windows" && this.model.windows.type == "contextual") {
                    if (ej.isMobile()) {
                        this._mcontainer.removeClass("e-m-tn-nonecontainer").addClass("e-m-tn-container");
                        if (ej.isPortrait()) {
                            this._positionMenu(this._tar);
                            this._mcontainer.height(5);
                            this._mcontainer.width(this.model.width ? this.model.width : "100%");
                            this._mcontainer.bind(ej.transitionEndEvent(), this._poranimationEndDelegate);
                        }
                        else {
                            var val = this._e.pageX < this._windowWidth / 2;
                            this.element.removeClass(val ? "e-m-right" : "e-m-left").addClass(val ? "e-m-left e-m-landscape" : "e-m-right e-m-landscape");
                            this._mcontainer.width(5);
                            this.element.css("top", 0);
                            this._mcontainer.height(this.model.height ? this.model.height : this._windowHeight);
                            this._mcontainer.bind(ej.transitionEndEvent(), this._landanimationEndDelegate);
                        }
                    }
                    else {
                        this._scrollPanel();
                        var val = this._pageTop + this._targetHeight < this._windowHeight;
                        this.element.css(val ? { "top": this._pageTop} : { "bottom": this._windowHeight - this._pageTop });
                        val = this._pageLeft + this.element.outerWidth() < this._windowWidth;
                        this.element.css(val ? { "left": this._pageLeft} : { "right": this._windowWidth - this._pageLeft });
                        this.element.css({ "display": "block" });
                        this._scrollRefresh();
                    }
                }
                else {
                    this._scrollPanel();
                    this.model.renderMode == "flat" ? this._setPosition(this._tar) : this._positionMenu(this._tar);
                    if (this.model.renderMode == "android" && this.model.android.type == "optionslist")
                        this.element.css(!ej.isPortrait() ? { 'right': '10px', 'left': 'auto'} : { 'right': 'auto' });
                    if ((this.model.renderMode == "ios7" && this.model.ios7.type == "animate") || (this.model.renderMode == "android" && (this.model.android.type == "optionslist" || this.model.android.type == "optionsmenu"))) {
                        if (this.overFlowMenu)
                            this.overFlowMenu.css({ "display": "none" });
                        this.element.css({ "bottom": 0 });
                    }
                    else if (this.model.renderMode == "ios7" && !ej.isMobile())
                        this.element.show().css({ "opacity": "1" });
                    else
                        this.element.css({ "display": "block" });
                    if (this._overlay)
                        this._overlay.removeClass(this.model.renderMode == "ios7" && !ej.isMobile() ? "e-m-overlay-hide" : "e-m-state-hide").css("pointer-events", "auto");
                    this._scrollRefresh();
                }
            }
            if (this.model.renderMode == "ios7" && !ej.isMobile())
                this.element.addClass("e-m-menu-showtrans").removeClass("e-m-menu-hidetrans");
            this._shown = true;
            if (this.model.show)
                this._trigger("show");
        },

        /**
        * To hide the menu.
        * @return jQuery
        * @example      
        * // Create menu control       
        * &lt;div&gt;
        *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu"/&gt;
        * &lt;/div&gt; <br/>
        * &lt;div id="menu" data-ej-targetid="menuitem"&gt;
        *   &lt;ul&gt; 
        *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
        *   &lt;/ul&gt;
        * &lt;/div&gt;
        *
        * &lt;script&gt;
        * var menuObj = $("#menu").data("ejmMenu");
        * menuObj.hide(); // hide the menu which is already opened
        * &lt;/script&gt;
        * @example             
        * &lt;div&gt;
        *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu"/&gt;
        * &lt;/div&gt; <br/>        
        * &lt;div id="menu" data-role="ejmmenu" data-ej-targetid="menuitem"&gt;
        *   &lt;ul&gt; 
        *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
        *   &lt;/ul&gt;
        * &lt;/div&gt;
        *
        * &lt;script&gt;
        * // Hide the menu which is already opened
        * $("#menu").ejmMenu("hide");	
        * &lt;/script&gt;
        *@memberof ejmMenu
        * @instance
        */
        //To hide the menu
        hide: function () {
            if (this._shown) {
                if (this.model.renderMode == "ios7" && !ej.isMobile())
                    this.element.removeClass("e-m-menu-showtrans").addClass("e-m-menu-hidetrans");
                this._shown = false;
                this.element.find('.e-m-menuitem.e-m-state-active').removeClass("e-m-state-active").addClass("e-m-state-default");
                if ((this.model.renderMode == "ios7" && this.model.ios7.type == "animate") || (this.model.renderMode == "android" && (this.model.android.type == "optionslist" || this.model.android.type == "optionsmenu"))) {
                    this.element.css({ "bottom": -ej.getDimension(this.element, "outerHeight") + "px" });
                    if (this.overFlowMenu)
                        this.overFlowMenu.css({ "display": "none" });
                }
                else if (this.model.renderMode == "windows" && this.model.windows.type == "contextual") {
                    if (ej.isMobile()) {
                        this._mcontainer.addClass("e-m-tn-nonecontainer");
                        this._mcontainer.css({ "width": "0", "height": "0" });
                    }
                    else
                        this.element.css({ "left": "auto", "top": "auto", "display": "none" });
                }
                else if (this.model.renderMode == "ios7" && !ej.isMobile())
                    this.element.css({ "opacity": "0" }).bind(ej.transitionEndEvent(), this._displayMenuDelegate);
                else
                    this.element.css("display", "none");
                if (this._overlay)
                    this._overlay.addClass(this.model.renderMode == "ios7" && !ej.isMobile() ? "e-m-overlay-hide" : "e-m-state-hide");
                if (this.model.hide)
                    this._trigger("hide");
            }
        },
        /**
        * To enable item in the given index.
        * @return jQuery
        * @example             
        * &lt;div&gt;
        *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu"/&gt;
        * &lt;/div&gt; <br/>
        * // Create menu control
        * &lt;div id="menu" data-ej-targetid="menuitem"&gt;
        *   &lt;ul&gt; 
        *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
        *   &lt;/ul&gt;
        * &lt;/div&gt;
        *
        * &lt;script&gt;
        * var menuObj = $("#menu").data("ejmMenu");
        * menuObj.enableItem(1); // enable the given index menu item
        * &lt;/script&gt;
        * @example             
        * &lt;div&gt;
        *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu"/&gt;
        * &lt;/div&gt; <br/>    
        * // Create menu control    
        * &lt;div id="menu" data-role="ejmmenu" data-ej-targetid="menuitem"&gt;
        *   &lt;ul&gt; 
        *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
        *   &lt;/ul&gt;
        * &lt;/div&gt;
        *
        * &lt;script&gt;
        * // Enable the given index menu item
        * $("#menu").ejmMenu("enableItem", "1");	
        * &lt;/script&gt;
        *@memberof ejmMenu
        * @instance
        */
        //To enable the Menu item
        enableItem: function (index) {
            this._enableDisable(index, true);
        },

        /**
        * To disable the item in the given index.
        * @return jQuery
        * @example             
        * &lt;div&gt;
        *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu"/&gt;
        * &lt;/div&gt; <br/>
        * // Create menu control
        * &lt;div id="menu" data-ej-targetid="menuitem"&gt;
        *   &lt;ul&gt; 
        *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
        *   &lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * $(function () {
        * 	var menuObj = $("#menu").data("ejmMenu");
        * 	menuObj.disableItem(1); // disable the given index menu item
        * });
        * &lt;/script&gt;
        * @example             
        * &lt;div&gt;
        *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu"/&gt;
        * &lt;/div&gt; <br/>    
        * // Create menu control    
        * &lt;div id="menu" data-role="ejmmenu" data-ej-targetid="menuitem"&gt;
        *   &lt;ul&gt; 
        *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
        *   &lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Disable the given index menu item
        * $(function (){
        * 	$("#menu").ejmMenu("disableItem", "1");	
        * });
        * &lt;/script&gt;
        *@memberof ejmMenu
        * @instance
        */
        //To disable the Menu item
        disableItem: function (index) {
            this._enableDisable(index, false);
        },
        /**
        * To enable overflow item in the given index.
        * @return jQuery
        * @example             
        * &lt;div&gt;
        *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu"/&gt;
        * &lt;/div&gt; <br/>
        * // Create menu control
        * &lt;div id="menu" data-ej-targetid="menuitem"&gt;
        *   &lt;ul&gt; 
        *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
        *   &lt;/ul&gt;
        * &lt;/div&gt;
        *
        * &lt;script&gt;
        * var menuObj = $("#menu").data("ejmMenu");
        * menuObj.enableOverflowItem(1); // enable the overflow menu item.
        * &lt;/script&gt;
        * @example             
        * &lt;div&gt;
        *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu"/&gt;
        * &lt;/div&gt; <br/>        
        * // Create menu control
        * &lt;div id="menu" data-role="ejmmenu" data-ej-targetid="menuitem"&gt;
        *   &lt;ul&gt; 
        *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
        *   &lt;/ul&gt;
        * &lt;/div&gt;
        *
        * &lt;script&gt;
        * // Enable the given index menu item
        * $("#menu").ejmMenu("enableOverflowItem", "1");	
        * &lt;/script&gt;
        *@memberof ejmMenu
        * @instance
        */
        //To enable the Overflow Menu item
        enableOverFlowItem: function (index) {
            this._enableDisableOverFlow(index, true);
        },

        /**
        * To disable overflow item in the given index.
        * @return jQuery
        * @example             
        * &lt;div&gt;
        *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu"/&gt;
        * &lt;/div&gt; <br/>
        * // Create menu control
        * &lt;div id="menu" data-ej-targetid="menuitem"&gt;
        *   &lt;ul&gt; 
        *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
        *   &lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * $(function (){
        * 	var menuObj = $("#menu").data("ejmMenu");
        * 	menuObj.disableOverflowItem(1); // disable the given index menu item in overflow menu
        * });
        * &lt;/script&gt;
        * @example             
        * &lt;div&gt;
        *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu"/&gt;
        * &lt;/div&gt; <br/>    
        * // Create menu control    
        * &lt;div id="menu" data-role="ejmmenu" data-ej-targetid="menuitem"&gt;
        *   &lt;ul&gt; 
        *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
        *   &lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Disable the given index menu item
        * $(function (){
        * 	$("#menu").ejmMenu("disableOverflowItem", "1");	
        * });
        * &lt;/script&gt;
        *@memberof ejmMenu
        * @instance
        */
        //To disable the Menu item
        disableOverFlowItem: function (index) {
            this._enableDisableOverFlow(index, false);
        },

        /**
        * To enable the menu.
        * @return jQuery
        * @example             
        * &lt;div&gt;
        *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu"/&gt;
        * &lt;/div&gt; <br/>
        * // Create menu control
        * &lt;div id="menu" data-ej-targetid="menuitem"&gt;
        *   &lt;ul&gt; 
        *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
        *   &lt;/ul&gt;
        * &lt;/div&gt;
        *
        * &lt;script&gt;
        * var menuObj = $("#menu").data("ejmMenu");
        * menuObj.enable(); // enable the menu control
        * &lt;/script&gt;
        * @example             
        * &lt;div&gt;
        *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu"/&gt;
        * &lt;/div&gt; <br/>        
        * // Create menu control
        * &lt;div id="menu" data-role="ejmmenu" data-ej-targetid="menuitem"&gt;
        *   &lt;ul&gt; 
        *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
        *   &lt;/ul&gt;
        * &lt;/div&gt;
        *
        * &lt;script&gt;
        * // Enable the menu control
        * $("#menu").ejmMenu("enable");	
        * &lt;/script&gt;
        *@memberof ejmMenu
        * @instance
        */
        //To enable the Menu 
        enable: function () {
            this._enabledisable(true);
        },

        /**
        * To disable the menu.
        * @return jQuery
        * @example             
        * &lt;div&gt;
        *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu"/&gt;
        * &lt;/div&gt; <br/>
        * // Create menu control
        * &lt;div id="menu" data-ej-targetid="menuitem"&gt;
        *   &lt;ul&gt; 
        *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
        *   &lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * $(function (){
        * 	var menuObj = $("#menu").data("ejmMenu");
        * 	menuObj.disable(); // disable the menu control
        * });
        * &lt;/script&gt;
        * @example             
        * &lt;div&gt;
        *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu"/&gt;
        * &lt;/div&gt; <br/>        
        * // Create menu control
        * &lt;div id="menu" data-role="ejmmenu" data-ej-targetid="menuitem"&gt;
        *   &lt;ul&gt; 
        *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
        *   &lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Disable the menu control
        * $(function (){
        * 	$("#menu").ejmMenu("disable");	
        * });
        * &lt;/script&gt;
        *@memberof ejmMenu
        * @instance
        */
        //To disable the Menu 
        disable: function () {
            this._enabledisable(false);
        },

        /**
        * To enable the overflow menu.
        * @return jQuery
        * @example             
        * &lt;div&gt;
        *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu"/&gt;
        * &lt;/div&gt; <br/>
        * // Create menu control
        * &lt;div id="menu" data-ej-targetid="menuitem"&gt;
        *   &lt;ul&gt; 
        *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
        *   &lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * $(function (){
        * 	var menuObj = $("#menu").data("ejmMenu");
        * 	menuObj.enableOverflow(); // enable the overflow menu
        * });
        * &lt;/script&gt;
        * @example             
        * &lt;div&gt;
        *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu"/&gt;
        * &lt;/div&gt; <br/>    
        * // Create menu control    
        * &lt;div id="menu" data-role="ejmmenu" data-ej-targetid="menuitem"&gt;
        *   &lt;ul&gt; 
        *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
        *   &lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Enable the overflow menu control
        * $(function (){
        * 	$("#menu").ejmMenu("enableOverflow");	
        * });
        * &lt;/script&gt;
        *@memberof ejmMenu
        * @instance
        */
        //To enable the Overflow Menu 
        enableOverFlow: function () {
            this._enabledisableOverflow(true);
        },

        /**
        * To disable the overflow menu.
        * @return jQuery
        * @example             
        * &lt;div&gt;
        *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu"/&gt;
        * &lt;/div&gt; <br/>
        * // Create menu control
        * &lt;div id="menu" data-ej-targetid="menuitem"&gt;
        *   &lt;ul&gt; 
        *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
        *   &lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * $(function (){
        * 	var menuObj = $("#menu").data("ejmMenu");
        * 	menuObj.disableOverflow(); // disableOverFlow menu item.
        * });
        * &lt;/script&gt;
        * @example             
        * &lt;div&gt;
        *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu"/&gt;
        * &lt;/div&gt; <br/>    
        * // Create menu control    
        * &lt;div id="menu" data-role="ejmmenu" data-ej-targetid="menuitem"&gt;
        *   &lt;ul&gt; 
        *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt
        *   &lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Disable the overflow menu control
        * $(function (){
        * 	$("#menu").ejmMenu("disableOverflow");	
        * });
        * &lt;/script&gt;
        *@memberof ejmMenu
        * @instance
        */
        //To disable the Menu 
        disableOverFlow: function () {
            this._enabledisableOverflow(false);
        },
        /**
        * To add item in the given index.
        * @return jQuery
        * @example             
        * &lt;div&gt;
        *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu" /&gt;
        * &lt;/div&gt; <br/>
        * // Create menu control
        * &lt;div id="menu" data-role="ejmmenu" data-ej-targetid="menuitem"&gt;
        *   &lt;ul&gt; 
        *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
        *   &lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * $(function (){
        * 	var menuObj = $("#menu").data("ejmMenu");
        * 	var element = ej.buildTag('li');
        * 	menuObj.addItem(element,3); // Add the given index menu item
        * });
        * &lt;/script&gt;
        * @example             
        * &lt;div&gt;
        *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu"/&gt;
        * &lt;/div&gt; <br/>        
        * // Create menu control
        * &lt;div id="menu" data-role="ejmmenu" data-ej-targetid="menuitem"&gt;
        *   &lt;ul&gt; 
        *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
        *   &lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * $(function(){
        * 	// Add the given index menu item
        * 	var element = ej.buildTag('li');
        * 	$("#menu").ejmMenu("addItem", element,3);	
        * });
        * &lt;/script&gt;
        *@memberof ejmMenu
        * @instance
        */
        //To add item in menu
        addItem: function (menu, index) {
            if (index)
                menu.insertBefore($(this._orgEle.children().children()[index - 1]));
            else
                this._orgEle.children().append(menu);
            this._refresh();
        },

        /**
        * To remove item in the given index.
        * @return jQuery
        * @example             
        * &lt;div&gt;
        *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu"/&gt;
        * &lt;/div&gt; <br/>
        * // Create menu control
        * &lt;div id="menu" data-ej-targetid="menuitem"&gt;
        *   &lt;ul&gt; 
        *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
        *   &lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * $(function (){
        * 	var menuObj = $("#menu").data("ejmMenu");
        * 	menuObj.removeItem(1); // remove the given index menu item
        * }):
        * &lt;/script&gt;
        * @example             
        * &lt;div&gt;
        *    &lt;input id="menuitem" type="button" data-role="ejmbutton" data-ej-text="Menu"/&gt;
        * &lt;/div&gt; <br/>        
        * // Create menu control
        * &lt;div id="menu" data-role="ejmmenu" data-ej-targetid="menuitem"&gt;
        *   &lt;ul&gt; 
        *      &lt;li data-ej-text="Get info"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Show in folder"&gt;&lt;/li&gt;
        *      &lt;li data-ej-text="Delete"&gt;&lt;/li&gt;
        *   &lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Remove the given index menu item
        * $(function (){
        * 	$("#menu").ejmMenu("removeItem", "1");	
        * });
        * &lt;/script&gt;
        *@memberof ejmMenu
        * @instance
        */
        //To remove item in menu
        removeItem: function (index) {
            if (index) {
                $(this._orgEle.children().children()[index - 1]).remove();
                this._refresh();
            }
        }
        /*---------------Public Methods End---------------*/

    });
    ej.mobile.Menu.IOS7 = {}
    /**
    * Enum for ej.mobile.Menu.IOS7.Type
    * @enum {string}
    * @global
    */
    ej.mobile.Menu.IOS7.Type = {

        /**
        Enum for auto type menu in ios7 mode*/
        Auto: "auto",
        /**
        Enum for animate type menu in ios7 mode*/
        Animate: "animate",
        /**
        Enum for normal type menu in ios7 mode*/
        Normal: "normal"
    }
    /**
    * Enum for ej.mobile.Menu.IOS7.CancelButtonColor
    * @enum {string}
    * @global
    */
    ej.mobile.Menu.IOS7.CancelButtonColor =
    {
        /**
        Enum for blue color button in ios7 mode*/
        Blue: "blue",
        /**
        Enum for gray color button in ios7 mode*/
        Gray: "gray",
        /**
        Enum for black color button in ios7 mode*/
        Black: "black",
        /**
        Enum for green color button in ios7 mode*/
        Green: "green",
        /**
        Enum for red color button in ios7 mode*/
        Red: "red"
    }
    /**
    * Enum for ej.mobile.Menu.IOS7.ButtonStyle
    * @enum {string}
    * @global
    */
    ej.mobile.Menu.IOS7.ButtonStyle = {
        /**
        Enum for normal ios7 button style*/
        Normal: "normal",
        /**
        Enum for back ios7 button style*/
        Back: "back",
        /**
        Enum for header ios7 button style*/
        Header: "header",
        /**
        Enum for dialog ios7 button style*/
        Dialog: "dialog"
    };
    ej.mobile.Menu.Android = {}
    /**
    * Enum for ej.mobile.Menu.Android.Type
    * @enum {string}
    * @global
    */
    ej.mobile.Menu.Android.Type =
        {
            /**
            Enum for contextual type menu in android mode*/
            Contextual: "contextual",
            /**
            Enum for popup type menu in android mode*/
            Popup: "popup",
            /**
            Enum for optionslist type menu in android mode*/
            OptionsList: "optionslist",
            /**
            Enum for optionsmenu type menu in android mode*/
            OptionsMenu: "optionsmenu"
        }
    ej.mobile.Menu.Windows = {}
    /**
    * Enum for ej.mobile.Menu.Windows.Type
    * @enum {string}
    * @global
    */
    ej.mobile.Menu.Windows.Type =
        {
            /**
            Enum for contextual type menu in windows mode*/
            Contextual: "contextual",
            /**
            Enum for popup type menu in windows mode*/
            Popup: "popup"
        }

    /**
    * Enum for Menu ShowOn
    * @enum {string}
    * @global
    */
    ej.mobile.Menu.ShowOn = {
        /**
        Enum for show menu on tap */
        Tap: "Tap",
        /**
        Enum for show menu on tap hold*/
        TapHold: "TapHold"
    }
})(jQuery, Syncfusion);