/**
* @fileOverview Plugin to style the Html AutoComplete elements
* @copyright Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/


(function ($, ej, undefined) {
    //mNavigationDrawer is the plugin name 
    //"m.NavigationDrawer" is "namespace.className" will hold functions and properties
    /**
    * @namespace ej
    * @class ejmNavigationDrawer
    * @requires jQuery
    * @requires ej.mobile.application
    * @requires ej.core
    * @requires ej.unobtrusive
    * @requires ej.mobile.core
    * @requires ej.data
    * @requires ej.touch
    * @requires ej.mobile.listview
    * @requires ej.mobile.scrollpanel
    * @requires ej.mobile.menu
    * @requires ej.navigationdrawerbase
    * @classdesc Custom Design for Html Navigation Drawer control.
    * @example 
    * //create Navigation Drawer in Unobtrusive way
    * &lt;div id="home" class="navsubpage"&gt;
    * &lt;div align="center" class="content"&gt;
    * &lt;h2 class="title"&gt;
    * Home&lt;/h2&gt;
    * &lt;p&gt;
    * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
    * &lt;/p&gt;
    * &lt;/div&gt;
    * &lt;/div&gt;
    * &lt;style&gt;
    * .list {
    *   border-bottom: 1px solid;
    *   line-height: 50px;
    *   text-align: center;
    *   width:200px;
    *   }
    * &lt;/style&gt;
    * &lt;div data-role="ejmnavigationdrawer" id="navpane" data-ej-type="overlay" data-ej-position="fixed"&gt;
    * &lt;div class="list"&gt; Home &lt;/div&gt;
    * &lt;div class="list"&gt; Communities &lt;/div&gt;
    * &lt;/div&gt;
    * @example 
    * //create Navigation Drawer in Obtrusive way
    * &lt;div id="home" class="navsubpage"&gt;
    * &lt;div align="center" class="content"&gt;
    * &lt;h2 class="title"&gt;
    * Home&lt;/h2&gt;
    * &lt;p&gt;
    * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
    * &lt;/p&gt;
    * &lt;/div&gt;
    * &lt;/div&gt;
    * &lt;style&gt;
    * .list {
    *   border-bottom: 1px solid;
    *   line-height: 50px;
    *   text-align: center;
    *   width:200px;
    *   }
    * &lt;/style&gt;
    * &lt;div &gt;
    * &lt;div class="list"&gt; Home &lt;/div&gt;
    * &lt;div class="list"&gt; Communities &lt;/div&gt;
    * &lt;/div&gt;
    * &lt;script&gt;
    * $(function () {
    * $("#navpane").ejmNavigationDrawer();	
    * });
    * &lt;/script&gt;
    **/
    ej.widget("ejmNavigationDrawer", "ej.mobile.NavigationDrawer", {

        _setFirst: true,
        _rootCSS: "e-m-nb",
        _prefixClass: "e-m-",
        // Default model values
        defaults: {
            /**		
            * Changes the rendering mode. See {@link RenderMode}
            * @default auto
            * @type {enum}
            * @example 
            * //Set the renderMode property in unobtrusive way.
            * &lt;div id="home" class="navsubpage"&gt;
            * &lt;div align="center" class="content"&gt;
            * &lt;h2 class="title"&gt;
            * Home&lt;/h2&gt;
            * &lt;p&gt;
            * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
            * &lt;/p&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;style&gt;
            * .list {
            *   border-bottom: 1px solid;
            *   line-height: 50px;
            *   text-align: center;
            *   width:200px;
            *   }
            * &lt;/style&gt;
            * &lt;div data-role="ejmnavigationdrawer" id="navpane" data-ej-rendermode="auto"&gt;
            * &lt;div class="list"&gt; Home &lt;/div&gt;
            * &lt;div class="list"&gt; Communities &lt;/div&gt;
            * &lt;/div&gt;
            * @example 
            * // Set Navigation Drawer renderMode on initialization. 
            * //To set renderMode API value 
            * &lt;div id="home" class="navsubpage"&gt;
            * &lt;div align="center" class="content"&gt;
            * &lt;h2 class="title"&gt;
            * Home&lt;/h2&gt;
            * &lt;p&gt;
            * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
            * &lt;/p&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;style&gt;
            * .list {
            *   border-bottom: 1px solid;
            *   line-height: 50px;
            *   text-align: center;
            *   width:200px;
            *   }
            * &lt;/style&gt;
            * &lt;div id="navpane"&gt;
            * &lt;div class="list"&gt; Home &lt;/div&gt;
            * &lt;div class="list"&gt; Communities &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function () {
            * $("#navpane").ejmNavigationDrawer("renderMode","auto");	
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the Navigation Drawer renderMode, after initialization:
            * &lt;script&gt;
            * // Gets the renderMode API value.		
            *  $("#navpane").ejmNavigationDrawer ("option", "renderMode");			
            * // Sets the renderMode API
            * $("#navpane").ejmNavigationDrawer ("option", "renderMode", ej.mobile.RenderMode.Auto);   
            * &lt;/script&gt;
            * @memberof ejmNavigationDrawer
            * @instance
            */
            renderMode: "auto",
            /**		
            * Changes the Theme of the control
            * @default auto
            * @type {enum}
            * @example 
            * //Set the Theme property in unobtrusive way.
            * &lt;div id="home" class="navsubpage"&gt;
            * &lt;div align="center" class="content"&gt;
            * &lt;h2 class="title"&gt;
            * Home&lt;/h2&gt;
            * &lt;p&gt;
            * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
            * &lt;/p&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;style&gt;
            * .list {
            *   border-bottom: 1px solid;
            *   line-height: 50px;
            *   text-align: center;
            *   width:200px;
            *   }
            * &lt;/style&gt;
            * &lt;div data-role="ejmnavigationdrawer" id="navpane" data-ej-theme="auto"&gt;
            * &lt;div class="list"&gt; Home &lt;/div&gt;
            * &lt;div class="list"&gt; Communities &lt;/div&gt;
            * &lt;/div&gt;
            * @example 
            * // Set Navigation Drawer renderMode on initialization. 
            * //To set Theme API value 
            * &lt;div id="home" class="navsubpage"&gt;
            * &lt;div align="center" class="content"&gt;
            * &lt;h2 class="title"&gt;
            * Home&lt;/h2&gt;
            * &lt;p&gt;
            * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
            * &lt;/p&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;style&gt;
            * .list {
            *   border-bottom: 1px solid;
            *   line-height: 50px;
            *   text-align: center;
            *   width:200px;
            *   }
            * &lt;/style&gt;
            * &lt;div id="navpane"&gt;
            * &lt;div class="list"&gt; Home &lt;/div&gt;
            * &lt;div class="list"&gt; Communities &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function () {
            * $("#navpane").ejmNavigationDrawer("theme","auto");	
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the Navigation Drawer Theme, after initialization:
            * &lt;script&gt;
            * // Gets the Theme API value.		
            *  $("#navpane").ejmNavigationDrawer ("option", "theme");			
            * // Sets the Theme API
            * $("#navpane").ejmNavigationDrawer ("option", "theme", ej.mobile.Theme.Auto);   
            * &lt;/script&gt;
            * @memberof ejmNavigationDrawer
            * @instance
            */
            theme: "auto",
            /**		
            * While set as true, enables scrollpanel inside the element.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the allowscrolling property in unobtrusive way.
            * &lt;div id="home" class="navsubpage"&gt;
            * &lt;div align="center" class="content"&gt;
            * &lt;h2 class="title"&gt;
            * Home&lt;/h2&gt;
            * &lt;p&gt;
            * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
            * &lt;/p&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;style&gt;
            * .list {
            *   border-bottom: 1px solid;
            *   line-height: 50px;
            *   text-align: center;
            *   width:200px;
            *   }
            * &lt;/style&gt;
            * &lt;div data-role="ejmnavigationdrawer" id="navpane" data-ej-allowscrolling="true"&gt;
            * &lt;div class="list"&gt; Home &lt;/div&gt;
            * &lt;div class="list"&gt; Communities &lt;/div&gt;
            * &lt;/div&gt;
            * @example 
            * // Set Navigation Drawer Scrolling on initialization. 
            * //To set scrolling API value 
            * &lt;div id="home" class="navsubpage"&gt;
            * &lt;div align="center" class="content"&gt;
            * &lt;h2 class="title"&gt;
            * Home&lt;/h2&gt;
            * &lt;p&gt;
            * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
            * &lt;/p&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;style&gt;
            * .list {
            *   border-bottom: 1px solid;
            *   line-height: 50px;
            *   text-align: center;
            *   width:200px;
            *   }
            * &lt;/style&gt;
            * &lt;div id="navpane"&gt;
            * &lt;div class="list"&gt; Home &lt;/div&gt;
            * &lt;div class="list"&gt; Communities &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function () {
            * $("#navpane").ejmNavigationDrawer("allowScrolling","true");	
            * });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set the Navigation Drawer allowscrolling, after initialization:
            * $(function () {
            * // Gets the allowscrolling API value.		
            * $("#navpane").ejmNavigationDrawer("option", "allowScrolling");	
            * // Sets the allowscrolling API	
            * $("#navpane").ejmNavigationDrawer ("option", "allowScrolling", false);  
            * });
            * &lt;/script&gt;  
            * @memberof ejmNavigationDrawer
            * @instance
            */
            allowScrolling: false,
            /**     
            * Used to set scrollpanel related properties to the navigation drawer                      
            * @memberof ejmNavigationDrawer
            * @instance
            */
            scrollSettings: {},
            /**		
            * When set as true, the control will render inside the closest subpage. 
            * @default false
            * @type {boolean}
            * @example 
            * //Set the allowscrolling property in unobtrusive way.
            * //Set the allowscrolling property in unobtrusive way.
            * &lt;div id="home" class="navsubpage"&gt;
            * &lt;div align="center" class="content"&gt;
            * &lt;h2 class="title"&gt;
            * Home&lt;/h2&gt;
            * &lt;p&gt;
            * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
            * &lt;/p&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;style&gt;
            * .list {
            *   border-bottom: 1px solid;
            *   line-height: 50px;
            *   text-align: center;
            *   width:200px;
            *   }
            * &lt;/style&gt;
            * &lt;div data-role="ejmnavigationdrawer" id="navpane" data-ej-considersubpage="true"&gt;
            * &lt;div class="list"&gt; Home &lt;/div&gt;
            * &lt;div class="list"&gt; Communities &lt;/div&gt;
            * &lt;/div&gt;
            * @example
            * // Set Navigation Drawer considersubpage on initialization. 
            * //To set scrolling API value 
            * &lt;div id="home" class="navsubpage"&gt;
            * &lt;div align="center" class="content"&gt;
            * &lt;h2 class="title"&gt;
            * Home&lt;/h2&gt;
            * &lt;p&gt;
            * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
            * &lt;/p&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;style&gt;
            * .list {
            *   border-bottom: 1px solid;
            *   line-height: 50px;
            *   text-align: center;
            *   width:200px;
            *   }
            * &lt;/style&gt;
            * &lt;div id="navpane"&gt;
            * &lt;div class="list"&gt; Home &lt;/div&gt;
            * &lt;div class="list"&gt; Communities &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function () {
            * $("#navpane").ejmNavigationDrawer("considerSubPage","true");	
            * });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set the Navigation Drawer allowscrolling, after initialization:
            * $(function () {
            * // Gets the Considersubpage API value.		
            * $("#navpane").ejmNavigationDrawer("option", "considerSubPage");	
            * // Sets the Considersubpage API	
            * $("#navpane").ejmNavigationDrawer ("option", "considerSubPage", false);  
            * });
            * &lt;/script&gt;  
            * @memberof ejmNavigationDrawer
            * @instance
            */
            considerSubPage: true
        },
        //datatype of model variables
        dataTypes: {
            renderMode: "enum",
            theme: "enum"
        },
        /**
        * Constructor function	
        * @private
        */
        _init: function () {
            this._load();
            this._renderControl();
            this._renderEJMControls();
            this._createDelegate();
            this._wireEvents();
        },
        /**
        * To configure the hide property for Navigation drawer control
        * @private
        */
        _load: function () {
            ej.setRenderMode(this);
            ej.setTheme(this);
            this._browser = ej.browser();
            this._setRenderMode();
            if (this.model.position == "normal" && this.model.type == "slide")
                this.model.type = "overlay";
            if (this.model.position == "normal") {
                this._elementWrapper = ej.buildTag("div#" + this._id + "_WrapContainer", {}, {}, { class: this._rootCSS + " e-m-nb-container" });
                this.element.wrapAll(this._elementWrapper);
                this._nbHome = $("#" + this._id + "_WrapContainer").parent();
            }
            else {
                this._nbHome = this.model.considerSubPage && this.element.closest('.subpage').length ? this.element.closest('.subpage') : this.element.closest('.appview');
                this.element.appendTo(this._nbHome);
            }
        },

        _renderEJMControls: function () {
            if (this.model.enableListView) {
                this._lb = ej.buildTag("div#" + this._id + "_listview", {}, {}, { class: "e-m-nb-listview" });
                this.element.find(">ul").wrapAll(this._lb);
                this._lb = ej.getCurrentPage().find($("#" + this._id + "_listview"));
                this.model.listViewSettings["renderMode"] = this.model.renderMode;
                this.model.listViewSettings["theme"] = this.model.theme;
                if (!this.model.listViewSettings["width"])
                    this.model.listViewSettings["width"] = ej.isMobile() ? 280 : 320;
                this._lb.ejmListView(this.model.listViewSettings);
                this._lb.ejmListView({ loadComplete: $.proxy(this._setLayout, this) });
                this._lbscrollbar = $("#" + this._id + "_listview_scroll");
            }
            else {
                if (this.model.allowScrolling) {
                    this._scrollbar = ej.buildTag("div#" + this._id + "_scrollpane", {}, {}, { class: "e-m-nb-scrollpane" });
                    this._scrollWrap = ej.buildTag("div#" + this._id + "_scrollwrap", {}, {}, { class: "e-m-nb-scrollwrap" });
                    $(this.element).wrapInner(this._scrollWrap);
                    $("#" + this._id + "_scrollwrap").wrapInner("<div></div>");
                    this.element.append(this._scrollbar);
                    this._scrollbar = ej.getCurrentPage().find($("#" + this._id + "_scrollpane"));
                    this.model.scrollSettings["target"] = this._id + "_scrollwrap";
                    this.model.scrollSettings["renderMode"] = this.model.rederMode;
                    this.model.scrollSettings["theme"] = this.model.theme;
                    this._scrollbar.ejmScrollPanel(this.model.scrollSettings);
                }
            }
        },
        /**
        * To set model values to the Navigation Drawer control 
        * @private
        */
        _setModel: function (options) {
            var refresh = false;
            for (var prop in options) {
                switch (prop) {
                    case "width":
                        this._setWidth();
                        this._setLayout();
                        break;
                    case "direction":
                        this._setLayout();
                        break;
                    case "type":
                        this._transform(0, 0, true);
                        this._transform(0, 0, false);
                        break;
                    case "rendermode":
                    case "theme":
                        this._setRenderMode();
                        break;
                    default:
                        refresh = true;
                }
                if (refresh) { this._refresh(); }
            }
        },
        /**
        * To set rendermode to Navigation Drawer Control 
        * @private
        */
        _setRenderMode: function () {
            this.element.removeClass("e-m-ios7 e-m-android e-m-windows e-m-flat e-m-dark e-m-light e-m-tablet e-m-mobile");
            this.element.addClass("e-m-" + this.model.renderMode + " e-m-" + this.model.theme + (!ej.isMobile() ? " e-m-tablet" : " e-m-mobile"));
            if (this._lb) this._lb.ejmListView({ renderMode: this.model.renderMode });
            if (this._scrollbar) this._scrollbar.ejmScrollPanel({ renderMode: this.model.renderMode });

        },
        _destroyEJMPlugin: function () {
            if (this._lb) { this._lb.ejmListView("destroy"); this._lb.children().unwrap(); }
            if (this._scrollbar) {
                this._scrollbar.ejmScrollPanel("destroy");
                if (this._scrollbar) this._scrollbar.remove();
            }

        }

    });
    $.extend(true, ej.mobile.NavigationDrawer.prototype, ej.NavigationDrawerBase.prototype);
    $.extend(true, ej.mobile.NavigationDrawer.prototype.defaults.listViewSettings, ej.mobile.ListView.prototype.defaults);
    $.extend(true, ej.mobile.NavigationDrawer.prototype.defaults.scrollSettings, ej.mobile.ScrollPanel.prototype.defaults);

})(jQuery, Syncfusion);