﻿/**
* @fileOverview Plugin to style the Html ProgressBar elements
* @copyright Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/

(function ($, ej, undefined) {

    /**
    * @namespace ej
    * @class ejmProgress
    * @requires jQuery
    * @requires ej.mobile.application
    * @requires ej.core
    * @requires ej.unobtrusive
    * @requires ej.mobile.core
    * @requires ej.data
    * @requires ej.touch
    * @classdesc Custom design for Html Progressbar control.
    * @example 
    * &lt;div id="progress" &gt;&lt;/div&gt;<br>
    * &lt;script&gt; 
    * // Create progressbar  
    * $("#progress").ejmProgress(); 
    * &lt;/script&gt;
    * @example 
    * &lt;div id="progress" data-role="ejmprogress" &gt;&lt;/div&gt;<br>
    */
    // mProgress is the plugin name 
    // "m.Progress" is "namespace.className" will hold functions and properties

    ej.widget("ejmProgress", "ej.mobile.Progress", {
        _setFirst: true,
        _rootCSS: "e-m-progress",
        // default model
        defaults: {
            /**		
            * Changes the rendering mode. See {@link RenderMode}
            * @default auto
            * @type {enum}
            * @example 
            * //Set the renderMode property in unobtrusive way.
            * &lt;div id="progress" data-role="ejmprogress" data-ej-rendermode="auto" &gt;&lt;/div&gt;<br>
            * @example 
            * // Set renderMode on initialization. 
            * //To set renderMode API value 
            * &lt;div id="progress" &gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * $(function(){
            * $("#progress").ejmProgress(); 
            * $("#progress").ejmProgress ({ renderMode: ej.mobile.RenderMode.Auto });
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the renderMode, after initialization:<br>
            * // Get the renderMode API value.	
            * &lt;div id="progress" &gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            *  $("#progress").ejmProgress ("option", "renderMode");			
            * // Set the renderMode API
            * $("#progress").ejmProgress ("option", "renderMode", ej.mobile.RenderMode.Auto);            
            * @memberof ejmProgress
            * @instance
            */
            renderMode: "auto",
            /**		
            * Specifies the initial value.
            * @default 0
            * @type {int}
            * @example 
            * //Set the value property in unobtrusive way.
            * &lt;div id="progress" data-role="ejmprogress" data-ej-value=35 &gt;&lt;/div&gt;<br>
            * @example 
            * // Set value on initialization. 
            * //To set value API value 
            * &lt;div id="progress" &gt;&lt;/div&gt;<br>
            * &lt;script&gt;   
            * $("#progress").ejmProgress(); 
            * $("#progress").ejmProgress ({ value: 35 });
            * &lt;/script&gt;		
            * @example 
            * //Get or set the value, after initialization:<br>
            * // Get the value API value.                                                
            * $("#progress").ejmProgress ("option", "value");           
            * // Set the value API
            * $("#progress").ejmProgress ("option", "value", 35);            
            * @memberof ejmProgress
            * @instance
            */
            value: 0,
            /**		
            * Specifies the initial value in percentage.
            * @default 0
            * @type {int}
            * @example 
            * //Set the percentage property in unobtrusive way.
            * &lt;div id="progress" data-role="ejmprogress" data-ej-percentage=35 &gt;&lt;/div&gt;<br>
            * @example 
            * // Set percentage on initialization. 
            * //To set percentage API value
            * &lt;div id="progress" &gt;&lt;/div&gt;<br>
            * &lt;script&gt;   
            * $("#progress").ejmProgress(); 
            * $("#progress").ejmProgress ({ percentage: 35 });
            * &lt;/script&gt;			
            * @example 
            * //Get or set the percentage, after initialization:<br>
            * // Get the percentage API value.		
            *  $("#progress").ejmProgress ("option", "percentage");			
            * // Set the percentage API
            * $("#progress").ejmProgress ("option", "percentage", 35);            
            * @memberof ejmProgress
            * @instance
            */
            percentage: 0,
            /**		
            * Specifies the value to be added in each step of increment.
            * @default 0
            * @type {int}
            * @example 
            * //Set the incrementStep property in unobtrusive way.
            * &lt;div id="progress" data-role="ejmprogress" data-ej-incrementstep=2 &gt;&lt;/div&gt;<br>
            * @example 
            * // Set incrementStep on initialization. 
            * //To set incrementStep API value 
            * &lt;div id="progress" &gt;&lt;/div&gt;<br>
            * &lt;script&gt;             
            * $("#progress").ejmProgress ({ incrementStep: 2 });
            * &lt;/script&gt;			
            * @example 
            * //Get or set the incrementStep, after initialization:<br>
            * // Get the incrementStep API value.		
            *  $("#progress").ejmProgress ("option", "incrementStep");			
            * // Set the incrementStep API
            * $("#progress").ejmProgress ("option", "incrementStep", 2);            
            * @memberof ejmProgress
            * @instance
            */
            incrementStep: 0,
            /**		
            * specifies the minimum value.
            * @default 0
            * @type {int}
            * @example 
            * //Set the minValue property in unobtrusive way.
            * &lt;div id="progress" data-role="ejmprogress" data-ej-minvalue=10 &gt;&lt;/div&gt;<br>
            * @example 
            * // Set minValue on initialization. 
            * //To set minimum API value
            * &lt;div id="progress" &gt;&lt;/div&gt;<br>
            * &lt;script&gt;  
            * $("#progress").ejmProgress(); 
            * $("#progress").ejmProgress ({ minValue: 10 });
            * &lt;/script&gt; 			
            * @example 
            * //Get or set the minValue, after initialization:<br>
            * // Get the minimum API value.
            *  $("#progress").ejmProgress ("option", "minValue");			
            * // Set the minValue API
            * $("#progress").ejmProgress ("option", "minValue", 10);            
            * @memberof ejmProgress
            * @instance
            */
            minValue: 0,
            /**		
            * Specifies the maximum value.
            * @default 100
            * @type {int}
            * @example 
            * //Set the maxValue property in unobtrusive way.
            * &lt;div id="progress" data-role="ejmprogress" data-ej-maxvalue=90 &gt;&lt;/div&gt;<br>
            * @example 
            * // Set maxValue on initialization. 
            * //To set maximum API value 
            * &lt;div id="progress" &gt;&lt;/div&gt;<br>
            * &lt;script&gt;  
            * $("#progress").ejmProgress(); 
            * $("#progress").ejmProgress ({ maxValue: 90 });
            * &lt;/script&gt;		
            * @example 
            * //Get or set the maxValue, after initialization:<br>
            * // Get the maximum API value.		
            *  $("#progress").ejmProgress ("option", "maxValue");			
            * // Set the maxValue API
            * $("#progress").ejmProgress ("option", "maxValue", 90);            
            * @memberof ejmProgress
            * @instance
            */
            maxValue: 100,
            /**		
            * Specifies the width.
            * @default auto
            * @type {int}
            * @example 
            * //Set the width property in unobtrusive way.
            * &lt;div id="progress" data-role="ejmprogress" data-ej-width=350 &gt;&lt;/div&gt;<br>
            * @example 
            * // Set width on initialization. 
            * //To set width API value 
            * &lt;div id="progress" &gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * $("#progress").ejmProgress(); 
            * $("#progress").ejmProgress ({ width: 350 });	
            * &lt;/script&gt;	
            * @example 
            * //Get or set the width, after initialization:<br>
            * // Get the width API value.		
            *  $("#progress").ejmProgress ("option", "width");			
            * // Set the width API
            * $("#progress").ejmProgress ("option", "width", 350);            
            * @memberof ejmProgress
            * @instance
            */
            width: null,
            /**		
            * Specifies the Height.
            * @default auto
            * @type {int}
            * @example 
            * //Set the height property in unobtrusive way.
            * &lt;div id="progress" data-role="ejmprogress" data-ej-height=10 &gt;&lt;/div&gt;<br>
            * @example 
            * // Set height on initialization. 
            * //To set height API value
            * &lt;div id="progress" &gt;&lt;/div&gt;<br>
            * &lt;script&gt;   
            * $("#progress").ejmProgress(); 
            * $("#progress").ejmProgress ({ height: 10 });
            * &lt;/script&gt;		
            * @example 
            * //Get or set the height, after initialization:<br>
            * // Get the height API value.		
            *  $("#progress").ejmProgress ("option", "height");			
            * // Set the height API
            * $("#progress").ejmProgress ("option", "height", 10);            
            * @memberof ejmProgress
            * @instance
            */
            height: null,
            /**		
            * Specifies the orientation whether it is horizontal or vertical. See {@link Orientation}
            * @default ej.mobile.Progress.Orientation.Horizontal
            * @type {enum}
            * @example
            * //Set the orientation property in unobtrusive way.
            * &lt;div id="progress" data-role="ejmprogress" data-ej-orientation="horizontal" &gt;&lt;/div&gt;<br>
            * @example 
            * // Set orientation on initialization. 
            * //To set orientation API value 
            * &lt;div id="progress" &gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * $(function(){
            * $("#progress").ejmProgress(); 
            * $("#progress").ejmProgress ({ orientation: ej.mobile.Progress.Orientation.Horizontal });
            * });
            * &lt;/script&gt;			
            * @example 
            * //Get or set the orientation, after initialization:<br>
            * // Get the orientation API value.		
            *  $("#progress").ejmProgress ("option", "orientation");			
            * // Set the orientation API
            * $("#progress").ejmProgress ("option", "orientation", ej.mobile.Progress.Orientation.Horizontal);            
            * @memberof ejmProgress
            * @instance
            */
            orientation: "horizontal",
            /**    
            * Event triggers when the create happens.
            * @event
            * @name ejmProgress#create 	
            * @param {Object} argument event parameters from progressbar     
            * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
            * @param {string} argument.model returns the progressbar model
            * @param {string} argument.type returns the name of the event
            * @param {object} argument.element returns the current element
            * @param {int} argument.value returns the current element associated value
            * @example 
            * &lt;div id="progress" data-role="ejmprogress" data-ej-create="onCreate"&gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // Create event   
            * function onCreate(args){ //handle the event
            *}
            * &lt;/script&gt;
            * @example 
            * //create event 
            * &lt;div id="progress"&gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * $("#progress").ejmProgress({
            *   create: function (args) { //handle the event 
            *}
            *}); 
            * &lt;/script&gt;
            * @memberof ejmProgress
            * @instance
            */
            create: null,
            /**    
            * Event triggers when the value change happens.
            * @event
            * @name ejmProgress#change 	
            * @param {Object} argument event parameters from progressbar     
            * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
            * @param {string} argument.model returns the progressbar model
            * @param {string} argument.type returns the name of the event
            * @param {object} argument.element returns the current element
            * @param {int} argument.value returns the current element associated value
            * @example 
            * &lt;div id="progress" data-role="ejmprogress" data-ej-change="onChange"&gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // change event   
            * function onChange(args){ //handle the event
            *}
            * &lt;/script&gt;
            * @example 
            * //change event 
            * &lt;div id="progress"&gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * $("#progress").ejmProgress({
            *   change: function (args) { //handle the event 
            *}
            *});  
            * &lt;/script&gt;
            * @memberof ejmProgress
            * @instance
            */
            change: null,
            /**    
            * Event triggers when the start happens.
            * @event
            * @name ejmProgress#start 	
            * @param {Object} argument event parameters from progressbar     
            * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
            * @param {string} argument.model returns the progressbar model
            * @param {string} argument.type returns the name of the event
            * @param {object} argument.element returns the current element
            * @param {int} argument.value returns the current element associated value
            * @example 
            * &lt;div id="progress" data-role="ejmprogress" data-ej-start="onStart"&gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // start event 
            * function onStart(args){ //handle the event
            *}
            * &lt;/script&gt;
            * @example 
            * //start event 
            * &lt;div id="progress"&gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * $("#progress").ejmProgress({
            *   start: function (args) { //handle the event 
            *}
            *});  
            * &lt;/script&gt;
            * @memberof ejmProgress
            * @instance
            */
            start: null,
            /**    
            * Event triggers when the complete happens.
            * @event
            * @name ejmProgress#complete 	
            * @param {Object} argument event parameters from progressbar     
            * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
            * @param {string} argument.model returns the progressbar model
            * @param {string} argument.type returns the name of the event
            * @param {object} argument.element returns the current element
            * @param {int} argument.value returns the current element associated value
            * @example 
            * &lt;div id="progress" data-role="ejmprogress" data-ej-complete="onComplete"&gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // complete event 
            * function onComplete(args){ //handle the event
            *}
            * &lt;/script&gt;
            * @example 
            * &lt;div id="progress"&gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * //complete event 
            * $("#progress").ejmProgress({
            *   complete: function (args) { //handle the event
            *}
            *}); 
            * &lt;/script&gt;
            * @memberof ejmProgress
            * @instance
            */
            complete: null,
            /**		
            * Applies custom text to notify it's current actions.
            * @default ""
            * @type {string}
            * @example 
            * //Set the text property in unobtrusive way.
            * &lt;div id="progress" data-role="ejmprogress" data-ej-enablecustomtext=true data-ej-text="in-progress" &gt;&lt;/div&gt;<br>
            * @example 
            * // Set text on initialization. 
            * //To set text API value 
            * &lt;div id="progress" &gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * $("#progress").ejmProgress(); 
            * $("#progress").ejmProgress ({ enableCustomText: true });
            * $("#progress").ejmProgress ({ text: "in-progress" });			
            * &lt;/script&gt;	
            * @example 
            * //Get or set the text, after initialization:<br>
            * // Get the text API value.		
            *  $("#progress").ejmProgress ("option", "text");			
            * // Set the text API
            * $("#progress").ejmProgress ("option", "text", "in-progress");            
            * @memberof ejmProgress
            * @instance
            */
            text: "",
            /**		
            * Specifies whether the control is enabled or disabled.
            * @default true
            * @type {bool}
            * @example 
            * //Set the enabled property in unobtrusive way.
            * &lt;div id="progress" data-role="ejmprogress" data-ej-enabled=true &gt;&lt;/div&gt;<br>
            * @example 
            * // Set enabled on initialization. 
            * //To set enabled API value 
            * &lt;div id="progress" &gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // Create progressbar  
            * $("#progress").ejmProgress(); 
            * $("#progress").ejmProgress ({ enabled: false});
            * &lt;/script&gt;			
            * @example 
            * //Get or set the enabled, after initialization:<br>
            * // Get the enabled API value.		
            *  $("#progress").ejmProgress ("option", "enabled");			
            * // Set the enabled API
            * $("#progress").ejmProgress ("option", "enabled", true);            
            * @memberof ejmProgress
            * @instance
            */
            enabled: true,
            /**		
            * Specifies whether to accept custom text or not.
            * @default false
            * @type {bool}
            * @example 
            * //Set the enableCustomText property in unobtrusive way.
            * &lt;div id="progress" data-role="ejmprogress" data-ej-enablecustomtext=false &gt;&lt;/div&gt;<br>
            * @example 
            * // Set enable custom text on initialization. 
            * //To set enable custom text API value 
            * &lt;div id="progress" &gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // Create progressbar  
            * $("#progress").ejmProgress(); 
            * $("#progress").ejmProgress ({ enableCustomText: false });			
            * &lt;/script&gt;
            * @example 
            * //Get or set the enable custom text, after initialization:<br>
            * // Get the enable custom text API value.		
            *  $("#progress").ejmProgress ("option", "enableCustomText");			
            * // Set the enable custom text API
            * $("#progress").ejmProgress ("option", "enableCustomText", false);            
            * @memberof ejmProgress
            * @instance
            */
            enableCustomText: false,
            /**		
            * Specifies the theme.See {@link Theme}
            * @default auto
            * @type {enum}
            * @example 
            * //Set the theme property in unobtrusive way.
            * &lt;div id="progress" data-role="ejmprogress" data-ej-theme="auto" &gt;&lt;/div&gt;<br>
            * @example 
            * // Set progressbar theme on initialization. 
            * //To set theme API value 
            * &lt;div id="progress" &gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // Create progressbar 
            * $(function(){
            * $("#progress").ejmProgress(); 
            * $("#progress").ejmProgress ({ theme: ej.mobile.Theme.Auto });
            * });
            * &lt;/script&gt;			
            * @example 
            * //Get or set the theme, after initialization:<br>
            * // Get the theme API value.		
            *  $("#progress").ejmProgress ("option", "theme");			
            * // Set the theme API
            * $("#progress").ejmProgress ("option", "theme", ej.mobile.Theme.Auto);            
            * @memberof ejmProgress
            * @instance
            */
            theme: "auto",
            /**		
            * Saves current model value to browser cookies for state maintainance. While refreshing the page it retains the model value and applies from browser cookies.
            * @default false
            * @type {bool}
            * @example 
            * //Set the enablePersistence property in unobtrusive way.
            * &lt;div id="progress" data-role="ejmprogress" data-ej-enablepersistence=false &gt;&lt;/div&gt;<br>
            * @example 
            * // Set progressbar enablePersistence on initialization. 
            * //To set enablePersistence API value 
            * &lt;div id="progress" &gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // Create progressbar  
            * $("#progress").ejmProgress(); 
            * $("#progress").ejmProgress ({ enablePersistence: false });
            * &lt;/script&gt;			
            * @example 
            * //Get or set the enablePersistence, after initialization:<br>
            * // Get the enablePersistence API value.		
            *  $("#progress").ejmProgress ("option", "enablePersistence");			
            * // Set the enablePersistence API
            * $("#progress").ejmProgress ("option", "enablePersistence", false);            
            * @memberof ejmProgress
            * @instance
            */
            enablePersistence: false
        },
        dataTypes: {
            renderMode: "enum",
            orientation: "enum",
            enabled: "boolean",
            enableCustomText: "boolean",
            theme: "enum",
            enablePersistence: "boolean"
        },

        // constructor function
        _init: function () {

            this._cloneElement = this.element.clone();
            this._createDelegate();
            this._wireEvents(false);
            this._renderControl();
            this._progressbarInit();
            this._pageLoad();
        },
        _renderControl: function () {

            ej.setRenderMode(this);
            ej.setTheme(this);
            var canvas = ej.buildTag("canvas");
            this.element.append(canvas);
        },
        _createDelegate: function () { 
            this._onOrientationChangedDelegate = $.proxy(this._onOrientationChangedHandler, this);
            this._onWindowsResizeDelegate = $.proxy(this._onWindowResizeHandler, this);
        },
        _wireEvents: function (remove) { 
            if (!remove)
                ej.listenEvents([window], [!ej.isTouchDevice() ? "resize" : "orientationchange"], [this._onWindowsResizeDelegate], remove);
        },
        _onWindowResizeHandler: function () {
            var proxy = this;
            window.setTimeout(function () {
                proxy._draw();
            }, 250);
        },
        _widthAndHeightProperties: function () {
            this._tempHeight = this.model.orientation == "horizontal" ? (this.model.height ? this.model.height : 3) : (this.model.width ? this.model.width : this.element.parent().height());
            this._tempWidth = this.model.orientation == "horizontal" ? (this.model.width ? this.model.width : this.element.parent().width()) : (this.model.height ? this.model.height : 3);
        },
        _progressbarInit: function () {

            var span;
            this._initialX = 0;
            this._initialY = 0;
            this._mProgress = this.element;
            this._increment = 0;
            this._result = 0;
            this._context = null;
            this._text = this.model.textStyle;
            this._externalText = null;
            this._totalWidth = 0;
            this._totalHeight = 0;
            this._radius = 0;
            this._currentValue = 1;
        },
        _pageLoad: function () {

            var elem = this.element.find("canvas")[0];
            var parent = $(elem).parent();
            if (typeof window.G_vmlCanvasManager != "undefined")
                elem = window.G_vmlCanvasManager.initElement(elem);
            if (!elem || !elem.getContext)
                return;
            var elem = this.element.find("canvas")[0];
            this._context = elem.getContext('2d');
            if (!this._context)
                return;
            this.model.value = this.model.value + this.model.incrementStep;
            this._validate();
            var data = { element: this.element, value: this.model.value };
            this._result = this._draw();
            var data = { value: this._setValue, percentage: this.model.percentage };
            if (this.model.minValue == this.model.value)
                this._trigger("start", data);
        },
        _validate: function () {

            if (this._setValue == this.model.maxValue) {
                var data = { value: this._setValue, text: this.model.text, percentage: this.model.percentage };
                if (this.model.complete)
                    this._trigger("complete", data);
            }
            this._setValue = this._setValue < this.model.minValue ? this.model.minValue : (this._setValue > this.model.maxValue ? this.model.maxValue : this._setValue);
            if (this._step > this._max)
                this._step = 1;
        },
        _draw: function () {

            this._widthAndHeightProperties();
            if (this._context != null) {
                if (!this.model.enabled) {
                    $(this.element).addClass("e-m-state-disabled");
                    this._wireEvents(true);
                }
                if (this.model.value <= 0 && this.model.percentage != 0)
                    this.model.value = Math.round((this.model.percentage * this.model.maxValue) / 100);
                else if (this.model.value != 0 && this.model.percentage <= 0)
                    this.model.percentage = Math.round((this.model.value / this.model.maxValue) * 100);
                else if (this.model.value != 0 && this.model.percentage != 0)
                    this.model.percentage = Math.round((this.model.value / this.model.maxValue) * 100);
                if ((this.model.minValue <= this.model.value) && (this.model.maxValue >= this.model.value)) {
                    this._cutOffValue = this.model.value - this.model.minValue;
                    if (this.model.percentage >= 100)
                        this.model.percentage = 100;
                    else if (this.model.percentage <= 0)
                        this.model.percentage = 0;
                    if (this.model.percentage != undefined)
                        this._setValue = this.model.percentage;
                    else
                        this._setValue = Math.round((100 / (this.model.maxValue - this.model.minValue)) * this._cutOffValue);
                }
                else if ((this.model.minValue > this.model.value) && (this.model.maxValue > this.model.value))
                    this._setValue = 0;
                else if ((this.model.minValue < this.model.value) && (this.model.maxValue < this.model.value))
                    this._setValue = 100;
                this._setOrientationProperties(this._tempWidth, this._tempHeight, this._tempHeight + 50, this._tempWidth + 50);
                this._context.translate(0.5, 0.5);
                // Clear everything before drawing
                this._context.clearRect(this._initialX - 5, this._initialY - 5, this._totalWidth + 15, this._totalHeight + 15);
                var value;
                value = (this.model.renderMode == "windows" || this.model.renderMode == "flat") ? 10 : 25;
                this._initialY = (this.model.orientation == "horizontal") ? value : 0;
                this._initialX = (this.model.orientation == "horizontal") ? 0 : value;
                if (this.model.renderMode == "ios7") {
                    if (this.model.orientation == "horizontal")
                        this._totalHeight = (this._tempHeight == "") ? 3 : this._tempHeight;
                    else
                        this._totalWidth = (this._tempWidth == "") ? 3 : this._tempWidth;
                    this.totalRadius = (this.model.orientation == "horizontal") ? Math.round(this._totalHeight / 2) : Math.round(this._totalWidth / 2);
                    this._fillRadius = this.totalRadius;
                }
                else {
                    if (this.model.orientation == "horizontal")
                        this._totalHeight = (this._tempHeight == "") ? 2 : this._tempHeight;
                    else
                        this._totalWidth = (this._tempWidth == "") ? 2 : this._tempWidth;
                    this.totalRadius = 0; //default radius value for other modes
                    this._fillRadius = 0;
                }
                (this.model.orientation == "horizontal") ?
                this._roundRectOuter(this._context, this._initialX, this._initialY, this._totalWidth - 15, this._totalHeight, this.totalRadius) :
                this._roundRectOuter(this._context, this._initialX, this._initialY, this._totalWidth, this._totalHeight - 15, this.totalRadius);
                (this.model.orientation == "horizontal") ?
                this._roundRectFill(this._context, this._initialX, this._initialY, this._increment, this._totalHeight, this._fillRadius) :
                this._roundRectFill(this._context, this._initialX, this._initialY, this._increment, this._totalHeight - 15, this._fillRadius);
                if (this._increment >= this._totalWidth)
                    window.clearInterval(this._result);
            }
            this._validate();
        },
        _setOrientationProperties: function (horLength, verLength, canvasHeight, canvasWidth) {
            this._totalWidth = horLength;
            this._totalHeight = verLength;
            this._radius = (this.model.orientation == "horizontal" ? this._totalHeight : this._totalWidth) / 2;
            this._increment = (this._setValue) * ((this.model.orientation == "horizontal") ? (this._totalWidth - 15) / 100 : (this._totalHeight - 15) / 100);
            this._context.canvas.width = (this.model.orientation == "horizontal") ? horLength : canvasWidth;
            this._context.canvas.height = (this.model.orientation == "horizontal") ? canvasHeight : verLength;
        },

        _roundRect: function (ctx, x, y, width, height, radius) {
            ctx.save();
            ctx.beginPath();
            ctx.strokeStyle = this._strokeStyle;
            ctx.fillStyle = this._fillStyle;
            ctx.lineWidth = 1;
            ctx.moveTo(x + radius, y);
            ctx.lineTo(x + width - radius, y);
            ctx.quadraticCurveTo(x + width, y, x + width, y + radius);
            ctx.lineTo(x + width, y + height - radius);
            ctx.quadraticCurveTo(x + width, y + height, x + width - radius, y + height);
            ctx.lineTo(x + radius, y + height);
            ctx.quadraticCurveTo(x, y + height, x, y + height - radius);
            ctx.lineTo(x, y + radius);
            ctx.quadraticCurveTo(x, y, x + radius, y);
            ctx.fill();
            ctx.stroke();
            ctx.closePath();
            ctx.restore();
        },
        _roundRectOuter: function (ctx, x, y, width, height, radius) {

            if (this.model.renderMode == "ios7") {
                var gradientColor = (this.model.theme == 'dark') ? [{ "ColorStop": 1, "Color": "#363636"}] : [{ "ColorStop": 1, "Color": "#b5b5b6"}];
                grd = (this.model.orientation == "horizontal") ? ctx.createLinearGradient(x, y, x, y + height) : ctx.createLinearGradient(x, y, x + width, y);
                ej._setGradientColor(this, grd, gradientColor);
                this._strokeStyle = grd;
                this._fillStyle = grd;
            }
            else if (this.model.renderMode == "android")
                this._setRectOuterProperties("#3A3A3A", "#A9A9A9");
            else if (this.model.renderMode == "windows")
                this._setRectOuterProperties("#373737", "#c5c5c5");
            else if (this.model.renderMode == "flat")
                this._setRectOuterProperties("#b3b3b3", "#b3b3b3");
            (this.model.orientation == "horizontal") ? this._roundRect(ctx, x, y, width + radius, height, radius) : this._roundRect(ctx, x + 5, y, width, height + radius, radius);
        },
        _setRectOuterProperties: function (dark, light) {
            if (this.model.theme == "dark") {
                this._strokeStyle = dark;
                this._fillStyle = dark;
            }
            else {
                this._strokeStyle = light;
                this._fillStyle = light;
            }

        },
        _roundRectFill: function (ctx, x, y, width, height, radius) {//for positioning the progressbar
            if (this.model.renderMode == "ios7") {
                var gradientColor = [{ "ColorStop": 0, "Color": "#017aff"}];
                grd = (this.model.orientation == "horizontal") ? ctx.createLinearGradient(x, y, x, y + height) : ctx.createLinearGradient(x, y, x + width, y);
                ej._setGradientColor(this, grd, gradientColor);
                this._strokeStyle = grd;
                this._fillStyle = grd;
            }
            else if (this.model.renderMode == "android")
                this._strokeStyle = this._fillStyle = "#33B5E5";
            else if (this.model.renderMode == "windows")
                this._strokeStyle = this._fillStyle = "#2ca1dd";
            else if (this.model.renderMode == "flat")
                this._strokeStyle = this._fillStyle = "#f48b22";
            if (width > 0)
                (this.model.orientation == "horizontal") ? this._roundRect(ctx, x, y, width + radius, height, radius) : this._roundRect(ctx, x + 5, height - width + y, this._totalWidth, width + radius, radius);
            ctx.save();
            if (this.model.orientation == "horizontal")
                this._setTextProperties();
            else {
                this._setTextProperties();
                var ang = 270;
                ctx.save();
                ctx.translate(this._totalWidth / 2, height / 2);
                ctx.rotate(ang * 2 * 3.1416 / 360);
                if (this.model.renderMode == "ios7")
                    ctx.textAlign = "center";
                else if (this.model.renderMode == "android")
                    ctx.textAlign = "right";
            }
            if (this.model.enableCustomText) {
                if (this.model.text == "" || this.model.text == undefined)
                    this.setCustomText(this._text);
                else
                    this.setCustomText(this.model.text);
            }
            else
                this.setCustomText(this._text);
            var data = { value: this._setValue, text: this.model.text, percentage: this.model.percentage };
            if (this.model.change && this.model.value > 0)
                this._trigger("change", data);
            ctx.restore();
        },
        _setTextProperties: function () {
            if (this.model.renderMode == "ios7")
                this._text = "Downloading " + this._setValue + " of 100%";
            else if (this.model.renderMode == "android")
                this._text = this._setValue + "%";
            else if (this.model.renderMode == "windows" || this.model.renderMode == "flat")
                this._text = this._setValue;
        },
        _setCustomtextProperties: function (context, dark, light, font) {
            context.fillStyle = this.model.theme == "dark" ? dark : light;
            context.font = font;
        },
        /**
        * To configure the renderMode of the progressbar		
        * @private
        */
        _setRenderMode: function (mode) {
            if (this.model.enabled) {
                this.model.renderMode = mode;
                if (mode == "auto")
                    ej.setRenderMode(this);
                this._draw();
            }
        },
        /**
        * To configure the theme of the progressbar		
        * @private
        */
        _setTheme: function (theme) {
            if (this.model.enabled) {
                this.model.theme = theme;
                this._draw();
            }
        },
        /**
        * To configure the value of the progressbar		
        * @private
        */
        _value: function (value) {
            if (this.model.enabled) {
                this._setValue = value;
                this._draw();
            }
        },
        /**
        * To configure the percentage of the progressbar		
        * @private
        */
        _setPercentage: function (percentage) {
            if (this.model.enabled) {
                this._value = percentage;
                this._draw();
            }
        },
        /**
        * To configure the disabled property of the progressbar		
        * @private
        */
        _disable: function () {
            this.model.enabled = false;
            this.element.addClass('e-m-state-disabled');
            this._wireEvents(true);
        },
        /**
        * To configure the disabled property of the progressbar		
        * @private
        */
        _enable: function () {
            this.model.enabled = true;
            this.element.removeClass('e-m-state-disabled');
            this._wireEvents(false);
        },
        /**
        * To configure the refresh property of the progressbar		
        * @private
        */
        _refresh: function () {
            this._clearElements();
            this._wireEvents(false);
            this._renderControl();
            this._progressbarInit();
            this._pageLoad();
        },
        /**
        * To configure the width of the progressbar		
        * @private
        */
        _setWidth: function (width) {
            this._tempWidth = this.model.width = width;
            this._draw();
        },
        /**
        * To configure the height of the progressbar		
        * @private
        */
        _setHeight: function (height) {
            this._tempHeight = this.model.height = height;
            this._draw();
        },
        /**
        * To configure the text of the progressbar		
        * @private
        */
        _setText: function (text) {
            if (this.model.enabled) {
                this.model.text = text;
                this._draw();
            }
        },
        _setModel: function (options) {
            for (var prop in options) {
                switch (prop) {
                    case "renderMode": this._setRenderMode(options.renderMode); break;
                    case "theme": (this.model.enabled) ? this._setTheme(options.theme) : ""; break;
                    case "width": (this.model.enabled) ? this._setWidth(options.width) : ""; break;
                    case "height": (this.model.enabled) ? this._setHeight(options.height) : ""; break;
                    case "orientation": (this.model.enabled) ? this._draw() : ""; break;
                    case "value": (this.model.enabled) ? this._value(options.value) : ""; break;
                    case "percentage": (this.model.enabled) ? this._setPercentage(options.percentage) : ""; break;
                    case "minValue": (this.model.enabled) ? this._draw() : ""; break;
                    case "maxValue": (this.model.enabled) ? this._draw() : ""; break;
                    case "enabled": (options.enabled) ? this._enable() : this._disable(); break;
                    case "text": (this.model.enabled) ? this._setText(options.text) : ""; break;
                }
            }
        },
        _clearElements: function () {
            this._wireEvents(true);
            this.element.removeAttr("class");
            this.element.removeClass('e-m-progress');
            this.element.html("");
        },
        // all events bound using this._on will be unbind automatically
        _destroy: function () {
            this._cloneElement.insertBefore(this.element).removeClass('e-m-progress');
            this.element.remove();
        },

        /*---------------Public Methods---------------*/
        /**
        * Gets the currentvalue.
        * @return jQuery
        * @example 
        * &lt;div id="progress"&gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * // Create progressbar
        * var progress = $("#progress").data("ejmProgress");
        * progress.getValue(); // returns the progressbar current value
        * &lt;/script&gt;
        * @example 
        * &lt;div id="progress"&gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * // Get the current value
        * $("#progress").ejmProgress("getValue");	
        * &lt;/script&gt;
        *@memberof ejmProgress
        * @instance
        */
        getValue: function () {
            return this._setValue;
        },
        /**
        * Get current value in percentage
        * @return jQuery
        * @example 
        * &lt;div id="progress"&gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * // Create progressbar
        * var progress = $("#progress").data("ejmProgress");
        * progress.getPercentage(); // returns the progressbar current percent value
        * &lt;/script&gt;
        * @example 
        * &lt;div id="progress"&gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * // Get the current percent value
        * $("#progress").ejmProgress("getPercentage");	
        * &lt;/script&gt;
        *@memberof ejmProgress
        * @instance
        */
        getPercentage: function () {
            /// <summary>Returns the Progress bar value in percentage.</summary>
            return this.model.percentage;
        },
        /**
        * Set the custom text on each action conplete.
        * @return jQuery
        * @example 
        * &lt;div id="progress"&gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * // Create progressbar
        * var progress = $("#progress").data("ejmProgress");
        * progress.setCustomText("Downloading.."); // Set the progressbar custom text
        * &lt;/script&gt;
        * @example 
        * &lt;div id="progress"&gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * // Set the custom text
        * $("#progress").ejmProgress("setCustomText", "Downloading..");	
        * &lt;/script&gt;
        *@memberof ejmProgress
        * @instance
        */
        setCustomText: function (customText) {
            var context = this._context, height = this._totalHeight, radius = this.totalRadius, width = this._totalWidth, x, y;
            this.model.text = customText;
            var ang = 270;
            if (this.model.renderMode == "ios7") {
                x = (this.model.orientation == "horizontal") ? 0 : 8;
                y = (this.model.orientation == "horizontal") ? 8 : 0;
            }
            else if (this.model.renderMode == "android")
                y = 15;
            else if (this.model.renderMode == "windows" || this.model.renderMode == "flat") {
                x = 0;
                y = 30;
            }
            context.save();
            if (this.model.renderMode == "ios7")
                this._setCustomtextProperties(context, "#fefefe", "#000000", "14px Helvetica");
            else if (this.model.renderMode == "android")
                this._setCustomtextProperties(context, "#fefefe", "#333333", "17px Roboto");
            else if (this.model.renderMode == "windows")
                this._setCustomtextProperties(context, "#ffffff", "#000000", "17px Segoe UI");
            else if (this.model.renderMode == "flat")
                this._setCustomtextProperties(context, "#333333", "#333333", "17px Segoe UI");
            var textWidth = context.measureText(this.model.text).width;
            var def_wid = context.measureText(this._setValue + "%").width;
            if (this.model.orientation == "horizontal") {
                var textX = x + width / 2 - textWidth / 2;
                if (this.model.renderMode == "ios7")
                    context.fillText(this.model.text, textX, y + 5);
                else if (this.model.renderMode == "android") {
                    if (this.model.text != "" && this.model.text != undefined)
                        context.fillText(this.model.text, width - textWidth - 15, y);
                    else
                        context.fillText(this.model.text, width - def_wid - 15, y);

                }
                else if (this.model.renderMode == "windows" || this.model.renderMode == "flat")
                    context.fillText(this.model.text, x, height + y);
            }
            else {
                var textX = y + 15;
                if (this.model.renderMode == "ios7")
                    context.fillText(this.model.text, y, textX);
                else if (this.model.renderMode == "android") {
                    if (this.model.text != "" && this.model.text != undefined)
                        context.fillText(this.model.text, (height - 15) / 2, 15);
                    else
                        context.fillText(this.model.text, (height - 15) / 2, y);
                    context.textAlign = "right";
                }
                else if (this.model.renderMode == "windows" || this.model.renderMode == "flat")
                    context.fillText(this.model.text, -(height - 15) / 2, y + width);
            }
            context.restore();
        },
        changeEventHandler: function (proxy, value) {
            var data = { element: this.element, value: this._setValue, percentage: this._value };
            if (this.model.change)
                this._trigger("change", data);
        }
        /*---------------Public Methods End---------------*/
    });

    /**
    * Enum for ProgressbarOrientation
    * @enum {string}
    * @global
    */
    ej.mobile.Progress.Orientation = {
        /**
        Enum for horizontal mode progress bar*/
        Horizontal: "horizontal",
        /**
        Enum for vertical mode progress bar*/
        Vertical: "vertical"
    }
})(jQuery, Syncfusion);