/**
* @fileOverview Plugin to style the Html Radial Menu elements
* @copyright Copyright Syncfusion Inc. 2001 - 2014. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/

(function ($, ej, undefined) {

    /**
    * @namespace ej
    * @class ejmRadialMenu
    * @requires jQuery
    * @requires ej.mobile.application
    * @requires ej.core
    * @requires ej.unobtrusive
    * @requires ej.mobile.core
    * @requires ej.data
    * @requires ej.touch
    * @classdesc Custom Design for Html radialmenu control.
    * @example 
    * //Create radialmenu in unobtrusive way
    * &lt;div &gt;
    * &lt;br /&gt;
    * &lt;p&gt;
    * Syncfusion is the enterprise technology partner of choice for Windows development
    * &lt;/p&gt;
    * &lt;/div&gt;  
    * &lt;div id="defaultradialmenu" data-role="ejmradialmenu"
    * &gt;
    * &lt;ul&gt;
    * &lt;li data-ej-imagename="social.png" data-ej-imagepath="../themes/sample/radialmenu"
    * data-ej-windows-text="social"&gt;&lt;/li&gt;
    * &lt;li data-ej-imagename="music.png" data-ej-imagepath="../themes/sample/radialmenu"
    * data-ej-windows-text="music"&gt;&lt;/li&gt;
    * &lt;li data-ej-imagename="direction.png" data-ej-imagepath="../themes/sample/radialmenu"
    * data-ej-windows-text="direction"&gt;&lt;/li&gt;
    * &lt;li data-ej-imagename="message.png" data-ej-imagepath="../themes/sample/radialmenu"
    * data-ej-windows-text="message"&gt;&lt;/li&gt;
    * &lt;li data-ej-imagename="browser.png" data-ej-imagepath="../themes/sample/radialmenu"
    * data-ej-windows-text="browser"&gt;&lt;/li&gt;
    * &lt;/ul&gt;
    * &lt;/div&gt;
    * @example
    * // Create radialmenu in obtrusive way
    * &lt;script&gt; 
    * $(function(){
    * $("#defaultradialmenu").ejmRadialMenu(); 
    * });
    * &lt;/script&gt;
    * &lt;div &gt;
    * &lt;br /&gt;
    * &lt;p&gt;
    * Syncfusion is the enterprise technology partner of choice for Windows development
    * &lt;/p&gt;
    * &lt;/div&gt;  
    * &lt;div id="defaultradialmenu"&gt;
    * &lt;ul&gt;
    * &lt;li data-ej-imagename="social.png" data-ej-imagepath="../themes/sample/radialmenu"
    * data-ej-windows-text="social"&gt;&lt;/li&gt;
    * &lt;li data-ej-imagename="music.png" data-ej-imagepath="../themes/sample/radialmenu"
    * data-ej-windows-text="music"&gt;&lt;/li&gt;
    * &lt;li data-ej-imagename="direction.png" data-ej-imagepath="../themes/sample/radialmenu"
    * data-ej-windows-text="direction"&gt;&lt;/li&gt;
    * &lt;li data-ej-imagename="message.png" data-ej-imagepath="../themes/sample/radialmenu"
    * data-ej-windows-text="message"&gt;&lt;/li&gt;
    * &lt;li data-ej-imagename="browser.png" data-ej-imagepath="../themes/sample/radialmenu"
    * data-ej-windows-text="browser"&gt;&lt;/li&gt;
    * &lt;/ul&gt;
    * &lt;/div&gt;
    */

    ej.widget("ejmRadialMenu", "ej.mobile.RadialMenu", {
        _setFirst: true,
        _rootCSS: "e-m-radialmenu",
        // Default model values
        defaults: {
            /**		
            * Changes the rendering mode. See {@link RenderMode}
            * @default auto
            * @type {enum}
            * @example 
            * //Set the renderMode property in unobtrusive way.
            * &lt;div &gt;
            * &lt;br /&gt;
            * &lt;p&gt;
            * Syncfusion is the enterprise technology partner of choice for Windows development
            * &lt;/p&gt;
            * &lt;/div&gt;  
            * &lt;div id="defaultradialmenu" data-role="ejmradialmenu" data-ej-rendermode="auto" 
            * &gt;
            * &lt;ul&gt;
            * &lt;li data-ej-imagename="social.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="social"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="music.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="music"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="direction.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="direction"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="message.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="message"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="browser.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="browser"&gt;&lt;/li&gt;
            * &lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * // Set Radialmenu renderMode on initialization. 
            * //To set renderMode API value 
            * &lt;div &gt;
            * &lt;br /&gt;
            * &lt;p&gt;
            * Syncfusion is the enterprise technology partner of choice for Windows development
            * &lt;/p&gt;
            * &lt;/div&gt;  
            * &lt;div id="defaultradialmenu"&gt;
            * &lt;ul&gt;
            * &lt;li data-ej-imagename="social.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="social"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="music.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="music"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="direction.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="direction"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="message.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="message"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="browser.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="browser"&gt;&lt;/li&gt;
            * &lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function () {
            * $("#defaultradialmenu").ejmRadialMenu({ "renderMode":ej.mobile.RenderMode.Auto });	
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the Radialmenu renderMode, after initialization:
            * &lt;script&gt;
            * // Gets the renderMode API value.		
            *  $("#defaultradialmenu").ejmRadialMenu ("option", "renderMode");			
            * // Sets the renderMode API
            * $("#defaultradialmenu").ejmRadialMenu ("option", "renderMode", ej.mobile.RenderMode.Auto);            
            * &lt;/script&gt;
            * @memberof ejmRadialMenu
            * @instance
            */
            renderMode: "auto",
            /**		
            * Renders the image for Radial using Class.
            * @default e-m-radialimage
            * @type {string}
            * @example 
            * //Set the imageClass property in unobtrusive way.
            * &lt;div &gt;
            * &lt;br /&gt;
            * &lt;p&gt;
            * Syncfusion is the enterprise technology partner of choice for Windows development
            * &lt;/p&gt;
            * &lt;/div&gt;  
            * &lt;div id="defaultradialmenu" data-role="ejmradialmenu" data-ej-imagaclass="e-m-radialimage" 
            * &gt;
            * &lt;ul&gt;
            * &lt;li data-ej-imagename="social.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="social"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="music.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="music"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="direction.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="direction"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="message.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="message"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="browser.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="browser"&gt;&lt;/li&gt;
            * &lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * // Set Radialmenu imageClass on initialization. 
            * //To set imageClass API  
            * &lt;div &gt;
            * &lt;br /&gt;
            * &lt;p&gt;
            * Syncfusion is the enterprise technology partner of choice for Windows development
            * &lt;/p&gt;
            * &lt;/div&gt;  
            * &lt;div id="defaultradialmenu"&gt;
            * &lt;ul&gt;
            * &lt;li data-ej-imagename="social.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="social"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="music.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="music"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="direction.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="direction"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="message.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="message"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="browser.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="browser"&gt;&lt;/li&gt;
            * &lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function () {
            * $("#defaultradialmenu").ejmRadialMenu({ "imageClass":"e-m-radialimage" });	
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the Radialmenu imageClass, after initialization:
            * &lt;script&gt;
            * // Gets the imageClass API.		
            *  $("#radialmenu").ejmRadialMenu ("option", "imageClass");			
            * // Sets the Width API
            * $("#radialmenu").ejmRadialMenu ("option", "imageClass", "e-m-radialimage");            
            * &lt;/script&gt;
            * @memberof ejmRadialMenu
            * @instance
            */
            imageClass: "e-m-radialimage",
            /**		
            * Renders the back button Image for Radial using class.
            * @default e-m-backimage
            * @type {string}
            * @example 
            * //Set the backImageClass property in unobtrusive way.
            * &lt;div &gt;
            * &lt;br /&gt;
            * &lt;p&gt;
            * Syncfusion is the enterprise technology partner of choice for Windows development
            * &lt;/p&gt;
            * &lt;/div&gt;  
            * &lt;div id="defaultradialmenu" data-role="ejmradialmenu" data-ej-backimageclass="e-m-backimage" 
            * &gt;
            * &lt;ul&gt;
            * &lt;li data-ej-imagename="social.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="social"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="music.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="music"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="direction.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="direction"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="message.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="message"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="browser.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="browser"&gt;&lt;/li&gt;
            * &lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * // Set Radialmenu backImageClass on initialization. 
            * //To set backImageClass API 
            * &lt;div &gt;
            * &lt;br /&gt;
            * &lt;p&gt;
            * Syncfusion is the enterprise technology partner of choice for Windows development
            * &lt;/p&gt;
            * &lt;/div&gt;  
            * &lt;div id="defaultradialmenu"&gt;
            * &lt;ul&gt;
            * &lt;li data-ej-imagename="social.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="social"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="music.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="music"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="direction.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="direction"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="message.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="message"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="browser.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="browser"&gt;&lt;/li&gt;
            * &lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function () {
            * $("#defaultradialmenu").ejmRadialMenu({ "backImageClass":"e-m-backimage" });	
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the Radialmenu backImageClass, after initialization:
            * &lt;script&gt;
            * // Gets the backImageClass API.		
            * $("#defaultradialmenu").ejmRadialMenu ("option", "backImageClass");			
            * // Sets the backImageClass API
            * $("#defaultradialmenu").ejmRadialMenu ("option", "backImageClass", "e-m-backimage");            
            * &lt;/script&gt;
            * @memberof ejmRadialMenu
            * @instance
            */
            backImageClass: "e-m-backimage",
            /**    
            * Event triggers when the touch end happens.
            * @event
            * @name ejmRadialMenu#touchEnd 	
            * @param {Object} argument Event parameters from Radialmenu     
            * @param {boolean} argument.cancel if the event should be canceled; otherwise, false.
            * @param {Object} argument.model returns the Radialmenu model
            * @param {string} argument.type returns the name of the event
            * @param {object} argument.item returns the item of element
            * @param {String} argument.itemName returns the name of item
            * @example 
            * &lt;div &gt;
            * &lt;br /&gt;
            * &lt;p&gt;
            * Syncfusion is the enterprise technology partner of choice for Windows development
            * &lt;/p&gt;
            * &lt;/div&gt;  
            * &lt;div id="defaultradialmenu" data-role="ejmradialmenu" data-ej-touchend="touchend" 
            * &gt;
            * &lt;ul&gt;
            * &lt;li data-ej-imagename="social.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="social"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="music.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="music"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="direction.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="direction"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="message.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="message"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="browser.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="browser"&gt;&lt;/li&gt;
            * &lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt; 
            * // TouchEnd event for Radialmenu  
            * function touchend(args){ //handle the event
            * }
            * &lt;/script&gt;
            * @example 
            * //TouchEnd event for Radialmenu
            * &lt;div &gt;
            * &lt;br /&gt;
            * &lt;p&gt;
            * Syncfusion is the enterprise technology partner of choice for Windows development
            * &lt;/p&gt;
            * &lt;/div&gt;  
            * &lt;div id="defaultradialmenu"&gt;
            * &lt;ul&gt;
            * &lt;li data-ej-imagename="social.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="social"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="music.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="music"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="direction.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="direction"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="message.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="message"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="browser.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="browser"&gt;&lt;/li&gt;
            * &lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $("#defaultradialmenu").ejmRadialMenu({
            *   touchend: function (args) { //handle the event
            * }
            * });         
            * &lt;/script&gt;
            * @memberof ejmRadialMenu
            * @instance
            */
            touchEnd: null,
            /**    
            * Event triggers when the touch start happens.
            * @event
            * @name ejmRadialMenu#touchStart 	
            * @param {Object} argument Event parameters from Radialmenu     
            * @param {boolean} argument.cancel if the event should be canceled; otherwise, false.
            * @param {Object} argument.model returns the Radialmenu model
            * @param {string} argument.type returns the name of the event
            * @param {object} argument.item returns the item of element
            * @param {String} argument.itemName returns the name of item
            * @example 
            * &lt;div &gt;
            * &lt;br /&gt;
            * &lt;p&gt;
            * Syncfusion is the enterprise technology partner of choice for Windows development
            * &lt;/p&gt;
            * &lt;/div&gt;  
            * &lt;div id="defaultradialmenu" data-role="ejmradialmenu" data-ej-touchstart="touchstart" 
            * &gt;
            * &lt;ul&gt;
            * &lt;li data-ej-imagename="social.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="social"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="music.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="music"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="direction.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="direction"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="message.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="message"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="browser.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="browser"&gt;&lt;/li&gt;
            * &lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt; 
            * // touchStart event for Radialmenu  
            * function touchStart(args){ //handle the event
            * }
            * &lt;/script&gt;
            * @example 
            * //touchStart event for Radialmenu
            * &lt;div &gt;
            * &lt;br /&gt;
            * &lt;p&gt;
            * Syncfusion is the enterprise technology partner of choice for Windows development
            * &lt;/p&gt;
            * &lt;/div&gt;  
            * &lt;div id="defaultradialmenu"&gt;
            * &lt;ul&gt;
            * &lt;li data-ej-imagename="social.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="social"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="music.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="music"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="direction.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="direction"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="message.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="message"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="browser.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="browser"&gt;&lt;/li&gt;
            * &lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $("#defaultradialmenu").ejmRadialMenu({
            *   touchStart: function (args) { //handle the event
            * }
            * });         
            * &lt;/script&gt;
            * @memberof ejmRadialMenu
            * @instance
            */
            touchStart: null,
            /**    
            * Event triggers when we select an item.
            * @event
            * @name ejmRadialMenu#select 	
            * @param {Object} argument Event parameters from Radialmenu     
            * @param {boolean} argument.cancel if the event should be canceled; otherwise, false.
            * @param {Object} argument.model returns the Radialmenu model
            * @param {string} argument.type returns the name of the event
            * @param {object} argument.item returns the item of element
            * @param {String} argument.itemName returns the name of item
            * @example 
            * &lt;div &gt;
            * &lt;br /&gt;
            * &lt;p&gt;
            * Syncfusion is the enterprise technology partner of choice for Windows development
            * &lt;/p&gt;
            * &lt;/div&gt;  
            * &lt;div id="defaultradialmenu" data-role="ejmradialmenu" data-ej-select="select" 
            * &gt;
            * &lt;ul&gt;
            * &lt;li data-ej-imagename="social.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="social"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="music.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="music"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="direction.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="direction"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="message.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="message"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="browser.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="browser"&gt;&lt;/li&gt;
            * &lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt; 
            * // select event for Radialmenu  
            * function select(args){ //handle the event
            * }
            * &lt;/script&gt;
            * @example 
            * //select event for Radialmenu
            * &lt;div &gt;
            * &lt;br /&gt;
            * &lt;p&gt;
            * Syncfusion is the enterprise technology partner of choice for Windows development
            * &lt;/p&gt;
            * &lt;/div&gt;  
            * &lt;div id="defaultradialmenu"&gt;
            * &lt;ul&gt;
            * &lt;li data-ej-imagename="social.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="social"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="music.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="music"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="direction.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="direction"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="message.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="message"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="browser.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="browser"&gt;&lt;/li&gt;
            * &lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $("#defaultradialmenu").ejmRadialMenu({
            *   select: function (args) { //handle the event
            * }
            * });         
            * &lt;/script&gt;
            * @memberof ejmRadialMenu
            * @instance
            */
            select: null,
            /**		
            * Changes the Position of the control.See {@link Position }
            * @default rightcenter
            * @type {enum}
            * @example 
            * //Set the position property in unobtrusive way.
            * &lt;div &gt;
            * &lt;br /&gt;
            * &lt;p&gt;
            * Syncfusion is the enterprise technology partner of choice for Windows development
            * &lt;/p&gt;
            * &lt;/div&gt;  
            * &lt;div id="defaultradialmenu" data-role="ejmradialmenu" data-ej-position="rightcenter" 
            * &gt;
            * &lt;ul&gt;
            * &lt;li data-ej-imagename="social.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="social"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="music.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="music"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="direction.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="direction"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="message.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="message"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="browser.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="browser"&gt;&lt;/li&gt;
            * &lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * // Set Radialmenu position on initialization. 
            * //To set position API value 
            * &lt;div &gt;
            * &lt;br /&gt;
            * &lt;p&gt;
            * Syncfusion is the enterprise technology partner of choice for Windows development
            * &lt;/p&gt;
            * &lt;/div&gt;  
            * &lt;div id="defaultradialmenu"&gt;
            * &lt;ul&gt;
            * &lt;li data-ej-imagename="social.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="social"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="music.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="music"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="direction.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="direction"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="message.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="message"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="browser.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="browser"&gt;&lt;/li&gt;
            * &lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function () {
            * $("#defaultradialmenu").ejmRadialMenu({ "position":"rightcenter" });	
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the Radialmenu position, after initialization:
            * &lt;script&gt;
            * // Gets the position API value.		
            *  $("#defaultradialmenu").ejmRadialMenu ("option", "position");			
            * // Sets the position API
            * $("#defaultradialmenu").ejmRadialMenu ("option", "position", "rightcenter");            
            * &lt;/script&gt;
            * @memberof ejmRadialMenu
            * @instance
            */
            position: "rightcenter",
            /**		
            * Specifies the theme. See {@link Theme}
            * @default auto
            * @type {enum}
            * @example 
            * //Set the theme property in unobtrusive way.
            * &lt;div &gt;
            * &lt;br /&gt;
            * &lt;p&gt;
            * Syncfusion is the enterprise technology partner of choice for Windows development
            * &lt;/p&gt;
            * &lt;/div&gt;  
            * &lt;div id="defaultradialmenu" data-role="ejmradialmenu" data-ej-theme="auto"
            * &gt;
            * &lt;ul&gt;
            * &lt;li data-ej-imagename="social.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="social"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="music.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="music"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="direction.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="direction"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="message.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="message"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="browser.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="browser"&gt;&lt;/li&gt;
            * &lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * // Set Radialmenu theme on initialization. 
            * //To set theme API value 
            * &lt;div &gt;
            * &lt;br /&gt;
            * &lt;p&gt;
            * Syncfusion is the enterprise technology partner of choice for Windows development
            * &lt;/p&gt;
            * &lt;/div&gt;  
            * &lt;div id="defaultradialmenu"&gt;
            * &lt;ul&gt;
            * &lt;li data-ej-imagename="social.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="social"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="music.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="music"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="direction.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="direction"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="message.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="message"&gt;&lt;/li&gt;
            * &lt;li data-ej-imagename="browser.png" data-ej-imagepath="../themes/sample/radialmenu"
            * data-ej-windows-text="browser"&gt;&lt;/li&gt;
            * &lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function () {
            * $("#defaultradialmenu").ejmRadialMenu({ "theme":ej.mobile.RenderMode.Auto });	
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the Radialmenu renderMode, after initialization:
            * &lt;script&gt;
            * // Gets the theme API value.		
            *  $("#defaultradialmenu").ejmRadialMenu ("option", "theme");			
            * // Sets the theme API
            * $("#defaultradialmenu").ejmRadialMenu ("option", "theme", "ej.mobile.Theme.Auto");            
            * &lt;/script&gt;
            * @memberof ejmRadialMenu
            * @instance
            */
            theme: "auto",
            /**     
            * Section for windows rendermode specific functionalities.                      
            * @memberof ejmRadialMenu
            * @instance
            */
            windows: {
                /**		
                * Specifies whether to render the Radial Menu based on the windowsphone's current accent color and device theme.
                * @default false
                * @type {boolean}
                * @alias ejmRadialMenu#windows->renderDefault
                * @example 
                * //Set the windows renderDefault property in unobtrusive way.
                * &lt;div &gt;
                * &lt;br /&gt;
                * &lt;p&gt;
                * Syncfusion is the enterprise technology partner of choice for Windows development
                * &lt;/p&gt;
                * &lt;/div&gt;  
                * &lt;div id="defaultradialmenu" data-role="ejmradialmenu" data-ej-windows-renderdefault="true"
                * &gt;
                * &lt;ul&gt;
                * &lt;li data-ej-imagename="social.png" data-ej-imagepath="../themes/sample/radialmenu"
                * data-ej-windows-text="social"&gt;&lt;/li&gt;
                * &lt;li data-ej-imagename="music.png" data-ej-imagepath="../themes/sample/radialmenu"
                * data-ej-windows-text="music"&gt;&lt;/li&gt;
                * &lt;li data-ej-imagename="direction.png" data-ej-imagepath="../themes/sample/radialmenu"
                * data-ej-windows-text="direction"&gt;&lt;/li&gt;
                * &lt;li data-ej-imagename="message.png" data-ej-imagepath="../themes/sample/radialmenu"
                * data-ej-windows-text="message"&gt;&lt;/li&gt;
                * &lt;li data-ej-imagename="browser.png" data-ej-imagepath="../themes/sample/radialmenu"
                * data-ej-windows-text="browser"&gt;&lt;/li&gt;
                * &lt;/ul&gt;
                * &lt;/div&gt;
                * @example 
                * // Set Radialmenu windows renderDefault on initialization. 
                * //To set windows renderDefault API value 
                * &lt;div &gt;
                * &lt;br /&gt;
                * &lt;p&gt;
                * Syncfusion is the enterprise technology partner of choice for Windows development
                * &lt;/p&gt;
                * &lt;/div&gt;  
                * &lt;div id="defaultradialmenu"&gt;
                * &lt;ul&gt;
                * &lt;li data-ej-imagename="social.png" data-ej-imagepath="../themes/sample/radialmenu"
                * data-ej-windows-text="social"&gt;&lt;/li&gt;
                * &lt;li data-ej-imagename="music.png" data-ej-imagepath="../themes/sample/radialmenu"
                * data-ej-windows-text="music"&gt;&lt;/li&gt;
                * &lt;li data-ej-imagename="direction.png" data-ej-imagepath="../themes/sample/radialmenu"
                * data-ej-windows-text="direction"&gt;&lt;/li&gt;
                * &lt;li data-ej-imagename="message.png" data-ej-imagepath="../themes/sample/radialmenu"
                * data-ej-windows-text="message"&gt;&lt;/li&gt;
                * &lt;li data-ej-imagename="browser.png" data-ej-imagepath="../themes/sample/radialmenu"
                * data-ej-windows-text="browser"&gt;&lt;/li&gt;
                * &lt;/ul&gt;
                * &lt;/div&gt;
                * &lt;script&gt;
                * $(function () {
                * $("#defaultradialmenu").ejmRadialMenu({ windows:{ renderDefault: true }});	
                * });
                * &lt;/script&gt;
                * @example 
                * //Get or set the Radialmenu windows renderDefault, after initialization:
                * &lt;script&gt;
                * // Gets the windows renderDefault API value.		
                *  $("#defaultradialmenu").ejmRadialMenu ("option", "windows.renderDefault");			
                * // Sets the windows renderDefault API
                * $("#defaultradialmenu").ejmRadialMenu ("option", "windows.renderDefault", true);            
                * &lt;/script&gt;
                * @memberof ejmRadialMenu
                * @instance	
                */
                "renderDefault": false
            }
        },
        // Datatypes of model variables
        dataTypes: {
            renderMode: "enum",
            theme: "enum",
            position: "enum",
            windows: { "renderDefault": "boolean" }
        },
        /**
        * Constructor function	
        * @private
        */
        _init: function () {
            this._initialization();
            this._setValues();
            this._renderRadial();
            this._wireEvents();
        },
        _setValues: function () {
            if (!(ej.browserInfo().name == "msie" && ej.browserInfo().version < 9)) {
                ej.setRenderMode(this);
                ej.setTheme(this);
                if (this.model.renderMode == "windows" && this.model.windows.renderDefault && ej.isMobile())
                    this.model.theme = "default";
                this._degDis = 0;
                this._totDis = 0;
                this._prefix = "e-m-";
                this._pos = this.model.position;
            }
        },
        /**
        * Render the Radialmenu control
        * @private
        */
        _renderRadial: function () {
            this._radial = ej.buildTag("div.e-m-radial e-m-abs " + this.model.imageClass + "").css({ "left": this._startXY - 25 + "px", "top": this._startXY - 25 + "px" });
            this._radialContainer = ej.buildTag("div.e-m-rel").css({ "height": this.model.width, "width": this.model.width });
            this.element.addClass("e-m-radialmenu e-m-overlow e-m-abs e-m-user-select e-m-" + this.model.renderMode + " e-m-" + this.model.theme + " e-m-radial" + this.model.position + "").append(this._radialContainer.append(this._radial));
            if (this._pos.charAt(0).toLowerCase() == "r")
                this._radialContainer.addClass("e-m-radialright").css("right", -this._startXY + "px");
            else
                this._radialContainer.css("left", -this._startXY + "px");
            this._posCenter();
            this["_" + this.model.renderMode + "RadialMenu"]();
        },
        /**
        * To wire the events for Radial Menu	
        * @private
        */
        _wireEvents: function () {
            this._touchStart = $.proxy(this._touchStartHandler, this);
            this._touchMove = $.proxy(this._touchMoveHandler, this);
            this._touchEnd = $.proxy(this._touchEndHandler, this);
            this._resize = $.proxy(this._resizeHandler, this);
            this._radialTouch = $.proxy(this._radialTouchHandler, this);
            this._documentTouch = $.proxy(this._documentTouchHandler, this);
            var evt = !ej.isTouchDevice() ? "resize" : "orientationchange";
            ej.listenEvents([this._radial, window, this._radialSVGDiv, $(document)], [ej.endEvent(), evt, ej.startEvent(), ej.endEvent()], [this._radialTouch, this._resize, this._touchStart, this._documentTouch], false);
        },
        /**
        * Render the ios7 Menu Item
        * @private
        */
        _ios7RadialMenu: function () {
            this._radialSVG = this._createSVGElement();
            this._menuItemsGroup = this._createGroupElement("menuitemsgroup");
            var childCircleGroup = this._createGroupElement();
            this._radialSVGDiv = ej.buildTag("div#radialsvgdiv.e-m-abs").css("height", this.model.width);
            this._radialMenuSVGDiv = ej.buildTag("div#radialmenusvgdiv.e-m-abs e-m-displaynone");
            var pointsVal = this._calculateRadialArc(this._itemCount, 1, 0.35, 0.2, 0.95);
            for (var i = 0; i < this._itemCount; i++) {
                var circleImgGroup = this._createGroupElement(),
                    currentEle = this.model.items[i];
                img = this._createImageElement(32, 32, currentEle, pointsVal.midx[i] - 16, pointsVal.midy[i] - 16);
                //var trans = "translate(" + (pointsVal.midx[i] - 16) + "," + (pointsVal.midy[i] - 16) + ")" + "rotate(0)";
                //img.setAttribute("transform", trans);
                var imgCircle = this._createCircleElement(pointsVal.midx[i], pointsVal.midy[i], 22, "e-m-radialdefault");
                this._menuItemsGroup.append(circleImgGroup.append(imgCircle).append(img));
                if (currentEle.items)
                    childCircleGroup.append(this._createCircleElement(pointsVal.midx[i], pointsVal.midy[i], 25, "e-m-chaildcircle"));
            }
            var radialCircle = this._createCircleElement(this._startXY, this._startXY, this._startXY, "e-m-radialcircle");
            this._radialContainer.append(this._radialSVGDiv.append(this._radialMenuSVGDiv.append(this._radialSVG.append(radialCircle).append(this._menuItemsGroup).append(childCircleGroup))));
        },
        /**
        * Render the ios7 Child Menu Item
        * @private
        */
        _ios7ChildRadialMenu: function (child, childcount, index) {
            this._degDis = 0;
            this._totDis = 0;
            this._radialChildSVG = this._createSVGElement();
            this._menuChildSVGDiv = ej.buildTag("div#menuchildsvgdiv.e-m-abs");
            if (this.model.enableAnimation) {
                this._radialMenuSVGDiv.removeClass("e-m-scalehide e-m-scaleshow").addClass("e-m-displaynone");
                this._menuChildSVGDiv.addClass("e-m-scaleshow");
            }
            else
                this._radialMenuSVGDiv.addClass("e-m-displaynone");
            this._radial.removeClass(this.model.imageClass).addClass("e-m-backarrow " + this.model.backImageClass + "");
            this._menuChildItemsGroup = this._createGroupElement("menuchilditemsgroup");
            var pointsVal = this._calculateRadialArc(childcount, 1, 0.35, 0.2, 0.95);
            for (var i = 0; i < childcount; i++) {
                var circleImgGroup = this._createGroupElement(),
                    currentEle = this.model.items[index].items[i],
                    img = this._createImageElement(32, 32, currentEle, pointsVal.midx[i] - 16, pointsVal.midy[i] - 16),
                    imgCircle = this._createCircleElement(pointsVal.midx[i], pointsVal.midy[i], 22, "e-m-radialdefault");
                this._menuChildItemsGroup.append(circleImgGroup.append(imgCircle).append(img));
            }
            var radialCircle = this._createCircleElement(this._startXY, this._startXY, this._startXY, "e-m-radialcircle");
            this._radialSVGDiv.append(this._menuChildSVGDiv.append(this._radialChildSVG.append(radialCircle).append(this._menuChildItemsGroup)));
        },
        /**
        * Render the Android Menu Item
        * @private
        */
        _androidRadialMenu: function () {
            this._radialSVG = this._createSVGElement();
            this._menuItemsGroup = this._createGroupElement("menuitemsgroup");
            this._androidArcGroup = this._createGroupElement("androidarcgroup");
            this._imageGroup = this._createGroupElement("imagegroup");
            this._imageGroup.attr("transform", "translate(-12,-12)");
            this._radialSVGDiv = ej.buildTag("div#radialsvgdiv.e-m-abs").css("height", this.model.width);
            this._radialMenuSVGDiv = ej.buildTag("div#radialmenusvgdiv.e-m-abs e-m-displaynone");
            var pointsVal = this._calculateRadialArc(this._itemCount, 1, 0.41, 0.65, null),
                pointsArcVal = this._calculateRadialArc(this._itemCount, 0.63, null, 0.95, null),
                childArc = this._createGroupElement();
            for (var i = 0; i < this._itemCount; i++) {
                var direction = "M" + " " + pointsVal.x1[i] + " " + pointsVal.y1[i] + " " + "A" + " " + pointsVal.radius + " " + pointsVal.radius + " " + "0" + " " + pointsVal.longArc[i] + " " + "1" + " " + pointsVal.x2[i] + " " + pointsVal.y2[i] + " " + "L" + " " + pointsVal.dEndX[i] + " " + pointsVal.dEndY[i] + " " + "A" + " " + pointsVal.dradius + " " + pointsVal.dradius + " " + "1" + " " + pointsVal.longArc[i] + " " + "0" + " " + pointsVal.dStartX[i] + " " + pointsVal.dStartY[i] + " " + "z",
                    arcDirection = "M" + " " + pointsArcVal.x1[i] + " " + pointsArcVal.y1[i] + " " + "A" + " " + pointsArcVal.radius + " " + pointsArcVal.radius + " " + "0" + " " + pointsArcVal.longArc[i] + " " + "1" + " " + pointsArcVal.x2[i] + " " + pointsArcVal.y2[i] + " " + "L" + " " + pointsArcVal.dEndX[i] + " " + pointsArcVal.dEndY[i] + " " + "A" + " " + pointsArcVal.dradius + " " + pointsArcVal.dradius + " " + "1" + " " + pointsArcVal.longArc[i] + " " + "0" + " " + pointsArcVal.dStartX[i] + " " + pointsArcVal.dStartY[i] + " " + "z",
                    currentEle = this.model.items[i],
                    arcPath = this._createPathElement(i, arcDirection, "e-m-radialarcdefault");
                this._imageGroup.append(this._createImageElement(25, 25, currentEle, pointsVal.midx[i], pointsVal.midy[i]));
                this._androidArcGroup.append(this._createPathElement(i, direction, "e-m-radialdefault"));
                childArc.append(arcPath);
                if (currentEle.items)
                    arcPath.setAttribute("class", "e-m-radialarcactive");
            }
            this._radialContainer.append(this._radialSVGDiv.append(this._radialMenuSVGDiv.append(this._radialSVG.append(this._menuItemsGroup.append(this._androidArcGroup).append(this._imageGroup).append(childArc)))));
        },
        /**
        * Render the Android Child Menu Item
        * @private
        */
        _androidChildRadialMenu: function (child, childcount, index) {
            this._degDis = 0;
            this._totDis = 0;
            this._radialChildSVG = this._createSVGElement();
            this._menuChildSVGDiv = ej.buildTag("div#menuchildsvgdiv.e-m-abs");
            if (this.model.enableAnimation) {
                setTimeout(function () { $("#radialmenusvgdiv.e-m-abs").removeClass("e-m-scalehide e-m-scaleshow").addClass("e-m-displaynone"); }, 150);
                this._menuChildSVGDiv.addClass("e-m-scaleshow");
            }
            else
                this._radialMenuSVGDiv.addClass("e-m-displaynone");
            this._radial.removeClass(this.model.imageClass).addClass("e-m-backarrow " + this.model.backImageClass + "");
            this._menuChildItemsGroup = this._createGroupElement("menuchilditemsgroup");
            this._androidChildArcGroup = this._createGroupElement("androidchildarcgroup");
            this._childImageGroup = this._createGroupElement("childimagegroup");
            this._childImageGroup.attr("transform", "translate(-12,-12)");
            var pointsVal = this._calculateRadialArc(childcount, 1, 0.41, 0.65, null),
                pointsArcVal = this._calculateRadialArc(childcount, 0.63, null, 0.95, null),
                childArc = this._createGroupElement();
            for (var i = 0; i < childcount; i++) {
                var direction = "M" + " " + pointsVal.x1[i] + " " + pointsVal.y1[i] + " " + "A" + " " + pointsVal.radius + " " + pointsVal.radius + " " + "0" + " " + pointsVal.longArc[i] + " " + "1" + " " + pointsVal.x2[i] + " " + pointsVal.y2[i] + " " + "L" + " " + pointsVal.dEndX[i] + " " + pointsVal.dEndY[i] + " " + "A" + " " + pointsVal.dradius + " " + pointsVal.dradius + " " + "1" + " " + pointsVal.longArc[i] + " " + "0" + " " + pointsVal.dStartX[i] + " " + pointsVal.dStartY[i] + " " + "z",
                    arcDirection = "M" + " " + pointsArcVal.x1[i] + " " + pointsArcVal.y1[i] + " " + "A" + " " + pointsArcVal.radius + " " + pointsArcVal.radius + " " + "0" + " " + pointsArcVal.longArc[i] + " " + "1" + " " + pointsArcVal.x2[i] + " " + pointsArcVal.y2[i] + " " + "L" + " " + pointsArcVal.dEndX[i] + " " + pointsArcVal.dEndY[i] + " " + "A" + " " + pointsArcVal.dradius + " " + pointsArcVal.dradius + " " + "1" + " " + pointsArcVal.longArc[i] + " " + "0" + " " + pointsArcVal.dStartX[i] + " " + pointsArcVal.dStartY[i] + " " + "z",
                    currentEle = this.model.items[index].items[i];
                this._childImageGroup.append(this._createImageElement(25, 25, currentEle, pointsVal.midx[i], pointsVal.midy[i]));
                this._androidChildArcGroup.append(this._createPathElement(i, direction, "e-m-radialdefault"));
                childArc.append(this._createPathElement(i, arcDirection, "e-m-radialarcdefault"));
            }
            this._radialSVGDiv.append(this._menuChildSVGDiv.append(this._radialChildSVG.append(this._menuChildItemsGroup.append(this._androidChildArcGroup).append(this._childImageGroup).append(childArc))));
        },
        /**
        * Render the Windows Menu Item
        * @private
        */
        _windowsRadialMenu: function () {
            this._renderRadialMenu();
        },
        /**
        * Render the Flat Menu Item
        * @private
        */
        _flatRadialMenu: function () {
            this._renderRadialMenu();
        },
        /**
        * To configure Menu Touch Start handler
        * @private
        */
        _touchStartHandler: function (evt) {
            evt.preventDefault();
            ej._touchStartPoints(evt, this);
            if (ej.isTouchDevice())
                evt = evt.touches ? evt.touches[0] : evt;
            this._startY = evt.clientY;
            this["_" + this.model.renderMode + "TouchStart"](evt);
            ej.listenEvents([this._radialSVGDiv, this._radialSVGDiv], [ej.moveEvent(), ej.endEvent()], [this._touchMove, this._touchEnd], false);
            ej.listenTouchEvent(this._radialSVGDiv, ej.startEvent(), this._touchStart, true);
        },
        _ios7TouchStart: function (evt) {
            var targetEle = $(evt.target);
            if (targetEle.attr("class") == "e-m-radialdefault" || evt.target.tagName == "image") {
                this._currentTarget = targetEle.parent();
                this._currentTarget.find("circle").attr("class", "e-m-radialactive");
                var index = this._currentTarget.index(),
                    data = this._childTarget ? { index: this._childIndex, childIndex: index } : { index: index, childIndex: null };
                if (this.model.touchStart)
                    this._trigger("touchStart", data);
            }
        },
        _androidTouchStart: function (evt) {
            var targetEle = $(evt.target),
                index = targetEle.index();
            if (targetEle.attr("class") == "e-m-radialdefault" || evt.target.tagName == "image") {
                var ele = this._childTarget ? this._androidChildArcGroup : this._androidArcGroup,
                    data = this._childTarget ? { index: this._childIndex, childIndex: index } : { index: index, childIndex: null };
                this._currentTarget = $(ele.children()[index]);
                this._currentTarget.attr("class", "e-m-radialactive");
                if (this.model.touchStart)
                    this._trigger("touchStart", data);
            }
        },
        _windowsTouchStart: function (evt) {
            this._windowsTouchStartAction(evt);
        },
        _flatTouchStart: function (evt) {
            this._windowsTouchStartAction(evt);
        },
        _windowsTouchStartAction: function (evt) {
            var targetEle = $(evt.target),
                index, text;
            if (targetEle.attr("class") == "e-m-itembgcolor" || targetEle.attr("class") == "e-m-default") {
                index = targetEle.index();
                text = !this._childTarget ? $(this._menuItemsGroup.children()[targetEle.index()]).text() : $(this._childItemsGroup.children()[targetEle.index()]).text();
                this._event = true;
            }
            else if (evt.target.tagName == "text" || evt.target.tagName == "image") {
                index = targetEle.parent().index();
                text = targetEle.parent().text();
                this._event = true;
            }
            else if (targetEle.attr("class") == "e-m-childdefault" || evt.target.tagName == "polygon") {
                index = parseInt(targetEle.attr("index"));
                this._windowsChild = this._childArcGroup.find('path[index=' + index + ']');
                this._windowsChild.attr("class", "e-m-active");
            }
            if (this._event) {
                var data = !this._childTarget ? { index: index, text: text } : { index: this._index, childIndex: index, text: text };
                this._currentTarget = !this._childTarget ? $(this._menuItemsArcPaths.children()[index]) : $(this._childItemsArcPaths.children()[index]);
                this._currentTarget.attr("class", "e-m-childdefault");
                if (this.model.touchStart)
                    this._trigger("touchStart", data);
                this._event = false;
            }
        },
        /**
        * To configure Menu Touch Move handler
        * @private
        */
        _touchMoveHandler: function (evt) {
            evt.preventDefault();
            if (ej.isTouchDevice())
                evt = evt.touches ? evt.touches[0] : evt;
            this._relativeDis = evt.clientY - this._startY;
            if (this._degDis != 0)
                this._relativeDis += this._totDis;
            this._degDis = this._pos.charAt(0).toLowerCase() == "r" ? -(this._relativeDis % 360) : this._relativeDis % 360;
            if (ej._isTouchMoved(evt, this)) {
                this["_" + this.model.renderMode + "TouchMove"](evt);
                this._move = true;
                this._currentTarget = null;
            }
        },
        _ios7TouchMoveAction: function () {
            this._childTarget ? this._radialChildSVG.css({ "transform-origin": "center", "transform": "rotate(" + this._degDis + "deg)" }) : this._radialSVG.css({ "transform-origin": "center", "transform": "rotate(" + this._degDis + "deg)" });
        },
        _windowsTouchMoveAction: function (evt) {
            if (this._windowsChild)
                this._windowsChild.attr("class", "e-m-childdefault");
            if (this._currentTarget)
                this._currentTarget.attr("class", "e-m-arcbgcolor");
            if (!this._childTarget) {
                this._radialSVG.css({ "transform-origin": "center", "transform": "rotate(" + this._degDis + "deg)" });
                this._radialChildSVG.css({ "transform-origin": "center", "transform": "rotate(" + this._degDis + "deg)" });
            }
            else
                this._menuChildSVG.css({ "transform-origin": "center", "transform": "rotate(" + this._degDis + "deg)" });
        },
        _ios7TouchMove: function () {
            this._ios7TouchMoveAction();
            if (this._currentTarget)
                this._currentTarget.find("circle").attr("class", "e-m-radialdefault");
        },
        _androidTouchMove: function () {
            this._ios7TouchMoveAction();
            if (this._currentTarget)
                this._currentTarget.attr("class", "e-m-radialdefault");
        },
        _windowsTouchMove: function (evt) {
            this._windowsTouchMoveAction(evt);
        },
        _flatTouchMove: function () {
            this._windowsTouchMoveAction();
        },
        /**
        * To configure Menu Touch End handler
        * @private
        */
        _touchEndHandler: function (evt) {
            this._totDis = this._relativeDis;
            this["_" + this.model.renderMode + "TouchEnd"](evt);
            ej.listenEvents([this._radialSVGDiv, this._radialSVGDiv], [ej.moveEvent(), ej.endEvent()], [this._touchMove, this._touchEnd], true);
            ej.listenTouchEvent(this._radialSVGDiv, ej.startEvent(), this._touchStart, false);
            this._move = false;
        },
        _ios7TouchEnd: function (evt) {
            this._ios7TouchEndAction(evt);
        },
        _androidTouchEnd: function (evt) {
            this._ios7TouchEndAction(evt);
        },
        _windowsTouchEnd: function (evt) {
            this._windowsTouchEndAction(evt);
        },
        _flatTouchEnd: function (evt) {
            this._windowsTouchEndAction(evt);
        },
        _ios7TouchEndAction: function (evt) {
            if (this._currentTarget) {
                var index = this._currentTarget.index();
                this.model.renderMode == "ios7" ? this._currentTarget.find("circle").attr("class", "e-m-radialdefault") : this._currentTarget.attr("class", "e-m-radialdefault");
                var childcount = 0;
                if (!this._childTarget) {
                    var child = this.model.items[index].items;
                    childcount = child ? child.length : 0;
                }
                if (childcount != 0) {
                    this["_" + this.model.renderMode + "ChildRadialMenu"](child, childcount, index);
                    this._childTarget = true;
                    this._childIndex = index;
                }
                else {
                    var data = this._childTarget ? { index: this._childIndex, childIndex: index } : { index: index, childIndex: null };
                    if (this.model.touchEnd)
                        this._trigger("touchEnd", data);
                    if (this.model.select)
                        this._trigger("select", data);
                }
            }
            this._currentTarget = null;
        },
        _windowsTouchEndAction: function (evt) {
            var targetEle = $(evt.target);
            if (targetEle.attr("class") == "e-m-active" || evt.target.tagName == "polygon") {
                this._childIndex = parseInt(targetEle.attr("index"));
                $(this._childArcGroup.find('path[index=' + this._childIndex + ']')).attr("class", "e-m-childdefault");
                this._renderRadialChildMenu(this._childIndex);
                this._childTarget = true;
            }
            if (this._currentTarget) {
                var index = this._currentTarget.index(),
                    data = this._childTarget ? { index: this._childIndex, childIndex: index } : { index: index, childIndex: null };
                if (this.model.touchEnd)
                    this._trigger("touchEnd", data);
                if (this.model.select)
                    this._trigger("select", data);
                this._currentTarget.attr("class", "e-m-arcbgcolor");
            }
            this._currentTarget = null;
        },
        _resizeHandler: function (evt) {
            this._posCenter();
        },
        _posCenter: function () {
            if (this._pos == "rightcenter" || this._pos == "leftcenter")
                this.element.css({ "top": (window.innerHeight / 2) - (this.model.width / 2) + "px" });
        },
        _radialTouchHandler: function (evt) {
            this["_" + this.model.renderMode + "RadialTouch"](evt);
        },
        _ios7RadialTouch: function (evt) {
            this._ios7RadialAction(evt);
        },
        _androidRadialTouch: function (evt) {
            this._ios7RadialAction(evt);
        },
        _windowsRadialTouch: function (evt) {
            this._windowsRadialAction(evt);
        },
        _flatRadialTouch: function (evt) {
            this._windowsRadialAction(evt);
        },
        _ios7RadialAction: function (evt) {
            if (this._radial.hasClass("e-m-backarrow")) {
                this._radial.removeClass("e-m-backarrow " + this.model.backImageClass + "").addClass(this.model.imageClass);
                if (this.model.enableAnimation) {
                    this._menuChildSVGDiv.removeClass("e-m-scaleshow").addClass("e-m-scalehide");
                    setTimeout(function () { $("#menuchildsvgdiv.e-m-abs").remove(); }, 150);
                    setTimeout(function () { $("#radialmenusvgdiv.e-m-abs").removeClass("e-m-scalehide e-m-displaynone").addClass("e-m-scaleshow"); }, 200);
                }
                else {
                    this._menuChildSVGDiv.remove();
                    this._radialMenuSVGDiv.removeClass("e-m-displaynone");
                }
                ej.listenEvents([this._radialSVGDiv, this._radialSVGDiv], [ej.moveEvent(), ej.endEvent()], [this._touchMove, this._touchEnd], true);
                ej.listenTouchEvent(this._radialSVGDiv, ej.startEvent(), this._touchStart, false);
            }
            else {
                if (this._radialMenuSVGDiv.hasClass("e-m-displaynone")) {
                    this.model.enableAnimation ? this._radialMenuSVGDiv.removeClass("e-m-displaynone e-m-radialhide").addClass("e-m-radialshow") : this._radialMenuSVGDiv.removeClass("e-m-displaynone");
                    ej.listenTouchEvent(this._radialSVGDiv, ej.startEvent(), this._touchStart, false);
                }
                else {
                    if (this.model.enableAnimation) {
                        this._radialMenuSVGDiv.removeClass("e-m-radialshow e-m-scaleshow").addClass("e-m-radialhide");
                        setTimeout(function () { $("#radialmenusvgdiv.e-m-abs").addClass("e-m-displaynone"); }, 160);
                    }
                    else
                        this._radialMenuSVGDiv.addClass("e-m-displaynone");
                    ej.listenEvents([this._radialSVGDiv, this._radialSVGDiv], [ej.moveEvent(), ej.endEvent()], [this._touchMove, this._touchEnd], true);
                }
            }
            this._degDis = 0;
            this._totDis = 0;
            this._childTarget = false;
            this._radialSVG.css("transform", "rotate(0deg)");
        },
        _windowsRadialAction: function (evt) {
            if (this._radial.hasClass("e-m-backarrow")) {
                this._radial.removeClass("e-m-backarrow " + this.model.backImageClass + "").addClass(this.model.imageClass);
                if (this.model.enableAnimation) {
                    this._menuChildSVGDiv.removeClass("e-m-scaleshow").addClass("e-m-scalehide");
                    setTimeout(function () { $("#menuchildsvgdiv.e-m-abs").remove(); }, 150);
                    setTimeout(function () { $("#radialchildsvgdiv.e-m-abs").removeClass("e-m-scalehide e-m-displaynone").addClass("e-m-scaleshow"); }, 200);
                }
                else {
                    this._menuChildSVGDiv.remove();
                    this._radialChildSVGDiv.removeClass("e-m-displaynone");
                }
                ej.listenEvents([this._radialSVGDiv, this._radialSVGDiv], [ej.moveEvent(), ej.endEvent()], [this._touchMove, this._touchEnd], true);
                ej.listenTouchEvent(this._radialSVGDiv, ej.startEvent(), this._touchStart, false);
            }
            else {
                if (this._radialCircleSVGDiv.hasClass("e-m-displaynone")) {
                    if (this.model.enableAnimation) {
                        this._radialCircleSVGDiv.removeClass("e-m-displaynone e-m-radialhide").addClass("e-m-radialshow");
                        this._radialChildSVGDiv.removeClass("e-m-displaynone e-m-radialhide").addClass("e-m-radialshow");
                    }
                    else {
                        this._radialCircleSVGDiv.removeClass("e-m-displaynone");
                        this._radialChildSVGDiv.removeClass("e-m-displaynone");
                    }
                    ej.listenTouchEvent(this._radialSVGDiv, ej.startEvent(), this._touchStart, false);
                }
                else {
                    if (this.model.enableAnimation) {
                        this._radialCircleSVGDiv.removeClass("e-m-radialshow").addClass("e-m-radialhide");
                        this._radialChildSVGDiv.removeClass("e-m-radialshow e-m-scaleshow").addClass("e-m-radialhide");
                        setTimeout(function () { $("#radialcirclesvgdiv.e-m-abs").addClass("e-m-displaynone"); $("#radialchildsvgdiv.e-m-abs").addClass("e-m-displaynone"); }, 160);
                    }
                    else {
                        this._radialCircleSVGDiv.addClass("e-m-displaynone");
                        this._radialChildSVGDiv.addClass("e-m-displaynone");
                    }
                    ej.listenEvents([this._radialSVGDiv, this._radialSVGDiv], [ej.moveEvent(), ej.endEvent()], [this._touchMove, this._touchEnd], true);
                }
            }
            this._degDis = 0;
            this._totDis = 0;
            this._childTarget = false;
            this._radialSVG.css("transform", "rotate(0deg)");
            this._radialChildSVG.css("transform", "rotate(0deg)");
        },
        _radialChildAnimate: function () {
            this._degDis = 0;
            this._totDis = 0;
            setTimeout(function () {
                $("#radialchildsvgdiv.e-m-abs").removeClass("e-m-scalehide e-m-scaleshow").addClass("e-m-displaynone");
            }, 150);
        },
        _documentTouchHandler: function (evt) {
            if ($($(evt.target).closest("div.e-m-rel")).length == 0 && !this._move) {
                this.menuHide();
                this._move = false;
            }
        },
        //public methods
        /**
        * To Show the redialmenu 
        * @return jQuery
        * @example 
        * &lt;div &gt;
        * &lt;br /&gt;
        * &lt;p&gt;
        * Syncfusion is the enterprise technology partner of choice for Windows development
        * &lt;/p&gt;
        * &lt;/div&gt;  
        * &lt;div id="defaultradialmenu"&gt;
        * &lt;ul&gt;
        * &lt;li data-ej-imagename="social.png" data-ej-imagepath="../themes/sample/radialmenu"
        * data-ej-windows-text="social"&gt;&lt;/li&gt;
        * &lt;li data-ej-imagename="music.png" data-ej-imagepath="../themes/sample/radialmenu"
        * data-ej-windows-text="music"&gt;&lt;/li&gt;
        * &lt;li data-ej-imagename="direction.png" data-ej-imagepath="../themes/sample/radialmenu"
        * data-ej-windows-text="direction"&gt;&lt;/li&gt;
        * &lt;li data-ej-imagename="message.png" data-ej-imagepath="../themes/sample/radialmenu"
        * data-ej-windows-text="message"&gt;&lt;/li&gt;
        * &lt;li data-ej-imagename="browser.png" data-ej-imagepath="../themes/sample/radialmenu"
        * data-ej-windows-text="browser"&gt;&lt;/li&gt;
        * &lt;/ul&gt;
        * &lt;/div&gt;
        * @example 
        * &lt;script&gt;
        * $("#defaultradialmenu").ejmRadialMenu ("show");
        * &lt;/script&gt;
        * @memberof ejmRadialMenu
        * @instance
        */
        show: function () {
            this.element.removeClass("e-m-displaynone");
        },
        /**
        * To hide the redialmenu
        * @return jQuery
        * @example 
        * &lt;div &gt;
        * &lt;br /&gt;
        * &lt;p&gt;
        * Syncfusion is the enterprise technology partner of choice for Windows development
        * &lt;/p&gt;
        * &lt;/div&gt;  
        * &lt;div id="defaultradialmenu"&gt;
        * &lt;ul&gt;
        * &lt;li data-ej-imagename="social.png" data-ej-imagepath="../themes/sample/radialmenu"
        * data-ej-windows-text="social"&gt;&lt;/li&gt;
        * &lt;li data-ej-imagename="music.png" data-ej-imagepath="../themes/sample/radialmenu"
        * data-ej-windows-text="music"&gt;&lt;/li&gt;
        * &lt;li data-ej-imagename="direction.png" data-ej-imagepath="../themes/sample/radialmenu"
        * data-ej-windows-text="direction"&gt;&lt;/li&gt;
        * &lt;li data-ej-imagename="message.png" data-ej-imagepath="../themes/sample/radialmenu"
        * data-ej-windows-text="message"&gt;&lt;/li&gt;
        * &lt;li data-ej-imagename="browser.png" data-ej-imagepath="../themes/sample/radialmenu"
        * data-ej-windows-text="browser"&gt;&lt;/li&gt;
        * &lt;/ul&gt;
        * &lt;/div&gt;
        * @example 
        * &lt;script&gt;
        * $("#defaultradialmenu").ejmRadialMenu ("hide");	
        * &lt;/script&gt;
        * @memberof ejmRadialMenu
        * @instance
        */
        hide: function () {
            this.element.addClass("e-m-displaynone");
        },
        /**
        * To hide the redialmenu items
        * @return jQuery
        * @example 
        * &lt;div &gt;
        * &lt;br /&gt;
        * &lt;p&gt;
        * Syncfusion is the enterprise technology partner of choice for Windows development
        * &lt;/p&gt;
        * &lt;/div&gt;  
        * &lt;div id="defaultradialmenu"&gt;
        * &lt;ul&gt;
        * &lt;li data-ej-imagename="social.png" data-ej-imagepath="../themes/sample/radialmenu"
        * data-ej-windows-text="social"&gt;&lt;/li&gt;
        * &lt;li data-ej-imagename="music.png" data-ej-imagepath="../themes/sample/radialmenu"
        * data-ej-windows-text="music"&gt;&lt;/li&gt;
        * &lt;li data-ej-imagename="direction.png" data-ej-imagepath="../themes/sample/radialmenu"
        * data-ej-windows-text="direction"&gt;&lt;/li&gt;
        * &lt;li data-ej-imagename="message.png" data-ej-imagepath="../themes/sample/radialmenu"
        * data-ej-windows-text="message"&gt;&lt;/li&gt;
        * &lt;li data-ej-imagename="browser.png" data-ej-imagepath="../themes/sample/radialmenu"
        * data-ej-windows-text="browser"&gt;&lt;/li&gt;
        * &lt;/ul&gt;
        * &lt;/div&gt;
        * @example 
        * &lt;script&gt;
        * $("#defaultradialmenu").ejmRadialMenu ("menuHide");
        * &lt;/script&gt;
        * @memberof ejmRadialMenu
        * @instance
        */
        menuHide: function () {
            if (this.model.renderMode != "windows" && this.model.renderMode != "flat") {
                if ($("#menuchildsvgdiv.e-m-abs").length != 0) {
                    this._radial.removeClass("e-m-backarrow " + this.model.backImageClass + "").addClass(this.model.imageClass);
                    this._childTarget = false;
                    if (this.model.enableAnimation) {
                        this._radialMenuSVGDiv.removeClass("e-m-radialshow e-m-radialhide e-m-scaleshow e-m-scalehide").addClass("e-m-displaynone");
                        this._menuChildSVGDiv.removeClass("e-m-scaleshow").addClass("e-m-radialhide");
                        setTimeout(function () { $("#menuchildsvgdiv.e-m-abs").removeClass("e-m-radialhide").remove(); }, 150);
                    }
                    else {
                        this._radialMenuSVGDiv.addClass("e-m-displaynone");
                        this._menuChildSVGDiv.remove();
                    }
                    ej.listenEvents([this._radialSVGDiv, this._radialSVGDiv], [ej.moveEvent(), ej.endEvent()], [this._touchMove, this._touchEnd], true);
                    ej.listenTouchEvent(this._radialSVGDiv, ej.startEvent(), this._touchStart, false);
                }
                else {
                    if (this.model.enableAnimation) {
                        this._radialMenuSVGDiv.removeClass("e-m-radialshow e-m-scaleshow").addClass("e-m-radialhide");
                        setTimeout(function () { $("#radialmenusvgdiv.e-m-abs").addClass("e-m-displaynone").removeClass("e-m-radialshow e-m-radialhide e-m-scaleshow e-m-scalehide"); }, 160);
                    }
                    else
                        this._radialMenuSVGDiv.addClass("e-m-displaynone");
                    ej.listenEvents([this._radialSVGDiv, this._radialSVGDiv], [ej.moveEvent(), ej.endEvent()], [this._touchMove, this._touchEnd], true);
                }
            }
            else {
                if ($("#menuchildsvgdiv.e-m-abs").length != 0) {
                    this._radial.removeClass("e-m-backarrow " + this.model.backImageClass + "").addClass(this.model.imageClass);
                    this._childTarget = false;
                    if (this.model.enableAnimation) {
                        this._radialCircleSVGDiv.removeClass("e-m-radialshow e-m-radialhide e-m-scaleshow e-m-scalehide").addClass("e-m-displaynone");
                        this._radialChildSVGDiv.removeClass("e-m-radialshow e-m-radialhide e-m-scaleshow e-m-scalehide").addClass("e-m-displaynone");
                        this._menuChildSVGDiv.removeClass("e-m-scaleshow").addClass("e-m-radialhide");
                        setTimeout(function () { $("#menuchildsvgdiv.e-m-abs").removeClass("e-m-radialhide").remove(); }, 150);
                    }
                    else {
                        this._radialCircleSVGDiv.addClass("e-m-displaynone");
                        this._radialChildSVGDiv.addClass("e-m-displaynone");
                        this._menuChildSVGDiv.remove();
                    }
                    ej.listenEvents([this._radialSVGDiv, this._radialSVGDiv], [ej.moveEvent(), ej.endEvent()], [this._touchMove, this._touchEnd], true);
                    ej.listenTouchEvent(this._radialSVGDiv, ej.startEvent(), this._touchStart, false);
                }
                else {
                    if (this.model.enableAnimation) {
                        this._radialCircleSVGDiv.removeClass("e-m-radialshow").addClass("e-m-radialhide");
                        this._radialChildSVGDiv.removeClass("e-m-radialshow e-m-scaleshow").addClass("e-m-radialhide");
                        setTimeout(function () {
                            $("#radialcirclesvgdiv.e-m-abs").addClass("e-m-displaynone").removeClass("e-m-radialshow e-m-radialhide e-m-scaleshow e-m-scalehide");
                            $("#radialchildsvgdiv.e-m-abs").addClass("e-m-displaynone").removeClass("e-m-radialshow e-m-radialhide e-m-scaleshow e-scalehide");
                        }, 160);
                    }
                    else {
                        this._radialCircleSVGDiv.addClass("e-m-displaynone");
                        this._radialChildSVGDiv.addClass("e-m-displaynone");
                    }
                    ej.listenEvents([this._radialSVGDiv, this._radialSVGDiv], [ej.moveEvent(), ej.endEvent()], [this._touchMove, this._touchEnd], true);
                }
            }
        }
    });
    /**
    * Enum for Position 
    * @enum {string}
    * @global
    */
    ej.mobile.RadialMenu.Position = {
        /**
        Enum for RightCenter Position*/
        RightCenter: "rightcenter",
        /**
        Enum for RightTop Position*/
        RightTop: "righttop",
        /**
        Enum for RightBottom Position*/
        RightBottom: "rightbottom",
        /**
        Enum for LeftCenter Position*/
        LeftCenter: "leftcenter",
        /**
        Enum for LeftTop Position*/
        LeftTop: "lefttop",
        /**
        Enum for LeftBottom Position*/
        LeftBottom: "leftbottom"
    };
    $.extend(true, ej.mobile.RadialMenu.prototype, ej.RadialMenuBase.prototype);
})(jQuery, Syncfusion);