﻿/**
* @fileOverview Plugin to style the Html RadioButton elements
* @copyright Copyright Syncfusion Inc. 2001 - 2014. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/

(function ($, ej, undefined) {
    // ejmRadioButton is the plugin name 
    // "ej.mobile.RadioButton" is "namespace.className" will hold functions and properties 
    /**
    * @namespace ej
    * @class ejmRadioButton
    * @requires jQuery
    * @requires ej.mobile.application
    * @requires ej.core
    * @requires ej.unobtrusive
    * @requires ej.mobile.core
    * @requires ej.data
    * @requires ej.touch   
    * @classdesc Custom Design for Html RadioButton control.
    * @example 
    * // Create radiobutton control in Unobtrusive way.
    * &lt;input type="radio" id="radbtn" data-role="ejmradiobutton" /&gt;<br>
    * @example 
    * &lt;input type="radio" id="radbtn" /&gt;<br>
    * &lt;script&gt; 
    *   // Create RadioButton  
    *   $("#radbtn").ejmRadioButton(); 
    * &lt;/script&gt;
    */

    ej.widget("ejmRadioButton", "ej.mobile.RadioButton", {
        _setFirst: true,

        _rootCSS: "e-m-radbtn",
        // default model
        defaults: {

            /**    
            * Event triggers when the touch end happens in the RadioButton.
            * @event
            * @name ejmRadioButton#touchEnd 	
            * @param {Object} argument Event parameters from RadioButton     
            * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
            * @param {Object} argument.model returns the RadioButton model
            * @param {boolean} argument.type returns the name of the event
            * @param {boolean} argument.value returns the current element associated value
            * @param {boolean} argument.isChecked  returns the status of the element
            * @example 
            * // Define the touchend event in Unobtrusive way.
            * &lt;input type="radio" id="radbtn" data-role="ejmradiobutton" data-ej-touchend="touchend" /&gt;<br>
            * &lt;script&gt; 
            * // touchEnd event for RadioButton            
            * function touchend(args){ 
            * //handle the event here
            * }
            * &lt;/script&gt;
            * @example 
            * // touchEnd event for RadioButton
            * &lt;input type="radio" id="radbtn" data-role="ejmradiobutton"/&gt;<br>
            * &lt;script&gt; 
            * $("#radbtn").ejmRadioButton({
            *   touchEnd: function (args) { 
            *       //handle the event 
            *   }
            *});     
            * &lt;/script&gt; 
            * @memberof ejmRadioButton
            * @instance
            */
            touchEnd: null,

            /**    
            * event triggers when the touch start happens in the RadioButton.
            * @event
            * @name ejmRadioButton#touchStart 	
            * @param {Object} argument Event parameters from RadioButton     
            * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
            * @param {Object} argument.model returns the RadioButton model
            * @param {boolean} argument.type returns the name of the event
            * @param {boolean} argument.value returns the current element associated value
            * @param {boolean} argument.isChecked  returns the status of the element
            * @example 
            * // Define the touchstart event in Unobtrusive way.
            * &lt;input type="radio" id="radbtn" data-role="ejmradiobutton" data-ej-touchstart="touchstart" /&gt;<br>
            * &lt;script&gt; 
            *   // touchStart event for RadioButton 
            *   function touchstart(args){ 
            *       //handle the event 
            *   }
            * &lt;/script&gt;
            * @example 
            * // touchStart event for RadioButton
            * &lt;input type="radio" id="radbtn" data-role="ejmradiobutton"/&gt;<br>
            * &lt;script&gt; 
            * $("#radbtn").ejmRadioButton({
            *   touchStart: function (args) { 
            *         //handle the event 
            *   }
            * });           
            * &lt;/script&gt; 
            * @memberof ejmRadioButton
            * @instance
            */
            touchStart: null,

            /**    
            * Event triggers when the selection in radiobutton is changed.
            * @event
            * @name ejmRadioButton#change 	
            * @param {Object} argument Event parameters from RadioButton     
            * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
            * @param {Object} argument.model returns the RadioButton model
            * @param {boolean} argument.type returns the name of the event
            * @param {boolean} argument.value returns the current element associated value
            * @param {boolean} argument.isChecked  returns the status of the element
            * @example 
            * // Define the change event in Unobtrusive way.
            * &lt;input type="radio" id="radbtn" data-role="ejmradiobutton" data-ej-change="change" /&gt;<br>
            * &lt;script&gt; 
            * // change event for RadioButton            
            * function change(args){ 
            * //handle the event here
            * }
            * &lt;/script&gt;
            * @example 
            * // change event for RadioButton
            * &lt;input type="radio" id="radbtn" data-role="ejmradiobutton"/&gt;<br>
            * &lt;script&gt; 
            * $("#radbtn").ejmRadioButton({
            *  change: function (args) { 
            *       //handle the event 
            *   }
            *});     
            * &lt;/script&gt; 
            * @memberof ejmRadioButton
            * @instance
            */
            change: null,

            /**		
            * Specifies the checked attribute.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the checked property in Unobtrusive way.
            * &lt;input type="radio" id="radbtn" data-role="ejmradiobutton" data-ej-checked=false /&gt;<br>
            * @example 
            * // To set checked API value during initialization  
            * &lt;input type="radio" id="radbtn"/&gt;<br>
            * &lt;script&gt;
            *  $("#radbtn").ejmRadioButton({ checked:  true });					
            * &lt;/script&gt;
            * @example 
            * // Get or set the checked API, after initialization:<br>
            *  //Gets the checked value  
            *  $("#radbtn").ejmRadioButton("option", "checked");<br>			
            *  //Sets the checked value 
            *  $("#radbtn").ejmRadioButton("option", "checked",  false );  
            * @memberof ejmRadioButton
            * @instance
            */
            checked: false,

            /**		
            * Changes the rendering mode. See {@link RenderMode}
            * @default  auto
            * @type {enum}
            * @example 
            * // Set the renderMode property in Unobtrusive way.
            * &lt;input type="radio" id="radbtn" data-role="ejmradiobutton" data-ej-rendermode="auto" /&gt;<br>
            * @example 
            * // Set RadioButton rendermode on initialization. 
            * // To set renderMode API value 
            * &lt;input type="radio" id="radbtn"/&gt;<br>
            * &lt;script&gt;
            *$(function() {
            * $("#radbtn").ejmRadioButton ({ renderMode: ej.mobile.RenderMode.Auto });		
            *});
            * &lt;/script&gt;
            * @example 
            * // Get or set the renderMode property, after initialization:<br>
            *   // Gets the renderMode API value.		
            *   $("#radbtn").ejmRadioButton ("option", "renderMode");			
            *   // Sets the renderMode API
            *   $("#radbtn").ejmRadioButton ("option", "renderMode", ej.mobile.RenderMode.Auto); 
            * @memberof ejmRadioButton
            * @instance
            */

            renderMode: "auto",
            /**		
            * Changes the theme. See {@link Theme}
            * @default auto
            * @type {enum}
            * @example 
            * //Set the theme property in Unobtrusive way.
            * &lt;input type="radio" id="radbtn" data-role="ejmradiobutton" data-ej-theme="auto" /&gt;<br>
            * @example 
            * // Set theme property on initialization. 
            *   // To set theme API value 
            * &lt;input type="radio" id="radbtn"/&gt;<br>
            * &lt;script&gt;
            * $(function(){
            *   $("#radbtn").ejmRadioButton ({ theme: ej.mobile.Theme.Auto });			
            * });
            * &lt;/script&gt;
            * @example 
            * // Get or set the theme API value, after initialization:<br>
            *   // Gets the theme API value.		
            *   $("#radbtn").ejmRadioButton ("option", "theme");			
            *   // Sets the theme API
            *   $("#radbtn").ejmRadioButton ("option", "theme", ej.mobile.Theme.Auto);
            * @memberof ejmRadioButton
            * @instance
            */
            theme: "auto",

            /**		
            * Specifies whether the control is enabled or not.
            * @default true
            * @type {boolean}
            * @example 
            * //Set the enabled property in Unobtrusive way.
            * &lt;input type="radio" id="radbtn" data-role="ejmradiobutton" data-ej-enabled=true /&gt;<br>
            * @example 
            * // Enabled RadioButton on initialization. 
            *   // To set width API value 
            * &lt;input type="radio" id="radbtn"/&gt;<br>
            * &lt;script&gt;
            * 	$("#radbtn").ejmRadioButton ({ enabled: true });			
            * &lt;/script&gt;
            * @example 
            * // Get or set the enabled state, after initialization:<br>
            *   // Gets the Enabled API value.		
            *	$("#radbtn").ejmRadioButton ("option", "enabled");			
            *   // Sets the Enabled API
            *	$("#radbtn").ejmRadioButton ("option", "enabled", true);
            * @memberof ejmRadioButton
            * @instance
            */
            enabled: true,

            /**		
            * Specifies the text content.
            * @default ""
            * @type {string}
            * @example 
            * // Set the text property in Unobtrusive way.
            * &lt;input type="radio" id="radbtn" data-role="ejmradiobutton" data-ej-text="RadioButton" /&gt;<br>
            * @example 
            * // To set text API value 
            * &lt;input type="radio" id="radbtn"/&gt;<br>
            * &lt;script&gt;
            *   $("#radbtn").ejmRadioButton({ text: "Hello World"});		 
            * &lt;/script&gt;
            * @example 
            * // Get or set the text API, after initialization:
            *   // Gets the text value  
            *   $("#radbtn").ejmRadioButton("option", "text");			
            *   // Sets the text value 
            *   $("#radbtn").ejmRadioButton("option", "text", "Hello World" ); 
            * @memberof ejmRadioButton
            * @instance
            */
            text: "",
            /**		
            * Saves current model value to browser cookies for state maintains. While refreshing the page retains the model value apply from browser cookies.
            * @default false
            * @type {boolean}
            * @example 
            * // Set the enablePersistence property in Unobtrusive way.
            * &lt;input type="radio" id="radbtn" data-role="ejmradiobutton" data-ej-enablepersistence=true /&gt;<br>
            * @example 
            * // To set enablePersistence API value 
            * &lt;input type="radio" id="radbtn"/&gt;<br>
            * &lt;script&gt;
            *   $("#radbtn").ejmRadioButton({ enablePersistence: true});		 
            * &lt;/script&gt;
            * @example 
            * // Get or set the enablePersistence API, after initialization:
            *   // Gets the enablePersistence value  
            *   $("#radbtn").ejmRadioButton("option", "enablePersistence");			
            *   // Sets the enablePersistence value 
            *   $("#radbtn").ejmRadioButton("option", "enablePersistence", true ); 
            * @memberof ejmRadioButton
            * @instance
            */
            enablePersistence: false
        },

        dataTypes: {
            renderMode: "enum",
            checked: "boolean",
            theme: "enum",
            enabled: "boolean",
            enablePersistence: "boolean"
        },

        /**
        * Create the RadioButton widget
        * @private
        */
        // constructor function
        _init: function () {
            this._renderControl();
            this._wireEvents(false);
        },

        /**
        * Render Section For RadioButton control	
        * @private
        */
        _renderControl: function () {
            ej.setRenderMode(this);
            ej.setTheme(this);
            this._wrapper = ej.buildTag("div.e-m-radbtn e-m-" + this.model.renderMode + " e-m-" + this.model.theme);
            $(this.element).attr("style", "display:none").addClass("e-m-input");
            this.element.wrap(this._wrapper);
            this._wrapper = this.element.parent();
            var div = ej.buildTag("div.e-m-rootel");
            this._innerDiv = ej.buildTag("div.e-m-innerel");
            if (this.model.checked) {
                this.element.attr("checked", true);
                this._innerDiv.addClass("e-m-state-active");
            }
            div.append(this._innerDiv);
            this._wrapper.append(div);
            this._setEnabled(this.model.enabled);
            this._setTextWrapper(this.model.text);
        },

        /**
        * Delegate for RadioButton control		
        * @private
        */
        _createDelegates: function () {
            this._touchStartHandler = $.proxy(this._touchStart, this);
            this._touchStopHandler = $.proxy(this._touchEnd, this);
            this._active = $.proxy(this._active, this);
            this._removeActive = $.proxy(this._removeActive, this);
            this._touchMoveHandler = $.proxy(this._removeActive, this);
        },

        /**
        * Wiring the events to RadioButton control		
        * @private
        */
        _wireEvents: function (remove) {
            this._createDelegates();
            ej.listenEvents([this._wrapper, this._wrapper, this._wrapper, this._wrapper, this._wrapper], ["click", "click", ej.startEvent(), ej.endEvent(), ej.moveEvent()], [this._touchStartHandler, this._touchStopHandler, this._active, this._removeActive, this._touchMoveHandler], remove);
        },

        /**
        * Section for handling the touchstart event
        * @private
        */
        _touchStart: function (evt) {
            var data = { value: this.element.val(), isChecked: this.model.checked };
            if (this.model.touchStart)
                this._trigger("touchStart", data);
            var curname = this.element.attr('name');
            var input = $('input[name=' + curname + ']:radio');
            $.each(input, function (i, obj) {
                $(obj).parent().find(".e-m-innerel").removeClass("e-m-state-active");
                $(obj).attr('checked', false);
            });
            this._wrapper.find(".e-m-innerel").addClass("e-m-state-active");
            this.element.attr("checked", true);
            if (this.model.change)
                this._trigger("change", data);
        },


        /**
        * To configure RadioButton active state		
        * @private
        */
        _active: function () {
            if (this.model.renderMode == "android")
                this._wrapper.find(".e-m-rootel").addClass("e-m-state-glow");
            this._wrapper.find(".e-m-rootel").addClass("e-m-active");
            var data = { value: this.element.val(), isChecked: this.model.checked };
            if (this.model.touchStart)
                this._trigger("touchStart", data);
        },

        /**
        * Section for handling the touchend event		
        * @private
        */
        _touchEnd: function (e) {
            var data = { value: this.element.val(), isChecked: this.model.checked };
            if (this.model.touchEnd)
                this._trigger("touchEnd", data);
        },

        /**
        * To remove RadioButton touch move state		
        * @private
        */
        _removeActive: function (e) {
            if (this.model.renderMode == "android")
                this._wrapper.find(".e-m-rootel").removeClass("e-m-state-glow");
            this._wrapper.find(".e-m-rootel").removeClass("e-m-active");
        },

        /**
        * To configure RadioButton textwrapper		
        * @private
        */
        _setTextWrapper: function (val) {
            if (val != "") {
                this.txtSpan = ej.buildTag("div.e-m-radtext", val);
                this._wrapper.append(this.txtSpan);
            }
        },

        /**
        * To configure RadioButton text	
        * @private
        */
        _setText: function (val) {
            if (!this.txtSpan) {
                this._setTextWrapper(val);
            } else {
                this.txtSpan.html(val);
            }
        },

        /**
        * To configure the Enable status of the RadioButton		
        * @private
        */
        _setEnabled: function (val) {
            this.model.enabled = val;
            this._wrapper[val ? "removeClass" : "addClass"]("e-m-state-disabled");
        },

        /**
        * To configure the theme of the RadioButton		
        * @private
        */
        _setTheme: function (theme) {
            ej.setTheme(this);
            this._wrapper.removeClass("e-m-light e-m-dark e-m-default").addClass("e-m-" + this.model.theme);
        },

        /**
        * To configure the rendermode of the RadioButton		
        * @private
        */
        _setRenderMode: function (renderMode) {
            ej.setRenderMode(this);
            this._wrapper.removeClass("e-m-ios7 e-m-android e-m-windows e-m-flat").addClass("e-m-" + this.model.renderMode);
        },

        /**
        * To configure the checked state of the RadioButton		
        * @private
        */
        _setChecked: function (active) {
            this.model.checked = active;
            this.element.attr("checked", active);
            this._innerDiv[active ? "addClass" : "removeClass"]("e-m-state-active");
        },
        //To enable the radio button
        /**
        * To enable the radio button
        * @return jQuery
        * @example 
        * &lt;input type="radio" id="radbtn" data-role="ejmradiobutton" /&gt;<br>
        * &lt;script&gt;
        * 	$("#radbtn").ejmRadioButton ("enable");			
        * &lt;/script&gt;
        * @memberof ejmRadioButton
        * @instance
        */
        enable: function () {
            this.model.enable = true;
            this._wrapper.removeClass("e-m-state-disabled");
        },
        //To disable the radio button
        /**
        * To disable the radio button.
        * @return jQuery
        * @example 
        * &lt;input type="radio" id="radbtn" data-role="ejmradiobutton" /&gt;<br>
        * &lt;script&gt;
        * 	$("#radbtn").ejmRadioButton ("disable");			
        * &lt;/script&gt;
        * @memberof ejmRadioButton
        * @instance
        */
        disable: function () {
            this.model.enable = false;
            this._wrapper.addClass("e-m-state-disabled");
        },

        /**
        * To configure the properties at runtime using SetModel		
        * @private
        */
        _setModel: function (options) {
            for (var prop in options) {
                var setModel = "_set" + prop.charAt(0).toUpperCase() + prop.slice(1);
                if (this[setModel])
                    this[setModel](options[prop]);
            }
        },
        /**
        * To remove the RadioButton widget and re-render the RadioButton control	
        * @private
        */
        _refresh: function () {
            this._destroy();
            this.element.addClass("e-m-radbtn");
            this._renderControl();
            this._wireEvents();
        },
        /**
        * To remove the ejmRadioButton control classes and retains the Html element	
        * @private
        */
        _clearElement: function () {
            this.element.insertAfter(this._wrapper);
            this._wrapper.remove();
            this.element.removeAttr("class");
        },

        /**
        * To destroy the Radiobutton widget	
        * @private
        */
        // all events bound using this._on will be unbind automatically
        _destroy: function () {
            this._wireEvents(true);
            this._clearElement();
        }
    });

})(jQuery, Syncfusion);