﻿/**
* @fileOverview Plugin to style the Html rating elements
* @copyright Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/
(function ($, ej, undefined) {
    /**
    * @namespace ej
    * @class ejmRating
    * @requires jQuery
    * @requires ej.mobile.application
    * @requires ej.core
    * @requires ej.unobtrusive
    * @requires ej.mobile.core
    * @requires ej.data
    * @requires ej.touch
    * @classdesc Custom Design for Html rating control.
    * @example 
    * &lt;div id="rating" &gt;&lt;/div&gt;<br>
    * &lt;script&gt; 
    * // Create rating control 
    * $("#rating").ejmRating(); 
    * &lt;/script&gt;
    * @example 
    * &lt;div id="rating" data-role="ejmrating" &gt;&lt;/div&gt;<br>
    */

    // ejmRating is the plugin name 
    // "ej.mobile.Rating" is "namespace.className" will hold functions and properties

    ej.widget("ejmRating", "ej.mobile.Rating", {
        _setFirst: true,
        _rootCSS: "e-m-rating",
        // default model
        defaults: {
            /**		
            * Specifies the maximum value.
            * @default 5
            * @type {int}
            * @example 
            * //Set the maxValue property in unobtrusive way.
            * &lt;div id="rating" data-role="ejmrating" data-ej-maxvalue=5 &gt;&lt;/div&gt;<br>
            * @example 
            * // Set rating maxValue on initialization. 
            * &lt;div id="rating"&gt;&lt;/div&gt;
            * &lt;script&gt;
            * //To set maximum API value
            * $("#rating").ejmRating ({ maxValue: 5 });	
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set the rating maxValue, after initialization:<br>
            * // Get the maximum API value.		
            *  $("#rating").ejmRating ("option", "maxValue");			
            * // Set the maximum value API
            * $("#rating").ejmRating ("option", "maxValue", 5);    
            * &lt;/script&gt;
            * @memberof ejmRating
            * @instance
            */
            maxValue: 5,
            /**		
            * Specifies the minimum value.
            * @default 0
            * @type {int}
            * @example 
            * //Set the minValue property in unobtrusive way.
            * &lt;div id="rating" data-role="ejmrating" data-ej-minvalue=0 &gt;&lt;/div&gt;<br>
            * @example 
            * // Set rating minValue on initialization. 
            * &lt;div id="rating"&gt;&lt;/div&gt;
            * &lt;script&gt;
            * //To set minimum API value 
            * $("#rating").ejmRating ({ minValue: 0 });		
            * &lt;/script&gt;			
            * @example 
            * &lt;script&gt;
            * //Get or set the rating minValue, after initialization:<br>
            * // Get the minimum API value.		
            *  $("#rating").ejmRating ("option", "minValue");			
            * // Set the minValue API
            * $("#rating").ejmRating ("option", "minValue", 0);   
            * &lt;/script&gt;
            * @memberof ejmRating
            * @instance
            */
            minValue: 0,
            /**		
            * Specifies the current value.
            * @default 1
            * @type {int}
            * @example 
            * //Set the current value property in unobtrusive way.
            * &lt;div id="rating" data-role="ejmrating" data-ej-value=1 &gt;&lt;/div&gt;<br>
            * @example 
            * // Set rating current value on initialization. 
            * &lt;div id="rating"&gt;&lt;/div&gt;
            * &lt;script&gt;
            * //To set current value API value 
            * $("#rating").ejmRating ({ value: 1 });		
            * &lt;/script&gt;				
            * @example 
            * &lt;script&gt;
            * //Get or set the rating current value, after initialization:<br>
            * // Get the current value API value.		
            *  $("#rating").ejmRating ("option", "value");			
            * // Set the current value API
            * $("#rating").ejmRating ("option", "value", 1);   
            * &lt;/script&gt;
            * @memberof ejmRating
            * @instance
            */
            value: 1,
            /**		
            * Specifies the step value for incrementation.
            * @default 1
            * @type {int}
            * @example 
            * //Set the incrementStep property in unobtrusive way.
            * &lt;div id="rating" data-role="ejmrating" data-ej-incrementstep=1 &gt;&lt;/div&gt;<br>
            * @example 
            * // Set incrementStep on initialization. 
            * &lt;div id="rating"&gt;&lt;/div&gt;
            * &lt;script&gt;
            * //To set incrementStep API value
            * $("#rating").ejmRating ({ incrementStep: 1 });	
            * &lt;/script&gt;				
            * @example 
            * &lt;script&gt;
            * //Get or set the rating incrementStep, after initialization:<br>
            * // Get the incrementStep API value.		
            *  $("#rating").ejmRating ("option", "incrementStep");			
            * // Set the incrementStep API
            * $("#rating").ejmRating ("option", "incrementStep", 1);      
            * &lt;/script&gt;
            * @memberof ejmRating
            * @instance
            */
            incrementStep: 1,
            /**		
            * Specifies the precision value. See {@link Precision}
            * @default ej.mobile.Rating.Precision.Full. 
            * @type {enum}
            * @example 
            * //Set the precision property in unobtrusive way.
            * &lt;div id="rating" data-role="ejmrating" data-ej-precision="full" &gt;&lt;/div&gt;<br>
            * @example 
            * // Set precision on initialization. 
            * //To set precision API value 
            * &lt;div id="rating"&gt;&lt;/div&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#rating").ejmRating ({ precision: ej.mobile.Rating.Precision.Full });		
            * });
            * &lt;/script&gt;			
            * @example 
            * &lt;script&gt;
            * //Get or set the rating precision, after initialization:<br>
            * // Get the precision API value.		
            *  $("#rating").ejmRating ("option", "precision");			
            * // Set the precision API
            * $("#rating").ejmRating ("option", "precision", ej.mobile.Rating.Precision.Full);  
            * &lt;/script&gt;
            * @memberof ejmRating
            * @instance
            */
            precision: "full",
            /**		
            * Specifies whether to enable or disable the control.
            * @default true
            * @type {bool}
            * @example 
            * //Set the enabled property in unobtrusive way.
            * &lt;div id="rating" data-role="ejmrating" data-ej-enabled=true &gt;&lt;/div&gt;<br>
            * @example 
            * // Set enabled on initialization. 
            * &lt;div id="rating"&gt;&lt;/div&gt;
            * &lt;script&gt;
            * //To set enabled API value 
            * $("#rating").ejmRating ({ enabled: true });			
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set the rating enabled, after initialization:<br>
            * // Get the enabled API value.		
            *  $("#rating").ejmRating ("option", "enabled");			
            * // Set the enabled API
            * $("#rating").ejmRating ("option", "enabled", true); 
            * &lt;/script&gt;
            * @memberof ejmRating
            * @instance
            */
            enabled: true,
            /**		
            * Specifies the theme. See {@link Theme}
            * @default auto 
            * @type {enum}
            * @example 
            * //Set the theme property in unobtrusive way.
            * &lt;div id="rating" data-role="ejmrating" data-ej-theme="auto" &gt;&lt;/div&gt;<br>
            * @example 
            * // Set theme on initialization. 
            * &lt;div id="rating"&gt;&lt;/div&gt;
            * &lt;script&gt;
            * //To set theme API value 
            * $(function(){
            * $("#rating").ejmRating ({ theme: ej.mobile.Theme.Auto });		
            * });
            * &lt;/script&gt;			
            * @example 
            * &lt;script&gt;
            * //Get or set the rating theme, after initialization:<br>
            * // Get the theme API value.		
            *  $("#rating").ejmRating ("option", "theme");			
            * // Set the theme API
            * $("#rating").ejmRating ("option", "theme", ej.mobile.Theme.Auto);            
            * &lt;/script&gt;
            * @memberof ejmRating
            * @instance
            */
            theme: "auto",
            /**		
            * Specifies the rendering mode of the control. See {@link RenderMode}
            * @default auto 
            * @type {enum}
            * @example 
            * //Set the renderMode property in unobtrusive way.
            * &lt;div id="rating" data-role="ejmrating" data-ej-rendermode="auto" &gt;&lt;/div&gt;<br>
            * @example 
            * // Set rendermode on initialization. 
            * &lt;div id="rating"&gt;&lt;/div&gt;
            * &lt;script&gt;
            * //To set renderMode API value 
            * $(function(){
            * $("#rating").ejmRating ({ renderMode: ej.mobile.RenderMode.Auto });	
            * });
            * &lt;/script&gt;			
            * @example 
            * &lt;script&gt;
            * //Get or set the rating rendermode, after initialization:<br>
            * // Get the renderMode API value.		
            *  $("#rating").ejmRating ("option", "renderMode");			
            * // Set the renderMode API
            * $("#rating").ejmRating ("option", "renderMode", ej.mobile.RenderMode.Auto);   
            * &lt;/script&gt;
            * @memberof ejmRating
            * @instance
            */
            renderMode: "auto",
            /**		
            * Specifies the shape. See {@link Shape}
            * @default ej.mobile.Rating.Shape.Star. 
            * @type {enum}
            * @example 
            * //Set the shape property in unobtrusive way.
            * &lt;div id="rating" data-role="ejmrating" data-ej-shape="star" &gt;&lt;/div&gt;<br>
            * @example 
            * // Set shape on initialization. 
            * &lt;div id="rating"&gt;&lt;/div&gt;
            * &lt;script&gt;
            * //To set shape API value 
            * $(function(){
            * $("#rating").ejmRating ({ shape: ej.mobile.Rating.Shape.Star });
            * });
            * &lt;/script&gt;			
            * @example 
            * &lt;script&gt;
            * //Get or set the rating shape, after initialization:<br>
            * // Get the shape API value.		
            *  $("#rating").ejmRating ("option", "shape");			
            * // Set the shape API
            * $("#rating").ejmRating ("option", "shape", ej.mobile.Rating.Shape.Star);          
            * &lt;/script&gt;
            * @memberof ejmRating
            * @instance
            */
            shape: "star",
            /**		
            * Specifies the shape width.
            * @default 25
            * @type {int}
            * @example 
            * //Set the shape width property in unobtrusive way.
            * &lt;div id="rating" data-role="ejmrating" data-ej-shapewidth=25 &gt;&lt;/div&gt;<br>
            * @example 
            * // Set shape width on initialization. 
            * &lt;div id="rating"&gt;&lt;/div&gt;
            * &lt;script&gt;
            * //To set shape width API value 
            * $("#rating").ejmRating ({ shapeWidth: 25 });	
            * &lt;/script&gt;			
            * @example 
            * &lt;script&gt;
            * //Get or set the rating shape width, after initialization:<br>
            * // Get the shape width API value.		
            *  $("#rating").ejmRating ("option", "shapeWidth");			
            * // Set the shape width API
            * $("#rating").ejmRating ("option", "shapeWidth", 25);       
            * &lt;/script&gt;
            * @memberof ejmRating
            * @instance
            */
            shapeWidth: 25,
            /**		
            * Specifies the shape height.
            * @default 25
            * @type {int}
            * @example 
            * //Set the shape height property in unobtrusive way.
            * &lt;div id="rating" data-role="ejmrating" data-ej-shapeheight=25 &gt;&lt;/div&gt;<br>
            * @example 
            * // Set shape height on initialization. 
            * &lt;div id="rating"&gt;&lt;/div&gt;
            * &lt;script&gt;
            * //To set shape height API value 
            * $("#rating").ejmRating ({ shapeHeight: 25 });	
            * &lt;/script&gt;			
            * @example 
            * &lt;script&gt;
            * //Get or set the rating shape height, after initialization:<br>
            * // Get the shape height API value.		
            *  $("#rating").ejmRating ("option", "shapeHeight");			
            * // Set the shape height API
            * $("#rating").ejmRating ("option", "shapeHeight", 25);  
            * &lt;/script&gt;
            * @memberof ejmRating
            * @instance
            */
            shapeHeight: 25,
            /**		
            * Specifies the space between shapes.
            * @default 25
            * @type {int}
            * @example 
            * //Set the space between shapes property in unobtrusive way.
            * &lt;div id="rating" data-role="ejmrating" data-ej-spacebetweenshapes=15 &gt;&lt;/div&gt;<br>
            * @example 
            * // Set space between shapes on initialization. 
            * &lt;div id="rating"&gt;&lt;/div&gt;
            * &lt;script&gt;
            * //To set space between shapes API value 
            * $("#rating").ejmRating ({ spaceBetweenShapes: 15 });		
            * &lt;/script&gt;			
            * @example 
            * &lt;script&gt;
            * //Get or set the rating space between shapes, after initialization:<br>
            * // Get the space between shapes API value.		
            *  $("#rating").ejmRating ("option", "spaceBetweenShapes");			
            * // Set the space between shapes API
            * $("#rating").ejmRating ("option", "spaceBetweenShapes", 15);            
            * &lt;/script&gt;
            * @memberof ejmRating
            * @instance
            */
            spaceBetweenShapes: 15.0,
            /**    
            * Event triggers when touch happens on the control.
            * @event
            * @name ejmRating#tap	
            * @param {Object} argument Event parameters from rating.
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @param {int} argument.value returns the current element associated value.
            * @example 
            * &lt;div id="rating" data-role="ejmrating" data-ej-tap="onTap"&gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // Change event for Rating  
            * function onTap(args){ //handle the event
            * }
            * &lt;/script&gt;
            * @example 
            * &lt;div id="rating"&gt;&lt;/div&gt;
            * &lt;script&gt; 
            * //Change event for Rating
            * $("#rating").ejmRating({
            *  tap: function (args) { //handle the event 
            * }
            *});     
            * &lt;/script&gt;			
            * @memberof ejmRating
            * @instance
            */
            tap: null,
            /**    
            * Event triggers when the value changed.
            * @event
            * @name ejmRating#change 	
            * @param {Object} argument Event parameters from rating.
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @param {int} argument.value returns the current element associated value.
            * @example 
            * &lt;div id="rating" data-role="ejmrating" data-ej-change="onChange"&gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // change event for Rating  
            * function onChange(args){ //handle the event
            * }
            * &lt;/script&gt;
            * @example 
            * &lt;div id="rating"&gt;&lt;/div&gt;
            * &lt;script&gt;
            * //change event for Rating
            * $("#rating").ejmRating({
            *   change: function (args) { //handle the event 
            * }
            *});           
            * &lt;/script&gt;
            * @memberof ejmRating
            * @instance
            */
            change: null,
            /**    
            * Event triggers when touch move happens on the control.
            * @event
            * @name ejmRating#touchMove	
            * @param {Object} argument Event parameters from rating.
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @param {int} argument.value returns the current element associated value.
            * @example 
            * &lt;div id="rating" data-role="ejmrating" data-ej-touchmove="ontouchMove"&gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // Change event for Rating  
            * function ontouchMove(args){ //handle the event
            * }
            * &lt;/script&gt;
            * @example 
            * &lt;div id="rating"&gt;&lt;/div&gt;
            * &lt;script&gt;
            * //change event for Rating
            * $("#rating").ejmRating({
            *   touchMove: function (args) { //handle the event 
            * }
            *});           
            * &lt;/script&gt;
            * @memberof ejmRating
            * @instance
            */
            touchMove: null,
            /**		
            * Specifies whether the orientation is horizontal or vertical. See {@link Orientation}
            * @default ej.mobile.Rating.Orientation.Horizontal. 
            * @type {enum}
            * @example 
            * //Set the orientation property in unobtrusive way.
            * &lt;div id="rating" data-role="ejmrating" data-ej-orientation="horizontal" &gt;&lt;/div&gt;<br>
            * @example 
            * // Set orientation on initialization. 
            * &lt;div id="rating"&gt;&lt;/div&gt;
            * &lt;script&gt;
            * //To set orientation API value 
            * $(function(){
            * $("#rating").ejmRating ({ orientation: ej.mobile.Progress.Orientation.Horizontal });
            * });
            * &lt;/script&gt;			
            * @example 
            * &lt;script&gt;
            * //Get or set the rating orientation, after initialization:<br>
            * // Get the orientation API value.		
            *  $("#rating").ejmRating ("option", "orientation");			
            * // Set the orientation API
            * $("#rating").ejmRating ("option", "orientation", ej.mobile.Progress.Orientation.Horizontal);     
            * &lt;/script&gt;
            * @memberof ejmRating
            * @instance
            */
            orientation: 'horizontal',
            /**		
            * Specifies whether the control is read only.
            * @default false
            * @type {bool}
            * @example 
            * //Set the read only property in unobtrusive way.
            * &lt;div id="rating" data-role="ejmrating" data-ej-readonly=false &gt;&lt;/div&gt;<br>
            * @example 
            * // Set read only on initialization. 
            * &lt;div id="rating"&gt;&lt;/div&gt;
            * &lt;script&gt;
            * //To set read only API value 
            * $("#rating").ejmRating ({ readOnly: false });			
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set the rating read only, after initialization:<br>
            * // Get the read only API value.		
            *  $("#rating").ejmRating ("option", "readOnly");			
            * // Set the read only API
            * $("#rating").ejmRating ("option", "readOnly", false);      
            * &lt;/script&gt;
            * @memberof ejmRating
            * @instance
            */
            readOnly: false,
            /**		
            * Specifies to maintain the current model value to browser cookies for state maintenance. While refresh the page, the model value will get apply to the control from browser cookies.
            * @default false
            * @type {bool}
            * @example 
            * //Set the enablePersistence property in unobtrusive way.
            * &lt;div id="rating" data-role="ejmrating" data-ej-enablePersistence=false &gt;&lt;/div&gt;<br>
            * @example 
            * // Set enablePersistence on initialization. 
            * &lt;div id="rating"&gt;&lt;/div&gt;
            * &lt;script&gt;
            * //To set enablePersistence API value 
            * $(function(){
            * $("#rating").ejmRating({enablePersistence:false});
            * });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set the rating enablePersistence, after initialization:<br>
            * // Get the enablePersistence API value.		
            *  $("#rating").ejmRating ("option", "enablePersistence");			
            * // Set the enablePersistence API
            * $("#rating").ejmRating ("option", "enablePersistence", false);   
            * &lt;/script&gt;
            * @memberof ejmRating
            * @instance
            */
            enablePersistence: false
        },
        dataTypes: {
            enabled: "boolean",
            renderMode: "enum",
            precision: "enum",
            shape: "enum",
            orientation: "enum",
            readOnly: "boolean",
            enablePersistence: "boolean"
        },
        observables: ["value"],
        value: ej.util.valueFunction("value"),
        /**
        * Create the Rating widget
        * @private
        */
        // constructor function
        _init: function () {
            //Get each rating properties
            this._cloneElement = this.element.clone();
            this._renderControl();
            this._wireEvents(false);
            this._isLoaded = true;
        },
        /**
        * To initialization of object
        * @private
        */
        _initObjects: function () {
            this.element.css({ "display": "inline-block" });
            this._canvasElement = this.element.find("canvas")[0];
            this._renderRatingControl();
            this._hiddenField = this.element.find("input")[0];
        },
        /**
        * Render Section For Rating control	
        * @private
        */
        //Renders a Rating control
        _renderControl: function () {
            ej.setRenderMode(this);
            ej.setTheme(this);
            this.element.addClass('e-m-' + this.model.renderMode + ' e-m-' + this.model.theme);
            if (!this.model.enabled)
                this.element.addClass('e-m-state-disabled');
            this._renderColorCodes();
            this["_" + this.model.precision + "PrecisionProperties"]();
            this._canvasElement = ej.buildTag('canvas');
            this._canvasElement.css("-ms-touch-action", "none");
            this.element.append(this._canvasElement);
            this._hiddenField = ej.buildTag("input ", {}, {}, { "type": "hidden", "value": this.model.minValue + this.value() });
            this.element.append(this._hiddenField);
            this._initObjects();
        },
        /**
        * To configure the full Precision property of rating		
        * @private
        */
        _fullPrecisionProperties: function () {
            var checkValue = Math.round(this.value());
            this.value(checkValue - (checkValue % this.model.incrementStep));
            this._currentIndex = Number(this.value() / this.model.incrementStep);
        },
        /**
        * To configure the exact Precision property of rating		
        * @private
        */
        _exactPrecisionProperties: function () {
            var checkValue = Math.ceil(this.value());
            this.value(Math.round(this.value(), 1));
            this._pricisionProperties(checkValue);
        },
        /**
        * To configure the half Precision property of rating		
        * @private
        */
        _halfPrecisionProperties: function () {
            var checkValue = Math.ceil(this.value());
            this.value(this.value() - (this.value() % (Number(this.model.incrementStep) / 2)));
            this._pricisionProperties(checkValue);
        },
        /**
        * To configure the Precision property of rating		
        * @private
        */
        _pricisionProperties: function (checkValue) {
            if (this.value() % this.model.incrementStep != 0) {
                checkValue = checkValue + (checkValue % this.model.incrementStep);
                currentItemIndex = Number(checkValue / this.model.incrementStep);
            }
            else {
                checkValue = this.value();
                currentItemIndex = Number(checkValue / this.model.incrementStep);
            }
        },
        /**
        * To render the color codes of rating		
        * @private
        */
        _renderColorCodes: function () {
            var bgcolor, shapebgcolor, shapeselectcolor, shapehovercolor, glowcolor;
            if (this.model.renderMode == "ios7") {
                if (this.model.theme == "dark") {
                    bgcolor = JSON.stringify({ "ColorInfo": [{ "ColorStop": NaN, "Color": { "R": 13, "G": 122, "B": 255, "A": 0, "Name": "Transparent"}}] });
                    shapebgcolor = JSON.stringify({ "ColorInfo": [{ "ColorStop": NaN, "Color": { "R": 67, "G": 67, "B": 67, "A": 100, "Name": "64ff9d09"}}] });
                    shapeselectcolor = JSON.stringify({ "ColorInfo": [{ "ColorStop": 0, "Color": { "R": 13, "G": 122, "B": 255, "A": 100, "Name": "64c1dff7"}}] });
                    shapehovercolor = JSON.stringify({ "ColorInfo": [{ "ColorStop": 0, "Color": { "R": 13, "G": 122, "B": 255, "A": 100, "Name": "64c1dff7"}}] });
                }
                else if (this.model.theme == "light") {
                    bgcolor = JSON.stringify({ "ColorInfo": [{ "ColorStop": NaN, "Color": { "R": 13, "G": 122, "B": 255, "A": 0, "Name": "Transparent"}}] });
                    shapebgcolor = JSON.stringify({ "ColorInfo": [{ "ColorStop": NaN, "Color": { "R": 238, "G": 238, "B": 238, "A": 100, "Name": "64ff9d09"}}] });
                    shapeselectcolor = JSON.stringify({ "ColorInfo": [{ "ColorStop": 0, "Color": { "R": 13, "G": 122, "B": 255, "A": 100, "Name": "64c1dff7"}}] });
                    shapehovercolor = JSON.stringify({ "ColorInfo": [{ "ColorStop": 0, "Color": { "R": 13, "G": 122, "B": 255, "A": 100, "Name": "64c1dff7"}}] });
                }
            }
            else if (this.model.renderMode == "android") {
                if (this.model.theme == "dark") {
                    bgcolor = JSON.stringify({ "ColorInfo": [{ "ColorStop": NaN, "Color": { "R": 255, "G": 255, "B": 255, "A": 100, "Name": "6433b5e5"}}] });
                    shapebgcolor = JSON.stringify({ "ColorInfo": [{ "ColorStop": NaN, "Color": { "R": 67, "G": 67, "B": 67, "A": 100, "Name": "64b7b7b7"}}] });
                    shapeselectcolor = JSON.stringify({ "ColorInfo": [{ "ColorStop": NaN, "Color": { "R": 54, "G": 190, "B": 240, "A": 100, "Name": "6433b5e5"}}] });
                    shapehovercolor = JSON.stringify({ "ColorInfo": [{ "ColorStop": NaN, "Color": { "R": 54, "G": 190, "B": 240, "A": 100, "Name": "6433b5e5"}}] });
                    glowcolor = JSON.stringify({ "ColorInfo": [{ "ColorStop": NaN, "Color": { "R": 74, "G": 188, "B": 230, "A": 100, "Name": "644abce6"}}] });
                }
                else if (this.model.theme == "light") {
                    bgcolor = JSON.stringify({ "ColorInfo": [{ "ColorStop": NaN, "Color": { "R": 255, "G": 255, "B": 255, "A": 100, "Name": "6433b5e5"}}] });
                    shapebgcolor = JSON.stringify({ "ColorInfo": [{ "ColorStop": NaN, "Color": { "R": 188, "G": 188, "B": 188, "A": 40, "Name": "64b7b7b7"}}] });
                    shapeselectcolor = JSON.stringify({ "ColorInfo": [{ "ColorStop": NaN, "Color": { "R": 54, "G": 190, "B": 240, "A": 100, "Name": "6433b5e5"}}] });
                    shapehovercolor = JSON.stringify({ "ColorInfo": [{ "ColorStop": NaN, "Color": { "R": 54, "G": 190, "B": 240, "A": 100, "Name": "6433b5e5"}}] });
                    glowcolor = JSON.stringify({ "ColorInfo": [{ "ColorStop": NaN, "Color": { "R": 74, "G": 188, "B": 230, "A": 100, "Name": "644abce6"}}] });
                }
            }
            else if (this.model.renderMode == "windows") {
                if (this.model.theme == "dark") {
                    bgcolor = JSON.stringify({ "ColorInfo": [{ "ColorStop": NaN, "Color": { "R": 51, "G": 181, "B": 229, "A": 100, "Name": "6433b5e5"}}] });
                    shapebgcolor = JSON.stringify({ "ColorInfo": [{ "ColorStop": NaN, "Color": { "R": 70, "G": 70, "B": 70, "A": 100, "Name": "64b7b7b7"}}] });
                    shapeselectcolor = JSON.stringify({ "ColorInfo": [{ "ColorStop": NaN, "Color": { "R": 255, "G": 255, "B": 255, "A": 100, "Name": "6433b5e5"}}] });
                    shapehovercolor = JSON.stringify({ "ColorInfo": [{ "ColorStop": NaN, "Color": { "R": 255, "G": 255, "B": 255, "A": 100, "Name": "6433b5e5"}}] });
                }
                else if (this.model.theme == "light") {
                    bgcolor = JSON.stringify({ "ColorInfo": [{ "ColorStop": NaN, "Color": { "R": 255, "G": 255, "B": 255, "A": 100, "Name": "6433b5e5"}}] });
                    shapebgcolor = JSON.stringify({ "ColorInfo": [{ "ColorStop": NaN, "Color": { "R": 209, "G": 207, "B": 207, "A": 100, "Name": "64b7b7b7"}}] });
                    shapeselectcolor = JSON.stringify({ "ColorInfo": [{ "ColorStop": NaN, "Color": { "R": 70, "G": 70, "B": 70, "A": 100, "Name": "6433b5e5"}}] });
                    shapehovercolor = JSON.stringify({ "ColorInfo": [{ "ColorStop": NaN, "Color": { "R": 70, "G": 70, "B": 70, "A": 100, "Name": "6433b5e5"}}] });

                }
            }
            else if (this.model.renderMode == "flat") {
                bgcolor = JSON.stringify({ "ColorInfo": [{ "ColorStop": NaN, "Color": { "R": 51, "G": 181, "B": 229, "A": 100, "Name": "6433b5e5"}}] });
                shapebgcolor = JSON.stringify({ "ColorInfo": [{ "ColorStop": NaN, "Color": { "R": 242, "G": 242, "B": 242, "A": 100, "Name": "64b7b7b7"}}] });
                shapeselectcolor = JSON.stringify({ "ColorInfo": [{ "ColorStop": NaN, "Color": { "R": 243, "G": 133, "B": 41, "A": 100, "Name": "6433b5e5"}}] });
                shapehovercolor = JSON.stringify({ "ColorInfo": [{ "ColorStop": NaN, "Color": { "R": 243, "G": 133, "B": 41, "A": 100, "Name": "6433b5e5"}}] });
            }
            bgcolor = bgcolor.replace('null', NaN);
            shapebgcolor = shapebgcolor.replace('null', NaN);
            shapeselectcolor = shapeselectcolor.replace('null', NaN);
            shapehovercolor = shapehovercolor.replace('null', NaN);
            this.model.backgroundColor = eval("(" + bgcolor + ")");
            this.model.shapeBackgroundColor = eval("(" + shapebgcolor + ")");
            this.model.shapeSelectedColor = eval("(" + shapeselectcolor + ")");
            this.model.shapeHoverColor = eval("(" + shapehovercolor + ")");
            if (this.model.renderMode == "android") {
                glowcolor = glowcolor.replace('null', NaN);
                this.model.glowColor = eval("(" + glowcolor + ")");
            }
        },
        /**
        * To configure the delegates for Rating control		
        * @private
        */
        _createDelegates: function () {
            this._canvasMDDelegate = $.proxy(this._canvasMouseDownHandler, this);
            this._canvasMMDelegate = $.proxy(this._canvasMouseMoveHandler, this);
            this._canvasMUDelegate = $.proxy(this._canvasMouseUpHandler, this);
            this._documentEndDelegate = $.proxy(this._documentEndHandler, this);
        },
        /**
        * Wiring the events to Rating control		
        * @private
        */
        _wireEvents: function (remove) {
            if (this.model.enabled) {
                this._createDelegates();
                if (!this.model.readOnly)
                    ej.listenEvents([this._canvasElement, this._canvasElement, document], [ej.startEvent(), ej.endEvent(), ej.endEvent()], [this._canvasMDDelegate, this._canvasMUDelegate, this._documentEndDelegate], remove);
            }
        },
        /**
        * Section for handling the canvas mouse down
        * @private
        */
        _canvasMouseDownHandler: function (evt) {
            ej.blockDefaultActions(evt);
            this._move = false;
            this._canvasAction = "mouseDown";
            ej.listenTouchEvent(this._canvasElement, ej.moveEvent(), this._canvasMMDelegate, false);
            var data = { value: this.value() };
            if (this.model.tap)
                this._trigger("tap", data);
        },
        /**
        * Section for handling the canvas mouse move
        * @private
        */
        _canvasMouseMoveHandler: function (evt) {
            ej.blockDefaultActions(evt);
            this._move = true;
            if (ej.isTouchDevice())
                evt = evt.touches ? evt.touches[0] : evt;
            this._canvasAction = "mouseMove";
            this._getCursorPosition(evt);
            this._mouseMove(evt);
        },
        /**
        * Section for handling the mouse move
        * @private
        */
        _mouseMove: function (evt) {
            this._getCursorPosition(evt);
            this._mousepos = (this.model.orientation == "vertical") ? this._mousePosition.y : this._mousePosition.x;
            var _value;
            var shapesCount = 0, st = 0;
            this["_" + this.model.orientation + "MouseMoveOrUpProperties"]();
            var roundValue = this._getRoundOffValue(this._value);
            this._currentMouseMove = roundValue;
            this._canvasContext.canvas.title = this.model.minValue + parseFloat(roundValue);
            this._canvasContext.canvas.alt = this.model.minValue + parseFloat(roundValue);
            this._renderRatingControl();
            var data = { value: this.value() };
            if (this.model.touchMove)
                this._trigger("touchMove", data);
        },
        /**
        * To configure the vertical mouse move or up property of rating		
        * @private
        */
        _verticalMouseMoveOrUpProperties: function () {
            shapesCount = Math.floor(this._mousepos - 1) / (this.model.shapeHeight + this.model.spaceBetweenShapes);
            this._value = ((this._mousepos - (shapesCount * this.model.spaceBetweenShapes)) * this.model.incrementStep / this.model.shapeHeight).toFixed(1);
        },
        /**
        * To configure the horizontal mouse move or up property of rating		
        * @private
        */
        _horizontalMouseMoveOrUpProperties: function () {
            shapesCount = Math.floor(this._mousepos - 1) / (this.model.shapeWidth + this.model.spaceBetweenShapes);
            this._value = ((this._mousepos - (shapesCount * this.model.spaceBetweenShapes)) * this.model.incrementStep / this.model.shapeWidth).toFixed(1);
        },
        /**
        * Section for handling the canvas mouse up
        * @private
        */
        _canvasMouseUpHandler: function (evt) {
            ej.blockDefaultActions(evt);
            if (ej.isTouchDevice())
                evt = evt.changedTouches ? evt.changedTouches[0] : evt;
            ej.listenTouchEvent(this._canvasElement, ej.moveEvent(), this._canvasMMDelegate, true);
            this._canvasAction = "mouseUp";
            this._getCursorPosition(evt);
            this._mouseUp(evt);
        },
        /**
        * Section for handling the document end
        * @private
        */
        _documentEndHandler: function (evt) {
            if ($(evt.target).closest('.e-m-rating').length == 0) {
                if (ej.isTouchDevice())
                    evt = evt.touches ? evt.touches[0] : evt;
                ej.listenTouchEvent(this._canvasElement, ej.moveEvent(), this._canvasMMDelegate, true);
            }
        },

        /**
        * Section for handling the mouse up
        * @private
        */
        _mouseUp: function (evt) {
            if (this.model.precision == "exact" && this._move) {
                if (this.model.change)
                    this._trigger("change", data);
                return;
            }
            this._move = false;
            var noofshapes = this._shapesCount, st = 0;
            this._mousepos = (this.model.orientation == "vertical") ? this._mousePosition.y : this._mousePosition.x;
            this._getCursorPosition(evt);
            var _value = 0;
            var shapesCount = 0;
            var width = this.model.shapeWidth, height = this.model.shapeHeight;
            this["_" + this.model.orientation + "MouseMoveOrUpProperties"]();
            var roundValue = this._getRoundOffValue(this._value);
            this.value(roundValue);
            this._currentMouseMove = roundValue;
            this._canvasContext.canvas.title = this.model.minValue + parseFloat(roundValue);
            this._canvasContext.canvas.alt = this.model.minValue + parseFloat(roundValue);
            $(this._hiddenField).val(this._canvasContext.canvas.title);
            this._renderRatingControl();
            var data = { value: this.value() };
            if (this.model.change)
                this._trigger("change", data);
        },
        /**
        * To render the rating control
        * @private
        */
        _renderRatingControl: function () {
            var elem = this._canvasElement;
            if (typeof window.G_vmlCanvasManager != "undefined")
                elem = window.G_vmlCanvasManager.initElement(elem);
            if (!elem || !elem.getContext)
                return;
            if (this._canvasElement.getContext) {
                this._canvasContext = this._canvasElement.getContext('2d');
                var context = this._canvasContext;
                this._shapesCount = Math.floor((this.model.maxValue - this.model.minValue) / this.model.incrementStep);
                this["_" + this.model.orientation + "RenderRatingProperties"]();
                this._canvasWidth = this.tempCanvasWidth;
                this._canvasHeight = this.tempCanvasHeight;
                context.canvas.width = this._canvasWidth;
                context.canvas.height = this._canvasHeight;
                var gradient = context.createLinearGradient(0, 0, this._canvasWidth, this._canvasHeight);
                if (this.model.backgroundColor.ColorInfo[0].ColorStop.toString() != "NaN") {
                    $.each(this.model.backgroundColor.ColorInfo, function (context, index, color) {
                        gradient.addColorStop(color.ColorStop.toString() == "NaN" ? 0 : color.ColorStop, "#" + (color.Color.Name ? ej.hexFromRGB(color.Color) : color.Color));
                    });
                }
                if (this.model.orientation == "horizontal")
                    context.translate(7, 15);
                else
                    context.translate(15, 7);
                context.fillStyle = gradient;
                context.fillRect(0, 0, context.canvas.width, context.canvas.height);
                this._renderRatingShapes(context);

            }
        },
        /**
        * To configure the vertical render rating property		
        * @private
        */
        _verticalRenderRatingProperties: function () {
            this._renderRatingProperties(this.model.shapeWidth, this.model.shapeHeight, this._canvasWidth, this._canvasHeight);
        },
        /**
        * To configure the horizontal render rating property	
        * @private
        */
        _horizontalRenderRatingProperties: function () {
            this._renderRatingProperties(this.model.shapeHeight, this.model.shapeWidth, this._canvasHeight, this._canvasWidth);
        },
        /**
        * To configure the render rating property		
        * @private
        */
        _renderRatingProperties: function (sHorLen, sVerLen, cHorLen, cVerLen) {
            cHorLen = sHorLen + 3 + 30;
            cVerLen = this._shapesCount * sVerLen;
            cVerLen += ((this._shapesCount) * this.model.spaceBetweenShapes);
            this.tempCanvasWidth = (this.model.orientation == "horizontal") ? cVerLen : cHorLen;
            this.tempCanvasHeight = (this.model.orientation == "horizontal") ? cHorLen : cVerLen;
        },
        /**
        * To render the shapes of rating		
        * @private
        */
        _renderRatingShapes: function (context) {
            var noOfShapes = this._shapesCount, noOfRatingShapes;
            var currValue = this.value();
            noOfRatingShapes = noOfShapes;
            st = 0;
            var fullValue = Math.floor(currValue / this.model.incrementStep);
            var partialValue = currValue % this.model.incrementStep;
            currValue = this.value();
            for (st = st; st < noOfRatingShapes; st++) {
                context.save();
                this._drawRatingShape(context, st);
                if (st < fullValue) {
                    this._notClipped = true;
                    this._setClippingRegion(context, st, this.model.shapeWidth, true);
                }
                else if (partialValue != 0) {
                    this._notClipped = true;
                    var value = partialValue * this.model.shapeWidth / this.model.incrementStep;
                    this._setClippingRegion(context, st, value, true);
                    partialValue = 0;
                }
                else
                    this._setClippingRegion(context, st, this.model.shapeWidth, false);
                context.restore();
            }
        },
        /**
        * To draw the shape of rating		
        * @private
        */
        _drawRatingShape: function (context, currentItemIndex) {
            this._drawShapeProperties(currentItemIndex);
            this._drawShape(context, this.x1, this.y1, this.width, this.height);
        },
        /**
        * To configure the draw shape property of rating		
        * @private
        */
        _drawShapeProperties: function (currentItemIndex) {
            this.width = this.model.shapeWidth, this.height = this.model.shapeHeight;
            this.x1, this.y1;
            if (this.model.orientation == "vertical") {
                this.x1 = 1;
                this.y1 = currentItemIndex * this.height + currentItemIndex * this.model.spaceBetweenShapes;
            }
            else {
                this.x1 = currentItemIndex * this.width + (currentItemIndex) * this.model.spaceBetweenShapes;
                this.y1 = 0;
            }
        },
        /**
        * To configure the draw shape of rating		
        * @private
        */
        _drawShape: function (context, x1, y1, width, height) {
            context.beginPath();
            switch (this.model.shape) {
                case "heart": this._drawHeartenShape(context, x1, y1, width, height); break;
                case "pentagon": this._drawPentagonShape(context, x1, y1, width, height); break;
                case "diamond": this._drawDiamondShape(context, x1, y1, width, height); break;
                case "triangle": this._drawTriangleShape(context, x1, y1, width, height); break;
                case "square": this._drawSquareShape(context, x1, y1, width, height); break;
                case "circle": this._drawCircleShape(context, x1, y1, width, height); break;
                default: this._drawStarShape(context, x1, y1, width, height); break;
            }
            context.closePath();
            if (this.model.renderMode != "windows") {
                context.strokeStyle = (this.model.renderMode == "ios7") ? this._generateGradient(context, this.model.backgroundColor, x1, y1) : "";
                context.stroke();
            }
            context.save();
            context.fillStyle = this._generateGradient(context, this.model.shapeBackgroundColor, x1, y1);
            context.fill();
            context.restore();
        },
        /**
        * To configure the star draw shape of rating		
        * @private
        */
        _drawStarShape: function (context, x1, y1, width, height) {
            context.moveTo(x1 + (width / 6), y1 + height); // 1
            context.lineTo(x1 + width, y1 + (height / 3)); // 2
            context.lineTo(x1, y1 + (height / 3)); // 3
            context.lineTo(x1 + width - (width / 6), y1 + height); // 4
            context.lineTo(x1 + width / 2, y1); // 5
            context.lineWidth = (this.model.renderMode == "android") ? 2 : 1;
        },
        /**
        * To configure the circle draw shape of rating		
        * @private
        */
        _drawCircleShape: function (context, x1, y1, width, height) {
            if (this._draw) {
                context.arc(x1 + width / 2, y1 + height / 2, height / 9, 0, Math.PI * 2, true);
                this._draw = false;
            }
            else
                context.arc(x1 + width / 2, y1 + height / 2, height / 2, 0, Math.PI * 2, true);
        },
        /**
        * To configure the square draw shape of rating		
        * @private
        */
        _drawSquareShape: function (context, x1, y1, width, height) {
            context.moveTo(x1, y1);
            context.lineTo(x1 + width, y1);
            context.lineTo(x1 + width, y1 + height);
            context.lineTo(x1, y1 + height);
        },
        /**
        * To configure the triangle draw shape of rating		
        * @private
        */
        _drawTriangleShape: function (context, x1, y1, width, height) {
            context.moveTo(x1 + width / 2, y1);
            context.lineTo(x1 + width, y1 + height);
            context.lineTo(x1, y1 + height);
        },
        /**
        * To configure the diamond draw shape of rating		
        * @private
        */
        _drawDiamondShape: function (context, x1, y1, width, height) {
            context.moveTo(x1 + width / 2, y1);
            context.lineTo(x1 + width, y1 + height / 2);
            context.lineTo(x1 + width / 2, y1 + height);
            context.lineTo(x1, y1 + height / 2);
        },
        /**
        * To configure the pentagon draw shape of rating		
        * @private
        */
        _drawPentagonShape: function (context, x1, y1, width, height) {
            context.moveTo(x1 + width / 2, y1);
            context.lineTo(x1 + width, y1 + height / 2);
            context.lineTo(x1 + width - width / 4, y1 + height);
            context.lineTo(x1 + width / 4, y1 + height);
            context.lineTo(x1, y1 + height / 2);
        },
        /**
        * To configure the heart draw shape of rating		
        * @private
        */
        _drawHeartenShape: function (context, x1, y1, width, height) {
            x1 += width / 2;
            y1 += height / 4;
            height -= (height * .25);
            context.beginPath();
            context.moveTo(x1, y1);
            context.bezierCurveTo(x1, y1 - (height * .4), x1 - width / 2, y1 - (height * .4), x1 - width / 2, y1);
            context.bezierCurveTo(x1 - width / 2, y1 + height / 2, x1, y1 + height / 2, x1, y1 + height);
            context.bezierCurveTo(x1, y1 + height / 2, x1 + width / 2, y1 + height / 2, x1 + width / 2, y1);
            context.bezierCurveTo(x1 + width / 2, y1 - (height * .4), x1, y1 - (height * .4), x1, y1);
        },
        /**
        * To configure the clipping region of rating		
        * @private
        */
        _setClippingRegion: function (context, currentItemIndex, clipValue, isClip) {
            context.save();
            this._drawShapeProperties(currentItemIndex);
            context.clip();
            context.beginPath();
            if (this._canvasAction == "mouseMove") {
                var posX, posY;
                if (this._mouseMoveValue != null) {
                    posX = this._mouseMoveValue * this.width + Math.floor(this._mouseMoveValue) * this.model.spaceBetweenShapes - 7;
                    posY = this._mouseMoveValue * this.height + Math.floor(this._mouseMoveValue) * this.model.spaceBetweenShapes - 7;
                }
                else {
                    posX = this._mousePosition.x - 7;
                    posY = this._mousePosition.y - 7;
                }
                context.fillStyle = this._generateGradient(context, this.model.shapeHoverColor, this.x1, this.y1);
                context.fill();
                (this.model.orientation == "vertical") ? context.fillRect(0, 0, this.width, posY) : context.fillRect(0, 0, posX, this.height);
            }
            else {
                if (isClip) {
                    context.fillStyle = this._generateGradient(context, this.model.shapeSelectedColor, this.x1, this.y1);
                    context.fill();
                    isClip = false;
                }
                (this.model.orientation == "vertical") ? context.fillRect(this.x1, this.y1, this.width, clipValue) : context.fillRect(this.x1, this.y1, clipValue, this.height);
            }
            context.restore();
        },
        /**
        * Sectiont for generate the gradient of rating		
        * @private
        */
        _generateGradient: function (context, gradientObj, x1, y1) {
            var gradient = (this.model.renderMode == "ios7") ? context.createLinearGradient(x1 + this.model.shapeWidth / 2, y1, x1 + this.model.shapeWidth / 2, y1 + this.model.shapeHeight) : context.createLinearGradient(x1 + this.model.shapeWidth / 2, y1 + this.model.shapeHeight, x1 + this.model.shapeWidth / 2, y1);
            $.each(gradientObj.ColorInfo, function (index, color) {
                gradient.addColorStop(color.ColorStop.toString() == "NaN" ? 0 : color.ColorStop, "#" + (color.Color.Name ? ej.hexFromRGB(color.Color) : color.Color));
            });
            return gradient;
        },
        /**
        * Section for clear the rating control		
        * @private
        */
        _clearRatingControl: function (context) {
            context.clearRect(0, 0, this._canvasWidth, this._canvasHeight);
        },
        /**
        * Section for position of cursor	
        * @private
        */
        _getCursorPosition: function (e) {
            var xPos, yPos;
            if (e.pageX || e.pageY) {
                xPos = e.pageX;
                yPos = e.pageY;
            }
            else {
                xPos = e.clientX + document.body.scrollLeft + document.documentElement.scrollLeft;
                yPos = e.clientY + document.body.scrollTop + document.documentElement.scrollTop;
            }
            xPos -= $(this._canvasElement).offset().left;
            yPos -= $(this._canvasElement).offset().top;
            this._mousePosition = { x: xPos, y: yPos };
            return this._mousePosition;
        },
        /**
        * Section for position of cursor	
        * @private
        */
        _getRoundOffValue: function (currValue) {
            var returnValue;
            if (this.model.precision == "full") {
                returnValue = Math.round(currValue);
                returnValue = returnValue - (returnValue % this.model.incrementStep);
            }
            else if (this.model.precision == "exact")
                returnValue = currValue;
            else {
                currValue = Math.round(currValue / .5) * .5;
                currValue = currValue - (currValue % (this.model.incrementStep / 2));
                returnValue = currValue;
            }
            return returnValue;
        },

        /**
        * To configure the renderMode of rating		
        * @private
        */
        _setRenderMode: function (mode) {
            this.model.renderMode = mode;
            this._refresh();
        },
        /**
        * To configure the theme of rating		
        * @private
        */
        _setTheme: function (theme) {
            this.model.theme = theme;
            this._refresh();
        },
        /**
        * To configure the shape of rating		
        * @private
        */
        _changeShape: function (shape) {
            this.model.shape = shape;
            this._renderRatingControl();
        },
        /**
        * To configure the refresh property of rating		
        * @private
        */
        _refresh: function () {
            this._clearElement();
            this.element.addClass("e-m-rating");
            this._renderControl();
            this._wireEvents(false);
        },
        _setModel: function (options) {
            var refresh = false;
            for (var prop in options) {
                switch (prop) {
                    case "renderMode": this._setRenderMode(options.renderMode); break;
                    case "theme": this._setTheme(options.theme); break;
                    case "shape": this._changeShape(options.shape); break;
                    case "shapeWidth": this._refresh(); break;
                    case "shapeHeight": this._refresh(); break;
                    case "incrementStep": this._refresh(); break;
                    case "orientation": this._refresh(); break;
                    case "precision": this._refresh(); break;
                    case "value": this._refresh(); break;
                    case "maxValue": this._refresh(); break;
                    case "enabled": this._refresh(); break;
                    case "readOnly": this._refresh(); break;
                }
            }
        },
        _clearElement: function () {
            this._wireEvents(true);
            this.element.removeAttr("class");
            this.element.removeAttr("style");
            this.element.html("");
        },
        // all events bound using this._on will be unbind automatically
        _destroy: function () {
            this._cloneElement.insertBefore(this.element).removeClass('e-m-rating');
            this.element.remove();
        },

        /*---------------Public Methods---------------*/

        /**
        * To disable the rating.
        * @return jQuery
        * @example 
        * &lt;div id="rating" data-role="ejmrating" &gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * $(function(){
        * // To get the instance of the rating control
        * var rating = $("#rating").data("ejmRating");
        * rating.disable(); // it will disable the rating control
        * });
        * &lt;/script&gt;
        * @example 
        * &lt;div id="rating" &gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * $("#rating").ejmRating();	
        * $(function(){
        * // To disable the Rating control
        * $("#rating").ejmRating("disable");
        * });   
        * &lt;/script&gt;
        *@memberof ejmRating
        * @instance
        */
        disable: function () {
            this.model.enabled = false;
            this._refresh();
        },
        /**
        * To enable the rating.
        * @return jQuery
        * @example 
        * &lt;div id="rating" data-role="ejmrating" &gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * $(function(){
        * // To get the instance of the rating control
        * var rating = $("#rating").data("ejmRating");
        * rating.enable(); // it will enable the rating control
        * });
        * &lt;/script&gt;
        * @example 
        * &lt;div id="rating" &gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * $("#rating").ejmRating();	
        * $(function(){
        * // To enable the Rating control
        * $("#rating").ejmRating("enable");
        * });   
        * &lt;/script&gt;
        *@memberof ejmRating
        * @instance
        */
        enable: function () {
            this.model.enabled = true;
            this._refresh();
        },
        /**
        * To show the rating.
        * @return jQuery
        * @example 
        * &lt;div id="rating" data-role="ejmrating" &gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * $(function(){
        * // To get the instance of the rating control
        * var rating = $("#rating").data("ejmRating");
        * rating.show(); // it will show the rating control
        * });
        * &lt;/script&gt;
        * @example 
        * &lt;div id="rating" &gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * $("#rating").ejmRating();	
        * $(function(){
        * // To show the Rating control
        * $("#rating").ejmRating("show");
        * });   
        * &lt;/script&gt;
        *@memberof ejmRating
        * @instance
        */
        show: function () {
            if (!this.model.enabled) return false;
            this.element.css("display", "block");
        },
        /**
        * To hide the rating.
        * @return jQuery
        * @example 
        * &lt;div id="rating" data-role="ejmrating" &gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * $(function(){
        * // To get the instance of the rating control
        * var rating = $("#rating").data("ejmRating");
        * rating.hide(); // it will hide the rating control
        * });
        * &lt;/script&gt;
        * @example 
        * &lt;div id="rating" &gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * $("#rating").ejmRating();	
        * $(function(){
        * // To hide the Rating control
        * $("#rating").ejmRating("hide");	
        * });
        * &lt;/script&gt;
        *@memberof ejmRating
        * @instance
        */
        hide: function () {
            if (!this.model.enabled) return false;
            this.element.css("display", "none");
        },
        /**
        * To get the current value.
        * @return jQuery
        * @example 
        * &lt;div id="rating" data-role="ejmrating"&gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * $(function(){
        * // To get the instance of rating control
        * var rating = $("#rating").data("ejmRating");
        * rating.getValue(); // it will return the current value of rating
        * });
        * &lt;/script&gt;
        * @example 
        * &lt;div id="rating"&gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * // To get the current value of Rating control
        * $("#rating").ejmRating("getValue");	
        * &lt;/script&gt;
        *@memberof ejmRating
        * @instance
        */
        getValue: function () {
            return this.value();
        },

        /**
        * To reset the value.
        * @return jQuery
        * @example 
        * &lt;div id="rating" data-role="ejmrating"&gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * $(function(){
        * // To get the instance of rating control
        * var rating = $("#rating").data("ejmRating");
        * rating.reset(); // it will reset the value of rating
        * });
        * &lt;/script&gt;
        * @example 
        * &lt;div id="rating"&gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * // To reset value of Rating control
        * $("#rating").ejmRating("reset");	
        * &lt;/script&gt;
        *@memberof ejmRating
        * @instance
        */
        reset: function () {
            this.value(0);
            this._refresh();
        },

        /**
        * To set the value.
        * @return jQuery
        * @example 
        * &lt;div id="rating" data-role="ejmrating"&gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * $(function(){
        * // To get the instance of rating control
        * var rating = $("#rating").data("ejmRating");
        * rating.setValue(3); // it will set the value of rating
        * });
        * &lt;/script&gt;
        * @example 
        * &lt;div id="rating"&gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * // To set the value of Rating control
        * $("#rating").ejmRating("setValue",3);	
        * &lt;/script&gt;
        *@memberof ejmRating
        * @instance
        */
        setValue: function (value) {
            this.value(value);
            this._refresh();
        }
        /*---------------Public Methods End---------------*/

    });
    /**
    * Enum for RatingPrecision
    * @enum {string}
    * @global
    */
    ej.mobile.Rating.Precision = {
        /**
        Enum for full precision rating*/
        Full: "full",
        /**
        Enum for exact precision rating*/
        Exact: "exact",
        /**
        Enum for half precision rating*/
        Half: "half"
    };

    /**
    * Enum for RatingShape
    * @enum {string}
    * @global
    */
    ej.mobile.Rating.Shape = {
        /**
        Enum for star shape rating*/
        Star: "star",
        /**
        Enum for circle shape rating*/
        Circle: "circle",
        /**
        Enum for diamond shape rating*/
        Diamond: "diamond",
        /**
        Enum for heart shape rating*/
        Heart: "heart",
        /**
        Enum for pentagon shape rating*/
        Pentagon: "pentagon",
        /**
        Enum for square shape rating*/
        Square: "square",
        /**
        Enum for triangle shape rating*/
        Triangle: "triangle"
    };
    /**
    * Enum for RatingOrientation
    * @enum {string}
    * @global
    */
    ej.mobile.Rating.Orientation = {
        /**
        Enum for horizontal mode rating*/
        Horizontal: "horizontal",
        /**
        Enum for vertical mode rating*/
        Vertical: "vertical"
    };
})(jQuery, Syncfusion);