/**
* @fileOverview Plugin to style the Html CheckBox elements
* @copyright Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/
(function ($, ej, undefined) {
    // ejmRotator is the plugin name 
    // "ej.mobile.Rotator" is "namespace.className" will hold functions and properties
    /**
    * @namespace ej
    * @class ejmRotator
    * @requires jQuery
    * @requires ej.mobile.application
    * @requires ej.core
    * @requires ej.unobtrusive
    * @requires ej.mobile.core
    * @requires ej.mobile.header
    * @requires ej.data
    * @requires ej.touch
    * @classdesc Custom Design for Html Rotator control.
    * @example
    * // Render rotator in unobtrusive way
    * &lt;div id="rotator" data-role="ejmrotator" data-ej-targetid="rotatorcontent"&gt;	
    * &lt;/div&gt;
    * &lt;div id="rotatorcontent"&gt;
    * &lt;div &gt;
    * &lt;div style="background-image:url(nature.jpg);height:350px;width:630px"&gt;
    * &lt;/div&gt;
    * &lt;/div&gt;&lt;div&gt;	
    * &lt;div style="background-image:url(bird.jpg);height:350px;width:630px"&gt;
    * &lt;/div&gt;
    * &lt;/div&gt;&lt;div&gt;	
    * &lt;div style="background-image:url(snowfall.jpg);height:350px;width:630px"&gt;
    * &lt;/div&gt;
    * &lt;/div&gt;&lt;div&gt;	
    * &lt;div style="background-image:url(sculpture.jpg);height:350px;width:630px"&gt;
    * &lt;/div&gt;
    * &lt;/div&gt;
    * &lt;/div&gt;
    * @example
    * //Render rotator on initialization
    * &lt;div id="rotator"&gt;	
    * &lt;/div&gt;
    * &lt;div id="rotatorcontent"&gt;
    * &lt;div &gt;
    * &lt;div style="background-image:url(nature.jpg);height:350px;width:630px"&gt;
    * &lt;/div&gt;
    * &lt;/div&gt;&lt;div&gt;	
    * &lt;div style="background-image:url(bird.jpg);height:350px;width:630px"&gt;
    * &lt;/div&gt;
    * &lt;/div&gt;&lt;div&gt;	
    * &lt;div style="background-image:url(snowfall.jpg);height:350px;width:630px"&gt;
    * &lt;/div&gt;
    * &lt;/div&gt;&lt;div&gt;	
    * &lt;div style="background-image:url(sculpture.jpg);height:350px;width:630px"&gt;
    * &lt;/div&gt;
    * &lt;/div&gt;
    * &lt;/div&gt;<br>
    * &lt;script&gt; 
    * // Create rotator  
    * $("#rotator").ejmRotator({ targetId: "rotatorcontent" }); 
    * &lt;/script&gt;
    */
    ej.widget("ejmRotator", "ej.mobile.Rotator", {
        _setFirst: true,
        _rootCSS: "e-m-rotator",
        // Default model values
        defaults: {
            /**		
            * Specifies the targetId to the content .
            * @default null
            * @type {string}
            * @example 
            * //Set the targetId property in unobtrusive way.
            * &lt;div id="rotator" data-role="ejmrotator" data-ej-targetid="rotatorcontent"&gt;
            * &lt;/div&gt;
            * &lt;div id="rotatorcontent"&gt;
            * &lt;div &gt;
            * &lt;div style="background-image:url(nature.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div&gt;	        
            * &lt;div style="background-image:url(bird.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div&gt;	        
            * &lt;div style="background-image:url(snowfall.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div&gt;	        
            * &lt;div style="background-image:url(sculpture.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * @example
            * // Set the targetId on initialization. 
            * &lt;div id="rotator"&gt;	
            * &lt;/div&gt;
            * &lt;div id="rotatorcontent"&gt;
            * &lt;div &gt;
            * &lt;div style="background-image:url(nature.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div&gt;	
            * &lt;div style="background-image:url(bird.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div&gt;	
            * &lt;div style="background-image:url(snowfall.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div&gt;	
            * &lt;div style="background-image:url(sculpture.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;<br>
            * &lt;script&gt; 
            * //To set the targetId API value 
            * $("#rotator").ejmRotator({ targetId: "rotatorcontent" });
            * &lt;/script&gt; 
            * @example 
            * //Get or set the targetId, after initialization:<br>
            * // Get the targetId API value.	
            *  $("#rotator").ejmRotator ("option", "targetId");			
            * // Set the targetId API
            * $("#rotator").ejmRotator ("option", "targetId", "rotatorcontent");            
            * @memberof ejmRotator
            * @instance          
            */
            targetId: null,
            /**		
            * Changes the rendering mode for rotator. See {@link RenderMode}
            * @default auto
            * @type {enum}
            * @example 
            * //Set the rendermode property in unobtrusive way.
            * &lt;div id="rotator" data-role="ejmrotator" data-ej-targetid="rotatorcontent" data-ej-rendermode="auto" &gt;
            * &lt;/div&gt;
            * &lt;div id="rotatorcontent" &gt;
            * &lt;div &gt;
            * &lt;div style="background-image:url(nature.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(bird.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(snowfall.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(sculpture.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * @example 
            * // Set the rendermode on initialization.
            * &lt;div id="rotator" &gt;	
            * &lt;/div&gt;
            * &lt;div id="rotatorcontent" &gt;
            * &lt;div &gt;
            * &lt;div style="background-image:url(nature.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(bird.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(snowfall.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(sculpture.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;<br>
            * &lt;script&gt; 
            * $(function(){
            * //To set the rendermode API value 
            * $("#rotator").ejmRotator({ targetId: "rotatorcontent", renderMode: ej.mobile.RenderMode.Auto});			
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the rendermode, after initialization:<br>
            * // Get the rendermode API value.	
            *  $("#rotator").ejmRotator ("option", "renderMode");			
            * // Set the renderMode API
            * $("#rotator").ejmRotator ("option", "renderMode", ej.mobile.RenderMode.Auto);            
            * @memberof ejmRotator
            * @instance	
            */
            renderMode: "auto",
            /**		
            * Specifies the targetHeight on initialization.
            * @default auto
            * @type {string}
            * @example 
            * //Set the targetHeight property in unobtrusive way.
            * &lt;div id="rotator" data-role="ejmrotator" data-ej-targetid="rotatorcontent" data-ej-targetheight="100px" &gt;
            * &lt;/div&gt;
            * &lt;div id="rotatorcontent" &gt;
            * &lt;div &gt;
            * &lt;div style="background-image:url(nature.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(bird.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(snowfall.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(sculpture.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * @example 
            * // Set the targetHeight on initialization. 
            * &lt;div id="rotator" &gt;	
            * &lt;/div&gt;
            * &lt;div id="rotatorcontent" &gt;
            * &lt;div &gt;
            * &lt;div style="background-image:url(nature.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(bird.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(snowfall.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(sculpture.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;<br>
            * &lt;script&gt; 
            * //To set the targetHeight API value 
            * $("#rotator").ejmRotator({ targetId: "rotatorcontent", targetHeight: "100px" });			
            * &lt;/script&gt;
            * @example 
            * //Get or set the  targetHeight, after initialization:<br>
            * // Get the targetHeight API value.	
            *  $("#rotator").ejmRotator ("option", "targetHeight");			
            * // Set the targetHeight API
            * $("#rotator").ejmRotator ("option", "targetHeight", "auto");            
            * @memberof ejmRotator
            * @instance	
            */
            targetHeight: "auto",
            /**		
            * Specifies the targetWidth on initialization.
            * @default auto
            * @type {string}
            * @example 
            * //Set the targetWidth property in unobtrusive way.
            * &lt;div id="rotator" data-role="ejmrotator" data-ej-targetid="rotatorcontent" data-ej-targetwidth="auto" &gt;
            * &lt;/div&gt;
            * &lt;div id="rotatorcontent" &gt;
            * &lt;div &gt;
            * &lt;div style="background-image:url(nature.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(bird.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(snowfall.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(sculpture.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * @example 
            * // Set the targetWidth on initialization. 
            * &lt;div id="rotator" &gt;	
            * &lt;/div&gt;
            * &lt;div id="rotatorcontent" &gt;
            * &lt;div &gt;
            * &lt;div style="background-image:url(nature.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(bird.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(snowfall.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(sculpture.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;<br>
            * &lt;script&gt; 
            * //To set the targetWidth API value 
            * $("#rotator").ejmRotator({ targetId: "rotatorcontent", targetWidth: "auto" });			
            * &lt;/script&gt;
            * @example 
            * //Get or set the rotator targetWidth, after initialization:<br>
            * // Get the targetWidth API value.	
            *  $("#rotator").ejmRotator ("option", "targetWidth");			
            * // Set the targetWidth API
            * $("#rotator").ejmRotator ("option", "targetWidth", "auto");            
            * @memberof ejmRotator
            * @instance	
            */
            targetWidth: "auto",
            /**		
            * Changes the theme of the Rotator. See{@link Theme}
            * @default auto
            * @type {enum}
            * @example 
            * //Set the theme property in unobtrusive way.
            * &lt;div id="rotator" data-role="ejmrotator" data-ej-targetid="rotatorcontent" data-ej-theme="auto" &gt;
            * &lt;/div&gt;
            * &lt;div id="rotatorcontent" &gt;
            * &lt;div &gt;
            * &lt;div style="background-image:url(nature.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(bird.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(snowfall.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(sculpture.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * @example 
            * // Set the theme on initialization. 
            * &lt;div id="rotator" &gt;	
            * &lt;/div&gt;
            * &lt;div id="rotatorcontent" &gt;
            * &lt;div &gt;
            * &lt;div style="background-image:url(nature.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(bird.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(snowfall.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(sculpture.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;<br>
            * &lt;script&gt; 
            * $(function(){
            * //To set the theme API value 
            * $("#rotator").ejmRotator({ targetId: "rotatorcontent", theme: ej.mobile.Theme.Light });			
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the theme, after initialization:<br>
            * // Get the theme API value.	
            *  $("#rotator").ejmRotator ("option", "theme");			
            * // Set the theme API
            * $("#rotator").ejmRotator ("option", "theme", ej.mobile.Theme.Light);            
            * @memberof ejmRotator
            * @instance	
            */
            theme: "auto",
            /**		
            * Specifies the currentItemIndex  for select the particular item based on the specified index.
            * @default 0
            * @type {number}
            * @example 
            * //Set the currentItemIndex property in unobtrusive way.
            * &lt;div id="rotator" data-role="ejmrotator" data-ej-targetid="rotatorcontent" data-ej-currentitemindex=0 &gt;
            * &lt;/div&gt;
            * &lt;div id="rotatorcontent" &gt;
            * &lt;div &gt;
            * &lt;div style="background-image:url(nature.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(bird.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(snowfall.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(sculpture.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * @example 
            * // Set the currentItemIndex on initialization. 
            * &lt;div id="rotator" &gt;	
            * &lt;/div&gt;
            * &lt;div id="rotatorcontent" &gt;
            * &lt;div &gt;
            * &lt;div style="background-image:url(nature.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(bird.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(snowfall.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(sculpture.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;<br>
            * &lt;script&gt; 
            * //To set the currentItemIndex API value 
            * $("#rotator").ejmRotator({ targetId: "rotatorcontent", currentItemIndex: 0 });			
            * &lt;/script&gt;
            * @example 
            * //Get or set the  currentItemIndex, after initialization:<br>
            * // Get the currentItemIndex API value.	
            *  $("#rotator").ejmRotator ("option", "currentItemIndex");			
            * // Set the currentItemIndex API
            * $("#rotator").ejmRotator ("option", "currentItemIndex", 0);            
            * @memberof ejmRotator
            * @instance	
            */
            currentItemIndex: 0,
            /**		
            * Specifies whether to show the Pager on initialization.
            * @default true
            * @type {boolean}
            * @example 
            * //Set the showPager property in unobtrusive way.
            * &lt;div id="rotator" data-role="ejmrotator" data-ej-targetid="rotatorcontent" data-ej-showpager=true &gt;
            * &lt;/div&gt;
            * &lt;div id="rotatorcontent" &gt;
            * &lt;div &gt;
            * &lt;div style="background-image:url(nature.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(bird.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(snowfall.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(sculpture.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * @example 
            * // Set the showPager on initialization. 
            * &lt;div id="rotator" &gt;	
            * &lt;/div&gt;
            * &lt;div id="rotatorcontent" &gt;
            * &lt;div &gt;
            * &lt;div style="background-image:url(nature.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(bird.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(snowfall.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(sculpture.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;<br>
            * &lt;script&gt; 
            * //To set the showPager API value 
            * $("#rotator").ejmRotator({ targetId: "rotatorcontent", showPager: true });			
            * &lt;/script&gt;
            * @example 
            * //Get or set the showPager, after initialization:<br>
            * // Get the showPager API value.	
            *  $("#rotator").ejmRotator ("option", "showPager");			
            * // Set the showPager API
            * $("#rotator").ejmRotator ("option", "showPager", true);            
            * @memberof ejmRotator
            * @instance	
            */
            showPager: true,
            /**		
            * Specifies whether to enable the header on initialization.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the showHeader property in unobtrusive way.
            * &lt;div id="rotator" data-role="ejmrotator" data-ej-targetid="rotatorcontent" data-ej-showheader=false &gt;
            * &lt;/div&gt;
            * &lt;div id="rotatorcontent" &gt;
            * &lt;div &gt;
            * &lt;div style="background-image:url(nature.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(bird.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(snowfall.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(sculpture.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * @example 

            * // Set the showHeader on initialization. 
            * &lt;div id="rotator" &gt;	
            * &lt;/div&gt;
            * &lt;div id="rotatorcontent" &gt;
            * &lt;div &gt;
            * &lt;div style="background-image:url(nature.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(bird.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(snowfall.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(sculpture.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;<br>
            * &lt;script&gt; 
            * //To set the showHeader API value 
            * $("#rotator").ejmRotator({ targetId: "rotatorcontent", showHeader: false });			
            * &lt;/script&gt;
            * @example 
            * //Get or set the  showHeader, after initialization:<br>
            * // Get the showHeader API value.	
            *  $("#rotator").ejmRotator ("option", "showHeader");			
            * // Set the showHeader API
            * $("#rotator").ejmRotator ("option", "showHeader", false);            
            * @memberof ejmRotator
            * @instance	
            */
            showHeader: false,
            /**	
            * Specifies the headerTitle on initialization .
            * @default Title
            * @type {string}
            * @example 
            * //Set the headerTitle property in unobtrusive way.
            * &lt;div id="rotator" data-role="ejmrotator" data-ej-targetid="rotatorcontent" data-ej-headertitle="Title" &gt;
            * &lt;/div&gt;
            * &lt;div id="rotatorcontent" &gt;
            * &lt;div &gt;
            * &lt;div style="background-image:url(nature.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(bird.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(snowfall.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(sculpture.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * @example 
            * // Set the headerTitle on initialization. 
            * &lt;div id="rotator" &gt;	
            * &lt;/div&gt;
            * &lt;div id="rotatorcontent" &gt;
            * &lt;div &gt;
            * &lt;div style="background-image:url(nature.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(bird.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(snowfall.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(sculpture.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;<br>
            * &lt;script&gt; 
            * //To set the headerTitle API value 
            * $("#rotator").ejmRotator({ targetId: "rotatorcontent", headerTitle: "Title" });			
            * &lt;/script&gt;
            * @example 
            * //Get or set the headerTitle, after initialization:<br>
            * // Get the headerTitle API value.	
            *  $("#rotator").ejmRotator ("option", "headerTitle");			
            * // Set the headerTitle API
            * $("#rotator").ejmRotator ("option", "headerTitle", "Title");            
            * @memberof ejmRotator
            * @instance	
            */
            headerTitle: "Title",
            /**    
            * Event triggers when the swipeLeft happens.
            * @event
            * @name ejmRotator#swipeLeft 	              
            * @param {boolean}  argument.cancel returns the cancel option value
            * @param {object}  argument.model returns the Rotator model
            * @param {string}  argument.type returns the name of the event
            * @param {string}  argument.targetElement returns the targetElement of the Rotator
            * @param {number}  argument.value returns the current slide index.
            * @example 
            * //SwipeLeft event for rotator
            * &lt;div id="rotator" data-role="ejmrotator" data-ej-targetid="rotatorcontent" data-ej-swipeleft="swipeLeft" &gt;
            * &lt;/div&gt;
            * &lt;div id="rotatorcontent" &gt;
            * &lt;div &gt;
            * &lt;div style="background-image:url(nature.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(bird.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(snowfall.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(sculpture.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * function swipeLeft(args) { 
            * //handle the event 
            * }
            * &lt;/script&gt;
            * @example 
            * //SwipeLeft event for rotator
            * &lt;div id="rotator" data-role="ejmrotator" data-ej-targetid="rotatorcontent" &gt;	
            * &lt;/div&gt;
            * &lt;div id="rotatorcontent" &gt;
            * &lt;div &gt;
            * &lt;div style="background-image:url(nature.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(bird.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(snowfall.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(sculpture.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;<br>
            * &lt;script&gt; 
            * $("#rotator").ejmRotator({
            *   swipeLeft: function (args) { 
            * //handle the event 
            * }
            * });           
            * &lt;/script&gt;
            * @memberof ejmRotator
            * @instance
            */
            swipeLeft: null,
            /**    
            * Event triggers when the swipeRight happens in the Rotator
            * @event
            * @name ejmRotator#swipeRight 	              
            * @param {boolean}  argument.cancel returns the cancel option value
            * @param {object}  argument.model returns the Rotator model
            * @param {string}  argument.type returns the name of the event
            * @param {string}  argument.targetElement returns the targetElement of the rotator
            * @param {number}  argument.value returns the current slide index.
            * @example 
            * //SwipeRight event for rotator
            * &lt;div id="rotator" data-role="ejmrotator" data-ej-targetid="rotatorcontent" data-ej-swiperight="swipeRight" &gt;
            * &lt;/div&gt;
            * &lt;div id="rotatorcontent" &gt;
            * &lt;div &gt;
            * &lt;div style="background-image:url(nature.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(bird.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(snowfall.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(sculpture.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * function swipeRight(args) { 
            * //handle the event 
            * }
            * &lt;/script&gt;
            * @example 
            * //SwipeRight event for rotator
            * &lt;div id="rotator" data-role="ejmrotator" data-ej-targetid="rotatorcontent" &gt;	
            * &lt;/div&gt;
            * &lt;div id="rotatorcontent" &gt;
            * &lt;div &gt;
            * &lt;div style="background-image:url(nature.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(bird.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(snowfall.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(sculpture.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;<br>
            * &lt;script&gt; 
            * $("#rotator").ejmRotator({
            *   swipeRight: function (args) { 
            * //handle the event 
            * }
            * });           
            * &lt;/script&gt;
            * @memberof ejmRotator
            * @instance
            */
            swipeRight: null,
            /**    
            * Event triggers when the swipeUp happens in the Rotator
            * @event
            * @name ejmRotator#swipeUp 	              
            * @param {boolean}  argument.cancel returns the cancel option value
            * @param {object}  argument.model returns the Rotator model
            * @param {string}  argument.type returns the name of the event
            * @param {string}  argument.targetElement returns the targetElement of the rotator
            * @param {number}  argument.value returns the current slide index.
            * @example 
            * //SwipeUp event for rotator
            * &lt;div id="rotator" data-role="ejmrotator" data-ej-targetid="rotatorcontent" data-ej-swipeup="swipeUp" &gt;
            * &lt;/div&gt;
            * &lt;div id="rotatorcontent" &gt;
            * &lt;div &gt;
            * &lt;div style="background-image:url(nature.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(bird.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(snowfall.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(sculpture.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * function swipeUp(args) { 
            * //handle the event 
            * }
            * &lt;/script&gt;
            * @example 
            * //SwipeUp event for rotator
            * &lt;div id="rotator" data-role="ejmrotator" data-ej-targetid="rotatorcontent" &gt;	
            * &lt;/div&gt;
            * &lt;div id="rotatorcontent" &gt;
            * &lt;div &gt;
            * &lt;div style="background-image:url(nature.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(bird.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(snowfall.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(sculpture.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;<br>
            * &lt;script&gt; 
            * $("#rotator").ejmRotator({
            *   swipeUp: function (args) { 
            * //handle the event 
            * }
            * });           
            * &lt;/script&gt;
            * @memberof ejmRotator
            * @instance
            */
            swipeUp: null,
            /**    
            * Event triggers when the swipeDown happens in the Rotator
            * @event
            * @name ejmRotator#swipeDown 	              
            * @param {boolean}  argument.cancel returns the cancel option value
            * @param {object}  argument.model returns the Rotator model
            * @param {string}  argument.type returns the name of the event
            * @param {string}  argument.targetElement returns the targetElement of the rotator
            * @param {number}  argument.value returns the current slide index.
            * @example 
            * //SwipeDown event for rotator
            * &lt;div id="rotator" data-role="ejmrotator" data-ej-targetid="rotatorcontent" data-ej-swipedown="swipeDown" &gt;
            * &lt;/div&gt;
            * &lt;div id="rotatorcontent" &gt;
            * &lt;div &gt;
            * &lt;div style="background-image:url(nature.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(bird.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(snowfall.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(sculpture.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * function swipeDown(args) { 
            * //handle the event 
            * }
            * &lt;/script&gt;
            * @example 
            * //SwipeDown event for rotator
            * &lt;div id="rotator" data-role="ejmrotator" data-ej-targetid="rotatorcontent" &gt;	
            * &lt;/div&gt;
            * &lt;div id="rotatorcontent" &gt;
            * &lt;div &gt;
            * &lt;div style="background-image:url(nature.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(bird.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(snowfall.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(sculpture.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;<br>
            * &lt;script&gt; 
            * $("#rotator").ejmRotator({
            *   swipeDown: function (args) { 
            * //handle the event 
            * }
            * });           
            * &lt;/script&gt;
            * @memberof ejmRotator
            * @instance
            */
            swipeDown: null,
            /**    
            * Event triggers when the rotator changes from one slide to another slide
            * @event
            * @name ejmRotator#change 	              
            * @param {boolean}  argument.cancel returns the cancel option value
            * @param {object}  argument.model returns the Rotator model
            * @param {string}  argument.type returns the name of the event
            * @param {string}  argument.targetElement returns the targetElement of the rotator
            * @param {number}  argument.value returns the current slide index.
            * @example 
            * //change event for rotator
            * &lt;div id="rotator" data-role="ejmrotator" data-ej-targetid="rotatorcontent" data-ej-change="onChange" &gt;
            * &lt;/div&gt;
            * &lt;div id="rotatorcontent" &gt;
            * &lt;div &gt;
            * &lt;div style="background-image:url(nature.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(bird.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(snowfall.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(sculpture.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * function onChange(args) { 
            * //handle the event 
            * }
            * &lt;/script&gt;
            * @example 
            * //change event for rotator
            * &lt;div id="rotator" data-role="ejmrotator" data-ej-targetid="rotatorcontent" &gt;	
            * &lt;/div&gt;
            * &lt;div id="rotatorcontent" &gt;
            * &lt;div &gt;
            * &lt;div style="background-image:url(nature.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(bird.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(snowfall.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(sculpture.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;<br>
            * &lt;script&gt; 
            * $("#rotator").ejmRotator({
            *   change: function (args) { 
            * //handle the event 
            * }
            * });           
            * &lt;/script&gt;
            * @memberof ejmRotator
            * @instance
            */
            change: null,
            /**    
            * Event triggers when the rotator's pager clicked
            * @event
            * @name ejmRotator#pagerSelect 	              
            * @param {boolean}  argument.cancel returns the cancel option value
            * @param {object}  argument.model returns the Rotator model
            * @param {string}  argument.type returns the name of the event
            * @param {string}  argument.targetElement returns the targetElement of the rotator
            * @param {number}  argument.value returns the current slide index.
            * @example 
            * //pagerSelect event for rotator
            * &lt;div id="rotator" data-role="ejmrotator" data-ej-targetid="rotatorcontent" data-ej-pagerselect="onUpdate" &gt;
            * &lt;/div&gt;
            * &lt;div id="rotatorcontent" &gt;
            * &lt;div &gt;
            * &lt;div style="background-image:url(nature.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(bird.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(snowfall.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(sculpture.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * function onUpdate(args) { 
            * //handle the event 
            * }
            * &lt;/script&gt;
            * @example 
            * //pagerSelect event for rotator
            * &lt;div id="rotator" data-role="ejmrotator" data-ej-targetid="rotatorcontent" &gt;	
            * &lt;/div&gt;
            * &lt;div id="rotatorcontent" &gt;
            * &lt;div &gt;
            * &lt;div style="background-image:url(nature.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(bird.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(snowfall.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(sculpture.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;<br>
            * &lt;script&gt; 
            * $("#rotator").ejmRotator({
            *   pagerSelect: function (args) { 
            * //handle the event 
            * }
            * });           
            * &lt;/script&gt;
            * @memberof ejmRotator
            * @instance
            */
            pagerSelect: null,
            /**		
            * Specifies whether to enable dataBinding for the items on initilization.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the dataBinding property in unobtrusive way.
            * &lt;div id="rotator" data-role="ejmrotator" data-ej-targetid="rotatorcontent" data-ej-databinding="false" &gt;
            * &lt;/div&gt;
            * &lt;div id="rotatorcontent" &gt;
            * &lt;div &gt;
            * &lt;div style="background-image:url(nature.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(bird.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(snowfall.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(sculpture.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * @example 
            * // Set the dataBinding on initialization. 
            * &lt;div id="rotator" &gt;	
            * &lt;/div&gt;
            * &lt;div id="rotatorcontent" &gt;
            * &lt;div &gt;
            * &lt;div style="background-image:url(nature.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(bird.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(snowfall.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(sculpture.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;<br>
            * &lt;script&gt; 
            * //To set the dataBinding API value 
            * $("#rotator").ejmRotator({ targetId: "rotatorcontent", dataBinding: false });			
            * &lt;/script&gt;
            * @example 
            * //Get or set the dataBinding, after initialization:<br>
            * // Get the dataBinding API value.	
            *  $("#rotator").ejmRotator ("option", "dataBinding");			
            * // Set the dataBinding API
            * $("#rotator").ejmRotator ("option", "dataBinding", false); 			
            * @memberof ejmRotator
            * @instance	
            */
            dataBinding: false,
            /**		
            * Specifies the dataSource for items .
            * @default null
            * @type {data}
            * @example 
            * //Set the dataSource property in unobtrusive way.
            * &lt;div id="rotator" data-role="ejmrotator" data-ej-targetid="rotatorcontent" data-ej-datasource="window.imgdata" data-ej-databinding=true &gt;
            * &lt;/div&gt;
            * &lt;div id="rotatorcontent"&gt;
            * &lt;div &gt;
            * &lt;div style="background-image:url({{:imageurl}});height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;/div&gt; 
           
            * @example 
            * // Set the dataSource on initialization. 
            * &lt;div id="rotator" &gt;	
            * &lt;/div&gt;
            * &lt;div id="rotatorcontent" &gt;
            * &lt;div &gt;
            * &lt;div style="background-image:url{{:imageurl}};height:350px;width:630px" &gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;/div&gt; 
            * &lt;script&gt; 
            * //To set the dataSource API value 
            * $("#rotator").ejmRotator({ targetId: "rotatorcontent", dataSource: "window.imgdata", dataBinding: true });			
            * &lt;/script&gt;
            * @example 
            * //Get or set the dataSource, after initialization:<br>
            * // Get the dataSource API value.	
            *  $("#rotator").ejmRotator ("option", "dataSource");			
            * // Set the dataSource API
            * $("#rotator").ejmRotator ("option", "dataSource", "window.imgdata"); 			
            * @memberof ejmRotator
            * @instance	
            */
            dataSource: null,
            /**		
            * Specifies the rotator orientation to the horizontal or vertical. See {@link Orientation }
            * @default ej.mobile.Rotator.Orientation.Horizontal
            * @type {enum}
            * @example 
            * //Set the orientation property in unobtrusive way.
            * &lt;div id="rotator" data-role="ejmrotator" data-ej-targetid="rotatorcontent" data-ej-orientation="horizontal" &gt;
            * &lt;/div&gt;
            * &lt;div id="rotatorcontent" &gt;
            * &lt;div &gt;
            * &lt;div style="background-image:url(nature.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(bird.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(snowfall.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(sculpture.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * @example 
            * // Set the orientation on initialization. 
            * &lt;div id="rotator" &gt;	
            * &lt;/div&gt;
            * &lt;div id="rotatorcontent" &gt;
            * &lt;div &gt;
            * &lt;div style="background-image:url(nature.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(bird.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(snowfall.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(sculpture.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;<br>
            * &lt;script&gt; 
            * $(function(){
            * //To set the orientation API value 
            * $("#rotator").ejmRotator({ targetId: "rotatorcontent", orientation: ej.mobile.Rotator.Orientation.Horizontal  });			
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the orientation, after initialization:<br>
            * // Get the orientation API value.	
            *  $("#rotator").ejmRotator ("option", "orientation");			
            * // Set the orientation API
            * $("#rotator").ejmRotator ("option", "orientation", ej.mobile.Rotator.Orientation.Horizontal);            
            * @memberof ejmRotator
            * @instance	
            */
            orientation: "horizontal",
            /**     
            * Section for pagerPosition specific functionalities.                      
            * @memberof ejmRotator            
            * @instance
            */
            pagerPosition: {
                /**		
                * Specifies the PagerPosition Horizontal to the top or bottom position. See {@link PagerPositionHorizontal }
                * @alias ejmRotator#pagerPosition->horizontal
                * @default ej.mobile.Rotator.PagerPositionHorizontal.Bottom
                * @type {enum}
                * @example 
                * //Set the pagerPosition horizontal property in unobtrusive way.
                * &lt;div id="rotator" data-role="ejmrotator" data-ej-targetid="rotatorcontent" data-ej-pagerposition-horizontal="bottom" &gt;
                * &lt;/div&gt;
                * &lt;div id="rotatorcontent" &gt;
                * &lt;div &gt;
                * &lt;div style="background-image:url(nature.jpg);height:350px;width:630px"&gt;
                * &lt;/div&gt;
                * &lt;/div&gt;&lt;div &gt;	        
                * &lt;div style="background-image:url(bird.jpg);height:350px;width:630px"&gt;
                * &lt;/div&gt;
                * &lt;/div&gt;&lt;div &gt;	        
                * &lt;div style="background-image:url(snowfall.jpg);height:350px;width:630px"&gt;
                * &lt;/div&gt;
                * &lt;/div&gt;&lt;div &gt;	        
                * &lt;div style="background-image:url(sculpture.jpg);height:350px;width:630px"&gt;
                * &lt;/div&gt;
                * &lt;/div&gt;
                * &lt;/div&gt;
                * @example 
                * // Set the pagerPosition horizontal on initialization. 
                * &lt;div id="rotator" &gt;	
                * &lt;/div&gt;
                * &lt;div id="rotatorcontent" &gt;
                * &lt;div &gt;
                * &lt;div style="background-image:url(nature.jpg);height:350px;width:630px"&gt;
                * &lt;/div&gt;
                * &lt;/div&gt;&lt;div &gt;	
                * &lt;div style="background-image:url(bird.jpg);height:350px;width:630px"&gt;
                * &lt;/div&gt;
                * &lt;/div&gt;&lt;div &gt;	
                * &lt;div style="background-image:url(snowfall.jpg);height:350px;width:630px"&gt;
                * &lt;/div&gt;
                * &lt;/div&gt;&lt;div &gt;	
                * &lt;div style="background-image:url(sculpture.jpg);height:350px;width:630px"&gt;
                * &lt;/div&gt;
                * &lt;/div&gt;
                * &lt;/div&gt;<br>
                * &lt;script&gt; 
                * $(function(){
                * //To set the pagerPosition horizontal API value 
                * $("#rotator").ejmRotator({ targetId: "rotatorcontent", pagerPosition: { horizontal: ej.mobile.Rotator.PagerPositionHorizontal.Bottom }});			
                * });
                * &lt;/script&gt;
                * @example 
                * //Get or set the pagerPosition horizontal, after initialization:<br>
                * // Get the pagerPosition horizontal API value.	
                *  $("#rotator").ejmRotator ("option", "pagerPosition.horizontal");			
                * // Set the pagerPosition horizontal API
                * $("#rotator").ejmRotator ("option", "pagerPosition.horizontal", ej.mobile.Rotator.PagerPositionHorizontal.Bottom);            
                * @memberof ejmRotator
                * @instance	
                */
                "horizontal": "bottom",
                /**		
                * Specifies the PagerPosition Vertical to the top or bottom position. See {@link PagerPositionVertical }
                * @alias ejmRotator#pagerPosition->vertical
                * @default ej.mobile.Rotator.PagerPositionVertical.Right
                * @type {enum}
                * @example 
                * //Set the pagerPosition vertical property in unobtrusive way.
                * &lt;div id="rotator" data-role="ejmrotator" data-ej-targetid="rotatorcontent" data-ej-orientation="vertical" data-ej-pagerposition-vertical="right" &gt;
                * &lt;/div&gt;
                * &lt;div id="rotatorcontent" &gt;
                * &lt;div &gt;
                * &lt;div style="background-image:url(nature.jpg);height:350px;width:630px"&gt;
                * &lt;/div&gt;
                * &lt;/div&gt;&lt;div &gt;	        
                * &lt;div style="background-image:url(bird.jpg);height:350px;width:630px"&gt;
                * &lt;/div&gt;
                * &lt;/div&gt;&lt;div &gt;	        
                * &lt;div style="background-image:url(snowfall.jpg);height:350px;width:630px"&gt;
                * &lt;/div&gt;
                * &lt;/div&gt;&lt;div &gt;	        
                * &lt;div style="background-image:url(sculpture.jpg);height:350px;width:630px"&gt;
                * &lt;/div&gt;
                * &lt;/div&gt;
                * &lt;/div&gt;
                * @example 
                * // Set the pagerPosition vertical on initialization. 
                * &lt;div id="rotator" &gt;	
                * &lt;/div&gt;
                * &lt;div id="rotatorcontent" &gt;
                * &lt;div &gt;
                * &lt;div style="background-image:url(nature.jpg);height:350px;width:630px"&gt;
                * &lt;/div&gt;
                * &lt;/div&gt;&lt;div &gt;	
                * &lt;div style="background-image:url(bird.jpg);height:350px;width:630px"&gt;
                * &lt;/div&gt;
                * &lt;/div&gt;&lt;div &gt;	
                * &lt;div style="background-image:url(snowfall.jpg);height:350px;width:630px"&gt;
                * &lt;/div&gt;
                * &lt;/div&gt;&lt;div &gt;	
                * &lt;div style="background-image:url(sculpture.jpg);height:350px;width:630px"&gt;
                * &lt;/div&gt;
                * &lt;/div&gt;
                * &lt;/div&gt;<br>
                * &lt;script&gt; 
                * $(function(){
                * //To set the pagerPosition vertical API value 
                * $("#rotator").ejmRotator({ targetId: "rotatorcontent", orientation: "vertical", pagerPosition: { vertical: ej.mobile.Rotator.PagerPositionVertical.Right }});		
                * });
                * &lt;/script&gt;
                * @example 
                * //Get or set the pagerPosition vertical, after initialization:<br>
                * // Get the pagerPosition vertical API value.	
                *  $("#rotator").ejmRotator ("option", "pagerPosition.vertical");			
                * // Set the pagerPosition vertical API
                * $("#rotator").ejmRotator ("option", "pagerPosition.vertical", ej.mobile.Rotator.PagerPositionVertical.Right);            
                * @memberof ejmRotator
                * @instance	
                */
                "vertical": "right"
            },
            /**		
            * Current model value to browser cookies for state maintains. While refresh the Rotator control page retains the model value apply from browser cookies.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the enablePersistence property in unobtrusive way.
            * &lt;div id="rotator" data-role="ejmrotator" data-ej-targetid="rotatorcontent" data-ej-enablepersistence=true &gt;
            * &lt;/div&gt;
            * &lt;div id="rotatorcontent" &gt;
            * &lt;div &gt;
            * &lt;div style="background-image:url(nature.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(bird.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(snowfall.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	        
            * &lt;div style="background-image:url(sculpture.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * @example 
            * // Set the enablePersistence on initialization. 
            * &lt;div id="rotator" &gt;	
            * &lt;/div&gt;
            * &lt;div id="rotatorcontent" &gt;
            * &lt;div &gt;
            * &lt;div style="background-image:url(nature.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(bird.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(snowfall.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;&lt;div &gt;	
            * &lt;div style="background-image:url(sculpture.jpg);height:350px;width:630px"&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;/div&gt;<br>
            * &lt;script&gt; 
            * //To set the enablePersistence API value 
            * $("#rotator").ejmRotator({ targetId: "rotatorcontent", enablePersistence: true });			
            * &lt;/script&gt;
            * @example 
            * //Get or set the enablePersistence, after initialization:<br>
            * // Get the enablePersistence API value.	
            *  $("#rotator").ejmRotator ("option", "enablePersistence");			
            * // Set the enablePersistence API
            * $("#rotator").ejmRotator ("option", "enablePersistence", true);            
            * @memberof ejmRotator
            * @instance	
            */
            enablePersistence: false,
            /**     
            * Section for windows rendermode specific functionalities.                      
            * @memberof ejmRotator
            * @instance
            */
            windows: {
                /**		
                * Specifies whether to render the rotator based on the windowsphone's current accent color and device theme.
                * @default false
                * @type {boolean}
                * @alias ejmRotator#windows->renderDefault
                * @example 
                * // Set the windows mode renderDefault property in unobtrusive way.
                * &lt;div id="rotator" data-role="ejmrotator" data-ej-targetid="rotatorcontent" data-ej-windows-renderdefault="true" &gt;
                * &lt;/div&gt;
                * &lt;div id="rotatorcontent" &gt;
                * &lt;div &gt;
                * &lt;div style="background-image:url(nature.jpg);height:350px;width:630px"&gt;
                * &lt;/div&gt;
                * &lt;/div&gt;&lt;div &gt;	        
                * &lt;div style="background-image:url(bird.jpg);height:350px;width:630px"&gt;
                * &lt;/div&gt;
                * &lt;/div&gt;&lt;div &gt;	        
                * &lt;div style="background-image:url(snowfall.jpg);height:350px;width:630px"&gt;
                * &lt;/div&gt;
                * &lt;/div&gt;&lt;div &gt;	        
                * &lt;div style="background-image:url(sculpture.jpg);height:350px;width:630px"&gt;
                * &lt;/div&gt;
                * &lt;/div&gt;
                * &lt;/div&gt;
                * @example 
                * // Set the windows renderDefault on initialization. 
                * &lt;div id="rotator" &gt;	
                * &lt;/div&gt;
                * &lt;div id="rotatorcontent" &gt;
                * &lt;div &gt;
                * &lt;div style="background-image:url(nature.jpg);height:350px;width:630px"&gt;
                * &lt;/div&gt;
                * &lt;/div&gt;&lt;div &gt;	
                * &lt;div style="background-image:url(bird.jpg);height:350px;width:630px"&gt;
                * &lt;/div&gt;
                * &lt;/div&gt;&lt;div &gt;	
                * &lt;div style="background-image:url(snowfall.jpg);height:350px;width:630px"&gt;
                * &lt;/div&gt;
                * &lt;/div&gt;&lt;div &gt;	
                * &lt;div style="background-image:url(sculpture.jpg);height:350px;width:630px"&gt;
                * &lt;/div&gt;
                * &lt;/div&gt;
                * &lt;/div&gt;<br>                
                * &lt;script&gt; 
                * //To set the windows renderDefault API value 
                * $("#rotator").ejmRotator({ targetId: "rotatorcontent", windows:{ renderDefault: true} });			
                * &lt;/script&gt;
                * @example 
                * //Get or set the windows renderDefault, after initialization:<br>
                * // Get the windows renderDefault API value.	
                *  $("#rotator").ejmRotator ("option", "windows.renderDefault");			
                * // Set the windows renderDefault API
                * $("#rotator").ejmRotator ("option", "windows.renderDefault", true);            
                * @memberof ejmRotator
                * @instance	
                */
                "renderDefault": false
            }
        },
        // Datatypes of model variables
        dataTypes: {
            renderMode: "enum",
            theme: "enum",
            showPager: "boolean",
            pagerPosition: { "horizontal": "enum", "vertical": "enum" },
            orientation: "enum",
            showHeader: "boolean",
            dataBinding: "boolean",
            dataSource: "data",
            enablePersistence: "boolean",
            windows: { "renderDefault": "boolean" }
        },
        observables: ["currentItemIndex"],
        currentItemIndex: ej.util.valueFunction("currentItemIndex"),
        /**
        * Create the Rotator widget
        * @private
        */
        _init: function () {
            this._setValues();
            this._createDelegate();
            this._renderControl();
            this._wireEvents();
        },
        /**
        * To set Rotator model values
        * @private
        */
        _setValues: function () {
            ej.setRenderMode(this);
            ej.setTheme(this);
            if (this.model.renderMode == "windows" && this.model.windows.renderDefault && ej.isMobile())
                this.model.theme = "default";
            this._wrapper = ej.getCurrentPage().find("#" + this.model.targetId);
            this._orgEle = this._wrapper;
            this._id = this.element.attr("id");
            this._divCount = this._wrapper.children().length;
            this._autoHeightWidthValues();
            this._browser = ej.browser();
            this._startValues();
        },
        /**
        * To do auto height and width values
        * @private
        */
        _autoHeightWidthValues: function () {
            this._mHeight = this.model.targetHeight == "auto" ? ej.getDimension(this.element.parent(),"height") : parseInt(this.model.targetHeight);
            this._mWidth = this.model.targetWidth == "auto" ? ej.getDimension(this.element.parent(),"width") : parseInt(this.model.targetWidth);
        },
        /**
        * To do Top and Left values
        * @private
        */
        _topLeftVaules: function () {
            if (this.model.renderMode == "android")
                this._andSpanVal = (this.model.orientation == "horizontal" ? this._mWidth : this._mHeight) / this._divCount;
            else
                this._spanVal = (this.model.orientation == "horizontal" ? this._mWidth : this._mHeight) / 2 - (ej.getDimension(this._span, 'width')) / 2;
            this._span.addClass("e-m-sv-pager" + this.model.pagerPosition[this.model.orientation] + "");
        },
        /**
        * To do Starting values of Scroll View 
        * @private
        */
        _startValues: function () {
            this._moveEle = (this._divCount > this.currentItemIndex() && this.currentItemIndex() >= 0) ? -(this.currentItemIndex() * ((this.model.orientation == "horizontal") ? this._mWidth : this._mHeight)) : 0;
            this._divEle = this._moveEle ? this.currentItemIndex() + 1 : 1;
            this._timeStart = 0;
        },
        /**
        * To do Scroll View Transform values
        * @private
        */
        _transform: function (dist, time, and) {
            var translate = "-" + this._browser + "-transform",
                translateVal = this.model.orientation == "horizontal" ? "translate3d(" + dist + "px,0px,0px) scale(1)" : "translate3d(0px," + dist + "px,0px) scale(1)",
                trans = "-" + this._browser + "-transition-property",
                transVal = "transform",
                transDur = "-" + this._browser + "-transition-duration",
                transDurVal = time + "ms";
            if (and == "pager")
                this._span.css(translate, translateVal).css(trans, transVal).css(transDur, transDurVal);
            else
                this._wrapper.css(translate, translateVal).css(trans, transVal).css(transDur, transDurVal);
        },
        /**
        * To render Scroll View control
        * @private
        */
        _renderControl: function () {
            ej.setRenderMode(this);
            if (this.model.showHeader)
                this._renderHeader();
            this.element.addClass("e-m-" + this.model.renderMode + " e-m-" + this.model.theme + " e-m-rotator e-m-user-select").append(this._wrapper);
            if (this.model.dataBinding)
                this._renderDatabind();
            else
                this._renderDataProAndtemp();
        },
        /**
        * To render Scoll View Header
        * @private
        */
        _renderHeader: function () {
            this.element.addClass('e-m-rotatorheader');
            this.header = ej.buildTag("div");
            this.element.append(this.header.ejmHeader({ "title": this.model.headerTitle, "renderMode": this.model.renderMode, "position": "normal" }));
            if (this.model.renderMode != "flat")
                this.header.ejmHeader({ "theme": this.model.theme });
        },
        /**
        * To render Databinding 
        * @private
        */
        _renderDatabind: function () {
            var jsRender = ej.buildTag("script#" + this._id + "_Template", {}, {}, { "type": "text/x-jsrender" });
            var tempEle = this._wrapper.find(">div");
            tempEle.remove();
            var newTemp = ej.buildTag("div").append(tempEle);
            jsRender[0].text = newTemp[0].innerHTML;
            ej.getCurrentPage().append(jsRender);
            if (this.model.dataSource)
                this.renderDatasource(this.model.dataSource);
        },
        /**
        * To render Data Properties and Template 
        * @private
        */
        _renderDataProAndtemp: function () {
            this._imgTag = this._wrapper.find("div:nth-child(1)").attr("data-ej-imageurl");
            this._textTag = this._wrapper.find("div:nth-child(1)").attr("data-ej-text");
            if (this._imgTag != undefined || this._textTag != undefined)
                this._tagCreate();
            this._scrollItem();
            this._transform(this._moveEle, 350, "");
            this._renderPager();
        },
        /**
        * To do scroll Item
        * @private
        */
        _scrollItem: function () {
            this.element.css({ "width": "" + this._mWidth + "px", "height": "" + (this._mHeight + this.element.find(".e-m-header").outerHeight()) + "px" });
            this._wrapper.addClass("e-m-sv-container e-m-" + this.model.orientation + "").css({ "height": "" + this._mHeight + "", "width": "" + this._mWidth + "" });
            this._wrapper.children().addClass("e-m-rot-item");
        },
        /**
        * To create html tag
        * @private
        */
        _tagCreate: function () {
            this._img = false;
            this._p = false;
            for (i = 1; i <= this._divCount; i++) {
                this._image = this._wrapper.find("div:nth-child(" + i + ")").attr("data-ej-imageurl");
                this._text = this._wrapper.find("div:nth-child(" + i + ")").attr("data-ej-text");
                if (this._imgTag != undefined) {
                    this._divImage = ej.buildTag("div").css({
                        "background-image": "url(" + this._image + ")",
                        "background-position": "center", "background-size": "100%", "background-repeat": "no-repeat", "height": "100%", "width": "100%"
                    });
                    this._img = true;
                }
                if (this._textTag != undefined) {
                    this._para = ej.buildTag("p").html(this._text).css({ "text-align": "center" });
                    this._p = true;
                }
                if (this._img == true && this._p == true)
                    this._wrapper.find("div:nth-child(" + i + ")").append(this._divImage).append(this._para);
                else if (this._img == true && this._p == false)
                    this._wrapper.find("div:nth-child(" + i + ")").append(this._divImage);
                else if (this._img == false && this._p == true)
                    this._wrapper.find("div:nth-child(" + i + ")").append(this._para);
            }
        },
        /**
        * To render Scroll View Pager	
        * @private
        */
        _renderPager: function () {
            this._span = ej.buildTag("div.e-m-abs e-m-" + this.model.theme + "");
            this._wrapper.after(this._span);
            if (this.model.renderMode != "android") {
                for (i = 0; i < this._divCount; i++)
                    this._span.append(ej.buildTag("span.e-m-sv-pager"));
                this._span.find(":nth-child(" + this._divEle + ")").addClass("e-m-active");
            }
            else
                this._span.append(ej.buildTag("span.e-m-sv-pager e-m-active"));
            this._pagerPos();
            this._setShowPager();
        },
        /**
        * To set Pager position	
        * @private
        */
        _pagerPos: function () {
            this._topLeftVaules();
            if (this.model.renderMode == "android") {
                this._spanTrans = (this._divEle - 1) * this._andSpanVal;
                this.model.orientation == "horizontal" ? this._span.children().css({ "width": "" + this._andSpanVal + "px" }).fadeOut("slow") : this._span.children().css({ "height": "" + this._andSpanVal + "px" }).fadeOut("slow");
                this._transform(this._spanTrans, 350, "pager");
            }
            else
                this.model.orientation == "horizontal" ? this._span.css("left", this._spanVal + "px") : this._span.css("top", (this._spanVal + this.element.find(".e-m-header").outerHeight()) + "px");
        },
        /**
        * To wire the events for Scroll View	
        * @private
        */
        _wireEvents: function (remove) {
            this._onMouseDownDelg = $.proxy(this._onMouseDownHandler, this);
            this._onMouseMoveDelg = $.proxy(this._onMouseMoveHandler, this);
            this._onMouseUpDelg = $.proxy(this._onMouseUpHandler, this);
            var evt = !ej.isTouchDevice() ? "resize" : "orientationchange";
            ej.listenTouchEvent(this._wrapper, ej.startEvent(), this._onMouseDownDelg, remove);
            if (this.model.targetHeight == "auto" || this.model.targetWidth == "auto") {
                ej.listenEvents([window], [evt], [this._onOrientationChangeDelegate], remove);

            }
            this._pagerEvents(remove);
        },
        _createDelegate: function () {
            this._onOrientationChangeDelegate = $.proxy(this._onOrientationChangeHandler, this);
        },
        /**
        * To wire the events for Scroll View pager
        * @private
        */
        _pagerEvents: function (rem) {
            if (this.model.renderMode != "android") {
                this._spanEle = this.element.find("div.e-m-abs").children();
                this._onTouchStartDelegate = $.proxy(this._onTouchStartHandler, this);
                this._onTouchEndDelegate = $.proxy(this._onTouchEndHandler, this);
                ej.listenEvents([this._spanEle, this._spanEle], [ej.startEvent(), ej.endEvent()], [this._onTouchStartDelegate, this._onTouchEndDelegate], rem);
            }
        },
        /**
        * To Handle TouchStart event
        * @private
        */
        _onTouchStartHandler: function (evt) {
            this._index = $(evt.currentTarget).index();
        },
        /**
        * To Handle TouchEnd event
        * @private
        */
        _onTouchEndHandler: function (evt) {
            this._moveEle = -(this._index * (this.model.orientation == "horizontal" ? this._mWidth : this._mHeight));
            this._transform(this._moveEle, 350, "");
            this._span.find(":nth-child(" + this._divEle + ")").removeClass("e-m-active");
            this._divEle = this._index + 1;
            this._span.find(":nth-child(" + this._divEle + ")").addClass("e-m-active");
            var data = { targetElement: this._wrapper, element: this._divEle };
            if (this.model.pagerSelect)
                this._trigger("pagerselect", data);
        },
        /**
        * To Handle OrientationChange event
        * @private
        */
        _onOrientationChangeHandler: function (evt) {
            var proxy = this;
            window.setTimeout(function () {
                evt.preventDefault();
                proxy._orientationAndResize();
            }, ej.isAndroid() ? 250 : 0);
        },
        /**
        * To do Orientation change and Resize values
        * @private
        */
        _orientationAndResize: function () {
            this._autoHeightWidthValues();
            var val = this.model.orientation == "horizontal" ? this._mWidth : this._mHeight;
            this._moveEle = -((this._divEle * val) - val);
            this._transform(this._moveEle, 0, "");
            this._scrollItem();
            this._spanTrans = (this._divEle - 1) * this._andSpanVal;
            this._pagerPos();
        },
        /**
        * Touch start event handler
        * @private
        */
        _onMouseDownHandler: function (evt) {
            if (ej.isTouchDevice())
                evt = evt.touches ? evt.touches[0] : evt;
            this._startX = evt.clientX;
            this._startY = evt.clientY;
            this._timeStart = evt.timeStamp || Date.now();
            ej.listenEvents([this._wrapper, this._wrapper], [ej.moveEvent(), ej.endEvent()], [this._onMouseMoveDelg, this._onMouseUpDelg], false);
            if (this.model.renderMode == "android")
                this._span.children().clearQueue();
        },
        /**
        * Touch move event handler
        * @private
        */
        _onMouseMoveHandler: function (evt) {
            if (ej.isTouchDevice())
                evt = evt.touches ? evt.touches[0] : evt;
            this._relativeX = evt.clientX - this._startX;
            this._relativeY = evt.clientY - this._startY;
            if (this.model.orientation == "horizontal") {
                this._start = this._startX;
                this._relative = this._relativeX;
                this._distValue = this._mWidth;
                this._swipeLeftUp = "swipeLeft";
                this._swipeRightDown = "swipeRight";
            }
            else {
                this._start = this._startY;
                this._relative = this._relativeY;
                this._distValue = this._mHeight;
                this._swipeLeftUp = "swipeUp";
                this._swipeRightDown = "swipeDown";
            }
            if (this._start != 0 && Math.abs(this._relative)) {
                if ((this._relative < 0 && this._divEle < this._divCount) || (this._relative > 0 && this._divEle > 1)) {
                    var move = this._moveEle + this._relative;
                    this._transform(move, 0, "");
                }
                else {
                    if (Math.abs(this._relative) < this._distValue / 2) {
                        var move = this._moveEle + this._relative;
                        this._transform(move, 0, "");
                    }
                }
            }
            if (this._start != 0 && this.model.renderMode == "android") {
                var tra = this._relative / 4;
                if ((this._relative < 0 && this._divEle < this._divCount) || (this._relative > 0 && this._divEle > 1))
                    var trans = this._spanTrans - tra;
                this._transform(trans, 0, "pager");
                this._span.children().css("opacity", 1).fadeIn("slow");
            }
            ej.listenTouchEvent(this._wrapper, "mouseleave", this._onMouseUpDelg, false);
        },
        /**
        * Touch end event handler
        * @private
        */
        _onMouseUpHandler: function (evt) {
            if (this._timeStart != 0) {
                this._data = { targetElement: this._wrapper, element: this._divEle };
                var duration = (evt.timeStamp || Date.now()) - this._timeStart,
                momentumX = { dist: 0, time: 0 },
                reverse = this._relative > 0 ? true : false,
                moveDist = this._relative;
                if (duration < 300) {
                    momentumX = this._relative ? this._momentum(this._relative, duration, (reverse ? this._relative : -this._relative), this._distValue + this._relative, this._distValue) : momentumX;
                    moveDist = this._relative + momentumX.dist;
                }
                if (moveDist < 0 && Math.abs(moveDist) > this._distValue / 2 && this._divEle < this._divCount) {
                    this._moveEle += -this._distValue;
                    if (this.model.showPager)
                        this._movePager(true);
                    else {
                        this._divEle++;
                        this._spanTrans = (this._divEle - 1) * this._andSpanVal;
                    }
                    this._transform(this._moveEle, 350, "");
                    if (this.model.swipeLeft || this.model.swipeUp)
                        this._trigger(this._swipeLeftUp, this._data);
                }
                else if (moveDist > 0 && Math.abs(moveDist) > this._distValue / 2 && this._divEle > 1) {
                    this._moveEle -= -this._distValue;
                    if (this.model.showPager)
                        this._movePager(false);
                    else {
                        this._divEle--;
                        this._spanTrans = (this._divEle - 1) * this._andSpanVal;
                    }
                    this._transform(this._moveEle, 350, "");
                    if (this.model.swipeRight || this.model.swipeDown)
                        this._trigger(this._swipeRightDown, this._data);
                }
                this._transform(this._moveEle, 350, "");
                if (this.model.renderMode == "android") {
                    this._transform(this._spanTrans, 350, "pager");
                    this._span.children().fadeOut("slow");
                }
                this._timeStart = 0;
                this._startX = 0;
                this._relativeX = 0;
                this._relative = 0;
                this._start = 0;
                ej.listenEvents([this._wrapper, this._wrapper], [ej.moveEvent(), ej.endEvent()], [this._onMouseMoveDelg, this._onMouseUpDelg], true);
            }
            this.currentItemIndex(this._divEle - 1);
        },
        /**
        * To do scroll view momentum values
        * @private
        */
        _momentum: function (dist, time, maxDistUpper, maxDistLower, size) {
            var deceleration = 0.0006,
            speed = Math.abs(dist) / time,
            newDist = (speed * speed) / (2 * deceleration),
            newTime = 0, outsideDist = 0;
            if (dist > 0 && newDist > maxDistUpper) {
                outsideDist = size / (6 / (newDist / speed * deceleration));
                maxDistUpper = maxDistUpper + outsideDist;
                speed = speed * maxDistUpper / newDist;
                newDist = maxDistUpper;
            } else if (dist < 0 && newDist > maxDistLower) {
                outsideDist = size / (6 / (newDist / speed * deceleration));
                maxDistLower = maxDistLower + outsideDist;
                speed = speed * maxDistLower / newDist;
                newDist = maxDistLower;
            }
            newDist = newDist * (dist < 0 ? -1 : 1);
            newTime = speed / deceleration;
            return { dist: newDist, time: Math.round(newTime) };
        },
        /**
        * To do Pager Selection
        * @private
        */
        _movePager: function (page) {
            if (this.model.renderMode != "android") {
                this._span.find(":nth-child(" + this._divEle + ")").removeClass("e-m-active");
                this._divEle = page ? (this._divEle + 1) : (this._divEle - 1);
                this._span.find(":nth-child(" + this._divEle + ")").addClass("e-m-active");
                this._spanTrans = (this._divEle - 1) * this._andSpanVal;
            }
            else {
                this._divEle = page ? (this._divEle + 1) : (this._divEle - 1);
                this._spanTrans = (this._divEle - 1) * this._andSpanVal;
                this._transform(this._spanTrans, 350, "pager");
                this._span.children().fadeOut("slow");
            }
            this._data = { targetElement: this._wrapper, element: this._divEle };
            if (this.model.change)
                this._trigger("change", this._data);
        },
        /**
        * To configure the properties at runtime	
        * @private
        */
        _setModel: function (options) {
            var refresh = false;
            for (var prop in options) {
                if (prop != "swipeLeft" || prop != "swipeRight")
                    var setModel = "_set" + prop.charAt(0).toUpperCase() + prop.slice(1);
                if (this[setModel])
                    this[setModel]();
                else
                    refresh = true;
            }
            if (refresh)
                this._refresh();
        },
        /**
        * To configure the RenderMode properties at runtime using SetModel		
        * @private
        */
        _setRenderMode: function () {
            this.element.removeClass("e-m-ios7 e-m-android e-m-windows e-m-flat").addClass("e-m-" + this.model.renderMode + "");
            this.element.find(".e-m-header").ejmHeader({ "renderMode": this.model.renderMode });
            this._pagerEvents(true);
            this._span.remove();
            this._renderPager();
            this._pagerEvents(false);
        },
        /**
        * To configure the Theme properties at runtime using SetModel		
        * @private
        */
        _setTheme: function () {
            this.element.removeClass("e-m-dark e-m-light").addClass("e-m-" + this.model.theme + "");
            this._span.removeClass("e-m-dark e-m-light").addClass("e-m-" + this.model.theme + "");
            this.element.find(".e-m-header").ejmHeader({ "theme": this.model.theme });
        },
        /**
        * To configure the showHeader properties at runtime using SetModel		
        * @private
        */
        _setShowHeader: function () {
            this.model.currentItemIndex = this._divEle - 1;
            this._refresh();
        },
        /**
        * To configure the HeaderTitle properties at runtime using SetModel		
        * @private
        */
        _setHeaderTitle: function () {
            this.element.find(".e-m-header").ejmHeader({ "title": this.model.headerTitle });
        },
        /**
        * To configure the showPager properties at runtime using SetModel		
        * @private
        */
        _setShowPager: function () {
            if (!this.model.showPager)
                this._span.css("display", "none");
            else
                this._span.css("display", "block");
        },
        /**
        * To configure the PagerPosition properties at runtime using SetModel		
        * @private
        */
        _setPagerPosition: function () {
            this._span.removeClass("e-m-sv-pagertop e-m-sv-pagerbottom e-m-sv-pagerleft e-m-sv-pagerright");
            this._span.addClass("e-m-sv-pager" + this.model.pagerPosition[this.model.orientation] + "");
        },
        /**
        * To configure the Orientation properties at runtime using SetModel		
        * @private
        */
        _setOrientation: function () {
            this.model.currentItemIndex = this._divEle - 1;
            this._refresh();
        },
        /**
        * To configure the CurrentItemIndex properties at runtime using SetModel		
        * @private
        */
        _setCurrentItemIndex: function () {
            if (this.model.renderMode != "android")
                this._span.find(":nth-child(" + this._divEle + ")").removeClass("e-m-active");
            this._startValues();
            this._transform(this._moveEle, 1000, "");
            this._spanTrans = (this._divEle - 1) * this._andSpanVal;
            (this.model.renderMode != "android") ? this._span.find(":nth-child(" + this._divEle + ")").addClass("e-m-active") : this._transform(this._spanTrans, 350, "pager");
        },
        /**
        * To refresh Rotator control		
        * @private
        */
        _refresh: function () {
            this._destroy();
            this._init();
        },
        /**
        * To destroy Rotator control		
        * @private
        */
        _destroy: function () {
            this._wireEvents(true);
            this._wrapper.children().removeAttr("class style");
            this.element.removeAttr("class style").children().removeAttr("class style").remove();
            this._span.remove();
            App.activePage.append(this._orgEle);
        },

        /*---------------Public Methods---------------*/

        // To render DataSource value
        /**
        * To handle the rotator datasource
        * @return jQuery
        * @example             
        * &lt;div id="rotator" &gt;
        * &lt;/div&gt;
        * &lt;div id="rotatorcontent" &gt;
        * &lt;div &gt;
        * &lt;div style="background-image:url{{:imageurl}};height:350px;width:630px" &gt;
        * &lt;/div&gt;
        * &lt;/div&gt;
        * &lt;/div&gt;            
        * //To set the dataSource API value
        * &lt;script &gt;
        * $("#rotator").ejmRotator({ targetId: "rotatorcontent", dataBinding: true });
        * var rotObj = $("#rotator").data("ejmRotator");
        * rotObj.renderDatasource(imgdata); 
        * &lt;/script &gt;
        * @example             
        * &lt;div id="rotator" &gt;
        * &lt;/div&gt;
        * &lt;div id="rotatorcontent" &gt;
        * &lt;div &gt;
        * &lt;div style="background-image:url{{:imageurl}};height:350px;width:630px" &gt;
        * &lt;/div&gt;
        * &lt;/div&gt;
        * &lt;/div&gt;            
        * //To set the dataSource API value
        * &lt;script &gt;
        * $("#rotator").ejmRotator({ targetId: "rotatorcontent", dataBinding: true });
        * $("#rotator").ejmRotator("renderDatasource", imgdata);
        * &lt;/script &gt;
        * @memberof ejmRotator
        * @instance
        */
        renderDatasource: function (data) {
            var template = $.templates("#" + this._id + "_Template");
            var htmlOutput = template.render(data);
            this._wrapper.html(htmlOutput);
            this._divCount = this._wrapper.children().length;
            this._scrollItem();
            this._transform(this._moveEle, 350, "");
            this._renderPager();
            this._wireEvents();
        }
        /*---------------Public Methods End---------------*/
    });
    /**
    * Enum for Orientation 
    * @enum {string}
    * @global
    */
    ej.mobile.Rotator.Orientation = {
        /**
        Enum for Horizontal Orientation*/
        Horizontal: "horizontal",
        /**
        Enum for Vertical Orientation*/
        Vertical: "vertical"
    };
    /**
    * Enum for PagerPositionHorizontal
    * @enum {string}
    * @global
    */
    ej.mobile.Rotator.PagerPositionHorizontal = {
        /**
        Enum for Bottom PagerPositionHorizontal*/
        Bottom: "bottom",
        /**
        Enum for Top PagerPositionHorizontal*/
        Top: "top"
    };
    /**
    * Enum for PagerPositionVertical
    * @enum {string}
    * @global
    */
    ej.mobile.Rotator.PagerPositionVertical = {
        /**
        Enum for Right PagerPositionVertical*/
        Right: "right",
        /**
        Enum for Left PagerPositionVertical*/
        Left: "left"
    };
})(jQuery, Syncfusion);