/**
* @fileOverview Plugin to style the Html Scrollpanel elements
* @copyright Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/

(function ($, ej, undefined) {
    // mScrollPanel is the plugin name 
    // "m.ScrollPanel" is "namespace.className" will hold functions and properties

    /**
    * @namespace ej
    * @class ejmScrollPanel
    * @requires jQuery
    * @requires ej.mobile.application
    * @requires ej.core
    * @requires ej.unobtrusive
    * @requires ej.mobile.core
    * @requires ej.data
    * @requires ej.touch
    * @requires ej.mobile.scrollbar
    * @classdesc Custom Design for Html Scrollpanel control.
    * @example 
    * // Create scrollpanel control in unobtrusive way.
    * &lt;div id="maincontent"&gt;
    *   &lt;div&gt;
    *       Scroll content here
    *   &lt;/div&gt;
    * &lt;/div&gt;
    * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" /&gt;
    */

    nextFrame = (function () {
        return window.requestAnimationFrame ||
			window.webkitRequestAnimationFrame ||
			window.mozRequestAnimationFrame ||
			window.oRequestAnimationFrame ||
			window.msRequestAnimationFrame ||
			function (callback) { return setTimeout(callback, 1); };
    })();
    cancelFrame = (function () {
        return window.cancelRequestAnimationFrame ||
			window.webkitCancelAnimationFrame ||
			window.webkitCancelRequestAnimationFrame ||
			window.mozCancelRequestAnimationFrame ||
			window.oCancelRequestAnimationFrame ||
			window.msCancelRequestAnimationFrame ||
			clearTimeout;
    })();
    ej.widget("ejmScrollPanel", "ej.mobile.ScrollPanel", {
        _setFirst: true,
        _rootCSS: "e-m-scroll",
        // default model
        defaults: {

            /**		
            * Specifies the rendering mode of the control. See {@link RenderMode}
            * @default auto 
            * @type {enum}
            * @example 
            * // Set the renderMode property in unobtrusive way.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" data-ej-rendermode="auto"/&gt;	
            * @example 
            * // Set the renderMode property on initilization.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#scrollpanel").ejmScrollPanel({target:"maincontent", renderMode:ej.mobile.RenderMode.Auto});		
            * });
            * &lt;/script&gt; 
            * @example 
            * // Get or set the scrollpanel rendermode, after initialization:<br>
            * &lt;script&gt;
            * // Get the renderMode API value.		
            *  $("#scrollpanel").ejmScrollPanel("option", "renderMode");			
            * // Set the renderMode API
            * $("#scrollpanel").ejmScrollPanel("option", "renderMode", ej.mobile.RenderMode.Auto);            
            * &lt;/script&gt; 
            * @memberof ejmScrollPanel
            * @instance
            */
            renderMode: 'auto',

            /**		
            * Specifies the theme. See {@link Theme}
            * @default auto
            * @type {enum}
            * @example 
            * // Set the theme property in unobtrusive way.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" data-ej-theme="auto"/&gt;
            * @example
            * // Set the theme property on initilization.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#scrollpanel").ejmScrollPanel({target:"maincontent", theme:ej.mobile.Theme.Auto});		
            * });
            * &lt;/script&gt; 
            * @example 
            * // Get or set the scrollpanel theme, after initialization:<br>
            * &lt;script&gt;
            * // Get the theme API value.		
            *  $("#scrollpanel").ejmScrollPanel("option", "theme");			
            * // Set the theme API
            * $("#scrollpanel").ejmScrollPanel("option", "theme", ej.mobile.Theme.Auto);            
            * &lt;/script&gt;
            * @memberof ejmScrollPanel
            * @instance
            */
            theme: "auto",

            /**		
            * Specifies whether need to resize the scrollbar.
            * @default false
            * @type {boolean}
            * @example 
            * // Set the enableResize property in unobtrusive way.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" data-ej-enableresize="true" /&gt;		
            * @example
            * // Set the enableResize property on initilization.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#scrollpanel").ejmScrollPanel({target:"maincontent", enableResize:true});		
            * });
            * &lt;/script&gt; 
            * @example 
            * // Get or set the scrollpanel enableResize property, after initialization:<br>
            * &lt;script&gt;
            * // Get the enableResize API value.		
            *  $("#scrollpanel").ejmScrollPanel("option", "enableResize");			
            * // Set the enableResize API
            * $("#scrollpanel").ejmScrollPanel("option", "enableResize", true);            
            * &lt;/script&gt;
            * @memberof ejmScrollPanel
            * @instance
            */
            enableResize: true,

            /**		
            * Specifies the target element height.
            * @default null
            * @type {int}
            * @example 
            * // Set the targetHeight property in unobtrusive way.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" data-ej-targetheight="300"/&gt;		
            * @example
            * // Set the targetHeight property on initilization.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#scrollpanel").ejmScrollPanel({target:"maincontent", targetHeight:300});		
            * });
            * &lt;/script&gt; 
            * @example 
            * // Get or set the scrollpanel targetHeight, after initialization:<br>
            * &lt;script&gt;
            * // Get the targetHeight API value.		
            *  $("#scrollpanel").ejmScrollpanel("option", "targetHeight");			
            * // Set the targetHeight API
            * $("#scrollpanel").ejmScrollpanel("option", "targetHeight", "300");            
            * &lt;/script&gt;
            * @memberof ejmScrollPanel
            * @instance
            */
            targetHeight: null,

            /**		
            * Specifies the target element width.
            * @default null
            * @type {int}
            * @example 
            * // Set the targetWidth property in unobtrusive way.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" data-ej-targetwidth="200"/&gt;		
            * @example
            * // Set the targetWidth property on initilization.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#scrollpanel").ejmScrollPanel({target:"maincontent", targetWidth:200});		
            * });
            * &lt;/script&gt; 
            * @example 
            * // Get or set the scrollpanel targetWidth, after initialization:<br>
            * &lt;script&gt;
            * // Get the targetWidth API value.		
            *  $("#scrollpanel").ejmScrollpanel("option", "targetWidth");			
            * // Set the targetWidth API
            * $("#scrollpanel").ejmScrollpanel("option", "targetWidth", "200");            
            * &lt;/script&gt;
            * @memberof ejmScrollPanel
            * @instance
            */
            targetWidth: null,

            /**		
            * Specifies the scroll height of the content.
            * @default null
            * @type {int}
            * @example 
            * // Set the scrollHeight property in unobtrusive way.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" data-ej-scrollheight="300"/&gt;	
            * @example
            * // Set the scrollHeight property on initilization.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#scrollpanel").ejmScrollPanel({target:"maincontent", scrollHeight:300});		
            * });
            * &lt;/script&gt; 
            * @example 
            * // Get or set the scrollpanel content scrollheight, after initialization:<br>
            * &lt;script&gt;
            * // Get the scrollHeight API value.		
            *  $("#scrollpanel").ejmScrollPanel("option", "scrollHeight");			
            * // Set the scrollHeight API
            * $("#scrollpanel").ejmScrollPanel("option", "scrollHeight", "300");            
            * &lt;/script&gt;
            * @memberof ejmScrollPanel
            * @instance
            */
            scrollHeight: null,

            /**		
            * Specifies the scroll width of the content.
            * @default null
            * @type {int}
            * @example 
            * // Set the scrollWidth property in unobtrusive way.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" data-ej-scrollwidth="200"/&gt;	
            * @example
            * // Set the scrolWidth property on initilization.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#scrollpanel").ejmScrollPanel({target:"maincontent", scrollWidth:"200"});		
            * });
            * &lt;/script&gt; 
            * @example 
            * // Get or set the scrollpanel content scrollwidth, after initialization:<br>
            * &lt;script&gt;
            * // Get the scrollWidth API value.		
            *  $("#scrollpanel").ejmScrollPanel("option", "scrollwidth");			
            * // Set the scrollWidth API
            * $("#scrollpanel").ejmScrollPanel("option", "scrollwidth", "200");            
            * &lt;/script&gt;
            * @memberof ejmScrollPanel
            * @instance
            */
            scrollWidth: null,

            /**		
            * Specifies whether need to fade the scrollbars.
            * @default true
            * @type {boolean}
            * @example 
            * // Set the enableFade property in unobtrusive way.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" data-ej-enablefade="true" /&gt;		
            * // Set the enableFade property on initilization.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#scrollpanel").ejmScrollPanel({target:"maincontent", enableFade:true});		
            * });
            * &lt;/script&gt; 
            * @example 
            * // Get or set the scrollpanel enableFade property, after initialization:<br>
            * &lt;script&gt;
            * // Get the enableFade API value.		
            *  $("#scrollpanel").ejmScrollPanel("option", "enableFade");			
            * // Set the enableFade API
            * $("#scrollpanel").ejmScrollPanel("option", "enableFade", true);            
            * &lt;/script&gt;
            * @memberof ejmScrollPanel
            * @instance
            */
            enableFade: true,

            /**		
            * Specifies whether need to shrink the scrollbars.
            * @default false
            * @type {boolean}
            * @example 
            * // Set the enableShrink property in unobtrusive way.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" data-ej-enableshrink="true" /&gt;		
            * // Set the enableShrink property on initilization.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#scrollpanel").ejmScrollPanel({target:"maincontent", enableShrink:"scale"});		
            * });
            * &lt;/script&gt; 
            * @example 
            * // Get or set the scrollpanel enableShrink property, after initialization:<br>
            * &lt;script&gt;
            * // Get the enableShrink API value.		
            *  $("#scrollpanel").ejmScrollPanel("option", "enableShrink");			
            * // Set the enableShrink API
            * $("#scrollpanel").ejmScrollPanel("option", "enableShrink", true);            
            * &lt;/script&gt;
            * @memberof ejmScrollPanel
            * @instance
            */
            enableShrink: ej.isWindows() ? false : "scale",

            /**		
            * Specifies whether need to calculate the scroll content height.
            * @default true
            * @type {boolean}
            * @example 
            * // Set the autoAdjustHeight property in unobtrusive way.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" data-ej-autoadjustheight="true" /&gt;		
            * @example
            * // Set the autoAdjustHeight property on initilization.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#scrollpanel").ejmScrollPanel({target:"maincontent", autoAdjustHeight:true});		
            * });
            * &lt;/script&gt; 
            * @example 
            * // Get or set the scrollpanel autoAdjustHeight property, after initialization:<br>
            * &lt;script&gt;
            * // Get the autoAdjustHeight API value.		
            *  $("#scrollpanel").ejmScrollPanel("option", "autoAdjustHeight");			
            * // Set the autoAdjustHeight API
            * $("#scrollpanel").ejmScrollPanel("option", "autoAdjustHeight", true);            
            * &lt;/script&gt;
            * @memberof ejmScrollPanel
            * @instance
            */
            autoAdjustHeight: true,

            /**		
            * Specifies whether need to style the target element with relative position.
            * @default true
            * @type {boolean}
            * @example 
            * // Set the isRelative property in unobtrusive way.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" data-ej-isrelative="true" /&gt;
            * @example
            * // Set the isRelative property on initilization.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#scrollpanel").ejmScrollPanel({target:"maincontent", isRelative:true});		
            * });
            * &lt;/script&gt; 
            * @example 
            * // Get or set the scrollpanel isRelative property, after initialization:<br>
            * &lt;script&gt;
            * // Get the isRelative API value.		
            *  $("#scrollpanel").ejmScrollPanel("option", "isRelative");			
            * // Set the isRelative API
            * $("#scrollpanel").ejmScrollPanel("option", "isRelative", true);            
            * &lt;/script&gt;
            * @memberof ejmScrollPanel
            * @instance
            */
            isRelative: true,
            /**		
            * Specifies the wheel speed.
            * @default 16
            * @type {int}
            * @example 
            * // Set the wheelSpeed property in unobtrusive way.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" data-ej-wheelspeed=20/&gt;		
            * @example
            * // Set the wheelSpeed property on initilization.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#scrollpanel").ejmScrollPanel({target:"maincontent", wheelSpeed:20});		
            * });
            * &lt;/script&gt; 
            * @example 
            * // Get or set the scrollpanel wheelSpeed property, after initialization:<br>
            * &lt;script&gt;
            * // Get the wheelSpeed API value.		
            *  $("#scrollpanel").ejmScrollPanel("option", "wheelSpeed");			
            * // Set the wheelSpeed API
            * $("#scrollpanel").ejmScrollPanel("option", "wheelSpeed", 20);            
            * &lt;/script&gt;
            * @memberof ejmScrollPanel
            * @instance
            */
            wheelSpeed: 16,

            /**		
            * Specifies whether need to enable the interactive scrollbars.
            * @default true
            * @type {boolean}
            * @example 
            * // Set the enableInteraction property in unobtrusive way.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" data-ej-enableinteraction="true" /&gt;		
            * @example
            * // Set the enableInteraction property on initilization.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#scrollpanel").ejmScrollPanel({target:"maincontent", enableInteraction:true});		
            * });
            * &lt;/script&gt; 
            * @example 
            * // Get or set the scrollpanel enableInteraction property, after initialization:<br>
            * &lt;script&gt;
            * // Get the enableInteraction API value.		
            *  $("#scrollpanel").ejmScrollPanel("option", "enableInteraction");			
            * // Set the enableInteraction API
            * $("#scrollpanel").ejmScrollPanel("option", "enableInteraction", true);            
            * &lt;/script&gt;
            * @memberof ejmScrollPanel
            * @instance
            */
            enableInteraction: true,

            /**		
            * Specifies whether to enable or disable the control.
            * @default true
            * @type {boolean}
            * @example 
            * // Set the enabled property in unobtrusive way.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" data-ej-enabled="true" /&gt;	
            * @example
            * // Set the enabled property on initilization.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#scrollpanel").ejmScrollPanel({target:"maincontent", enabled:true});		
            * });
            * &lt;/script&gt; 
            * @example 
            * // Get or set the scrollpanel interactiveScrollbars property, after initialization:<br>
            * &lt;script&gt;
            * // Get the enabled API value.		
            *  $("#scrollpanel").ejmScrollPanel("option", "enabled");			
            * // Set the enabled API
            * $("#scrollpanel").ejmScrollPanel("option", "enabled", true);            
            * &lt;/script&gt;
            * @memberof ejmScrollPanel
            * @instance
            */
            enabled: true,

            /**		
            * Specifies whether need to refresh scrollpanel when elements are added dynamically.
            * @default false
            * @type {boolean}
            * @example 
            * // Set the checkDOMChanges property in unobtrusive way.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" data-ej-checkdomchanges=false/&gt;		
            * @example
            * // Set the checkDOMChanges property on initilization.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#scrollpanel").ejmScrollPanel({target:"maincontent", checkDOMChanges:"200"});		
            * });
            * &lt;/script&gt; 
            * @example 
            * // Get or set the scrollpanel checkDOMChanges property, after initialization:<br>
            * &lt;script&gt;
            * // Get the checkDOMChanges API value.		
            *  $("#scrollpanel").ejmScrollPanel("option", "checkDOMChanges");			
            * // Set the checkDOMChanges API
            * $("#scrollpanel").ejmScrollPanel("option", "checkDOMChanges", true);            
            * &lt;/script&gt;
            * @memberof ejmScrollPanel
            * @instance
            */
            checkDOMChanges: false,
            /**		
            * Specifies whether need to enable the horizontal scrolling.
            * @default false <br/>
            * Note: For windows tablet horizontal scrolling is true
            * @type {boolean}
            * @example 
            * // Set the enableHrScroll property in unobtrusive way.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" data-ej-enablehrscroll=false/&gt;		
            * @example
            * // Set the enableHrScroll property on initilization.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#scrollpanel").ejmScrollPanel({target:"maincontent", enableHrScroll:true});		
            * });
            * &lt;/script&gt; 
            * @example 
            * // Get or set the scrollpanel enableHrScroll property, after initialization:<br>
            * &lt;script&gt;
            * // Get the enableHrScroll API value.		
            *  $("#scrollpanel").ejmScrollPanel("option", "enableHrScroll");			
            * // Set the enableHrScroll API
            * $("#scrollpanel").ejmScrollPanel("option", "enableHrScroll", true);            
            * &lt;/script&gt;
            * @memberof ejmScrollPanel
            * @instance
            */
            enableHrScroll: (ej.isWindows() && !ej.isMobile()) ? true : false,

            /**		
            * Specifies whether need to enable the vertical scrolling.
            * @default true
            * @type {boolean}
            * @example 
            * // Set the enableVrScroll property in unobtrusive way.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" data-ej-enablevrscroll="true" /&gt;		
            * @example
            * // Set the enableVrScroll property on initilization.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#scrollpanel").ejmScrollPanel({target:"maincontent", enableVrScroll:true});		
            * });
            * &lt;/script&gt; 
            * @example 
            * // Get or set the scrollpanel enableVrScroll property, after initialization:<br>
            * &lt;script&gt;
            * // Get the enableVrScroll API value.		
            *  $("#scrollpanel").ejmScrollPanel("option", "enableVrScroll");			
            * // Set the enableVrScroll API
            * $("#scrollpanel").ejmScrollPanel("option", "enableVrScroll", true);            
            * &lt;/script&gt;
            * @memberof ejmScrollPanel
            * @instance
            */
            enableVrScroll: true,
            eventPassthrough: null,
            translateZ: ej.browserInfo()["name"] == "msie" ? '' : $.support.has3d ? ' translateZ(0)' : '',
            /**		
            * Specifies the minimum zoom value.
            * @default 1
            * @type {int}
            * @example 
            * // Set the zoomMin property in unobtrusive way.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" data-ej-zoom="true" data-ej-zoommin=2/&gt;		
            * @example
            * // Set the zoomMin property on initilization.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#scrollpanel").ejmScrollPanel({target:"maincontent", zoom:true, zoomMin:2});		
            * });
            * &lt;/script&gt; 
            * @example 
            * // Get or set the scrollpanel zoomMin property, after initialization:<br>
            * &lt;script&gt;
            * // Get the zoomMin API value.		
            *  $("#scrollpanel").ejmScrollPanel("option", "zoomMin");			
            * // Set the zoomMin API
            * $("#scrollpanel").ejmScrollPanel("option", "zoomMin", 2);            
            * &lt;/script&gt;
            * @memberof ejmScrollPanel
            * @instance
            */
            zoomMin: 1,
            /**		
            * Specifies the maximum zoom value.
            * @default 6
            * @type {int}
            * @example 
            * // Set the zoomMax property in unobtrusive way.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" data-ej-zoom="true" data-ej-zoommax=10/&gt;		
            * @example
            * // Set the zoomMax property on initilization.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#scrollpanel").ejmScrollPanel({target:"maincontent", zoom:true, zoomMax:10});		
            * });
            * &lt;/script&gt; 
            * @example 
            * // Get or set the scrollpanel zoomMax property, after initialization:<br>
            * &lt;script&gt;
            * // Get the zoomMax API value.		
            *  $("#scrollpanel").ejmScrollPanel("option", "zoomMax");			
            * // Set the zoomMax API
            * $("#scrollpanel").ejmScrollPanel("option", "zoomMax", 10);            
            * &lt;/script&gt;
            * @memberof ejmScrollPanel
            * @instance
            */
            zoomMax: 6,

            /**		
            * Specifies whether need to adjust the scrolling content height for fixed position elements.
            * @default true
            * @type {boolean}
            * @example 
            * // Set the adjustFixedPosition property in unobtrusive way.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" data-ej-adjustfixedposition="true" /&gt;		
            * @example
            * // Set the adjustFixedPosition property on initilization.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#scrollpanel").ejmScrollPanel({target:"maincontent", adjustFixedPosition:true});		
            * });
            * &lt;/script&gt; 
            * @example 
            * // Get or set the scrollpanel adjustFixedPosition property, after initialization:<br>
            * &lt;script&gt;
            * // Get the adjustFixedPosition API value.		
            *  $("#scrollpanel").ejmScrollPanel("option", "adjustFixedPosition");			
            * // Set the adjustFixedPosition API
            * $("#scrollpanel").ejmScrollPanel("option", "adjustFixedPosition", true);            
            * &lt;/script&gt;
            * @memberof ejmScrollPanel
            * @instance
            */
            adjustFixedPosition: true,
            /**		
            * Specifies the initial zooming value.
            * @default 1
            * @type {int}
            * @example 
            * // Set the startZoom property in unobtrusive way.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" data-ej-enablezoom="true" data-ej-startzoom=2/&gt;
            * @example
            * // Set the startZoom property on initilization.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#scrollpanel").ejmScrollPanel({target:"maincontent", enableZoom:true, startZoom:2});		
            * });
            * &lt;/script&gt; 
            * @example 
            * // Get or set the scrollpanel startZoom property, after initialization:<br>
            * &lt;script&gt;
            * // Get the startZoom API value.		
            *  $("#scrollpanel").ejmScrollPanel("option", "startZoom");			
            * // Set the startZoom API
            * $("#scrollpanel").ejmScrollPanel("option", "startZoom", 2);            
            * &lt;/script&gt;
            * @memberof ejmScrollPanel
            * @instance
            */
            startZoom: 1,
            /**
            * Specifies the x position on intialize.
            * @default 0
            * @type {int}
            * @example 
            * // Set the startX property in unobtrusive way.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" data-ej-startx=0/&gt;
            * @example
            * // Set the startX property on initilization.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#scrollpanel").ejmScrollPanel({target:"maincontent", startX:0});		
            * });
            * &lt;/script&gt; 
            * @example 
            * // Get or set the scrollpanel startX property, after initialization:<br>
            * &lt;script&gt;
            * // Get the startX API value.
            *  $("#scrollpanel").ejmScrollPanel("option", "startX");
            * // Set the startX API
            * $("#scrollpanel").ejmScrollPanel("option", "startX", 0);
            * &lt;/script&gt;
            * @memberof ejmScrollPanel
            * @instance
            */
            startX: 0,
            /**		
            * Specifies the y position on intialize.
            * @default 0
            * @type {int}
            * @example 
            * // Set the startY property in unobtrusive way.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" data-ej-starty=30/&gt;
            * @example
            * // Set the startY property on initilization.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#scrollpanel").ejmScrollPanel({target:"maincontent", startY:0});		
            * });
            * &lt;/script&gt; 
            * @example 
            * // Get or set the scrollpanel startY property, after initialization:<br>
            * &lt;script&gt;
            * // Get the startY API value.		
            *  $("#scrollpanel").ejmScrollPanel("option", "startY");			
            * // Set the startY API
            * $("#scrollpanel").ejmScrollPanel("option", "startY", 30);            
            * &lt;/script&gt;
            * @memberof ejmScrollPanel
            * @instance
            */
            startY: 0,
            /**		
            * Specifies whether to enable displacement for the control.
            * @default false
            * @type {boolean}
            */
            enableDisplacement: false,
            /**		
            * Specifies the displacement value.
            * @default 94
            * @type {int}
            */
            displacementValue: 94,
            /**		
            * Specifies the displacement time.
            * @default 800
            * @type {int}
            */
            displacementTime: 800,
            /**		
            * Specifies the deceleration.
            * @type {int}
            */
            deceleration: null,
            /**		
            * Specifies whether to disable pointer.
            * @default false
            * @type {bool}
            * @example 
            * // Set the disablePointer, property in unobtrusive way.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" data-ej-disablepointer="true" /&gt;		
            * @example
            * // Set the disablePointer property on initilization.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#scrollpanel").ejmScrollPanel({target:"maincontent", disablePointer:true});		
            * });
            * &lt;/script&gt; 
            * @example 
            * // Get or set the scrollpanel disablePointer property, after initialization:<br>
            * &lt;script&gt;
            * // Get the disablePointer API value.		
            *  $("#scrollpanel").ejmScrollPanel("option", "disablePointer");			
            * // Set the disablePointer API
            * $("#scrollpanel").ejmScrollPanel("option", "disablePointer", true);            
            * &lt;/script&gt;
            * @memberof ejmScrollPanel
            * @instance
            */
            disablePointer: false,
            /**		
            * Specifies whether to disable mouse.
            * @default false
            * @type {bool}
            * @example 
            * // Set the disableMouse, property in unobtrusive way.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" data-ej-disablemouse="true" /&gt;	
            * @example
            * // Set the disableMouse property on initilization.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#scrollpanel").ejmScrollPanel({target:"maincontent", disableMouse:true});		
            * });
            * &lt;/script&gt; 
            * @example 
            * // Get or set the scrollpanel disableMouse property, after initialization:<br>
            * &lt;script&gt;
            * // Get the disableMouse API value.		
            *  $("#scrollpanel").ejmScrollPanel("option", "disableMouse");			
            * // Set the disableMouse API
            * $("#scrollpanel").ejmScrollPanel("option", "disableMouse", true);            
            * &lt;/script&gt;
            * @memberof ejmScrollPanel
            * @instance
            */
            disableMouse: false,
            /**		
            * Specifies whether to disable touch.
            * @default false
            * @type {bool}
            * @example 
            * // Set the disableTouch, property in unobtrusive way.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" data-ej-disabletouch="true" /&gt;		
            * @example
            * // Set the disableTouch property on initilization.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#scrollpanel").ejmScrollPanel({target:"maincontent", disableTouch:true});		
            * });
            * &lt;/script&gt; 
            * @example 
            * // Get or set the scrollpanel disableTouch property, after initialization:<br>
            * &lt;script&gt;
            * // Get the disableTouch API value.		
            *  $("#scrollpanel").ejmScrollPanel("option", "disableTouch");			
            * // Set the disableTouch API
            * $("#scrollpanel").ejmScrollPanel("option", "disableTouch", true);            
            * &lt;/script&gt;
            * @memberof ejmScrollPanel
            * @instance
            */
            disableTouch: false,
            /**
            *Specifies the value for direction lock threshold.
            * @default 5
            * @type {int}
            * @example 
            * // Set the directionLockThreshold property in unobtrusive way.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" data-ej-directionlockthreshold=12/&gt;		
            * @example
            * // Set the directionLockThreshold property on initilization.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#scrollpanel").ejmScrollPanel({target:"maincontent", directionLockThreshold:12});		
            * });
            * &lt;/script&gt; 
            * @example 
            * // Get or set the scrollpanel directionLockThreshold property, after initialization:<br>
            * &lt;script&gt;
            * // Get the directionLockThreshold API value.		
            *  $("#scrollpanel").ejmScrollPanel("option", "directionLockThreshold ");			
            * // Set the directionLockThreshold  API
            * $("#scrollpanel").ejmScrollPanel("option", "directionLockThreshold ", 12);            
            * &lt;/script&gt;
            * @memberof ejmScrollPanel
            * @instance
            */
            directionLockThreshold: 5,
            /**		
            * Specifies whether to enable momentum.
            * @default true
            * @type {boolean}
            */
            momentum: true,

            /**		
            * Specifies whether to enable bouncing behaviour.
            * @default true <br/>
            * Note: For Android platform this property is false
            * @type {boolean}
            * @example 
            * // Set the enableBounce property in unobtrusive way.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" data-ej-enablebounce="true" /&gt;	
            * @example
            * // Set the enableBounce property on initilization.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#scrollpanel").ejmScrollPanel({target:"maincontent", enableBounce:true});		
            * });
            * &lt;/script&gt; 
            * @example 
            * // Get or set the scrollpanel enableBounce property, after initialization:<br>
            * &lt;script&gt;
            * // Get the enableBounce API value.		
            *  $("#scrollpanel").ejmScrollpanel("option", "enableBounce");			
            * // Set the enableBounce API
            * $("#scrollpanel").ejmScrollpanel("option", "enableBounce", true);            
            * &lt;/script&gt;
            * @memberof ejmScrollPanel
            * @instance
            */
            enableBounce: ej.isAndroid() ? false : true,

            /**		
            * Specifies the bouncing time when bouncing behaviour is enabled.
            * @default 450
            * @type {int}
            * @example 
            * // Set the bounceTime property in unobtrusive way.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" data-ej-bouncetime=450/&gt;	
            * @example
            * // Set the bounceTime property on initilization.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#scrollpanel").ejmScrollPanel({target:"maincontent", bounceTime:500});		
            * });
            * &lt;/script&gt; 
            * @example 
            * // Get or set the scrollpanel bounceTime property, after initialization:<br>
            * &lt;script&gt;
            * // Get the bounceTime API value.		
            *  $("#scrollpanel").ejmScrollPanel("option", "bounceTime");			
            * // Set the bounceTime API
            * $("#scrollpanel").ejmScrollPanel("option", "bounceTime", "500");            
            * &lt;/script&gt;
            * @memberof ejmScrollPanel
            * @instance
            */
            bounceTime: 450,
            /**		
            * Specifies the bounce easing value when bouncing behaviour is enabled.
            */
            bounceEasing: '',
            /**		
            * Specifies whether to prevent default events.
            * @default true
            * @type {bool}
            * @example 
            * // Set the preventDefault property in unobtrusive way.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" data-ej-preventdefault=false/&gt;
            * @example
            * // Set the preventDefault property on initilization.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#scrollpanel").ejmScrollPanel({target:"maincontent", preventDefault:false});		
            * });
            * &lt;/script&gt; 
            * @example 
            * // Get or set the scrollpanel preventDefault property, after initialization:<br>
            * &lt;script&gt;
            * // Get the preventDefault API value.		
            *  $("#scrollpanel").ejmScrollPanel("option", "preventDefault");			
            * // Set the preventDefault API
            * $("#scrollpanel").ejmScrollPanel("option", "preventDefault", false);            
            * &lt;/script&gt;
            * @memberof ejmScrollPanel
            * @instance
            */
            preventDefault: true,
            /**		
            * Specifies whether to prevent default exception.
            */
            preventDefaultException: { tagName: /^(INPUT|TEXTAREA|BUTTON|SELECT)$/ },
            /**		
            * Specifies whether to enable transition effect for the control.
            * @default true
            * @type {boolean}
            * @example 
            * // Set the enableTransition property in unobtrusive way.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" data-ej-enabletransition=false/&gt;		
            * @example
            * // Set the enableTransition property on initilization.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#scrollpanel").ejmScrollPanel({target:"maincontent", enableTransition:false});		
            * });
            * &lt;/script&gt; 
            * @example 
            * // Get or set the scrollpanel enableTransition property, after initialization:<br>
            * &lt;script&gt;
            * // Get the enableTransition API value.		
            *  $("#scrollpanel").ejmScrollPanel("option", "enableTransition");			
            * // Set the enableTransition API
            * $("#scrollpanel").ejmScrollPanel("option", "enableTransition", false);            
            * &lt;/script&gt;
            * @memberof ejmScrollPanel
            * @instance
            */
            enableTransition: true,
            /**		
            * Specifies whether to enable transform style for the control.
            * @default true
            * @type {boolean}
            * @example 
            * // Set the enableTransform property in unobtrusive way.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" data-ej-enabletransform=false/&gt;		
            * @example
            * // Set the enableTransform property on initilization.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#scrollpanel").ejmScrollPanel({target:"maincontent", enableTransform:false});		
            * });
            * &lt;/script&gt; 
            * @example 
            * // Get or set the scrollpanel enableTransform property, after initialization:<br>
            * &lt;script&gt;
            * // Get the enableTransform API value.		
            *  $("#scrollpanel").ejmScrollPanel("option", "enableTransform");			
            * // Set the enableTransform API
            * $("#scrollpanel").ejmScrollPanel("option", "enableTransform", false);            
            * &lt;/script&gt;
            * @memberof ejmScrollPanel
            * @instance      
            */
            enableTransform: true,
            /**		
            * Specifies whether need to show the scroll bars.
            * @default true
            * @type {boolean}
            * @example 
            * // Set the showScrollbars property in unobtrusive way.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" data-ej-showscrollbars="true" /&gt;
            * @example
            * // Set the showScrollbars property on initilization.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#scrollpanel").ejmScrollPanel({target:"maincontent", showScrollbars:true});		
            * });
            * &lt;/script&gt; 
            * @example 
            * // Get or set the scrollpanel showScrollbars property, after initialization:<br>
            * &lt;script&gt;
            * // Get the showScrollbars API value.		
            *  $("#scrollpanel").ejmScrollpanel("option", "showScrollbars");			
            * // Set the showScrollbars API
            * $("#scrollpanel").ejmScrollpanel("option", "showScrollbars", true);            
            * &lt;/script&gt;
            * @memberof ejmScrollPanel
            * @instance
            */
            showScrollbars: true,
            /**		
            * Specifies whether to enable mouse wheel scrolling.
            * @default true
            * @type {boolean}
            * @example 
            * // Set the enableMouseWheel property in unobtrusive way.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" data-ej-enablemousewheel=false/&gt;	
            * // Set the enableMouseWheel property on initilization.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#scrollpanel").ejmScrollPanel({target:"maincontent", enableMouseWheel:false});		
            * });
            * &lt;/script&gt; 
            * @example 
            * // Get or set the scrollpanel enableMouseWheel property, after initialization:<br>
            * &lt;script&gt;
            * // Get the enableMouseWheel API value.		
            *  $("#scrollpanel").ejmScrollPanel("option", "enableMouseWheel");			
            * // Set the enableMouseWheel API
            * $("#scrollpanel").ejmScrollPnel("option", "enableMouseWheel", false);            
            * &lt;/script&gt;
            * @memberof ejmScrollPanel
            * @instance
            */
            enableMouseWheel: true,
            /**		
            * Specifies whether to enable keys.
            * @default true
            * @type {boolean}
            * @example 
            * // Set the enableKeys property in unobtrusive way.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" data-ej-enablekeys=false/&gt;		
            * // Set the enableKeys property on initilization.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#scrollpanel").ejmScrollPanel({target:"maincontent", enableKeys:false});		
            * });
            * &lt;/script&gt; 
            * @example 
            * // Get or set the scrollpanel enableKeys property, after initialization:<br>
            * &lt;script&gt;
            * // Get the enableKeys API value.		
            *  $("#scrollpanel").ejmScrollpanel("option", "enableKeys");			
            * // Set the enableKeys API
            * $("#scrollpanel").ejmScrollpanel("option", "enableKeys", false);            
            * &lt;/script&gt;
            * @memberof ejmScrollPanel
            * @instance
            */
            enableKeys: true,
            /**		
            * Specifies whether to enable zooming.
            * @default false
            * @type {boolean}
            * @example 
            * // Set the enableZoom property in unobtrusive way.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" data-ej-enablezoom="true" /&gt;
            * @example
            * // Set the enableZoom property on initilization.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#scrollpanel").ejmScrollPanel({target:"maincontent", enableZoom:true});		
            * });
            * &lt;/script&gt; 
            * @example 
            * // Get or set the scrollpanel enableZoom property, after initialization:<br>
            * &lt;script&gt;
            * // Get the enableZoom API value.		
            *  $("#scrollpanel").ejmScrollpanel("option", "enableZoom");			
            * // Set the enableZoom API
            * $("#scrollpanel").ejmScrollpanel("option", "enableZoom", true);            
            * &lt;/script&gt;
            * @memberof ejmScrollPanel
            * @instance
            */
            enableZoom: false,

            /**		
            * Specifies whether to enable device's native scroll behaviour.
            * @default false <br/>
            * Note: For Windows tablet, this property is true
            * @type {boolean}
            * @example 
            * // Set the enableNativeScrolling property in unobtrusive way.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" data-ej-enablenativescrolling="true" /&gt;		
            * @eample
            * // Set the enableNativeScrolling property on initilization.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#scrollpanel").ejmScrollPanel({target:"maincontent", enableNativeScrolling:true});		
            * });
            * &lt;/script&gt; 
            * @example 
            * // Get or set the scrollpanel enableNativeScrolling property, after initialization:<br>
            * &lt;script&gt;
            * // Get the enableNativeScrolling API value.		
            *  $("#scrollpanel").ejmScrollPanel("option", "enableNativeScrolling");			
            * // Set the enableNativeScrolling API
            * $("#scrollpanel").ejmScrollPanel("option", "enableNativeScrolling", true);            
            * &lt;/script&gt;
            * @memberof ejmScrollPanel
            * @instance
            */
            enableNativeScrolling: (ej.isAndroid() || ej.isIOS()) ? false : ej.isDevice() ? true : false,
            /**		
            * Specifies whether to enable invert wheel.
            * @default false
            * @type {boolean}
            * @example 
            * // Set the invertWheel property in unobtrusive way.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" data-ej-invertwheel="true" /&gt;
            * @example
            * // Set the invertWheel property on initilization.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#scrollpanel").ejmScrollPanel({target:"maincontent", invertWheel:true});		
            * });
            * &lt;/script&gt; 
            * @example 
            * // Get or set the scrollpanel invertWheel property, after initialization:<br>
            * &lt;script&gt;
            * // Get the invertWheel API value.		
            *  $("#scrollpanel").ejmScrollpanel("option", "invertWheel");			
            * // Set the invertWheel API
            * $("#scrollpanel").ejmScrollpanel("option", "invertWheel", true);            
            * &lt;script&gt;
            * @memberof ejmScrollPanel
            * @instance
            */
            invertWheel: false,
            /**		
            * Specifies to maintain the current model value to browser cookies for state maintenance. While refresh the page, the model value will get apply to the control from browser cookies.
            * @default false
            * @type {boolean}
            * @example 
            * // Set the enablePersistence property in unobtrusive way.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" data-ej-enablepersistence="true" /&gt;
            * @example
            * // Set the enablePersistence property on initilization.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#scrollpanel").ejmScrollPanel({target:"maincontent", enablePersistence:true});		
            * });
            * &lt;/script&gt; 
            * @example 
            * // Get or set the scrollpanel enablePersistence property, after initialization:<br>
            * &lt;script&gt;
            * // Get the enablePersistence API value.		
            *  $("#scrollpanel").ejmScrollpanel("option", "enablePersistence");			
            * // Set the enablePersistence API
            * $("#scrollpanel").ejmScrollpanel("option", "enablePersistence", true);            
            * &lt;/script&gt;
            * @memberof ejmScrollPanel
            * @instance
            */
            enablePersistence: false,
            /**    
            * Event triggers when scroll start happens on the control.
            * @event
            * @name ejmScrollPanel#scrollStart 	
            * @param {Object} argument Event parameters from scrollpanel.
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @param {int} argument.x returns the x position.
            * @param {int} argument.y returns the y position.
            * @example 
            * // Create Scrollpanel control
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" data-ej-scrollstart="scrollStart"/&gt;		
            * &lt;script&gt; 
            * // scrollStart event for scrollpanel
            * function scrollStart(args){ //handle the event 
            * }
            * &lt;/script&gt;
            * @example 
            * // Create Scrollpanel control
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;	
            * &lt;script&gt; 
            * // scrollStart event for scrollpanel
            * $("#scrollpanel").ejmScrollPanel({
            *   target: "maincontent",
            *   scrollStart: function (args) { //handle the event
            * }
            * });           
            * &lt;/script&gt; 
            * @memberof ejmScrollPanel
            * @instance
            */
            scrollStart: null,
            /**    
            * Event triggers when scroll move happens on the control.
            * @event
            * @name ejmScrollPanel#scroll
            * @param {Object} argument Event parameters from scrollpanel.
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @param {int} argument.x returns the x position.
            * @param {int} argument.y returns the y position.
            * @example 
            * // Create Scrollpanel control
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" data-ej-scroll="scroll"/&gt;		
            * &lt;script&gt; 
            * // scroll event for scrollpanel
            * function scroll(args){ //handle the event 
            * }
            * &lt;/script&gt;
            * @example 
            * // Create Scrollpanel control
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;	
            * &lt;script&gt; 
            * // scroll event for scrollpanel
            * $("#scrollpanel").ejmScrollPanel({
            *   target: "maincontent",
            *   scroll: function (args) { //handle the event
            * }
            * });           
            * &lt;/script&gt; 
            * @memberof ejmScrollPanel
            * @instance
            */
            scroll: null,
            /**    
            * Event triggers when scroll end happens on the control.
            * @event
            * @name ejmScrollPanel#scrollEnd
            * @param {Object} argument Event parameters from scrollpanel.
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @param {int} argument.x returns the x position.
            * @param {int} argument.y returns the y position.
            * @example 
            * // Create Scrollpanel control
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" data-ej-scrollend="scrollEnd"/&gt;		
            * &lt;script&gt; 
            * // scrollEnd event for scrollpanel
            * function scrollEnd(args){ //handle the event
            * }
            * &lt;/script&gt;
            * @example 
            * // Create Scrollpanel control
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;	
            * &lt;script&gt; 
            * // scrollEnd event for scrollpanel
            * $("#scrollpanel").ejmScrollPanel({
            *   target: "maincontent",
            *   scrollEnd: function (args) { //handle the event 
            * }
            * });           
            * &lt;/script&gt; 
            * @memberof ejmScrollPanel
            * @instance
            */
            scrollEnd: null,
            /**    
            * Event triggers when zoom start happens on the control.
            * @event
            * @name ejmScrollPanel#zoomStart
            * @param {Object} argument Event parameters from scrollpanel.	
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @param {int} argument.x returns the x position.
            * @param {int} argument.y returns the y position.
            * @example 
            * // Create Scrollpanel control
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" data-ej-zoomstart="zoomStart"/&gt;		
            * &lt;script&gt; 
            * // zoomStart event for scrollpanel
            * function zoomStart(args){ //handle the event
            * }
            * &lt;/script&gt;
            * @example 
            * // Create Scrollpanel control
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;	
            * &lt;script&gt; 
            * // zoomStart event for scrollpanel
            * $("#scrollpanel").ejmScrollPanel({
            *   target: "maincontent",
            *   zoomStart: function (args) { //handle the event
            * }
            * });           
            * &lt;/script&gt; 
            * @memberof ejmScrollPanel
            * @instance
            */
            zoomStart: null,
            /**    
            * Event triggers when zoom end happens on the control.
            * @event
            * @name ejmScrollPanel#zoomEnd	
            * @param {Object} argument Event parameters from scrollpanel.
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @param {int} argument.x returns the x position.
            * @param {int} argument.y returns the y position.
            * @example 
            * // Create Scrollpanel control
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" data-ej-zoomend="zoomEnd"/&gt;		
            * &lt;script&gt; 
            * // zoomEnd event for scrollpanel
            * function zoomEnd(args){ //handle the event 
            * }
            * &lt;/script&gt;
            * @example 
            * // Create Scrollpanel control
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;	
            * &lt;script&gt; 
            * // zoomEnd event for scrollpanel
            * $("#scrollpanel").ejmScrollPanel({
            *   target: "maincontent",
            *   zoomEnd: function (args) { //handle the event 
            * }
            * });           
            * &lt;/script&gt; 
            * @memberof ejmScrollPanel
            * @instance
            */
            zoomEnd: null,
            /**		
            * Specifies the target element.
            * @default null
            * @type {string}
            * @example 
            * // Set the target property in unobtrusive way.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent" /&gt;
            * @example
            * // Set the target property on initilization.
            * &lt;div id="maincontent"&gt;
            *   &lt;div&gt;
            *       Scroll content here
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="scrollpanel"/&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#scrollpanel").ejmScrollPanel({target:"maincontent"});		
            * });
            * &lt;/script&gt; 
            * @example 
            * // Get or set the scrollpanel target property, after initialization:<br>
            * &lt;script&gt;
            * // Get the target API value.		
            *  $("#scrollpanel").ejmScrollpanel("option", "target");			
            * // Set the target API
            * $("#scrollpanel").ejmScrollpanel("option", "target", "maincontent");            
            * &lt;/script&gt;
            * @memberof ejmScrollPanel
            * @instance
            */
            target: null
        },
        dataTypes: {
        },
        _init: function () {
            ej.setRenderMode(this);
            ej.setTheme(this);
            if (this.model.enableDisplacement && ej.isWindows())
                this.model.deceleration = 0.00006;
            this._eventType = { touchstart: 1, touchmove: 1, touchend: 1, ejtouchmove: 3, mousedown: 2, mousemove: 2, mouseup: 2, MSPointerDown: 3, MSPointerMove: 3, MSPointerUp: 3, pointerdown: 3, pointermove: 3, pointerup: 3 };
            this._scrollEvents = { scrollEnd: [this.model.scrollEnd], scroll: [this.model.scroll], scrollStart: [this.model.scrollStart], zoomStart: [this.model.zoomStart], zoomEnd: [this.model.zoomEnd] };
            this._scale = Math.min(Math.max(this.model.startZoom, this.model.zoomMin), this.model.zoomMax);
            this._wrapper = typeof this.model.target == 'string' ? $("#" + this.model.target)[0] : this.model.target;
            if (this._wrapper)
                this._scroller = this._wrapper.children[0];
            if (!this._scroller)
                return;
            this._aniTime = null;
            this._createDelegates();
            this._wireEvents();
            this._$wrapper = $(this._wrapper);
            this._$wrapper.append(this.element);
            $(this._wrapper).addClass("e-m-scrollpanel");
            $(this.element).addClass("e-m-scroll");
            if (this.model.enableNativeScrolling) {
                this.refresh();
                this._$wrapper.addClass('e-m-scroll-native e-m-scroll-wrapper');
                if (this.model.renderMode == "ios7" || this.model.renderMode == "android")
                    $(this._scroller).addClass('e-m-scroll-content');
                this._scroller[ej.transform] = 'translate3d(' + 0 + 'px,' + 0 + 'px,0)';
                if (((!this._hasVScroll && this._maxScrollY == 0) || (!this._hasHScroll && this._maxScrollX == 0)) && this.model.renderMode == "ios7")
                    this._$wrapper.addClass('e-m-scroll-box');
                if (!this.model.showScrollbars)
                    this._$wrapper.addClass('e-m-scroll-hide');
                if (!this.model.enableZoom)
                    this._$wrapper.addClass('e-m-zoom');
            }
            else {
                var proxy = this;
                $(this._wrapper).css("overflow", "hidden");
                this._scrollerStyle = this._scroller.style;
                this.model.enableTransition = $.support.hasTransition && this.model.enableTransition;
                this.model.enableTransform = $.support.hasTransform && this.model.enableTransform;
                this.model.eventPassthrough = this.model.eventPassthrough === true ? 'vertical' : this.model.eventPassthrough;
                this.model.preventDefault = !this.model.eventPassthrough && this.model.preventDefault;
                this.model.enableVrScroll = this.model.eventPassthrough == 'vertical' ? false : this.model.enableVrScroll;
                this.model.enableHrScroll = this.model.eventPassthrough == 'horizontal' ? false : this.model.enableHrScroll;
                this.model.directionLockThreshold = this.model.eventPassthrough ? 0 : this.model.directionLockThreshold;
                this.model.invertWheel = this.model.invertWheel ? -1 : 1;
                if (this.model.isRelative)
                    $(this._wrapper).css("position", "relative");
                this._x = 0;
                this._y = 0;
                this._directionX = 0;
                this._directionY = 0;

                this._startX = 0;
                this._startY = 0;

                if (this.model.enableZoom)
                    this._scrollerStyle[ej.transformOrigin] = '0 0';
                if (this.model.showScrollbars)
                    this._initScrollbars();
                if (this.model.enableMouseWheel)
                    this._initWheel();
                if (this.model.enableKeys)
                    this._initKeys();
                this.refresh();
                this.scrollTo(this.model.startX, this.model.startY);
                if (this.model.checkDOMChanges) this._checkDOMTime = setInterval(function () {
                    proxy._checkDOMChanges();
                }, 500);
            }
        },
        _dataValue: function () {
            return data = { x: this.model.enableNativeScrolling ? this._nx : this._x, y: this.model.enableNativeScrolling ? this._ny : this._y, object: this };
        },
        _transitionEnd: function (e) {
            if (e.target != this._scroller || !this._isInTransition) {
                return;
            }
            this._transitionTime();
            if (!this.resetPosition(this.model.bounceTime)) {
                this._isInTransition = false;
                this._moved = false;
                this._triggerEvent('scrollEnd', this._dataValue());
            }
        },

        _touchStart: function (e) {
            if ($(e.target).parents(".e-m-scrollpanel").length > 1 && $(e.target).closest(".e-m-scrollpanel")[0] != this._wrapper)
                return;
            var point = e.touches ? e.touches[0] : e,
			pos;

            ej.listenEvents([window, window, window],
                                [ej.moveEvent(), ej.cancelEvent(), ej.endEvent()],
                                [this._touchMoveHandler, this._touchEndHandler, this._touchEndHandler],
                                false, this, this.model.disableMouse);

            if (this.model.enableNativeScrolling) {
                this._moved = false;
                if (this.model.renderMode == "ios7" || this.model.renderMode == "android") {
                    startY = point.pageY;
                    startTopScroll = this._wrapper.scrollTop;
                    if (startTopScroll <= 0)
                        this._wrapper.scrollTop = 1;
                    if (startTopScroll + this._wrapper.offsetHeight >= this._wrapper.scrollHeight)
                        this._wrapper.scrollTop = this._wrapper.scrollHeight - this._wrapper.offsetHeight - 1;
                }
                return;
            }

            if (this._eventType[e.type] != 1) {
                if (e.button !== 0) {
                    return;
                }
            }
            if (!this.model.enabled || (this._startedScroll && this._eventType[e.type] !== this._startedScroll)) {
                return;
            }
            if (this.model.preventDefault && !ej.isDevice() && !ej._preventDefaultException(e.target, this.model.preventDefaultException)) {
                e.preventDefault();
            }
            if (this.model.preventDefault && this._moved) {
                ej.blockDefaultActions(e);
            }

            this._startedScroll = this._eventType[e.type];

            this._distX = 0;
            this._distY = 0;
            this._directionX = 0;
            this._directionY = 0;
            this._lockedDir = 0;
            this._transitionTime();
            this._startTime = this._getTime();
            if (this.model.enableTransition && this._isInTransition) {
                this._isInTransition = false;
                pos = this.getComputedPosition();
                this._translate(Math.round(pos.x), Math.round(pos.y));
                this._triggerEvent('scrollEnd', this._dataValue());
            } else if (!this.model.enableTransition && this._animating) {
                cancelFrame(this._aniTime);
                this._steps = [];
                this._animating = false;
                this._translate(this._wrapper.scrollLeft, this._wrapper.scrollTop);
                this._triggerEvent('scrollEnd', this._dataValue());
            }
            this._moved = false;
            this._startX = this._x;
            this._startY = this._y;
            this._absStartX = this._x;
            this._absStartY = this._y;
            this._pointX = point.pageX;
            this._pointY = point.pageY;
            if (this.model.enableZoom && e.touches && e.touches.length > 1) {
                this._zoomStart(e);
            }
        },
        _scrollStart: function (e) {
            this._moved = false;
            this._nx = this._$wrapper.scrollLeft();
            this._ny = this._$wrapper.scrollTop();
            this._trigger('scrollStart', this._dataValue());
        },
        _touchMove: function (e) {
            if (this.model.enableNativeScrolling) {
                return;
            }
            if (!this.model.enabled || this._eventType[e.type] !== this._startedScroll) {
                return;
            }

            if (this.model.preventDefault) {
                e.preventDefault();
            }
            if (this.model.enableZoom && e.touches && e.touches[1]) {
                this._zoom(e);
                return;
            }
            var point = e.touches ? e.touches[0] : e,
			deltaX = point.pageX - this._pointX,
			deltaY = point.pageY - this._pointY,
			timestamp = this._getTime(),
			newX, newY,
			absDistX, absDistY;
            this._pointX = point.pageX;
            this._pointY = point.pageY;
            this._distX += deltaX;
            this._distY += deltaY;
            absDistX = Math.abs(this._distX);
            absDistY = Math.abs(this._distY);
            if (timestamp - this._endTime > 300 && (absDistX < 10 && absDistY < 10))
                return;
            if (!this._lockedDir) {
                if (absDistX > absDistY + this.model.directionLockThreshold) {
                    this._lockedDir = 'horizontal';
                } else if (absDistY >= absDistX + this.model.directionLockThreshold) {
                    this._lockedDir = 'vertical';
                } else {
                    this._lockedDir = 'none';
                }
            }
            if (this._lockedDir == 'horizontal') {
                if (this.model.eventPassthrough == 'vertical') {
                    e.preventDefault();
                } else if (this.model.eventPassthrough == 'horizontal') {
                    this._startedScroll = false;
                    return;
                }

                deltaY = 0;
            } else if (this._lockedDir == 'vertical') {
                if (this.model.eventPassthrough == 'horizontal') {
                    e.preventDefault();
                } else if (this.model.eventPassthrough == 'vertical') {
                    this._startedScroll = false;
                    return;
                }

                deltaX = 0;
            }
            deltaX = (this.model.enableHrScroll || this._hasHScroll) ? deltaX : 0;
            deltaY = (this.model.enableVrScroll || this._hasVScroll) ? deltaY : 0;
            newX = this._x + deltaX;
            newY = this._y + deltaY;
            if (newX > 0 || newX < this._maxScrollX) {
                newX = this.model.enableBounce ? this._x + deltaX / 3 : newX > 0 ? 0 : this._maxScrollX;
            }
            if (newY > 0 || newY < this._maxScrollY) {
                newY = this.model.enableBounce ? this._y + deltaY / 3 : newY > 0 ? 0 : this._maxScrollY;
            }
            this._directionX = deltaX > 0 ? -1 : deltaX < 0 ? 1 : 0;
            this._directionY = deltaY > 0 ? -1 : deltaY < 0 ? 1 : 0;
            if (!this._moved) {
                this._triggerEvent('scrollStart', this._dataValue());
            }

            this._moved = true;
            this._translate(newX, newY);
            if (timestamp - this._startTime > 300) {
                this._startTime = timestamp;
                this._startX = this._x;
                this._startY = this._y;
            }
            if (this._moved)
                this._triggerEvent('scroll', this._dataValue());
        },
        _scroll: function (e) {
            this._moved = true;
            this._nx = this._$wrapper.scrollLeft();
            this._ny = this._$wrapper.scrollTop();
            this._trigger('scroll', this._dataValue());
        },
        _touchEnd: function (e) {
            ej.listenEvents([window, window, window],
                                [ej.moveEvent(), ej.cancelEvent(), ej.endEvent()],
                                [this._touchMoveHandler, this._touchEndHandler, this._touchEndHandler],
                                true, this, this.model.disableMouse);
            if (!this.model.enabled || this._eventType[e.type] !== this._startedScroll) {
                return;
            }
            if (this.model.preventDefault && !ej.isDevice() && !ej._preventDefaultException(e.target, this.model.preventDefaultException)) {
                e.preventDefault();
            }
            if (this.model.enableNativeScrolling && this._moved) {
                ej.blockDefaultActions(e);
                this._moved = false;
                return;
            }
            if (this._scaled) {
                this._zoomEnd(e);
                return;
            }
            var point = e.changedTouches ? e.changedTouches[0] : e,
            	momentumX,
            	momentumY,
            	duration = this._getTime() - this._startTime,
            	newX = Math.round(this._x),
            	newY = Math.round(this._y),
            	distanceX = Math.abs(newX - this._startX),
            	distanceY = Math.abs(newY - this._startY),
            	time = 0,
            	easing = '';

            this._isInTransition = 0;
            this._startedScroll = 0;
            this._endTime = this._getTime();
            if (this.resetPosition(this.model.bounceTime)) {
                return;
            }
            if (this.model.momentum && duration < 500) {
                momentumX = this._hasHScroll ? ej._nativeMomentum(this._x, this._startX, duration, this._maxScrollX, this.model.enableBounce ? this._wrpWd : 0, this.model.deceleration, ej.isWindows() ? 10 : 1) : { dest: newX, duration: 0 };
                momentumY = this._hasVScroll ? ej._nativeMomentum(this._y, this._startY, duration, this._maxScrollY, this.model.enableBounce ? this._wrpHt : 0, this.model.deceleration, ej.isWindows() ? 10 : 1) : { dest: newY, duration: 0 };
                newX = momentumX.dest;
                newY = momentumY.dest;
                time = Math.max(momentumX.duration, momentumY.duration);
                this._isInTransition = 1;
            }

            if (this.model.displacementValue && this.model.enableDisplacement) {
                newY = this.model.displacementValue * Math.round(newY / this.model.displacementValue);
                newX = this.model.displacementValue * Math.round(newX / this.model.displacementValue);

                if (time < this.model.displacementTime)
                    time = this.model.diplacementTime;
            }
            if (newY < this._maxScrollY)
                newY = this._maxScrollY;
            if (newX < this._maxScrollX)
                newX = this._maxScrollX;
            if (newX != this._x || newY != this._y) {
                if (newX > 0 || newX < this._maxScrollX || newY > 0 || newY < this._maxScrollY) {
                    easing = ej.ease.quadratic;
                }

                this.scrollTo(newX, newY, time, easing);
                return;
            }
            this._moved = false;
            this._triggerEvent('scrollEnd', this._dataValue());
        },
        _scrollStop: function (e) {
            this._nx = this._$wrapper.scrollLeft();
            this._ny = this._$wrapper.scrollTop();
            this._trigger('scrollEnd', this._dataValue());
        },
        _zoomStart: function (e) {
            var c1 = Math.abs(e.touches[0].pageX - e.touches[1].pageX),
			c2 = Math.abs(e.touches[0].pageY - e.touches[1].pageY);

            this._touchesDistanceStart = Math.sqrt(c1 * c1 + c2 * c2);
            this._startScale = this._scale;

            this._originX = Math.abs(e.touches[0].pageX + e.touches[1].pageX) / 2 + this._wrapperOffset.left - this._x;
            this._originY = Math.abs(e.touches[0].pageY + e.touches[1].pageY) / 2 + this._wrapperOffset.top - this._y;

            this._triggerEvent('zoomStart', this._dataValue());
        },

        _zoom: function (e) {

            if (!this.model.enabled || this._eventType[e.type] !== this._startedScroll) {
                return;
            }

            if (this.model.preventDefault) {
                e.preventDefault();
            }

            var c1 = Math.abs(e.touches[0].pageX - e.touches[1].pageX),
			c2 = Math.abs(e.touches[0].pageY - e.touches[1].pageY),
			distance = Math.sqrt(c1 * c1 + c2 * c2),
			scale = 1 / this._touchesDistanceStart * distance * this._startScale,
			lastScale,
			x, y;

            this._scaled = true;

            if (scale < this.model.zoomMin) {
                scale = 0.5 * this.model.zoomMin * Math.pow(2.0, scale / this.model.zoomMin);
            } else if (scale > this.model.zoomMax) {
                scale = 2.0 * this.model.zoomMax * Math.pow(0.5, this.model.zoomMax / scale);
            }


            lastScale = scale / this._startScale;
            x = this._originX - this._originX * lastScale + this._startX;
            y = this._originY - this._originY * lastScale + this._startY;

            this._scale = scale;

            this.scrollTo(x, y, 0);
        },

        _zoomEnd: function (e) {
            if (!this.model.enabled || this._eventType[e.type] !== this._startedScroll) {
                return;
            }

            if (this.model.preventDefault) {
                e.preventDefault();
            }

            var newX, newY,
			lastScale;

            this._isInTransition = 0;
            this._startedScroll = 0;

            if (this._scale > this.model.zoomMax) {
                this._scale = this.model.zoomMax;
            } else if (this._scale < this.model.zoomMin) {
                this._scale = this.model.zoomMin;
            }

            // Update boundaries
            this.refresh();

            lastScale = this._scale / this._startScale;

            newX = this._originX - this._originX * lastScale + this._startX;
            newY = this._originY - this._originY * lastScale + this._startY;

            if (newX > 0) {
                newX = 0;
            } else if (newX < this._maxScrollX) {
                newX = this._maxScrollX;
            }

            if (newY > 0) {
                newY = 0;
            } else if (newY < this._maxScrollY) {
                newY = this._maxScrollY;
            }

            if (this._x != newX || this._y != newY) {
                this.scrollTo(newX, newY, this.model.bounceTime);
            }

            this._scaled = false;

            this._triggerEvent('zoomEnd', this._dataValue());
        },

        /**
        * To configure the resize of the Scrollpanel		
        * @private
        */
        _resize: function () {
            if (!this._$wrapper.is(":visible"))
                return;
            var proxy = this;
            clearTimeout(this._resizeTimeout);
            this._resizeTimeout = setTimeout(function () {
                proxy.refresh();
            }, ej.isAndroid() ? 250 : 0);
        },
        /**
        * To configure the _checkDOMChanges property of the Scrollpanel		
        * @private
        */
        _checkDOMChanges: function () {
            if (this._moved || this._animating ||
			(this._scrollerWidth == this._scroller.scrollWidth * this._scale && this._scrollerHeight == this._scroller.scrollHeight * this._scale)) return;
            this.model.isFixedPosition = false;
            this.refresh();
        },

        _scrollable: function () {
            return $(this._wrapper).map(function () {
                var elem = this,
				isWin = !elem.nodeName || $.inArray(elem.nodeName.toLowerCase(), ['iframe', '#document', 'html', 'body']) != -1;

                if (!isWin)
                    return elem;

                var doc = (elem.contentWindow || elem).document || elem.ownerDocument || elem;

                return /webkit/i.test(navigator.userAgent) || doc.compatMode == 'BackCompat' ?
				doc.body :
				doc.documentElement;
            });
        },
        _both: function (val) {
            return $.isFunction(val) || typeof val == 'object' ? val : { top: val, left: val };
        },
        _scrollTo: function (target, duration, settings) {
            var proxy = this;
            if (typeof duration == 'object') {
                settings = duration;
                duration = 0;
            }
            if (typeof settings == 'function')
                settings = { onAfter: settings };

            if (target == 'max')
                target = 9e9;

            settings = $.extend({}, { axis: 'xy', duration: 0, limit: true }, settings);
            duration = duration || settings.duration;
            settings.queue = settings.queue && settings.axis.length > 1;

            if (settings.queue)
                duration /= 2;
            settings.offset = this._both(settings.offset);
            settings.over = this._both(settings.over);

            return this._scrollable().each(function () {
                if (target == null) return;

                var elem = this,
				$elem = $(elem),
				targ = target, toff, attr = {},
				win = $elem.is('html,body');

                switch (typeof targ) {
                    case 'number':
                    case 'string':
                        if (/^([+-]=?)?\d+(\.\d+)?(px|%)?$/.test(targ)) {
                            targ = this._both(targ);
                            break;
                        }
                        targ = $(targ, this);
                        if (!targ.length) return;
                    case 'object':
                        if (targ.is || targ.style)
                            toff = (targ = $(targ)).offset();
                }

                var offset = $.isFunction(settings.offset) && settings.offset(elem, targ) || settings.offset;

                $.each(settings.axis.split(''), function (i, axis) {
                    var Pos = axis == 'x' ? 'Left' : 'Top',
					pos = Pos.toLowerCase(),
					key = 'scroll' + Pos,
					old = elem[key],
					max = proxy._scrollToMax(elem, axis);

                    if (toff) {
                        attr[key] = toff[pos] + (win ? 0 : old - $elem.offset()[pos]);

                        if (settings.margin) {
                            attr[key] -= parseInt(targ.css('margin' + Pos)) || 0;
                            attr[key] -= parseInt(targ.css('border' + Pos + 'Width')) || 0;
                        }

                        attr[key] += offset[pos] || 0;

                        if (settings.over[pos])
                            attr[key] += targ[axis == 'x' ? 'width' : 'height']() * settings.over[pos];
                    } else {
                        var val = targ[pos];
                        attr[key] = val.slice && val.slice(-1) == '%' ?
						parseFloat(val) / 100 * max
						: val;
                    }

                    if (settings.limit && /^\d+$/.test(attr[key]))
                        attr[key] = attr[key] <= 0 ? 0 : Math.min(attr[key], max);

                    if (!i && settings.queue) {
                        if (old != attr[key])
                            animate(settings.onAfterFirst);
                        delete attr[key];
                    }
                });

                animate(settings.onAfter);

                function animate(callback) {
                    $elem.animate(attr, duration, settings.easing, callback && function () {
                        callback.call(this, targ, settings);
                    });
                };

            }).end();
        },
        _scrollToMax: function (elem, axis) {
            var Dim = axis == 'x' ? 'Width' : 'Height',
			scroll = 'scroll' + Dim;

            if (!$(elem).is('html,body'))
                return elem[scroll] - $(elem)[Dim.toLowerCase()]();

            var size = 'client' + Dim,
			html = elem.ownerDocument.documentElement,
			body = elem.ownerDocument.body;

            return Math.max(html[scroll], body[scroll])
			 - Math.min(html[size], body[size]);
        },
        _transitionTime: function (time) {
            if (ej.getAndroidVersion() && ej.getAndroidVersion() <= 4)
                return;
            time = time || 0;
            this._scrollerStyle[ej.transitionDuration] = time + 'ms';
            if (this._scrollbars) {
                for (var i = this._scrollbars.length; i--; ) {
                    this._scrollbars[i].transitionTime(time);
                }
            }

        },

        _transitionTimingFunction: function (easing) {
            this._scrollerStyle[ej.transitionTimingFunction] = easing;
            if (this._scrollbars) {
                for (var i = this._scrollbars.length; i--; ) {
                    this._scrollbars[i].transitionTimingFunction(easing);
                }
            }
        },
        /**
        * To configure the translateZ property of the Scrollpanel		
        * @private
        */
        _translate: function (x, y) {
            if (this.model.enableTransform) {
                this._scrollerStyle[ej.transform] = 'translate3d(' + x + 'px,' + y + 'px,0) scale(' + this._scale + ')' + this.model.translateZ;
            } else {
                $(this._wrapper).scrollTop(Math.abs(y));
                $(this._wrapper).scrollLeft(Math.abs(x));
            }
            this._x = x;
            this._y = this.model.enableTransform ? y : -Math.abs(y);
            if (this._scrollbars) {
                for (var i = this._scrollbars.length; i--; ) {
                    this._scrollbars[i].setPosition();
                }
            }

        },
        _createDelegates: function () {
            this._resizeHandler = $.proxy(this._resize, this);
            this._touchStartHandler = $.proxy(this._touchStart, this);
            this._touchMoveHandler = $.proxy(this._touchMove, this);
            this._touchEndHandler = $.proxy(this._touchEnd, this);
            this._transitionEndHandler = $.proxy(this._transitionEnd, this);
            this._scrollStartHandler = $.proxy(this._scrollStart, this);
            this._scrollHandler = $.proxy(this._scroll, this);
            this._scrollStopHandler = $.proxy(this._scrollStop, this);
            this._wheelDelegate = $.proxy(this._wheel, this);
        },
        _isWinrt: function () {
            return (!this.model.enableTransform && ej.isWindows() && !ej.isMobile())
        },
        _wireEvents: function (remove) {
            var bind = remove ? "off" : "on";
            var evt = !ej.isTouchDevice() ? "resize" : "orientationchange";
            ej.listenEvents([window], [evt], [this._resizeHandler], remove);
            if (!this.model.disableTouch)
                ej.listenEvents([this._wrapper], [ej.startEvent()], [this._touchStartHandler], remove, this, this.model.disableMouse);
            if (this.model.enableNativeScrolling) {
                $(this._wrapper)[bind]("scrollstart", this._scrollStartHandler);
                $(this._wrapper)[bind]("scroll", this._scrollHandler);
                $(this._wrapper)[bind]("scrollstop", this._scrollStopHandler);
            }
            ej.listenTouchEvent(this._scroller, ej.transitionEndEvent(), this._transitionEndHandler, remove);
        },
        _initScrollbars: function () {
            var interactive = this.model.enableInteraction,
			showScrollbars = [],
			scrollbar;

            this._scrollbars = [];

            if (this.model.showScrollbars) {
                // Vertical scrollbar
                if (this.model.enableVrScroll) {
                    scrollbar = {
                        el: this._createDefaultScrollbar('vertical', interactive, this.model.showScrollbars),
                        enableInteraction: interactive,
                        enableShrink: this.model.enableShrink,
                        enableFade: this.model.enableFade,
                        enableResize: this.model.enableResize,
                        listenX: false

                    };

                    this._wrapper.appendChild(scrollbar.el);
                    showScrollbars.push(scrollbar);
                    this.element.append(this._sbw);
                }

                // Horizontal scrollbar
                if (this.model.enableHrScroll) {
                    scrollbar = {
                        el: this._createDefaultScrollbar('horizontal', interactive, this.model.showScrollbars),
                        enableInteraction: interactive,
                        enableShrink: this.model.enableShrink,
                        enableFade: this.model.enableFade,
                        enableResize: this.model.enableResize,
                        listenY: false
                    };

                    this._wrapper.appendChild(scrollbar.el);
                    showScrollbars.push(scrollbar);
                    this.element.append(this._sbw);
                }
            }

            if (this.model.showScrollbars) {
                showScrollbars = showScrollbars.concat();
            }

            for (var i = showScrollbars.length; i--; ) {
                this._scrollbars[i] = new Scrollbar(this, showScrollbars[i]);
            }
            if (this.model.enableFade) {
                this.on('scrollEnd', function (args) {
                    if (args.model.showScrollbars) {
                        for (var i = args.object._scrollbars.length; i--; ) {
                            args.object._scrollbars[i].enableFade();
                        }
                    }
                });

                this.on('scrollCancel', function (args) {
                    if (args.model.showScrollbars) {
                        for (var i = args.object._scrollbars.length; i--; ) {
                            args.object._scrollbars[i].enableFade();
                        }
                    }
                });

                this.on('scrollStart', function (args) {
                    if (args.model.showScrollbars) {
                        for (var i = args.object._scrollbars.length; i--; ) {
                            args.object._scrollbars[i].enableFade(1);
                        }
                    }
                });
            }
            this.on('refresh', function (args) {
                if (args.model.showScrollbars) {
                    for (var i = args.object._scrollbars.length; i--; ) {
                        args.object._scrollbars[i].refresh();
                    }
                }
            });

            this.on('destroy', function (args) {
                if (args.model.showScrollbars) {
                    for (var i = args.object._scrollbars.length; i--; ) {
                        args.object._scrollbars[i].destroy();
                    }
                }

                delete this._scrollbars;
            });
        },

        _triggerEvent: function (type, data) {
            if (!this._scrollEvents[type]) {
                return;
            }

            var i = 0,
			l = this._scrollEvents[type].length;

            if (!l) {
                return;
            }
            for (; i < l; i++) {
                this._triggerInternalEvent(this._scrollEvents[type][i], type, data, this);
            }
        },
        _triggerInternalEvent: function (type, event, data, element) {
            if (type) {
                var fn = type;
                if (typeof fn === "string")
                    fn = ej.util.getObject(fn, window);
                event = $.Event(event);
                event.type = type;
                args = ej.event(event, this.model, data);
                return !($.isFunction(fn) && fn.call(this, args) === false || event.isDefaultPrevented());
            }
        },
        _initWheel: function () {
            var proxy = this;
            this._bindWheelEvents();
            this.on('destroy', function () {
                proxy._bindWheelEvents(remove);
            });
        },
        _bindWheelEvents: function (remove) {
            ej.listenEvents([this._wrapper, this._wrapper], ["mouseWheel", "DOMMouseScroll"], [this._wheelDelegate, this._wheelDelegate], remove);
        },
        _wheel: function (e) {
            if (!this.model.enabled) {
                return;
            }

            e.preventDefault();

            var wheelDeltaX, wheelDeltaY,
			newX, newY,
			proxy = this;

            if (this.wheelTimeout === undefined) {
                this._triggerEvent('scrollStart', this._dataValue());
            };
            clearTimeout(this.wheelTimeout);
            this.wheelTimeout = setTimeout(function () {
                proxy._triggerEvent('scrollEnd', proxy._dataValue());
            }, 400);
            if ('deltaX' in e) {
                wheelDeltaX = -e.deltaX;
                wheelDeltaY = -e.deltaY;
            }
            else if ('wheelDeltaX' in e) {
                wheelDeltaX = e.wheelDeltaX / 120;
                wheelDeltaY = e.wheelDeltaY / 120;
            } else if ('wheelDelta' in e) {
                wheelDeltaX = wheelDeltaY = e.wheelDelta / 120;
            } else if ('detail' in e) {
                wheelDeltaX = wheelDeltaY = -e.detail / 3;
            } else {
                return;
            }

            wheelDeltaX *= this.model.wheelSpeed;
            wheelDeltaY *= this.model.wheelSpeed;

            if (!this._hasVScroll) {
                wheelDeltaX = wheelDeltaY;
                wheelDeltaY = 0;
            }


            newX = this._x + Math.round(this._hasHScroll ? wheelDeltaX * this.model.invertWheel : 0);
            newY = this._y + Math.round(this._hasVScroll ? wheelDeltaY * this.model.invertWheel : 0);
            if (newX > 0) {
                newX = 0;
            } else if (newX < this._maxScrollX) {
                newX = this._maxScrollX;
            }
            if (newY > 0) {
                newY = 0;
            } else if (newY < this._maxScrollY) {
                newY = this._maxScrollY;
            }

            this.scrollTo(newX, newY, 0);
        },
        _initKeys: function (e) {
            var keys = {
                pageUp: 33,
                pageDown: 34,
                end: 35,
                home: 36,
                left: 37,
                up: 38,
                right: 39,
                down: 40
            };
            var i;
            if (typeof this.model.enableKeys == 'object') {
                for (i in this.model.enableKeys) {
                    if (typeof this.model.enableKeys[i] == 'string') {
                        this.mdoel.enableKeys[i] = this.model.enableKeys[i].toUpperCase().charCodeAt(0);
                    }
                }
            } else {
                this.model.enableKeys = {};
            }
            for (i in keys) {
                this.model.enableKeys[i] = this.model.enableKeys[i] || keys[i];
            }
            var keyDownDelegate = $.proxy(this._keyPress, this);
            ej.listenTouchEvent(window, "keydown", keyDownDelegate);
            this.on('destroy', function () {
                ej.listenTouchEvent(window, "keydown", keyDownDelegate, true);
            });
        },
        _startAni: function () {
            var proxy = this,
			startX = this._startX, startY = this._startY,
			startTime = Date.now(),
			step, easeOut,
			animate;

            var proxy = this;
            if (this._animating) return;

            if (!this._steps.length) {
                this.resetPosition(400);
                return;
            }

            step = this._steps.shift();

            if (step.x == startX && step.y == startY) step.time = 0;

            this._animating = true;
            this._moved = true;



            animate = function () {
                var now = Date.now(),
				newX, newY;
                if (now >= startTime + step.time) {
                    proxy._translate(step.x, step.y);
                    proxy._animating = false;
                    proxy._moved = false;
                    if (proxy.model.scrollEnd) proxy._triggerEvent('scrollEnd', proxy._dataValue());
                    proxy._startAni();
                    return;
                }

                now = (now - startTime) / step.time - 1;
                easeOut = Math.sqrt(1 - now * now);
                newX = (step.x - startX) * easeOut + startX;
                newY = (step.y - startY) * easeOut + startY;
                proxy._translate(newX, newY);
                if (proxy._animating) proxy._aniTime = nextFrame(animate);
            };

            animate();
        },
        _keyPress: function (e) {
            if (!this.model.enabled) {
                return;
            }
            var newX = this._x,
			newY = this._y,
			now = this._getTime(),
			prevTime = this._keyTime || 0,
			acceleration = 0.250,
			pos;
            if (this.model.enableTransition && this._isInTransition) {
                pos = this.getComputedPosition();

                this._translate(Math.round(pos.x), Math.round(pos.y));
                this._isInTransition = false;
            }
            this._keyAcc = now - prevTime < 200 ? Math.min(this._keyAcc + acceleration, 50) : 0;
            switch (e.keyCode) {
                case this.model.enableKeys.pageUp:
                    if (this._hasHScroll && !this._hasVScroll) {
                        newX += this._wrpWd;
                    } else {
                        newY += this._wrpHt;
                    }
                    break;
                case this.model.enableKeys.pageDown:
                    if (this._hasHScroll && !this._hasVScroll) {
                        newX -= this._wrpWd;
                    } else {
                        newY -= this._wrpHt;
                    }
                    break;
                case this.model.enableKeys.end:
                    newX = this._maxScrollX;
                    newY = this._maxScrollY;
                    break;
                case this.model.enableKeys.home:
                    newX = 0;
                    newY = 0;
                    break;
                case this.model.enableKeys.left:
                    newX += 5 + this._keyAcc >> 0;
                    break;
                case this.model.enableKeys.up:
                    newY += 5 + this._keyAcc >> 0;
                    break;
                case this.model.enableKeys.right:
                    newX -= 5 + this._keyAcc >> 0;
                    break;
                case this.model.enableKeys.down:
                    newY -= 5 + this._keyAcc >> 0;
                    break;
                default:
                    return;
            }

            if (newX > 0) {
                newX = 0;
                this.keyAcceleration = 0;
            } else if (newX < this._maxScrollX) {
                newX = this._maxScrollX;
                this._keyAcc = 0;
            }

            if (newY > 0) {
                newY = 0;
                this._keyAcc = 0;
            } else if (newY < this._maxScrollY) {
                newY = this._maxScrollY;
                this._keyAcc = 0;
            }

            this.scrollTo(newX, newY, 0);

            this._keyTime = now;
        },
        _setModel: function (options) {
            this._refresh();
        },
        _refresh: function () {
            this._destroy();
            this._init();
            this._wireEvents();
        },
        _clearElement: function () {
            if (this._sbw)
                this._sbw.remove();
            this.element.removeAttr("class");
            var target = typeof this.model.target == 'string' ? $("#" + this.model.target)[0] : this.model.target;
            $(target).removeAttr("style");
            $(target).removeClass("e-m-scrollpanel e-m-scroll-native e-m-scroll-wrapper e-m-scroll-box e-m-scroll-hide e-m-zoom");
            if (this.model.enableTransform)
                $($(target).children()[0]).css(ej.transform, "");
        },
        // all events bound using this._on will be unbind automatically
        _destroy: function () {
            this._wireEvents(true);
            this._clearElement();
        },
        /**
        * To get the current time.
        * @private
        */
        _getTime: function () {
            return Date.now();
        },
        /**
        * To reset the position.
        * @private
        */
        resetPosition: function (time) {
            if (!this.model.enableNativeScrolling && this.model.enableTransform) {
                var x = this._x,
        y = this._y;

                time = time || 0;

                if (!this._hasHScroll || this._x > 0) {
                    x = 0;
                } else if (this._x < this._maxScrollX) {
                    x = this._maxScrollX;
                }

                if (!this._hasVScroll || this._y > 0) {
                    y = 0;
                } else if (this._y < this._maxScrollY) {
                    y = this._maxScrollY;
                }

                if (x == this._x && y == this._y) {
                    return false;
                }

                this.scrollTo(x, y, time, this.model.bounceEasing);

                return true;
            }
        },
        /**
        * To scroll the page to the element given.
        * @private
        */
        scrollToElement: function (el, time, offsetX, offsetY, easing) {
            el = el.nodeType ? el : this._scroller.querySelector(el);

            if (!el) {
                return;
            }

            var pos = $(el).offset();

            pos.left -= this._wrapperOffset.left;
            pos.top -= this._wrapperOffset.top;

            // if offsetX/Y are true we center the element to the screen
            if (offsetX === true) {
                offsetX = Math.round(el.offsetWidth / 2 - this._wrapper.offsetWidth / 2);
            }
            if (offsetY === true) {
                offsetY = Math.round(el.offsetHeight / 2 - this._wrapper.offsetHeight / 2);
            }

            pos.left -= offsetX || 0;
            pos.top -= offsetY || 0;

            pos.left = pos.left > 0 ? 0 : pos.left < this._maxScrollX ? this_.maxScrollX : pos.left;
            pos.top = pos.top > 0 ? 0 : pos.top < this._maxScrollY ? this._maxScrollY : pos.top;

            time = time === undefined || time === null || time === 'auto' ? Math.max(Math.abs(this._x - pos.left), Math.abs(this._y - pos.top)) : time;

            this.scrollTo(pos.left, pos.top, time, easing);
        },
        /**
        * To enable the event.
        * @private
        */
        on: function (type, fn) {
            if (!this._scrollEvents[type]) {
                this._scrollEvents[type] = [];
            }
            this._scrollEvents[type].push(fn);
        },
        /**
        * To create default scrollbars.
        * @private
        */
        _createDefaultScrollbar: function (direction, interactive, type) {
            this._sbw = ej.buildTag('div.e-m-sbw e-m-' + this.model.renderMode + ' e-m-' + this.model.theme),
		    sb = ej.buildTag('div.e-m-sb');


            if (direction == 'horizontal' && type)
                this._sbw.addClass('e-m-hr');
            else if (direction == 'vertical' && type)
                this._sbw.addClass('e-m-ver');
            if (!interactive) {
                this._sbw[0].style.pointerEvents = 'none';
            }
            this._sbw.append(sb);

            return this._sbw[0];
        },
        /*---------------Public Methods---------------*/

        /**
        * To zoom the scroll content.
        * @return jQuery
        * @example
        * &lt;div id="maincontent"&gt;
        * &lt;div&gt;
        * Scroll content here
        * &lt;/div&gt;
        * &lt;/div&gt;
        * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent"/&gt;
        * &lt;script&gt;
        * // Refresh the scroll panel
        * $(function (){
        * var scroll= $("#scrollpanel").data("ejmScrollPanel");
        * $( "#maincontent" ).click(function() {
        * scroll.zoom(10,1,1,1);
        *  });
        *  });
        * &lt;/script&gt;
        *@memberof ejmScrollPanel
        * @instance
        */
        zoom: function (scale, x, y, time) {

            if (scale < this.model.zoomMin) {
                scale = this.model.zoomMin;
            } else if (scale > this.model.zoomMax) {
                scale = this.model.zoomMax;
            }

            if (scale == this._scale) {
                return;
            }

            var relScale = scale / this._scale;

            x = x === undefined ? this._wrpWd / 2 : x;
            y = y === undefined ? this._wrpHt / 2 : y;
            time = time === undefined ? 300 : time;

            x = x + this._wrapperOffset.left - this._x;
            y = y + this._wrapperOffset.top - this._y;

            x = x - x * relScale + this._x;
            y = y - y * relScale + this._y;

            this._scale = scale;

            this.refresh();

            if (x > 0) {
                x = 0;
            } else if (x < this._maxScrollX) {
                x = this._maxScrollX;
            }

            if (y > 0) {
                y = 0;
            } else if (y < this._maxScrollY) {
                y = this._maxScrollY;
            }

            this.scrollTo(x, y, time);
        },
        /**
        * To disable the scrollpanel.
        * @return jQuery
        * @example
        * &lt;div id="maincontent"&gt;
        * &lt;div&gt;
        * Scroll content here
        * &lt;/div&gt;
        * &lt;/div&gt;
        * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent"/&gt;
        * &lt;script&gt;
        * // Disable the scroll panel
        * $("#scrollpanel").ejmScrollPanel('disable');	
        * &lt;/script&gt;
        *@memberof ejmScrollPanel
        * @instance
        */
        disable: function () {
            this.model.enabled = false;
        },
        /**
        * To enable the scrollpanel.
        * @return jQuery
        * @example
        * &lt;div id="maincontent"&gt;
        * &lt;div&gt;
        * Scroll content here
        * &lt;/div&gt;
        * &lt;/div&gt;
        * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent"/&gt;
        * &lt;script&gt;
        * // Enable the scroll panel
        * $("#scrollpanel").ejmScrollPanel('enable');	
        * &lt;/script&gt;
        *@memberof ejmScrollPanel
        * @instance
        */
        enable: function () {
            this.model.enabled = true;
        },
        /**
        * To refresh the scrollpanel.
        * @return jQuery
        * @example
        * &lt;div id="maincontent"&gt;
        * &lt;div&gt;
        * Scroll content here
        * &lt;/div&gt;
        * &lt;/div&gt;
        * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent"/&gt;
        * &lt;script&gt;
        * // Refresh the scroll panel
        * $("#scrollpanel").ejmScrollPanel('refesh');	
        * &lt;/script&gt;
        *@memberof ejmScrollPanel
        * @instance
        */
        refresh: function () {
            if (!this._scroller)
                return;
            var rf = this._wrapper.offsetHeight;
            var page = ej.getCurrentPage();
            if (this.model.adjustFixedPosition) {
                if (page.find(".e-m-header.e-m-fixed:visible").length) {
                    if ($(this._wrapper).offset().top == 0) {
                        $(this._wrapper).css("margin-top", page.find(".e-m-header.e-m-fixed:visible").height());
                    }
                    this.model.isFixedPosition = true;
                    this._footerHeight = 0;
                }
                if (page.find(".e-m-tb.e-m-android.e-m-fixed:visible").length > 0) {
                    if ($(this._wrapper).offset().top == 0) {
                        $(this._wrapper).css("margin-top", page.find(".e-m-tb.e-m-android.e-m-fixed:visible").height());
                    }
                    this.model.isFixedPosition = true;
                    this._footerHeight = 0;
                }
                if (page.find(".e-m-footer.e-m-fixed:visible").length > 0 || (page.find(".e-m-footer:visible").length && !$(this._wrapper).find(".e-m-footer:visible").length)) {
                    this._footerHeight = page.find(".e-m-footer:visible").height()
                    this.model.isFixedPosition = true;
                }
                if (page.find(".e-m-tab.e-m-ios7.e-m-fixed:visible").length > 0 || (page.find(".e-m-tab.e-m-ios7:visible").length && !$(this._wrapper).find(".e-m-tab.e-m-ios7:visible").length)) {
                    this._footerHeight = page.find(".e-m-tab.e-m-ios7:visible").height();
                    this.model.isFixedPosition = true;
                }
                else if (page.find(".e-m-tab.e-m-fixed:visible").length) {
                    if ($(this._wrapper).offset().top == 0) {
                        $(this._wrapper).css("margin-top", page.find(".e-m-tab.e-m-fixed:visible").height());
                    }
                    this.model.isFixedPosition = true;
                    this._footerHeight = 0;
                }
                if (page.find(".e-m-tb.e-m-windows.e-m-fixed,.e-m-tb.e-m-ios7.e-m-fixed:visible").length > 0 || (page.find(".e-m-tb.e-m-windows:visible,.e-m-tb.e-m-ios7:visible").length && !$(this._wrapper).find(".e-m-tb.e-m-windows:visible,.e-m-tb.e-m-ios7:visible").length)) {
                    this._footerHeight = page.find(".e-m-tb.e-m-windows:visible,.e-m-tb.e-m-ios7:visible").height();
                    this.model.isFixedPosition = true;
                }

            }
            if (this.model.targetHeight)
                $(this._wrapper).height(this.model.targetHeight);
            else if (this.model.autoAdjustHeight)
                $(this._wrapper).height(window.innerHeight - $(this._wrapper).offset().top - parseInt($(this._wrapper).css("margin-bottom")) - (this.model.isFixedPosition ? this._footerHeight : 0) - parseInt($(this._wrapper).css("padding-top")) - parseInt($(this._wrapper).css("padding-bottom")));

            if (this.model.targetWidth)
                $(this._wrapper).width(this.model.targetWidth);

            if (this.model.scrollWidth)
                $(this._scroller).width(this.model.scrollWidth);
            if (this.model.scrollHeight)
                $(this._scroller).height(this.model.scrollHeight);
            this._wrpWd = this._wrapper.clientWidth;
            this._wrpHt = this.model.autoAdjustHeight ? $(this._wrapper).height() : this._wrapper.clientHeight;
            this._scrollerWidth = this._scroller.scrollWidth * this._scale;
            this._scrollerHeight = this._scroller.scrollHeight * this._scale;
            this._maxScrollX = this._wrpWd - this._scrollerWidth;
            this._maxScrollY = this._wrpHt - this._scrollerHeight;
            this._hasHScroll = this.model.enableHrScroll && this._maxScrollX < 0;
            this._hasVScroll = this.model.enableVrScroll && this._maxScrollY < 0;

            if (!this._hasHScroll) {
                this._maxScrollX = 0;
                this._scrollerWidth = this._wrpWd;
            }
            if (!this._hasVScroll) {
                this._maxScrollY = 0;
                this._scrollerHeight = this._wrpHt;
            }
            this._endTime = 0;
            this._directionX = 0;
            this._directionY = 0;
            this._wrapperOffset = $(this._wrapper).offset();
            this._triggerEvent('refresh', this._dataValue());
            if (!this.model.showScrollbars)
                this._$wrapper.addClass("e-m-hidescrollbar");
            if (this.model.enableNativeScrolling)
                this._hasHScroll && this._hasVScroll ? this._$wrapper.css("overflow", "auto") : this._hasVScroll ? this._$wrapper.css("overflow-y", "auto") : this._hasHScroll ? this._$wrapper.css("overflow-x", "auto") : (this.model.renderMode == "windows" && !ej.isMobile()) ? this._$wrapper.css("overflow", "scroll") : this._$wrapper.css("overflow", "auto");
            if (this.model.enableNativeScrolling && ej.isWindows()) {
                if (this._hasHScroll && !this._hasVScroll)
                    this._$wrapper.addClass("e-m-horizontal");
                else if (this._hasVScroll && !this._hasHScroll)
                    this._$wrapper.addClass("e-m-vertical");
            }
            this.resetPosition();
        },
        /**
        * To make the content scroll with time and easing given.
        * @return jQuery
        * @example
        * &lt;div id="maincontent"&gt;
        * &lt;div&gt;
        * Scroll content here
        * &lt;/div&gt;
        * &lt;/div&gt;
        * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent"/&gt;
        * &lt;script&gt;        
        * $(function (){
        * var scroll= $("#scrollpanel").data("ejmScrollPanel");
        * $( "#maincontent" ).click(function() {
        * scroll.scrollBy(100,1000,5,10);
        * });     
        * });
        * &lt;/script&gt;
        *@memberof ejmScrollPanel
        * @instance
        */
        scrollBy: function (x, y, time, easing) {
            x = this._x + x;
            y = this._y + y;
            time = time || 0;

            this.scrollTo(x, y, time, easing);
        },
        /**
        * To make the content scroll to the position given.
        * @return jQuery
        * @example
        * &lt;div id="maincontent"&gt;
        * &lt;div&gt;
        * Scroll content here
        * &lt;/div&gt;
        * &lt;/div&gt;
        * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent"/&gt;
        * &lt;script&gt;        
        * $(function (){
        * var scroll= $("#scrollpanel").data("ejmScrollPanel");
        * $( "#maincontent" ).click(function() {
        * scroll.scrollTo(10,10);
        * });     
        * });
        * &lt;/script&gt;
        *@memberof ejmScrollPanel
        * @instance
        */
        scrollTo: function (x, y, time, relative, easing) {
            var proxy = this;
            if (!this.model.enableNativeScrolling) {
                easing = easing || ej.ease.circular;
                if (this.model.enableTransition && easing.style) {
                    this._isInTransition = this.model.enableTransition && time > 0;
                    this._transitionTimingFunction(easing.style);
                    this._transitionTime(time);
                    this._translate(x, y);
                } else {
                    if (this._x == x && this._y == y)
                        return;
                    var step = x,
			i, l;

                    this.stop();

                    if (!step.length) step = [{ x: x, y: y, time: time, relative: relative}];

                    for (i = 0, l = step.length; i < l; i++) {
                        if (step[i].relative) { step[i].x = this._x - step[i].x; step[i].y = this._y - step[i].y; }
                        this._steps.push({ x: step[i].x, y: step[i].y, time: step[i].time || 0 });
                    }

                    this._startAni();
                }
            }
            else {
                this._nx = x, this._ny = y;
                this._scrollTo({ top: y, left: x }, time, {
                    queue: true, easing: 0, onAfter: function () {
                        proxy._nx = $(proxy._wrapper).scrollLeft();
                        proxy._ny = $(proxy._wrapper).scrollTop();
                    }
                });
            }
        },
        /**
        * To get the computed position.
        * @return jQuery
        * @example
        * &lt;div id="maincontent"&gt;
        * &lt;div&gt;
        * Scroll content here
        * &lt;/div&gt;
        * &lt;/div&gt;
        * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent"/&gt;
        * &lt;script&gt;
        * // Refresh the scroll panel
        * $("#scrollpanel").ejmScrollPanel('getComputedPosition');	
        * &lt;/script&gt;
        *@memberof ejmScrollPanel
        * @instance
        */
        getComputedPosition: function () {
            var matrix = window.getComputedStyle(this._scroller, null),
			x, y;

            if (this.model.enableTransform) {
                matrix = matrix[ej.transform].split(')')[0].split(', ');
                x = +(matrix[12] || matrix[4]);
                y = +(matrix[13] || matrix[5]);
            } else {
                x = +matrix.left.replace(/[^-\d.]/g, '');
                y = +matrix.top.replace(/[^-\d.]/g, '');
            }

            return { x: x, y: y };
        },

        /**
        * To stop the scrolling.
        * @return jQuery
        * @example
        * &lt;div id="maincontent"&gt;
        * &lt;div&gt;
        * Scroll content here
        * &lt;/div&gt;
        * &lt;/div&gt;
        * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent"/&gt;
        * &lt;script&gt;
        * // Refresh the scroll panel
        * $("#scrollpanel").ejmScrollPanel('stop');	
        * &lt;/script&gt;
        *@memberof ejmScrollPanel
        * @instance
        */
        stop: function () {
            cancelFrame(this._aniTime);
            this._steps = [];
            this._moved = false;
            this._animating = false;
        },
        /**
        * To get the scroll position.
        * @return jQuery
        * @example
        * &lt;div id="maincontent"&gt;
        * &lt;div&gt;
        * Scroll content here
        * &lt;/div&gt;
        * &lt;/div&gt;
        * &lt;div id="scrollpanel" data-role="ejmscrollpanel" data-ej-target="maincontent"/&gt;
        * &lt;script&gt;
        * // Refresh the scroll panel
        * $("#scrollpanel").ejmScrollPanel('getScrollPosition');	
        * &lt;/script&gt;
        *@memberof ejmScrollPanel
        * @instance
        */
        getScrollPosition: function () {
            return { "x": this.model.enableNativeScrolling ? this._nx : this._x, "y": this.model.enableNativeScrolling ? this._ny : this._y };
        }

        /*---------------Public Methods End---------------*/

    });
})(jQuery, Syncfusion);