﻿/**
* @fileOverview Plugin to style the Html slider elements
* @copyright Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/
(function ($, ej, undefined) {
    /**
    * @namespace ej
    * @class ejmSlider
    * @requires jQuery
    * @requires ej.mobile.application
    * @requires ej.core
    * @requires ej.unobtrusive
    * @requires ej.mobile.core
    * @requires ej.data
    * @requires ej.touch
    * @classdesc Custom Design for Html slider control.
    * @example 
    * &lt;div id="slider" &gt;&lt;/div&gt;<br>
    * &lt;script&gt; 
    * // Create slider  
    * $("#slider").ejmSlider(); 
    * &lt;/script&gt;
    * @example 
    * &lt;div id="slider" data-role="ejmslider" &gt;&lt;/div&gt;<br>
    */

    // ejSlider is the plugin name 
    // "ej.slider" is "namespace.className" will hold functions and properties

    ej.widget("ejmSlider", "ej.mobile.slider", {
        _setFirst: true,
        _rootCSS: "e-m-slider",
        // default model
        defaults: {
            /**		
            * Specifies the theme.  See {@link Theme}
            * @default auto
            * @type {enum}
            * @example 
            * //Set the theme property in unobtrusive way.
            * &lt;div id="slider" data-role="ejmslider" data-ej-theme="auto" &gt;&lt;/div&gt;<br>
            * @example 
            * // Set slider theme on initialization. 
            * //To set theme API value 
            * &lt;div id="slider" &gt;&lt;/div&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#slider").ejmSlider ({ theme: ej.mobile.Theme.Dark });		
            * });
            * &lt;/script&gt;			
            * @example 
            * &lt;script&gt;
            * //Get or set the slider theme, after initialization:<br>
            * // Get the theme API value.		
            *  $("#slider").ejmSlider ("option", "theme");			
            * // Set the theme API
            * $("#slider").ejmSlider ("option", "theme", ej.mobile.Theme.Dark);        
            * &lt;/script&gt;
            * @memberof ejmSlider
            * @instance
            */
            theme: "auto",
            /**		
            * Specifies whether the orientation is horizontal or vertical. See {@link Orientation}
            * @default ej.mobile.slider.Orientation.Horizontal. 
            * @type {enum}
            * @example 
            * //Set the orientation property in unobtrusive way.
            * &lt;div id="slider" data-role="ejmslider" data-ej-orientation="horizontal" &gt;&lt;/div&gt;<br>
            * @example 
            * // Set slider orientation on initialization. 
            * //To set orientation API value 
            * &lt;div id="slider" &gt;&lt;/div&gt;
            * &lt;script&gt;
            * $("#slider").ejmSlider ({ orientation: ej.mobile.slider.Orientation.Vertical });			
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set the slider orientation, after initialization:<br>
            * // Get the orientation API value.		
            *  $("#slider").ejmSlider ("option", "orientation");			
            * // Set the orientation API
            * $("#slider").ejmSlider ("option", "orientation", ej.mobile.slider.Orientation.Horizontal);  
            * &lt;/script&gt;
            * @memberof ejmSlider
            * @instance
            */
            orientation: "horizontal",
            /**		
            * Specifies the maximum value.
            * @default 100
            * @type {int}
            * @example 
            * //Set the maxValue property in unobtrusive way.
            * &lt;div id="slider" data-role="ejmslider" data-ej-maxValue=100 &gt;&lt;/div&gt;<br>
            * @example 
            * // Set slider maxValue on initialization. 
            * //To set maxValue API value 
            * &lt;div id="slider" &gt;&lt;/div&gt;
            * &lt;script&gt;
            * $("#slider").ejmSlider ({ maxValue: 100 });	
            * &lt;/script&gt;			
            * @example 
            * &lt;script&gt;
            * //Get or set the slider maxValue, after initialization:<br>
            * // Get the maxValue API value.		
            *  $("#slider").ejmSlider ("option", "maxValue");			
            * // Set the maxValue API
            * $("#slider").ejmSlider ("option", "maxValue", 100);    
            * &lt;/script&gt;
            * @memberof ejmSlider
            * @instance
            */
            maxValue: 100,
            /**		
            * Specifies the minimum value.
            * @default 0
            * @type {int}
            * @example 
            * //Set the minValue property in unobtrusive way.
            * &lt;div id="slider" data-role="ejmslider" data-ej-minValue=0 &gt;&lt;/div&gt;<br>
            * @example 
            * // Set slider minValue on initialization. 
            * //To set minValue API value 
            * &lt;div id="slider" &gt;&lt;/div&gt;
            * &lt;script&gt;
            * $("#slider").ejmSlider ({ minValue: 0 });	
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set the slider minValue, after initialization:<br>
            * // Get the minValue API value.		
            *  $("#slider").ejmSlider ("option", "minValue");			
            * // Set the minValue API
            * $("#slider").ejmSlider ("option", "minValue", 0);     
            * &lt;/script&gt;
            * @memberof ejmSlider
            * @instance
            */
            minValue: 0,
            /**		
            * Specifies whether to enable range slider.
            * @default false
            * @type {bool}
            * @example 
            * //Set the enableRange property in unobtrusive way.
            * &lt;div id="slider" data-role="ejmslider" data-ej-enablerange=false &gt;&lt;/div&gt;<br>
            * @example 
            * &lt;div id="slider" &gt;&lt;/div&gt;
            * &lt;script&gt;
            * // Set slider enableRange on initialization. 
            * //To set enableRange API value 
            * $("#slider").ejmSlider ({ enableRange: false });	
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set the slider enableRange, after initialization:<br>
            * // Get the enableRange API value.		
            *  $("#slider").ejmSlider ("option", "enableRange");			
            * // Set the enableRange API
            * $("#slider").ejmSlider ("option", "enableRange", false);
            * &lt;/script&gt;
            * @memberof ejmSlider
            * @instance
            */
            enableRange: false,
            /**		
            * Specifies the values when range slider is enabled.
            * @default [20,80]
            * @type {int[]}
            * @example 
            * //Set the values property in unobtrusive way.
            * &lt;div id="slider" data-role="ejmslider" data-ej-enablerange=true data-ej-values=[20,80] &gt;&lt;/div&gt;<br>
            * @example 
            * // Set slider values on initialization. 
            * //To set values API value
            * &lt;div id="slider" &gt;&lt;/div&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#slider").ejmSlider ({ enableRange: true,  values: [20,80] });
            * });
            * &lt;/script&gt;			
            * @example 
            * &lt;script&gt;
            * //Get or set the slider values, after initialization:<br>
            * // Get the values API value.		
            *  $("#slider").ejmSlider ("option", "values");			
            * // Set the values API
            * $("#slider").ejmSlider ("option", "values", [20,80]);  
            * &lt;/script&gt;
            * @memberof ejmSlider
            * @instance
            */
            values: [20, 80],
            /**		
            * Specifies whether to enable animation.
            * @default false
            * @type {bool}
            * @example 
            * //Set the enableanimation property in unobtrusive way.
            * &lt;div id="slider" data-role="ejmslider" data-ej-enableanimation=true &gt;&lt;/div&gt;<br>
            * @example 
            * // Set slider enableanimation on initialization. 
            * //To set enableAnimation API value 
            * &lt;div id="slider" &gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * $("#slider").ejmSlider ({ enableAnimation: false });	
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set the slider enableAnimation, after initialization:<br>
            * // Get the enableAnimation API value.		
            *  $("#slider").ejmSlider ("option", "enableAnimation");			
            * // Set the enableAnimation API
            * $("#slider").ejmSlider ("option", "enableAnimation", false);  
            * &lt;/script&gt;
            * @memberof ejmSlider
            * @instance
            */
            enableAnimation: false,
            /**		
            * Specifies the animation speed when animation is enabled.
            * @default 400
            * @type {int}
            * @example 
            * //Set the animationSpeed property in unobtrusive way.
            * &lt;div id="slider" data-role="ejmslider" data-ej-animationSpeed=100 &gt;&lt;/div&gt;<br>
            * @example 
            * // Set slider animationSpeed on initialization. 
            * //To set animationSpeed API value 
            * &lt;div id="slider" &gt;&lt;/div&gt;
            * &lt;script&gt;
            * $("#slider").ejmSlider ({ animationSpeed: 400 });		
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set the slider animationSpeed, after initialization:<br>
            * // Get the animationSpeed API value.		
            *  $("#slider").ejmSlider ("option", "animationSpeed");			
            * // Set the animationSpeed API
            * $("#slider").ejmSlider ("option", "animationSpeed", 400);  
            * &lt;/script&gt;
            * @memberof ejmSlider
            * @instance
            */
            animationSpeed: 400,
            /**		
            * Specifies whether the control is read only.
            * @default false
            * @type {bool}
            * @example 
            * //Set the readOnly property in unobtrusive way.
            * &lt;div id="slider" data-role="ejmslider" data-ej-readOnly=true &gt;&lt;/div&gt;<br>
            * @example 
            * // Set slider readOnly on initialization. 
            * //To set readOnly API value 
            * &lt;div id="slider" &gt;&lt;/div&gt;
            * &lt;script&gt;
            * $("#slider").ejmSlider ({ readOnly: false });		
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set the slider readOnly, after initialization:<br>
            * // Get the readOnly API value.		
            *  $("#slider").ejmSlider ("option", "readOnly");			
            * // Set the readOnly API
            * $("#slider").ejmSlider ("option", "readOnly", false);    
            * &lt;/script&gt;
            * @memberof ejmSlider
            * @instance
            */
            readOnly: false,
            /**		
            * Specifies the step value for incrementation.
            * @default 1
            * @type {int}
            * @example 
            * //Set the incrementStep property in unobtrusive way.
            * &lt;div id="slider" data-role="ejmslider" data-ej-incrementstep=1 &gt;&lt;/div&gt;<br>
            * @example 
            * &lt;div id="slider" &gt;&lt;/div&gt;
            * &lt;script&gt;
            * // Set slider incrementStep on initialization. 
            * //To set incrementStep API value 
            * $("#slider").ejmSlider ({ incrementStep: 1 });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set the slider incrementStep, after initialization:<br>
            * // Get the incrementStep API value.		
            *  $("#slider").ejmSlider ("option", "incrementStep");			
            * // Set the incrementStep API
            * $("#slider").ejmSlider ("option", "incrementStep", 1);      
            * &lt;/script&gt;
            * @memberof ejmSlider
            * @instance
            */
            incrementStep: 1,
            /**		
            * Specifies the current value.
            * @default 0
            * @type {int}
            * @example 
            * //Set the value property in unobtrusive way.
            * &lt;div id="slider" data-role="ejmslider" data-ej-value=0 &gt;&lt;/div&gt;<br>
            * @example 
            * // Set slider value on initialization. 
            * //To set value API value 
            * &lt;div id="slider" &gt;&lt;/div&gt;
            * &lt;script&gt;
            * $("#slider").ejmSlider ({ value: 50 });	
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set the slider value, after initialization:<br>
            * // Get the value API value.		
            *  $("#slider").ejmSlider ("option", "value");			
            * // Set the value API
            * $("#slider").ejmSlider ("option", "value", 0);         
            * &lt;/script&gt;
            * @memberof ejmSlider
            * @instance
            */
            value: 0,
            /**		
            * Specifies whether to enable or disable the control.
            * @default true
            * @type {bool}
            * @example 
            * //Set the enabled property in unobtrusive way.
            * &lt;div id="slider" data-role="ejmslider" data-ej-enabled=true &gt;&lt;/div&gt;<br>
            * @example 
            * // Set slider enabled on initialization. 
            * //To set enabled API value 
            * &lt;div id="slider" &gt;&lt;/div&gt;
            * &lt;script&gt;
            * $("#slider").ejmSlider ({ enabled: false });	
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set the slider enabled, after initialization:<br>
            * // Get the enabled API value.		
            *  $("#slider").ejmSlider ("option", "enabled");			
            * // Set the enabled API
            * $("#slider").ejmSlider ("option", "enabled", true); 
            * &lt;/script&gt;
            * @memberof ejmSlider
            * @instance
            */
            enabled: true,
            /**		
            * Specifies to maintain the current model value to browser cookies for state maintenance. While refresh the page, the model value will get apply to the control from browser cookies.
            * @default false
            * @type {bool}
            * @example 
            * //Set the enablePersistence property in unobtrusive way.
            * &lt;div id="slider" data-role="ejmslider" data-ej-enablePersistence=false &gt;&lt;/div&gt;<br>
            * @example 
            * // Set slider enablePersistence on initialization. 
            * //To set persist API value 
            * &lt;div id="slider" &gt;&lt;/div&gt;
            * &lt;script&gt;
            * $("#slider").ejmSlider ({ enablePersistence: false });	
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set the slider enablePersistence, after initialization:<br>
            * // Get the enablePersistence API value.		
            *  $("#slider").ejmSlider ("option", "enablePersistence");			
            * // Set the enablePersistence API
            * $("#slider").ejmSlider ("option", "enablePersistence", false);  
            * &lt;/script&gt;
            * @memberof ejmSlider
            * @instance
            */
            enablePersistence: false,
            /**    
            * Event triggers when touch start happens on the control.
            * @event
            * @name ejmSlider#touchStart 
            * @param {Object} argument Event parameters from slider.     	  
            * @param {boolean}  argument.cancel if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @param {int} argument.value returns the current value of the control.
            * @example 
            * &lt;div id="slider" data-role="ejmslider" data-ej-touchStart="onStart"&gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // touchStart event for slider  
            * function onStart(args){ //handle the event
            * }
            * &lt;/script&gt;
            * @example 
            * &lt;div id="slider" &gt;&lt;/div&gt;
            * &lt;script&gt;
            * //touchStart event for slider
            * $("#slider").ejmSlider({
            *   touchStart: function (args) { //handle the event 
            * }
            * });  
            * &lt;/script&gt;
            * @memberof ejmSlider
            * @instance
            */
            touchStart: null,
            /**    
            * Event triggers when touch end happens on the control.
            * @event
            * @name ejmSlider#touchEnd
            * @param {Object} argument Event parameters from slider.
            * @param {boolean}  argument.cancel if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @param {int} argument.value returns the current value of the control.
            * @example 
            * &lt;div id="slider" data-role="ejmslider" data-ej-touchEnd="onStop"&gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // touchEnd event for slider  
            * function onStop(args){ //handle the event
            * }
            * &lt;/script&gt;
            * @example 
            * &lt;div id="slider" &gt;&lt;/div&gt;
            * &lt;script&gt;
            * //touchEnd event for slider
            * $("#slider").ejmSlider({
            *   touchEnd: function (args) { //handle the event 
            * }
            * });           
            * &lt;/script&gt;
            * @memberof ejmSlider
            * @instance
            */
            touchEnd: null,
            /**    
            * Event triggers when the value changed.
            * @event
            * @name ejmSlider#change 	
            * @param {Object} argument Event parameters from slider.
            * @param {boolean}  argument.cancel if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @param {int} argument.value returns the current value of the control.
            * @example 
            * &lt;div id="slider" data-role="ejmslider" data-ej-change="onChange"&gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // Change event for slider  
            * function onChange(args){ //handle the event
            * }
            * &lt;/script&gt;
            * @example 
            * &lt;div id="slider" &gt;&lt;/div&gt;
            * &lt;script&gt;
            * //change event for slider
            * $("#slider").ejmSlider({
            *   change: function (args) { //handle the event 
            * }
            * });        
            * &lt;/script&gt;
            * @memberof ejmSlider
            * @instance
            */
            change: null,
            /**    
            * Event triggers when touch move happens on the control.
            * @event
            * @name ejmSlider#slide 	    
            * @param {Object} argument Event parameters from slider.
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @param {int} argument.value returns the current value of the control.
            * @param {int[]} argument.values returns the current range values of the control when range slider feature is enabled.
            * @example 
            * &lt;div id="slider" data-role="ejmslider" data-ej-slide="onslide"&gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // slide event for slider  
            * function onslide(args){ //handle the event
            * }
            * &lt;/script&gt;
            * @example 
            * &lt;div id="slider" &gt;&lt;/div&gt;
            * &lt;script&gt;
            * //Slide event for slider
            * $("#slider").ejmSlider({
            *   slide: function (args) { //handle the event 
            * }
            * });   
            * &lt;/script&gt;
            * @memberof ejmSlider
            * @instance
            */
            slide: null,
            /**    
            * Event triggers before the control get loaded.
            * @event
            * @name ejmSlider#load 	   
            * @param {Object} argument Event parameters from slider.
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @param {int} argument.value returns the current value of the control.
            * @param {int[]} argument.values returns the current range values of the control when range slider feature is enabled.
            * @example 
            * &lt;div id="slider" data-role="ejmslider" data-ej-load="onLoad" &gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // Load event for slider  
            * function onLoad(args){ //handle the event
            * }
            * &lt;/script&gt;
            * @example 
            * &lt;div id="slider" &gt;&lt;/div&gt;
            * &lt;script&gt;
            * //Load event for slider
            * $("#slider").ejmSlider({
            *   load: function (args) { //handle the event 
            * }
            * });    
            * &lt;/script&gt;
            * @memberof ejmSlider
            * @instance
            */
            load: null,
            /**     
            * Section for windows mode specific functionalities.                      
            * @memberof ejmSlider
            * @instance
            */
            windows: {
                /**  
                * Specifies whether to render control based on the windowsphone's current accent color and device theme.
                * @default false
                * @type {boolean}
                * @alias ejmSlider#windows->renderDefault
                * @example 
                * // Set the windows mode renderDefault property in unobtrusive way.
                * &lt;div id="slider" data-role="ejmslider" data-ej-rendermode="windows" data-ej-windows-renderDefault=false &gt;&lt;/div&gt;<br>
                * @example 
                * &lt;div id="slider" &gt;&lt;/div&gt;
                * &lt;script&gt;
                * // To set windows mode renderDefault property API value 
                * $("#slider").ejmSlider({ renderMode:"windows", windows:{renderDefault: false}});   
                * &lt;/script&gt;
                * @example 
                * &lt;script&gt; 
                * // Get or set the windows mode renderDefault API, after initialization:
                * // Get the windows mode renderDefault value  
                * $("#slider").ejmSlider("option", "windows.renderDefault");   
                * // Set the windows mode renderDefault value 
                * $("#slider").ejmSlider("option", "windows.renderDefault", false); 
                * &lt;/script&gt; 
                * @memberof ejmSlider
                * @instance
                */
                "renderDefault": false
            },
            /**     
            * Section for ios7 mode specific functionalities.                      
            * @memberof ejmSlider
            * @instance
            */
            ios7: {
                /**  
                * Specifies the thumb style in ios7 mode. See {@link ThumbStyle}
                * @default ej.mobile.slider.ThumbStyle.Normal. 
                * @type {enum}
                * @alias ejmSlider#ios7->thumbStyle
                * @example 
                * // Set the ios7 mode thumbStyle property in unobtrusive way.
                * &lt;div id="slider" data-role="ejmslider" data-ej-rendermode="ios7" data-ej-ios7-thumbstyle="normal" &gt;&lt;/div&gt;<br>
                * @example 
                * // To set ios7 mode thumbStyle property API value 
                * &lt;div id="slider" &gt;&lt;/div&gt;
                * &lt;script&gt;
                * $("#slider").ejmSlider({renderMode:"ios7", ios7:{thumbStyle: ej.mobile.slider.ThumbStyle.Small}});   
                * &lt;/script&gt;
                * @example 
                * &lt;script&gt; 
                * // Get or set the ios7 mode thumbStyle API, after initialization:
                * // Get the ios7 mode thumb style value  
                * $("#slider").ejmSlider("option", "ios7.thumbStyle");   
                * // Set the ios7 mode thumbStyle value 
                * $("#slider").ejmSlider("option", "ios7.thumbStyle", ej.mobile.slider.ThumbStyle.Normal); 
                * &lt;/script&gt; 
                * @memberof ejmSlider
                * @instance
                */
                "thumbStyle": "normal"
            },
            /**		
            * Specifies the rendering mode of the control. See {@link RenderMode}
            * @default auto 
            * @type {enum}
            * @example 
            * //Set the renderMode property in unobtrusive way.
            * &lt;div id="slider" data-role="ejmslider" data-ej-rendermode="auto" &gt;&lt;/div&gt;<br>
            * @example 
            * // Set slider rendermode on initialization. 
            * //To set renderMode API value 
            * &lt;div id="slider" &gt;&lt;/div&gt;
            * &lt;script&gt;
            * $(function(){
            * $("#slider").ejmSlider ({ renderMode: ej.mobile.RenderMode.Android });	
            * });
            * &lt;/script&gt;
            * @example
            * &lt;script&gt; 
            * //Get or set the slider rendermode, after initialization:<br>
            * // Get the renderMode API value.		
            *  $("#slider").ejmSlider ("option", "renderMode");			
            * // Set the renderMode API
            * $("#slider").ejmSlider ("option", "renderMode", ej.mobile.RenderMode.Android);      
            * &lt;/script&gt; 
            * @memberof ejmSlider
            * @instance
            */
            renderMode: "auto"
        },
        dataTypes: {
            theme: "enum",
            orientation: "enum",
            enableRange: "boolean",
            thumbStyle: "enum",
            enableAnimation: "boolean",
            enabled: "boolean",
            renderMode: "enum",
            values: "array",
            enablePersistence: "boolean"
        },
        observables: ["value"],
        observableArray: ["values"],
        value: ej.util.valueFunction("value"),
        values: ej.util.valueFunction("values"),
        // constructor function
        _init: function () {
            this._cloneElement = this.element.clone();
            this._load();
            ej.setRenderMode(this);
            ej.setTheme(this);
            this._renderControl();
            this._initObjects();
            if (!this.model.readOnly)
                this._wireEvents(false);
        },
        _renderControl: function () {
            var obj = this.model;
            if (!this.model.enabled)
                this.element.addClass("e-m-state-disabled");
            if (this.model.renderMode == "windows" && this.model.windows.renderDefault)
                this.model.theme = "default";
            this._sliderHandle = ej.buildTag("div .e-m-slider-outer");
            this._selectedRegion = ej.buildTag("div .e-m-slider-inner").appendTo(this._sliderHandle);
            if (this.model.renderMode == "ios7" && this.model.ios7.thumbStyle == "small")
                this._dragHandle = ej.buildTag("div .e-m-slider-handleout e-m-small-handle e-m-slider-left ").appendTo(this._sliderHandle);
            else
                this._dragHandle = ej.buildTag("div .e-m-slider-handleout e-m-slider-left ").appendTo(this._sliderHandle);
            var handleIn = ej.buildTag("div .e-m-slider-handlein").appendTo(this._dragHandle);
            if (obj.enableRange) {
                if (this.model.renderMode == "ios7" && this.model.ios7.thumbStyle == "small")
                    var handleRange = ej.buildTag("div .e-m-slider-handleout e-m-small-handle e-m-slider-right");
                else
                    var handleRange = ej.buildTag("div .e-m-slider-handleout e-m-slider-right");
                var rangeHandleIn = ej.buildTag("div .e-m-slider-handlein").appendTo(handleRange);
                handleRange.appendTo(this._sliderHandle);
            }
            this.element.addClass("e-m-" + obj.orientation + " e-m-" + obj.theme).addClass("e-m-slider e-m-" + obj.renderMode).append(this._sliderHandle);
            this.element.append(ej.buildTag("input ", {}, {}, { "type": "hidden", "name": "sliderValue" }));
            this._dragHandle = this.element.find(".e-m-slider-handleout");
            this._inputValue = this.element.find("input");
            this._wrapperDiv = this.element;
            this._currentValue = this.value();
            this["_" + obj.orientation + "RenderMode"]();
        },
        _horizontalRenderMode: function () {
            this._setOrientationProperties("width", "left");
        },
        _verticalRenderMode: function () {
            this._setOrientationProperties("height", "bottom");
        },
        _setOrientationProperties: function (dimensionProp, posProp) {
            var obj = this.model;
            if (obj.enableRange) {
                if (this.values()[0] <= this.values()[1]) {
                    this.values()[0] = (this.values()[0] < obj.minValue && this.values()[0] <= obj.maxValue) ? obj.minValue : this.values()[0];
                    this.values()[1] = (this.values()[1] >= obj.minValue && this.values()[1] > obj.maxValue) ? obj.maxValue : this.values()[1];
                }
                else
                    this.values()[1] = this.values()[0];
                this._selectedRegion.css(posProp, parseFloat(((this.values()[0] - obj.minValue) / (obj.maxValue - obj.minValue)) * 100) + "%").css(dimensionProp,
                    parseFloat(((this.values()[1] - obj.minValue) / (obj.maxValue - obj.minValue)) * 100) - parseFloat(((this.values()[0] - obj.minValue) / (obj.maxValue - obj.minValue)) * 100) + "%");
                $(this._dragHandle[0]).css(posProp, parseFloat(((this.values()[0] - obj.minValue) / (obj.maxValue - obj.minValue)) * 100) + "%");
                $(this._dragHandle[1]).css(posProp, parseFloat(((this.values()[1] - obj.minValue) / (obj.maxValue - obj.minValue)) * 100) + "%");
            }
            else {
                this.value((this.value() < obj.minValue) ? obj.minValue : this.value());
                this.value((this.value() > obj.maxValue) ? obj.maxValue : this.value());
                this._selectedRegion.css(dimensionProp, parseFloat(((this.value() - obj.minValue) / (obj.maxValue - obj.minValue)) * 100) + "%");
                this._dragHandle.css(posProp, parseFloat(((this.value() - obj.minValue) / (obj.maxValue - obj.minValue)) * 100) + "%");
            }
        },
        _initObjects: function () {
            this._createDelegates();
        },
        _createDelegates: function () {
            this._mouseDownHandler = $.proxy(this._onMouseDownHandler, this);
            this._mouseMoveHandler = $.proxy(this._onMouseMove, this);
            this._mouseUpHandler = $.proxy(this._onMouseUp, this);
            this._destroyHandler = $.proxy(this._destroy, this);
        },
        _onMouseDownHandler: function (evt) {
            ej.blockDefaultActions(evt);
            if(ej.isTouchDevice())
                evt = evt.touches ? evt.touches[0] : evt;
            if (!this.model.enabled)
                return false;
            jQuery.fx.off = false;
            this.sliderClick = evt;
            if (!this.model.enableRange)
                this._dragHandle.addClass("e-m-state-active");
            ej.listenEvents([document, document], [ej.moveEvent(), ej.endEvent()], [this._mouseMoveHandler, this._mouseUpHandler], false);
            var index;
            var position = { x: evt.pageX, y: evt.pageY };
            var normalValue = this._getNormalValue(position);
            this._currentValue = normalValue;
            var self = this;
            var distance = this.model.maxValue - this.model.minValue + 1;
            $(this._dragHandle).each(function (curIndex) {
                var curDistance = Math.abs(normalValue - self._getNewValues(curIndex));
                if (distance >= curDistance) {
                    if (self._getNewValues(0) != self._getNewValues(1)) {
                        distance = curDistance;
                        self._closestHandle = $(this);
                        index = curIndex;
                    }
                }
            });
            $(this.model.enableRange ? this._closestHandle : this._dragHandle).removeClass("e-m-state-hover").addClass("e-m-state-active");
            this._start(evt, index);
            if (this.model.enableRange) {
                this._setZindex();
                if (self._getNewValues(0) == self._getNewValues(1)) {
                    self._closestHandle = $(this);
                    index = this._handlingIndex;
                }
                this._setRangeValueProperties(evt, index);
            }
        },
        _setZindex: function () {
            this._dragHandle.css("z-index", 0);
            this._closestHandle.css("z-index", 5);
        },
        _setRangeValueProperties: function (evt, index) {
            var tempValues = [];
            var otherValues = [];
            var highestValue, lowestValue;
            var tempValue = this.values()[index];
            this._closestHandle = $(this._dragHandle[index]);
            this._handlingIndex = index;
            for (var curValue = 0; curValue < this.values().length; curValue++) {
                if (curValue != index)
                    otherValues.push(this.values()[curValue]);
                tempValues.push(this.values()[curValue]);
            }
            for (var curValue = 0; curValue < otherValues.length; curValue++) {
                if (tempValue >= otherValues[curValue]) {
                    this._closestLeftValue = otherValues[curValue];
                    break;
                }
                else if (tempValue <= otherValues[curValue]) {
                    this._closestRightValue = otherValues[curValue];
                    break;
                }
            }
            lowestValue = tempValues[0];
            highestValue = tempValues[tempValues.length - 1];
            if (lowestValue != highestValue) {
                if (tempValue <= lowestValue)
                    this._closestLeftValue = this.model.minValue;
                else if (tempValue >= highestValue)
                    this._closestRightValue = this.model.maxValue;
            }
            else if (lowestValue == highestValue) {
                if (this._closestHandle.hasClass("e-m-slider-left"))
                    this._closestLeftValue = this.model.minValue;
                else if (this._closestHandle.hasClass("e-m-slider-right"))
                    this._closestRightValue = this.model.maxValue;
            }
            if (evt.preventDefault)
                evt.preventDefault();
            return true;
        },
        _onMouseMove: function (evt, bAnimate) {
            ej.blockDefaultActions(evt);
            if (ej.isTouchDevice())
                evt = evt.touches ? evt.touches[0] : evt;
            if (!this.model.enabled)
                return false;
            jQuery.fx.off = true;
            this.element.css("cursor", "pointer");
            var position = { x: evt.pageX, y: evt.pageY };
            var normalValue = this._getNormalValue(position);
            this._currentValue = normalValue;
            if (this.model.enableRange)
                this._slide(evt, normalValue, this._handlingIndex);
            else
                this._slide(evt, normalValue);
            $(this.model.enableRange ? this._closestHandle : this._dragHandle).addClass("e-m-state-active");
            if (evt.preventDefault)
                evt.preventDefault();
        },
        _onMouseUp: function (evt) {
            ej.blockDefaultActions(evt);
            if (ej.isTouchDevice())
                evt = evt.changedTouches ? evt.changedTouches[0] : evt;
            if (!this.model.enabled)
                return false;
            jQuery.fx.off = false;
            ej.listenEvents([document, document], [ej.moveEvent(), ej.endEvent()], [this._mouseMoveHandler, this._mouseUpHandler], true);
            if (this._mouseMoveStarted) {
                this._mouseMoveStarted = false;
                if (evt.target == this.sliderClick.target)
                    $.data(evt.target, this.model.sliderId + '.preventClickEvent', true);
            }
            this.element.css("cursor", "default");
            var position = { x: evt.pageX, y: evt.pageY };
            var normalValue = this._getNormalValue(position);
            if (this.model.enableRange)
                this._slide(evt, normalValue, this._handlingIndex);
            else
                this._slide(evt, normalValue);
            this._stop(evt, this._handlingIndex);
            this._change(evt, this._handlingIndex);
            $(this.model.enableRange ? this._closestHandle : this._dragHandle).removeClass("e-m-state-hover").removeClass("e-m-state-active");
            return false;
        },
        _getNewValues: function (index) {
            if (!this.model.enableRange)
                return this.value();
            else
                return this._trimValue(this.values()[index]);
        },
        _getCurrentValue: function (newValue, index) {
            if (this.model.enableRange) {
                this.values()[index] = this._trimValue(newValue);
                this.value(this.values()[index]);
            }
            else {
                this.value(this._trimValue(newValue));
                this._currentValue = newValue;
            }
            this._refreshValue();
            return this._trimValue(this.value());
        },
        _refreshValue: function () {
            var animateOrCss = this.model.enableAnimation ? "animate" : "css";
            var values;
            if (this.model.enableRange) {
                values = (this.values()[0] + "," + this.values()[1]);
                this._inputValue.val(values);
            }
            else
                this._inputValue.val(this._currentValue);
            correctedPercent = (this._dragHandle.width() / 2) / this._dragHandle.parent().width() * 100;
            if ((this.model.enableRange))
                this._rangeRefreshProperties();
            else {
                var percentValue = (this.model.minValue != this.model.maxValue) ? (this.value() - this.model.minValue) / (this.model.maxValue - this.model.minValue) * 100 : 0;
                var handlePercent = percentValue - ((this._dragHandle.width() / $(this._dragHandle.parent()).width()) * 100);
                if (handlePercent < 0)
                    handlePercent = percentValue;
                if (this.model.orientation == "horizontal")
                    this._rangeRefreshOrientationProperties({ 'width': percentValue + "%" }, { 'left': percentValue + "%" }, this.model.animationSpeed, animateOrCss);
                else
                    this._rangeRefreshOrientationProperties({ 'height': percentValue + "%" }, { 'bottom': percentValue + "%" }, this.model.animationSpeed, animateOrCss);
            }
        },
        _rangeRefreshProperties: function () {
            var left, width, bottom, left;
            var self = this;
            var animateOrCss = this.model.enableAnimation ? "animate" : "css";
            var animateValue = this.model.animationSpeed;
            var maxPercentValue = (this.values()[1] - this.model.minValue) / (this.model.maxValue - this.model.minValue) * 100;
            var minPercentValue = (this.values()[0] - this.model.minValue) / (this.model.maxValue - this.model.minValue) * 100;
            if (this.model.orientation == "horizontal") {
                this._selectedRegion[animateOrCss]({ "left": (minPercentValue) + "%" }, animateValue)
                [animateOrCss]({ "width": (maxPercentValue - minPercentValue) + "%" }, animateValue);
            }
            else {
                this._selectedRegion[animateOrCss]({ "bottom": (minPercentValue) + "%" }, animateValue)
                    [animateOrCss]({ "height": (maxPercentValue - minPercentValue) + "%" }, animateValue);
            }
            this._dragHandle.each(function (index, element) {
                percentValue = (self.values()[index] - self.model.minValue) / (self.model.maxValue - self.model.minValue) * 100;
                handlePercent = percentValue - (($(this).width() / $($(this).parent()).width()) * 100);
                if (handlePercent < 0)
                    handlePercent = percentValue;
                if (self.model.orientation == "horizontal")
                    $(this)[animateOrCss]({ "left": percentValue + "%" }, animateValue);
                else
                    $(this)[animateOrCss]({ "bottom": percentValue + "%" }, animateValue);
                lastPercentValue = percentValue;
            });
        },
        _rangeRefreshOrientationProperties: function (dimObj, posObj, animateValue, animateOrCss) {
            this._selectedRegion[animateOrCss](dimObj, animateValue);
            this._dragHandle[animateOrCss](posObj, animateValue);
        },

        _getNormalValue: function (position) {
            var currentLOB, currentLOBPercent, totalValue, currentValue; //currentLOB = current left or bottom
            if (this.model.orientation == "vertical") {
                currentLOB = position.y - this._sliderHandle.offset().top;
                currentLOBPercent = (currentLOB / this._sliderHandle[0].offsetHeight);
            }
            else {
                currentLOB = position.x - this._sliderHandle.offset().left;
                currentLOBPercent = (currentLOB / this._sliderHandle[0].offsetWidth);
            }

            if (this.model.orientation == "vertical")
                currentLOBPercent = 1 - currentLOBPercent;
            totalValue = this.model.maxValue - this.model.minValue;
            currentValue = this.model.minValue + currentLOBPercent * totalValue;
            return this._trimValue(currentValue);
        },
        _trimValue: function (value) {
            if (!this.model.enableRange) {
                if (value < this.model.minValue)
                    value = this.model.minValue;
                else if (value > this.model.maxValue)
                    value = this.model.maxValue;
            }
            var step = (this.model.incrementStep > 0) ? this.model.incrementStep : 1;
            var stepModValue = (value - this.model.minValue) % step;
            var correctedValue = value - stepModValue;
            if (Math.abs(stepModValue) * 2 >= step)
                correctedValue += (stepModValue > 0) ? step : (-step);
            return parseFloat(correctedValue.toFixed(5));
        },
        _slide: function (evt, newValue, index) {
            if (this.model.enableRange) {
                if (newValue != this._getCurrentValue()) {
                    this.value(newValue);
                    if (newValue < this._closestLeftValue)
                        newValue = this._closestLeftValue;
                    else if (newValue > this._closestRightValue)
                        newValue = this._closestRightValue;
                    if (newValue != this._getNewValues(index)) {
                        var newValues = this._getCurrentValue(newValue, index);
                        newValues[index] = newValue;
                        var data = { value: this.value(), values: this.values() };
                        this.values([this.values()[0], this.values()[1]]);
                        this._triggerSlide(data, newValue, this._getNewValues(index), index);
                    }
                }
            }
            else {

                if (newValue != this.value()) {
                    this._getCurrentValue(newValue);
                    var data = { value: this.value(), values: this.values() };
                    this._triggerSlide(data, newValue, this.value());
                }
            }

        },
        _triggerSlide: function (data, newValue, prevValue, index) {
            if (this.model.slide)
                this._trigger("slide", data);
            this._getCurrentValue(newValue, index);
            this.prevValue = this._getNewValues(index);
        },
        //client side events
        _load: function () {
            var data = (this.model.enableRange) ? { values: this._getNewValues()} : { value: this.value() };
            if (this.model.load)
                this._trigger("load", data);
        },

        _start: function (evt, index) {
            var data = { value: this.value(), values: this.values() };
            if (this.model.enableRange) {
                data._getCurrentValue = this._getNewValues(index);
                data.values = this._getNewValues();
            }
            else {
                data._getCurrentValue = this.value();
                data.value = this.value();

            }
            if (this.model.touchStart)
                this._trigger("touchStart", data);
        },
        _stop: function (evt, index) {
            var data = { value: this.value(), values: this.values() };
            if (this.model.enableRange) {
                data._getCurrentValue = this._getNewValues(index);
                data.values = this._getNewValues();
            }
            else {
                data._getCurrentValue = this.value();
                data.value = this.value();
            }
            if (this.model.touchEnd)
                this._trigger("touchEnd", data);
        },
        _change: function (evt, index) {
            var data = { value: this.value(), values: this.values() };
            if (this.model.enableRange) {
                data._getCurrentValue = this._getNewValues(index);
                data.values = this._getNewValues();
            }
            else {
                data._getCurrentValue = this.value();
                data.value = this.value();

            }
            if (this.model.change)
                this._trigger("change", data);
        },
        _wireEvents: function (remove) {
            ej.listenEvents([this._sliderHandle, this.element, $(window)], [ej.startEvent(), ej.startEvent(), "unload"], [this._mouseDownHandler, this._mouseDownHandler, this._destroyHandler], remove);
        },
        /**
        * To configure the renderMode of the slider		
        * @private
        */
        _setRenderMode: function (mode) {
            if (this.model.enabled) {
                this.model.renderMode = mode;
                if (mode == "auto")
                    ej.setRenderMode(this);
                this.element.removeClass("e-m-ios7 e-m-android e-m-windows e-m-flat").addClass("e-m-" + this.model.renderMode);
            }
        },
        /**
        * To configure the theme of the slider		
        * @private
        */
        _setTheme: function (theme) {
            if (this.model.enabled) {
                this.model.theme = theme;
                this.element.removeClass("e-m-dark e-m-light").addClass("e-m-" + theme);
            }
        },
        /**
        * To configure the value of the slider		
        * @private
        */
        _validateValue: function (value) {
            if (this.model.enabled) {
                if (!this.model.enableRange)
                    this["_" + this.model.orientation + "RenderMode"]();
            }
        },
        /**
        * To configure the values of the Range slider		
        * @private
        */
        _validateRangeValue: function (rangeValue) {
            this["_" + this.model.orientation + "RenderMode"]();
            if (this.values()[0] == this.values()[1]) {
                (this.model.maxValue == this.values()[1]) ? this._setRangeValueProperties("", 0) : this._setRangeValueProperties("", 1);
            }
        },
        /**
        * To configure whether the slider is disabled or not		
        * @private
        */
        _disable: function () {
            this.model.enabled = false;
            this.element.addClass("e-m-state-disabled");
            this._wireEvents(true);
        },
        /**
        * To configure whether the slider is disabled or not		
        * @private
        */
        _enable: function () {
            this.model.enabled = true;
            this.element.removeClass("e-m-state-disabled");
            this._wireEvents();
        },
        /**
        * To configure the animate property of the slider		
        * @private
        */
        _enableAnimation: function (isAnimate) {
            if (this.model.enabled)
                this.model.enableAnimation = isAnimate;
        },
        /**
        * To configure the refresh property of the slider		
        * @private
        */
        _refresh: function () {
            if (this.model.enabled) {
                this._clearElements();
                this._renderControl();
                this._wireEvents(false);
            }
        },
        _setModel: function (options) {
            var refresh = false;
            for (var prop in options) {
                switch (prop) {
                    case "renderMode": this._setRenderMode(options.renderMode); break;
                    case "theme": this._setTheme(options.theme); break;
                    case "orientation": this._refresh(); break;
                    case "value": this._validateValue(options.value); break;
                    case "values": if (this.model.enableRange && this.model.enabled)
                            this._validateRangeValue(options.values);
                        break;
                    case "enabled": (options.enabled) ? this._enable() : this._disable(); break;
                    case "enableRange": this._refresh(); break;
                    case "minValue": this.model.minValue = options.minValue; break;
                    case "maxValue": this.model.maxValue = options.maxValue; break;
                    case "enableAnimation": this._enableAnimation(options.enableAnimation); break;
                    case "readOnly": (options.readOnly) ? this._wireEvents(true) : this._wireEvents(false); break;
                }
            }
        },
        // all events bound using this._on will be unbind automatically
        _destroy: function () {
            this._cloneElement.insertBefore(this.element);
            this.element.remove();
        },
        _clearElements: function () {
            this._wireEvents(true);
            this.element.removeAttr("class");
            this.element.removeAttr("style");
            this.element.html("");
        },

        /*---------------Public Methods---------------*/

        /**
        * To get the current value.
        * @return jQuery
        * @example 
        * &lt;div id="slider" data-role="ejmslider" &gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * // Create slider
        * $(function(){
        * var slider = $("#slider").data("ejmSlider");
        * slider.getValue(); // returns the slider's current value
        * });
        * &lt;/script&gt;
        * @example 
        * &lt;div id="slider"&gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * // get the slider's current value
        * $("#slider").ejmSlider();	
        * $(function(){
        * $("#slider").ejmSlider("getValue");	
        * });
        * &lt;/script&gt;
        *@memberof ejmSlider
        * @instance
        */
        getValue: function () {
            if (this.model.enableRange)
                return (this.values()[0] + "," + this.values()[1]);
            else
                return this._trimValue(this.value());
        },
        //client side methods
        dispose: function () {
            return this._destroy();
        }
        /*---------------Public Methods End---------------*/

    });
    /**
    * Enum for slider
    * @enum {string}
    * @global
    */
    ej.mobile.slider.Orientation = {
        /**
        Enum for horizontal mode slider*/
        Horizontal: "horizontal",
        /**
        Enum for vertical mode slider*/
        Vertical: "vertical"
    }
    /**
    * Enum for slider
    * @enum {string}
    * @global
    */
    ej.mobile.slider.ThumbStyle = {
        /**
        Enum for normal mode thumb style slider*/
        Normal: "normal",
        /**
        Enum for small mode thumb style slider*/
        Small: "small"
    }
})(jQuery, Syncfusion);