﻿/**
* @fileOverview Plugin to style the Html SplitPane elements
* @copyright Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/
(function ($, ej, undefined) {
    // mSplitPane is the plugin name 
    // "m.SplitPane" is "namespace.className" will hold functions and properties
    /**
    * @namespace ej
    * @class ejmSplitPane
    * @requires jQuery
    * @requires ej.mobile.application
    * @requires ej.core
    * @requires ej.unobtrusive
    * @requires ej.mobile.core
    * @requires ej.data
    * @requires ej.touch    
    * @requires ej.mobile.scrollbar
    * @requires ej.mobile.scrollpanel
    * @requires ej.mobile.toolbar
    * @requires ej.mobile.menu
    * @requires ej.mobile.header
    * @classdesc Custom Design for Html SplitPane control.
    * @example
    * // Create SplitPane in unobtrusive way
    * &lt;div id="splitview" data-role="ejmsplitpane" &gt;
    *   &lt;div data-ej-layout="pane"&gt;
    *    &lt;div&gt;
    *    &lt;/div&gt;
    *   &lt;/div&gt;
    *   &lt;div data-ej-layout="pane"&gt;
    *   &lt;/div&gt;
    * &lt;/div&gt;
    * @example
    * &lt;div id="splitview"&gt;
    *   &lt;div data-ej-layout="pane"&gt;
    *     &lt;div&gt;
    *     &lt;/div&gt;
    *   &lt;/div&gt;
    *   &lt;div data-ej-layout="pane"&gt;
    *   &lt;/div&gt;
    * &lt;/div&gt;
    * &lt;script&gt; 
    * // Create SplitPane in obtrusive way
    * $(function(){
    * $("#splitview").ejmSplitPane(); 
    * });
    * &lt;/script&gt;
    */

    ej.widget("ejmSplitPane", "ej.mobile.SplitPane", {
        _setFirst: true,
        _rootCSS: "e-m-splitpane",
        // default model
        defaults: {
            /**		
            * Changes the rendering mode of the SplitPane. See {@link RenderMode}
            * @default auto
            * @type {enum}
            * @example 
            * //Set the renderMode property in Unobtrusive way.
            * &lt;div id="splitview" data-role="ejmsplitpane" data-ej-rendermode="auto"&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *     &lt;div&gt;
            *     &lt;/div&gt;
            *   &lt;/div&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *   &lt;/div&gt;
            * &lt;/div&gt;			
            * @example 
            * &lt;div id="splitview"&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *     &lt;div&gt;
            *     &lt;/div&gt;
            *   &lt;/div&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt; 
            * $(function(){
            * // Set SplitPane rendermode on initialization. 
            * //To set renderMode API value 
            * $("#splitview").ejmSplitPane({ renderMode: ej.mobile.RenderMode.Android });	
            * });
            * &lt;/script&gt; 
            * @example 
            * //Get or set the renderMode, after initialization:<br>
            * // Get the renderMode API value.		
            *  $("#splitview").ejmSplitPane("option", "renderMode");			
            * // Set the renderMode  API value
            * $("#splitview").ejmSplitpane("option", "renderMode", ej.mobile.RenderMode.Android);			
            * @memberof ejmSplitPane
            * @instance
            */
            renderMode: "auto",
            /**		
            * Changes the theme of the SplitPane. See {@link Theme}
            * @default auto
            * @type {enum}
            * @example 
            * //Set the theme property in Unobtrusive way.
            * &lt;div id="splitview" data-role="ejmsplitpane" data-ej-theme="auto"&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *     &lt;div&gt;
            *     &lt;/div&gt;
            *   &lt;/div&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * @example 
            * &lt;div id="splitview"&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *     &lt;div&gt;
            *     &lt;/div&gt;
            *   &lt;/div&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt; 
            * $(function(){
            * // Set the theme on initialization. 
            * //To set theme API value 
            * $("#splitview").ejmSplitPane({ theme: ej.mobile.Theme.Dark });	
            * });
            * &lt;/script&gt; 
            * @example 
            * //Get or set the theme, after initialization:<br>
            * // Get the theme API value.		
            *  $("#splitpane").ejmSplitPane("option", "theme");			
            * // Set the theme API value.
            * $("#splitview").ejmSplitPane("option", "theme", ej.mobile.Theme.Dark);			
            * @memberof ejmSplitPane
            * @instance
            */
            theme: "auto",
            /**		
            * Specifies whether to allow scrolling for leftpane content.
            * @default true
            * @type {boolean}
            * @example 
            * //Set the allowLeftPaneScrolling property in Unobtrusive way.
            * &lt;div id="splitview" data-role="ejmsplitpane" data-ej-allowleftpanescrolling=false&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *     &lt;div&gt;
            *     &lt;/div&gt;
            *   &lt;/div&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * @example 
            * &lt;div id="splitview"&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *     &lt;div&gt;
            *     &lt;/div&gt;
            *   &lt;/div&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt; 
            * $(function(){
            * // Set the allowLeftPaneScrolling on initialization. 
            * //To set allowLeftPaneScrolling API value 
            * $("#splitview").ejmSplitPane({ allowLeftPaneScrolling: false });	
            * });
            * &lt;/script&gt; 
            * @example 
            * //Get or set the allowLeftPaneScrolling, after initialization:<br>
            * // Get the allowLeftPaneScrolling API value.		
            *  $("#splitview").ejmSplitPane("option", "allowLeftPaneScrolling");			
            * // Set the allowLeftPaneScrolling API value.
            * $("#splitview").ejmSplitPane("option", "allowLeftPaneScrolling", false);			
            * @memberof ejmSplitPane
            * @instance
            */
            allowLeftPaneScrolling: true,
            /**		
            * Specifies whether to allow scrolling for rightpane content.
            * @default true
            * @type {boolean}
            * @example 
            * //Set the allowRightPaneScrolling property in Unobtrusive way.
            * &lt;div id="splitview" data-role="ejmsplitpane" data-ej-allowrightpanescrolling=false&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *     &lt;div&gt;
            *     &lt;/div&gt;
            *   &lt;/div&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * @example 
            * &lt;div id="splitview"&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *     &lt;div&gt;
            *     &lt;/div&gt;
            *   &lt;/div&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt; 
            * $(function(){
            * // Set the allowRightPaneScrolling on initialization. 
            * //To set allowRightPaneScrolling API value 
            * $("#splitview").ejmSplitPane({ allowRightPaneScrolling: false });	
            * });
            * &lt;/script&gt; 
            * @example 
            * //Get or set the allowRightPaneScrolling, after initialization:<br>
            * // Get the allowRightPaneScrolling API value.		
            *  $("#splitview").ejmSplitPane("option", "allowRightPaneScrolling");			
            * // Set the allowRightPaneScrolling API value.
            * $("#splitview").ejmSplitPane("option", "allowRightPaneScrolling", false);			
            * @memberof ejmSplitPane
            * @instance
            */
            allowRightPaneScrolling: true,
            /**     
            * Section for scroll panel specific functionalities appear to the left pane content
            * @default null
            * @type {Number}
            * @example 
            * //Set the leftPaneScrollSettings property in Unobtrusive way.
            * &lt;div id="splitview" data-role="ejmsplitpane" data-ej-leftpanescrollsettings-targetwidth=300&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *     &lt;div&gt;
            *     &lt;/div&gt;
            *   &lt;/div&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * @example 
            * &lt;div id="splitview"&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *     &lt;div&gt;
            *     &lt;/div&gt;
            *   &lt;/div&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt; 
            * // Set the leftPaneScrollSettings on initialization. 
            * //To set leftPaneScrollSettings API value 
            * $("#splitview").ejmSplitPane({ leftPaneScrollSettings.targetWidth: 300 });	
            * &lt;/script&gt; 
            * @example 
            * //Get or set the leftPaneScrollSettings, after initialization:<br>
            * // Get the leftPaneScrollSettings API value.		
            *  $("#splitview").ejmSplitPane("option", "leftPaneScrollSettings.targetWidth");			
            * // Set the leftPaneScrollSettings API value.
            * $("#splitview").ejmSplitPane("option", "leftPaneScrollSettings.targetWidth", 300);			
            * @memberof ejmSplitPane
            * @instance
            */
            leftPaneScrollSettings: {},
            /**     
            * Section for scroll panel specific functionalities appear to the right pane content.
            * @default null
            * @type {Number}
            * @example 
            * //Set the rightPaneScrollSettings property in Unobtrusive way.
            * &lt;div id="splitview" data-role="ejmsplitpane" data-ej-rightpanescrollsettings-targetwidth=300&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *     &lt;div&gt;
            *     &lt;/div&gt;
            *   &lt;/div&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * @example 
            * &lt;div id="splitview"&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *     &lt;div&gt;
            *     &lt;/div&gt;
            *   &lt;/div&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt; 
            * // Set the rightPaneScrollSettings on initialization. 
            * //To set rightPaneScrollSettings API value 
            * $("#splitview").ejmSplitPane({ rightPaneScrollSettings.targetWidth: 300 });	
            * &lt;/script&gt; 
            * @example 
            * //Get or set the rightPaneScrollSettings, after initialization:<br>
            * // Get the rightPaneScrollSettings API value.		
            *  $("#splitview").ejmSplitPane("option", "rightPaneScrollSettings.targetWidth");			
            * // Set the rightPaneScrollSettings API value.
            * $("#splitview").ejmSplitPane("option", "rightPaneScrollSettings.targetWidth", 300);			
            * @memberof ejmSplitPane
            * @instance
            */
            rightPaneScrollSettings: {},
            /**		
            * Saves current model value to browser cookies for state maintains. While refreshing the page retains the model value apply from browser cookies.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the enablePersistence property in Unobtrusive way.
            * &lt;div id="splitview" data-role="ejmsplitpane" data-ej-enablepersistence=true &gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *     &lt;div&gt;
            *     &lt;/div&gt;
            *   &lt;/div&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * @example 
            * &lt;div id="splitview"&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *     &lt;div&gt;
            *     &lt;/div&gt;
            *   &lt;/div&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt; 
            * // Set the enablePersistence on initialization. 
            * //To set enablePersistence API value 
            * $("#splitview").ejmSplitPane({ enablePersistence: true });	
            * &lt;/script&gt; 
            * @example 
            * //Get or set the enablePersistence, after initialization:<br>
            * // Get the enablePersistence API value.		
            *  $("#splitview").ejmSplitPane("option", "enablePersistence");			
            * // Set the enablePersistence API value.
            * $("#splitview").ejmSplitPane("option", "enablePersistence", true);			
            * @memberof ejmSplitPane
            * @instance
            */
            enablePersistence: false,
            /**     
            * Section for android rendermode specific functionalities.                      
            * @memberof ejmSplitPane
            * @instance
            */
            android:
            {
                /**		
                * Specifies whether to show the toolbar when the control is rendered in android mode.
                * @default true
                * @type {bool}
                * @alias ejmSplitPane#android->showToolbar
                * @example 
                * //Set the showToolbar property in Unobtrusive way.
                * &lt;div id="splitview" data-role="ejmsplitpane" data-ej-rendermode="android" data-ej-android-showtoolbar=false&gt;
                *   &lt;div data-ej-layout="pane"&gt;
                *     &lt;div&gt;
                *     &lt;/div&gt;
                *   &lt;/div&gt;
                *   &lt;div data-ej-layout="pane"&gt;
                *   &lt;/div&gt;
                * &lt;/div&gt;
                * @example 
                * &lt;div id="splitview"&gt;
                *   &lt;div data-ej-layout="pane"&gt;
                *     &lt;div&gt;
                *     &lt;/div&gt;
                *   &lt;/div&gt;
                *   &lt;div data-ej-layout="pane"&gt;
                *   &lt;/div&gt;
                * &lt;/div&gt;
                * &lt;script&gt; 
                * // Set the showToolbar on initialization. 
                * //To set showToolbar API value 
                * $(function(){
                * $("#splitview").ejmSplitPane({ android:{showToolbar: false} ,renderMode:"android"});	
                * });	
                * &lt;/script&gt; 
                * @example 
                * //Get or set the showToolbar, after initialization:<br>
                * // Get the showToolbar API value.		
                *  $("#splitview").ejmSplitPane("option", "android.showToolbar");			
                * // Set the showToolbar API value.
                * $("#splitview").ejmSplitPane("option", "android.showToolbar", false);			
                * @memberof ejmSplitPane
                * @instance
                */
                "showToolbar": true
            },
            /**     
            * Section for specifies toolbar functionalities when the control is rendered.
            * @default null
            * @type {String}
            * @example 
            * //Set the toolbarSettings property in Unobtrusive way.
            * &lt;div id="splitview" data-role="ejmsplitpane" data-ej-toolbarsettings-title="Title"&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *     &lt;div&gt;
            *     &lt;/div&gt;
            *   &lt;/div&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * @example 
            * &lt;div id="splitview"&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *     &lt;div&gt;
            *     &lt;/div&gt;
            *   &lt;/div&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt; 
            * // Set the toolbarSettings on initialization. 
            * //To set toolbarSettings API value 
            * $("#splitview").ejmSplitPane({ toolbarSettings.title: "Title" });	
            * &lt;/script&gt; 
            * @example 
            * //Get or set the toolbarSettings, after initialization:<br>
            * // Get the toolbarSettings API value.		
            *  $("#splitview").ejmSplitPane("option", "toolbarSettings.title");			
            * // Set the toolbarSettings API value.
            * $("#splitview").ejmSplitPane("option", "toolbarSettings.title","Title");			
            * @memberof ejmSplitPane
            * @instance
            */
            toolbarSettings: {},
            /**     
            * Section for windows rendermode specific functionalities.                      
            * @memberof ejmSplitPane
            * @instance
            */
            windows: {
                /**		
                * Specifies whether to show the left header .
                * @default true
                * @type {bool}
                * @alias ejmSplitPane#ios7->showLeftPaneHeader
                * @example 
                * //Set the showLeftPaneHeader property in Unobtrusive way.
                * &lt;div id="splitview" data-role="ejmsplitpane" data-ej-ios7-showleftpaneheader=false&gt;
                *   &lt;div data-ej-layout="pane"&gt;
                *     &lt;div&gt;
                *     &lt;/div&gt;
                *   &lt;/div&gt;
                *   &lt;div data-ej-layout="pane"&gt;
                *   &lt;/div&gt;
                * &lt;/div&gt;
                * @example 
                * &lt;div id="splitview"&gt;
                *   &lt;div data-ej-layout="pane"&gt;
                *     &lt;div&gt;
                *     &lt;/div&gt;
                *   &lt;/div&gt;
                *   &lt;div data-ej-layout="pane"&gt;
                *   &lt;/div&gt;
                * &lt;/div&gt;
                * &lt;script&gt; 
                * // Set the showLeftPaneHeader on initialization. 
                * //To set showLeftPaneHeader API value 
                * $(function(){
                * $("#splitview").ejmSplitPane({ ios7:{ showLeftPaneHeader: false } ,renderMode:"ios7"});	
                * });
                * &lt;/script&gt; 
                * @example 
                * //Get or set the showLeftPaneHeader, after initialization:<br>
                * // Get the showLeftPaneHeader API value.		
                *  $("#splitview").ejmSplitPane("option", "ios7.showLeftPaneHeader");			
                * // Set the showLeftPaneHeader API value.
                * $("#splitview").ejmSplitPane("option", "ios7.showLeftPaneHeader", false);			
                * @memberof ejmSplitPane
                * @instance
                */
                "showLeftPaneHeader": true,
                /**		
                * Specifies whether to show the right header .
                * @default true
                * @type {bool}
                * @alias ejmSplitPane#ios7->showRightPaneHeader
                * @example 
                * //Set the showRightPaneHeader property in Unobtrusive way.
                * &lt;div id="splitview" data-role="ejmsplitpane" data-ej-ios7-showrightpaneheader=false&gt;
                *   &lt;div data-ej-layout="pane"&gt;
                *     &lt;div&gt;
                *     &lt;/div&gt;
                *   &lt;/div&gt;
                *   &lt;div data-ej-layout="pane"&gt;
                *   &lt;/div&gt;
                * &lt;/div&gt;
                * @example 
                * &lt;div id="splitview"&gt;
                *   &lt;div data-ej-layout="pane"&gt;
                *     &lt;div&gt;
                *     &lt;/div&gt;
                *   &lt;/div&gt;
                *   &lt;div data-ej-layout="pane"&gt;
                *   &lt;/div&gt;
                * &lt;/div&gt;
                * &lt;script&gt; 
                * // Set the showRightPaneHeader on initialization. 
                * //To set showRightPaneHeader API value 
                * $(function(){
                * $("#splitview").ejmSplitPane({ ios7:{ showRightPaneHeader: false } ,renderMode:"ios7"});	
                * });
                * &lt;/script&gt; 
                * @example 
                * //Get or set the showRightPaneHeader, after initialization:<br>
                * // Get the showRightPaneHeader API value.		
                *  $("#splitview").ejmSplitPane("option", "ios7.showRightPaneHeader");			
                * // Set the showRightPaneHeader API value.
                * $("#splitview").ejmSplitPane("option", "ios7.showRightPaneHeader", false);			
                * @memberof ejmSplitPane
                * @instance
                */
                "showRightPaneHeader": true
            },
            /**     
            * Section for ios7 rendermode specific functionalities.                      
            * @memberof ejmSplitPane
            * @instance
            */
            ios7: {
                /**		
                * Specifies whether to show the left header .
                * @default true
                * @type {bool}
                * @alias ejmSplitPane#ios7->showLeftPaneHeader
                * @example 
                * //Set the showLeftPaneHeader property in Unobtrusive way.
                * &lt;div id="splitview" data-role="ejmsplitpane" data-ej-ios7-showleftpaneheader=false&gt;
                *   &lt;div data-ej-layout="pane"&gt;
                *     &lt;div&gt;
                *     &lt;/div&gt;
                *   &lt;/div&gt;
                *   &lt;div data-ej-layout="pane"&gt;
                *   &lt;/div&gt;
                * &lt;/div&gt;
                * @example 
                * &lt;div id="splitview"&gt;
                *   &lt;div data-ej-layout="pane"&gt;
                *     &lt;div&gt;
                *     &lt;/div&gt;
                *   &lt;/div&gt;
                *   &lt;div data-ej-layout="pane"&gt;
                *   &lt;/div&gt;
                * &lt;/div&gt;
                * &lt;script&gt; 
                * // Set the showLeftPaneHeader on initialization. 
                * //To set showLeftPaneHeader API value 
                * $(function(){
                * $("#splitview").ejmSplitPane({ ios7:{ showLeftPaneHeader: false } ,renderMode:"ios7"});	
                * });
                * &lt;/script&gt; 
                * @example 
                * //Get or set the showLeftPaneHeader, after initialization:<br>
                * // Get the showLeftPaneHeader API value.		
                *  $("#splitview").ejmSplitPane("option", "ios7.showLeftPaneHeader");			
                * // Set the showLeftPaneHeader API value.
                * $("#splitview").ejmSplitPane("option", "ios7.showLeftPaneHeader", false);			
                * @memberof ejmSplitPane
                * @instance
                */
                "showLeftPaneHeader": true,
                /**		
                * Specifies whether to show the right header .
                * @default true
                * @type {bool}
                * @alias ejmSplitPane#ios7->showRightPaneHeader
                * @example 
                * //Set the showRightPaneHeader property in Unobtrusive way.
                * &lt;div id="splitview" data-role="ejmsplitpane" data-ej-ios7-showrightpaneheader=false&gt;
                *   &lt;div data-ej-layout="pane"&gt;
                *     &lt;div&gt;
                *     &lt;/div&gt;
                *   &lt;/div&gt;
                *   &lt;div data-ej-layout="pane"&gt;
                *   &lt;/div&gt;
                * &lt;/div&gt;
                * @example 
                * &lt;div id="splitview"&gt;
                *   &lt;div data-ej-layout="pane"&gt;
                *     &lt;div&gt;
                *     &lt;/div&gt;
                *   &lt;/div&gt;
                *   &lt;div data-ej-layout="pane"&gt;
                *   &lt;/div&gt;
                * &lt;/div&gt;
                * &lt;script&gt; 
                * // Set the showRightPaneHeader on initialization. 
                * //To set showRightPaneHeader API value 
                * $(function(){
                * $("#splitview").ejmSplitPane({ ios7:{ showRightPaneHeader: false } ,renderMode:"ios7"});	
                * });
                * &lt;/script&gt; 
                * @example 
                * //Get or set the showRightPaneHeader, after initialization:<br>
                * // Get the showRightPaneHeader API value.		
                *  $("#splitview").ejmSplitPane("option", "ios7.showRightPaneHeader");			
                * // Set the showRightPaneHeader API value.
                * $("#splitview").ejmSplitPane("option", "ios7.showRightPaneHeader", false);			
                * @memberof ejmSplitPane
                * @instance
                */
                "showRightPaneHeader": true
            },
            /**     
            * Section for set the header functionalities to the left header of the Split Pane control.
            * @default null
            * @type {String}
            * @example 
            * //Set the leftHeaderSettings property in Unobtrusive way.
            * &lt;div id="splitview" data-role="ejmsplitpane" data-ej-leftheadersettings-title="Title"&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *     &lt;div&gt;
            *     &lt;/div&gt;
            *   &lt;/div&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * @example 
            * &lt;div id="splitview"&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *     &lt;div&gt;
            *     &lt;/div&gt;
            *   &lt;/div&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt; 
            * // Set the leftHeaderSettings on initialization. 
            * //To set leftHeaderSettings API value 
            * $("#splitview").ejmSplitPane({ leftHeaderSettings.title: "Title" });	
            * &lt;/script&gt; 
            * @example 
            * //Get or set the leftHeaderSettings, after initialization:<br>
            * // Get the leftHeaderSettings API value.		
            *  $("#splitview").ejmSplitPane("option", "leftHeaderSettings.title");			
            * // Set the leftHeaderSettings API value.
            * $("#splitview").ejmSplitPane("option", "leftHeaderSettings.title","Title");			
            * @memberof ejmSplitPane
            * @instance
            */
            leftHeaderSettings: {},
            /**     
            * Section for set the header functionalities to the right header of the Split Pane control.
            * @default null
            * @type {String}
            * @example 
            * //Set the rightHeaderSettings property in Unobtrusive way.
            * &lt;div id="splitview" data-role="ejmsplitpane" data-ej-rightheadersettings-title="Title"&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *     &lt;div&gt;
            *     &lt;/div&gt;
            *   &lt;/div&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * @example 
            * &lt;div id="splitview"&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *     &lt;div&gt;
            *     &lt;/div&gt;
            *   &lt;/div&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt; 
            * // Set the rightHeaderSettings on initialization. 
            * //To set rightHeaderSettings API value 
            * $("#splitview").ejmSplitPane({ rightHeaderSettings.title: "Title" });	
            * &lt;/script&gt; 
            * @example 
            * //Get or set the rightHeaderSettings, after initialization:<br>
            * // Get the rightHeaderSettings API value.		
            *  $("#splitview").ejmSplitPane("option", "rightHeaderSettings.title");			
            * // Set the rightHeaderSettings API value.
            * $("#splitview").ejmSplitPane("option", "rightHeaderSettings.title","Title");			
            * @memberof ejmSplitPane
            * @instance
            */
            rightHeaderSettings: {},
            /**		
            * specifies whether to overlay the leftpane content on lower resolutions.
            * @default true
            * @type {Boolean}
            * @example 
            * //Set the overlayLeftPane property in Unobtrusive way.
            * &lt;div id="splitview" data-role="ejmsplitpane" data-ej-overlayleftpane=false&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *     &lt;div&gt;
            *     &lt;/div&gt;
            *   &lt;/div&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * @example 
            * &lt;div id="splitview"&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *     &lt;div&gt;
            *     &lt;/div&gt;
            *   &lt;/div&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt; 
            * // Set the overlayLeftPane on initialization. 
            * //To set overlayLeftPane API value 
            * $("#splitview").ejmSplitPane({ overlayLeftPane: false });	
            * &lt;/script&gt; 
            * @example 
            * //Get or set the overlayLeftPane, after initialization:<br>
            * // Get the overlayLeftPane API value.		
            *  $("#splitview").ejmSplitPane("option", "overlayLeftPane");			
            * // Set the overlayLeftPane API value.
            * $("#splitview").ejmSplitPane("option", "overlayLeftPane",false);			
            * @memberof ejmSplitPane
            * @instance
            */
            overlayLeftPane: true,
            /**		
            * Specifies the direction to slide the overlay leftpane
            * @default left
            * @type {enum}
            * @example 
            * //Set the overlayDirection property in Unobtrusive way.
            * &lt;div id="splitview" data-role="ejmsplitpane" data-ej-overlaydirection=right&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *     &lt;div&gt;
            *     &lt;/div&gt;
            *   &lt;/div&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * @example 
            * &lt;div id="splitview"&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *     &lt;div&gt;
            *     &lt;/div&gt;
            *   &lt;/div&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt; 
            * // Set the overlayDirection on initialization. 
            * //To set overlayDirection API value 
            * $("#splitview").ejmSplitPane({ overlayDirection: right });	
            * &lt;/script&gt; 
            * @example 
            * //Get or set the overlayDirection, after initialization:<br>
            * // Get the overlayDirection API value.		
            *  $("#splitview").ejmSplitPane("option", "overlayDirection");			
            * // Set the overlayDirection API value.
            * $("#splitview").ejmSplitPane("option", "overlayDirection",right);			
            * @memberof ejmSplitPane
            * @instance
            */
            overlayDirection: "left",
            /**		
            * Enable or Disable the swiping behaviour to the content.
            * @default true
            * @type {Boolean}
            * @example 
            * //Set the enableSwipe property in Unobtrusive way.
            * &lt;div id="splitview" data-role="ejmsplitpane" data-ej-enableswipe=false&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *     &lt;div&gt;
            *     &lt;/div&gt;
            *   &lt;/div&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * @example 
            * &lt;div id="splitview"&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *     &lt;div&gt;
            *     &lt;/div&gt;
            *   &lt;/div&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt; 
            * // Set the enableSwipe on initialization. 
            * //To set enableSwipe API value 
            * $("#splitview").ejmSplitPane({ enableSwipe: false });	
            * &lt;/script&gt; 
            * @example 
            * //Get or set the enableSwipe, after initialization:<br>
            * // Get the enableSwipe API value.		
            *  $("#splitview").ejmSplitPane("option", "enableSwipe");			
            * // Set the enableSwipe API value.
            * $("#splitview").ejmSplitPane("option", "enableSwipe",false);			
            * @memberof ejmSplitPane
            * @instance
            */
            enableSwipe: true,
            /**     
            * Event triggers after the ajax content is loaded.
            * @event
            * @name ejmSplitPane#afterLoadSuccess    
            * @param {Object} argument.topage returns the sub page.
            * @param {boolean} argument.rightPaneHeader returns the instance of right header 
            * @param {Object} argument Event parameters from  toolbar  
            * @param {boolean} argument.leftPaneHeader returns the instance of left header  
            * @example 
            * &lt;div id="splitview" data-role="ejmsplitpane" data-ej-afterloadsuccess="afterLoadSuccess"&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *     &lt;div&gt;
            *     &lt;/div&gt;
            *   &lt;/div&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * @example 
            * // afterLoadSuccess event for Splitpanes
            * $("#splitview").ejmSplitPane({
            *   	afterLoadSuccess: function (args) { //handle the event }
            *	});           
            * @memberof ejmSplitPane
            * @instance
            */
            afterLoadSuccess: null,
            /**     
            * Event triggers before the content is transfer.
            * @event
            * @name ejmSplitPane#beforeTransfer    
            * @param {Object} argument.topage returns the sub page.
            * @param {boolean} argument.rightPaneHeader returns the instance of right header
            * @param {Object} argument Event parameters from  toolbar  
            * @param {boolean} argument.leftPaneHeader returns the instance  of left header 
            * @example 
            * &lt;div id="splitview" data-role="ejmsplitpane" data-ej-afterloadsuccess="beforeTransfer"&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *     &lt;div&gt;
            *     &lt;/div&gt;
            *   &lt;/div&gt;
            *   &lt;div data-ej-layout="pane"&gt;
            *   &lt;/div&gt;
            * &lt;/div&gt;
            * @example 
            * //  beforeTransfer event for Splitpanes
            * $("#splitview").ejmSplitPane({
            *   	beforeTransfer: function (args) { //handle the event }
            *	});           
            * @memberof ejmSplitPane
            * @instance
            */
            beforeTransfer: null
        },
        /**
        * Specify the data types for default properties 
        * @private
        */
        dataTypes: {
            allowLeftPaneScrolling: "boolean",
            allowRightPaneScrolling: "boolean",
            renderMode: "enum",
            theme: "enum",
            enablePersistence: "boolean",
            ios7: { "showLeftPaneHeader": "boolean", "showRightPaneHeader": "boolean" },
            android: { "showToolbar": "boolean" },
            windows: { "showLeftHeader": "boolean", "showRightHeader": "boolean" },
            overlayLeftPane: "boolean",
            overlayDirection: "enum",
            enableSwipe: "boolean"
        },

        /**
        * Create the SplitPane widget
        * @private
        */
        _init: function () {
            this._historyLength = 0;
            this._nextPage = null;
            this._currentPage = null;
            this._previousPage = null;
            this._uniqueIds = [];
            this._wp = null;
            this._renderControl();
            this._wireEvents();
        },
        /**
        * Render Section For SplitPane control		
        * @private
        */
        _renderControl: function () {
            ej.setRenderMode(this);
            ej.setTheme(this);
            this.element.addClass("e-m-splitpane e-m-" + this.model.renderMode + " e-m-" + this.model.theme);
            if (!this.model.overlayLeftPane)
                this.element.addClass(ej.isMobile() ? "e-m-mobile" : "e-m-tablet");
            this._orgEle = $(this.element).clone();
            this._layouts = this.element.find("[data-ej-layout='pane']");
            this._leftPane = $(this._layouts[0]).addClass("pane");

            if (this.model.overlayLeftPane) {
                this._overlayModal = ej.buildTag("div.e-m-sp-overlay e-m-state-hide").css("z-index", ej.getMaxZindex() + 1);
                this.element.addClass("e-m-overlaypane").append(this._overlayModal);
                this._leftPane.addClass("e-m-sp-overlay" + this.model.overlayDirection);
            }
            if (this.model.renderMode == "android")
                this._renderToolBar();
            this._leftPane.addClass("e-m-sp-left e-m-firstpage");
            if (ej.isWindows())
                this._leftPane.css("z-index", ej.getMaxZindex() + 1);
            this._leftWrapper = ej.buildTag("div#leftscroller").addClass("e-m-sp-leftwrapper");
            this._leftPane.wrapInner(this._leftWrapper);
            this._leftWrapper = this._leftPane.find(".e-m-sp-leftwrapper");
            this._rightPane = $(this._layouts).not(".e-m-sp-left").hide();
            if (!this.model.overlayLeftPane && ej.isMobile())
                this._layouts.addClass("subpage");
            else
                this._rightPane.addClass("subpage")
            if (this.model.renderMode == "ios7" || this.model.renderMode == "windows")
                this._renderLeftHeader();
            if (this.model.allowLeftPaneScrolling) {
                this._leftScroller = ej.buildTag("div#" + this.element[0].id + "_scrollpanel");
                this._leftWrapper.append(this._leftScroller);
                this.model.leftPaneScrollSettings.target = "leftscroller";
                this.model.leftPaneScrollSettings.renderMode = this.model.renderMode;
                this.model.leftPaneScrollSettings.theme = this.model.theme;
                this._leftScroller.ejmScrollPanel(this.model.leftPaneScrollSettings);
            }
            if (this.model.overlayLeftPane)
                this._setOverlayInitialStyles();
            else
                this._setModeInitialStyles();
            this._setPaneSize();
        },
        _setOverlayInitialStyles: function () {
            if (ej.isLowerResolution()) {
                this.element.addClass("e-m-sp-lower").removeClass("e-m-sp-higher");
            }
            else {
                this.element.addClass("e-m-sp-higher").removeClass("e-m-sp-lower");
                this.element.find(".e-m-sp-right").width(this.element.closest('.appview').width() - this.element.find(".e-m-sp-left").outerWidth() - (this.model.renderMode == "android" ? 4 : 0));
            }
        },
        _setModeInitialStyles: function () {
            if (ej.isMobile() && this._rightPane) {
                this._currentPage = this._leftPane;
                this._layouts.css({ "width": "100%" });
            }
            else {
                this.element.find(".e-m-sp-right").width(this.element.closest('.appview').width() - this.element.find(".e-m-sp-left").outerWidth() - (this.model.renderMode == "android" ? 4 : 0));
            }
        },
        _renderToolBar: function () {
            this._andTB = ej.buildTag("div#" + this.element[0].id + "_toolbar", "", "", {});
            this._andTB.insertBefore(this.element);
            this.model.toolbarSettings.position = "normal";
            this.model.toolbarSettings.renderMode = "android";
            this.model.toolbarSettings.theme = this.model.toolbarSettings.theme != "auto" ? this.model.toolbarSettings.theme : this.model.theme;
            this._andTB.ejmToolbar(this.model.toolbarSettings);
            this._toolbarItems = this.element.find("div[data-toolbaritems] ul");
            if (this._toolbarItems.length > 0)
                this._andTB.append(this._toolbarItems);
            this.element.css("min-height", window.innerHeight - this._andTB.height());
            if (!this.model.android.showToolbar) this._andTB.css('display', 'none');
        },
        _renderLeftHeader: function () {
            this._leftHeader = ej.buildTag("div");
            this._leftPane.prepend(this._leftHeader);
            this.model.leftHeaderSettings.renderMode = this.model.renderMode;
            this.model.leftHeaderSettings.theme = this.model.theme;
            this.model.leftHeaderSettings.position = "normal";
            this._leftHeader.ejmHeader(this.model.leftHeaderSettings);
            if ((this.model.renderMode == "ios7" && !this.model.ios7.showLeftPaneHeader) || (this.model.renderMode == "windows" && !this.model.windows.showLeftPaneHeader)) this._leftHeader.css('display', 'none');
        },
        /**
        * Creating the delegates to the SplitPane control		
        * @private
        */
        _createDelegates: function () {
            this._changeDelegate = $.proxy(this._onResize, this);
            this._swipeRightDelegate = $.proxy(this._swipeRightHandler, this);
            this._swipeLeftDelegate = $.proxy(this._swipeLeftHandler, this);
            this._hideLeftPaneDelegate = $.proxy(this._hideLeftPaneHandler, this);
            this._popDelegate = $.proxy(this._popHandler, this);
            this._tapDelegate = $.proxy(this._documentClick, this);
        },
        /**
        * Wiring and UnWiring the events to the SplitPane control		
        * @private
        */
        _wireEvents: function (remove) {
            var eventType = remove ? "unbind" : "bind";
            this._createDelegates();
            var evt = !ej.isTouchDevice() ? "resize" : "orientationchange";
            ej.listenEvents([window], [evt], [this._changeDelegate], remove);
            this._swipeEvent(eventType);
            if (this.model.overlayLeftPane)
                App.container[eventType]("tap", this._tapDelegate);
            App.container.bind("viewpopstate", this._popDelegate);
        },
        _swipeEvent: function (eventType) {
            if (this.model.overlayLeftPane && this.model.enableSwipe) {
                if (this.model.overlayDirection == "left") {
                    App.container[eventType]("swiperight", this._swipeRightDelegate);
                    App.container[eventType]("swipeleft", this._swipeLeftDelegate);
                }
                else {
                    App.container[eventType]("swipeleft", this._swipeRightDelegate);
                    App.container[eventType]("swiperight", this._swipeLeftDelegate);
                }
            }
        },
        _documentClick: function (e) {
            if ($(e.target).closest(".e-m-sp-left").length)
                return;
            this._hideLeftPaneHandler();
        },
        _popHandler: function (e) {
            if (this._historyLength)
                this._historyLength = this._historyLength - 1;
            this._currentPage = $(App.route.splitUrl(arguments[1].toPage).hash);
            if (this.model.android.showToolbar && ej.isAndroid()) {
                if (this._currentPage.attr("data-ej-toolbarsettings-android-title"))
                    this._andTB.ejmToolbar("model.android.title", this._currentPage.attr("data-ej-toolbarsettings-android-title"));
            }
        },
        _swipeRightHandler: function (evt) {
            this.openLeftPane();
        },
        _swipeLeftHandler: function (evt) {
            this.closeLeftPane();
        },
        openLeftPane: function (evt) {
            this._leftPane.addClass("e-m-sp-show");
            if (!this.model.renderMode == "ios7")
                this._overlayModal.removeClass("e-m-state-hide");
        },
        closeLeftPane: function (evt) {
            this._leftPane.removeClass("e-m-sp-show");
            if (!this.model.renderMode == "ios7")
                this._overlayModal.addClass("e-m-state-hide");
        },
        _hideLeftPaneHandler: function () {
            if (ej.isLowerResolution())
                this.closeLeftPane();
        },
        /**
        * Configure to the resize event
        * @private
        */
        _onResize: function () {
            this._setPaneSize();
            if (this.model.overlayLeftPane) {
                if (!ej.isLowerResolution()) {
                    if (this.element.hasClass("e-m-sp-lower")) {
                        this._layouts.css("width", "");
                        if (!this.model.renderMode == "ios7")
                            this._overlayModal.addClass("e-m-state-hide");
                        this.element.addClass("e-m-sp-higher").removeClass("e-m-sp-lower");
                    }
                }
                else if (this.element.hasClass("e-m-sp-higher")) {
                    this._rightPane.css("width", "100%").hide();
                    if (App.activeSubPage)
                        App.activeSubPage.show();
                    else if (this._currentPage)
                        this._currentPage.show();
                    this._leftPane.css({ "width": "" }).show();
                    this.element.addClass("e-m-sp-lower").removeClass("e-m-sp-higher");
                }
            }
        },
        /**
        * Configure to handle the PaneSize
        * @private
        */
        _setPaneSize: function () {
            var widthlayout = window.innerHeight;
            if (this.model.android.showToolbar && ej.isAndroid())
                widthlayout = widthlayout - this._andTB.height();
            this._layouts.not(".e-m-sp-preventautoheight").height(widthlayout);
            if (this._rightPane && ((!ej.isLowerResolution() && this.model.overlayLeftPane) || (!ej.isMobile() && !this.model.overlayLeftPane)))
                this._rightPane.width(window.innerWidth - this._leftPane.outerWidth());
        },
        /**
        * Configure to handle the Android specific properties
        * @private
        */
        _setAndroid: function (options) {
            for (var prop in options)
                this.model.android[prop] = options[prop];
            if (prop == "showToolbar")
                this._showToolbar(options.showToolbar);
            else
                this._andTB.ejmToolbar(options.android.toolbarSettings);
        },
        /**
        * Configure to handle the IOS7 specific properties
        * @private
        */
        _setIos7: function (options) {
            for (var prop in options)
                this.model.ios7[prop] = options[prop];
            switch (prop) {
                case "showLeftPaneHeader": (options.showLeftPaneHeader) ? this._leftHeader.css('display', 'block') : this._leftHeader.css('display', 'none'); break;
                case "showRightPaneHeader": (options.showRightPaneHeader) ? App.activeSubPage.find('div.e-m-header').css('display', 'block') : App.activeSubPage.find('div.e-m-header').css('display', 'none'); break;
            }
            if (prop.toLowerCase().contains("left"))
                this._leftHeader.ejmHeader(this.model.leftHeaderSettings);
            else if (prop.toLowerCase().contains("right"))
                App.activeSubPage.find('div.e-m-header').ejmHeader(this.model.rightHeaderSettings);
        },
        /**
        * Configure to handle the windows specific properties
        * @private
        */
        _setWindows: function (options) {
            for (var prop in options)
                this.model.windows[prop] = options[prop];
            switch (prop) {
                case "showLeftHeader": (options.showLeftHeader) ? this._leftHeader.css('display', 'block') : this._leftHeader.css('display', 'none'); break;
                case "showRightHeader": (options.showRightHeader) ? App.activeSubPage.find('div.e-m-header').css('display', 'block') : App.activeSubPage.find('div.e-m-header').css('display', 'none'); break;
            }
        },
        /**
        * To configure the properties at runtime using SetModel		
        * @private
        */
        _setModel: function (options) {
            this._trigger("modelChange", { "changes": options });
            var refresh = false;
            for (var prop in options) {
                if (!(prop.toLowerCase().contains("windows") || prop.toLowerCase().contains("android") || prop.toLowerCase().contains("ios7"))) {
                    switch (prop) {
                        case "leftHeaderTitle": this._leftHeader.ejmHeader({ title: options.leftHeaderSettings.title }); break;
                        case "rightHeaderTitle": App.activeSubPage.find('div.e-m-header').ejmHeader({ title: options.rightHeaderSettings.title }); break;
                        case "showLeftHeaderButton": this._leftHeader.ejmHeader({ "showLeftButton": options.leftHeaderSettings.showLeftButton }); break;
                        case "showRightHeaderButton": this._leftHeader.ejmHeader({ "showRightButton": options.rightHeaderSettings.showRightButton }); break;
                        case "enableSwipe": this._setSwipe(options.enableSwipe); break;
                    }
                }
                else {
                    var setModel = "_set" + prop.charAt(0).toUpperCase() + prop.slice(1);
                    if (this[setModel])
                        this[setModel](options[prop]);
                }
            }
        },
        _setSwipe: function (value) {
            this._swipeEvent(value ? "bind" : "unbind");
        },

        /**
        * Configure the toolbar to enable or not.
        * @private
        */
        _showToolbar: function (value) {
            this._andTB.css('display', value ? 'block' : 'none');
            this._setPaneSize();
        },
        /**
        * To refresh splitpane control		
        * @private
        */
        _refresh: function () {
            this._clearElements();
            this._renderControl();
            this._wireEvents(false);
        },
        /**
        * To clear SplitPane elements	
        * @private
        */
        _clearElements: function () {
            this._wireEvents(true);
            this.element.removeAttr("class");
            this.element.removeAttr("style");
            this.element.html(this._orgEle.html());
        },
        // all events bound using this._on will be unbind automatically
        /**
        * Destroy the SplitPane widget		
        * @private
        */
        _destroy: function () {
            this._clearElements();
        },

        /*---------------Public Methods---------------*/

        /**
        * To handle right side content loading
        * @return jQuery       
        * @example 
        * &lt;div id="splitview"&gt;
        *   &lt;div data-ej-layout="pane"&gt;
        *     &lt;div&gt;
        *     &lt;/div&gt;
        *   &lt;/div&gt;
        *   &lt;div data-ej-layout="pane"&gt;
        *   &lt;/div&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // To load right Pane content
        * $("#splitview").ejmSplitPane("loadContent", "sample.html",{
        reload: true,
        documenturl: "#Default",
        type: "get",
        title: "title",
        transition: "none",
        enableNativeScrolling: true,
        pageId: "currentpageid",
        checkDOMChanges: true,
        isHigherLevel: true,
        hashMonitoring: true,
        enableLeftButton: true,
        enableRightButton: true,
        leftButtonCaption: "Home",
        rightButtonCaption: "Next",
        leftButtonStyle: "back",
        leftButtonTap: "LeftButtonTapped",
        rightButtonTap: "RightButtonTapped"
        });
        * &lt;/script&gt;
        *@memberof ejmSplitPane
        * @instance
        */
        loadContent: function (toPage, options) {
            var proxy = this;
            if (this.model.overlayLeftPane)
                this._hideLeftPaneHandler();
            var curoptions = $.extend({}, ej.mobile.SplitPane.toPage.defaults, options), newPageTitle;
            if (!curoptions.isHigherLevel && this._historyLength > 0) {
                App.pageHistory.clearHistory(this._historyLength + 1);
                this._historyLength = 0;
            }

            isTargetString = typeof toPage === "string";
            if (isTargetString) {
                var existingPage = this.element.find("[data-subpageurl='" + App.route.makeUrlAbsolute(toPage) + "']"), url = toPage;
                if (existingPage.length && !curoptions.reload) {
                    proxy.transferPage(existingPage, curoptions, true);
                    return;
                }
                else if (existingPage.length > 0)
                    existingPage.remove();
                App.loadView(toPage, curoptions).done(function (absUrl, options, newPage, isAjaxLoading) {
                    if (newPage[0].nodeName.toLowerCase() == "script")
                        newPage = $(ej.getClearString(newPage[0].innerHTML));
                    var pageid = newPage[0].id ? newPage[0].id : options.pageId ? options.pageId : "page_" + parseInt(Math.random().toFixed(3) * 1000);
                    options.hash = "#" + pageid;
                    var temp = ej.buildTag("div.e-m-sp-right subpage").attr({ "data-ej-layout": "pane", "data-url": pageid });
                    proxy._rightWrapper = ej.buildTag("div#" + pageid + "_rightscroller").addClass("e-m-sp-rightwrapper");
                    proxy._rightWrapper.append(newPage);
                    temp.append(proxy._rightWrapper.wrapInner("<div></div>"));
                    proxy.element.append(temp);
                    if ((proxy.model.overlayLeftPane && !ej.isLowerResolution()) || (!proxy.model.overlayLeftPane && !ej.isMobile()))
                        temp.width(proxy.element.closest('.appview').width() - proxy.element.find(".e-m-sp-left").outerWidth() - (proxy.model.renderMode == "android" ? 4 : 0));
                    proxy.transferPage(temp, options, false, newPage);
                    temp.attr({ "data-subpageurl": App.route.makeUrlAbsolute(url) });
                    ej.widget.init(temp);
                    if ((proxy.model.allowRightPaneScrolling && options.allowRightPaneScrolling) || (proxy.model.allowRightPaneScrolling && options.allowRightPaneScrolling == undefined)) {
                        proxy._rightScroller = ej.buildTag("div");
                        proxy.model.rightPaneScrollSettings.target = pageid + "_rightscroller";
                        proxy.model.rightPaneScrollSettings.renderMode = proxy.model.renderMode;
                        proxy.model.rightPaneScrollSettings.theme = proxy.model.theme;
                        proxy._rightWrapper.append(proxy._rightScroller.ejmScrollPanel($.extend(true, proxy.model.rightPaneScrollSettings, options.rightPaneScrollSettings)));
                    }
                    if (proxy.model.afterLoadSuccess) {
                        var data = { toPage: temp, rightPaneHeader: proxy._rightHeader, leftPaneHeader: proxy._leftHeader, toolbar: proxy._andTB };
                        proxy._trigger("afterLoadSuccess", data);
                    }
                }).fail(function (url, options) {
                });
            }
            else {
                proxy.transferPage(toPage, curoptions);
            }

        },
        /**
        * To handle transferPage
        * @return jQuery       
        * @example 
        * &lt;div id="splitview"&gt;
        *   &lt;div data-ej-layout="pane"&gt;
        *     &lt;div&gt;
        *     &lt;/div&gt;
        *   &lt;/div&gt;
        *   &lt;div data-ej-layout="pane"&gt;
        *   &lt;/div&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // To transfer the page
        * $("#splitview").ejmSplitPane("transferPage", $("#newpage"),{
        reload: true,
        documenturl: "#Default",
        type: "get",
        title: "title",
        transition: "none",
        enableNativeScrolling: true,
        pageId: "currentpageid",
        checkDOMChanges: true,
        isHigherLevel: true,
        hashMonitoring: true,
        enableLeftButton: true,
        enableRightButton: true,
        leftButtonCaption: "Home",
        rightButtonCaption: "Next",
        leftButtonStyle: "back",
        leftButtonTap: "LeftButtonTapped",
        rightButtonTap: "RightButtonTapped"
        });
        * &lt;/script&gt;
        *@memberof ejmSplitPane
        * @instance
        */
        transferPage: function (toPage, options, existing, newPage) {
            if (!existing) {
                var pageheight = window.innerHeight;
                if ((this.model.renderMode == "ios7" && this.model.ios7.showRightPaneHeader) || (this.model.renderMode == "windows" && this.model.windows.showRightPaneHeader)) {
                    if (!toPage.find(">div").hasClass("e-m-header")) {
                        var header = ej.buildTag("div");
                        var backbtnCaption = $(this.element).find(".e-m-sp-left div.e-m-lb li.e-m-state-active .e-m-lb-text").html();
                        toPage.prepend(header);
                        var showbutton;
                        if ((!this.model.overlayLeftPane && ej.isMobile()) || options.isHigherLevel || options.showLeftButton)
                            showbutton = true;
                        this.model.rightHeaderSettings.renderMode = this.model.renderMode;
                        this.model.rightHeaderSettings.theme = this.model.theme;
                        this.model.rightHeaderSettings.position = "normal";
                        this._rightHeader = header.ejmHeader($.extend(true, this.model.rightHeaderSettings, options.rightHeaderSettings));
                    }
                    pageheight = window.innerHeight;
                }
                if (this.model.android.showToolbar && ej.isAndroid())
                    pageheight = window.innerHeight - this._andTB.innerHeight();
                if (options.autoAdjustHeight)
                    toPage.height(pageheight);
                else
                    toPage.addClass("e-m-sp-preventautoheight");
            }
            if (options.isHigherLevel || (!this.model.overlayLeftPane && ej.isMobile())) {
                this._historyLength++;
                options.hashMonitoring = true;
            }
            else {
                options.transition = "none";
                options.hashMonitoring = false;
            }
            this._currentPage = App.activeSubPage ? App.activeSubPage : this._currentPage;
            if (!this._currentPage && (this.model.overlayLeftPane || !ej.isMobile())) {
                this._currentPage = toPage.show();
            }
            else if (!this._currentPage)
                this._currentPage = this._leftPane;
            if (!existing && newPage) {
                App.createPage(this._currentPage);
                newPage.show();
            }
            if (this.model.android.showToolbar && ej.isAndroid() && options.toolbarSettings) {
                if (options.toolbarSettings.android) {
                    this._andTB.ejmToolbar("model.android.title", options.toolbarSettings.android.title);
                    toPage.attr("data-ej-toolbarsettings-android-title", options.toolbarSettings.android.title);
                }
            }
            App.transferPage(this._currentPage, toPage, options);
            if (this.model.beforeTransfer) {
                var data = { toPage: toPage, rightPaneHeader: this._rightHeader, leftPaneHeader: this._leftHeader, toolbar: this._andTB };
                this._trigger("beforeTransfer", data);
            }
            this._layouts = this._layouts.add(toPage);
            this._rightPane = this._rightPane.add(toPage);
        }
        /*---------------Public Methods End---------------*/
    });
    $.extend(true, ej.mobile.SplitPane.prototype.defaults.toolbarSettings, ej.mobile.Toolbar.prototype.defaults);
    $.extend(true, ej.mobile.SplitPane.prototype.defaults.leftPaneScrollSettings, ej.mobile.ScrollPanel.prototype.defaults);
    $.extend(true, ej.mobile.SplitPane.prototype.defaults.rightPaneScrollSettings, ej.mobile.ScrollPanel.prototype.defaults);
    $.extend(true, ej.mobile.SplitPane.prototype.defaults.leftHeaderSettings, ej.mobile.Header.prototype.defaults);
    $.extend(true, ej.mobile.SplitPane.prototype.defaults.rightHeaderSettings, ej.mobile.Header.prototype.defaults);
    ej.mobile.SplitPane.toPage =
    {
        defaults: {
            transition: "auto",
            reverse: false,
            changeHash: true,
            reloadSamePage: true,
            autoAdjustHeight: true,
            samePage: false
        }
    }
    /**
    * Enum for headerLeftButtonStyle
    * @enum {String}
    * @global
    */
    ej.mobile.SplitPane.HeaderLeftButtonStyle = {
        /**
        Enum for back Button Style*/
        Back: "back",
        /**
        Enum for header Button Style*/
        Header: "header",
        /**
        Enum for normal Button Style*/
        Normal: "normal"
    },
    /**
    * Enum for headerRightButtonStyle
    * @enum {String}
    * @global
    */
        ej.mobile.SplitPane.HeaderRightButtonStyle = {
            /**
            Enum for header Button Style*/
            Header: "header",
            /**
            Enum for normal Button Style*/
            Normal: "normal"
        }
})(jQuery, Syncfusion);