/**
* @fileOverview Plugin to style the Html CheckBox elements
* @copyright Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/
(function ($, ej, undefined) {

    //mTab is the plugin name 
    //"m.Tab" is "namespace.className" will hold functions and properties
    /**
    * @namespace ej
    * @class ejmTab
    * @requires jQuery    
    * @requires ej.mobile.application
    * @requires ej.core
    * @requires ej.unobtrusive
    * @requires ej.mobile.core
    * @requires ej.data
    * @requires ej.touch
    * @requires ej.mobile.listbox
    * @requires ej.mobile.scrollbar
    * @requires ej.mobile.scrollpanel
    * @classdesc Custom design for Html Tab control.
    * @example 
    * &lt;div id="tab" data-role="ejmtab" &gt;
    * &lt;ul &gt;
    * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
    * &lt;/li &gt;
    * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
    * &lt;/li &gt;
    * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
    * &lt;/li &gt;
    * &lt;/ul &gt;
    * &lt;/div&gt;  
    * &lt;div id="default1" &gt;
    * Movies content here
    * &lt;/div&gt;	
    * &lt;div id="default2" &gt;
    * Music content here
    * &lt;/div&gt;
    * &lt;div id="default3" &gt;
    * Favourites content here
    * &lt;/div&gt;
    * &lt;script&gt; 
    * // Create tab  
    * $("#tab").ejmTab(); 
    * &lt;/script&gt;
    */
    ej.widget("ejmTab", "ej.mobile.Tab", {
        _setFirst: true,
        _rootCSS: "e-m-tab",
        _tags: [{
            tag: "items",
            attr: ["text", "href", "enableAjax", "ios7.imageClass", "android.imageClass", "badge.enabled", "badge.value", "badge.maxValue", "badge.minValue", "touchStart", "touchEnd"]
        }],
        //Default model values
        defaults: {
            /**		
            * Changes the theme. See {@link Theme}
            * @default auto
            * @type {enum}
            * @example 
            * //Set the theme property in unobtrusive way.
            * &lt;div id="tab" data-role="ejmtab" data-ej-theme="auto" &gt;
            * &lt;ul &gt;
            * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
            * &lt;/li &gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;  
            * &lt;div id="default1" &gt;
            * Movies content here
            * &lt;/div&gt;	
            * &lt;div id="default2" &gt;
            * Music content here
            * &lt;/div&gt;
            * &lt;div id="default3" &gt;
            * Favourites content here
            * &lt;/div&gt;
            * @example 
            * &lt;div id="tab"&gt;
            * &lt;ul &gt;
            * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
            * &lt;/li &gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;  
            * &lt;div id="default1" &gt;
            * Movies content here
            * &lt;/div&gt;	
            * &lt;div id="default2" &gt;
            * Music content here
            * &lt;/div&gt;
            * &lt;div id="default3" &gt;
            * Favourites content here
            * &lt;/div&gt;
            * // Set theme on initialization. 
            * //To set theme API value 
            * &lt;script&gt;
            * $(function(){
            * // To enable tab Control
            * $("#tab").ejmTab({theme:ej.mobile.Theme.Dark});	
            * });
            * &lt;/script&gt;		
            * @example 
            * //Get or set the theme, after initialization:<br>
            * // Get the theme API value.
            *  $("#tab").ejmTab ("option", "theme");			
            * // Set the theme API
            * $("#tab").ejmTab ("option", "theme", ej.mobile.Theme.Dark);            
            * @memberof ejmTab
            * @instance				
            */
            theme: "auto",
            /**		
            * Changes the rendering mode. See {@link RenderMode}
            * @default auto
            * @type {enum}
            * @example 
            * //Set the renderMode property in unobtrusive way.
            * &lt;div id="tab" data-role="ejmtab" data-ej-rendermode="auto" &gt;
            * &lt;ul &gt;
            * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
            * &lt;/li &gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;  
            * &lt;div id="default1" &gt;
            * Movies content here
            * &lt;/div&gt;	
            * &lt;div id="default2" &gt;
            * Music content here
            * &lt;/div&gt;
            * &lt;div id="default3" &gt;
            * Favourites content here
            * &lt;/div&gt;
            * @example 
            * &lt;div id="tab"&gt;
            * &lt;ul &gt;
            * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
            * &lt;/li &gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;  
            * &lt;div id="default1" &gt;
            * Movies content here
            * &lt;/div&gt;	
            * &lt;div id="default2" &gt;
            * Music content here
            * &lt;/div&gt;
            * &lt;div id="default3" &gt;
            * Favourites content here
            * &lt;/div&gt;  
            * &lt;script&gt;
            * $(function(){
            * // To hideBadge Tab Control
            * $("#tab").ejmTab({renderMode:ej.mobile.RenderMode.Android});	
            * });
            * &lt;/script&gt;		
            * @example 
            * //Get or set the renderMode, after initialization:<br>
            * // Get the renderMode API value.
            *  $("#tab").ejmTab ("option", "renderMode");			
            * // Set the renderMode API
            * $("#tab").ejmTab ("option", "renderMode", ej.mobile.RenderMode.Android);            
            * @memberof ejmTab
            * @instance				
            */
            renderMode: "auto",
            /**		
            * Specifies whether enable tab content's scrolling or not.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the allowScrolling property in unobtrusive way.
            * &lt;div id="tab" data-role="ejmtab" data-ej-allowscrolling="true" &gt;
            * &lt;ul &gt;
            * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
            * &lt;/li &gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;  
            * &lt;div id="default1" &gt;
            * Movies content here
            * &lt;/div&gt;	
            * &lt;div id="default2" &gt;
            * Music content here
            * &lt;/div&gt;
            * &lt;div id="default3" &gt;
            * Favourites content here
            * &lt;/div&gt;
            * @example 
            * // Set allowScrolling on initialization. 
            * //To set allowScrolling API value 
            * &lt;div id="tab"&gt;
            * &lt;ul &gt;
            * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
            * &lt;/li &gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;  
            * &lt;div id="default1" &gt;
            * Movies content here
            * &lt;/div&gt;	
            * &lt;div id="default2" &gt;
            * Music content here
            * &lt;/div&gt;
            * &lt;div id="default3" &gt;
            * Favourites content here
            * &lt;/div&gt;  
            * &lt;script&gt;
            * $(function(){
            * $("#tab").ejmTab({allowScrolling:true});	
            * });
            * &lt;/script&gt;			
            * @example 
            * //Get or set the allowScrolling, after initialization:<br>
            * // Get the allowScrolling API value.
            *  $("#tab").ejmTab ("option", "allowScrolling");			
            * // Set the allowScrolling API
            * $("#tab").ejmTab ("option", "allowScrolling", "true");            
            * @memberof ejmTab
            * @instance				
            */
            allowScrolling: false,
            /**		
            * Specifies whether enable native scrolling or not.
            * @default null
            * @type {boolean}
            * @example 
            * //Set the enableNativeScrolling property in unobtrusive way.
            * &lt;div id="tab" data-role="ejmtab" data-ej-allowscrolling="true" data-ej-enablenativescrolling="true" &gt;
            * &lt;ul &gt;
            * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
            * &lt;/li &gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;  
            * &lt;div id="default1" &gt;
            * Movies content here
            * &lt;/div&gt;	
            * &lt;div id="default2" &gt;
            * Music content here
            * &lt;/div&gt;
            * &lt;div id="default3" &gt;
            * Favourites content here
            * &lt;/div&gt;
            * @example 
            * // Set enableNativeScrolling on initialization. 
            * //To set enableNativeScrolling API value 
            * &lt;div id="tab"&gt;
            * &lt;ul &gt;
            * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
            * &lt;/li &gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;  
            * &lt;div id="default1" &gt;
            * Movies content here
            * &lt;/div&gt;	
            * &lt;div id="default2" &gt;
            * Music content here
            * &lt;/div&gt;
            * &lt;div id="default3" &gt;
            * Favourites content here
            * &lt;/div&gt;  
            * &lt;script&gt;
            * $(function(){
            * $("#tab").ejmTab({allowScrolling:true, enableNativeScrolling:true});	
            * });
            * &lt;/script&gt;			
            * @example 
            * //Get or set the enableNativeScrolling, after initialization:<br>
            * // Get the allowScrolling API value.
            *  $("#tab").ejmTab ("option", "enableNativeScrolling");			
            * // Set the allowScrolling API
            * $("#tab").ejmTab ("option", "enableNativeScrolling", "true");            
            * @memberof ejmTab
            * @instance				
            */
            enableNativeScrolling: (ej.isAndroid() || ej.isIOS()) ? false : ej.isDevice() ? true : false,
            /**		
            * Specifies whether show the scrollbars or not
            * @default null
            * @type {boolean}
            * @example 
            * //Set the showScrollbars property in unobtrusive way.
            * &lt;div id="tab" data-role="ejmtab" data-ej-allowscrolling="true" data-ej-showscrollbars="false" &gt;
            * &lt;ul &gt;
            * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
            * &lt;/li &gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;  
            * &lt;div id="default1" &gt;
            * Movies content here
            * &lt;/div&gt;	
            * &lt;div id="default2" &gt;
            * Music content here
            * &lt;/div&gt;
            * &lt;div id="default3" &gt;
            * Favourites content here
            * &lt;/div&gt;
            * @example 
            * // Set showScrollbars property on initialization. 
            * //To set showScrollbars API value 
            * &lt;div id="tab"&gt;
            * &lt;ul &gt;
            * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
            * &lt;/li &gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;  
            * &lt;div id="default1" &gt;
            * Movies content here
            * &lt;/div&gt;	
            * &lt;div id="default2" &gt;
            * Music content here
            * &lt;/div&gt;
            * &lt;div id="default3" &gt;
            * Favourites content here
            * &lt;/div&gt;  
            * &lt;script&gt;
            * $(function(){
            * $("#tab").ejmTab({allowScrolling:true,showScrollbars:false});	
            * });
            * &lt;/script&gt;			
            * @example 
            * //Get or set the showScrollbars property, after initialization:<br>
            * // Get the showScrollbars API value.
            *  $("#tab").ejmTab ("option", "showScrollbars");			
            * // Set the showScrollbars API
            * $("#tab").ejmTab ("option", "showScrollbars", "false");            
            * @memberof ejmTab
            * @instance				
            */
            showScrollbars: true,
            /**		
            * Specifies whether Ajax content will be used to load the tab contents.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the enableAjax property in unobtrusive way.
            * &lt;div id="tab" data-role="ejmtab" data-ej-enableajax="true" &gt;
            * &lt;ul &gt;
            * &lt;li data-ej-href="movies.html" data-ej-text='Movies' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="music.html" data-ej-text='Music' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="favourites.html" data-ej-text='Favourites' &gt;
            * &lt;/li &gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;             
            * //Create the movies.html file with following content.
            *  Movies contents here 
            * //Create the music.html file with following content.
            *  Music contents here 
            * //Create the favourites.html file with following content.
            *  Favourites contents here            
            * // Set enableAjax on initialization. 
            * //To set enableAjax API value 
            * &lt;div id="tab"&gt;
            * &lt;ul &gt;
            * &lt;li data-ej-href="movies.html" data-ej-text='Movies' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="music.html" data-ej-text='Music' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="favourites.html" data-ej-text='Favourites' &gt;
            * &lt;/li &gt;
            * &lt;/ul &gt;
            * &lt;/div&gt; 
            * &lt;script&gt;            
            * $(function(){
            * $("#tab").ejmTab({enableAjax: true});	
            * });
            * &lt;/script&gt;		
            * @example 
            * //Get or set the enableAjax, after initialization:<br>
            * // Get the enableAjax API value.
            *  $("#tab").ejmTab ("option", "enableAjax");			
            * // Set the enableAjax API
            * $("#tab").ejmTab ("option", "enableAjax", "true");            
            * @memberof ejmTab
            * @instance				
            */
            enableAjax: false,
            /**		
            * Specifies whether to enable Caching or not.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the enableCache property in unobtrusive way.
            * &lt;div id="tab" data-role="ejmtab" data-ej-enableajax="true" data-ej-enablecache="true" &gt;
            * &lt;ul &gt;
            * &lt;li data-ej-href="movies.html" data-ej-text='Movies' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="music.html" data-ej-text='Music' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="favourites.html" data-ej-text='Favourites' &gt;
            * &lt;/li &gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;             
            * //Create the movies.html file with following content.
            *  Movies contents here 
            * //Create the music.html file with following content.
            *  Music contents here 
            * //Create the favourites.html file with following content.
            *  Favourites contents here
            * @example 
            * // Set enableCache on initialization. 
            * //To set enableCache API value 
            * &lt;div id="tab"&gt;
            * &lt;ul &gt;
            * &lt;li data-ej-href="movies.html" data-ej-text='Movies' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="music.html" data-ej-text='Music' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="favourites.html" data-ej-text='Favourites' &gt;
            * &lt;/li &gt;
            * &lt;/ul &gt;
            * &lt;/div&gt; 
            * &lt;script&gt;
            * $(function(){
            * $("#tab").ejmTab({enableAjax: true, enableCache: true });	
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the enableCache, after initialization:<br>
            * // Get the enableCache API value.
            *  $("#tab").ejmTab ("option", "enableCache");			
            * // Set the enableCache API
            * $("#tab").ejmTab ("option", "enableCache", "true");            
            * @memberof ejmTab
            * @instance				
            */
            enableCache: false,
            /**		
            * Specifies whether show waiting popup in Ajax content loading or not.
            * @default true
            * @type {boolean}
            * @example 
            * //Set the showAjaxPopup property in unobtrusive way.
            * &lt;div id="tab" data-role="ejmtab" data-ej-enableajax="true" data-ej-showajaxpopup="true" &gt;
            * &lt;ul &gt;
            * &lt;li data-ej-href="movies.html" data-ej-text='Movies' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="music.html" data-ej-text='Music' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="favourites.html" data-ej-text='Favourites' &gt;
            * &lt;/li &gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;             
            * //Create the movies.html file with following content.
            *  Movies contents here 
            * //Create the music.html file with following content.
            *  Music contents here 
            * //Create the favourites.html file with following content.
            *  Favourites contents here
            * @example 
            * // Set showAjaxPopup on initialization. 
            * //To set showAjaxPopup API value 
            * &lt;div id="tab"&gt;
            * &lt;ul &gt;
            * &lt;li data-ej-href="movies.html" data-ej-text='Movies' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="music.html" data-ej-text='Music' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="favourites.html" data-ej-text='Favourites' &gt;
            * &lt;/li &gt;
            * &lt;/ul &gt;
            * &lt;/div&gt; 
            * &lt;script&gt;
            * $(function(){
            * $("#tab").ejmTab({enableAjax: true, showAjaxPopup: false });	
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the showAjaxPopup, after initialization:<br>
            * // Get the showAjaxPopup API value.
            *  $("#tab").ejmTab ("option", "showAjaxPopup");			
            * // Set the showAjaxPopup API
            * $("#tab").ejmTab ("option", "showAjaxPopup", "false");            
            * @memberof ejmTab
            * @instance				
            */
            showAjaxPopup: false,
            /**		
            * Specifies the Item Index which is selected.
            * @default 0
            * @type {number}
            * @example 
            * //Set the selectedItemIndex property in unobtrusive way.
            * &lt;div id="tab" data-role="ejmtab" data-ej-selecteditemindex="1" &gt;
            * &lt;ul &gt;
            * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
            * &lt;/li &gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;  
            * &lt;div id="default1" &gt;
            * Movies content here
            * &lt;/div&gt;	
            * &lt;div id="default2" &gt;
            * Music content here
            * &lt;/div&gt;
            * &lt;div id="default3" &gt;
            * Favourites content here
            * &lt;/div&gt;
            * @example
            * // Set selectedItemIndex on initialization. 
            * //To set selectedItemIndex API value 
            * &lt;div id="tab"&gt;
            * &lt;ul &gt;
            * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
            * &lt;/li &gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;  
            * &lt;div id="default1" &gt;
            * Movies content here
            * &lt;/div&gt;	
            * &lt;div id="default2" &gt;
            * Music content here
            * &lt;/div&gt;
            * &lt;div id="default3" &gt;
            * Favourites content here
            * &lt;/div&gt; 
            * &lt;script&gt;
            * $(function(){
            * $("#tab").ejmTab({selectedItemIndex:1});	
            * });
            * &lt;/script&gt; 
            * @example 
            * //Get or set the selectedItemIndex, after initialization:<br>
            * // Get the selectedItemIndex API value.
            *  $("#tab").ejmTab ("option", "selectedItemIndex");			
            * // Set the selectedItemIndex API
            * $("#tab").ejmTab ("option", "selectedItemIndex", "1");            
            * @memberof ejmTab
            * @instance				
            */
            selectedItemIndex: 0,
            /**		
            * Saves current model value to browser cookies for state maintains. While refreshing the page retains the model value applies from browser cookies.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the enablePersistence property in unobtrusive way.
            * &lt;div id="tab" data-role="ejmtab" data-ej-enablepersistence=true &gt;
            * &lt;ul &gt;
            * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
            * &lt;/li &gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;  
            * &lt;div id="default1" &gt;
            * Movies content here
            * &lt;/div&gt;	
            * &lt;div id="default2" &gt;
            * Music content here
            * &lt;/div&gt;
            * &lt;div id="default3" &gt;
            * Favourites content here
            * &lt;/div&gt;
            * @example
            * // Set enablePersistence on initialization. 
            * //To set enablePersistence API value 
            * &lt;div id="tab"&gt;
            * &lt;ul &gt;
            * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
            * &lt;/li &gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;  
            * &lt;div id="default1" &gt;
            * Movies content here
            * &lt;/div&gt;	
            * &lt;div id="default2" &gt;
            * Music content here
            * &lt;/div&gt;
            * &lt;div id="default3" &gt;
            * Favourites content here
            * &lt;/div&gt; 
            * &lt;script&gt;
            * $(function(){
            * $("#tab").ejmTab({enablePersistence:true});	
            * });
            * &lt;/script&gt; 
            * @example 
            * //Get or set the enablePersistence, after initialization:<br>
            * // Get the enablePersistence API value.
            *  $("#tab").ejmTab ("option", "enablePersistence");			
            * // Set the enablePersistence API
            * $("#tab").ejmTab ("option", "enablePersistence", true);            
            * @memberof ejmTab
            * @instance				
            */
            enablePersistence: false,
            /**		
            * Section for badge specific functionalities.                      
            * @memberof ejmTab
            * @instance
            */
            badge: {
                /**	
                * Specifies whether to enable Badge or not.
                * @default false
                * @type {boolean}
                * @alias ejmTab#badge->enabled
                * @example 
                * //Set the enabled property in unobtrusive way.
                * &lt;div id="tab" data-role="ejmtab" data-ej-badge-enabled="false" &gt;
                * &lt;ul &gt;
                * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
                * &lt;/li &gt;
                * &lt;/ul &gt;
                * &lt;/div&gt;  
                * &lt;div id="default1" &gt;
                * Movies content here
                * &lt;/div&gt;	
                * &lt;div id="default2" &gt;
                * Music content here
                * &lt;/div&gt;
                * &lt;div id="default3" &gt;
                * Favourites content here
                * &lt;/div&gt;
                * @example 
                * // Set enabled on initialization. 
                * // To enabled API value 
                * &lt;div id="tab"&gt;
                * &lt;ul &gt;
                * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
                * &lt;/li &gt;
                * &lt;/ul &gt;
                * &lt;/div&gt;  
                * &lt;div id="default1" &gt;
                * Movies content here
                * &lt;/div&gt;	
                * &lt;div id="default2" &gt;
                * Music content here
                * &lt;/div&gt;
                * &lt;div id="default3" &gt;
                * Favourites content here
                * &lt;/div&gt;
                * &lt;script&gt;
                * $(function(){
                * $("#tab").ejmTab({badge:{enabled:true}});	
                * });
                * &lt;/script&gt;		
                * @example 
                * //Get or set the enabled, after initialization:<br>
                * // Get the enabled API value.
                *  $("#tab").ejmTab ("option", "badge.enabled");			
                * // Set the showBadge API
                * $("#tab").ejmTab ("option", "badge.enabled", "true");            
                * @memberof ejmTab
                * @instance				
                */
                enabled: false,
                /**		
                * Specifies the badge Value.
                * @default 0
                * @type {number}
                * @alias ejmTab#badge->value
                * @example 
                * @example 
                * //Set the Badge Value property in unobtrusive way.
                * &lt;div id="tab" data-role="ejmtab" data-ej-badge-enabled="true" data-ej-badge-value="2" &gt;
                * &lt;ul &gt;
                * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
                * &lt;/li &gt;
                * &lt;/ul &gt;
                * &lt;/div&gt;  
                * &lt;div id="default1" &gt;
                * Movies content here
                * &lt;/div&gt;	
                * &lt;div id="default2" &gt;
                * Music content here
                * &lt;/div&gt;
                * &lt;div id="default3" &gt;
                * Favourites content here
                * &lt;/div&gt;           
                * @example 
                * // Set badge value on initialization. 
                * &lt;div id="tab"&gt;
                * &lt;ul &gt;
                * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
                * &lt;/li &gt;
                * &lt;/ul &gt;
                * &lt;/div&gt;  
                * &lt;div id="default1" &gt;
                * Movies content here
                * &lt;/div&gt;	
                * &lt;div id="default2" &gt;
                * Music content here
                * &lt;/div&gt;
                * &lt;div id="default3" &gt;
                * Favourites content here
                * &lt;/div&gt;
                * &lt;script&gt;
                * $(function(){
                * $("#tab").ejmTab({badge:{value:2}});	
                * });
                * &lt;/script&gt;		
                * @example 
                * //Get or set the badge value, after initialization:<br>
                * // Get the badge value API.
                *  $("#tab").ejmTab ("option", "badge.value");			
                * // Set the badge value API
                * $("#tab").ejmTab ("option", "badge.value", "2");            
                * @memberof ejmTab
                * @instance				
                */
                value: 0,
                /**		
                * Specifies the maximum value allowed for a badge.
                * @default 100
                * @type {number}
                * @alias ejmTab#badge->maxValue
                * @example 
                * //Set the maximum Badge Value property in unobtrusive way.
                * &lt;div id="tab" data-role="ejmtab" data-ej-badge-enabled="true" data-ej-badge-maxvalue="100" &gt;
                * &lt;ul &gt;
                * &lt;li data-ej-href="#default1" data-ej-text='Movies' data-ej-badge-value="120" &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="#default2" data-ej-text='Music'data-ej-badge-value="80" &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="#default3" data-ej-text='Favourites' data-ej-badge-value="64" &gt;
                * &lt;/li &gt;
                * &lt;/ul &gt;
                * &lt;/div&gt;  
                * &lt;div id="default1" &gt;
                * Movies content here
                * &lt;/div&gt;	
                * &lt;div id="default2" &gt;
                * Music content here
                * &lt;/div&gt;
                * &lt;div id="default3" &gt;
                * Favourites content here
                * &lt;/div&gt;
                * @example 
                * // Set maxValue on initialization. 
                * // To maxValue API value 
                * &lt;div id="tab"&gt;
                * &lt;ul &gt;
                * &lt;li data-ej-href="#default1" data-ej-text='Movies' data-ej-badge-value="120"&gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="#default2" data-ej-text='Music' data-ej-badge-value="80"&gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="#default3" data-ej-text='Favourites' data-ej-badge-value="64"&gt;
                * &lt;/li &gt;
                * &lt;/ul &gt;
                * &lt;/div&gt;  
                * &lt;div id="default1" &gt;
                * Movies content here
                * &lt;/div&gt;	
                * &lt;div id="default2" &gt;
                * Music content here
                * &lt;/div&gt;
                * &lt;div id="default3" &gt;
                * Favourites content here
                * &lt;/div&gt;
                * &lt;script&gt;
                * $(function(){
                * $("#tab").ejmTab({badge:{maxValue:100}});	
                * });
                * &lt;/script&gt;		
                * @example 
                * //Get or set the maxValue, after initialization:<br>
                * // Get the maxValue API.
                *  $("#tab").ejmTab ("option", "badge.maxValue");			
                * // Set the maxValue API
                * $("#tab").ejmTab ("option", "badge.maxValue", "100");            
                * @memberof ejmTab
                * @instance				
                */
                maxValue: 100,
                /**		
                * Specifies the minimum value allowed for a badge.
                * @default 1
                * @type {number}
                * @alias ejmTab#badge->minValue
                * @example 
                * //Set the minimum Badge Value property in unobtrusive way.
                * &lt;div id="tab" data-role="ejmtab" data-ej-badge-enabled="true" data-ej-badge-minvalue="10" &gt;
                * &lt;ul &gt;
                * &lt;li data-ej-href="#default1" data-ej-text='Movies' data-ej-badge-value="120" &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="#default2" data-ej-text='Music'data-ej-badge-value="80" &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="#default3" data-ej-text='Favourites' data-ej-badge-value="64" &gt;
                * &lt;/li &gt;
                * &lt;/ul &gt;
                * &lt;/div&gt;  
                * &lt;div id="default1" &gt;
                * Movies content here
                * &lt;/div&gt;	
                * &lt;div id="default2" &gt;
                * Music content here
                * &lt;/div&gt;
                * &lt;div id="default3" &gt;
                * Favourites content here
                * &lt;/div&gt;
                * @example 
                * // Set minValue on initialization. 
                * // To minValue API value 
                * &lt;div id="tab"&gt;
                * &lt;ul &gt;
                * &lt;li data-ej-href="#default1" data-ej-text='Movies' data-ej-badge-value="120"&gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="#default2" data-ej-text='Music' data-ej-badge-value="80"&gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="#default3" data-ej-text='Favourites' data-ej-badge-value="64"&gt;
                * &lt;/li &gt;
                * &lt;/ul &gt;
                * &lt;/div&gt;  
                * &lt;div id="default1" &gt;
                * Movies content here
                * &lt;/div&gt;	
                * &lt;div id="default2" &gt;
                * Music content here
                * &lt;/div&gt;
                * &lt;div id="default3" &gt;
                * Favourites content here
                * &lt;/div&gt;
                * &lt;script&gt;
                * $(function(){
                * $("#tab").ejmTab({badge:{minValue:10}});	
                * });
                * &lt;/script&gt;		
                * @example 
                * //Get or set the minValue, after initialization:<br>
                * // Get the minValue API.
                *  $("#tab").ejmTab ("option", "badge.minValue");			
                * // Set the minValue API
                * $("#tab").ejmTab ("option", "badge.minValue", "10");            
                * @memberof ejmTab
                * @instance				
                */
                minValue: 1
            },
            /**     
            * Section for ios7 rendermode specific functionalities.                      
            * @memberof ejmTab
            * @instance
            */
            ios7: {
                /**  
                * Specifies the class for image to display in ios7 mode.
                * @default ""
                * @type {string}
                * @alias ejmTab#ios7->imageClass
                * @example 
                * // Set the ios7 mode imageClass property in unobtrusive way.
                * &lt;div id="tab" data-role="ejmtab" data-ej-rendermode="ios7"&gt;
                * &lt;ul &gt;
                * &lt;li data-ej-ios7-imageclass="icn-Movies" data-ej-href="#default1" data-ej-text='Movies' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-ios7-imageclass="icn-Music" data-ej-href="#default2" data-ej-text='Music' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-ios7-imageclass="icn-Favourites" data-ej-href="#default3" data-ej-text='Favourites' &gt;
                * &lt;/li &gt;
                * &lt;/ul &gt;
                * &lt;/div&gt;  
                * &lt;div id="default1" &gt;
                * Movies content here
                * &lt;/div&gt;	
                * &lt;div id="default2" &gt;
                * Music content here
                * &lt;/div&gt;
                * &lt;div id="default3" &gt;
                * Favourites content here
                * &lt;/div&gt;			
                * @memberof ejmTab
                * @instance
                */
                "imageClass": "",
                /**     
                * Section for overflow badge specific functionalities.  
                * @alias ejmTab#ios7->overflowBadge
                * @memberof ejmTab
                * @instance
                */

                overflowBadge: {
                    /**
                    * Specifies whether to enable badge for overflow tab or not.
                    * @default false
                    * @type {boolean}
                    * @alias ejmTab#ios7->overflowBadge->enabled
                    * @example 
                    * // Set the ios7 overflowBadge mode enabled property in unobtrusive way.
                    * &lt;div id="tab" data-role="ejmtab" data-ej-rendermode="ios7" data-ej-ios7-overflowbadge-enabled="true" &gt;
                    * &lt;ul &gt;
                    * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
                    * &lt;/li &gt;
                    * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
                    * &lt;/li &gt;
                    * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
                    * &lt;/li &gt;
                    * &lt;/ul &gt;
                    * &lt;/div&gt;  
                    * &lt;div id="default1" &gt;
                    * Movies content here
                    * &lt;/div&gt;	
                    * &lt;div id="default2" &gt;
                    * Music content here
                    * &lt;/div&gt;
                    * &lt;div id="default3" &gt;
                    * Favourites content here
                    * &lt;/div&gt;           
                    * @example 
                    * // Set ios7 mode overflowbadge enabled badge on initialization. 
                    * //To set ios7 mode overflowbadge enabled badge customText API value 
                    * &lt;div id="tab"&gt;
                    * &lt;ul &gt;
                    * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
                    * &lt;/li &gt;
                    * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
                    * &lt;/li &gt;
                    * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
                    * &lt;/li &gt;
                    * &lt;/ul &gt;
                    * &lt;/div&gt;  
                    * &lt;div id="default1" &gt;
                    * Movies content here
                    * &lt;/div&gt;	
                    * &lt;div id="default2" &gt;
                    * Music content here
                    * &lt;/div&gt;
                    * &lt;div id="default3" &gt;
                    * Favourites content here
                    * &lt;/div&gt; 
                    * &lt;script&gt;
                    * $(function(){
                    * $("#tab").ejmTab({renderMode:"ios7", ios7:{overflowBadge:{enabled:true}}});	
                    * });
                    * &lt;/script&gt;  
                    * @example 
                    * // Get or set the ios7 overflowBadge mode enabled API, after initialization:
                    * // Get the ios7 mode enabled value  
                    * $("#tab").ejmTab("option", "ios7.overflowBadge.enabled");   
                    * // Set the ios7 overflowBadge mode enabled value 
                    *$("#tab").ejmTab("option", "ios7.overflowBadge.enabled", true); 
                    * @memberof ejmTab
                    * @instance
                    */
                    enabled: false,
                    /**  
                    * Specifies the value for overflow badge in ios7 mode.
                    * @default 0
                    * @type {number}
                    * @alias ejmTab#ios7->overflowBadge->value
                    * @example 
                    * // Set the ios7 overflowBadge mode value property in unobtrusive way.
                    * &lt;div id="tab" data-role="ejmtab" data-ej-rendermode="ios7" data-ej-ios7-overflowbadge-enabled="true" data-ej-ios7-overflowbadge-value="2" &gt;
                    * &lt;ul &gt;
                    * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
                    * &lt;/li &gt;
                    * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
                    * &lt;/li &gt;
                    * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
                    * &lt;/li &gt;
                    * &lt;/ul &gt;
                    * &lt;/div&gt;  
                    * &lt;div id="default1" &gt;
                    * Movies content here
                    * &lt;/div&gt;	
                    * &lt;div id="default2" &gt;
                    * Music content here
                    * &lt;/div&gt;
                    * &lt;div id="default3" &gt;
                    * Favourites content here
                    * &lt;/div&gt;          
                    * @example 
                    * // Set ios7 mode overflowbadge value on initialization. 
                    * //To set ios7 mode overflowbadge value API value 
                    * &lt;div id="tab"&gt;
                    * &lt;ul &gt;
                    * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
                    * &lt;/li &gt;
                    * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
                    * &lt;/li &gt;
                    * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
                    * &lt;/li &gt;
                    * &lt;/ul &gt;
                    * &lt;/div&gt;  
                    * &lt;div id="default1" &gt;
                    * Movies content here
                    * &lt;/div&gt;	
                    * &lt;div id="default2" &gt;
                    * Music content here
                    * &lt;/div&gt;
                    * &lt;div id="default3" &gt;
                    * Favourites content here
                    * &lt;/div&gt; 
                    * &lt;script&gt;
                    * $(function(){
                    * $("#tab").ejmTab({renderMode:"ios7",ios7:{overflowBadge:{enabled:true,value:2}}});	
                    * });
                    * &lt;/script&gt;  
                    * @example 
                    * // Get or set the ios7 overflowbadge mode value API, after initialization:
                    * // Get the ios7 overflowBadge mode value  
                    * $("#tab").ejmTab("option", "ios7.overflowBadge.value");   
                    * // Set the ios7 overflowBadge mode value 
                    *$("#tab").ejmTab("option", "ios7.overflowBadge.value",2); 
                    * @memberof ejmTab
                    * @instance
                    */
                    value: 0,
                    /**  
                    * Specifies the maximum value for overflow batch in ios7 mode.
                    * @default 100
                    * @type {number}
                    * @alias ejmTab#ios7->overflowBadge->maxValue
                    * @example 
                    * // Set the ios7 mode overflowBadge maxValue property in unobtrusive way.
                    * &lt;div id="tab" data-role="ejmtab" data-ej-rendermode="ios7" data-ej-ios7-overflowbadge-enabled="true" data-ej-ios7-overflowbadge-maxvalue="100" &gt;
                    * &lt;ul &gt;
                    * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
                    * &lt;/li &gt;
                    * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
                    * &lt;/li &gt;
                    * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
                    * &lt;/li &gt;
                    * &lt;/ul &gt;
                    * &lt;/div&gt;  
                    * &lt;div id="default1" &gt;
                    * Movies content here
                    * &lt;/div&gt;	
                    * &lt;div id="default2" &gt;
                    * Music content here
                    * &lt;/div&gt;
                    * &lt;div id="default3" &gt;
                    * Favourites content here
                    * &lt;/div&gt;            
                    * @example 
                    * // Set ios7 mode overflowbadge maxvalue on initialization. 
                    * //To set ios7 mode overflowbadge maxvalue  API value 
                    * &lt;div id="tab"&gt;
                    * &lt;ul &gt;
                    * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
                    * &lt;/li &gt;
                    * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
                    * &lt;/li &gt;
                    * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
                    * &lt;/li &gt;
                    * &lt;/ul &gt;
                    * &lt;/div&gt;  
                    * &lt;div id="default1" &gt;
                    * Movies content here
                    * &lt;/div&gt;	
                    * &lt;div id="default2" &gt;
                    * Music content here
                    * &lt;/div&gt;
                    * &lt;div id="default3" &gt;
                    * Favourites content here
                    * &lt;/div&gt; 
                    * &lt;script&gt;
                    * $(function(){
                    * $("#tab").ejmTab({renderMode:"ios7",ios7:{overflowBadge:{enabled:true,maxValue:100}}});	
                    * });
                    * &lt;/script&gt;    
                    * @example 
                    * // Get or set the ios7 overflowBadge mode maxValue API, after initialization:
                    * // Get the ios7 overflowBadge mode maxValue value  
                    * $("#tab").ejmTab("option", "ios7.overflowBadge.maxValue");   
                    * // Set the ios7 overflowBadge mode maxValue value 
                    *$("#tab").ejmTab("option", "ios7.overflowBadge.maxValue",100); 
                    * @memberof ejmTab
                    * @instance
                    */
                    maxValue: 100,
                    /**  
                    * Specifies the minimum value for overflow batch in ios7 mode.
                    * @default 100
                    * @type {number}
                    * @alias ejmTab#ios7->overflowBadge->minValue
                    * @example 
                    * // Set the ios7 mode overflowBadge minValue property in unobtrusive way.
                    * &lt;div id="tab" data-role="ejmtab" data-ej-rendermode="ios7" data-ej-ios7-overflowbadge-enabled="true" data-ej-ios7-overflowbadge-minvalue="10" &gt;
                    * &lt;ul &gt;
                    * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
                    * &lt;/li &gt;
                    * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
                    * &lt;/li &gt;
                    * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
                    * &lt;/li &gt;
                    * &lt;/ul &gt;
                    * &lt;/div&gt;  
                    * &lt;div id="default1" &gt;
                    * Movies content here
                    * &lt;/div&gt;	
                    * &lt;div id="default2" &gt;
                    * Music content here
                    * &lt;/div&gt;
                    * &lt;div id="default3" &gt;
                    * Favourites content here
                    * &lt;/div&gt;            
                    * @example 
                    * // Set ios7 mode overflowbadge minvalue on initialization. 
                    * //To set ios7 mode overflowbadge minvalue  API value 
                    * &lt;div id="tab"&gt;
                    * &lt;ul &gt;
                    * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
                    * &lt;/li &gt;
                    * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
                    * &lt;/li &gt;
                    * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
                    * &lt;/li &gt;
                    * &lt;/ul &gt;
                    * &lt;/div&gt;  
                    * &lt;div id="default1" &gt;
                    * Movies content here
                    * &lt;/div&gt;	
                    * &lt;div id="default2" &gt;
                    * Music content here
                    * &lt;/div&gt;
                    * &lt;div id="default3" &gt;
                    * Favourites content here
                    * &lt;/div&gt; 
                    * &lt;script&gt;
                    * $(function(){
                    * $("#tab").ejmTab({renderMode:"ios7",ios7:{overflowBadge:{enabled:true,minValue:10}}});	
                    * });
                    * &lt;/script&gt;    
                    * @example 
                    * // Get or set the ios7 overflowBadge mode minValue API, after initialization:
                    * // Get the ios7 overflowBadge mode minValue value  
                    * $("#tab").ejmTab("option", "ios7.overflowBadge.minValue");   
                    * // Set the ios7 overflowBadge mode minValue value 
                    *$("#tab").ejmTab("option", "ios7.overflowBadge.minValue",10); 
                    * @memberof ejmTab
                    * @instance
                    */
                    minValue: 1
                }
            },
            /**     
            * Section for android rendermode specific functionalities.                      
            * @memberof ejmTab
            * @instance
            */
            android: {
                /**  
                * Specifies class name for image to display in android mode.
                * @default ""
                * @type {string}
                * @alias ejmTab#android->imageClass
                * @example 
                * // Set the android mode imageClass property in unobtrusive way.
                * &lt;div id="tab" data-role="ejmtab" data-ej-rendermode="android"&gt;
                * &lt;ul &gt;
                * &lt;li data-ej-android-imageClass="icn-Movies" data-ej-href="#default1" data-ej-text='Movies' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-android-imageClass="icn-Music" data-ej-href="#default2" data-ej-text='Music' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-android-imageClass="icn-Favourites" data-ej-href="#default3" data-ej-text='Favourites' &gt;
                * &lt;/li &gt;
                * &lt;/ul &gt;
                * &lt;/div&gt;  
                * &lt;div id="default1" &gt;
                * Movies content here
                * &lt;/div&gt;	
                * &lt;div id="default2" &gt;
                * Music content here
                * &lt;/div&gt;
                * &lt;div id="default3" &gt;
                * Favourites content here
                * &lt;/div&gt;		                
                * @memberof ejmTab
                * @instance
                */
                "imageClass": "",
                /**  
                * Specifies whether to position the tabs in fixed or relative position in the page. See {@link Position}.
                * @default fixed
                * @type {enum}
                * @alias ejmTab#android->position
                * @example 
                * // Set the android mode position property in unobtrusive way.
                * &lt;div id="tab" data-role="ejmtab" data-ej-rendermode="android" data-ej-android-position="fixed" &gt;
                * &lt;ul &gt;
                * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
                * &lt;/li &gt;
                * &lt;/ul &gt;
                * &lt;/div&gt;  
                * &lt;div id="default1" &gt;
                * Movies content here
                * &lt;/div&gt;	
                * &lt;div id="default2" &gt;
                * Music content here
                * &lt;/div&gt;
                * &lt;div id="default3" &gt;
                * Favourites content here
                * &lt;/div&gt;        
                * @example 
                * // Set position on initialization. 
                * //To set position API value 
                * &lt;div id="tab"&gt;
                * &lt;ul &gt;
                * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
                * &lt;/li &gt;
                * &lt;/ul &gt;
                * &lt;/div&gt;  
                * &lt;div id="default1" &gt;
                * Movies content here
                * &lt;/div&gt;	
                * &lt;div id="default2" &gt;
                * Music content here
                * &lt;/div&gt;
                * &lt;div id="default3" &gt;
                * Favourites content here
                * &lt;/div&gt; 
                * &lt;script&gt;
                * $(function(){
                * $("#tab").ejmTab({renderMode:"android", android:{position: ej.mobile.Tab.Android.Position.Fixed}});	
                * });
                * &lt;/script&gt;    
                * @example 
                * // Get or set the android mode position API, after initialization:
                * // Get the android mode position value  
                * $("#tab").ejmTab("option", "android.position");   
                * // Set the android mode position value 
                *$("#tab").ejmTab("option", "android.position",  ej.mobile.Tab.Android.Position.Fixed); 
                * @memberof ejmTab
                * @instance
                */
                position: "fixed",
                /**  
                * Specifies android tab content type tab content.  
                * @default both
                * @type {enum}
                * @alias ejmTab#android->contentType
                * @example 
                * // Set the android mode contentType property in unobtrusive way.
                * &lt;div id="tab" data-role="ejmtab" data-ej-rendermode="android" data-ej-android-contenttype="text" &gt;
                * &lt;ul &gt;
                * &lt;li data-ej-href="#default1" data-ej-text='Movies' data-ej-android-imageClass="icn-Movies" &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="#default2" data-ej-text='Music' data-ej-android-imageClass="icn-Music" &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="#default3" data-ej-text='Favourites' data-ej-android-imageClass="icn-Favourites" &gt;
                * &lt;/li &gt;
                * &lt;/ul &gt;
                * &lt;/div&gt;  
                * &lt;div id="default1" &gt;
                * Movies content here
                * &lt;/div&gt;	
                * &lt;div id="default2" &gt;
                * Music content here
                * &lt;/div&gt;
                * &lt;div id="default3" &gt;
                * Favourites content here
                * &lt;/div&gt;            
                * @example 
                * // Set android mode contentType on initialization. 
                * //To android mode contentType API value 
                * &lt;div id="tab" &gt;
                * &lt;ul &gt;
                * &lt;li data-ej-href="#default1" data-ej-text='Movies' data-ej-android-imageClass="icn-Movies" &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="#default2" data-ej-text='Music' data-ej-android-imageClass="icn-Music" &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="#default3" data-ej-text='Favourites' data-ej-android-imageClass="icn-Favourites" &gt;
                * &lt;/li &gt;
                * &lt;/ul &gt;
                * &lt;/div&gt;  
                * &lt;div id="default1" &gt;
                * Movies content here
                * &lt;/div&gt;	
                * &lt;div id="default2" &gt;
                * Music content here
                * &lt;/div&gt;
                * &lt;div id="default3" &gt;
                * Favourites content here
                * &lt;/div&gt; 
                * &lt;script&gt;
                * $(function(){
                * $("#tab").ejmTab({renderMode:"android", android:{contentType:"ej.mobile.Tab.Android.ContentType.Text"}});	
                * });
                * &lt;/script&gt;  
                * @example 
                * // Get or set the android mode contentType API, after initialization:
                * // Get the android mode contentType value  
                * $("#tab").ejmTab("option", "android.ContentType");   
                * // Set the android mode contentType value 
                *$("#tab").ejmTab("option", "android.ContentType", "ej.mobile.Tab.Android.ContentType.Text"); 
                * @memberof ejmTab
                * @instance
                */
                contentType: "text"
            },
            /**     
            * Section for windows rendermode specific functionalities.                      
            * @memberof ejmTab
            * @instance
            */
            windows: {
                /**  
                * Specifies whether to prevent swiping geture or not in windows mode.
                * @default false
                * @type {boolean}
                * @alias ejmTab#windows->preventContentSwipe
                * @example 
                * // Set the windows mode preventContentSwipe property in unobtrusive way.
                * &lt;div id="tab" data-role="ejmtab" data-ej-rendermode="windows" data-ej-windows-preventcontentswipe="true" &gt;
                * &lt;ul &gt;
                * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
                * &lt;/li &gt;
                * &lt;/ul &gt;
                * &lt;/div&gt;  
                * &lt;div id="default1" &gt;
                * Movies content here
                * &lt;/div&gt;	
                * &lt;div id="default2" &gt;
                * Music content here
                * &lt;/div&gt;
                * &lt;div id="default3" &gt;
                * Favourites content here
                * &lt;/div&gt;            
                * @example 
                * // Set windows mode preventContentSwipe on initialization. 
                * //To set windows mode preventContentSwipe API value 
                * &lt;div id="tab"&gt;
                * &lt;ul &gt;
                * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
                * &lt;/li &gt;
                * &lt;/ul &gt;
                * &lt;/div&gt;  
                * &lt;div id="default1" &gt;
                * Movies content here
                * &lt;/div&gt;	
                * &lt;div id="default2" &gt;
                * Music content here
                * &lt;/div&gt;
                * &lt;div id="default3" &gt;
                * Favourites content here
                * &lt;/div&gt; 
                * &lt;script&gt;
                * $(function(){
                * $("#tab").ejmTab({renderMode:"windows", windows:{preventContentSwipe:true}});	
                * });
                * &lt;/script&gt;  
                * @example 
                * // Get or set the windows mode preventContentSwipe API, after initialization:
                * // Get the windows mode preventContentSwipe value  
                * $("#tab").ejmTab("option", "windows.preventContentSwipe");   
                * // Set the windows mode preventContentSwipe value 
                *$("#tab").ejmTab("option", "windows.preventContentSwipe", "true"); 
                * @memberof ejmTab
                * @instance
                */
                preventContentSwipe: false,
                /**  
                * Specifies whether to enable custom text for windows mode or not.
                * @default false
                * @type {boolean}
                * @alias ejmTab#windows->enableCustomText
                * @example 
                * // Set the windows mode enableCustomText property in unobtrusive way.
                * &lt;div id="tab" data-role="ejmtab" data-ej-rendermode="windows" data-ej-windows-enablecustomtext="true" &gt;
                * &lt;ul &gt;
                * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
                * &lt;/li &gt;
                * &lt;/ul &gt;
                * &lt;/div&gt;  
                * &lt;div id="default1" &gt;
                * Movies content here
                * &lt;/div&gt;	
                * &lt;div id="default2" &gt;
                * Music content here
                * &lt;/div&gt;
                * &lt;div id="default3" &gt;
                * Favourites content here
                * &lt;/div&gt;            
                * @example 
                * // Set windows mode enableCustomText on initialization. 
                * //To set windows mode enableCustomText API value 
                * &lt;div id="tab"&gt;
                * &lt;ul &gt;
                * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
                * &lt;/li &gt;
                * &lt;/ul &gt;
                * &lt;/div&gt;  
                * &lt;div id="default1" &gt;
                * Movies content here
                * &lt;/div&gt;	
                * &lt;div id="default2" &gt;
                * Music content here
                * &lt;/div&gt;
                * &lt;div id="default3" &gt;
                * Favourites content here
                * &lt;/div&gt; 
                * &lt;script&gt;
                * $(function(){
                * $("#tab").ejmTab({renderMode:"windows", windows:{enableCustomText:true}});	
                * });
                * &lt;/script&gt;  
                * @example 
                * // Get or set the windows mode enableCustomText API, after initialization:
                * // Get the windows mode enableCustomText value  
                * $("#tab").ejmTab("option", "windows.enableCustomText");   
                * // Set the windows mode enableCustomText value 
                *$("#tab").ejmTab("option", "windows.enableCustomText", "true"); 
                * @memberof ejmTab
                * @instance
                */
                "enableCustomText": false,
                /**  
                * Specifies whether to position the tabs in fixed or relative position in the page. See {@link Position}.
                * @default fixed
                * @type {enum}
                * @alias ejmTab#windows->position
                * @example 
                * // Set the windows mode position property in unobtrusive way.
                * &lt;div id="tab" data-role="ejmtab" data-ej-rendermode="windows" data-ej-windows-position="fixed" &gt;
                * &lt;ul &gt;
                * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
                * &lt;/li &gt;
                * &lt;/ul &gt;
                * &lt;/div&gt;  
                * &lt;div id="default1" &gt;
                * Movies content here
                * &lt;/div&gt;	
                * &lt;div id="default2" &gt;
                * Music content here
                * &lt;/div&gt;
                * &lt;div id="default3" &gt;
                * Favourites content here
                * &lt;/div&gt;           
                * @example 
                * // Set windows mode position on initialization. 
                * //To set windows mode position API value 
                * &lt;div id="tab"&gt;
                * &lt;ul &gt;
                * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
                * &lt;/li &gt;
                * &lt;/ul &gt;
                * &lt;/div&gt;  
                * &lt;div id="default1" &gt;
                * Movies content here
                * &lt;/div&gt;	
                * &lt;div id="default2" &gt;
                * Music content here
                * &lt;/div&gt;
                * &lt;div id="default3" &gt;
                * Favourites content here
                * &lt;/div&gt; 
                * &lt;script&gt;
                * $(function(){
                * $("#tab").ejmTab({renderMode:"windows", windows:{position: ej.mobile.Tab.Windows.Position.Fixed}});	
                * });
                * &lt;/script&gt; 
                * @example 
                * // Get or set the windows mode position API, after initialization:
                * // Get the windows mode position value  
                * $("#tab").ejmTab("option", "windows.position");   
                * // Set the windows mode position value 
                *$("#tab").ejmTab("option", "windows.position",  ej.mobile.Tab.Windows.Position.Fixed); 
                * @memberof ejmTab
                * @instance
                */
                position: ej.isMobile() ? "fixed" : "normal",
                /**  
                * Specifies whether to render based on the windowsphone's current accent color and device theme
                * @default false
                * @type {boolean}
                * @alias ejmTab#windows->renderDefault
                * @example 
                * // Set the windows mode renderDefault property in unobtrusive way.
                * &lt;div id="tab" data-role="ejmtab" data-ej-rendermode="windows" data-ej-windows-renderdefault="false" &gt;
                * &lt;ul &gt;
                * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
                * &lt;/li &gt;
                * &lt;/ul &gt;
                * &lt;/div&gt;  
                * &lt;div id="default1" &gt;
                * Movies content here
                * &lt;/div&gt;	
                * &lt;div id="default2" &gt;
                * Music content here
                * &lt;/div&gt;
                * &lt;div id="default3" &gt;
                * Favourites content here
                * &lt;/div&gt;         
                * @example 
                * // Set windows mode renderDefault on initialization. 
                * //To set windows mode renderDefault API value 
                * &lt;div id="tab"&gt;
                * &lt;ul &gt;
                * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
                * &lt;/li &gt;
                * &lt;/ul &gt;
                * &lt;/div&gt;  
                * &lt;div id="default1" &gt;
                * Movies content here
                * &lt;/div&gt;	
                * &lt;div id="default2" &gt;
                * Music content here
                * &lt;/div&gt;
                * &lt;div id="default3" &gt;
                * Favourites content here
                * &lt;/div&gt; 
                * &lt;script&gt;
                * $(function(){
                * $("#tab").ejmTab({renderMode:"windows", windows:{renderDefault:true}});	
                * });
                * &lt;/script&gt; 
                * @example 
                * // Get or set the windows mode renderDefault API, after initialization:
                * // Get the windows mode renderDefault value  
                * $("#tab").ejmTab("option", "windows.renderDefault");   
                * // Set the windows mode renderDefault value 
                *$("#tab").ejmTab("option", "windows.renderDefault", "false"); 
                * @memberof ejmTab
                * @instance
                */
                "renderDefault": false
            },
            /**     
            * Section for flat rendermode specific functionalities.                      
            * @memberof ejmTab
            * @instance
            */
            flat: {
                /**  
                * Specifies whether to position the tabs in fixed or relative position in the page. See {@link Position}.
                * @default fixed
                * @type {enum}
                * @alias ejmTab#flat->position
                * @example 
                * // Set the flat mode position property in unobtrusive way.
                * &lt;div id="tab" data-role="ejmtab" data-ej-rendermode="flat" data-ej-flat-position="fixed" &gt;
                * &lt;ul &gt;
                * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
                * &lt;/li &gt;
                * &lt;/ul &gt;
                * &lt;/div&gt;  
                * &lt;div id="default1" &gt;
                * Movies content here
                * &lt;/div&gt;	
                * &lt;div id="default2" &gt;
                * Music content here
                * &lt;/div&gt;
                * &lt;div id="default3" &gt;
                * Favourites content here
                * &lt;/div&gt;           
                * @example 
                * // Set flat mode position on initialization. 
                * //To set flat mode position API value 
                * &lt;div id="tab"&gt;
                * &lt;ul &gt;
                * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
                * &lt;/li &gt;
                * &lt;/ul &gt;
                * &lt;/div&gt;  
                * &lt;div id="default1" &gt;
                * Movies content here
                * &lt;/div&gt;	
                * &lt;div id="default2" &gt;
                * Music content here
                * &lt;/div&gt;  
                * &lt;div id="default3" &gt;
                * Favourites content here
                * &lt;/div&gt;
                * &lt;script&gt;
                * $(function(){
                * $("#tab").ejmTab({renderMode:"flat", flat:{position: ej.mobile.Tab.Flat.Fixed}});	
                * });
                * &lt;/script&gt;  
                * @example 
                * // Get or set the flat mode position API, after initialization:
                * // Get the flat mode position value  
                * $("#tab").ejmTab("option", "flat.position");   
                * // Set the flat mode position value 
                *$("#tab").ejmTab("option", "flat.position",  ej.mobile.Tab.Flat.Fixed); 
                * @memberof ejmTab
                * @instance
                */
                position: "fixed"
            },
            /**		
            * Specifies whether need to prefetch the ajax content or not
            * @default false
            * @type {boolean}
            * @example 
            * //Set the prefetchAjaxContent property in unobtrusive way.
            * &lt;div id="tab" data-role="ejmtab" data-ej-prefetchajaxcontent="true" data-ej-enableajax="true" data-ej-enablecache="true" &gt;
            * &lt;ul &gt;
            * &lt;li data-ej-href="movies.html" data-ej-text='Movies' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="music.html" data-ej-text='Music' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="favourites.html" data-ej-text='Favourites' &gt;
            * &lt;/li &gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;             
            * //Create the movies.html file with following content.
            *  Movies contents here 
            * //Create the music.html file with following content.
            *  Music contents here 
            * //Create the favourites.html file with following content.
            *  Favourites contents here
            * @example 
            * // Set prefetchAjaxContent on initialization. 
            * //To set prefetchAjaxContent API value 
            * &lt;div id="tab"&gt;
            * &lt;ul &gt;
            * &lt;li data-ej-href="movies.html" data-ej-text='Movies' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="music.html" data-ej-text='Music' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="favourites.html" data-ej-text='Favourites' &gt;
            * &lt;/li &gt;
            * &lt;/ul &gt;
            * &lt;/div&gt; 
            * &lt;script&gt;
            * $(function(){
            * $("#tab").ejmTab({enableAjax: true, enableCache: true, prefetchAjaxContent:true});	
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the prefetchAjaxContent, after initialization:<br>
            * // Get the prefetchAjaxContent API value.
            *  $("#tab").ejmTab ("option", "prefetchAjaxContent");			
            * // Set the enableCache API
            * $("#tab").ejmTab ("option", "prefetchAjaxContent", "true");            
            * @memberof ejmTab
            * @instance				
            */
            "prefetchAjaxContent": false,
            /**		
            * Event triggered after ajax contents are prefetched.
            * @event
            * @name ejmTab#prefetchContentLoaded 	               			                   
            * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
            * @param {object}  argument.model returns the tab model
            * @param {string}  argument.type returns the name of the event
            * @param {object}  argument.item returns the curent tab item
            * @param {string}  argument.content returns the ajax current content
            * @param {string}  argument.text returns the current item text
            * @param {string}  argument.url returns the current item's url
            * @param {number}  argument.index returns the current item index
            * @example             
            * &lt;div id="tab" data-role="ejmtab" data-ej-prefetchContentLoaded="onPrefetch" data-ej-prefetchajaxcontent="true" data-ej-enableajax="true" data-ej-enablecache="true" &gt;
            * &lt;ul &gt;
            * &lt;li data-ej-href="movies.html" data-ej-text='Movies' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="music.html" data-ej-text='Music' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="favourites.html" data-ej-text='Favourites' &gt;
            * &lt;/li &gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;             
            * //Create the movies.html file with following content.
            *  Movies contents here 
            *
            * //Create the music.html file with following content.
            *  Music contents here 
            *
            * //Create the favourites.html file with following content.
            *  Favourites contents here
            * &lt;script&gt; 
            * // prefetchContentLoaded event 
            * function onPrefetch(args){ //handle the event
            *}
            * &lt;/script&gt;                        
            * @example 
            * //prefetchContentLoaded event for Tab
            * &lt;div id="tab" data-role="ejmtab" &gt;
            * &lt;ul &gt;
            * &lt;li data-ej-href="movies.html" data-ej-text='Movies' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="music.html" data-ej-text='Music' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="favourites.html" data-ej-text='Favourites' &gt;
            * &lt;/li &gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;             
            * //Create the movies.html file with following content.
            *  Movies contents here 
            *
            * //Create the music.html file with following content.
            *  Music contents here 
            *
            * //Create the favourites.html file with following content.
            *  Favourites contents here            
            * &lt;script&gt; 
            * //prefetchContentLoaded event 
            * $("#tab").ejmTab({enableAjax: true, enableCache: true, prefetchAjaxContent:true},ajaxSuccess: function (args) { //handle the event 
            * }
            * });           
            * &lt;/script&gt; 
            * @memberof ejmTab
            * @instance
            */
            "prefetchContentLoaded": null,
            /**    
            * Event triggers when the load happens in the Tab
            * @event
            * @name ejmTab#load 	               
            * @param {boolean}  argument.cancel returns the cancel option value
            * @param {object}  argument.model returns the Tab model
            * @param {string}  argument.type returns the name of the event
            * @example             
            * &lt;div id="tab" data-role="ejmtab" data-ej-load="onLoad" &gt;
            * &lt;ul &gt;
            * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
            * &lt;/li &gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;  
            * &lt;div id="default1" &gt;
            * Movies content here
            * &lt;/div&gt;	
            * &lt;div id="default2" &gt;
            * Music content here
            * &lt;/div&gt;
            * &lt;div id="default3" &gt;
            * Favourites content here
            * &lt;script&gt; 
            * // complete event 
            * function onLoad(args){ //handle the event
            *}
            * &lt;/script&gt;

            * @example 
            * //open event for Tab
            * &lt;div id="tab" data-role="ejmtab"&gt;
            * &lt;ul &gt;
            * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
            * &lt;/li &gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;  
            * &lt;div id="default1" &gt;
            * Movies content here
            * &lt;/div&gt;	
            * &lt;div id="default2" &gt;
            * Music content here
            * &lt;/div&gt;
            * &lt;div id="default3" &gt;
            * Favourites content here
            * &lt;/div&gt;   
            * &lt;script&gt; 
            * //load event 
            * $("#tab").ejmTab({
            *   load: function (args) { //handle the event 
            * }
            *});           
            * &lt;/script&gt; 
            * @memberof ejmTab
            * @instance
            */
            load: null,
            /**    
            * Event triggers when the loadComplete happens in the Tab
            * @event
            * @name ejmTab#loadComplete 	               
            * @param {boolean}  argument.cancel returns the cancel option value
            * @param {object}  argument.model returns the Tab model
            * @param {string}  argument.type returns the name of the event
            * @param {object}  argument.element returns the Tab element
            * @param {string}  argument.id returns the name of the id
            * @example             
            * &lt;div id="tab" data-role="ejmtab" data-ej-loadcomplete="onComplete" &gt;
            * &lt;ul &gt;
            * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
            * &lt;/li &gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;  
            * &lt;div id="default1" &gt;
            * Movies content here
            * &lt;/div&gt;	
            * &lt;div id="default2" &gt;
            * Music content here
            * &lt;/div&gt;
            * &lt;div id="default3" &gt;
            * Favourites content here
            * &lt;script&gt; 
            * // loadcomplete event 
            * function onComplete(args){ //handle the event
            *}
            * &lt;/script&gt;  
            * @example 
            * //open event for Tab
            * &lt;div id="tab" data-role="ejmtab"&gt;
            * &lt;ul &gt;
            * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
            * &lt;/li &gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;  
            * &lt;div id="default1" &gt;
            * Movies content here
            * &lt;/div&gt;	
            * &lt;div id="default2" &gt;
            * Music content here
            * &lt;/div&gt;
            * &lt;div id="default3" &gt;
            * Favourites content here
            * &lt;/div&gt;
            * &lt;script&gt; 
            * //loadComplete event 
            * $("#tab").ejmTab({
            *   loadComplete: function (args) { //handle the event 
            * }
            *});           
            * &lt;/script&gt; 
            * @memberof ejmTab
            * @instance
            */
            loadComplete: null,
            /**    
            * Event triggers when the touchStart happens in the Tab
            * @event
            * @name ejmTab#touchStart                			 
            * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
            * @param {object}  argument.model returns the Tab model
            * @param {string}  argument.type returns the name of the event
            * @param {string}  argument.text returns the text of the Tab
            * @example             
            * &lt;div id="tab" data-role="ejmtab" data-ej-touchstart="start" &gt;
            * &lt;ul &gt;
            * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
            * &lt;/li &gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;  
            * &lt;div id="default1" &gt;
            * Movies content here
            * &lt;/div&gt;	
            * &lt;div id="default2" &gt;
            * Music content here
            * &lt;/div&gt;
            * &lt;div id="default3" &gt;
            * Favourites content here
            * &lt;/div&gt;            
            * &lt;script&gt; 
            * // touchStart event 
            * function start(args){ //handle the event
            *}
            * &lt;/script&gt; 
            * @example 
            * //open event for Tab
            * &lt;div id="tab" data-role="ejmtab"&gt;
            * &lt;ul &gt;
            * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
            * &lt;/li &gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;  
            * &lt;div id="default1" &gt;
            * Movies content here
            * &lt;/div&gt;	
            * &lt;div id="default2" &gt;
            * Music content here
            * &lt;/div&gt;
            * &lt;div id="default3" &gt;
            * Favourites content here
            * &lt;/div&gt;    
            * &lt;script&gt; 
            * //touchStart event 
            * $("#tab").ejmTab({
            *   touchStart: function (args) { //handle the event 
            * }
            *});           
            * &lt;/script&gt; 
            * @memberof ejmTab
            * @instance
            */
            touchStart: null,
            /**    
            * Event triggers when the touchEnd happens in the Tab
            * @event
            * @name ejmTab#touchEnd 	               			                  
            * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
            * @param {object}  argument.model returns the Tab model
            * @param {string}  argument.type returns the name of the event
            * @param {string}  argument.text returns the text of the Tab
            * @example             
            * &lt;div id="tab" data-role="ejmtab" data-ej-touchend="end" &gt;
            * &lt;ul &gt;
            * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
            * &lt;/li &gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;  
            * &lt;div id="default1" &gt;
            * Movies content here
            * &lt;/div&gt;	
            * &lt;div id="default2" &gt;
            * Music content here
            * &lt;/div&gt;
            * &lt;div id="default3" &gt;
            * Favourites content here
            * &lt;/div&gt;            
            * &lt;script&gt; 
            * // touchEnd event 
            * function end(args){ //handle the event
            *}
            * &lt;/script&gt; 
            * @example             
            * &lt;div id="tab" data-role="ejmtab" &gt;
            * &lt;ul &gt;
            * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
            * &lt;/li &gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;  
            * &lt;div id="default1" &gt;
            * Movies content here
            * &lt;/div&gt;	
            * &lt;div id="default2" &gt;
            * Music content here
            * &lt;/div&gt;
            * &lt;div id="default3" &gt;
            * Favourites content here
            * &lt;/div&gt;    
            * &lt;script&gt; 
            * //touchEnd event
            * $("#tab").ejmTab({
            *   touchEnd: function (args) { //handle the event 
            * }
            *});           
            * &lt;/script&gt; 
            * @memberof ejmTab
            * @instance
            */
            touchEnd: null,
            /**    
            * Event triggers when the ajaxBeforeLoad happens in the Tab
            * @event
            * @name ejmTab#ajaxBeforeLoad 	               			                   
            * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
            * @param {object}  argument.model returns the Tab model
            * @param {string}  argument.type returns the name of the event
            * @param {string}  argument.item returns the ajax element.
            * @param {string}  argument.content returns the ajax current content.     
            * @example             
            * &lt;div id="tab" data-role="ejmtab" data-ej-ajaxbeforeload="beforeLoad" &gt;
            * &lt;ul &gt;
            * &lt;li data-ej-href="movies.html" data-ej-text='Movies' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="music.html" data-ej-text='Music' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="favourites.html" data-ej-text='Favourites' &gt;
            * &lt;/li &gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;             
            * //Create the movies.html file with following content.
            *  Movies contents here 
            *
            * //Create the music.html file with following content.
            *  Music contents here 
            *
            * //Create the favourites.html file with following content.
            *  Favourites contents here
            * &lt;script&gt; 
            * // ajaxbeforeload event 
            * function beforeLoad(args){ //handle the event
            *}
            * &lt;/script&gt;
            * @example 
            * //open event for Tab
            * &lt;div id="tab" data-role="ejmtab" &gt;
            * &lt;ul &gt;
            * &lt;li data-ej-href="movies.html" data-ej-text='Movies' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="music.html" data-ej-text='Music' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="favourites.html" data-ej-text='Favourites' &gt;
            * &lt;/li &gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;             
            * //Create the movies.html file with following content.
            *  Movies contents here 
            *
            * //Create the music.html file with following content.
            *  Music contents here 
            *
            * //Create the favourites.html file with following content.
            *  Favourites contents here            
            * //ajaxBeforeLoad event
            * &lt;script&gt; 
            * $("#tab").ejmTab({
            *   ajaxBeforeLoad: function (args) { //handle the event 
            * }
            *});           
            * &lt;/script&gt; 
            * @memberof ejmTab
            * @instance
            */
            ajaxBeforeLoad: null,
            /**    
            * Event triggers when the ajaxSuccess happens in the tab
            * @event
            * @name ejmTab#ajaxSuccess 	               			                   
            * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
            * @param {object}  argument.model returns the tab model
            * @param {string}  argument.type returns the name of the event
            * @param {object}  argument.item returns the curent tab item
            * @param {string}  argument.content returns the ajax current content
            * @param {string}  argument.text returns the current item text
            * @param {number}  argument.index returns the current item index
            * @example             
            * &lt;div id="tab" data-role="ejmtab" data-ej-ajaxsuccess="success" &gt;
            * &lt;ul &gt;
            * &lt;li data-ej-href="movies.html" data-ej-text='Movies' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="music.html" data-ej-text='Music' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="favourites.html" data-ej-text='Favourites' &gt;
            * &lt;/li &gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;             
            * //Create the movies.html file with following content.
            *  Movies contents here 
            *
            * //Create the music.html file with following content.
            *  Music contents here 
            *
            * //Create the favourites.html file with following content.
            *  Favourites contents here
            * &lt;script&gt; 
            * // ajaxSuccess event 
            * function success(args){ //handle the event
            *}
            * &lt;/script&gt;                        
            * @example 
            * //open event for Tab
            * &lt;div id="tab" data-role="ejmtab" &gt;
            * &lt;ul &gt;
            * &lt;li data-ej-href="movies.html" data-ej-text='Movies' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="music.html" data-ej-text='Music' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="favourites.html" data-ej-text='Favourites' &gt;
            * &lt;/li &gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;             
            * //Create the movies.html file with following content.
            *  Movies contents here 
            *
            * //Create the music.html file with following content.
            *  Music contents here 
            *
            * //Create the favourites.html file with following content.
            *  Favourites contents here            
            * &lt;script&gt; 
            * //ajaxSuccess event 
            * $("#tab").ejmTab({
            *   ajaxSuccess: function (args) { //handle the event 
            * }
            *});           
            * &lt;/script&gt; 
            * @memberof ejmTab
            * @instance
            */
            ajaxSuccess: null,
            /**    
            * Event triggers when the ajaxError happens in the tab
            * @event
            * @name ejmTab#ajaxError 	               		                 
            * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
            * @param {object}  argument.model returns the tab model
            * @param {string}  argument.type returns the name of the event			
            * @param {string}  argument.error returns the ajax error content. 
            * @param {boolean}  argument.status return the tab state		
            * @param {object}  argument.item returns the curent tab item
            * @param {string}  argument.text returns the current item text
            * @param {number}  argument.index returns the current item index
            * @example             
            * &lt;div id="tab" data-role="ejmtab" data-ej-ajaxerror="error" &gt;
            * &lt;ul &gt;
            * &lt;li data-ej-href="movies.html" data-ej-text='Movies' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="music.html" data-ej-text='Music' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="favourites.html" data-ej-text='Favourites' &gt;
            * &lt;/li &gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;             
            * //Create the movies.html file with following content.
            *  Movies contents here 
            *
            * //Create the music.html file with following content.
            *  Music contents here 
            *
            * //Create the favourites.html file with following content.
            *  Favourites contents here
            * &lt;script&gt; 
            * // ajaxError event 
            * function error(args){ //handle the event
            *}
            * &lt;/script&gt;
            * @example 
            * //open event for Tab
            * &lt;div id="tab" data-role="ejmtab" &gt;
            * &lt;ul &gt;
            * &lt;li data-ej-href="movies.html" data-ej-text='Movies' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="music.html" data-ej-text='Music' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="favourites.html" data-ej-text='Favourites' &gt;
            * &lt;/li &gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;             
            * //Create the movies.html file with following content.
            *  Movies contents here 
            *
            * //Create the music.html file with following content.
            *  Music contents here 
            *
            * //Create the favourites.html file with following content.
            *  Favourites contents here 
            * &lt;script&gt; 
            * //ajaxError event 
            * $("#tab").ejmTab({
            *   ajaxError: function (args) { //handle the event 
            * }
            * });   
            * &lt;/script&gt; 
            * @memberof ejmTab
            * @instance
            */
            ajaxError: null,
            /**    
            * Event triggers when the ajaxComplete happens in the tab.
            * @event
            * @name ejmTab#ajaxComplete 	               		                   
            * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
            * @param {object}  argument.model returns the tab model
            * @param {string}  argument.type returns the name of the event	           		
            * @example             
            * &lt;div id="tab" data-role="ejmtab" data-ej-ajaxcomplete="complete" &gt;
            * &lt;ul &gt;
            * &lt;li data-ej-href="movies.html" data-ej-text='Movies' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="music.html" data-ej-text='Music' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="favourites.html" data-ej-text='Favourites' &gt;
            * &lt;/li &gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;             
            * //Create the movies.html file with following content.
            *  Movies contents here 
            *
            * //Create the music.html file with following content.
            *  Music contents here 
            *
            * //Create the favourites.html file with following content.
            *  Favourites contents here
            * &lt;script&gt; 
            * // ajaxComplete event 
            * function complete(args){ //handle the event
            *}
            * &lt;/script&gt;
            * @example 
            * //open event for Tab
            * &lt;div id="tab" data-role="ejmtab" &gt;
            * &lt;ul &gt;
            * &lt;li data-ej-href="movies.html" data-ej-text='Movies' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="music.html" data-ej-text='Music' &gt;
            * &lt;/li &gt;
            * &lt;li data-ej-href="favourites.html" data-ej-text='Favourites' &gt;
            * &lt;/li &gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;             
            * //Create the movies.html file with following content.
            *  Movies contents here 
            *
            * //Create the music.html file with following content.
            *  Music contents here 
            *
            * //Create the favourites.html file with following content.
            *  Favourites contents here            
            * &lt;script&gt; 
            * //ajaxComplete event 
            * $("#tab").ejmTab({
            *   ajaxComplete: function (args) { //handle the event 
            * }
            *});           
            * &lt;/script&gt; 
            * @memberof ejmTab
            * @instance
            */
            ajaxComplete: null,
            /**		
            * Section for ajaxSettings specific functionalities.                      
            * @memberof ejmTab
            * @instance
            */
            ajaxSettings: {
                /**
                * Specifies the tab ajaxOptions.
                * @default ""
                * @type {JSONObject}            
                * @alias ejmTab#ajaxSettings->type
                * @example 
                * //Set the ajaxSettings property in unobtrusive way.
                * &lt;div id="tab" data-role="ejmtab" data-ej-enableAjax="true"&gt;
                * &lt;ul &gt;
                * &lt;li data-ej-href="movies.html" data-ej-text='Movies' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="music.html" data-ej-text='Music' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="favourites.html" data-ej-text='Favourites' &gt;
                * &lt;/li &gt;
                * &lt;/ul &gt;
                * &lt;/div&gt; 
                * //Create the movies.html file with following content.
                *  Movies contents here 
                *
                * //Create the music.html file with following content.
                *  Music contents here 
                *
                * //Create the favourites.html file with following content.
                *  Favourites contents here
                * // Set ajaxSettings on initialization. 
                * // To set ajaxSettings API value 
                * &lt;script&gt; 
                * $("#tab").ejmTab({ ajaxSettings: { type: 'GET',                
                *   } });			
                * &lt;/script&gt; 		
                * @example 
                * //Get or set the ajaxSettings, after initialization:<br>
                * // Get the ajaxSetttings API value.
                *  $("#tab").ejmTab ("option", "ajaxSettings");			
                * // Set the ajaxSettings API
                * $("#tab").ejmTab ("option", "ajaxSettings", { type: 'GET'});            
                * @memberof ejmTab
                * @instance				
                */
                type: 'GET',
                /**
                * Specifies the tab ajaxOptions.
                * @default false
                * @type {boolean}            
                * @alias ejmTab#ajaxSettings->cache
                * @example 
                * //Set the ajaxSettings property in unobtrusive way.
                * &lt;div id="tab" data-role="ejmtab" data-ej-enableAjax="true"&gt;
                * &lt;ul &gt;
                * &lt;li data-ej-href="movies.html" data-ej-text='Movies' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="music.html" data-ej-text='Music' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="favourites.html" data-ej-text='Favourites' &gt;
                * &lt;/li &gt;
                * &lt;/ul &gt;
                * &lt;/div&gt; 
                * //Create the movies.html file with following content.
                *  Movies contents here 
                *
                * //Create the music.html file with following content.
                *  Music contents here 
                *
                * //Create the favourites.html file with following content.
                *  Favourites contents here
                * // Set ajaxSettings on initialization. 
                * // To set ajaxSettings API value 
                * &lt;script&gt; 
                * $("#tab").ejmTab({ ajaxSettings: { 
                *   cache: false,                
                *   } });			
                * &lt;/script&gt; 		
                * @example 
                * //Get or set the ajaxSettings, after initialization:<br>
                * // Get the ajaxSetttings API value.
                *  $("#tab").ejmTab ("option", "ajaxSettings");			
                * // Set the ajaxSettings API
                * $("#tab").ejmTab ("option", "ajaxSettings", { cache: false });            
                * @memberof ejmTab
                * @instance				
                */
                cache: false,
                /**
                * Specifies the tab ajaxOptions.
                * @default true
                * @type {boolean}            
                * @alias ejmTab#ajaxSettings->async
                * @example 
                * //Set the ajaxSettings property in unobtrusive way.
                * &lt;div id="tab" data-role="ejmtab" data-ej-enableAjax="true"&gt;
                * &lt;ul &gt;
                * &lt;li data-ej-href="movies.html" data-ej-text='Movies' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="music.html" data-ej-text='Music' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="favourites.html" data-ej-text='Favourites' &gt;
                * &lt;/li &gt;
                * &lt;/ul &gt;
                * &lt;/div&gt; 
                * //Create the movies.html file with following content.
                *  Movies contents here 
                *
                * //Create the music.html file with following content.
                *  Music contents here 
                *
                * //Create the favourites.html file with following content.
                *  Favourites contents here
                * // Set ajaxSettings on initialization. 
                * // To set ajaxSettings API value 
                * &lt;script&gt; 
                * $("#tab").ejmTab({ ajaxSettings: {                 
                *   async: true,                                                                
                *   } });			
                * &lt;/script&gt; 	
                * @example 
                * //Get or set the ajaxSettings, after initialization:<br>
                * // Get the ajaxSetttings API value.
                *  $("#tab").ejmTab ("option", "ajaxSettings");			
                * // Set the ajaxSettings API
                * $("#tab").ejmTab ("option", "ajaxSettings", { async: true });            
                * @memberof ejmTab
                * @instance				
                */
                async: true,
                /**
                * Specifies the tab ajaxOptions.
                * @default ""
                * @type {string}            
                * @alias ejmTab#ajaxSettings->dataType
                * @example 
                * //Set the ajaxSettings property in unobtrusive way.
                * &lt;div id="tab" data-role="ejmtab" data-ej-enableAjax="true"&gt;
                * &lt;ul &gt;
                * &lt;li data-ej-href="movies.html" data-ej-text='Movies' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="music.html" data-ej-text='Music' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="favourites.html" data-ej-text='Favourites' &gt;
                * &lt;/li &gt;
                * &lt;/ul &gt;
                * &lt;/div&gt; 
                * //Create the movies.html file with following content.
                *  Movies contents here 
                *
                * //Create the music.html file with following content.
                *  Music contents here 
                *
                * //Create the favourites.html file with following content.
                *  Favourites contents here
                * // Set ajaxSettings on initialization. 
                * // To set ajaxSettings API value 
                * &lt;script&gt; 
                * $("#tab").ejmTab({ ajaxSettings: {                                 
                *   dataType: "html",                                                
                *   } });			
                * &lt;/script&gt; 		
                * @example 
                * //Get or set the ajaxSettings, after initialization:<br>
                * // Get the ajaxSetttings API value.
                *  $("#tab").ejmTab ("option", "ajaxSettings");			
                * // Set the ajaxSettings API
                * $("#tab").ejmTab ("option", "ajaxSettings", { dataType: "html" });            
                * @memberof ejmTab
                * @instance				
                */
                dataType: "html",
                /**
                * Specifies the tab ajaxOptions.
                * @default ""
                * @type {string}            
                * @alias ejmTab#ajaxSettings->contentType
                * @example 
                * //Set the ajaxSettings property in unobtrusive way.
                * &lt;div id="tab" data-role="ejmtab" data-ej-enableAjax="true"&gt;
                * &lt;ul &gt;
                * &lt;li data-ej-href="movies.html" data-ej-text='Movies' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="music.html" data-ej-text='Music' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="favourites.html" data-ej-text='Favourites' &gt;
                * &lt;/li &gt;
                * &lt;/ul &gt;
                * &lt;/div&gt; 
                * //Create the movies.html file with following content.
                *  Movies contents here 
                *
                * //Create the music.html file with following content.
                *  Music contents here 
                *
                * //Create the favourites.html file with following content.
                *  Favourites contents here
                * // Set ajaxSettings on initialization. 
                * // To set ajaxSettings API value 
                * &lt;script&gt; 
                * $("#tab").ejmTab({ ajaxSettings: { 
                *   contentType: "html",                                
                *   } });			
                * &lt;/script&gt; 		
                * @example 
                * //Get or set the ajaxSettings, after initialization:<br>
                * // Get the ajaxSetttings API value.
                *  $("#tab").ejmTab ("option", "ajaxSettings");			
                * // Set the ajaxSettings API
                * $("#tab").ejmTab ("option", "ajaxSettings", { contentType: "html" });            
                * @memberof ejmTab
                * @instance				
                */
                contentType: "html",
                /**
                * Specifies the tab ajaxOptions.
                * @default ""
                * @type {string}            
                * @alias ejmTab#ajaxSettings->url
                * @example 
                * //Set the ajaxSettings property in unobtrusive way.
                * &lt;div id="tab" data-role="ejmtab" data-ej-enableAjax="true"&gt;
                * &lt;ul &gt;
                * &lt;li data-ej-href="movies.html" data-ej-text='Movies' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="music.html" data-ej-text='Music' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="favourites.html" data-ej-text='Favourites' &gt;
                * &lt;/li &gt;
                * &lt;/ul &gt;
                * &lt;/div&gt; 
                * //Create the movies.html file with following content.
                *  Movies contents here 
                *
                * //Create the music.html file with following content.
                *  Music contents here 
                *
                * //Create the favourites.html file with following content.
                *  Favourites contents here
                * // Set ajaxSettings on initialization. 
                * // To set ajaxSettings API value 
                * &lt;script&gt; 
                * $("#tab").ejmTab({ ajaxSettings: { 
                *   url: "",                
                *   } });			
                * &lt;/script&gt; 		
                * @example 
                * //Get or set the ajaxSettings, after initialization:<br>
                * // Get the ajaxSetttings API value.
                *  $("#tab").ejmTab ("option", "ajaxSettings");			
                * // Set the ajaxSettings API
                * $("#tab").ejmTab ("option", "ajaxSettings", { url: "" });            
                * @memberof ejmTab
                * @instance				
                */
                url: "",
                /**
                * Specifies the tab ajaxOptions.
                * @default ""
                * @type {JSONObject}            
                * @alias ejmTab#ajaxSettings->data
                * @example 
                * //Set the ajaxSettings property in unobtrusive way.
                * &lt;div id="tab" data-role="ejmtab" data-ej-enableAjax="true"&gt;
                * &lt;ul &gt;
                * &lt;li data-ej-href="movies.html" data-ej-text='Movies' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="music.html" data-ej-text='Music' &gt;
                * &lt;/li &gt;
                * &lt;li data-ej-href="favourites.html" data-ej-text='Favourites' &gt;
                * &lt;/li &gt;
                * &lt;/ul &gt;
                * &lt;/div&gt; 
                * //Create the movies.html file with following content.
                *  Movies contents here 
                *
                * //Create the music.html file with following content.
                *  Music contents here 
                *
                * //Create the favourites.html file with following content.
                *  Favourites contents here
                * // Set ajaxSettings on initialization. 
                * // To set ajaxSettings API value 
                * &lt;script&gt; 
                * $("#tab").ejmTab({ ajaxSettings: { 
                *   data: {}
                *   } });			
                * &lt;/script&gt; 		
                * @example 
                * //Get or set the ajaxSettings, after initialization:<br>
                * // Get the ajaxSetttings API value.
                *  $("#tab").ejmTab ("option", "ajaxSettings");			
                * // Set the ajaxSettings API
                * $("#tab").ejmTab ("option", "ajaxSettings", {data: {}});            
                * @memberof ejmTab
                * @instance				
                */
                data: {}
            },
            items: []
        },
        observables: ["selectedItemIndex"],
        selectedItemIndex: ej.util.valueFunction("selectedItemIndex"),
        //Datatypes of model variables
        dataTypes: {
            android: { "position": "enum" },
            windows: { "position": "enum" },
            flat: { "position": "enum" },
            renderMode: "enum",
            theme: "enum",
            enablePersistence: "boolean"
        },
        //Constructor function
        /**
        * Create the Tab widget
        * @private
        */
        _init: function () {
            this._renderControl();
            this._wireEvents();
        },
        //Before loading the tab
        /**
        * Before loading the tab
        * @private
        */
        _load: function () {
            ej.setRenderMode(this);
            ej.setTheme(this);
            this._touchStart = this.model.touchStart;
            this._touchEnd = this.model.touchEnd;
            if (this.model.renderMode == "windows" && ej.isMobile() && this.model.windows.renderDefault)
                this.model.theme = "default";
            this._hasMoreItem = false;
            this._storedContent = [];
            this._orgEle = this.element.clone();
            this._index = 0;
            this._length = (this.model.items.length) ? this.model.items.length : this.element.find('>ul >li').length;
            this._x = 0;
            this._y = 0;
            this._preventEndAfterMove = false;
            this.model.id = this.element[0].id;
            if (this.selectedItemIndex() < 0)
                this.selectedItemIndex((this.selectedItemIndex(0)));
            if (this.model.load)
                this._trigger("load");
        },
        //To render the Tab control
        /**
        * To render the Tab control
        * @private
        */
        _renderControl: function () {
            this._load();
            this.element.addClass("e-m-" + this.model.renderMode + " e-m-" + this.model.theme).addClass(!ej.isMobile() ? "e-m-tablet" : "e-m-mobile");
            var proxy = this;
            this.t_container = ej.buildTag("div.e-m-tab-container");
            if (!this.model.items.length) {
                this._liItems = this.element.find("li");
                for (i = 0; i < this._liItems.length; i++) {
                    var item = {};
                    item.ios7 = { imageclass: undefined };
                    item.android = { imageclass: undefined };
                    item.badge = { enabled: undefined, value: undefined, maxvalue: undefined, minvalue: undefined };
                    item.text = ej.getAttrVal($(this._liItems[i]), 'data-ej-text', undefined);
                    item.href = ej.getAttrVal($(this._liItems[i]), 'data-ej-href', undefined);
                    item.enableAjax = ej.getAttrVal($(this._liItems[i]), 'data-ej-enableajax', undefined);
                    item.ios7.imageClass = ej.getAttrVal($(this._liItems[i]), 'data-ej-ios7-imageclass', undefined);
                    item.android.imageClass = ej.getAttrVal($(this._liItems[i]), 'data-ej-android-imageclass', undefined);
                    item.badge.enabled = ej.getAttrVal($(this._liItems[i]), 'data-ej-badge-enabled', undefined);
                    item.badge.value = ej.getAttrVal($(this._liItems[i]), 'data-ej-badge-value', undefined);
                    item.badge.maxValue = ej.getAttrVal($(this._liItems[i]), 'data-ej-badge-maxvalue', undefined);
                    item.badge.minValue = ej.getAttrVal($(this._liItems[i]), 'data-ej-badge-minvalue', undefined);
                    item.touchStart = ej.getAttrVal($(this._liItems[i]), 'data-ej-touchstart', undefined);
                    item.touchEnd = ej.getAttrVal($(this._liItems[i]), 'data-ej-touchend', undefined);
                    this.model.items.push(item);
                }
            }
            else {
                var ul = ej.buildTag('ul');
                for (i = 0; i < this.model.items.length; i++) {
                    var li = ej.buildTag('li');
                    ul.append(li);
                }
                this.element.append(ul);
            }
            this._ulItems = this.element.find(">ul").addClass("e-m-tab-hdr e-m-clearall e-m-user-select");
            this._content = ej.buildTag("div.e-m-content-container");
            this._tabWrapper = ej.buildTag("div#" + this.model.id + "_wrapper.e-m-" + this.model.renderMode + " e-m-" + this.model.theme + " e-m-tab-content", this._content);
            this._tabWrapper.addClass(!ej.isMobile() ? "e-m-tablet" : "e-m-mobile");
            this.element.parent().append(this._tabWrapper);
            if (this.model.renderMode == "ios7")
                App.activePage.append(this.element);
            else {
                if (this.model[this.model.renderMode].position == "fixed")
                    App.activePage.prepend(this.element);
                this.element.addClass(this.model[this.model.renderMode].position == "normal" ? "e-m-rel" : "e-m-fixed");
            }
            this._tabLiItems = this._ulItems.find(">li");
            var proxy = this;
            $.each(proxy._tabLiItems, function (index, element) {
                var isAjax = (proxy.model.items[index].enableAjax != undefined) ? proxy.model.items[index].enableAjax : proxy.model.enableAjax;
                if (!proxy._storedContent[index] && !isAjax) {
                    if (proxy.model.items[index].href)
                        proxy._storedContent[index] = ej.getCurrentPage().find(proxy.model.items[index].href);
                    else
                        proxy._storedContent[index] = $(element).html();
                }
            });
            if (this["_" + this.model.renderMode + "Properties"])
                this["_" + this.model.renderMode + "Properties"]();
            this._tabLiItems = this._ulItems.find(">li").addClass("e-m-tabitem e-m-user-select e-m-state-default");
            this._tabLiItems.each(function (index, element) {
                proxy._renderTabItems(element, index);
                var val = (proxy.model.items[index].badge && proxy.model.items[index].badge.value) ? proxy.model.items[index].badge.value : proxy.model.badge.value,
                 maxVal = (proxy.model.items[index].badge && proxy.model.items[index].badge.maxValue) ? proxy.model.items[index].badge.maxValue : proxy.model.badge.maxValue,
                 minVal = (proxy.model.items[index].badge && proxy.model.items[index].badge.minValue) ? proxy.model.items[index].badge.value : proxy.model.badge.minValue;
                var badge = ej.buildTag("div.e-m-tab-badgediv", ej.buildTag("div.e-m-tab-badge", proxy._setBadgeValue(val, minVal, maxVal)));
                if (proxy.model.renderMode == "android")
                    badge.addClass('e-m-' + proxy.model.android.contentType.toLowerCase());
                $(element).find('.e-m-tabitem-anchor').append(badge);
                var showBadge = (proxy.model.items[index].badge && proxy.model.items[index].badge.enabled != undefined) ? proxy.model.items[index].badge.enabled : proxy.model.badge.enabled;
                if (!showBadge || val <= minVal)
                    badge.hide();
            });
            if (this._hasMoreItem) {
                var list = ej.buildTag("li.e-m-tabitem e-m-tab-more e-m-user-select e-m-state-default", "More", "", { "data-ej-ios7-imageclass": "e-m-tab-moreimg", "data-ej-text": "More" });
                list = this._renderTabItems(list, this._tabLiItems.length);
                var val = this.model.ios7.overflowBadge.value, maxVal = this.model.ios7.overflowBadge.maxValue, minVal = this.model.ios7.overflowBadge.minValue;
                var badge = ej.buildTag("div.e-m-tab-badgediv", ej.buildTag("div.e-m-tab-badge", this._setBadgeValue(val, minVal, maxVal)));
                list.append(badge);
                if (!this.model.ios7.overflowBadge.enabled || !(val >= minVal && val <= maxVal))
                    badge.hide();
                this._ulItems.append(list);
            }
            this.element.append(this.t_container.append(this._ulItems));
            var isAjax = (this.model.items[this.selectedItemIndex()].enableAjax != undefined) ? this.model.items[this.selectedItemIndex()].enableAjax : this.model.enableAjax;
            if (this.model.enableAjax || isAjax) {
                if (this.model.prefetchAjaxContent && this.model.enableCache && this.model.showAjaxPopup)
                    App.waitingPopUp.show();
                this._enableTab(this._tabLiItems[this.selectedItemIndex()], this.selectedItemIndex(), this.model.prefetchAjaxContent && this.model.enableCache ? true : false);
            }
            else
                this._setDimensions();
            if (this["_" + this.model.renderMode + "RenderTab"])
                this["_" + this.model.renderMode + "RenderTab"]();
            this.element.find("#" + this.model.id + "_header" + this.selectedItemIndex()).removeClass("e-m-state-default").addClass("e-m-state-active");
            this._liEle = this._ulItems.find(">li");
            this._anchorEle = this.element.find("a");
            this._liEle.first().addClass('e-m-firstitem');
            this._liEle.last().addClass('e-m-lastitem');
            if (this.model.renderMode != "ios7" && this.model[this.model.renderMode].position == "fixed" && !this.model.allowScrolling)
                this._tabWrapper.css("margin-top", this.element.outerHeight());
            if (this.model.loadComplete)
                this._trigger("loadComplete");
        },
        //To do iOS7 specific actions
        /**
        * To do iOS7 specific actions
        * @private
        */
        _ios7Properties: function () {
            if (ej.isMobile() && this._length > 5 || !ej.isMobile() && this._length > 6) {
                this._hasMoreItem = true;
                var i = !ej.isMobile() ? 4 : 3;
                this._listControl = ej.buildTag("div#" + this.model.id + "_list", ej.buildTag("ul"), {}, {});
                this._listControl.find('ul').append($(this._ulItems.find('>li').get(i)).nextAll());
                this._content.append(this._listControl);
                this._listControl.ejmListView({ headerTitle: "More", theme: this.model.theme, allowScrolling: true, renderMode: this.model.renderMode, windows: { renderDefault: this.model.windows.renderDefault }, allowScrolling: false });
                this._listControl.attr("id", this.model.id + "_content" + (i + 1)).addClass("e-m-state-hide e-m-tab-more");
            }
            this.element.addClass('e-m-fixed');
        },
        //To render android tab control
        /**
        * To render android tab control
        * @private
        */
        _androidRenderTab: function () {
            this._renderingScrolling();
        },
        //To render flat mode tab control
        /**
        * To render flat mode tab control
        * @private
        */
        _flatRenderTab: function () {
            this._renderingScrolling();
        },
        //To render windows mode tab control
        /**
        * To render windows mode tab control
        * @private
        */
        _windowsRenderTab: function () {
            if (!ej.isMobile())
                this._renderingScrolling();
        },
        //To render scrolling for tab header
        /**
        * To render scrolling for tab header
        * @private
        */
        _renderingScrolling: function () {
            ej._removeHidden(this.element);
            if ((this._ulItems[0].scrollWidth > window.innerWidth && this.model[this.model.renderMode].position == "fixed") || (this._ulItems[0].scrollWidth > this.element.innerWidth() && this.model[this.model.renderMode].position == "normal"))
                this._renderScrollPanel(this.model.id + "_scroll", this.model.id, true, false, false, true, false);
            ej._setHidden(this.element);
        },
        //To create image tag for ios7 and android mode tab
        /**
        * To create image tag for ios7 and android mode tab
        * @private
        */
        _createImageTag: function (element, index) {
            var imgDiv = ej.buildTag("div", "", "", { "class": "e-m-tab-image " + (this.model.items[index][this.model.renderMode].imageClass ? this.model.items[index][this.model.renderMode].imageClass : this.model[this.model.renderMode].imageClass) });
            if ($(element).hasClass('e-m-tab-more'))
                $(imgDiv).addClass('e-m-fontimage');
            return imgDiv;
        },
        //To render the tab items
        /**
        * To render the tab items
        * @private
        */
        _renderTabItems: function (element, index) {
            var linkTag = ej.buildTag("a.e-m-tabitem-anchor e-m-remove-shadow");
            var img = this.model.renderMode == "ios7" || (this.model.renderMode == "android" && this.model[this.model.renderMode].contentType != "text") ? this._createImageTag(element, index) : "";
            var text = ej.buildTag("div.e-m-tab-text e-m-user-select");
            var textVal = this.model.items[index].text ? this.model.items[index].text : 'Item';
            textVal = this.model.renderMode == "windows" && ej.isMobile() ? this.model.windows.enableCustomText ? textVal : textVal.toLowerCase() : textVal;
            this.model.renderMode != "android" || (this.model.renderMode == "android" && this.model[this.model.renderMode].contentType == "both") ? linkTag.append(img ? text.append(img).append(ej.buildTag("div.e-m-text", textVal)) : text.append(textVal)) : (linkTag.append(this.model.android.contentType == "image" ? text.append(img) : text.append(textVal)));
            if (!$(element).hasClass('e-m-tab-more')) {
                if (!ej.getBooleanVal(element, 'data-ej-enableajax', this.model.enableAjax)) {
                    var item = ej.buildTag("div.e-m-content e-m-state-hide#" + this.model.id + "_content" + index, this._storedContent[index]);
                    if (index == this.selectedItemIndex())
                        item.removeClass("e-m-state-hide").addClass("e-m-state-block");
                    this._content.append(item);
                }
            }
            $(element).attr("id", this.model.id + "_header" + index).empty().append(linkTag);
            return element;
        },
        //To render scrollpanel
        /**
        * To render scrollpanel
        * @private
        */
        _renderScrollPanel: function (id, targetid, hrscroll, verscroll, autoheight, isHeader, relative) {
            var scrollWrapper = ej.buildTag("div#" + id, "", {}, {});
            scrollWrapper.ejmScrollPanel({ enableNativeScrolling: isHeader ? false : this.model.enableNativeScrolling, theme: this.model.theme, preventDefault: false, adjustFixedPosition: (isHeader) ? false : true, renderMode: this.model.renderMode, target: targetid, showScrollbars: isHeader ? false : this.model.showScrollbars, enableHrScroll: hrscroll, enableVrScroll: verscroll, autoAdjustHeight: autoheight, isRelative: relative });
            if (isHeader)
                this._headerScroller = scrollWrapper.ejmScrollPanel("instance");
            else
                this._scroller = scrollWrapper.ejmScrollPanel("instance");
        },
        //To load the ajax content of tab
        /**
        * To load the ajax content of tab
        * @private
        */
        _loadAjaxContent: function (ele, prefetch) {
            if (this.model.showAjaxPopup && !prefetch)
                App.waitingPopUp.show();
            var proxy = this;
            var index = $(ele).index();
            var urlVal = this.model.items[index].href;
            if (!$.support.pushstate || ej.isWindowsWebView())
                urlVal = App.route.makeUrlAbsolute(urlVal, true);
            var BeforeLoad = { content: proxy._content, item: ele, index: index, text: $(ele).find('.e-m-tab-text').text(), url: proxy.model.ajaxSettings.url ? proxy.model.ajaxSettings.url : urlVal };
            if (this.model.ajaxBeforeLoad)
                this._trigger("ajaxBeforeLoad", BeforeLoad);
            var ajaxSettings = {
                cache: proxy.model.ajaxSettings.cache,
                async: proxy.model.ajaxSettings.async,
                type: proxy.model.ajaxSettings.type,
                contentType: proxy.model.ajaxSettings.contentType,
                url: ej.isWindowsWebView() ? urlVal : proxy.model.ajaxSettings.url ? proxy.model.ajaxSettings.url : urlVal,
                dataType: proxy.model.ajaxSettings.dataType,
                data: proxy.model.ajaxSettings.data,
                "successHandler": function (data) { //Ajax post success event handler 
                    var successData = { content: proxy._content, item: ele, index: $(ele).index(), text: $(ele).find('.e-m-tab-text').text(), url: proxy.model.ajaxSettings.url ? proxy.model.ajaxSettings.url : urlVal };
                    var prefetchData = { index: proxy._index, content: proxy._content.children()[proxy._index], item: proxy._liEle[proxy._index], url: proxy.model.ajaxSettings.url ? proxy.model.ajaxSettings.url : urlVal, text: $(proxy._liEle[proxy._index]).find('.e-m-tab-text').text() };
                    var currContent = $(proxy._content).find("#" + proxy.model.id + "_content" + proxy._index);
                    if (!proxy.model.enableCache || currContent.length == 0) {
                        if (currContent.length)
                            currContent.remove();
                        var content = ej.buildTag("div.e-m-content e-m-state-hide#" + proxy.model.id + "_content" + proxy._index, (/<\/?body[^>]*>/gmi).test(data) ? data.split(/<\/?body[^>]*>/gmi)[1] : data || "");
                        proxy._content.prepend(content);
                        proxy._hideContent(proxy._content, proxy._index, ele);
                        proxy._setDimensions();
                        ej.widget.init($(content));
                    }
                    if (prefetch) {
                        if ($(ele).index() != proxy.selectedItemIndex()) {
                            var content = ej.buildTag("div.e-m-content e-m-state-hide#" + proxy.model.id + "_content" + $(ele).index(), (/<\/?body[^>]*>/gmi).test(data) ? data.split(/<\/?body[^>]*>/gmi)[1] : data || "");
                            proxy._content.append(content);
                            proxy._setDimensions();
                            ej.widget.init($(content));
                        }
                        if (!proxy._ajaxCurrentEle)
                            proxy._ajaxCurrentEle = proxy._tabLiItems.first();
                        else
                            proxy._ajaxCurrentEle = proxy._ajaxCurrentEle.next();
                        if (proxy._ajaxCurrentEle.length)
                            proxy._loadAjaxContent(proxy._ajaxCurrentEle, true);
                        else {
                            if (proxy.model.showAjaxPopup)
                                App.waitingPopUp.hide();
                            if (proxy.model.prefetchContentLoaded)
                                proxy._trigger("prefetchContentLoaded", prefetchData);
                        }
                    }
                    if (proxy.model.ajaxSuccess)
                        proxy._trigger("ajaxSuccess", successData);
                },
                "errorHandler": function (xhr, textStatus, errorThrown) {
                    var errorData = { "xhr": xhr, "textStatus": textStatus, "errorThrown": errorThrown, item: ele, index: $(ele).index(), text: $(ele).find('.e-m-tab-text').text(), url: proxy.model.ajaxSettings.url ? proxy.model.ajaxSettings.url : urlVal };
                    if (proxy.model.ajaxError)
                        proxy._trigger("ajaxError", errorData);
                },
                "completeHandler": function (data) {
                    if (proxy.model.showAjaxPopup && !prefetch)
                        App.waitingPopUp.hide();
                    var CompleteData = { content: proxy._content, item: ele, index: $(ele).index(), text: $(ele).find('.e-m-tab-text').text(), url: proxy.model.ajaxSettings.url ? proxy.model.ajaxSettings.url : urlVal };
                    if (proxy.model.ajaxComplete)
                        proxy._trigger("ajaxComplete", CompleteData);
                }
            };
            ej.sendAjaxRequest(ajaxSettings);
        },
        //To hide tab content
        /**
        * To hide tab content
        * @private
        */
        _hideContent: function (ele, index, current) {
            if (current && $(current).hasClass("e-m-tab-more") && this.model.allowScrolling)
                this._scroller.disable();
            else if (this.model.allowScrolling && this._scroller)
                this._scroller.enable();
            var prev = ele.find(".e-m-state-block");
            var curr = ele.find("#" + this.model.id + "_content" + index).removeClass("e-m-state-hide").addClass("e-m-state-block");
            if (this._scroller) {
                prev.attr("scrollX", this._scroller.getScrollPosition().x).attr("scrollY", this._scroller.getScrollPosition().y)
                if (curr.attr("scrollX") && curr.attr("scrollY"))
                    this._scroller.scrollTo(parseInt(curr.attr("scrollX")), parseInt(curr.attr("scrollY")));
                else
                    this._scroller.scrollTo(0, 0);
            }
            if ((prev.length > 0 && curr.length > 0) && (prev[0].id != curr[0].id || ej.getBooleanVal(current, 'data-ej-enableajax', this.model.enableAjax) && !this.model.enableCache && !prev.hasClass("e-m-tab-more"))) {
                if (this.model.renderMode != "windows") {
                    prev.removeClass("e-m-state-block").addClass("e-m-state-hide");
                    if (!this.model.enableCache && ej.getBooleanVal(prev, 'data-ej-enableajax', this.model.enableAjax) && !prev.hasClass("e-m-tab-more"))
                        prev.remove();
                }
                else if (this._content.children().length > 1) {
                    if (this._length > 1) {
                        var proxy = this;
                        ej._slideOutWithoutDuration(curr[0], this._reverse);
                        setTimeout(function () {
                            var loadAjax = proxy.model.items[$(prev).index()].enableAjax ? proxy.model.items[$(prev).index()].enableAjax : proxy.model.enableAjax;
                            if (!$.support.hasTransition) {
                                proxy._hide(prev, proxy, loadAjax);
                                proxy._blockContent(curr, proxy);
                            }
                            proxy._addHideClassDelegate = $.proxy(proxy._addHideClassHandler, { "prevEle": $(prev), "object": proxy, "loadAjax": loadAjax, "delegate": proxy._addHideClassDelegate });
                            prev.bind(ej.transitionEndEvent(), proxy._addHideClassDelegate);
                            ej._slideInWithDuration(prev[0], proxy._reverse);
                            proxy._addBlockClassDelegate = $.proxy(proxy._addBlockClassHandler, { "ele": $(current), "currEle": $(curr), "object": proxy, "delegate": proxy._addBlockClassDelegate });
                            curr.bind(ej.transitionEndEvent(), proxy._addBlockClassDelegate);
                            ej._slide(curr[0], proxy._reverse);
                        });

                    }
                    else
                        prev.remove();
                }
                if (this._scroller) {
                    this._content.css('height', 'auto');
                    this._scroller.refresh();
                }
            }
        },
        //To set the height for the scrolling content
        /**
        * To set the height for the scrolling content
        * @private
        */
        _setDimensions: function () {
            if (this.model.allowScrolling) {
                if (!this._scroller)
                    this._renderScrollPanel(this.model.id + "_contentscroll", this.model.id + "_wrapper", false, true, true);
            } else {
                this._content.children().height(window.innerHeight - this.element.outerHeight());
                var hgt = $(this._content.children()).outerHeight();
                this._content.css('height', $(this._content.find('.e-m-state-block'))[0].scrollHeight);
                if (this._content.find("#" + this.model.id + "_content" + this._index).length > 0)
                    this._content.css('height', $(this._content.find("#" + this.model.id + "_content" + this._index))[0].scrollHeight);
            }
        },
        //To scroll the header
        /**
        * To scroll the header
        * @private
        */
        _scrollHeader: function (currentTab) {
            if (this._headerScroller) {
                var $cTab = $(currentTab), cTabOffLeft = $cTab.offset().left, cTabWidth = $cTab.outerWidth(), chkWidth = window.innerWidth;
                if (this.model[this.model.renderMode].position == "normal") {
                    cTabOffLeft = cTabOffLeft - this.element.offset().left;
                    chkWidth = this.element.outerWidth();
                }
                if (cTabOffLeft > 0 && (cTabOffLeft + cTabWidth) > chkWidth)
                    this._headerScroller.scrollTo((this._tabLiItems.index($cTab) == this._tabLiItems.length - 1 ? this._headerScroller._maxScrollX : this._headerScroller._x - cTabWidth), 0, 300);
                else if (cTabOffLeft < 0)
                    this._headerScroller.scrollTo((this._tabLiItems.index($cTab) == 0 ? 0 : this._headerScroller._x + cTabWidth), 0, 300);
            }
        },
        //Android specific actions on touch end
        /**
        * Android specific actions on touch end
        * @private
        */
        _androidTouchEnd: function (currentTab) {
            $(this._currentTab).removeClass("e-m-pressed");
            this._scrollHeader(currentTab);
        },
        //Windows specific actions on touch end
        /**
        * Windows specific actions on touch end
        * @private
        */
        _windowsTouchEnd: function (currentTab) {
            if (!ej.isMobile())
                this._scrollHeader(currentTab);
            else {
                $('.e-m-tabitem.e-m-state-active').removeClass('e-m-state-active').addClass('e-m-state-default');
                $(currentTab).removeClass('e-m-state-default').addClass('e-m-state-active');
                var proxy = this;
                setTimeout(function () {
                    var animate = 0, prevItems = $(currentTab);
                    if (!proxy._cloned) {
                        prevItems = $(currentTab).prevAll();
                        prevItems.each(function (index, element) {
                            animate = animate + $(element).outerWidth();
                        });
                    }
                    if (!$.support.hasTransition)
                        proxy._appendElement(prevItems, proxy.element, proxy, $(currentTab), proxy._cloned);
                    else {
                        ej._transitionTime(100, proxy._ulItems[0]);
                        proxy._appendPrevEleDelegate = $.proxy(proxy._appendPrevEleHandler, { "proxy": proxy, "ele": prevItems, "currentTab": $(currentTab), "ulItems": proxy._ulItems, "tab": proxy.element, "cloned": proxy._cloned, "delegate": proxy._appendPrevEleDelegate });
                        proxy._ulItems.bind(ej.transitionEndEvent(), proxy._appendPrevEleDelegate).css('-' + ej.browser() + '-transform', "translateX(" + (proxy._reverse ? animate : -(animate)) + "px)");
                    }
                    proxy._cloned = false;
                });
            }
        },
        //Argmenets for tabitem touch events
        /**
        * Argmenets for tabitem touch events
        * @private
        */
        _eventArgs: function (currentTab) {
            return { item: $(currentTab), text: $(currentTab).find('.e-m-tab-text').text(), index: $(currentTab).index() };
        },
        //Touch Start event handler for tab item
        /**
        * Touch Start event handler for tab item
        * @private
        */
        _onTouchStartHandler: function (evt) {
            if (!this._isInTransition) {
                this._currentTab = evt.currentTarget;
                this.isMoved = false;
                this._preventEndAfterMove = false;
                this._isHeader = true;
                this._index = $(this._currentTab)[0].id.split(this.model.id + "_header")[1];
                if (this.model.renderMode == "android")
                    $(this._currentTab).addClass("e-m-pressed");
                this.model.touchStart = this.model.items[this._index].touchStart ? this.model.items[this._index].touchStart : this._touchStart;
                if (this.model.touchStart)
                    this._trigger("touchStart", this._eventArgs(this._currentTab));
                ej.listenEvents([this._liEle, this._liEle, this._liEle],
                           [ej.moveEvent(), ej.endEvent(), ej.cancelEvent()],
                           [this._touchMoveDelegate, this._touchEndDelegate, this._touchCancelDelegate]);
            }
        },
        //Touch Move event handler for tab item
        /**
        * Touch Move event handler for tab item
        * @private
        */
        _onTouchMoveHandler: function (evt) {
            if (this.model.renderMode != "windows" || (this.model.renderMode == "windows" && ej.isMobile()))
                this.isMoved = true;
            if (this.model.renderMode == "android")
                $(this._currentTab).removeClass("e-m-pressed");
        },
        //Touch End event handler for tab item
        /**
        * Touch End event handler for tab item
        * @private
        */
        _onTouchEndHandler: function (evt) {
            if ((!this._preventEndAfterMove && !this.isMoved || ej.isWindows()) && this.element.find('.e-m-state-active').index() != $(evt.currentTarget).index()) {
                this._reverse = false;
                var index = (parseInt(this._index) - 1 < 0 ? this._length - 1 : parseInt(this._index) - 1).toString();
                if (this._tabWrapper.find("#" + this.model.id + "_content" + index).length > 0)
                    this._tabWrapper.find("#" + this.model.id + "_content" + index)[0].style[ej.transform] = "";
                this._enableTab(this._currentTab, this._index);
                this.model.touchEnd = this.model.items[this._index].touchEnd ? this.model.items[this._index].touchEnd : this._touchEnd;
                if (this.model.touchEnd)
                    this._trigger("touchEnd", this._eventArgs(this._currentTab));
            }
            this.isMoved = false;
            ej.listenEvents([this._liEle, this._liEle, this._liEle],
                           [ej.moveEvent(), ej.endEvent(), ej.cancelEvent()],
                           [this._touchMoveDelegate, this._touchEndDelegate, this._touchCancelDelegate], true);
        },
        //To enable the tab and the content
        /**
        * To enable the tab and the content
        * @private
        */
        _enableTab: function (current, index, prefetch) {
            this._index = index;
            this.selectedItemIndex(index);
            //Updating the header of the tab item
            if (this._length > 1) {
                if (this["_" + this.model.renderMode + "TouchEnd"])
                    this["_" + this.model.renderMode + "TouchEnd"](current);
                if (this.model.renderMode != "windows" || (this.model.renderMode == "windows" && !ej.isMobile())) {
                    this.element.find('.e-m-state-active').removeClass("e-m-state-active").addClass("e-m-state-default");
                    $(current).removeClass("e-m-state-default").addClass("e-m-state-active");
                }
            }
            //Updating the content of the tab item
            var loadAjax = (this.model.items[index].enableAjax != undefined) ? this.model.items[index].enableAjax : this.model.enableAjax;
            if ((loadAjax && this.model.enableCache && $(this._tabWrapper.find("#" + this.model.id + "_content" + index)).length > 0 && $(this._tabWrapper.find("#" + this.model.id + "_content" + index)).hasClass("e-m-state-hide")) || (!loadAjax && $(this._tabWrapper.find("#" + this.model.id + "_content" + index)).hasClass("e-m-state-hide")) || $(current).hasClass("e-m-tab-more"))
                this._hideContent(this._tabWrapper, index, current);

            else if (loadAjax)
                this._loadAjaxContent(current, prefetch);
        },
        /**
        * To do Scroll Start
        * @private
        */
        _onScrollStart: function (args) {
            this._scrollY = args.y;
            this._contentScroll = false;
        },
        /**
        * To do Scroll Move
        * @private
        */
        _onScrollMove: function (args) {
            this._scrollDistY = args.y - this._scrollY;
            if (Math.abs(this._scrollDistY) > 0)
                this._contentScroll = true;
        },
        /**
        * To do Scroll End
        * @private
        */
        _onScrollEnd: function (args) {
            this._contentScroll = false;
        },
        //Tab Content Touch Start handler
        /**
        * Tab Content Touch Start handler
        * @private
        */
        _onContentTouchStartHandler: function (evt) {
            if (!this._isInTransition) {
                this._isHeader = false;
                var point = evt.touches ? evt.touches[0] : evt;
                this._x = 0;
                this._y = 0;
                this._distX = 0;
                this._distY = 0;
                this._directionX = 0;
                this._directionY = 0;
                this._lockedDir = 0;
                this._moved = false;
                this._startX = 0;
                this._startY = 0;
                this._absStartX = this._x;
                this._absStartY = this._y;
                this._pointX = point.pageX;
                this._pointY = point.pageY;
                this._startTime = Date.now();
                this._endTime = 0;
                this._reverse = false;
                this._end = false;
                if ($(evt.currentTarget).hasClass('m-tab')) {
                    this._headerMove = true;
                    this._target = this._tabWrapper.find("#" + this.model.id + "_content" + this.element.find('ul .e-m-state-active')[0].id.split(this.model.id + "_header")[1])[0];
                }
                else
                    this._target = this._tabWrapper.find("#" + this.model.id + "_content" + this.element.find('ul .e-m-state-active')[0].id.split(this.model.id + "_header")[1])[0];
                ej.listenEvents([document, document], [ej.moveEvent(), ej.endEvent()], [this._contentTouchMoveDelegate, this._contentTouchEndDelegate]);
                ej._transitionTime(0, this._ulItems[0]);
                ej._transitionTime(0, this._target);
            }
        },
        //Tab Content Touch Move handler
        /**
        * Tab Content Touch Move handler
        * @private
        */
        _onContentTouchMoveHandler: function (evt) {
            if (!this._contentScroll) {
                var point = evt.touches ? evt.touches[0] : evt,
			deltaX = point.pageX - this._pointX,
			deltaY = point.pageY - this._pointY,
			timestamp = Date.now(),
			newX, newY,
			absDistX, absDistY;
                this._pointX = point.pageX;
                this._pointY = point.pageY;
                this._distX += deltaX;
                this._distY += deltaY;
                absDistX = Math.abs(this._distX);
                absDistY = Math.abs(this._distY);
                if (timestamp - this._endTime > 300 && (absDistX < 10 && absDistY < 10))
                    return;
                if (!this._lockedDir) {
                    if (absDistX > absDistY + 5) {
                        this._lockedDir = 'horizontal';
                    } else if (absDistY >= absDistX) {
                        this._lockedDir = 'vertical';
                    } else {
                        this._lockedDir = 'vertical';
                    }
                }
                if (this._lockedDir == 'horizontal') {
                    this._isInTransition = true;
                    deltaY = 0;
                    newX = this._x + deltaX;
                    newY = this._y + deltaY;
                    this._translateContent(this._target, newX, true);
                    this._moved = true;
                    var li = this._ulItems.find('>li');
                    if (newX > 0 && !this._cloned && $(li.last())[0].id != $(li.first())[0].id) {
                        var lastLi = li.last();
                        this._cloneItem = lastLi.clone();
                        this._cloneWidth = lastLi.outerWidth();
                        this._ulItems[0].style[ej.transform] = "translateX(-" + this._cloneWidth + "px)";
                        this._ulItems.prepend(this._cloneItem);
                        this._cloned = true;
                    }
                } else if (this._lockedDir == 'vertical') {
                    deltaX = 0;
                }
                if (this._headerMove)
                    this._preventEndAfterMove = true;
                if (timestamp - this._startTime > 300) {
                    this._startX = this._x;
                }

            }
        },
        //Tab Content Touch Start handler
        /**
        * Tab Content Touch Start handler
        * @private
        */
        _onContentTouchEndHandler: function (evt) {
            ej.listenEvents([document, document], [ej.moveEvent(), ej.endEvent()], [this._contentTouchMoveDelegate, this._contentTouchEndDelegate], true);
            var index = Number($(this._target)[0].id.split(this.model.id + "_content")[1]);
            var point = evt.touches ? evt.touches[0] : evt,
            	momentumX = { dist: 0, time: 0 },
			duration = ej.getTime() - this._startTime,
			newPosX = this._x,
			distX, distY, newDuration = 0;
            this._reverse = newPosX > 0 ? true : false;
            if (duration < 300) {
                momentumX = newPosX ? ej._momentum(newPosX - this._startX, duration, (this._reverse ? this._x : -this._x), App.window.width() + this._x, App.window.width()) : momentumX;
                newPosX = this._x + momentumX.dist;
            }
            if (momentumX.dist) {
                newDuration = Math.max(momentumX.time, 10);
            }
            ej._transitionTime(newDuration ? newDuration : 300, this._target);
            ej._transitionTime(newDuration ? newDuration : 300, this._ulItems[0]);
            if (newPosX < 0 && Math.abs(newPosX) > App.window.width() / 2 || (this._headerMove && -(newPosX) > $(window).width() / 3)) {
                if ($($(this._ulItems).children()).length == index + 1)
                    index = 0;
                else
                    index = index + 1;
                this._index = index;
                var ele = (this.element.find("#" + this.model.id + "_header" + index).length) ? this.element.find("#" + this.model.id + "_header" + index) : $(this.element.find("#" + this.model.id + "_header" + (index - 1) + "")).next();
                this._enableTab(ele, ele.attr('id').split(this.model.id + "_header")[1]);
            }
            else if (newPosX > 0 && Math.abs(newPosX) > App.window.width() / 2 || (this._headerMove && (newPosX) > $(window).width() / 3)) {
                var first = $(this._ulItems.find('>li')).first();
                ej.listenEvents([first, first], [ej.startEvent(), ej.endEvent()], [this._touchStartDelegate, this._touchEndDelegate]);
                this._ulItems.find('>li').last().remove();
                if (index - 1 < 0)
                    index = $($(this._ulItems).children()).length - 1;
                else
                    index = index - 1;
                var ele = (this.element.find("#" + this.model.id + "_header" + index).length) ? this.element.find("#" + this.model.id + "_header" + index) : $(this.element.find("#" + this.model.id + "_header" + (index + 1) + "")).prev();
                this._enableTab(ele, ele.attr('id').split(this.model.id + "_header")[1]);
            }
            else {
                this._translateContentDelegate = $.proxy(this._translateContentHandler, { "object": this, "ele": $(this._target), "delegate": this._translateContentDelegate });
                $(this._target).bind(ej.transitionEndEvent(), this._translateContentDelegate);
                if (this._cloned) {
                    $(this._ulItems.find('>li')).first().remove();
                    ej._transitionTime(0, this._ulItems[0]);
                    this._cloned = false;
                    this._translateContent(this._target, 0);
                }
                else
                    this._translateContent(this._target, 0);
            }

        },
        //To add transition style to the target
        /**
        * To add transition style to the target
        * @private
        */
        _translateContent: function (ele, x) {
            var proxy = this;
            var x1 = x;
            if (this._cloned)
                x1 = parseInt(x) / 3 - this._cloneWidth;
            else
                x1 = parseInt(x) / 3;
            if (!this._cloned && -x1 > this._ulItems.find(".e-m-state-active").outerWidth()) {
                x1 = -this._ulItems.find(".e-m-state-active").outerWidth();
            }
            this._ulItems[0].style[ej.transform] = "translateX(" + x1 + "px)";
            ele.style[ej.transform] = "translateX(" + x + "px)";
            this._x = x;
        },
        _translateContentHandler: function () {
            this.object._isInTransition = false;
            this.ele.unbind(ej.transitionEndEvent(), this.delegate);
        },
        //Handler to show the content with transition
        /**
        * Handler to show the content with transition
        * @private
        */
        _addBlockClassHandler: function () {
            this.object._isInTransition = false;
            if (!this.object._isHeader && this.object.model.touchEnd)
                this.object._trigger("touchEnd", this.object._eventArgs(this.ele));
            this.object._blockContent(this.currEle, this.object, this.delegate);

        },
        /**
        * To do block Content
        * @private
        */
        _blockContent: function (currEle, obj, delegate) {
            currEle.removeClass("e-m-state-hide").addClass("e-m-state-block").unbind(ej.transitionEndEvent(), delegate);
            if (obj._scroller)
                obj._scroller.refresh();
        },
        //Handler to hide the content with transition
        /**
        * Handler to hide the content with transition
        * @private
        */
        _addHideClassHandler: function () {
            this.object._isInTransition = false;
            this.object._hide(this.prevEle, this.object, this.loadAjax, this.delegate);
        },
        /**
        * To do Tab Hide
        * @private
        */
        _hide: function (prev, obj, loadAjax, delegate) {
            prev.removeClass("e-m-state-block").addClass("e-m-state-hide").unbind(ej.transitionEndEvent(), delegate);
            if (!obj.model.enableCache && loadAjax)
                prev.remove();
            if (obj._scroller)
                obj._scroller.refresh();
        },
        //Handler to append prev elements to the last in the header for Windows mode
        /**
        * Handler to append prev elements to the last in the header for Windows mode
        * @private
        */
        _appendPrevEleHandler: function (evt) {
            this.proxy._isInTransition = false;
            this.proxy._appendElement(this.ele, this.tab, this.proxy, this.currentTab, this.cloned, this.delegate);
        },
        /**
        * Handler to append elements to the last in the header 
        * @private
        */
        _appendElement: function (ele, tab, obj, currentTab, cloned, delegate) {
            ej._transitionTime(0, obj._ulItems[0]);
            ele.parent().css('-' + ej.browser() + "-transform", "translateX(0)");
            if (cloned)
                ele.parent().prepend(ele);
            else
                ele.parent().append(ele.toArray().reverse());
            obj._ulItems.unbind(ej.transitionEndEvent(), delegate);
        },
        //Orientation change event handler
        /**
        * Orientation change event handler 
        * @private
        */
        _changeHandler: function (evt) {
            var proxy = this;
            setTimeout(function () {
                proxy._setDimensions();
            }, 250);
        },
        //Anchor tag click handler
        /**
        * Anchor tag click handler
        * @private
        */
        _anchorClickHandler: function (e) {
            e.preventDefault();
        },
        //To create delegates for event handling
        /**
        * To create delegates for event handling
        * @private
        */
        _createDelegates: function () {
            this._anchorClickDelegate = $.proxy(this._anchorClickHandler, this);
            this._touchStartDelegate = $.proxy(this._onTouchStartHandler, this);
            this._touchMoveDelegate = $.proxy(this._onTouchMoveHandler, this);
            this._touchEndDelegate = $.proxy(this._onTouchEndHandler, this);
            this._touchCancelDelegate = $.proxy(this._onTouchEndHandler, this);
            this._changeDelegate = $.proxy(this._changeHandler, this);
            if (this.model.renderMode == "windows" && ej.isMobile() && this._length > 1) {
                this._contentTouchStartDelegate = $.proxy(this._onContentTouchStartHandler, this);
                this._contentTouchMoveDelegate = $.proxy(this._onContentTouchMoveHandler, this);
                this._contentTouchEndDelegate = $.proxy(this._onContentTouchEndHandler, this);
            }
        },
        //To wire events for the tab
        /**
        * To wire events for the tab
        * @private
        */
        _wireEvents: function (remove) {
            this._createDelegates();
            var eventType = remove ? "unbind" : "bind";
            ej.listenEvents([this._liEle, this._anchorEle, this._anchorEle],
                           [ej.startEvent(), ej.tapEvent(), ej.tapHoldEvent()],
                           [this._touchStartDelegate, this._anchorClickDelegate, this._anchorClickDelegate], remove);
            if (this.model.renderMode == "windows" && ej.isMobile() && this._length > 1) {
                if (!this.model.windows.preventContentSwipe)
                    ej.listenEvents([this._tabWrapper], [ej.startEvent()], [this._contentTouchStartDelegate]);
                ej.listenEvents([this.element], [ej.startEvent()], [this._contentTouchStartDelegate]);
            }
            $(window)[eventType](!ej.isTouchDevice() ? "resize" : "orientationchange", this._changeDelegate);
        },
        //To set the model values
        /**
        * To configure the properties at runtime using SetModel		
        * @private
        */
        _setModel: function (options) {
            var refresh = false;
            for (var prop in options) {
                var setModel = "_set" + prop.charAt(0).toUpperCase() + prop.slice(1);
                if (this[setModel])
                    this[setModel](options[prop]);
                else
                    refresh = true;
            }
            if (refresh)
                this._refresh();
        },
        //To change the Theme property
        /**
        * To configure the Theme properties at runtime using SetModel		
        * @private
        */
        _setTheme: function (value) {
            if (value) {
                this.model.theme = value;
                this.element.removeClass("e-m-dark e-m-light e-m-default").addClass("e-m-" + this.model.theme);
                this._tabWrapper.removeClass("e-m-dark e-m-light e-m-default").addClass("e-m-" + this.model.theme);
                if (this._listControl)
                    this._listControl.ejmListView('model.theme', this.model.theme);
            }
        },
        //To check the element is disabled
        /**
        * Section for to check the element is disabled.	
        * @private
        */
        _isEnable: function (item) {
            item = (this.model.renderMode == "windows" && ej.isMobile()) ? $(item).find('.e-m-tabitem-anchor') : item;
            return item.hasClass('e-m-state-disabled') ? false : true;
        },

        //To refresh the control
        /**
        * To refresh Tab control		
        * @private
        */
        _refresh: function () {
            this._destroy();
            this.element.addClass("e-m-tab");
            this._renderControl();
            this._wireEvents();
        },
        //To clear the element
        /**
        * To clear the Tab element
        * @private
        */
        _clearElement: function () {
            this.element.removeAttr("class");
            this.element.html(this._orgEle.html());
            this._tabWrapper.remove();
            var proxy = this;
            $.each(this._storedContent, function (index, element) {
                ej.getCurrentPage().append(element);
            });
        },
        // all events bound using this._on will be unbind automatically
        /**
        * all events bound using this._on will be unbind automatically
        * @private
        */
        _destroy: function () {
            this._wireEvents(true);
            this._clearElement();
        },

        /*---------------Public Methods---------------*/
        //To show the badge		
        /**
        * To show the tab's badge.
        * @return jQuery       
        * @example 
        * &lt;div id="tab" data-role="ejmtab" &gt;
        * &lt;ul &gt;
        * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
        * &lt;/li &gt;
        * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
        * &lt;/li &gt;
        * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
        * &lt;/li &gt;
        * &lt;/ul &gt;
        * &lt;/div&gt;  
        * &lt;div id="default1" &gt;
        * Movies content here
        * &lt;/div&gt;	
        * &lt;div id="default2" &gt;
        * Music content here
        * &lt;/div&gt;
        * &lt;div id="default3" &gt;
        * Favourites content here
        * &lt;/div&gt;  
        * &lt;script&gt;
        * // To showBadge Tab Control
        * $(function(){
        * $("#tab").ejmTab("showBadge",1);	
        * });
        * &lt;/script&gt;
        * @memberof ejmTab
        * @instance
        */
        showBadge: function (index) {
            var ele = this.element.find("#" + this.model.id + "_header" + index);
            if (index >= 0 && this._isEnable(ele)) {
                var badge = ele.find('.e-m-tab-badgediv');
                if (badge.length) {
                    this.model.items[index].badge.enabled = true;
                    badge.show();
                }
            }
        },
        //To hide the tab's badge
        /**
        * To hide a badge
        * @return jQuery       
        * @example 
        * &lt;div id="tab" data-role="ejmtab" data-ej-badge-enabled="true"&gt;
        * &lt;ul &gt;
        * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
        * &lt;/li &gt;
        * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
        * &lt;/li &gt;
        * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
        * &lt;/li &gt;
        * &lt;/ul &gt;
        * &lt;/div&gt;  
        * &lt;div id="default1" &gt;
        * Movies content here
        * &lt;/div&gt;	
        * &lt;div id="default2" &gt;
        * Music content here
        * &lt;/div&gt;
        * &lt;div id="default3" &gt;
        * Favourites content here
        * &lt;/div&gt;  
        * &lt;script&gt;
        * $(function(){
        * // Call hideBadge method
        * $("#tab").ejmTab("hideBadge",1);	
        * });
        * &lt;/script&gt;
        *@memberof ejmTab
        * @instance
        */
        hideBadge: function (index) {
            var ele = this.element.find("#" + this.model.id + "_header" + index);
            if (index >= 0 && this._isEnable(ele)) {
                var badge = ele.find('.e-m-tab-badgediv');
                if (badge.length) {
                    this.model.items[index].badge.enabled = false;
                    badge.hide();
                }
            }
        },
        //To update the badge value
        /**
        * To update the badge value
        * @return jQuery       
        * @example 
        * &lt;div id="tab" data-role="ejmtab" data-ej-badge-enabled="true" &gt;
        * &lt;ul &gt;
        * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
        * &lt;/li &gt;
        * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
        * &lt;/li &gt;
        * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
        * &lt;/li &gt;
        * &lt;/ul &gt;
        * &lt;/div&gt;  
        * &lt;div id="default1" &gt;
        * Movies content here
        * &lt;/div&gt;	
        * &lt;div id="default2" &gt;
        * Music content here
        * &lt;/div&gt;
        * &lt;div id="default3" &gt;
        * Favourites content here
        * &lt;/div&gt;  
        * &lt;script&gt;
        * $(function(){
        * //Call updateBadgeValue method
        * $("#tab").ejmTab("updateBadgeValue",1,"Music Collection");	
        * });
        * &lt;/script&gt;
        *@memberof ejmTab
        * @instance
        */
        updateBadgeValue: function (index, val) {
            var ele = this.element.find("#" + this.model.id + "_header" + index);
            if (index >= 0 && this._isEnable(ele) && val != undefined) {
                var badge = ele.find('.e-m-tab-badge');
                if (badge.length) {
                    var maxVal = ele.hasClass('e-m-tab-more') ? Number(this.model.ios7.overflowBadge.maxValue) : Number(ej.getAttrVal(ele, 'data-ej-badge-maxvalue', this.model.badge.maxValue)),
                    minVal = ele.hasClass('e-m-tab-more') ? Number(this.model.ios7.overflowBadge.minValue) : Number(ej.getAttrVal(ele, 'data-ej-badge-minvalue', this.model.badge.minValue));
                    if (val)
                        val = this._setBadgeValue(val, minVal, maxVal);
                    this.model.items[index].badge.value = val;
                    badge.html(val);
                    if (!val)
                        this.hideBadge(index);
                    else
                        this.showBadge(index);
                }
            }
        },
        //To set the badge value based on the max and min value
        _setBadgeValue: function (val, minVal, maxVal) {
            return (val >= minVal && val <= maxVal ? val : (minVal > val ? minVal : maxVal + "+")).toString();
        },

        //To make the tab item to be active
        /**
        * To make the tab item to be active
        * @return jQuery       
        * @example 
        * &lt;div id="tab" data-role="ejmtab" &gt;
        * &lt;ul &gt;
        * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
        * &lt;/li &gt;
        * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
        * &lt;/li &gt;
        * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
        * &lt;/li &gt;
        * &lt;/ul &gt;
        * &lt;/div&gt;  
        * &lt;div id="default1" &gt;
        * Movies content here
        * &lt;/div&gt;	
        * &lt;div id="default2" &gt;
        * Music content here
        * &lt;/div&gt;
        * &lt;div id="default3" &gt;
        * Favourites content here
        * &lt;/div&gt;  
        * &lt;script&gt;
        * $(function(){
        * // Call selectTabItem method
        * $("#tab").ejmTab("selectItem",1);	
        * });
        * &lt;/script&gt;
        * @memberof ejmTab
        * @instance
        */
        selectItem: function (index) {
            if (index >= 0 && this._isEnable($(this._tabLiItems[index]))) {
                this.selectedItemIndex(index);
                this._currentTab = this._tabLiItems[index];
                this._index = index;
                this._onTouchEndHandler({ currentTarget: this._currentTab });
            }
        },
        //To enable the tab item
        /**
        * To enable the tab item
        * @return jQuery       
        * @example 
        * &lt;div id="tab" data-role="ejmtab" &gt;
        * &lt;ul &gt;
        * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
        * &lt;/li &gt;
        * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
        * &lt;/li &gt;
        * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
        * &lt;/li &gt;
        * &lt;/ul &gt;
        * &lt;/div&gt;  
        * &lt;div id="default1" &gt;
        * Movies content here
        * &lt;/div&gt;	
        * &lt;div id="default2" &gt;
        * Music content here
        * &lt;/div&gt;
        * &lt;div id="default3" &gt;
        * Favourites content here
        * &lt;/div&gt;  
        * &lt;script&gt;
        * $(function(){
        * // Call enableItem method
        * $("#tab").ejmTab("enableItem",1);	
        * });
        * &lt;/script&gt;
        *@memberof ejmTab
        * @instance
        */
        enableItem: function (index) {
            if (index >= 0) {
                var ele = this.element.find("#" + this.model.id + "_header" + index);
                ((this.model.renderMode == "windows" && ej.isMobile()) ? ele.children() : ele).removeClass('e-m-state-disabled');
                this.enableContent(index);
            }
        },
        //To disable the tab item
        /**
        * To disable the tab item
        * @return jQuery       
        * @example 
        * &lt;div id="tab" data-role="ejmtab" &gt;
        * &lt;ul &gt;
        * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
        * &lt;/li &gt;
        * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
        * &lt;/li &gt;
        * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
        * &lt;/li &gt;
        * &lt;/ul &gt;
        * &lt;/div&gt;  
        * &lt;div id="default1" &gt;
        * Movies content here
        * &lt;/div&gt;	
        * &lt;div id="default2" &gt;
        * Music content here
        * &lt;/div&gt;
        * &lt;div id="default3" &gt;
        * Favourites content here
        * &lt;/div&gt;  
        * &lt;script&gt;
        * $(function(){
        * // Call disableItem method
        * $("#tab").ejmTab("disableItem",1);	
        * });
        * &lt;/script&gt;
        *@memberof ejmTab
        * @instance
        */
        disableItem: function (index) {
            if (index >= 0) {
                var ele = this.element.find("#" + this.model.id + "_header" + index);
                ((this.model.renderMode == "windows" && ej.isMobile()) ? ele.children() : ele).addClass('e-m-state-disabled');
                this.disableContent(index);
            }
        },
        //To enable the tab item content
        /**
        * To enable the tab item content
        * @return jQuery       
        * @example 
        * &lt;div id="tab" data-role="ejmtab" &gt;
        * &lt;ul &gt;
        * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
        * &lt;/li &gt;
        * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
        * &lt;/li &gt;
        * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
        * &lt;/li &gt;
        * &lt;/ul &gt;
        * &lt;/div&gt;  
        * &lt;div id="default1" &gt;
        * Movies content here
        * &lt;/div&gt;	
        * &lt;div id="default2" &gt;
        * Music content here
        * &lt;/div&gt;
        * &lt;div id="default3" &gt;
        * Favourites content here
        * &lt;/div&gt;  
        * &lt;script&gt;
        * $(function(){
        * // Call enableContent method
        * $("#tab").ejmTab("enableContent",1);	
        * });
        * &lt;/script&gt;
        *@memberof ejmTab
        * @instance
        */
        enableContent: function (index) {
            var ele = $(this._tabWrapper.find('#' + this.model.id + '_content' + (index)));
            if (index >= 0)
                ((this.model.renderMode == "windows" && ej.isMobile()) ? ele.children() : ele).removeClass('e-m-state-disabled');
            else
                this._tabWrapper.removeClass('e-m-state-disabled');
        },
        //To disable the tab item content
        /**
        * To disable the tab item content
        * @return jQuery       
        * @example 
        * &lt;div id="tab" data-role="ejmtab" &gt;
        * &lt;ul &gt;
        * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
        * &lt;/li &gt;
        * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
        * &lt;/li &gt;
        * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
        * &lt;/li &gt;
        * &lt;/ul &gt;
        * &lt;/div&gt;  
        * &lt;div id="default1" &gt;
        * Movies content here
        * &lt;/div&gt;	
        * &lt;div id="default2" &gt;
        * Music content here
        * &lt;/div&gt;
        * &lt;div id="default3" &gt;
        * Favourites content here
        * &lt;/div&gt;  
        * &lt;script&gt;
        * $(function(){
        * // Call disableContent method
        * $("#tab").ejmTab("disableContent",1);	
        * });
        * &lt;/script&gt;
        *@memberof ejmTab
        * @instance
        */
        disableContent: function (index) {
            var ele = $(this._tabWrapper.find('#' + this.model.id + '_content' + (index)));
            if (index >= 0)
                ((this.model.renderMode == "windows" && ej.isMobile()) ? ele.children() : ele).addClass('e-m-state-disabled');
            else
                this._tabWrapper.addClass('e-m-state-disabled');
        },
        //To add a tab item
        /**
        * To add a tab item
        * @return jQuery       
        * @example 
        * &lt;div id="tab" data-role="ejmtab" &gt;
        * &lt;ul &gt;
        * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
        * &lt;/li &gt;
        * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
        * &lt;/li &gt;
        * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
        * &lt;/li &gt;
        * &lt;/ul &gt;
        * &lt;/div&gt;  
        * &lt;div id="default1" &gt;
        * Movies content here
        * &lt;/div&gt;	
        * &lt;div id="default2" &gt;
        * Music content here
        * &lt;/div&gt;
        * &lt;div id="default3" &gt;
        * Favourites content here
        * &lt;/div&gt;  
        * &lt;script&gt;
        * $(function(){
        * // Call addItem method
        * $("#tab").ejmTab("addItem","addTab",3);	
        * });
        * &lt;/script&gt;
        *@memberof ejmTab
        * @instance
        */
        addItem: function (tab, index) {
            if (index >= 0)
                tab.insertBefore($(this._orgEle.children().children()[index]));
            else
                this._orgEle.children().append(tab);
            this._refresh();
        },
        //To add tab item in overflow tab option
        /**
        * To add tab item in more option
        * @return jQuery       
        * @example 
        * &lt;div id="tab" data-role="ejmtab" &gt;
        * &lt;ul &gt;
        * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
        * &lt;/li &gt;
        * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
        * &lt;/li &gt;
        * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
        * &lt;/li &gt;
        * &lt;/ul &gt;
        * &lt;/div&gt;  
        * &lt;div id="default1" &gt;
        * Movies content here
        * &lt;/div&gt;	
        * &lt;div id="default2" &gt;
        * Music content here
        * &lt;/div&gt;
        * &lt;div id="default3" &gt;
        * Favourites content here
        * &lt;/div&gt;  
        * &lt;script&gt;
        * $(function(){
        * // To addOverflowItem Tab Control
        * $("#tab").ejmTab("addOverflowItem","addMoreTab",3);
        * });
        * &lt;/script&gt;
        * @memberof ejmTab
        * @instance
        */
        addOverflowItem: function (tab, index) {
            if (this._listControl && index >= 0) {
                this._className = this._listControl.attr('class');
                this._listControl.ejmListView('addItem', tab, index);
                this._listControl.addClass(this._className);
            }
        },
        //To remove tab item
        /**
        * To remove tab item
        * @return jQuery       
        * @example 
        * &lt;div id="tab" data-role="ejmtab" &gt;
        * &lt;ul &gt;
        * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
        * &lt;/li &gt;
        * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
        * &lt;/li &gt;
        * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
        * &lt;/li &gt;
        * &lt;/ul &gt;
        * &lt;/div&gt;  
        * &lt;div id="default1" &gt;
        * Movies content here
        * &lt;/div&gt;	
        * &lt;div id="default2" &gt;
        * Music content here
        * &lt;/div&gt;
        * &lt;div id="default3" &gt;
        * Favourites content here
        * &lt;/div&gt;  
        * &lt;script&gt;
        * $(function(){
        * // Call removeItem method
        * $("#tab").ejmTab("removeItem",1);	
        * });
        * &lt;/script&gt;
        *@memberof ejmTab
        * @instance
        */
        removeItem: function (index) {
            if (index >= 0) {
                $(this._tabWrapper.find('#' + this.model.id + '_content' + (index))).remove();
                this.element.find("#" + this.model.id + "_header" + index).remove();
            }
        },
        //To remove tab item in overflow option
        /**
        * To remove tab item in overflow option
        * @return jQuery       
        * @example 
        * &lt;div id="tab" data-role="ejmtab" &gt;
        * &lt;ul &gt;
        * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
        * &lt;/li &gt;
        * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
        * &lt;/li &gt;
        * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
        * &lt;/li &gt;
        * &lt;/ul &gt;
        * &lt;/div&gt;  
        * &lt;div id="default1" &gt;
        * Movies content here
        * &lt;/div&gt;	
        * &lt;div id="default2" &gt;
        * Music content here
        * &lt;/div&gt;
        * &lt;div id="default3" &gt;
        * Favourites content here
        * &lt;/div&gt;  
        * &lt;script&gt;
        * $(function(){
        * // Call removeOverflowItem method
        * $("#tab").ejmTab("removeOverflowItem",1);	
        * });
        * &lt;/script&gt;
        *@memberof ejmTab
        * @instance
        */
        removeOverflowItem: function (index) {
            if (this._listControl && index >= 0) {
                this._listControl.ejmListView('removeItem', index);
                if (!this._listControl.ejmListView('getItemsCount')) {
                    if ($(this.element.find('.e-m-tab-more.e-m-state-active')).length)
                        this.selectItem(this._index - 1);
                    this.element.find('.e-m-tab-more').remove();
                    this._content.find('.e-m-tab-more').remove();
                }
            }
        },
        //Gets the tab item count
        /**
        * To return the tab item count
        * @return jQuery       
        * @example 
        * &lt;div id="tab" data-role="ejmtab" &gt;
        * &lt;ul &gt;
        * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
        * &lt;/li &gt;
        * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
        * &lt;/li &gt;
        * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
        * &lt;/li &gt;
        * &lt;/ul &gt;
        * &lt;/div&gt;  
        * &lt;div id="default1" &gt;
        * Movies content here
        * &lt;/div&gt;	
        * &lt;div id="default2" &gt;
        * Music content here
        * &lt;/div&gt;
        * &lt;div id="default3" &gt;
        * Favourites content here
        * &lt;/div&gt;  
        * &lt;script&gt;
        * $(function(){
        * // Call getItemsCount method
        * $("#tab").ejmTab("getItemsCount");	
        * });
        * &lt;/script&gt;
        *@memberof ejmTab
        * @instance
        */
        getItemsCount: function () {
            return this._hasMoreItem ? this.element.find('.e-m-tabitem').length - 1 : this.element.find('.e-m-tabitem').length;
        },
        //Get the more tab item count
        /**
        * Get the overflow tab item count
        * @return jQuery       
        * @example 
        * &lt;div id="tab" data-role="ejmtab" &gt;
        * &lt;ul &gt;
        * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
        * &lt;/li &gt;
        * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
        * &lt;/li &gt;
        * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
        * &lt;/li &gt;
        * &lt;/ul &gt;
        * &lt;/div&gt;  
        * &lt;div id="default1" &gt;
        * Movies content here
        * &lt;/div&gt;	
        * &lt;div id="default2" &gt;
        * Music content here
        * &lt;/div&gt;
        * &lt;div id="default3" &gt;
        * Favourites content here
        * &lt;/div&gt;  
        * &lt;script&gt;
        * $(function(){
        * // Call getOverflowItemCount method
        * $("#tab").ejmTab("getOverflowItemCount");	
        * });
        * &lt;/script&gt;
        *@memberof ejmTab
        * @instance
        */
        getOverflowItemCount: function () {
            if (this._listControl)
                return this._listControl.ejmListView('getItemsCount');
        },
        //Get the active item
        /**
        * Get the current active item
        * @return jQuery       
        * @example 
        * &lt;div id="tab" data-role="ejmtab" &gt;
        * &lt;ul &gt;
        * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
        * &lt;/li &gt;
        * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
        * &lt;/li &gt;
        * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
        * &lt;/li &gt;
        * &lt;/ul &gt;
        * &lt;/div&gt;  
        * &lt;div id="default1" &gt;
        * Movies content here
        * &lt;/div&gt;	
        * &lt;div id="default2" &gt;
        * Music content here
        * &lt;/div&gt;
        * &lt;div id="default3" &gt;
        * Favourites content here
        * &lt;/div&gt;  
        * &lt;script&gt;
        * $(function(){
        * // Call getActiveItem method
        * $("#tab").ejmTab("getActiveItem");	
        * });
        * &lt;/script&gt;
        *@memberof ejmTab
        * @instance
        */
        getActiveItem: function () {
            return this.element.find('li.e-m-state-active');
        },
        //Get the active item text
        /**
        * Get the current active item text
        * @return jQuery       
        * @example 
        * &lt;div id="tab" data-role="ejmtab" &gt;
        * &lt;ul &gt;
        * &lt;li data-ej-href="#default1" data-ej-text='Movies' &gt;
        * &lt;/li &gt;
        * &lt;li data-ej-href="#default2" data-ej-text='Music' &gt;
        * &lt;/li &gt;
        * &lt;li data-ej-href="#default3" data-ej-text='Favourites' &gt;
        * &lt;/li &gt;
        * &lt;/ul &gt;
        * &lt;/div&gt;  
        * &lt;div id="default1" &gt;
        * Movies content here
        * &lt;/div&gt;	
        * &lt;div id="default2" &gt;
        * Music content here
        * &lt;/div&gt;
        * &lt;div id="default3" &gt;
        * Favourites content here
        * &lt;/div&gt;  
        * &lt;script&gt;
        * $(function(){
        * // Call getActiveItem method
        * $("#tab").ejmTab("getActiveItemText");	
        * });
        * &lt;/script&gt;
        *@memberof ejmTab
        * @instance
        */
        getActiveItemText: function () {
            return this.element.find('li.e-m-state-active .e-m-tab-text').text();
        }
        /*---------------Public Methods End---------------*/

    });
    /**
    * Enum for Position
    * @enum {string}
    * @global
    */
    ej.mobile.Tab.Position = {
        /**
        Enum for Fixed position Tab				
        */
        Fixed: "fixed",
        /**
        Enum for Normal position Tab	       	
        */
        Normal: "normal"
    };
    ej.mobile.Tab.Android = {};
    /**
    * Enum for Android tabContentType
    * @enum {string}
    * @global
    */
    ej.mobile.Tab.Android.ContentType = {
        /**
        Enum for text content type*/
        Text: "text",
        /**
        Enum for image content type*/
        Image: "image",
        /**
        Enum for displaying both text and image content type*/
        Both: "both"
    };
})(jQuery, Syncfusion);