/**
* @fileOverview Plugin to style the Html TextBox elements
* @copyright Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/
(function ($, ej, undefined) {
    /**
    * @namespace ej
    * @class ejmTextBox
    * @requires jQuery
    * @requires ej.mobile.application
    * @requires ej.core
    * @requires ej.unobtrusive
    * @requires ej.mobile.core
    * @requires ej.data
    * @requires ej.touch
    * @classdesc Custom Design for Html TextBox control.

    * @example
    * //To create the textbox 
    * &lt;input id="textbox" /&gt;<br>
    * &lt;script&gt; 
    * //Create the textbox  
    * $("#textbox").ejmTextBox(); 
    * &lt;/script&gt;
    * @example 
    * &lt;input id="textbox" data-role="ejmtextbox" /&gt;<br>

    * @example 
    * //To create the password
    * &lt;input id="password" /&gt;<br>
    * &lt;script&gt; 
    * //Create the password  
    * $("#password").ejmPassword(); 
    * &lt;/script&gt;
    * @example 
    * &lt;input id="password" data-role="ejmpassword" /&gt;<br>

    * @example 
    * //To create the maskedit
    * &lt;input id="maskedit" /&gt;<br>
    * &lt;script&gt; 
    * //Create the maskedit  
    * $("#maskedit").ejmMaskEdit(); 
    * &lt;/script&gt;
    * @example 
    * &lt;input id="maskedit" data-role="ejmmaskedit" /&gt;<br>

    * @example 
    * //To create the textarea
    * &lt;textarea id="textarea" &gt;&lt;/textarea&gt;<br>
    * &lt;script&gt; 
    * //Create the textarea  
    * $("#textarea").ejmTextArea();
    * &lt;/script&gt;
    * @example 
    * &lt;textarea id="textarea" data-role="ejmtextarea" &gt;&lt;/textarea&gt;<br>
    */
    // ejmTextBox is the plugin name 
    // "ej.mobile.TextBox" is "namespace.className" will hold functions and properties
    ej.widget({ "ejmTextBox": "ej.mobile.TextBox", "ejmPassword": "ej.mobile.Password", "ejmMaskEdit": "ej.mobile.MaskEdit", "ejmTextArea": "ej.mobile.TextArea" }, {
        _setFirst: true,
        _rootCSS: "e-m-text-input",
        validTags: ["input"],
        type: "editor",
        // default model
        defaults: {
            /**		
            * Changes the rendering mode of the TextBox, Password, Mask Edit, and Textarea. See {@link RenderMode}
            * @default auto
            * @type {enum}            
            * @example 
            * // For textbox 
            * //Set the renderMode property in unobtrusive way.
            * &lt;input id="textbox" data-role="ejmtextbox" data-ej-rendermode="auto" /&gt;<br>
            * @example 
            * // Set the renderMode on initialization. 
            * //To set the renderMode API value 
            * &lt;input id="textbox" data-role="ejmtextbox"/&gt;<br>
            * &lt;script&gt;
            * $(function () {
            * $("#textbox").ejmTextBox ({ renderMode:ej.mobile.RenderMode.Auto });	
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the  renderMode, after initialization:<br>
            * // Get the renderMode API value.	
            * &lt;script&gt;
            *  $("#textbox").ejmTextBox ("option", "renderMode");			
            * // Set the renderMode API
            * $("#textbox").ejmTextBox ("option", "renderMode", ej.mobile.RenderMode.Auto);
            * &lt;/script&gt;<br>

                
            * @example
            * // For Password 
            * //Set the renderMode property in unobtrusive way.
            * &lt;input id="password" data-role="ejmpassword"/&gt;<br>
            * @example
            * // Set the renderMode on initialization. 
            * //To set the renderMode API value 
            * &lt;input id="password" data-role="ejmpassword"/&gt;<br>
            * &lt;script&gt;
            * $(function () {
            * $("#password").ejmPassword ({ renderMode: ej.mobile.RenderMode.Auto});
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the renderMode, after initialization:<br>
            * // Get the renderMode API value.	
            * &lt;script&gt;
            *  $("#password").ejmPassword ("option", "renderMode");			
            * // Set the renderMode API
            * $("#password").ejmPassword ("option", "renderMode", ej.mobile.RenderMode.Auto); 
            * &lt;/script&gt;<br>

            * @example             
            * // For MaskEdit
            * //Set the renderMode property in unobtrusive way.
            * &lt;input id="maskedit" data-role="ejmmaskedit" data-ej-mask="+1 (999) 999-9999"/&gt;<br>
            * @example 
            * // Set the renderMode on initialization. 
            * //To set the renderMode API value 
            * &lt;input id="maskedit" data-role="ejmmaskedit" /&gt;<br>
            * &lt;script&gt;
            * $(function () {
            * $("#maskedit").ejmMaskEdit ({ renderMode:ej.mobile.RenderMode.Auto,mask:"+1 (999) 999-9999" });		
            * });
            * &lt;/script&gt;
           
            * @example 
            * //Get or set the renderMode, after initialization:<br>
            * // Get the renderMode API value.	
            * &lt;script&gt;
            *  $("#maskedit").ejmMaskEdit ("option", "renderMode");			
            * // Set the renderMode API
            * $("#maskedit").ejmMaskEdit ("option", "renderMode", ej.mobile.RenderMode.Auto);
            * &lt;/script&gt;<br>
           
            * @example    
            * // For TextArea
            * //Set the renderMode property in unobtrusive way. 
            * &lt;textarea id="textarea" data-role="ejmtextarea" &gt; &lt;/textarea&gt;<br>
            * @example 
            * // Set the renderMode on initialization. 
            * //To set the renderMode API value 
            * &lt;textarea id="textarea" data-role="ejmtextarea" &gt; &lt;/textarea&gt;<br>
            * &lt;script&gt;
            * $(function () {
            * $("#textarea").ejmTextArea ({ renderMode:ej.mobile.RenderMode.Auto });	
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the renderMode, after initialization:<br>
            * // Get the renderMode API value.		
            * &lt;script&gt;
            *  $("#textarea").ejmTextArea ("option", "renderMode");			
            * // Set the renderMode API
            * $("#textarea").ejmTextArea ("option", "renderMode", ej.mobile.RenderMode.Auto);
            * &lt;/script&gt;
            * @memberof ejmTextBox
            * @instance
            */
            renderMode: "auto",
            /**		
            * Changes the theme of the TextBox, Password, Mask Edit, and Textarea. See {@link Theme}
            * @default auto
            * @type {enum}

            * @example
            * // For TextBox  
            * //Set the theme property in unobtrusive way.
            * &lt;input id="textbox" data-role="ejmtextbox" data-ej-theme="auto" /&gt;<br>
            * @example 
            * // Set the theme on initialization. 
            * //To set the theme API value 
            * &lt;input id="textbox" data-role="ejmtextbox" /&gt;<br>
            * &lt;script&gt;
            * $(function () {
            * $("#textbox").ejmTextBox ({ theme: ej.mobile.Theme.Auto });	
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the theme, after initialization:<br>
            * // Get the theme API value.		
            * &lt;script&gt;
            *  $("#textbox").ejmTextBox ("option", "theme");			
            * // Set the theme API
            * $("#textbox").ejmTextBox ("option", "theme", ej.mobile.Theme.Auto);
            * &lt;/script&gt; <br> 
                        
            * @example 
            * // For Password
            * //Set the theme property in unobtrusive way.
            * &lt;input id="password" data-role="ejmpassword" data-ej-theme="auto" /&gt;<br>
            * @example 
            * // Set the theme on initialization. 
            * //To set the theme API value 
            * &lt;input id="password" data-role="ejmpassword"/&gt;<br>
            * &lt;script&gt;
            * $(function () {
            * $("#password").ejmPassword ({ theme: ej.mobile.Theme.Auto });	
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the theme, after initialization:<br>
            * // Get the theme API value.	
            * &lt;script&gt;
            *  $("#password").ejmPassword ("option", "theme");			
            * // Set the theme API
            * $("#password").ejmPassword ("option", "theme", ej.mobile.Theme.Auto); 
            * &lt;/script&gt; <br> 
                     
            * @example
            * // For MaskEdit 
            * //Set the theme property in unobtrusive way.
            * &lt;input id="maskedit" data-role="ejmmaskedit" data-ej-theme="auto" data-ej-mask="+1 (999) 999-9999" /&gt;<br>
            * @example 
            * // Set the theme on initialization. 
            * //To set the theme API value 
            * &lt;input id="maskedit" data-role="ejmmaskedit"/&gt;<br>
            * &lt;script&gt;
            * $(function () {
            * $("#maskedit").ejmMaskEdit ({ theme: ej.mobile.Theme.Auto,mask:"+1 (999) 999-9999"  });	
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the theme, after initialization:<br>
            * // Get the theme API value.	
            * &lt;script&gt;
            *  $("#maskedit").ejmMaskEdit ("option", "theme");			
            * // Set the theme API
            * $("#maskedit").ejmMaskEdit ("option", "theme", ej.mobile.Theme.Auto); 
            * &lt;/script&gt;<br>
            * @example 
            * // For TextArea
            * //Set the theme property in unobtrusive way.
            * &lt;textarea id="textarea" data-role="ejmtextarea" data-ej-theme="auto" &gt;&lt;/textarea&gt;<br>
            * @example 
            * // Set the theme on initialization. 
            * //To set the theme API value 
            * &lt;textarea id="textarea" data-role="ejmtextarea"&gt;&lt;/textarea&gt;<br>
            * &lt;script&gt;
            * $(function () {
            * $("#textarea").ejmTextArea ({ theme: ej.mobile.Theme.Auto });
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the textarea theme, after initialization:<br>
            * // Get the theme API value.	
            * &lt;script&gt;
            *  $("#textarea").ejmTextArea ("option", "theme");			
            * // Set the theme API
            * $("#textarea").ejmTextArea ("option", "theme", ej.mobile.Theme.Auto); 
            * &lt;/script&gt;
            * @memberof ejmTextBox
            * @instance
            */
            theme: "auto",
            /**		
            * Specifies whether to show the border on the TextBox, Password, Mask Edit, and Textarea.
            * @default true
            * @type {boolean}

            * @example
            * // For TextBox 
            * //Set the showBorder property in unobtrusive way.
            * &lt;input id="textbox" data-role="ejmtextbox" data-ej-showborder=true /&gt;<br>
            * @example 
            * // Set the showBorder on initialization. 
            * //To set the showBorder API value 
            * &lt;input id="textbox" data-role="ejmtextbox"/&gt;<br>
            * &lt;script&gt;
            * $("#textbox").ejmTextBox ({ showBorder: true });
            * &lt;/script&gt;
            * @example 
            * //Get or set the showBorder, after initialization:<br>
            * // Get the showBorder API value.
            * &lt;script&gt;
            *  $("#textbox").ejmTextBox ("option", "showBorder");			
            * // Set the showBorder API
            * $("#textbox").ejmTextBox ("option", "showBorder", true); 
            * &lt;/script&gt;<br>
               
            * @example 
            * // For Password
            * //Set the showBorder property in unobtrusive way.
            * &lt;input id="password" data-role="ejmpassword" data-ej-showborder=true /&gt;<br>
            * @example 
            * // Set the showBorder on initialization. 
            * //To set the showBorder API value 
            * &lt;input id="password" data-role="ejmpassword"/&gt;<br>
            * &lt;script&gt;
            * $("#password").ejmPassword ({ showBorder: true });	
            * &lt;/script&gt;
            * @example 
            * //Get or set the showBorder, after initialization:<br>
            * // Get the showBorder API value.		
            * &lt;script&gt;
            *  $("#password").ejmPassword ("option", "showBorder");			
            * // Set the showBorder API
            * $("#password").ejmPassword ("option", "showBorder", true); 
            * &lt;/script&gt;<br>       
            
            * @example 
            * // For MaskEdit
            * //Set the showBorder property in unobtrusive way.
            * &lt;input id="maskedit" data-role="ejmmaskedit" data-ej-showborder=true data-ej-mask="+1 (999) 999-9999" /&gt;<br>
            * @example 
            * // Set the showBorder on initialization. 
            * //To set the showBorder API value 
            * &lt;input id="maskedit" data-role="ejmmaskedit"/&gt;<br>
            * &lt;script&gt;
            * $("#maskedit").ejmMaskEdit ({ showBorder: true,mask:"+1 (999) 999-9999" });
            * &lt;/script&gt;
            * @example 
            * //Get or set the showBorder, after initialization:<br>
            * // Get the showBorder API value.		
            * &lt;script&gt;
            *  $("#maskedit").ejmMaskEdit ("option", "showBorder");			
            * // Set the showBorder API
            * $("#maskedit").ejmMaskEdit ("option", "showBorder", true); 
            * &lt;/script&gt;<br> 
            
            * @example 
            * // For TextArea
            * //Set the showBorder property in unobtrusive way.
            * &lt;textarea id="textarea" data-role="ejmtextarea" data-ej-showborder=true &gt; &lt;/textarea&gt;<br>
            * @example 
            * // Set the showBorder on initialization. 
            * //To set the showBorder API value 
            * &lt;textarea id="textarea" data-role="ejmtextarea"&gt;&lt;/textarea&gt;<br>
            * &lt;script&gt;
            * $("#textarea").ejmTextArea ({ showBorder: true });
            * &lt;/script&gt;
            * @example 
            * //Get or set the  showBorder, after initialization:<br>
            * // Get the showBorder API value.
            * &lt;script&gt;
            *  $("#textarea").ejmTextArea ("option", "showBorder");			
            * // Set the showBorder API
            * $("#textarea").ejmTextArea ("option", "showBorder", true);
            * &lt;/script&gt;
            * @memberof ejmTextBox
            * @instance
            */
            showBorder: true,
            /**     
            * Section for windows rendermode specific functionalities.                      
            * @memberof ejmTextBox
            * @instance
            */
            windows: {
                /** 
                * Specifies whether to render control based on the windowsphone's current accent color and device theme.
                * @default false
                * @type {boolean}

                * @alias ejmTextBox#windows->renderDefault
                * @example 
                * //For TextBox Control
                * // Set the windows mode renderDefault property in unobtrusive way.
                * &lt;input id="textbox" data-role="ejmtextbox" data-ej-rendermode="windows" data-ej-windows-renderDefault=false /&gt<br>
                * @example 
                * // To set the windows mode renderDefault property API value 
                * &lt;input id="textbox"/&gt<br>
                * &lt;script&gt;
                * $(function () {
                * $("#textbox").ejmTextBox({ windows:{renderDefault: false},renderMode:ej.mobile.RenderMode.Windows});
                * });
                * &lt;/script&gt;
                * @example 
                * // Get or set the windows mode renderDefault API, after initialization:
                * // Get the windows mode renderDefault value  
                * &lt;script&gt;
                * $("#textbox").ejmTextBox("option", "windows.renderDefault");   
                * // Set the windows mode renderDefault value 
                *$("#textbox").ejmTextBox("option", "windows.renderDefault", false);
                * &lt;/script&gt;

                * @example 
                * //For Password Control
                * // Set the windows mode renderDefault property in unobtrusive way.
                * &lt;input id="password" data-role="ejmpassword" data-ej-rendermode="windows" data-ej-windows-renderDefault=false /&gt<br>
                * @example 
                * // To set the windows mode renderDefault property API value 
                * &lt;input id="password"/&gt<br>
                * &lt;script&gt;
                * $(function () {
                * $("#password").ejmPassword({ windows:{renderDefault: false},renderMode:ej.mobile.RenderMode.Windows});   
                * });
                * &lt;/script&gt;
                * @example 
                * // Get or set the windows mode renderDefault API, after initialization:
                * // Get the windows mode renderDefault value  
                * &lt;script&gt;
                * $("#password").ejmPassword("option", "windows.renderDefault");   
                * // Set the windows mode renderDefault value 
                *$("#password").ejmPassword("option", "windows.renderDefault", false);
                * &lt;/script&gt;

                * @example 
                * //For MaskEdit Control
                * // Set the windows mode renderDefault property in unobtrusive way.
                * &lt;input id="maskedit" data-role="ejmmaskedit" data-ej-rendermode="windows" data-ej-windows-renderDefault=false data-ej-mask="+1 (999) 999-9999"  /&gt<br>
                * @example 
                * // To set the windows mode renderDefault property API value 
                * &lt;input id="maskedit" /&gt<br>
                * &lt;script&gt;
                * $(function () {
                * $("#maskedit").ejmMaskEdit({ windows:{renderDefault: false},mask:"+1 (999) 999-9999"},renderMode:ej.mobile.RenderMode.Windows); 
                * });
                * &lt;/script&gt;
                * @example 
                * // Get or set the windows mode renderDefault API, after initialization:
                * // Get the windows mode renderDefault value  
                * &lt;script&gt;
                * $("#maskedit").ejmMaskEdit("option", "windows.renderDefault"); 
                * // Set the windows mode renderDefault value 
                *$("#maskedit").ejmMaskEdit("option", "windows.renderDefault", false);
                * &lt;/script&gt;
                 
                * @example 
                * //For Text Area Control
                * // Set the windows mode renderDefault property in unobtrusive way.
                * &lt;textarea id="textarea" data-role="ejmtextarea" data-ej-rendermode="windows" data-ej-windows-renderDefault=false&gt;&lt;/textarea&gt;<br>
                * @example 
                * // To set windows mode renderDefault property API value 
                * &lt;textarea id="textarea" &gt;&lt;/textarea&gt;<br>
                * &lt;script&gt;
                * $(function () {
                * $("#textarea").ejmTextArea({windows:{renderDefault: false},renderMode:ej.mobile.RenderMode.Windows});   
                * });
                * &lt;/script&gt;
                * @example 
                * // Get or set the windows mode renderDefault API, after initialization:
                * // Get the windows mode renderDefault value  
                * &lt;script&gt;
                * $("#textarea").ejmTextArea("option", "windows.renderDefault");   
                * // Set the windows mode renderDefault value 
                * $("#textarea").ejmTextArea("option", "windows.renderDefault", false); 
                * &lt;/script&gt;
                * @memberof ejmTextBox
                * @instance
                */
                "renderDefault": false,
                /**  
                * Specifies whether to allow the reset button for the windows mode in TextBox, Password, MaskEdit, TextArea.
                * @default true
                * @type {boolean}
                * @alias ejmTextBox#windows->allowReset

                * @example 
                * //For TextBox Control
                * // Set the windows mode allowReset property in unobtrusive way.
                * &lt;input id="textbox" data-role="ejmtextbox" data-ej-rendermode="windows" data-ej-windows-allowreset=true /&gt<br>
                * @example 
                * // To set the windows mode allowReset property API value 
                * &lt;input id="textbox"/&gt<br>
                * &lt;script&gt;
                * $(function () {
                * $("#textbox").ejmTextBox({ windows:{allowReset: true},renderMode:ej.mobile.RenderMode.Windows});   
                * });
                * &lt;/script&gt;
                * @example 
                * // Get or set the windows mode allowReset API, after initialization:
                * // Get the windows mode allowReset value  
                * &lt;script&gt;
                * $("#textbox").ejmTextBox("option", "windows.allowReset");   
                * // Set the windows mode allowReset value 
                * $("#textbox").ejmTextBox("option", "windows.allowReset", true);
                * &lt;/script&gt;

                * @example 
                * //For Password Control
                * // Set the windows mode allowReset property in unobtrusive way.
                * &lt;input id="password" data-role="ejmpassword" data-ej-rendermode="windows" data-ej-windows-allowreset=true /&gt<br>
                * @example 
                * // To set the windows mode allowReset property API value 
                * &lt;input id="password"/&gt<br>
                * &lt;script&gt;
                * $(function () {
                * $("#password").ejmPassword({ windows:{allowReset: true},renderMode:ej.mobile.RenderMode.Windows});  
                * });
                * &lt;/script&gt;
                * @example 
                * // Get or set the windows mode allowReset API, after initialization:
                * // Get the windows mode allowReset value  
                * &lt;script&gt;
                * $("#password").ejmPassword("option", "windows.allowReset");   
                * // Set the windows mode allowReset value 
                *$("#password").ejmPassword("option", "windows.allowReset", true); 
                * &lt;/script&gt;

                * @example 
                * //For MaskEdit Control
                * // Set the windows mode allowReset property in unobtrusive way.
                * &lt;input id="maskedit" data-role="ejmmaskedit"  data-ej-rendermode="windows" data-ej-windows-allowreset=true data-ej-mask="+1 (999) 999-9999" /&gt<br>
                * @example 
                * // To set the windows mode allowReset property API value 
                * &lt;input id="maskedit"/&gt<br>
                * &lt;script&gt;
                * $(function () {
                * $("#maskedit").ejmMaskEdit({ windows:{allowReset: true},mask:"+1 (999) 999-9999",renderMode:ej.mobile.RenderMode.Windows});   
                * });
                * &lt;/script&gt;
                * @example 
                * // Get or set the windows mode allowReset API, after initialization:
                * // Get the windows mode allowReset value  
                * &lt;script&gt;
                * $("#maskedit").ejmMaskEdit("option", "windows.allowReset");   
                * // Set the windows mode allowReset value 
                *$("#maskedit").ejmMaskEdit("option", "windows.allowReset", true);
                * &lt;/script&gt;

                * @example 
                * //For Text Area Control
                * // Set the windows mode allowReset property in unobtrusive way.
                * &lt;textarea id="textarea" data-role="ejmtextarea" data-ej-rendermode="windows" data-ej-windows-allowreset=true &gt; &lt;/textarea&gt;<br>
                * @example 
                * // To set the windows mode allowReset property API value 
                * &lt;textarea id="textarea"&gt;&lt;/textarea&gt;<br>
                * &lt;script&gt;
                * $(function () {
                * $("#textarea").ejmTextArea({windows:{allowReset: true,renderMode:ej.mobile.RenderMode.Windows}});  
                * });
                * &lt;/script&gt;
                * @example 
                * // Get or set the windows mode allowReset API, after initialization:
                * // Get the windows mode allowReset value  
                * &lt;script&gt;
                * $("#textarea").ejmTextArea("option", "windows.allowReset");   
                * // Set the windows mode allowReset value 
                *$("#textarea").ejmTextArea("option", "windows.allowReset", true); 
                * &lt;/script&gt;
                * @memberof ejmTextBox
                * @instance
                */
                "allowReset": true
            },
            /**		
            * Specifies the value on initialization.
            * @default ""
            * @type {string}

            * @example
            * // For TextBox 
            * //Set the value property in unobtrusive way.
            * &lt;input id="textbox" data-role="ejmtextbox" data-ej-value="" /&gt;<br>
            * @example 
            * // Set the value on initialization. 
            * //To set the value API value 
            * &lt;input id="textbox"/&gt;<br>
            * &lt;script&gt;
            * $("#textbox").ejmTextBox ({ value: "" });		
            * &lt;/script&gt;
            * @example 
            * //Get or set the TextBox value, after initialization:<br>
            * // Get the value API value.		
            * &lt;script&gt;
            *  $("#textbox").ejmTextBox ("option", "value");			
            * // Set the value API
            * $("#textbox").ejmTextBox ("option", "value", "");  
            * &lt;/script&gt;

            * @example 
            * // For Password
            * //Set the value property in unobtrusive way.
            * &lt;input id="password" data-role="ejmpassword" data-ej-value="" /&gt;<br>
            * @example 
            * // Set Password value on initialization. 
            * //To set the value API value 
            * &lt;input id="password"/&gt;<br>
            * &lt;script&gt;
            * $("#password").ejmPassword ({ value: "" });	
            * &lt;/script&gt;
            * @example 
            * //Get or set the Password value, after initialization:<br>
            * // Get the value API value.		
            * &lt;script&gt;
            *  $("#password").ejmPassword ("option", "value");			
            * // Set the value API
            * $("#password").ejmPassword ("option", "value", "");
            * &lt;/script&gt;
            
            * @example 
            * // For MaskEdit
            * //Set the value property in unobtrusive way.
            * &lt;input id="maskedit" data-role="ejmmaskedit" data-ej-value="" data-ej-mask="+1 (999) 999-9999"/&gt;<br>
            * @example 
            * // Set the value on initialization. 
            * //To set the value API value 
            * &lt;input id="maskedit"/&gt;<br>
            * &lt;script&gt;
            * $("#maskedit").ejmMaskEdit ({ value: "",mask:"+1 (999) 999-9999" });	
            * &lt;/script&gt;
            * @example 
            * //Get or set the value, after initialization:<br>
            * // Get the value API value.		
            * &lt;script&gt;
            *  $("#maskedit").ejmMaskEdit ("option", "value");			
            * // Set the value API
            * $("#maskedit").ejmMaskEdit ("option", "value", "");
            * &lt;/script&gt;
            
            * @example 
            * // For TextArea
            * //Set the value property in unobtrusive way.
            * &lt;textarea id="textarea" data-role="ejmtextarea" data-ej-value="" &gt;&lt;/textarea&gt;<br>
            * @example 
            * // Set the value on initialization. 
            * //To set the value API value 
            * &lt;textarea id="textarea"&gt;&lt;/textarea&gt;<br>
            * &lt;script&gt;
            * $("#textarea").ejmTextArea ({ value: "" });		
            * &lt;/script&gt;
            * @example 
            * //Get or set the value, after initialization:<br>
            * // Get the value API value.		
            * &lt;script&gt;
            * $("#textarea").ejmTextArea ("option", "value");			
            * // Set the value API
            * $("#textarea").ejmTextArea ("option", "value", "");    
            * &lt;/script&gt;
            * @memberof ejmTextBox
            * @instance
            */
            value: "",
            /**		
            * Specifies the watermarkText on initialization.
            * @default ""
            * @type {string}

            * @example 
            * // For TextBox
            * //Set the watermarkText property in unobtrusive way.
            * &lt;input id="textbox" data-role="ejmtextbox" data-ej-watermarktext="" /&gt;<br>
            * @example 
            * // Set the watermarkText on initialization. 
            * //To set the watermarkText API value 
            * &lt;input id="textbox"/&gt;<br>
            * &lt;script&gt;
            * $("#textbox").ejmTextBox ({ watermarkText: "" });
            * &lt;/script&gt;
            * @example 
            * //Get or set the watermarkText, after initialization:<br>
            * // Get the watermarkText API value.		
            * &lt;script&gt;
            *  $("#textbox").ejmTextBox ("option", "watermarkText");			
            * // Set the watermarkText API
            * $("#textbox").ejmTextBox ("option", "watermarkText", "");  
            * &lt;/script&gt;
            
            * @example 
            * // For Password
            * //Set the watermarkText property in unobtrusive way.
            * &lt;input id="password" data-role="ejmpassword" data-ej-watermarktext="" /&gt;<br>
            * @example 
            * // Set the watermarkText on initialization. 
            * //To set the watermarkText API value 
            * &lt;input id="password"/&gt;<br>
            * &lt;script&gt;
            * $("#password").ejmPassword ({ watermarkText: "" });	
            * &lt;/script&gt;
            * @example 
            * //Get or set the watermarkText, after initialization:<br>
            * // Get the watermarkText API value.		
            * &lt;script&gt;
            *  $("#password").ejmPassword ("option", "watermarkText");			
            * // Set the watermarkText API
            * $("#password").ejmPassword ("option", "watermarkText", "");  
            * &lt;/script&gt;
            
            * @example 
            * // For MaskEdit
            * //Set the watermarkText property in unobtrusive way.
            * &lt;input id="maskedit" data-role="ejmmaskedit" data-ej-watermarktext="" data-ej-mask="+1 (999) 999-9999" /&gt;<br>
            * @example 
            * // Set the watermarkText on initialization. 
            * //To set the watermarkText API value 
            * &lt;input id="maskedit"/&gt;<br>
            * &lt;script&gt;
            * $("#maskedit").ejmMaskEdit ({ watermarkText: "",mask:"+1 (999) 999-9999" });
            * &lt;/script&gt;
            * @example 
            * //Get or set the watermarkText, after initialization:<br>
            * // Get the watermarkText API value.	
            * &lt;script&gt;
            *  $("#maskedit").ejmMaskEdit ("option", "watermarkText");			
            * // Set the watermarkText API
            * $("#maskedit").ejmMaskEdit ("option", "watermarkText", ""); 
            * &lt;/script&gt;
            
            * @example 
            * // For TextArea
            * //Set the watermarkText property in unobtrusive way.
            * &lt;textarea id="textarea" data-role="ejmtextarea" data-ej-watermarktext="" &gt;&lt;/textarea&gt;<br>
            * @example 
            * // Set the watermarkText on initialization. 
            * //To set the watermarkText API value 
            * &lt;textarea id="textarea"&gt;&lt;/textarea&gt;<br>
            * &lt;script&gt;
            * $("#textarea").ejmTextArea ({ watermarkText: "" });		
            * &lt;/script&gt;
            * @example 
            * //Get or set the watermarkText, after initialization:<br>
            * // Get the watermarkText API value.		
            * &lt;script&gt;
            *  $("#textarea").ejmTextArea ("option", "watermarkText");			
            * // Set the watermarkText API
            * $("#textarea").ejmTextArea ("option", "watermarkText", "");        
            * &lt;/script&gt;
            * @memberof ejmTextBox
            * @instance
            */
            watermarkText: "",
            /**    
            * Event triggers when the Textbox or Password or Maskedit or textarea value changed
            * @event
            * @name ejmTextBox#change  	
            * @param {Object} argument Event parameters from Textbox or Password or Maskedit or textarea   
            * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
            * @param {string} argument.model returns the Textbox or Password or Maskedit or textarea model
            * @param {string} argument.type returns the name of the event
            * @param {object} argument.element returns the current element
            * @param {string} argument.value returns the value of the control

            * @example 
            * // For TextBox
            * &lt;input id="textbox" data-role="ejmtextbox" data-ej-change="onChange"/&gt;<br>
            * &lt;script&gt; 
            * // Change event for textbox
            * function onChange(args) { 
            * //handle the event 
            * }
            * &lt;/script&gt;
            * @example 
            * //Change event for textbox
            * &lt;input id="textbox" data-role="ejmtextbox" data-ej-change="onChange"/&gt;<br>
            * &lt;script&gt;
            * $("#textbox").ejmTextBox({
            *   change: function (args) { 
            * //handle the event 
            * }
            *});  
            * &lt;/script&gt;
                   
            * @example 
            * //For Password
            * &lt;input id="password" data-role="ejmpassword" data-ej-change="onChange"/&gt;<br>
            * &lt;script&gt; 
            * // Change event for password
            * function onChange(args) { 
            * //handle the event 
            * }
            * &lt;/script&gt;
            * @example 
            * //Change event for password
            * &lt;input id="password" data-role="ejmpassword" data-ej-change="onChange"/&gt;<br>
            * &lt;script&gt;
            * $("#password").ejmPassword({
            *   change: function (args) { 
            * //handle the event 
            * }
            *});    
            * &lt;/script&gt;
                   
            * @example 
            * //For maskedit
            * &lt;input id="maskedit" data-role="ejmmaskedit" data-ej-change="onChange" data-ej-mask="+1 (999) 999-9999" /&gt;<br>
            * &lt;script&gt; 
            * // Change event for maskedit
            * function onChange(args) { 
            * //handle the event 
            * }
            * &lt;/script&gt;
            * @example 
            * //Change event for maskedit
            * &lt;input id="maskedit" data-role="ejmmaskedit" data-ej-change="onChange" data-ej-mask="+1 (999) 999-9999" /&gt;<br>
            * &lt;script&gt; 
            * $("#maskedit").ejmMaskEdit({
            *   change: function (args) { 
            * //handle the event 
            * }
            *});     
            * &lt;/script&gt; 
                  
            * @example 
            * //For textarea
            * &lt;textarea id="textarea" data-role="ejmtextarea" data-ej-change="onChange"&gt;&lt;/textarea&gt;<br>
            * &lt;script&gt; 
            * // Change event for textArea
            * function onChange(args) { 
            * //handle the event 
            * }
            * &lt;/script&gt;
            * @example 
            * //Change event for textarea
            * &lt;textarea id="textarea" data-role="ejmtextarea" data-ej-change="onChange"&gt;&lt;/textarea&gt;<br>
            * &lt;script&gt; 
            * $("#textarea").ejmTextArea({
            *   change: function (args) { 
            * //handle the event 
            * }
            *});           
            * &lt;/script&gt; 
            * @memberof ejmTextBox
            * @instance
            */
            change: null,
            /**		
            * Specifies  whether to be enable on initialization.
            * @default true
            * @type {boolean}

            * @example 
            * // For TextBox
            * //Set the enabled property in unobtrusive way.
            * &lt;input id="textbox" data-role="ejmtextbox" data-ej-enabled=true /&gt;<br>
            * @example 
            * // Set the enabled on initialization. 
            * //To set the enabled API value
            * &lt;input id="textbox"/&gt;<br>
            * &lt;script&gt;
            * $("#textbox").ejmTextBox ({ enabled: true });		
            * &lt;/script&gt;
            * @example 
            * //Get or set the  enabled, after initialization:<br>
            * // Get the enabled API value.		
            * &lt;script&gt;
            *  $("#textbox").ejmTextBox ("option", "enabled");			
            * // Set the enabled API
            * $("#textbox").ejmTextBox ("option", "enabled", true);
            * &lt;/script&gt;
                      
            * @example 
            * // For Password
            * //Set the enabled property in unobtrusive way.
            * &lt;input id="password" data-role="ejmpassword" data-ej-enabled=true /&gt;<br>
            * @example 
            * // Set the enabled on initialization. 
            * //To set enabled API value 
            * &lt;input id="password" /&gt;<br>
            * &lt;script&gt;
            * $("#password").ejmPassword ({ enabled: true });		
            * &lt;/script&gt;
            * @example 
            * //Get or set the enabled, after initialization:<br>
            * // Get the enabled API value.		
            * &lt;script&gt;
            *  $("#password").ejmPassword ("option", "enabled");			
            * // Set the enabled API
            * $("#password").ejmPassword ("option", "enabled", true);
            * &lt;/script&gt;
                        
            * @example 
            * // For MaskEdit
            * //Set the enabled property in unobtrusive way.
            * &lt;input id="maskedit" data-role="ejmmaskedit" data-ej-enabled=true data-ej-mask="+1 (999) 999-9999"  /&gt;<br>
            * @example 
            * // Set the enabled on initialization. 
            * //To set the enabled API value 
            * &lt;input id="maskedit"/&gt;<br>
            * &lt;script&gt;
            * $("#maskedit").ejmMaskEdit ({ enabled: true,mask:"+1 (999) 999-9999" });	
            * &lt;/script&gt;
            * @example 
            * //Get or set the enabled, after initialization:<br>
            * // Get the enabled API value.		
            * &lt;script&gt;
            *  $("#maskedit").ejmMaskEdit ("option", "enabled");			
            * // Set the enabled API
            * $("#maskedit").ejmMaskEdit ("option", "enabled", true); 
            * &lt;/script&gt;
                        
            * @example 
            * // For textarea
            * //Set the enabled property in unobtrusive way.
            * &lt;textarea id="textarea" data-role="ejmtextarea" data-ej-enabled=true &gt;&lt;/textarea&gt;<br>
            * @example 
            * // Set the enabled on initialization. 
            * //To set the enabled API value 
            * &lt;textarea id="textarea"&gt;&lt;/textarea&gt;<br>
            * &lt;script&gt;
            * $("#textarea").ejmTextArea ({ enabled: true });			
            * &lt;/script&gt;
            * @example 
            * //Get or set the enabled, after initialization:<br>
            * // Get the enabled API value.		
            * &lt;script&gt;
            *  $("#textarea").ejmTextArea ("option", "enabled");			
            * // Set the enabled API
            * $("#textarea").ejmTextArea ("option", "enabled", true);  
            * &lt;/script&gt;
            * @memberof ejmTextBox
            * @instance
            */
            enabled: true,
            /**		
            * Specifies to maintain the current model value to browser cookies for state maintenance. While refresh the page, the model value will get apply to the control from browser cookies.
            * @default false
            * @type {boolean}
                   
            * @example 
            * // For TextBox
            * //Set the enablePersistence property in unobtrusive way.
            * &lt;input id="textbox" data-role="ejmtextbox" data-ej-enablepersistence=false /&gt;<br>
            * @example 
            * // Set the enablePersistence on initialization. 
            * //To set the enablePersistence API value 
            * &lt;input id="textbox"/&gt;<br>
            * &lt;script&gt;
            * $("#textbox").ejmTextBox ({ enablePersistence: false });	
            * &lt;/script&gt;
            * @example 
            * //Get or set the enablePersistence, after initialization:<br>
            * // Get the enablePersistence API value.	
            * &lt;script&gt;
            *  $("#textbox").ejmTextBox ("option", "enablePersistence");			
            * // Set the enablePersistence API
            * $("#textbox").ejmTextBox ("option", "enablePersistence", false);  
            * &lt;/script&gt;

            * @example 
            * // For Password
            * //Set the enablePersistence property in unobtrusive way.
            * &lt;input id="password" data-role="ejmpassword" data-ej-enablepersistence=false /&gt;<br>
            * @example 
            * // Set the enablePersistence on initialization. 
            * //To set the enablePersistence API value 
            * &lt;input id="password"/&gt;<br>
            * &lt;script&gt;
            * $("#password").ejmPassword ({ enablePersistence: false });	
            * &lt;/script&gt;
            * @example 
            * //Get or set the enablePersistence, after initialization:<br>
            * // Get the enablePersistence API value.		
            * &lt;script&gt;
            *  $("#password").ejmPassword ("option", "enablePersistence");			
            * // Set the enablePersistence API
            * $("#password").ejmPassword ("option", "enablePersistence", false);
            * &lt;/script&gt;
                  
            * @example 
            * // For MaskEdit
            * //Set the enablePersistence property in unobtrusive way.
            * &lt;input id="maskedit" data-role="ejmmaskedit" data-ej-enablepersistence=false data-ej-mask="+1 (999) 999-9999" /&gt;<br>
            * @example 
            * // Set the enablePersistence on initialization. 
            * //To set the enablePersistence API value 
            * &lt;input id="maskedit"/&gt;<br>
            * &lt;script&gt;
            * $("#maskedit").ejmMaskEdit ({ enablePersistence: false,mask:"+1 (999) 999-9999" });
            * &lt;/script&gt;
            * @example 
            * //Get or set the enablePersistence, after initialization:<br>
            * // Get the enablePersistence API value.		
            * &lt;script&gt;
            *  $("#maskedit").ejmMaskEdit ("option", "enablePersistence");			
            * // Set the enablePersistence API
            * $("#maskedit").ejmMaskEdit ("option", "enablePersistence", false);  
            * &lt;/script&gt;
                   
            * @example 
            * // For TextArea
            * //Set the enablePersistence property in unobtrusive way.
            * &lt;textarea id="textarea" data-role="ejmtextarea" data-ej-enablepersistence=false &gt;&lt;/textarea&gt;<br>
            * @example 
            * // Set the enablePersistence on initialization. 
            * //To set the enablePersistence API value 
            * &lt;textarea id="textarea"&gt;&lt;/textarea&gt;<br>
            * &lt;script&gt;
            * $("#textarea").ejmTextArea ({ enablePersistence: false });	
            * &lt;/script&gt;
            * @example 
            * //Get or set the enablePersistence, after initialization:<br>
            * // Get the enablePersistence API value.		
            * &lt;script&gt;
            *  $("#textarea").ejmTextArea ("option", "enablePersistence");			
            * // Set the enablePersistence API
            * $("#textarea").ejmTextArea ("option", "enablePersistence", false); 
            * &lt;/script&gt;
            * @memberof ejmTextBox
            * @instance
            */
            enablePersistence: false,
            /**		
            * Specifies the TextBox, Password, Mask Edit, and Textarea readOnly.
            * @default false
            * @type {boolean}
                   
            * @example 
            * // For TextBox
            * //Set the readOnly property in unobtrusive way.
            * &lt;input id="textbox" data-role="ejmtextbox" data-ej-readonly=false /&gt;<br>
            * @example 
            * // Set the readOnly on initialization. 
            * //To set the readOnly API value
            * &lt;input id="textbox"/&gt;<br>
            * &lt;script&gt;
            * $("#textbox").ejmTextBox ({ readOnly: false });		
            * &lt;/script&gt;
            * @example 
            * //Get or set the readOnly, after initialization:<br>
            * // Get the readOnly API value.		
            * &lt;script&gt;
            *  $("#textbox").ejmTextBox ("option", "readOnly");			
            * // Set the readOnly API
            * $("#textbox").ejmTextBox ("option", "readOnly", false);
            * &lt;/script&gt;
                   
            * @example 
            * // For Password
            * //Set the readOnly property in unobtrusive way.
            * &lt;input id="password" data-role="ejmpassword" data-ej-readonly=false /&gt;<br>
            * @example 
            * // Set the readOnly on initialization. 
            * //To set readOnly API value 
            * &lt;input id="password"/&gt;<br>
            * &lt;script&gt;
            * $("#password").ejmPassword ({ readOnly: false });		
            * &lt;/script&gt;
            * @example 
            * //Get or set the  readOnly, after initialization:<br>
            * // Get the readOnly API value.		
            * &lt;script&gt;
            *  $("#password").ejmPassword ("option", "readOnly");			
            * // Set the readOnly API
            * $("#password").ejmPassword ("option", "readOnly", false);  
            * &lt;/script&gt;
                   
            * @example 
            * // For MaskEdit
            * //Set the readOnly property in unobtrusive way.
            * &lt;input id="maskedit" data-role="ejmmaskedit" data-ej-readonly=false data-ej-mask="+1 (999) 999-9999" /&gt;<br>
            * @example 
            * // Set the readOnly on initialization. 
            * //To set the readOnly API value 
            * &lt;input id="maskedit"/&gt;<br>
            * &lt;script&gt;
            * $("#maskedit").ejmMaskEdit ({ readOnly: false,mask:"+1 (999) 999-9999" });
            * &lt;/script&gt;
            * @example 
            * //Get or set the readOnly, after initialization:<br>
            * // Get the readOnly API value.		
            * &lt;script&gt;
            *  $("#maskedit").ejmMaskEdit ("option", "readOnly");			
            * // Set the readOnly API
            * $("#maskedit").ejmMaskEdit ("option", "readOnly", false);   
            * &lt;/script&gt;
                   
            * @example 
            * // For TextArea
            * //Set the readOnly property in unobtrusive way.
            * &lt;textarea id="textarea" data-role="ejmtextarea" data-ej-readonly=false &gt;&lt;/textarea&gt;<br>
            * @example 
            * // Set the readOnly on initialization. 
            * //To set the readOnly API value 
            * &lt;textarea id="textarea"&gt; &lt;/textarea&gt;<br>
            * &lt;script&gt;
            * $("#textarea").ejmTextArea ({ readOnly: false });			
            * &lt;/script&gt;
            * @example 
            * //Get or set the readOnly, after initialization:<br>
            * // Get the readOnly API value.		
            * &lt;script&gt;
            *  $("#textarea").ejmTextArea ("option", "readOnly");			
            * // Set the readOnly API
            * $("#textarea").ejmTextArea ("option", "readOnly", false);          
            * &lt;/script&gt;
            * @memberof ejmTextBox
            * @instance
            */
            readOnly: false
        },
        observables: ["value"],
        value: ej.util.valueFunction("value"),

        dataTypes: {
            theme: "enum",
            showBorder: "boolean",
            windows: {
                "allowReset": 'boolean'
            },
            renderMode: "enum",
            enabled: "boolean",
            readOnly: "boolean"
        },
        // constructor function
        /**
        * Create the TextBox,Password, MaskEdit and TextArea widget
        * @private
        */
        _init: function () {
            this._cloneElement = this.element.clone();
            this._isMaskedit = this.pluginName === "ejmMaskEdit" ? true : false;
            this._isTextarea = this.pluginName === "ejmTextArea" ? true : false;
            this._dataInit();
            this._renderControl();
            ej._setScroller(this);
            this._wireEvents(false);
            this.model.enabled ? this.enable() : this.disable();
        },
        _dataInit: function () {
            this._clearClicked = false;
            if (this._isMaskedit)
                this._maskInit();
        },
        _maskInit: function () {
            this._isInitialRendered = true;
            this._hiddenField = this.element.parent().find("#" + this.model.id + "_maskedithiddenField")[0];
            //Predefined character definitions
            this._charMap = {
                '9': "[0-9]",
                'a': "[A-Za-z]",
                '*': "[A-Za-z0-9]"
            };
        },
        /**
        * To render TextBox control
        * @private
        */
        _renderControl: function () {
            ej.setRenderMode(this);
            ej.setTheme(this);
            if (this.model.renderMode == "windows" && this.model.windows.renderDefault)
                this.model.theme = "default";
            this._isTextarea ? this._textAreaProperties() : this._textBoxProperties();
            if ((this.model.watermarkText != "") && (this.value() == "") && (!this._isMaskedit || this._isTextarea))
                this._setWaterMark();
            else
                this._setValue(this.value());
            if (this.model.readOnly) this._setReadOnly(this.model.readOnly);
            if (!this.model.showBorder)
                this._showBorder(false);
        },
        /**
        * To set the properties of TextBox control
        * @private
        */
        _textBoxProperties: function () {
            var element = this.element;
            var obj = this.model;
            this._wrapper = ej.buildTag("div.e-m-" + obj.renderMode + " e-m-textbox" + " e-m-" + obj.theme);
            element.after(this._wrapper);
            this._wrapper.append(element);
            if (this.pluginName == "ejmPassword")
                element.attr("type", "password");
            element.addClass("e-m-input-focusout").attr("name", obj.id);
            var spandiv = ej.buildTag("span");
            spandiv.addClass("e-m-textspan");
            if (this._isMaskedit) {
                if (this._isInitialRendered) {
                    this._keypressFlag = 0;
                    this._selectedTextKeyDown = 0;
                    // KeyDown trace [ 0 - None, 1 - BackSpace, 2 - Delete]
                    this._keydownFlag = 0;
                    // Length of the Mask
                    this._maskLength = obj.mask.length;
                    //Replacing all [9a*] to '_'
                    this._maskModel = obj.mask.replace(/[9a*]/g, '_');
                    this._validatedValue = this._maskModel;
                    // Validating user's value
                    this._validateValue();
                    // Setting WaterMark Text
                    this._setWaterMark();
                }
            }
            if (obj.windows.allowReset && !this._isMaskedit) {
                this._clearBtn = ej.buildTag("div");
                this.pluginName == "ejmPassword" ? this._clearBtn.addClass("e-m-pass e-m-icon-allowreset") : this._clearBtn.addClass("e-m-icon-clear");
                this._wrapper.append(this._clearBtn);
                this._clearBtn.css("display", "none");
            }
            this._wrapper.append(spandiv);
        },
        /**
        * To set the properties of TextArea control
        * @private
        */
        _textAreaProperties: function () {
            var element = this.element;
            var obj = this.model;
            this.defaultHeight = element[0].style.height == "" ? 30 : parseInt(element[0].style.height);
            this._wrapper = ej.buildTag("div.e-m-" + obj.renderMode + " e-m-textbox" + " e-m-" + obj.theme);
            var spandiv = ej.buildTag("span");
            spandiv.addClass("e-m-textspan");
            element.wrap(this._wrapper);
            element.css({ "resize": "none", "text-indent": "0px", "padding-left": "5px" });
            element.focus();
            this._focus();
            element.after(spandiv);
            element.attr("rows", 1);
            this._resize();
        },
        /**
        * To Handle TouchStart event
        * @private
        */
        _touchStart: function (evt) {
            ej._inputTouchStart(evt, this);
            ej.listenEvents([window, window, window],
                                [ej.moveEvent(), ej.cancelEvent(), ej.endEvent()],
                                [this._touchMoveProxy, this._touchEndProxy, this._touchEndProxy],
                                false);
        },
        /**
        * To Handle TouchMove event
        * @private
        */
        _touchMove: function (evt) {
            ej._inputTouchMove(evt, this);
        },
        /**
        * To Handle TouchEnd event
        * @private
        */
        _touchEnd: function (evt) {
            ej._inputTouchEnd(evt, this);
            ej.listenEvents([window, window, window],
                                [ej.moveEvent(), ej.cancelEvent(), ej.endEvent()],
                                [this._touchMoveProxy, this._touchEndProxy, this._touchEndProxy],
                                true);
        },
        _createDelegate: function () {
            this.resize = $.proxy(this._resize, this);
            this.delayedResize = $.proxy(this._delayedResize, this);
            this.blur = $.proxy(this._blur, this);
            this.focus = $.proxy(this._focus, this);
            this._keyDownProxy = $.proxy(this._keyDown, this);
            this._keyPressProxy = $.proxy(this._keyPress, this);
            this._keyUpProxy = $.proxy(this._keyUp, this);
            this._touchStartProxy = $.proxy(this._touchStart, this);
            this._touchMoveProxy = $.proxy(this._touchMove, this);
            this._touchEndProxy = $.proxy(this._touchEnd, this);
            if (!this._isTextarea && !this.isMaskedit) {
                this._showClearProxy = $.proxy(this._showClear, this);
                this._clearTextProxy = $.proxy(this._clearText, this);
            }
        },
        /**
        * To wire the events for TextBox	
        * @private
        */
        _wireEvents: function (remove) {
            var element = this.element;
            this._createDelegate();
            ej.listenEvents([element, element, element, element, element, element, element], ["change", "cut", "paste", "keydown", "focus", "blur", "keyup"], [this.resize, this.delayedResize, this.delayedResize, this.delayedResize, this.focus, this.blur, this._keyUpProxy], remove);
            if (ej.isDevice())
                ej.listenTouchEvent(element, ej.startEvent(), this._touchStartProxy, remove);
            if (this._isMaskedit)
                ej.listenEvents([element, element], ["keydown", "keypress"], [this._keyDownProxy, this._keyPressProxy], remove);
            if (this.model.renderMode == "windows" && this.model.windows.allowReset && !this._isMaskedit && !this._isTextarea)
                ej.listenEvents([element, this._clearBtn], ["keyup", ej.startEvent()], [this._showClearProxy, this._clearTextProxy], remove);
        },
        /* Setting the WaterMark text*/
        /**
        * To Set the WaterMark text to the control
        * @private
        */
        _setWaterMark: function () {
            if (this.model.watermarkText && (this.value() == '' || this.value() == this._maskModel))
                $(this.element).attr("placeholder", this.model.watermarkText).addClass("e-m-watermarktext");
            else if (this.value() == '')
                this.element.val(this._maskModel);
        },
        /* Clearing the WaterMark Text*/
        /**
        * To clear the WaterMark Text from the control
        * @private
        */
        _removeWaterMark: function () {
            if (this.element.hasClass("e-m-watermarktext"))
                this.element.val(this._maskModel).removeClass("e-m-watermarktext");
        },
        /* Validating User's TextBox Value*/
        /**
        * To Validate User's TextBox Value
        * @private
        */
        _validateValue: function () {
            var tempValue = this.value();
            var tempModel = this._maskModel;
            var valueLength = tempValue ? tempValue.length : 0;
            var settextFlag = 1;
            var valueIndex = -1;
            // Check if Mask is Empty display the text
            if (this._maskLength == 0) {
                return true;
            }
            for (var maskIndex = 0; maskIndex < this._maskLength; maskIndex++) {
                if (this._charMap[this.model.mask.charAt(maskIndex)]) {
                    valueIndex++;
                    var charCode = tempValue.charCodeAt(valueIndex);
                    if (this._validateChars(charCode, maskIndex)) {
                        var strBefore = tempModel.substring(0, maskIndex);
                        var strAfter = tempModel.substring(maskIndex);
                        tempModel = strBefore + tempValue.charAt(valueIndex) + strAfter.substr(1, strAfter.length);
                    }
                }
            }
            this.element.val(tempModel);
            this._updateHiddenField();
        },
        /* Show alert when user press Wrong key*/
        /**
        * To show alert when user press Wrong key
        * @private
        */
        _showAlert: function () {
            var ptr = this;
            this.element.addClass("e-error").animate({ Opacity: 1 }, 700, null, function () {
                $(this.element).removeClass("e-error");
            });
        },
        //Updates the value of the hidden field
        /**
        * To Update the value of the hidden field
        * @private
        */
        _updateHiddenField: function () {
            //Check for water mark text   
            var value = this.getUnstrippedValue() == this.model.watermarkText ? "" : (this._bindingMode == 0
                   ? this.getStrippedValue() : this.getUnstrippedValue());
            $(this._hiddenField).val(value);
        },
        /* If it is Selected Text operation, This Function clears the Selected Text to MaskModel*/
        /**
        * To clear the Selected Text to MaskModel
        * @private
        */
        _selectionText: function (begin, end) {
            var replaceValue = this._maskModel.substring(begin, end);
            this.element.val(this.element.val().substring(0, begin) + replaceValue + this.element.val().substring(end));
            if (this._keydownFlag == 1) {
                this._setCaretPosition(begin);
                return begin;
            }
            else if (this._keydownFlag == 2) {
                this._setCaretPosition(end);
                return end;
            }
            return begin;
        },
        /* Get the CaretPosition of the cursor, if it selected 1/more text call _selectionText*/
        /**
        * To Get the CaretPosition of the cursor, if it selected 1/more text call _selectionText
        * @private
        */
        _caretPosition: function (textbox) {
            //caretPos starts with 0
            var caretPos = 0;
            // Microsoft supports only IE for using document.selection
            if (document.selection) {
                // Create a Range of selected position
                var selectedRange = document.selection.createRange();
                var selectionLength = selectedRange.text.length;
                // Move selection start to 0 position
                selectedRange.moveStart('character', -textbox.value.length);
                // Get caret position by selection length, becoz now range is from Zero to current focus
                caretPos = selectedRange.text.length - selectionLength;
                if (selectionLength != 0) {
                    caretPos = this._selectionText(caretPos, selectedRange.text.length);
                    this._selectedTextKeyDown = 1;
                }
            }
            // For Firefox
            else if (textbox.selectionStart || textbox.selectionStart == '0') {
                caretPos = textbox.selectionStart;
                if (textbox.selectionStart != textbox.selectionEnd) {
                    caretPos = this._selectionText(textbox.selectionStart, textbox.selectionEnd);
                    this._selectedTextKeyDown = 1;
                }
            }
            // Return caret Position
            return (caretPos);
        },
        /* Set the curosr at required position in textbox*/
        /**
        * To Set the curosr at required position in textbox
        * @private
        */
        _setCaretPosition: function (caretPos) {
            //element will have MaskEdit Textbox
            var element = this.element[0];
            //For IE
            if (ej.browserInfo()["name"] == "msie") {
                if (element.createTextRange) {
                    var range = element.createTextRange();
                    range.move('character', caretPos);
                    range.select();
                }
            }
            else
            /* For FireFox and Chrome */
                if (element.selectionStart || element.selectionStart == '0') {
                    element.focus();
                    element.setSelectionRange(caretPos, caretPos);
                }
                else
                    element.focus();
        },
        /* Validate the User Pressed Char with the Mask Format*/
        /**
        * To Validate the User Pressed Char with the Mask Format
        * @private
        */
        _validateChars: function (key, caretPos) {
            if (this.model.mask.charAt(caretPos) == '9' && (key >= 48 && key <= 57))
                return true;
            if (this.model.mask.charAt(caretPos) == 'a' && ((key >= 65 && key <= 90) || (key >= 97 && key <= 122)))
                return true;
            if (this.model.mask.charAt(caretPos) == '*' && (((key >= 65 && key <= 90) || (key >= 97 && key <= 122)) || (key >= 48 && key <= 57)))
                return true;
            else
                this._showAlert();
            return false;
        },
        /* Seek to the next valid position on right*/
        /**
        * To Seek to the next valid position on right
        * @private
        */
        _seekNext: function () {
            var currentPos = this._caretPosition(this.element[0]);
            var tempPos = currentPos;
            var seekFlag = true;
            //seeking the focus to next valid position on right of MaskEdit TextBox
            while (seekFlag) {
                if (currentPos >= 0 && currentPos < this._maskLength) {
                    if (!this._charMap[this.model.mask.charAt(currentPos)]) {
                        this._setCaretPosition(currentPos + 1);
                        currentPos++;
                    }
                    if (currentPos != tempPos) {
                        tempPos = currentPos;
                        continue;
                    }
                }
                seekFlag = false;
            }
            return currentPos;
        },
        /* Seek to the next valid position on left*/
        /**
        * To Seek to the next valid position on left
        * @private
        */
        _seekBefore: function (caretPos) {
            var currentPos = this._caretPosition(this.element[0]);
            var tempPos = --currentPos;
            var seekFlag = true;
            // Stop Seek when backspace of select more than a char
            if (this._selectedTextKeyDown == 1)
                seekFlag = false;
            //seeking the focus to next valid position on left of MaskEdit TextBox
            while (seekFlag) {
                if (currentPos >= 0 && currentPos < this._maskLength) {
                    if (!this._charMap[this.model.mask.charAt(currentPos)])
                        this._setCaretPosition(--currentPos);
                    if (currentPos != tempPos) {
                        tempPos = currentPos;
                        continue;
                    }
                }
                seekFlag = false;
            }
            return currentPos;
        },
        /* Write the User Pressed Character*/
        /**
        * To Write the User Pressed Character
        * @private
        */
        _writeBuffer: function (key, cursorPos) {
            if (cursorPos <= this._maskLength) {
                var input = this.element.val();
                var strBeforeCursor = input.substring(0, cursorPos);
                var strAfterCursor = input.substring(cursorPos);
                this.element.val(strBeforeCursor + key + strAfterCursor.substr(1, strAfterCursor.length));
                this._setCaretPosition(cursorPos + 1);
            }
        },
        /**
        * To Handle focus event
        * @private
        */
        _focus: function () {
            var proxy = this;
            this._removeWaterMark();
            this.element.parent().find(".e-m-textspan").removeClass("e-m-default").addClass("e-m-active");
            if (this.model.renderMode == "windows") {
                if (this._clearClicked)
                    element.focus();
                this._clearClicked = false;
            }
            this.element.removeClass("e-m-input-focusout").addClass("e-m-input-focusin")
            .parent().find(".e-m-textspan").addClass("e-m-active");
            if (this._isMaskedit) {
                this._removeWaterMark();
                this._updateHiddenField();
                var elem = this.element[0];
                this._setCaretPosition(elem.value.indexOf("_"));
                selectRange = function (start, end) {
                    return this.each(function () {
                        if (elem.setSelectionRange) {
                            elem.focus();
                            elem.setSelectionRange(start, end);
                        } else if (this.createTextRange) {
                            var range = elem.createTextRange();
                            range.collapse(true);
                            range.moveEnd('character', end);
                            range.moveStart('character', start);
                            range.select();
                        }
                    });
                };
            }
            if (this.model.renderMode == "windows" && this.model.windows.allowReset && !this._isMaskedit && !this._isTextarea)
                this._showClear();
            proxy.element[0].scrollLeft = proxy.element[0].scrollWidth;
            window.setTimeout(function () {
                ej.setCaretToPos(proxy.element[0], proxy.element.val().length, proxy.element.val().length);
            });
        },
        /**
        * To Handle blur event
        * @private
        */
        _blur: function () {
            this.element.parent().find(".e-m-textspan").removeClass("e-m-active").addClass("e-m-default");
            this.element.removeClass("e-m-input-focusin").addClass("e-m-input-focusout")
            .parent().find(".e-m-textspan").removeClass("e-m-active");
            if (this.element.val() == "" && this._isMaskedit)
                this.element.val(this._maskModel).removeClass("MaskWaterMark");
            else
                this._setWaterMark();
            if (this.model.renderMode == "windows" && this.model.windows.allowReset && !this._isMaskedit && !this._isTextarea)
                this._clearBtn.css("display", "none");
            this.element[0].scrollLeft = 0;
        },
        /**
        * To Handle keyUp event
        * @private
        */
        _keyUp: function (e) {
            var data = { value: this.element.val() };
            this.value(data.value);
            ej._setScroller(this);
            this._x = this.element[0].scrollLeft;
            if (this.model.change)
                this._trigger("change", data);
        },
        /**
        * To Handle keyPress event
        * @private
        */
        _keyPress: function (e) {
            if (this._maskLength == 0)
                return true;
            var unicode = e.keyCode ? e.keyCode : e.charCode;
            var actualkey = String.fromCharCode(unicode);
            var seekFlag = true;
            var tempPos;
            if ((unicode >= 48 && unicode <= 57) || (unicode >= 65 && unicode <= 90) || (unicode >= 97 && unicode <= 122)) {
                // Seek to next valid position
                currentPos = this._seekNext();
                if (this._validateChars(unicode, currentPos)) {
                    this._writeBuffer(actualkey, currentPos);
                }
            }
            // To stop default press actions
            if (!this._keypressFlag && unicode != 9) {//Shift + Tab Navigation
                this._keypressFlag = 0;
                e.preventDefault();
                return false;
            }
            this._keypressFlag = 0;
            this._updateHiddenField();
            ej._setScroller(this);
            this._x = this.element[0].scrollLeft;
        },
        /**
        * To Handle keyDown event
        * @private
        */
        _keyDown: function (e) {
            if (this._maskLength == 0)
                return true;
            var unicode = e.keyCode ? e.keyCode : e.charCode;
            var actualkey = String.fromCharCode(unicode);
            if (unicode >= 35 && unicode <= 41) {
                if (ej.browserInfo()["name"] == "mozilla" || ej.browserInfo()["name"] == "opera")
                    this._keypressFlag = 1;
            }
            else if (unicode == 8 || unicode == 46) {
                this._keydownFlag = unicode == 8 ? 1 : 2;
                currentPos = this._keydownFlag == 1 ? this._seekBefore() : this._seekNext();
                if (!this._selectedTextKeyDown) {
                    if (currentPos >= 0 && currentPos < this._maskLength)
                        this._writeBuffer("_", currentPos);
                    unicode == 8 ? this._setCaretPosition(currentPos) : {};
                }
                this._keydownFlag = 0;
                this._selectedTextKeyDown = 0;
                e.preventDefault();
                return false;
            }
            this._updateHiddenField();
        },
        /**
        * To do cancel of an event
        * @private
        */
        _cancelEvent: function (e) {
            e.cancelBubble = true;
            e.returnValue = false;
            e.stopPropagation();
            e.preventDefault();
            return false;
        },
        /**
        * To show Border of the control
        * @private
        */
        _showBorder: function (obj) {
            if (obj) {
                this.element.removeClass("e-m-noborder");
                this.element.parent().find(".e-m-noborder").addClass("e-m-textspan").removeClass("e-m-noborder");
            }
            else {
                this.element.addClass("e-m-noborder");
                this.element.parent().find(".e-m-textspan").addClass("e-m-noborder").removeClass("e-m-textspan");
            }
        },
        /**
        * To clear the Text of the control
        * @private
        */
        _clearText: function (e) {
            this.element.val("");
            this._clearBtn.css("display", "none");
            this._clearClicked = true;
            e.preventDefault();
        },
        /**
        * To show the already cleared Text of the control
        * @private
        */
        _showClear: function () {
            if (this.element.attr("value") != "")
                this._clearBtn.css("display", "inline-block");
            else
                this._clearBtn.css("display", "none");
        },
        /**
        * To do Resize the control
        * @private
        */
        _resize: function () {
            this.element.css('height', 'auto');
            if (this.element[0].scrollHeight >= this.defaultHeight)
                this.element.css('height', this.element[0].scrollHeight + 'px')
            else
                this.element.css('height', this.defaultHeight);
        },
        /**
        * To do Delayed Resize the control
        * @private
        */
        _delayedResize: function () {
            window.setTimeout(this.resize, 0);
        },
        /**
        * To configure the RenderMode properties at runtime using SetModel		
        * @private
        */
        _setRenderMode: function (mode) {
            this.model.renderMode = mode;
            this.element.parent().removeClass("e-m-ios7 e-m-android e-m-windows e-m-flat").addClass("e-m-" + mode);
        },
        /**
        * To configure the Theme properties at runtime using SetModel		
        * @private
        */
        _setTheme: function (theme) {
            this.model.theme = theme;
            this.element.parent().removeClass("e-m-dark e-m-light").addClass("e-m-" + theme);
        },
        /**
        * To configure the Value properties at runtime using SetModel		
        * @private
        */
        _setValue: function (value) {
            this.value(value);
            this.element.val(value);
        },
        /**
        * To configure the WaterMarkText properties at runtime using SetModel		
        * @private
        */
        _setWatermarkText: function (watermarktext) {
            this.model.watermarkText = watermarktext;
            this._setWaterMark();
        },
        /**
        * To configure the Mask properties at runtime using SetModel		
        * @private
        */
        _setMask: function (mask) {
            this._maskModel = mask.replace(/[9a*]/g, '_');
            this.element.val(this._maskModel);
            this._validatedValue = this._maskModel;
            this._validateValue();
        },
        /**
        * To configure the ReadOnly properties at runtime using SetModel		
        * @private
        */
        _setReadOnly: function (bool) {
            if (bool) {
                this.element.attr("readonly", true);
            }
            else {
                this.element.removeAttr("readonly");
            }
        },
        /**
        * To configure the properties at runtime	
        * @private
        */
        _setModel: function (options) {
            var refresh = false;
            for (var prop in options) {
                switch (prop) {
                    case "renderMode": this._setRenderMode(options.renderMode); break;
                    case "showBorder": this._showBorder(options.showBorder); break;
                    case "theme": this._setTheme(options.theme); break;
                    case "value": this._setValue(options.value); break;
                    case "watermarkText": this._setWatermarkText(options.watermarkText); break;
                    case "mask": this._setMask(options.mask); break;
                    case "enabled": options.enabled ? (this.enable(), this._wireEvents(false)) : (this.disable(), this._wireEvents(true)); break;
                    case "readOnly": this._setReadOnly(options.readOnly); break;
                }
            }
        },
        _clearElement: function () {
            this._wireEvents(true);
            //var parent = ej.buildTag("input");
            this.element.parent().removeAttr("class");
        },
        // all events bound using this._on will be unbind automatically
        /**
        * To destroy the control		
        * @private
        */
        _destroy: function () {
            this._cloneElement.insertBefore(this.element);
            this.element.remove();
        },

        /*---------------Public Methods---------------*/
        /**
        * To handle the TextBox, or Password or MaskEdit or TextArea to enable
        * @return jQuery

        * @example 
        * //For TextBox
        * &lt;input id="textbox" /&gt;<br>
        * &lt;script&gt;
        * // Create the textbox
        * $("#textbox").ejmTextBox();
        * var textbox = $("#textbox").data("ejmTextBox");
        * textbox.enable(); // Returns the textbox to enable mode.
        * &lt;/script&gt;
        * @example 
        * &lt;input id="textbox"/&gt;<br>
        * &lt;script&gt;
        * // Get the textbox to enable
        * $("#textbox").ejmTextBox();
        * $("#textbox").ejmTextBox("enable");	
        * &lt;/script&gt;

        * @example 
        * //For Password
        * &lt;input id="password" /&gt;<br>
        * &lt;script&gt;
        * // Create the password
        * $("#password").ejmPassword();
        * var password = $("#password").data("ejmPassword");
        * password.enable(); // Returns the password to enable mode.
        * &lt;/script&gt;
        * @example 
        * &lt;input id="password"/&gt;<br>
        * &lt;script&gt;
        * // Get the password to enable
        * $("#password").ejmPassword();
        * $("#password").ejmPassword("enable");	
        * &lt;/script&gt;
        
        * @example 
        * //For MaskEdit
        * &lt;input id="maskedit" /&gt;<br>
        * &lt;script&gt;
        * // Create the maskedit
        * $("#maskedit").ejmMaskEdit();
        * var maskedit = $("#maskedit").data("ejmMaskEdit");
        * maskedit.enable(); // Returns the maskedit to enable mode.
        * &lt;/script&gt;
        * @example 
        * &lt;input id="maskedit"/&gt;<br>
        * &lt;script&gt;
        * // Get the maskedit to enable
        * $("#maskedit").ejmMaskEdit();
        * $("#maskedit").ejmMaskEdit("enable");	
        * &lt;/script&gt;
        
        * @example 
        * //For Text Area
        * &lt;textarea id="textarea" &gt;&lt;/textarea&gt;<br>
        * &lt;script&gt;
        * // Create the textarea
        * $("#textarea").ejmTextArea();
        * var textarea = $("#textarea").data("ejmTextArea");
        * textarea.enable(); // Returns the textarea to enable mode.
        * &lt;/script&gt;
        * @example 
        * &lt;textarea id="textarea"&gt;&lt;/textarea&gt;<br>
        * &lt;script&gt;
        * // Get the textarea to enable
        * $("#textarea").ejmTextArea();
        * $("#textarea").ejmTextArea("enable");	
        * &lt;/script&gt;
        *@memberof ejmTextBox
        * @instance
        */
        enable: function () {
            this.model.enabled = true;
            this.element.removeClass("e-m-state-disabled");
            this._wireEvents(false);
        },
        /**
        * To handle the TextBox, or Password or MaskEdit or TextArea to disable
        * @return jQuery
        
        * @example 
        * //For TextBox
        * &lt;input id="textbox" /&gt;<br>
        * &lt;script&gt;
        * // Create the textbox
        * $("#textbox").ejmTextBox();
        * var textbox = $("#textbox").data("ejmTextBox");
        * textbox.disable(); // Returns the textbox to disable mode.
        * &lt;/script&gt;
        * @example 
        * &lt;input id="textbox"/&gt;<br>
        * &lt;script&gt;
        * // Get the textbox to disable
        * $("#textbox").ejmTextBox();
        * $("#textbox").ejmTextBox("disable");	
        * &lt;/script&gt;
        
        * @example 
        * //For Password
        * &lt;input id="password" /&gt;<br>
        * &lt;script&gt;
        * // Create the password
        * $("#password").ejmPassword();
        * var password = $("#password").data("ejmPassword");
        * password.disable(); // Returns the password to disable mode.
        * &lt;/script&gt;
        * @example 
        * &lt;input id="password"/&gt;<br>
        * &lt;script&gt;
        * // Get the password to disable
        * $("#password").ejmPassword();
        * $("#password").ejmPassword("disable");	
        * &lt;/script&gt;

        * @example 
        * //For MaskEdit
        * &lt;input id="maskedit" /&gt;<br>
        * &lt;script&gt;
        * // Create the MaskEdit
        * $("#maskedit").ejmMaskEdit({mask:"+1 (999) 999-9999"});
        * var maskedit = $("#maskedit").data("ejmMaskEdit");
        * maskedit.disable(); // returns the maskedit to disable mode.
        * &lt;/script&gt;
        * @example 
        * &lt;input id="maskedit"/&gt;<br>
        * &lt;script&gt;
        * // Get the maskedit to disable
        * $("#maskedit").ejmMaskEdit({mask:"+1 (999) 999-9999"});
        * $("#maskedit").ejmMaskEdit("disable");	
        * &lt;/script&gt;
       
        
        * @example 
        * //For Text Area
        * &lt;textarea id="textarea" &gt; &lt;/textarea&gt;<br>
        * &lt;script&gt;
        * // Create the textarea
        *$("#textarea").ejmTextArea();
        * var textarea = $("#textarea").data("ejmTextArea");
        * textarea.disable(); // Returns the textarea to disable mode.
        * &lt;/script&gt;
        * @example 
        * &lt;textarea id="textarea"&gt;&lt;/textarea&gt;<br>
        * &lt;script&gt;
        * // Get the textarea to disable
        * $("#textarea").ejmTextArea();
        * $("#textarea").ejmTextArea("disable");	
        * &lt;/script&gt;
        *@memberof ejmTextBox
        * @instance
        */
        disable: function () {
            this.model.enabled = false;
            this.element.addClass("e-m-state-disabled");
            this._wireEvents(true);
        },
        /**
        * To handle the TextBox, or Password or MaskEdit or TextArea to getStrippedValue
        * @return jQuery

        * @example 
        * //For TextBox
        * &lt;input id="textbox" /&gt;<br>
        * &lt;script&gt;
        * // Create the textbox
        * $("#textbox").ejmTextBox();
        * var textbox = $("#textbox").data("ejmTextBox");
        * textbox.getStrippedValue(); // Returns the textbox value with stripped mode.
        * &lt;/script&gt;
        * @example 
        * &lt;input id="textbox"/&gt;<br>
        * &lt;script&gt;
        * // Get the textbox to getStrippedValue
        * $("#textbox").ejmTextBox();
        * $("#textbox").ejmTextBox("getStrippedValue");	
        * &lt;/script&gt;

        * @example 
        * //For Password
        * &lt;input id="password" /&gt;<br>
        * &lt;script&gt;
        * // Create the password
        * $("#password").ejmPassword();
        * var password = $("#password").data("ejmPassword");
        * password.getStrippedValue(); // Returns the password value with stripped mode.
        * &lt;/script&gt;
        * @example 
        * &lt;input id="password"/&gt;<br>
        * &lt;script&gt;
        * // Get the password to getStrippedValue
        * $("#password").ejmPassword();
        * $("#password").ejmPassword("getStrippedValue");	
        * &lt;/script&gt;

        * @example 
        * //For MaskEdit
        * &lt;input id="maskedit" /&gt;<br>
        * &lt;script&gt;
        * // Create the MaskEdit
        * $("#maskedit").ejmMaskEdit();
        * var maskedit = $("#maskedit").data("ejmMaskEdit");
        * maskedit.getStrippedValue(); // Returns the maskedit Value with Stripped mode.
        * &lt;/script&gt;
        * @example 
        * &lt;input id="maskedit"/&gt;<br>
        * &lt;script&gt;
        * // Get the maskedit to getStrippedValue
        * $("#maskedit").ejmMaskEdit();
        * $("#maskedit").ejmMaskEdit("getStrippedValue");	
        * &lt;/script&gt;

        * @example 
        * //For Text Area
        * &lt;textarea id="textarea" &gt; &lt;/textarea&gt;<br>
        * &lt;script&gt;
        * // Create the textarea
        * $("#textarea").ejmTextArea();
        * var textarea = $("#textarea").data("ejmTextArea");
        * textarea.getStrippedValue(); // Returns the textarea value with stripped mode.
        * &lt;/script&gt;
        * @example 
        * &lt;textarea id="textarea"&gt;&lt;/textarea&gt;<br>
        * &lt;script&gt;
        * // Get the textarea to getStrippedValue
        * $("#textarea").ejmTextArea();
        * $("#textarea").ejmTextArea("getStrippedValue");	
        * &lt;/script&gt;
        *@memberof ejmTextBox
        * @instance
        */
        /* Return the pure value of the textvalue, removes all the symbols*/
        getStrippedValue: function () {
            var val = this.element.val();
            var stripVal = "";
            if (val != undefined)
                stripVal = val.replace(/[^a-zA-Z0-9]/g, "");
            return stripVal;
        },
        /**
        * To handle the TextBox, or Password or MaskEdit or TextArea to getUnstrippedValue
        * @return jQuery

        * @example 
        * //For TextBox
        * &lt;input id="textbox" /&gt;<br>
        * &lt;script&gt;
        * // Create the textbox
        * $("#textbox").ejmTextBox();
        * var textbox = $("#textbox").data("ejmTextBox");
        * textbox.getUnstrippedValue(); // Returns the textbox value with unstripped mode.
        * &lt;/script&gt;
        * @example 
        * &lt;input id="textbox"/&gt;<br>
        * &lt;script&gt;
        * // Get the textbox to getUnstrippedValue
        * $("#textbox").ejmTextBox();
        * $("#textbox").ejmTextBox("getUnstrippedValue");	
        * &lt;/script&gt;

        * @example 
        * //For Password
        * &lt;input id="password" /&gt;<br>
        * &lt;script&gt;
        * // Create the password
        * $("#password").ejmPassword();
        * var password = $("#password").data("ejmPassword");
        * password.getUnstrippedValue(); // Returns the password value with unstripped mode.
        * &lt;/script&gt;
        * @example 
        * &lt;input id="password"/&gt;<br>
        * &lt;script&gt;
        * // Get the password to getUnstrippedValue
        * $("#password").ejmPassword();
        * $("#password").ejmPassword("getUnstrippedValue");	
        * &lt;/script&gt;

        * @example 
        * //For MaskEdit
        * &lt;input id="maskedit" /&gt;<br>
        * &lt;script&gt;
        * // Create the MaskEdit
        * $("#maskedit").ejmMaskEdit();
        * var maskedit = $("#maskedit").data("ejmMaskEdit");
        * maskedit.getUnstrippedValue(); // Returns the maskedit value with unstripped mode.
        * &lt;/script&gt;
        * @example 
        * &lt;input id="maskedit"/&gt;<br>
        * &lt;script&gt;
        * // Get the maskedit to getUnstrippedValue
        * $("#maskedit").ejmMaskEdit();
        * $("#maskedit").ejmMaskEdit("getUnstrippedValue");	
        * &lt;/script&gt;

        * @example 
        * //For Text Area
        * &lt;textarea id="textarea" &gt;&lt;/textarea&gt;<br>
        * &lt;script&gt;
        * // Create the textarea
        * $("#textarea").ejmTextArea();
        * var textarea = $("#textarea").data("ejmTextArea");
        * textarea.getUnstrippedValue(); // Returns the textarea value with unstripped mode.
        * &lt;/script&gt;
        * @example 
        * &lt;textarea id="textarea"&gt; &lt;/textarea &gt;<br>
        * &lt;script&gt;
        * // Get the textarea to getUnstrippedValue
        * $("#textarea").ejmTextArea();
        * $("#textarea").ejmTextArea("getUnstrippedValue");	
        * &lt;/script&gt;
        *@memberof ejmTextBox
        * @instance
        */
        /* Return the textbox value as such that, Just replace all '_' to ' '(space)*/
        getUnstrippedValue: function () {
            var val = this.element.val();
            var unstripVal = "";
            if (val != undefined)
                unstripVal = val.replace(/[_]/g, " ");
            return unstripVal;
        },
        /**
        * To handle the TextBox, or Password or MaskEdit or TextArea to getWatermarkText
        * @return jQuery

        * @example 
        * //For TextBox
        * &lt;input id="textbox" /&gt;<br>
        * &lt;script&gt;
        * // Create the textbox
        * $("#textbox").ejmTextBox();
        * var textbox = $("#textbox").data("ejmTextBox");
        * textbox.getWatermarkText(); // Returns the textbox watermarkText.
        * &lt;/script&gt;
        * @example 
        * &lt;input id="textbox"/&gt;<br>
        * &lt;script&gt;
        * //Get the textbox to getWatermarkText
        * $("#textbox").ejmTextBox();
        * $("#textbox").ejmTextBox("getWatermarkText");	
        * &lt;/script&gt;
       
        * @example 
        * //For Password
        * &lt;input id="password" /&gt;<br>
        * &lt;script&gt;
        * // Create the password
        * $("#password").ejmPassword();
        * var password = $("#password").data("ejmPassword");
        * password.getWatermarkText(); // Returns the password watermarkText.
        * &lt;/script&gt;
        * @example 
        * &lt;input id="password"/&gt;<br>
        * &lt;script&gt;
        * // Get the password to getWatermarkText
        * $("#password").ejmPassword();
        * $("#password").ejmPassword("getWatermarkText");	
        * &lt;/script&gt;

        * @example 
        * //For MaskEdit
        * &lt;input id="maskedit" /&gt;<br>
        * &lt;script&gt;
        * // Create the maskedit
        * $("#maskedit").ejmMaskEdit();
        * var maskedit = $("#maskedit").data("ejmMaskEdit");
        * maskedit.getWatermarkText(); // Returns the maskedit watermarkText.
        * &lt;/script&gt;
        * @example 
        * &lt;input id="maskedit"/&gt;<br>
        * &lt;script&gt;
        * // Get the maskedit to getWatermarkText
        * $("#maskedit").ejmMaskEdit();
        * $("#maskedit").ejmMaskEdit("getWatermarkText");	
        * &lt;/script&gt;

        * @example
        * //For Text Area 
        * &lt;textarea id="textarea" &gt;&lt;/textarea&gt;<br>
        * &lt;script&gt;
        * // Create the textarea
        * $("#textarea").ejmTextArea();
        * var textarea = $("#textarea").data("ejmTextArea");
        * textarea.getWatermarkText(); // Returns the textarea watermarkText.
        * &lt;/script&gt;
        * @example 
        * &lt;textarea id="textarea"&gt; &lt;/textarea &gt;<br>
        * &lt;script&gt;
        * // Get the textarea to getWatermarkText
        * $("#textarea").ejmTextArea();
        * $("#textarea").ejmTextArea("getWatermarkText");	
        * &lt;/script&gt;
        *@memberof ejmTextBox
        * @instance
        */
        getWatermarkText: function () {
            return this.model.watermarkText;
        },
        /**
        * To handle the TextBox, or Password or MaskEdit or TextArea to getValue
        * @return jQuery

        * @example 
        * //For TextBox
        * &lt;input id="textbox" /&gt;<br>
        * &lt;script&gt;
        * // Create the textbox
        * $("#textbox").ejmTextBox();
        * var textbox = $("#textbox").data("ejmTextBox");
        * textbox.getValue(); // Returns the textbox value.
        * &lt;/script&gt;
        * @example 
        * &lt;input id="textbox"/&gt;<br>
        * &lt;script&gt;
        * // Get the textbox to getValue
        * $("#textbox").ejmTextBox();
        * $("#textbox").ejmTextBox("getValue");	
        * &lt;/script&gt;

        * @example 
        * //For Password
        * &lt;input id="password" /&gt;<br>
        * &lt;script&gt;
        * // Create the password
        * $("#password").ejmPassword();
        * var password = $("#password").data("ejmPassword");
        * password.getValue(); // Returns the password value.
        * &lt;/script&gt;
        * @example 
        * &lt;input id="password"/&gt;<br>
        * &lt;script&gt;
        * // Get the password to getValue
        * $("#password").ejmPassword();
        * $("#password").ejmPassword("getValue");	
        * &lt;/script&gt;

        * @example 
        * //For MaskEdit
        * &lt;input id="maskedit" /&gt;<br>
        * &lt;script&gt;
        * // Create the maskedit
        * $("#maskedit").ejmMaskEdit();
        * var maskedit = $("#maskedit").data("ejmMaskEdit");
        * maskedit.getValue(); // Returns the maskedit value.
        * &lt;/script&gt;
        * @example 
        * &lt;input id="maskedit"/&gt;<br>
        * &lt;script&gt;
        * // Get the maskedit to getValue
        * $("#maskedit").ejmMaskEdit();
        * $("#maskedit").ejmMaskEdit("getValue");	
        * &lt;/script&gt;

        * @example 
        * //For Text Area
        * &lt;textarea id="textarea" &gt;&lt;/textarea&gt;<br>
        * &lt;script&gt;
        * // Create the textarea
        * $("#textarea").ejmTextArea();
        * var textarea = $("#textarea").data("ejmTextArea");
        * textarea.getValue(); // Returns the textarea value.
        * &lt;/script&gt;
        * @example 
        * &lt;textarea id="textarea"&gt;&lt;/textarea&gt;<br>
        * &lt;script&gt;
        * // Get the textarea to getValue
        * $("#textarea").ejmTextArea();
        * $("#textarea").ejmTextArea("getValue");	
        * &lt;/script&gt;
        *@memberof ejmTextBox
        * @instance
        */
        getValue: function () {
            return this.value();
        },
        /**
        * To refresh the control		
        * @private
        */
        refresh: function () {
            this._clearElement();
            this._renderControl();
            this._wireEvents(false);
        }
        /*---------------Public Methods End---------------*/
    });
})(jQuery, Syncfusion);