/**
* @fileOverview Plugin to style the Html Tile elements
* @copyright Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/
(function ($, ej, undefined) {
    /**
    * @namespace ej
    * @class ejmTile
    * @requires jQuery
    * @requires ej.mobile.application
    * @requires ej.core
    * @requires ej.unobtrusive
    * @requires ej.mobile.core
    * @requires ej.data
    * @requires ej.touch
    * @requires ej.tilebase
    * @classdesc Custom Design for Html Tile control.
    * @example 
    * &lt;div id="tile" data-role="ejmtile" data-ej-imagepath="themes/sample/tile" data-ej-imageurl="people.png"&gt;&lt;/div&gt;<br>
    * @example 
    * &lt;div id="tile" &gt;&lt;/div&gt;<br>
    * &lt;script&gt; 
    * // Create Tile control 
    * $("#tile").ejmTile({ imagePath: "themes/sample/tile", imageUrl: "people.png" }); 
    * &lt;/script&gt;
    */

    // ejmTile is the plugin name 
    // "ej.mobile.Tile" is "namespace.className" will hold functions and properties
    ej.widget("ejmTile", "ej.mobile.Tile", {
        _setFirst: true,
        // default model
        _rootCSS: "e-m-tile",
        defaults: {
            /**		
            * Specifies the file path of tile image.
            * @default null
            * @type {string}
            * @example 
            * //Set the imagePath property in unobtrusive way.
            * &lt;div id="tile" data-role="ejmtile" data-ej-imagepath="themes/sample/tile" data-ej-imageurl="people.png"&gt;
            * &lt;/div&gt;  
            * @example 
            * // Set imagePath on initialization. 
            * // To set imagePath API value 
            * &lt;div id="tile" &gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // Create Tile control 
            * $("#tile").ejmTile({ imagePath: "themes/sample/tile", imageUrl: "people.png" }); 
            * &lt;/script&gt;
            * @example 
            * //Get or set the imagePath, after initialization:<br>
            * // Get the imagePath API value.
            *  $("#tile").ejmTile("option", "imagePath");			
            * // Set the imagePath API
            * $("#tile").ejmTile("option", "imagePath", "themes/sample/tile");            
            * @memberof ejmTile
            * @instance
            */
            imagePath: null,
            /**		
            * Changes the rendering mode of Tile.
            * @default auto
            * @type {enum}
            * @example 
            * //Set the renderMode property in unobtrusive way.
            * &lt;div id="tile" data-role="ejmtile" data-ej-imagepath="themes/sample/tile" data-ej-imageurl="people.png" data-ej-rendermode="android" &gt;
            * &lt;/div&gt;  
            * @example 
            * // Set renderMode on initialization. 
            * // To set renderMode API value 
            * &lt;div id="tile" &gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // Create Tile control 
            * $("#tile").ejmTile({ imagePath: "themes/sample/tile", imageUrl: "people.png", renderMode:"android" }); 
            * &lt;/script&gt;
            * @example 
            * //Get or set the renderMode, after initialization:<br>
            * // Get the renderMode API value.
            *  $("#tile").ejmTile("option", "renderMode");			
            * // Set the renderMode API
            * $("#tile").ejmTile("option", "renderMode", "android");            
            * @memberof ejmTile
            * @instance
            */
            renderMode: "auto",
            /**		
            * Changes the theme of Tile.
            * @default auto
            * @type {enum}
            * @example 
            * //Set the theme property in unobtrusive way.
            * &lt;div id="tile" data-role="ejmtile" data-ej-imagepath="themes/sample/tile" data-ej-imageurl="people.png" data-ej-theme="dark" &gt;
            * &lt;/div&gt;  
            * @example 
            * // Set theme on initialization. 
            * // To set theme API value 
            * &lt;div id="tile" &gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // Create Tile control 
            * $("#tile").ejmTile({ imagePath: "themes/sample/tile", imageUrl: "people.png", theme:"dark" }); 
            * &lt;/script&gt;
            * @example 
            * //Get or set the theme, after initialization:<br>
            * // Get the theme API value.
            *  $("#tile").ejmTile("option", "theme");			
            * // Set the theme API
            * $("#tile").ejmTile("option", "theme", "dark");            
            * @memberof ejmTile
            * @instance
            */
            theme: "auto",
            /**     
            * Section for ios7 rendermode specific functionalities.                      
            * @memberof ejmTile
            * @instance
            */
            ios7: {
                /**	
                * Specifies the position of the tile text. i.e inner or outer.
                * @default "inner"
                * @type {enum}
                * @alias ejmTile#ios7->textPosition
                * @example 
                * //Set the textPosition property in unobtrusive way.
                * &lt;div id="tile" data-role="ejmtile" data-ej-rendermode="ios7" data-ej-ios7-textposition="outer" data-ej-imagepath="themes/sample/tile" data-ej-imageurl="people.png" &gt;
                * &lt;/div&gt;  
                * @example 
                * // Set textPosition on initialization. 
                * // To set textPosition API value 
                * &lt;div id="tile" &gt;&lt;/div&gt;<br>
                * &lt;script&gt; 
                * // Create Tile control 
                * $("#tile").ejmTile({ renderMode:"ios7", ios7:{ textPosition:"outer" }, imagePath: "themes/sample/tile", imageUrl:"people.png" }); 
                * &lt;/script&gt;
                * @example 
                * //Get or set the textPosition, after initialization:<br>
                * // Get the textPosition API value.
                *  $("#tile").ejmTile("option", "ios7.textPosition");			
                * // Set the textPosition API
                * $("#tile").ejmTile("option", "ios7.textPosition", "outer");            
                * @memberof ejmTile
                * @instance
                */
                textPosition: "inner"
            },
            /**     
            * Section for android rendermode specific functionalities.                      
            * @memberof ejmTile
            * @instance
            */
            android: {
                /**	
                * Specifies the position of the tile text. i.e inner or outer.
                * @default "inner"
                * @type {enum}
                * @alias ejmTile#android->textPosition
                * @example 
                * //Set the textPosition property in unobtrusive way.
                * &lt;div id="tile" data-role="ejmtile" data-ej-rendermode="android" data-ej-android-textposition="outer" data-ej-imagepath="themes/sample/tile" data-ej-imageurl="people.png" &gt;
                * &lt;/div&gt;  
                * @example 
                * // Set textPosition on initialization. 
                * // To set textPosition API value 
                * &lt;div id="tile" &gt;&lt;/div&gt;<br>
                * &lt;script&gt; 
                * // Create Tile control 
                * $("#tile").ejmTile({ renderMode:"android", android:{ textPosition:"outer" }, imagePath: "themes/sample/tile", imageUrl:"people.png" }); 
                * &lt;/script&gt;
                * @example 
                * //Get or set the textPosition, after initialization:<br>
                * // Get the textPosition API value.
                *  $("#tile").ejmTile("option", "android.textPosition");			
                * // Set the textPosition API
                * $("#tile").ejmTile("option", "android.textPosition", "outer");            
                * @memberof ejmTile
                * @instance
                */
                textPosition: "inner"
            },

            //Mobile
            /**		
            * Changes the background color of Tile.
            * @default null
            * @type {string}
            * @example 
            * //Set the backgroundColor property in unobtrusive way.
            * &lt;div id="tile" data-role="ejmtile" data-ej-imagepath="themes/sample/tile" data-ej-imageurl="people.png" data-ej-tilesize="medium" data-ej-backgroundcolor="black" &gt;
            * &lt;/div&gt;  
            * @example 
            * // Set backgroundColor on initialization. 
            * // To set backgroundColor API value 
            * &lt;div id="tile" &gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // Create Tile control 
            * $("#tile").ejmTile({ imagePath: "themes/sample/tile", imageUrl: "people.png", tileSize: "medium", backgroundColor:"black" }); 
            * &lt;/script&gt;
            * @example 
            * //Get or set the backgroundColor, after initialization:<br>
            * // Get the backgroundColor API value.
            *  $("#tile").ejmTile("option", "backgroundColor");			
            * // Set the backgroundColor API
            * $("#tile").ejmTile("option", "backgroundColor", "black");            
            * @memberof ejmTile
            * @instance
            */
            backgroundColor: null,
            /**    
            * Event triggers when the touchstart happens in the tile
            * @event
            * @name ejmTile#touchStart 	
            * @param {Object} argument Event parameters from tile     
            * @param {boolean} argument.cancel if the event should be canceled; otherwise, false.
            * @param {boolean} argument.model returns the tile model
            * @param {boolean} argument.type returns the name of the event
            * @param {boolean} argument.text returns the current tile text
            * @example 
            * //Define touchStart event in unobtrusive way.
            * &lt;div id="tile" data-role="ejmtile" data-ej-imagepath="themes/sample/tile" data-ej-imageurl="people.png" data-ej-touchstart="touchstart" &gt;
            * &lt;/div&gt;  
            * &lt;script&gt;
            * // touchStart event for tile
            * function touchstart(args){ 
            * //handle the event
            * }
            * &lt;/script&gt;
            * @example 
            * // Define touchStart event on initialization. 
            * // To set touchStart event API value 
            * &lt;div id="tile" &gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // Create Tile control 
            * $("#tile").ejmTile({ imagePath: "themes/sample/tile", imageUrl: "people.png", 
            * touchStart: function (args) { 
            * //handle the event 
            * }
            * }); 
            * &lt;/script&gt;
            * @memberof ejmTile
            * @instance
            */
            touchStart: null,

            /**    
            * Event triggers when the touchend happens in the tile
            * @event
            * @name ejmTile#touchEnd 	
            * @param {Object} argument Event parameters from tile     
            * @param {boolean} argument.cancel if the event should be canceled; otherwise, false.
            * @param {boolean} argument.model returns the tile model
            * @param {boolean} argument.type returns the name of the event
            * @param {boolean} argument.text returns the current tile text
            * @example 
            * //Define touchEnd event in unobtrusive way.
            * &lt;div id="tile" data-role="ejmtile" data-ej-imagepath="themes/sample/tile" data-ej-imageurl="people.png" data-ej-touchend="touchend" &gt;
            * &lt;/div&gt;  
            * &lt;script&gt;
            * // touchEnd event for tile
            * function touchend(args){ 
            * //handle the event
            * }
            * &lt;/script&gt;
            * @example 
            * // Define touchEnd event on initialization. 
            * // To set touchEnd event API value 
            * &lt;div id="tile" &gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // Create Tile control 
            * $("#tile").ejmTile({ imagePath: "themes/sample/tile", imageUrl: "people.png", 
            * touchEnd: function (args) { 
            * //handle the event 
            * }
            * }); 
            * &lt;/script&gt;
            * @memberof ejmTile
            * @instance
            */
            touchEnd: null
        },
        dataTypes: {
            ios7: {
                textPosition: "enum"
            },
            android: {
                textPosition: "enum"
            },
            renderMode: "enum",
            theme: "enum",
            backgroundColor: "string"
        },
        //Constructor function
        _init: function () {
            this._orgEle = this.element.clone();
            this._renderEJMControl();
        },
        //To render the Tile control
        _renderEJMControl: function () {
            ej.setRenderMode(this);
            ej.setTheme(this);
            this._prefix = "e-m-";
            this.element.addClass("e-m-" + this.model.renderMode + " e-m-" + this.model.theme);
            this._tileRender();
            if ((this.model.renderMode == "windows" && this.model.tileSize != "small") || this.model.renderMode == "flat")
                this.element.css("background-color", this.model.backgroundColor);
            if (this.model.renderMode == "windows" && this.model.tileSize == "small" && !this._isCustomizeSize())
                this.element.find(".e-m-fontimage").css("background-color", this.model.backgroundColor);
            if (this.model.renderMode == "windows" && this.model.tileSize == "small" && this._isCustomizeSize())
                this.element.css("background-color", this.model.backgroundColor);
            if (this.model.renderMode == "ios7" || this.model.renderMode == "android") {
                this.element.addClass("e-m-text-" + this.model[this.model.renderMode].textPosition.toLowerCase());
                if (this.model[this.model.renderMode].textPosition == "inner") {
                    this._mainTile.append(this._layer);
                    if (this.model.tileSize == 'small')
                        this._isCustomizeSize() ? this.element.css("background-color", this.model.backgroundColor).find("." + this._prefix + "child-tile").append(this._layer) : this.element.find("." + this._prefix + "tile-image").css("background-color", this.model.backgroundColor).append(this._layer);
                    else
                        this.element.css("background-color", this.model.backgroundColor);
                    this.model.textAlignment == "left" && this._isCustomizeSize() ? this.element.find("." + this._prefix + "tile-text").css({ "width": this.model.width - 8 }) : "";
                    this._isBelowSmallSize() ? this.element.find("." + this._prefix + "tile-image").css({ "margin": 0, "width": this.model.width, "height": this.model.height }) : "";
                    this.model.renderMode == "android" && this._isBelowSmallSize() ? this.element.removeClass(this._prefix + "tile-wrapper-small").addClass(this._prefix + "tile-wrapper-medium") : "";
                }
                if (((this.model[this.model.renderMode].textPosition == "outer") && ((this.model.tileSize != "small") || (this.model.tileSize == "small" && this._isCustomizeSize())))) {
                    this._image.css("background-color", this.model.backgroundColor).append(this._layer);
                    if (this._isCustomizeSize()) {
                        if (this.model.renderMode == "ios7") {
                            this.element.find("." + this._prefix + "tile-image").css({ "margin": 12, "margin-top": 0, "margin-bottom": 0, "width": this.model.width - 24, "height": this.model.height - 24 });
                            this.model.showText ? this.element.find("." + this._prefix + "tile-text").css({ "width": this.model.width - 24 }) : "";
                        }
                        else {
                            this.element.find("." + this._prefix + "tile-image").css({ "margin-left": 15, "margin-top": 0, "margin-bottom": 0, "width": this.model.width - 30, "height": this.model.height - 30 });
                            this.model.showText ? this.element.find("." + this._prefix + "tile-text").css({ "width": this.model.width - 30 }) : "";
                        }
                            if (this.model.tileSize == "small" && this._isBelowSmallSize())
                            this.element.find("." + this._prefix + "tile-image").css({ "margin": 7, "width": this.model.width - 14, "height": this.model.height - 14 });
                    }
                }
                if (this._isBelowSmallSize() && this.model[this.model.renderMode].textPosition == "outer") {
                    this.element.removeClass(this._prefix + "text-outer").addClass(this._prefix + "text-inner");
                    this.model.backgroundColor ? this.element.css("background-color", this.model.backgroundColor) : "";
                    this._mainTile.append(this._layer);
                }
            }
            else
                this._mainTile.append(this._layer);
            this._wireEvents();
        },
        //Section for handling the touchstart event
        _onTouchStartHandler: function (evt) {
            var item = this.element, eventobj;
            if (this.model.renderMode == "windows")
                eventobj = evt.touches ? evt.touches[0] : evt;
            if (ej.isWindows())
                ej._touchStartPoints(evt, this);
            item.addClass(this.model.renderMode == "windows" ? ej._getSkewClass(item, eventobj.pageX, eventobj.pageY) : this._prefix + "state-active");
            if (this.model.touchStart)
                this._trigger("touchStart", { text: item.find(".e-m-tile-text").html() });
            ej.listenTouchEvent(this.element, ej.moveEvent(), this._onMoveDelegate, false);
            ej.listenTouchEvent(this.element, ej.endEvent(), this._onEndDelegate, false);
            this._isMoved = false;
        },
        //Section for handling the touchmove event
        _onTouchMoveHandler: function (evt) {
            if (!ej.isWindows() || (ej.isWindows() && ej._isTouchMoved(evt, this))) {
                this._isMoved = true;
                this._removeActiveClass();
            }
        },
        // Section for handling the touchstart event
        _onTouchEndHandler: function (evt) {
            if (!this._isMoved && this.model.touchEnd)
                this._trigger("touchEnd", { text: this.element.find(".e-m-tile-text").html() });
            this._removeActiveClass();
            this._isMoved = false;
            ej.listenTouchEvent(this.element, ej.moveEvent(), this._onMoveDelegate, true);
            ej.listenTouchEvent(this.element, ej.endEvent(), this._onEndDelegate, true);
        },
        //To refresh the control
        _refresh: function () {
            this._destroy();
            this.element.removeAttr("style");
            this.element.addClass(this._prefix + "tile e-js");
            this._renderEJMControl();
        }
    });
    /**
    * Enum for Tile ImagePosition
    * @enum {string}
    * @global
    */
    ej.mobile.Tile.ImagePosition = {
        /**
        Enum for center position of tile image*/
        Center: "center",
        /**
        Enum for top position of tile image*/
        Top: "top",
        /**
        Enum for bottom position of tile image*/
        Bottom: "bottom",
        /**
        Enum for right position of tile image*/
        Right: "right",
        /**
        Enum for left position of tile image*/
        Left: "left",
        /**
        Enum for topleft position of tile image*/
        TopLeft: "topleft",
        /**
        Enum for topright position of tile image*/
        TopRight: "topright",
        /**
        Enum for bottomright position of tile image*/
        BottomRight: "bottomright",
        /**
        Enum for bottomleft position of tile image*/
        BottomLeft: "bottomleft",
        /**
        Enum for fill position of tile image*/
        Fill: "fill"
    },
    /**
    * Enum for Tile TextAlignment
    * @enum {string}
    * @global
    */
    ej.mobile.Tile.TextAlignment = {
        /**
        Enum for normal alignment of tile text*/
        Normal: "normal",
        /**
        Enum for left alignment of tile text*/
        Left: "left",
        /**
        Enum for right alignment of tile text*/
        Right: "right",
        /**
        Enum for center alignment of tile text*/
        Center: "center"
    },
    /**
    * Enum for Tile TextPosition
    * @enum {string}
    * @global
    */
    ej.mobile.Tile.TextPosition = {
        /**
        Enum for inner position of tile text*/
        Inner: "inner",
        /**
        Enum for outer position of tile text*/
        Outer: "outer"
    },
    /**
    * Enum for Tile Size
    * @enum {string}
    * @global
    */
    ej.mobile.Tile.TileSize = {
        /**
        Enum for medium size of tile*/
        Medium: "medium",
        /**
        Enum for small size of tile*/
        Small: "small",
        /**
        Enum for large size of tile*/
        Large: "large",
        /**
        Enum for wide size of tile*/
        Wide: "wide"
    },
    /**
    * Enum for LiveTileType
    * @enum {string}
    * @global
    */
    ej.mobile.Tile.LiveTileType = {
        /**
        Enum for flip type of livetile*/
        Flip: "flip",
        /**
        Enum for slide type of livetile*/
        Slide: "slide",
        /**
        Enum for carousel type of livetile*/
        Carousel: "carousel"
    }
    $.extend(true, ej.mobile.Tile.prototype, ej.TileBase.prototype);
})(jQuery, Syncfusion);