﻿/**
* @fileOverview Plugin to style the Html Timepicker elements
* @copyright Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/
(function ($, ej, undefined) {
    /**
    * @namespace ej
    * @class ejmTimePicker
    * @requires jQuery
    * @requires ej.mobile.application
    * @requires ej.core
    * @requires ej.unobtrusive
    * @requires ej.mobile.core
    * @requires ej.data
    * @requires ej.touch    
    * @requires ej.mobile.menu
    * @requires ej.mobile.dialog
    * @requires ej.mobile.button
    * @requires ej.mobile.toolbar
    * @requires ej.mobile.scrollbar
    * @requires ej.mobile.scrollpanel
    * @classdesc Custom Design for Html TimePicker control.
    * @example 
    * &lt;input id="timepicker" data-role="none" /&gt;<br>
    * &lt;script&gt;  
    * $(function(){
    * $("#timepicker").ejmTimePicker(); 
    * });
    * &lt;/script&gt;
    */
    ej.widget("ejmTimePicker", "ej.mobile.TimePicker", {
        _setFirst: true,
        // default model
        _rootCSS: "e-m-timepicker",
        defaults: {
            /**		
            * Changes the rendering mode. See {@link RenderMode}
            * @default auto
            * @type {enum}
            * @example 
            * //Set the renderMode property in Unobtrusive way.
            * &lt;input id="timepicker" data-role="ejmtimepicker" data-ej-rendermode="auto" /&gt;<br>
            * @example 
            * // Set the renderMode on initialization. 
            * //To set renderMode API value 
            * &lt;input id="timepicker" data-role="none" /&gt;<br>
            * &lt;script&gt;
            * $(function(){
            * $("#timepicker").ejmTimePicker({ renderMode: "auto" });			
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the renderMode, after initialization:<br>
            * // Get the renderMode API value.		
            *  $("#timepicker").ejmTimePicker("option", "renderMode");			
            * // Set the renderMode API
            * $("#timepicker").ejmTimePicker("option", "renderMode", "auto");            
            * @memberof ejmTimePicker
            * @instance
            */
            renderMode: "auto",
            /**		
            * Specifies the hour format See {@link HourFormat}.
            * @default "twentyfour"
            * @type {enum}
            * @example 
            * //Set the hourFormat property in Unobtrusive way.
            * &lt;input id="timepicker" data-role="ejmtimepicker" data-ej-hourformat="twentyfour" /&gt;<br>
            * @example 
            * // Set the hourFormat on initialization. 
            * //To set hourFormat API value 
            * &lt;input id="timepicker" data-role="none" /&gt;<br>
            * &lt;script&gt;
            * $(function(){
            * $("#timepicker").ejmTimePicker({ hourFormat: "twentyfour" });			
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the hourFormat, after initialization:<br>
            * // Get the hourFormat API value.		
            *  $("#timepicker").ejmTimePicker("option", "hourFormat");			
            * // Set the hourFormat API
            * $("#timepicker").ejmTimePicker("option", "hourFormat", "twentyfour");            
            * @memberof ejmTimePicker
            * @instance
            */
            hourFormat: "twentyfour",
            /**		
            * Specifies the value.
            * @default new Date().ToString()
            * @type {string}
            * @example 
            * //Set the value property in Unobtrusive way.
            * &lt;input id="timepicker" data-role="ejmtimepicker" data-ej-value="02:20 PM" /&gt;<br>
            * @example 
            * // Set the value on initialization. 
            * //To set value API value 
            * &lt;input id="timepicker" data-role="none" /&gt;<br>
            * &lt;script&gt;
            * $(function(){
            * $("#timepicker").ejmTimePicker({ value: "02:20 PM" });
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the value, after initialization:<br>
            * // Get the value API value.		
            *  $("#timepicker").ejmTimePicker("option", "value");			
            * // Set the value API
            * $("#timepicker").ejmTimePicker("option", "value", "02:20 PM");            
            * @memberof ejmTimePicker
            * @instance
            */
            value: new Date(),
            /**		
            * Specifies the time format.
            * @default null
            * @type {string}
            * @example 
            * //Set the timeFormat property in Unobtrusive way.
            * &lt;input id="timepicker" data-role="ejmtimepicker" data-ej-hourformat="twelve" data-ej-timeformat="hh:mm tt" /&gt;<br>
            * @example 
            * // Set the timeFormat on initialization. 
            * //To set timeFormat API value 
            * &lt;input id="timepicker" data-role="none" /&gt;<br>
            * &lt;script&gt;
            * $(function(){
            * $("#timepicker").ejmTimePicker({ hourFormat: "twelve", timeFormat: "hh:mm tt" });			
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the timeFormat, after initialization:<br>
            * // Get the timeFormat API value.		
            *  $("#timepicker").ejmTimePicker("option", "timeFormat");			
            * // Set the timeFormat API
            * $("#timepicker").ejmTimePicker("option", "timeFormat", "hh:mm tt");            
            * @memberof ejmTimePicker
            * @instance
            */
            timeFormat: null,
            /**		
            * Changes the theme. See {@link Theme}
            * @default auto
            * @type {enum}
            * @example 
            * //Set the theme property in Unobtrusive way.
            * &lt;input id="timepicker" data-role="ejmtimepicker" data-ej-theme="auto" /&gt;<br>
            * @example 
            * // Set the theme on initialization. 
            * //To set theme API value 
            * &lt;input id="timepicker" data-role="none" /&gt;<br>
            * &lt;script&gt;
            * $(function(){
            * $("#timepicker").ejmTimePicker({ theme: "auto" });			
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the theme, after initialization:<br>
            * // Get the theme API value.		
            *  $("#timepicker").ejmTimePicker("option", "theme");			
            * // Set the theme API
            * $("#timepicker").ejmTimePicker("option", "theme", "auto");            
            * @memberof ejmTimePicker
            * @instance
            */
            theme: "auto",
            /**		
            * Specifies whether to enable the control on initialization.
            * @default true
            * @type {boolean}
            * @example 
            * //Set the enabled property in Unobtrusive way.
            * &lt;input id="timepicker" data-role="ejmtimepicker" data-ej-enabled=true /&gt;<br>
            * @example 
            * // Set the enabled on initialization. 
            * //To set enabled API value 
            * &lt;input id="timepicker" data-role="none" /&gt;<br>
            * &lt;script&gt;
            * $(function(){
            * $("#timepicker").ejmTimePicker({ enabled: true });	
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the enabled, after initialization:<br>
            * // Get the enabled API value.		
            *  $("#timepicker").ejmTimePicker("option", "enabled");			
            * // Set the enabled API
            * $("#timepicker").ejmTimePicker("option", "enabled", true);            
            * @memberof ejmTimePicker
            * @instance
            */
            enabled: true,
            /**		
            * Current model value to browser cookies for state maintains. While refresh the page retains the model value apply from browser cookies.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the enablePersistence property in Unobtrusive way.
            * &lt;input id="timepicker" data-role="ejmtimepicker" data-ej-enablepersistence=true /&gt;<br>
            * @example 
            * // Set the enablePersistence on initialization. 
            * //To set enablePersistence API value 
            * &lt;input id="timepicker" data-role="none" /&gt;<br>
            * &lt;script&gt;
            * $(function(){
            * $("#timepicker").ejmTimePicker({ enablePersistence: true });	
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the enablePersistence, after initialization:<br>
            * // Get the enablePersistence API value.		
            *  $("#TimePicker").ejmTimePicker("option", "enablePersistence");			
            * // Set the enablePersistence API
            * $("#TimePicker").ejmTimePicker("option", "enablePersistence", true);            
            * @memberof ejmTimePicker
            * @instance
            */
            enablePersistence: false,
            /**     
            * Event triggers when the time is selected.
            * @event
            * @name ejmTimePicker#select 	
            * @param {Object} argument Event parameters from timepicker     
            * @param {boolean} argument.cancel if the event should be canceled; otherwise, false.
            * @param {object} argument.model returns the timepicker model
            * @param {string} argument.type returns the name of the event
            * @param {boolean} argument.value return the timepicker state
            * @example 
            * //Bind the select event using Unobtrusive way.
            * &lt;input id="timepicker" data-role="ejmtimepicker" data-ej-select="Select" /&gt;<br>
            * &lt;script&gt;
            * function Select(args) {}
            * &lt;/script&gt;
            * @example 
            * //select event for TimePicker
            * &lt;input id="timepicker" data-role="none" /&gt;<br>
            * &lt;script&gt;
            * $(function(){
            * $("#timepicker").ejmTimePicker({ select:"Select" });
            * });
            * function Select(args) {}                       
            * &lt;/script&gt;            
            * @memberof ejmTimePicker
            * @instance
            */
            select: null,
            /**     
            * Event triggers when the control is loaded.
            * @event
            * @name ejmTimePicker#load 	
            * @param {Object} argument Event parameters from timepicker     
            * @param {boolean} argument.cancel if the event should be canceled; otherwise, false.
            * @param {object} argument.model returns the Timepicker model
            * @param {string} argument.type returns the name of the event
            * @param {boolean} argument.value return the Timepicker state
            * @example 
            * //Bind the select event using Unobtrusive way.
            * &lt;input id="timepicker" data-role="ejmtimepicker" data-ej-load="Load" /&gt;<br>
            * &lt;script&gt;
            * function Load(args) {}
            * &lt;/script&gt;
            * @example 
            * //load event for TimePicker            
            * &lt;input id="timepicker" data-role="none" /&gt;<br>            
            * &lt;script&gt;
            * $(function(){
            * $("#timepicker").ejmTimePicker({ load:"Load" });
            * });
            * function Load(args) {}                       
            * &lt;/script&gt;           
            * @memberof ejmTimePicker
            * @instance
            */
            load: null,
            /**     
            * Event triggers when the input element is focused.
            * @event
            * @name ejmTimePicker#focusIn 	
            * @param {Object} argument Event parameters from TimePicker     
            * @param {boolean} argument.cancel if the event should be canceled; otherwise, false.
            * @param {object} argument.model returns the TimePicker model
            * @param {string} argument.type returns the name of the event
            * @param {string} argument.value return the TimePicker value
            * @example 
            * //Bind the focusin event using Unobtrusive way.
            * &lt;input id="timepicker" data-role="ejmtimepicker" data-ej-focusin="Focusin" /&gt;<br>
            * &lt;script&gt;
            * function Focusin(args) {}
            * &lt;/script&gt;
            * @example 
            * &lt;input id="timepicker" data-role="none" /&gt;<br>
            * //select focusIn for TimePicker
            * &lt;script&gt;
            * $(function(){
            * $("#timepicker").ejmTimePicker({ focusin:"Focusin" });
            * });
            * function Focusin(args) {}                       
            * &lt;/script&gt;        		 
            * @memberof ejmTimePicker
            * @instance
            */
            focusIn: null,
            /**     
            * Event triggers when the input element is blurred.
            * @event
            * @name ejmTimePicker#focusOut 	
            * @param {Object} argument Event parameters from TimePicker     
            * @param {boolean} argument.cancel if the event should be canceled; otherwise, false.
            * @param {object} argument.model returns the TimePicker model
            * @param {string} argument.type returns the name of the event
            * @param {string} argument.value return the TimePicker value
            * @example 
            * //Bind the focusout event using Unobtrusive way.
            * &lt;input id="timepicker" data-role="ejmtimepicker" data-ej-focusout="Focusout" /&gt;<br>
            * &lt;script&gt;
            * function Focusout(args) {}
            * &lt;/script&gt;
            * @example 
            * &lt;input id="timepicker" data-role="none" /&gt;<br>
            * //select focusOut for TimePicker
            * &lt;script&gt;
            * $(function(){
            * $("#timepicker").ejmTimePicker({ focusout:"Focusout" });
            * });
            * function focusout(args) {}                       
            * &lt;/script&gt;       		 
            * @memberof ejmTimePicker
            * @instance
            */
            focusOut: null,
            /**     
            * Event triggers when the control is opened.
            * @event
            * @name ejmTimePicker#open 	
            * @param {Object} argument Event parameters from TimePicker     
            * @param {boolean} argument.cancel if the event should be canceled; otherwise, false.
            * @param {object} argument.model returns the TimePicker model
            * @param {string} argument.type returns the name of the event
            * @param {string} argument.value return the TimePicker value
            * @example 
            * //Bind the open event using Unobtrusive way.
            * &lt;input id="timepicker" data-role="ejmtimepicker" data-ej-open="Open" /&gt;<br>
            * &lt;script&gt;
            * function Open(args) {}
            * &lt;/script&gt;
            * @example 
            * &lt;input id="timepicker" data-role="none" /&gt;<br>
            * //select open for TimePicker
            * &lt;script&gt;
            * $(function(){
            * $("#timepicker").ejmTimePicker({ open:"Open" });
            * });
            * function Open(args) {}                       
            * &lt;/script&gt;        		 
            * @memberof ejmTimePicker
            * @instance
            */
            open: null,
            /**     
            * Event triggers when the control is closed.
            * @event
            * @name ejmTimePicker#close 	
            * @param {Object} argument Event parameters from TimePicker     
            * @param {boolean} argument.cancel if the event should be canceled; otherwise, false.
            * @param {object} argument.model returns the TimePicker model
            * @param {string} argument.type returns the name of the event
            * @param {string} argument.value return the TimePicker value
            * @example 
            * //Bind the close event using Unobtrusive way.
            * &lt;input id="timepicker" data-role="ejmtimepicker" data-ej-close="Close" /&gt;<br>
            * &lt;script&gt;
            * function Close(args) {}
            * &lt;/script&gt;
            * @example 
            * &lt;input id="timepicker" data-role="none" /&gt;<br>
            * //select close for TimePicker
            * &lt;script&gt;
            * $(function(){
            * $("#timepicker").ejmTimePicker({ close:"Close" });
            * });
            * function Close(args) {}                       
            * &lt;/script&gt;        		 
            * @memberof ejmTimePicker
            * @instance
            */
            close: null,
            /**     
            * Event triggers when the time is changed.
            * @event
            * @name ejmTimePicker#change 	
            * @param {Object} argument Event parameters from TimePicker     
            * @param {boolean} argument.cancel if the event should be canceled; otherwise, false.
            * @param {object} argument.model returns the TimePicker model
            * @param {string} argument.type returns the name of the event
            * @param {string} argument.value return the TimePicker value
            * @example 
            * //Bind the change event using Unobtrusive way.
            * &lt;input id="timepicker" data-role="ejmtimepicker" data-ej-change="Change" /&gt;<br>
            * &lt;script&gt;
            * function Change(args) {}
            * &lt;/script&gt;
            * @example 
            * &lt;input id="timepicker" data-role="none" /&gt;<br>
            * //select change for TimePicker
            * &lt;script&gt;
            * $(function(){
            * $("#timepicker").ejmTimePicker({ change:"Change" });
            * });
            * function Change(args) {}                       
            * &lt;/script&gt;        		 
            * @memberof ejmTimePicker
            * @instance
            */
            change: null,
            /**     
            * Section for ios7 rendermode specific functionalities.                      
            * @memberof ejmTimePicker
            * @instance
            */
            ios7: {
                /**		
                * Specifies whether to use ios7 native timepicker or not.
                * @default false
                * @type {boolean}
                * @alias ejmTimePicker#ios7->renderDefault
                * @example 
                * // Set the ios7 mode renderDefault property in Unobtrusive way.
                * &lt;input id="timepicker" data-role="ejmtimepicker" data-ej-rendermode="ios7" data-ej-ios7-renderdefault="false" /&gt;<br>
                * @example 
                * // To set ios7 mode renderDefault property API value 
                * &lt;input id="timepicker" /&gt;<br>
                * &lt;script&gt;
                * $(function(){
                * $("#timepicker").ejmTimePicker({ renderMode: "ios7", ios7: { renderDefault: false } });		 
                * });
                * &lt;/script&gt;
                * @example 
                * // Get or set the ios7 mode renderDefault API, after initialization:
                * // Get the ios7 mode renderDefault value  
                * $("#timepicker").ejmTimePicker("option", "ios7.renderDefault");			
                * // Set the ios7 mode renderDefault value 
                *$("#timepicker").ejmTimePicker("option", "ios7.renderDefault", false); 
                * @memberof ejmTimePicker
                * @instance
                */
                "renderDefault": false
            },
            /**     
            * Section for windows rendermode specific functionalities.                      
            * @memberof ejmTimePicker
            * @instance
            */
            windows: {
                /**		
                * Specifies whether to render the control based on the windowsphone's current theme or not.
                * @default false
                * @type {boolean}
                * @alias ejmTimePicker#windows->renderDefault
                * @example 
                * // Set the windows mode renderDefault property in Unobtrusive way.
                * &lt;input id="timepicker" data-role="ejmtimepicker" data-ej-rendermode="windows" data-ej-windows-renderdefault="false" /&gt;<br>
                * @example 
                * // To set windows mode renderDefault property API value 
                * &lt;input id="timepicker" /&gt;<br>
                * &lt;script&gt;
                * $(function(){
                * $("#timepicker").ejmTimePicker({ renderMode: "windows", windows: { renderDefault: false } });		 
                * });
                * &lt;/script&gt;
                * @example 
                * // Get or set the windows mode renderDefault API, after initialization:
                * // Get the windows mode renderDefault value  
                * $("#timepicker").ejmTimePicker("option", "windows.renderDefault");			
                * // Set the windows mode renderDefault value 
                *$("#timepicker").ejmTimePicker("option", "windows.renderDefault", false); 
                * @memberof ejmTimePicker
                * @instance
                */
                "renderDefault": false
            }
        },
        dataTypes: {
            renderMode: "enum",
            hourFormat: "enum",
            theme: "enum",
            enabled: "boolean",
            enablePersistence: "boolean",
            ios7: { "renderDefault": "boolean" },
            windows: { "renderDefault": "boolean" }
        },
        /**
        * Create the TimePicker widget
        * @private
        */
        _init: function () {
            this._renderControl();
            this._createDelegates();
            this._wireEvents();
        },
        /**
        * To configure the values for timepicker control rendering 
        * @private
        */
        _timepickerInitialize: function () {
            this._winrt = this.model.renderMode == "windows" && !ej.isMobile();
            if (this.model.renderMode == "windows" && this.model.windows.renderDefault && ej.isMobile())
                this.model.theme = "default";
            this._id = $(this.element).attr('name') ? $(this.element).attr('name') : $(this.element).attr('id');
            $(this.element).attr('id', $(this.element).attr('id') ? $(this.element).attr('id') : this._id);
            this._menuTargetId = $(this.element).attr('id');
            this.model.timeFormat = this.model.timeFormat == null ? (this.model.hourFormat == "twelve" ? "hh:mm tt" : "HH:mm") : this.model.timeFormat;
            this.model.value = new Date(Globalize.format(new Date(), "MM/dd/yyyy") + " " + (typeof this.model.value == "string" ? this.model.value : Globalize.format(new Date(), this.model.timeFormat)));
            this._currentTime = this.model.value;
            this._twelvedata = [{ "value": "01" }, { "value": "02" }, { "value": "03" }, { "value": "04" }, { "value": "05" }, { "value": "06" }, { "value": "07" }, { "value": "08" }, { "value": "09" }, { "value": "10" }, { "value": "11" }, { "value": "12"}];
            this._twentyfourdata = [{ "value": "00" }, { "value": "01" }, { "value": "02" }, { "value": "03" }, { "value": "04" }, { "value": "05" }, { "value": "06" }, { "value": "07" }, { "value": "08" }, { "value": "09" }, { "value": "10" }, { "value": "11" }, { "value": "12" }, { "value": "13" }, { "value": "14" }, { "value": "15" }, { "value": "16" }, { "value": "17" }, { "value": "18" }, { "value": "19" }, { "value": "20" }, { "value": "21" }, { "value": "22" }, { "value": "23"}];
            this._minsdata = [{ "value": "00" }, { "value": "01" }, { "value": "02" }, { "value": "03" }, { "value": "04" }, { "value": "05" }, { "value": "06" }, { "value": "07" }, { "value": "08" }, { "value": "09" }, { "value": "10" }, { "value": "11" }, { "value": "12" }, { "value": "13" }, { "value": "14" }, { "value": "15" }, { "value": "16" }, { "value": "17" }, { "value": "18" }, { "value": "19" },
                                { "value": "20" }, { "value": "21" }, { "value": "22" }, { "value": "23" }, { "value": "24" }, { "value": "25" }, { "value": "26" }, { "value": "27" }, { "value": "28" }, { "value": "29" }, { "value": "30" }, { "value": "31" }, { "value": "32" }, { "value": "33" }, { "value": "34" }, { "value": "35" }, { "value": "36" }, { "value": "37" }, { "value": "38" }, { "value": "39" },
                                { "value": "40" }, { "value": "41" }, { "value": "42" }, { "value": "43" }, { "value": "44" }, { "value": "45" }, { "value": "46" }, { "value": "47" }, { "value": "48" }, { "value": "49" }, { "value": "50" }, { "value": "51" }, { "value": "52" }, { "value": "53" }, { "value": "54" }, { "value": "55" }, { "value": "56" }, { "value": "57" }, { "value": "58" }, { "value": "59"}];
            this._meridiansdata = [{ "value": "AM" }, { "value": "PM"}];
        },
        /**
        * Render Section For TimePicker control	
        * @private
        */
        _renderControl: function () {
            ej.setRenderMode(this);
            ej.setTheme(this);
            if (this.model.renderMode == "windows" && this.model.windows.renderDefault && ej.isMobile())
                this.model.theme = "default";
            this._timepickerInitialize();
            this._timepickerwrapper = ej.buildTag("div.e-m-timepickerwrapper e-m-" + this.model.renderMode + " e-m-" + this.model.theme + " e-m-user-select#" + this._id + "_Wrapper", "", {}, {});
            this.element.width("100%").attr({ "name": this._id }).wrap(this._timepickerwrapper);
            this._timepickerwrapper = this.element.parent();
            if (ej.isDevice() && this.model.renderMode == "ios7" && this.model.ios7.renderDefault) {
                this.element.attr({ "type": "time" });
            }
            else {
                this.element.attr({ "readonly": true });
                this._outerdiv = ej.buildTag("div.e-m-" + this.model.renderMode + " e-m-" + this.model.theme + " e-m-tp e-m-user-select #" + this._id + "_tp", "", {}, {});
                this._innerdiv = ej.buildTag("div.e-m-tpinner", "", {}, {});
                this._wrapdiv = ej.buildTag("div.e-m-tpwrap", "", {}, {});
                this._visibletexthtml = this._winrt ? "" : "<div class='col-fill'></div>";
                this._hours = ej.buildTag("div.e-m-tp e-m-tphours e-m-left", "<div class='e-m-timewrapper'><div id=" + this._id + "_tphour><div class='e-m-tpouter'>" + this._visibletexthtml + "</div></div></div><div class='e-m-tp-overlay'></div></div>", {}, {});
                this._mins = ej.buildTag("div.e-m-tp e-m-tpmins e-m-center", "<div class='e-m-timewrapper'><div id=" + this._id + "_tpmin><div class='e-m-tpouter'>" + this._visibletexthtml + "</div></div></div><div class='e-m-tp-overlay'></div></div>", {}, {});
                this._meridians = ej.buildTag("div.e-m-tp e-m-tpmeridians e-m-right", "<div class='e-m-timewrapper'><div id=" + this._id + "_tpmeridian><div class='e-m-tpouter'>" + this._visibletexthtml + "</div></div></div><div class='e-m-tp-overlay'></div></div>", {}, {});
                this["_" + this.model.renderMode + "Rendering"]();
                this._scrollInitialize();
                this._setInitialTime();
            }
            if (this.model.load)
                this._trigger("load", this._argsValue());
            this._controlStatus(this.model.enabled);
            this._timepickerwrapper.width(this.element.outerWidth());
            this._initscroll = false;
            this._setcurrent = false;
        },
        /**
        * Render Section For scrollpanel for individual scoller column.
        * @private
        */
        _scrollPanel: function (e) {
            this["_" + e] = ej.buildTag("div#'" + this._id + "'tp'" + e + "'_scrollpanel", "", {}, {});
            this._outerdiv.find("#" + this._id + "_tp" + e).append(this["_" + e]);
            this["_" + e].ejmScrollPanel({
                "enableNativeScrolling": false, "enableTransition": false, "enableTransform": false, "showScrollbars": false, "target": this._id + "_tp" + e, "targetHeight": this._targetHeight, "renderMode": this.model.renderMode,
                "scrollEnd": $.proxy(this._onScrollStop, this), "enableBounce": false, "scrollStart": $.proxy(this._onScrollStart, this), "enableDisplacement": true, "displacementValue": this._displacement, "displacementTime": ej.isWindows() ? 800 : 350
            });
        },
        /**
        * Render Section For initialize the scrollpanel input values and scrollpanel rendering for the columns.
        * @private
        */
        _scrollInitialize: function () {
            this._displacement = this.model.renderMode == "ios7" ? 40 : (this.model.renderMode == "android" ? 45 : 94);
            this._targetHeight = this.model.renderMode == "ios7" ? 200 : (this.model.renderMode == "android" ? 135 : !this._winrt ? this._appHeight : 0);
            if (!this._winrt) {
                this._scrollPanel("hour");
                this._scrollPanel("min");
                this._scrollPanel("meridian");
                if (this.model.renderMode == "windows" || this.model.renderMode == "flat") {
                    $(this._outerdiv).css("top", -this._appHeight + "px").addClass("flip");
                    $(this._toolbar).css("visibility", "hidden");
                }
                this._domElements();
            }
            this._initscroll = true;
        },
        /**
        * Render Section For jsrender templates in timepicker content .
        * @private
        */
        _renderTemplate: function () {
            var template = {};
            template["default"] = "<div class='e-m-text'>{{:value}}</div>";
            template["winrt"] = "<option value='{{:value}}'>{{:value}}</option>";
            $.templates(template);
        },
        /**
        * Render Section For timepicker content .
        * @private
        */
        _renderTimeContent: function () {
            if (this.model.hourFormat == "twentyfour")
                this._meridians.addClass("e-m-display-none");
            this._renderTemplate();
            this._columnRendering("hours");
            this._columnRendering("mins");
            this._columnRendering("meridians");
            this._innerdiv.append(this._wrapdiv);
            this._outerdiv.append(this._innerdiv);
        },
        /**
        * Render Section For ios7 specific api's Timepicker control	
        * @private
        */
        _ios7Rendering: function () {
            this._renderTimeContent();
            this._innerdiv.append("<div class='e-m-ios7-overlay'></div>");
            this._menu = ej.buildTag('div#' + this._id + '_menu.e-m-tp-menu');
            this._menu.append(this._outerdiv);
            App.activePage.append(this._menu);
            this._menu.ejmMenu({ "allowScrolling": false, "renderTemplate": true, "targetId": this._menuTargetId, "height": 205, "width": this._outerdiv.width(), "theme": this.model.theme, "rendermode": this.model.renderMode, "ios7": { "showTitle": false, "showCancelButton": false }, "hide": $.proxy(this._menuHide, this) });
        },
        /**
        * Render Section For android specific api's Timepicker control	
        * @private
        */
        _androidRendering: function () {
            this._timepickerwrapper.append("<span class='e-m-textspan'></div>");
            this._wrapdiv.append("<span class='e-m-and-overlay'>:</span>");
            this._renderTimeContent();
            this._dialog = ej.buildTag("div.e-m-tp-dialog#" + this._id + "_dialog");
            this._dialog.ejmDialog({ "allowScrolling": false, "theme": this.model.theme, "title": "Set Time", "leftButtonCaption": "Done", "mode": "alert", "renderMode": this.model.renderMode, "enableAnimation": false });
            this._dialog.find("#" + this._id + "_dialogcontent").append(this._outerdiv);
        },
        /**
        * Render Section For windows specific api's Timepicker control	
        * @private
        */
        _windowsRendering: function () {
            this._outerdiv.append("<div class='e-m-tp-header'>CHOOSE TIME</div>");
            if (this.model.renderMode == "windows" && !ej.isMobile()) {
                this._renderTimeContent();
                this._dialog = ej.buildTag("div.e-m-tp-dialog#" + this._id + "_dialog");
                this._dialog.ejmDialog({ "showModal": true, "allowScrolling": false, "theme": this.model.theme, "title": "Set Time", "leftButtonCaption": "Done", "rightButtonCaption": "Cancel", "mode": "confirm", "renderMode": this.model.renderMode, "enableModal": true, "windows": { "renderDefault": this.model.windows.renderDefault } });
                this._dialog.find("#" + this._id + "_dialogcontent").append(this._outerdiv);
            }
            else {
                this._renderTimeContent();
                this._toolbar = ej.buildTag("div#" + this._id + "_toolbar.e-m-tp-tb", "<ul><li data-ej-iconname='done'></li><li data-ej-iconname='close'></li></ul>");
                App.activePage.append(this._outerdiv);
                this._appHeight = App.activePage.innerHeight();
                this._outerdiv.find(".col-fill").css("height", (((this._appHeight - 94) / 2) + 1) + "px");
                this._toolbar.ejmToolbar({ "theme": this.model.theme, "renderMode": this.model.renderMode, "touchEnd": $.proxy(this._winToolbarItem, this), "windows": { "renderDefault": this.model.windows.renderDefault } });
            }
        },
        /**
        * Render Section For winrt native appearance content in timepicker	
        * @private
        */
        _winrtContent: function (column, data) {
            this._select = ej.buildTag("select");
            data = $.render["winrt"](data);
            this["_" + column].find(".e-m-tpouter").html(this._select.append(data));
            this._wrapdiv.append(this["_" + column]);
        },
        /**
        * Render Section For flat specific api's Timepicker control	
        * @private
        */
        _flatRendering: function () {
            this._windowsRendering();
        },
        /**
        * Render Section For column content with specific templates defined in timepicker.
        * @private
        */
        _columnRendering: function (colname) {
            var dataval = (colname == "hours") ? this["_" + this.model.hourFormat + "data"] : this["_" + colname + "data"];
            if (this._winrt)
                this._winrtContent(colname, dataval);
            else {
                var htmldata = $.render["default"](dataval) + this._visibletexthtml;
                this["_" + colname].find(".e-m-tpouter").html(this["_" + colname].find(".e-m-tpouter").html() + htmldata);
                this._wrapdiv.append(this["_" + colname]);
            }
        },
        /**
        * To configure the delegates for Timepicker control		
        * @private
        */
        _createDelegates: function () {
            this._winScrlHndlr = $.proxy(this._outerScroll, this);
            this._focusHndlr = $.proxy(this._showTimePicker, this);
            this._blurHndlr = $.proxy(this._blurEventHandler, this);
            this._andBtnClkHndlr = $.proxy(this._androidDialogButtonClick, this);
            this._winrtBtnClkHndlr = $.proxy(this._winrtDialogButtonClick, this);
        },
        /**
        * Wiring the events to Timepicker control		
        * @private
        */
        _wireEvents: function (remove) {
            if (this.model.renderMode == "android")
                ej.listenTouchEvent($(this._dialog).find(".e-m-btn"), ej.tapEvent(), this._andBtnClkHndlr, remove);
            else if (this._winrt)
                ej.listenTouchEvent($(this._dialog).find(".e-m-btn"), ej.tapEvent(), this._winrtBtnClkHndlr, remove);
            else if (this.model.renderMode == "windows" || this.model.renderMode == "flat")
                ej.listenTouchEvent($(this._outerdiv).find(".e-m-tpwrap .e-m-tp"), ej.startEvent(), this._winScrlHndlr, remove);
            ej.listenEvents([$(this.element), $(this.element)], ["focus", "blur"], [this._focusHndlr, this._blurHndlr], remove);
        },
        /**
        * To get the scroll coordinates of the scroller at the runtime in timepicker
        * @private
        */
        _scrollCoordinates: function () {
            var time = {};
            time.Scrollhours = Math.round(this._hour.ejmScrollPanel("getScrollPosition").y / this._displacement);
            time.Scrollmins = Math.round(this._min.ejmScrollPanel("getScrollPosition").y / this._displacement);
            time.Scrollmeridian = Math.round(this._meridian.ejmScrollPanel("getScrollPosition").y / this._displacement);
            time.hours = -(time.Scrollhours);
            time.mins = -(time.Scrollmins);
            time.meridian = -(time.Scrollmeridian);
            return time;
        },
        /**
        * To manipulate the domelements that are accessed in the control functionality
        * @private
        */
        _domElements: function () {
            this._hourstext = this._outerdiv.find("#" + this._id + "_tphour .e-m-text");
            this._minstext = this._outerdiv.find("#" + this._id + "_tpmin .e-m-text");
            this._meridianstext = this._outerdiv.find("#" + this._id + "_tpmeridian .e-m-text");
        },
        /**
        * To set the active time after currenttime is successfully calculated.
        * @private
        */
        _activeText: function (hours, mins, meridians, target) {
            if ((target && target == "tpmin") || target == undefined) {
                $(this._minstext).removeClass("e-m-text-active");
                $(this._minstext[mins - 1]).addClass("e-m-text-active");
            }
            if (target && target == "tphour" || target == undefined) {
                $(this._hourstext).removeClass("e-m-text-active");
                $(this._hourstext[hours - 1]).addClass("e-m-text-active");
            }
            if (target && target == "tpmeridian" || target == undefined) {
                $(this._meridianstext).removeClass("e-m-text-active");
                $(this._meridianstext[(meridians)]).addClass("e-m-text-active");
            }
        },
        /**
        * To configure the timevalue in the input area in the timepicker control.
        * @private
        */
        _setTimeInput: function () {
            $(this.element).val(Globalize.format(this._currentTime, this.model.timeFormat));
            this._timeSelect();
        },
        /**
        * To configure the current time in the winrt timepicker control.
        * @private
        */
        _winrtInitialTime: function (date) {
            var date = new Date(this._currentTime);
            var ampm = date.getHours() < 12 ? 'AM' : 'PM';
            $("#" + this._id + "_tphour").find("select option[value='" + (date.getHours() < 10 ? "0" + date.getHours() : date.getHours()) + "']").attr("selected", true);
            $("#" + this._id + "_tpmin").find("select option[value='" + (date.getMinutes() < 10 ? "0" + date.getMinutes() : date.getMinutes()) + "']").attr("selected", true);
            $("#" + this._id + "_tpmeridian").find("select option[value='" + ampm + "']").attr("selected", true);
        },
        /**
        * To configure the current time in the timepicker control.
        * @private
        */
        _setInitialTime: function () {
            if (this._winrt)
                this._winrtInitialTime(this._currentTime);
            else {
                this._setValue(this._currentTime);
                var proxy = this;
                setTimeout(function () {
                    proxy._setProperTime(100);
                }, 200);
            }
            $(this.element).val(Globalize.format(new Date(this._currentTime), this.model.timeFormat));
            this._selectedTime = $(this.element).val();
        },
        /**
        * To configure the current time in the picker element .
        * @private
        */
        _setValue: function (date) {
            var date = new Date(date);
            var time = ej.isAndroid() || ej.isWindows() ? 0 : (!this._initscroll && !this._setcurrent) ? 200 : 0;
            this._hour.ejmScrollPanel("scrollTo", 0, -this._displacement * (this.model.hourFormat == "twelve" ? (date.getHours() % 12 == 0 ? 12 : date.getHours() % 12 - 1) : date.getHours()), time);
            this._min.ejmScrollPanel("scrollTo", 0, -this._displacement * (date.getMinutes()), time);
            this._meridian.ejmScrollPanel("scrollTo", 0, -this._displacement * (date.getHours() > 11 ? 1 : 0), time);
        },
        /**
        * To set proper time after the time selection process is over .
        * @private
        */
        _setProperTime: function (duration, target) {
            var time = this._scrollCoordinates();
            var hours = this.model.hourFormat == "twelve" ? (time.meridian > 0 ? (time.hours == 12 ? 12 : time.hours == 0 ? 13 : time.hours == 11 ? 12 : time.hours + 13) : (time.hours == 0 ? 1 : time.hours == 12 ? 11 : time.hours + 1)) : time.hours;
            if (this.model.renderMode == "ios7" && !this._initscroll) {
                var proxy = this;
                setTimeout(function () {
                    $(proxy.element).val((Globalize.format(new Date(new Date().setHours(proxy.model.hourFormat == "twelve" ? hours : time.hours, time.mins)), proxy.model.timeFormat)));
                }, duration);
            }
            this._currentTime = new Date(new Date().setHours(this.model.hourFormat == "twelve" ? hours : time.hours, time.mins));
            this._activeText(this.model.hourFormat == 'twelve' ? time.hours == 12 ? time.hours : time.hours + 1 : time.hours + 1, time.mins + 1, time.meridian, target);
            if (this.model.change)
                this._trigger("change", this._argsValue());
        },
        /**
        * To configure the args value to the events in the timepicker
        * @private
        */
        _argsValue: function () {
            return { value: Globalize.format(this._currentTime, this.model.timeFormat) };
        },
        /**
        * To configure the scrollend event for the scroller in the timepicker
        * @private
        */
        _onScrollStop: function (e) {
            if (!e.object._moved) {
                var target = e.model.target.replace(this._id + "_", '');
                this._setProperTime(this.model.renderMode == "windows" ? 700 : 200, target);
                if (this["_" + this.model.renderMode + "ScrollStop"])
                    this["_" + this.model.renderMode + "ScrollStop"](e.model.target, target, e);
            }
        },
        /**
        * To configure the scrollend event for the windows mode timepicker
        * @private
        */
        _windowsScrollStop: function (e, target, scrollModel) {
            var startTarget = this._id + "_" + this._target;
            this._hideWrapper(target);
        },
        /**
        * To configure the scrollend event for the flat mode timepicker
        * @private
        */
        _flatScrollStop: function (e, target, scrollModel) {
            this._windowsScrollStop(e, target, scrollModel);
        },
        /**
        * To configure the scrollstart event for the scroller in the timepicker
        * @private
        */
        _onScrollStart: function (e) {
            this._target = e.model.target.replace(this._id + "_", '');
            if (this["_" + this.model.renderMode + "ScrollStart"])
                this["_" + this.model.renderMode + "ScrollStart"](e.model.target, this._target);
        },
        /**
        * To configure the scrollstart event for the windows mode timepicker
        * @private
        */
        _windowsScrollStart: function (e, target) {
            $("#" + e + "").find(".e-m-text.e-m-text-active").removeClass("e-m-text-active");
            this._hideWrapper(target);
        },
        /**
        * To configure the scrollstart event for the flat mode timepicker
        * @private
        */
        _flatScrollStart: function (e, target) {
            this._windowsScrollStart(e, target);
        },
        /**
        * To hide the column wrapper in windows mode timepicker when the scrolling animation in over.
        * @private
        */
        _hideWrapper: function (target) {
            if (target && target == "tphour") {
                if (!this._min.ejmScrollPanel("instance")._moved)
                    $("#" + this._id + "_tpmin").closest(".e-m-timewrapper").removeClass("e-m-scrollstart");
                if (!this._meridian.ejmScrollPanel("instance")._moved)
                    $("#" + this._id + "_tpmeridian").closest(".e-m-timewrapper").removeClass("e-m-scrollstart");
            }
            if (target && target == "tpmin") {
                if (!this._hour.ejmScrollPanel("instance")._moved)
                    $("#" + this._id + "_tphour").closest(".e-m-timewrapper").removeClass("e-m-scrollstart");
                if (!this._meridian.ejmScrollPanel("instance")._moved)
                    $("#" + this._id + "_tpmeridian").closest(".e-m-timewrapper").removeClass("e-m-scrollstart");
            }
            if (target && target == "tpmeridian") {
                if (!this._hour.ejmScrollPanel("instance")._moved)
                    $("#" + this._id + "_tphour").closest(".e-m-timewrapper").removeClass("e-m-scrollstart");
                if (!this._min.ejmScrollPanel("instance")._moved)
                    $("#" + this._id + "_tpmin").closest(".e-m-timewrapper").removeClass("e-m-scrollstart");
            }
        },
        /**
        * To configure the blur event for the control.
        * @private
        */
        _blurEventHandler: function () {
            if (this.model.focusOut) {
                this._trigger("focusOut", this._argsValue());
            }
            if (this.model.renderMode == "ios7") {
                if (this.model.select) {
                    if (this._previousDate != $(this.element).val())
                        this._trigger("select", this._argsValue());
                }
                if (this.model.close)
                    this._trigger("close", this._argsValue());
            }
        },
        /**
        * To configure the select event trigger for the control when the control is hided.
        * @private
        */
        _timeSelect: function (e) {
            if (this._selectedTime != $(this.element).val()) {
                if (this.model.select)
                    this._trigger("select", this._argsValue());
            }
            this._selectedTime = $(this.element).val();
            this._hideTimePicker();
        },
        /**
        * To configure the toolbar item click action in windows phone mode timepicker .
        * @private
        */
        _winToolbarItem: function (e) {
            if (e.itemname == "done")
                this._setTimeInput();
            else if (e.itemname == "close")
                this._hideTimePicker();
        },
        /**
        * To configure the diloag button click action in windows tablet mode timepicker .
        * @private
        */
        _winrtDialogButtonClick: function (e) {
            if ($(e.target).val() == "Done") {
                var hours = this.model.hourFormat == "twelve" ? $("#" + this._id + "_tpmeridian").find("select option:selected").val() == "PM" ? $("#" + this._id + "_tphour").find("select option:selected").val() == "01" ? 13 : parseInt($("#" + this._id + "_tphour").find("select option:selected").val()) + 12 : parseInt($("#" + this._id + "_tphour").find("select option:selected").val()) : parseInt($("#" + this._id + "_tphour").find("select option:selected").val());
                this._currentTime = new Date(new Date().setHours(parseInt(hours), parseInt($("#" + this._id + "_tpmin").find("select option:selected").val())));
                this._setTimeInput();
            }
            else
                this._showHidePicker(true);
        },
        /**
        * To configure the diloag button click action in android mode timepicker .
        * @private
        */
        _androidDialogButtonClick: function (e) {
            this._setTimeInput();
        },
        /**
        * To configure the outerscrolling in windows mode timepicker .
        * @private
        */
        _outerScroll: function (e) {
            $(e.target).closest(".e-m-tp").find(".e-m-timewrapper").addClass("e-m-scrollstart");
        },
        /**
        * To configure the timepicker control to either to hide or show based on arguments. 
        * @private
        */
        _showHidePicker: function (remove) {
            var e = { currentTarget: this._timepickerwrapper };
            var visibility = remove ? "hidden" : "visible";
            var flipclass = remove ? "out" : "in";
            var zindex = ej.getMaxZindex();
            this.element.next("span")[remove ? "removeClass" : "addClass"]("e-m-focusin");
            if (this._winrt)
                this._dialog.ejmDialog(remove ? "close" : "open");
            else if (this.model.renderMode == "android")
                this._dialog.css("visibility", remove ? "hidden" : "visible").css("z-index", zindex + 1);
            else if (this.model.renderMode == "windows" || this.model.renderMode == "flat") {
                this._outerdiv.css({ "top": remove ? "" : "0px", "bottom": remove ? this._appHeight + "px" : "0px", "z-index": zindex + 1, "visibility ": visibility }).removeClass("in out").addClass(flipclass);
                this._outerdiv.find(".e-m-tp-header").css({ "z-index": zindex + 2 });
                this._toolbar.css({ "z-index": zindex + 2, "visibility": visibility });
            }
        },
        /**
        * To configure the Timepicker control to show 
        * @private
        */
        _showTimePicker: function (e) {
            if (this.model.focusIn)
                this._trigger("focusIn", this._argsValue());
            this._showHidePicker();
            this._outerdiv.find(".e-m-timewrapper").removeClass("e-m-scrollstart");
            if (this.model.open)
                this._trigger("open", this._argsValue());
        },
        /**
        * To configure the timepicker control to hide 
        * @private
        */
        _hideTimePicker: function (e) {
            this._showHidePicker(true);
            if (this.model.close)
                this._trigger("close", this._argsValue());
        },
        /**
        * To refresh the scrollers in the Timepicker control		
        * @private
        */
        _refreshScroller: function () {
            this._hour.ejmScrollPanel("refresh");
            this._min.ejmScrollPanel("refresh");
            this._meridian.ejmScrollPanel("refresh");
        },
        /**
        * SetModel section for Timepicker control		
        * @private
        */
        _setModel: function (options) {
            var refresh;
            for (var prop in options) {
                if (prop == "renderMode" || prop == "hourFormat" || prop == "value" || (this.model.renderMode == "ios7" && prop == "renderDefault"))
                    refresh = true;
                else {
                    setprop = "_set" + prop.charAt(0).toUpperCase() + prop.slice(1);
                    if (this[setprop])
                        this[setprop](options[prop])
                }
            }
            if (refresh)
                this._refresh();
        },
        /**
        * To configure the theme of the Timepicker		
        * @private
        */
        _setTheme: function (theme) {
            this.model.theme = theme;
            this._timepickerwrapper.removeClass("e-m-dark e-m-light e-m-default").addClass("e-m-" + this.model.theme);
            if (this.model.renderMode == "ios7" && !ej.isMobile())
                this._menu.ejmMenu({ "theme": this.model.theme });
            if (this.model.renderMode == "android")
                this._dialog.ejmDialog({ "theme": this.model.theme });
            else if (this.model.renderMode == "windows")
                this._toolbar.ejmToolbar({ "theme": this.model.theme });
        },
        /**
        * To configure the TimeFormat of the Timepicker		
        * @private
        */
        _setTimeFormat: function (timeformat) {
            $(this.element).val(Globalize.format(this._currentTime, this.model.timeFormat));
        },
        /**
        * To configure the Enabling of the Timepicker		
        * @private
        */
        _setEnabled: function (enabled) {
            this._controlStatus(enabled);
        },
        /**
        * To configure the control status of the Timepicker		
        * @private
        */
        _controlStatus: function (enabled) {
            this._timepickerwrapper[!enabled ? "addClass" : "removeClass"]("e-m-state-disabled");
        },

        /**
        * Refresh section for to refresh the DOM elements back to original input element.		
        * @private
        */
        _refresh: function () {
            this._destroy();
            this.element.addClass("e-m-timepicker");
            this._renderControl();
            this._wireEvents();
        },
        /**
        * Clear Element section for Timepicker control		
        * @private
        */
        _clearElement: function () {
            this.element.insertAfter(this._timepickerwrapper);
            this._timepickerwrapper.remove();
            if (this._dialog) {
                this._dialog.ejmDialog("instance")._destroy();
                this._dialog.remove();
                this._dialog = null;
            }
            else if (this._toolbar) {
                this._toolbar.ejmToolbar("instance")._destroy();
                this._toolbar.remove();
                this._toolbar = null;
            }
            else if (this._menu) {
                this._menu.ejmMenu("instance")._destroy();
                this._menu.remove();
                this._menu = null;
            }
            this.element = $(this.element);
            this._outerdiv.remove();
        },
        /**
        * Destroy the Timepicker widget
        * @private
        */
        _destroy: function () {
            this._wireEvents(true);
            this._clearElement();
        },

        /*---------------Public Methods---------------*/
        /**
        * To show the TimePicker control 
        * @return jQuery
        * @example 
        * &lt;input id="timepicker" data-role="ejmtimepicker"/&gt;<br>
        * &lt;script&gt;
        * // Create TimePicker instance
        * $(function(){
        * var tpObj = $("#timepicker").data("ejmTimePicker");
        * tpObj.show(); 
        * });
        * &lt;/script&gt;        
        *@memberof ejmTimePicker
        * @instance
        */
        show: function (e) {
            var e = { currentTarget: this._timepickerwrapper };
            if (this.model.renderMode == "ios7")
                this._menu.ejmMenu("show", e);
            else
                this._showHidePicker();
        },
        /**
        * To hide the TimePicker control
        * @return jQuery
        * @example 
        * &lt;input id="timepicker" data-role="ejmtimepicker"/&gt;<br>
        * &lt;script&gt;
        * // Create TimePicker instance
        * $(function(){
        * var tpObj = $("#timepicker").data("ejmTimePicker");
        * tpObj.hide(); 
        * });
        * &lt;/script&gt;        
        *@memberof ejmTimePicker
        * @instance
        */
        hide: function (e) {
            var e = { currentTarget: this._timepickerwrapper };
            if (this.model.renderMode == "ios7")
                this._menu.ejmMenu("hide", e);
            else
                this._showHidePicker(true);
        },
        /**
        * To handle the TimePicker control enabled state
        * @return jQuery
        * @example 
        * &lt;input id="timepicker" data-role="ejmtimepicker"/&gt;<br>
        * &lt;script&gt;
        * $(function(){
        * // Create TimePicker instance
        * var tpObj = $("#timepicker").data("ejmTimePicker");
        * tpObj.enable(); 
        * });
        * &lt;/script&gt;        
        *@memberof ejmTimePicker
        * @instance
        */
        enable: function (e) {
            this.model.enabled = true;
            this._controlStatus(this.model.enabled);
            this._showHidePicker(true);
        },
        /**
        * To handle the TimePicker control disabled state
        * @return jQuery
        * @example 
        * &lt;input id="timepicker" data-role="ejmtimepicker"/&gt;<br>
        * &lt;script&gt;
        * // Create TimePicker instance
        * $(function(){
        * var tpObj = $("#timepicker").data("ejmTimePicker");
        * tpObj.disable(); 
        * });
        * &lt;/script&gt;                
        *@memberof ejmTimePicker
        * @instance
        */
        disable: function (e) {
            this.model.enabled = false;
            this._controlStatus(this.model.enabled);
            this._showHidePicker(true);
        },
        /**
        * To change the TimePicker control to disabled state
        * @return jQuery
        * @example 
        * &lt;input id="timepicker" data-role="ejmtimepicker"/&gt;<br>
        * &lt;script&gt;
        * $(function(){
        * // Create TimePicker instance
        * var dpObj = $("#timepicker").data("ejmTimePicker");
        * dpObj.getValue();
        * });
        * &lt;/script&gt;        	
        * @memberof ejmTimePicker
        * @instance
        */
        getValue: function () {
            return $(this.element).val();
        },
        /**
        * To change the TimePicker control to disabled state
        * @return jQuery
        * @example 
        * &lt;input id="timepicker" data-role="ejmtimepicker"/&gt;<br>
        * &lt;script&gt;
        * $(function(){
        * // Create TimePicker instance
        * var dpObj = $("#timepicker").data("ejmTimePicker");
        * dpObj.setCurrentTime("05:20");
        * });
        * &lt;/script&gt;        
        * @memberof ejmTimePicker
        * @instance
        */
        setCurrentTime: function (time) {
            this._setcurrent = true;
            this._currentTime = new Date(Globalize.format(new Date(), "MM/dd/yyyy") + " " + time);
            this._setInitialTime();
            this._setcurrent = false;
        }

        /*---------------Public Methods End---------------*/
    });
    /**
    * Enum for Hour format
    * @enum {string}
    * @global
    */
    ej.mobile.TimePicker.HourFormat = {
        /**
        Enum for twentyfour hourformat */
        TwentyFour: "twentyfour",
        /**
        Enum for twentyfour hourformat*/
        Twelve: "twelve"
    };
})(jQuery, Syncfusion);