/**
* @fileOverview Plugin to style the Html ToggleButton elements
* @copyright Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/

(function ($, ej, undefined) {
    /**
    * @namespace ej
    * @class ejmToggleButton
    * @requires jQuery
    * @requires ej.mobile.application
    * @requires ej.core
    * @requires ej.unobtrusive
    * @requires ej.mobile.core
    * @requires ej.data
    * @requires ej.touch
    * @classdesc Custom Design for Html ToggleButton control.
    * @example 
    * &lt;div id="togglebutton" &gt;&lt;/div&gt;<br>
    * &lt;script&gt; 
    * // Create ToggleButton  
    * $("#togglebutton").ejmToggleButton(); 
    * &lt;/script&gt;
    * @example 
    * &lt;div id="togglebutton" data-role="ejmtogglebutton"&gt;&lt;/div&gt;<br>
    */

    ej.widget("ejmToggleButton", "ej.mobile.ToggleButton", {
        _setFirst: true,
        _rootCSS: "e-m-tbutton",
        defaults: {
            /**		
            * Specifies the theme.  See {@link Theme}
            * @default auto
            * @type {enum}
            * @example 
            * //Set the theme property in unobtrusive way.
            * &lt;div id="togglebutton" data-role="ejmtogglebutton" data-ej-theme="auto"&gt;&lt;/div&gt;<br>
            * @example 
            * // Set togglebutton theme on initialization. 
            * //To set theme API value 
            * &lt;div id="togglebutton" &gt;&lt;/div&gt;
            * &lt;script&gt;
            * $(function () {
            * $("#togglebutton").ejmToggleButton ({ theme:ej.mobile.Theme.Auto });	
            * });
            * &lt;/script&gt;	
            * @example 
            * &lt;script&gt;
            * //Get or set the togglebutton theme, after initialization:<br>
            * // Get the theme API value.		
            * $("#togglebutton").ejmToggleButton ("option", "theme");			
            * // Set the theme API
            * $("#togglebutton").ejmToggleButton ("option", "theme", ej.mobile.Theme.Auto);       
            * &lt;/script&gt;
            * @memberof ejmToggleButton
            * @instance
            */
            theme: "auto",
            /**		
            * Specifies the transition effect for state change.
            * @default true
            * @type {boolean}
            * @example 
            * //Set the animate property in unobtrusive way.
            * &lt;div id="togglebutton" data-role="ejmtogglebutton" data-ej-animate=true&gt;&lt;/div&gt;<br>
            * @example 
            * // Set animate on initialization. 
            * //To set animate API value 
            * &lt;div id="togglebutton" &gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * $("#togglebutton").ejmToggleButton ({ animate:true });  
            * &lt;/script&gt;	
            * @example 
            * &lt;script&gt;
            * //Get or set the togglebutton animate, after initialization:<br>
            * // Get the animate API value.		
            * $("#togglebutton").ejmToggleButton ("option", "animate");			
            * // Set the animate API
            * $("#togglebutton").ejmToggleButton ("option", "animate", true);            
            * &lt;/script&gt;
            * @memberof ejmToggleButton
            * @instance
            */
            animate: true,
            /**		
            * Specifies whether state is on or off.
            * @default true
            * @type {boolean}
            * @example 
            * //Set the togglestate property in unobtrusive way.
            * &lt;div id="togglebutton" data-role="ejmtogglebutton" data-ej-togglestate=true&gt;&lt;/div&gt;<br>
            * @example 
            * // Set togglebutton togglestate on initialization. 
            * //To set togglestate API value 
            * &lt;div id="togglebutton" &gt;&lt;/div&gt;
            * &lt;script&gt;
            * $("#togglebutton").ejmToggleButton ({ toggleState:true  });	
            * &lt;/script&gt;	
            * @example 
            * &lt;script&gt;
            * //Get or set the togglebutton togglestate, after initialization:<br>
            * // Get the togglestate API value.		
            * $("#togglebutton").ejmToggleButton ("option", "toggleState");			
            * // Set the togglestate API
            * $("#togglebutton").ejmToggleButton ("option", "toggleState", true);  
            * &lt;/script&gt;
            * @memberof ejmToggleButton
            * @instance
            */
            toggleState: true,
            /**		
            * Specifies the rendering mode of the control. See {@link RenderMode}
            * @default auto
            * @type {enum}
            * @example 
            * //Set the renderMode property in unobtrusive way.
            * &lt;div id="togglebutton" data-role="ejmtogglebutton" data-ej-rendermode="auto"&gt;&lt;/div&gt;<br>
            * @example 
            * // Set togglebutton rendermode on initialization. 
            * //To set renderMode API value 
            * &lt;div id="togglebutton" &gt;&lt;/div&gt;
            * &lt;script&gt;
            * $(function () {
            * $("#togglebutton").ejmToggleButton ({ renderMode:ej.mobile.RenderMode.Auto });	
            * });
            * &lt;/script&gt;	
            * @example 
            * &lt;script&gt;
            * //Get or set the togglebutton rendermode, after initialization:<br>
            * // Get the renderMode API value.		
            *  $("#togglebutton").ejmToggleButton ("option", "renderMode");			
            * // Set the renderMode API
            * $("#togglebutton").ejmToggleButton ("option", "renderMode", ej.mobile.RenderMode.Auto);    
            * &lt;/script&gt;
            * @memberof ejmToggleButton
            * @instance
            */
            renderMode: "auto",
            /**     
            * Section for windows mode specific functionalities.                      
            * @memberof ejmToggleButton
            * @instance
            */
            windows: {
                /**  
                * Specifies whether to render control based on the windowsphone's current accent color and device theme.
                * @default false
                * @type {boolean}
                * @alias ejmToggleButton#windows->renderDefault
                * @example 
                * // Set the windows mode renderDefault property in unobtrusive way.
                * &lt;div id="togglebutton" data-role="ejmtogglebutton" data-ej-rendermode="windows" data-ej-windows-renderDefault=false&gt;&lt;/div&gt;<br>
                * @example 
                * &lt;div id="togglebutton" &gt;&lt;/div&gt;
                * &lt;script&gt;
                * // To set windows mode renderDefault property API value 
                * $(function () {
                * $("#togglebutton").ejmToggleButton({ renderMode:ej.mobile.RenderMode.Windows, windows.renderDefault: false});   
                * });
                * &lt;/script&gt;
                * @example
                * &lt;script&gt;
                * // Get or set the windows mode renderDefault API, after initialization:
                * // Get the windows mode renderDefault value  
                * $("#togglebutton").ejmToggleButton("option", "windows.renderDefault");   
                * // Set the windows mode renderDefault value 
                * $("#togglebutton").ejmToggleButton("option", "windows.renderDefault", false); 
                * &lt;/script&gt;
                * @memberof ejmToggleButton
                * @instance
                */
                "renderDefault": false
            },
            /**    
            * Event triggers when touch start happens on the control.
            * @event
            * @name ejmToggleButton#touchStart 
            * @param {Object} argument Event parameters from togglebutton.
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @param {boolean} argument.state returns the current state of the control.
            * @example 
            * &lt;div id="togglebutton" data-role="ejmtogglebutton" data-ej-touchstart="onTouchStart"&gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // touchStart event to be triggered
            * function onTouchStart(args){ //handle the event
            * }
            * &lt;/script&gt;
            * @example 
            * &lt;div id="togglebutton"&gt;&lt;/div&gt;
            * &lt;script&gt; 
            * //touchStart event to be triggered
            * $("#togglebutton").ejmToggleButton({
            * touchStart: function (args) { //handle the event 
            * }
            * });  
            * &lt;/script&gt; 
            * @memberof ejmToggleButton
            * @instance
            */
            touchStart: null,
            /**    
            * Event triggers when touch end happens on the control.
            * @event
            * @name ejmToggleButton#touchEnd 	
            * @param {Object} argument Event parameters from togglebutton.
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @param {boolean} argument.state returns the current state of the control.
            * @example 
            * &lt;div id="togglebutton" data-role="ejmtogglebutton" data-ej-touchEnd="onTouchEnd"&gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // touchEnd event for ToggleButton  
            * function onTouchEnd(args){ //handle the event
            * }
            * &lt;/script&gt
            * @example 
            * //touchEnd event for ToggleButton
            * &lt;div id="togglebutton"&gt;&lt;/div&gt;
            * &lt;script&gt;
            * $("#togglebutton").ejmToggleButton({
            * touchEnd: function (args) { //handle the event
            * }
            * }); 
            * &lt;/script&gt			
            * @memberof ejmToggleButton
            * @instance
            */
            touchEnd: null,
            /**    
            * Event triggers when the state change occurs.
            * @event
            * @name ejmToggleButton#change 	
            * @param {Object} argument Event parameters from togglebutton.
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @param {boolean} argument.state returns the current state of the control.
            * @example 
            * &lt;div id="togglebutton" data-role="ejmtogglebutton" data-ej-change="onChange"&gt;&lt;/div&gt;<br>
            * &lt;script&gt; 
            * // Change event for toggleButton 
            * function onChange(args){ //handle the event
            * }
            * &lt;/script&gt
            * @example 
            * //change event for toggleButton
            * &lt;div id="togglebutton"&gt;&lt;/div&gt;
            * &lt;script&gt;
            * $("#togglebutton").ejmToggleButton({
            * change: function (args) { //handle the event
            * }
            * });  
            * &lt;/script&gt;
            * @memberof ejmToggleButton
            * @instance
            */
            change: null,
            /**		
            * Specifies whether to enable or disable the control.
            * @default true
            * @type {boolean}
            * @example 
            * //Set the enabled property in unobtrusive way.
            * &lt;div id="togglebutton" data-role="ejmtogglebutton" data-ej-enabled=true&gt;&lt;/div&gt;<br>
            * @example 
            * // Set togglebutton enabled on initialization. 
            * //To set enabled API value 
            * &lt;div id="togglebutton" &gt;&lt;/div&gt;
            * &lt;script&gt; 
            * $("#togglebutton").ejmToggleButton ({ enabled:true  });	
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set the togglebutton enabled, after initialization:<br>
            * // Get the enabled API value.		
            *  $("#togglebutton").ejmToggleButton ("option", "enabled");			
            * // Set the enabled API
            * $("#togglebutton").ejmToggleButton ("option", "enabled", true);      
            * &lt;/script&gt;
            * @memberof ejmToggleButton
            * @instance
            */
            enabled: true,
            /**		
            * Specifies to maintain the current model value to browser cookies for state maintenance. While refresh the page, the model value will get apply to the control from browser cookies.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the enablePersistence property in unobtrusive way.
            * &lt;div id="togglebutton" data-role="ejmtogglebutton" data-ej-enablePersistence=false&gt;&lt;/div&gt;<br>
            * @example 
            * // Set togglebutton persistence on initialization. 
            * //To set enablePersistence API value 
            * &lt;div id="togglebutton" &gt;&lt;/div&gt;
            * &lt;script&gt; 
            * $("#togglebutton").ejmToggleButton ({ enablePersistence:false  });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set the togglebutton persistence, after initialization:<br>
            * // Get the enablePersistence API value.		
            *  $("#togglebutton").ejmToggleButton ("option", "enablePersistence");			
            * // Set the enablePersistence API
            * $("#togglebutton").ejmToggleButton ("option", "enablePersistence", false);  
            * &lt;/script&gt;
            * @memberof ejmToggleButton
            * @instance
            */
            enablePersistence: false
        },
        dataTypes: {
            renderMode: "enum",
            theme: "enum",
            animate: "boolean",
            toggleState: "boolean",
            enabled: "boolean",
            enablePersistence: "boolean"
        },
        /**
        * To initialize the ToggleButton 	
        * @private
        */
        _init: function () {
            this._cloneElement = this.element.clone();
            this._browser = ej.browser();
            this._renderControl();
            this._wireEvents(false);
            (this.model.enabled) ? this.enable() : this.disable();
        },
        /**
        * ToggleButton rendering	
        * @private
        */
        _renderControl: function () {
            ej.setRenderMode(this);
            ej.setTheme(this);
            if (this.model.renderMode == "windows" && this.model.windows.renderDefault && ej.isMobile())
                this.model.theme = "default";
            var modelobj = this.model;
            this.element.addClass('e-m-tbutton e-m-' + modelobj.renderMode + ' e-m-' + modelobj.theme).css({ "visibility": "hidden" }).addClass('e-m-' + modelobj.renderMode + 'corner-all');
            this._input = ej.buildTag("input", {}, {}, { "name": $(this.element).attr('id'), "type": "checkbox", "data-role": "none" }).css('display', 'none');
            this._innerdiv = ej.buildTag("div.e-m-innerdiv");
            this._filler = ej.buildTag("div.e-m-filler");
            this._offstate = ej.buildTag("div.e-m-offstate").html("ON");
            this._onstate = ej.buildTag("div.e-m-onstate").html("OFF");
            this._slider = ej.buildTag("div.e-m-tslider");
            if (modelobj.toggleState) {
                this._input.attr('checked', 'checked').attr("value", true);
                this._offstate.addClass('e-m-active');
                this._slider.html("OFF").addClass("e-m-" + modelobj.renderMode + "-active");
                this.element.addClass("e-m-" + modelobj.renderMode + "-active");
            }
            else {
                this._input.attr("value", false);
                this._onstate.addClass('e-m-default');
                this._slider.html("ON");
            }
            this._input.attr('class', 'e-m-input');
            this._innerdiv.append(this._offstate).append(this._slider).append(this._onstate);
            this.element.append(this._input).append(this._innerdiv).append(this._filler);
            this._slider.attr('Draggable', 'false');
            this.transtime = (this.model.renderMode == "flat" || this.model.renderMode == "ios7")
							 ? ((this.model.animate) ? "200ms" : "0ms") : "0ms";
            this._setToggleNativePosition();
        },
        /**
        * To create delegates for ToggleButton control
        * @private
        */
        _createDelegates: function () {
            this._touchStartHandler = $.proxy(this._touchStart, this);
            this._touchEndHandler = $.proxy(this._touchEnd, this);
            this._touchMoveHandler = $.proxy(this._touchMove, this);
        },
        /**
        * To wire events for ToggleButton control
        * @private
        */
        _wireEvents: function (remove) {
            this._createDelegates();
            ej.listenTouchEvent(this.element, ej.startEvent(), this._touchStartHandler, remove);
        },
        /**
        * Touchstart operations for ToggleButton control
        * @private
        */
        _touchStart: function (evt) {
            ej.blockDefaultActions(evt);
            var point = evt.touches ? evt.touches[0] : evt;
            this._startPoint = point.pageY;
            this.maxMove = this.element.width() - this._slider.width();
            var modelobj = this.model;
            this._flag = true;
            this._startstate = modelobj.toggleState;
            this._startTime = evt.timeStamp || Date.now();
            this._startPos = evt.pageX;
            if (ej.isTouchDevice())
                evt = evt.touches ? evt.touches[0] : evt;
            if (this.model.renderMode == "flat" || this.model.renderMode == "ios7") this.maxMove = this.maxMove - 2;
            this._slider.addClass("e-m-touchactive");
            this.element.addClass("e-m-touchactive");
            this._onstate.addClass("e-m-touchactive");
            this._position = { x: evt.pageX, y: evt.pageY };
            this.startValue = this._getNormalValue(this._position);
            this._handleX = this._slider.offset().left - this.element.offset().left;
            ej.listenEvents([document, document], [ej.endEvent(), ej.moveEvent()], [this._touchEndHandler, this._touchMoveHandler], false);
            var data = { state: modelobj.toggleState };
            if (modelobj.touchStart) this._trigger("touchStart", data);
        },
        /**
        * Touchmove operations for ToggleButton control
        * @private
        */
        _touchMove: function (evt) {
            ej.blockDefaultActions(evt);
            var point = evt.touches ? evt.touches[0] : evt;
            this._endPoint = point.pageY;
            if (this._startPoint != this._endPoint) {
                var modelobj = this.model;
                this._flag = false;
                if (ej.isTouchDevice())
                    evt = evt.touches ? evt.touches[0] : evt;
                this._position = { x: evt.pageX, y: evt.pageY };
                var value = this._getNormalValue(this._position);
                this._curValue = value - this.startValue;
                this._endTime = evt.timeStamp || Date.now();
                this._endPos = evt.pageX;
                this._offstate.css("opacity", 1);
                this._onstate.css("opacity", 1);
                this._transitionTime(this._innerdiv, this.transtime);
                if (modelobj.renderMode != "ios7") {
                    if ((this._handleX + this._curValue) >= 0 && (this._handleX + this._curValue) <= this.maxMove) {
                        if (this.model.renderMode == "android")
                            (!this._flag) ? (((this._handleX + this._curValue) < this.maxMove / 2) ? this._offState() : this._onState()) : ((this._onstate.hasClass('e-m-active')) ? this._offState() : this._onState());
                        if (this.model.renderMode == "windows") {
                            this._translateContent(this._slider, (this._handleX + this._curValue));
                            this._filler.width(this._handleX + this._curValue - 4);
                        }
                        else
                            this._translateContent(this._innerdiv, (this._handleX + this._curValue));

                    }
                }
                else ((this._handleX + this._curValue) < this.maxMove / 2) ? this._offState() : this._onState();

            }
        },
        /**
        * Touchend operations for ToggleButton control
        * @private
        */
        _touchEnd: function (evt) {
            ej.blockDefaultActions(evt);
            this._slider.removeClass("e-m-touchactive");
            this.element.removeClass("e-m-touchactive");
            this._onstate.removeClass("e-m-touchactive");
            var modelobj = this.model;
            ej.listenEvents([document, document], [ej.endEvent(), ej.moveEvent()], [this._touchEndHandler, this._touchMoveHandler], true);
            if (ej.isTouchDevice())
                evt = evt.changedTouches ? evt.changedTouches[0] : evt;
            var endX = this._slider.offset().left - this.element.offset().left;
            this._delTime = this._endTime - this._startTime;
            this._delPos = (this._startstate) ? -(this._endPos - this._startPos) : (this._endPos - this._startPos);
            if ((modelobj.renderMode === 'ios7' || modelobj.renderMode === 'windows') && this._delTime < 300 && this._delPos > 10) {
                (this._startstate) ? this._offState() : this._onState();
            }
            else {
                if (modelobj.animate == "true" && !this._innerdiv.hasClass("e-m-transition")) this._innerdiv.addClass("e-m-transition");
                if (!this._flag) ((endX < this.maxMove / 2) ? this._offState() : this._onState());
                else ((this._onstate.hasClass('e-m-active')) ? this._offState() : this._onState());
            }
            if (this._input.attr("checked")) {
                this._slider.addClass("e-m-" + modelobj.renderMode + "-active");
                this.element.addClass("e-m-" + modelobj.renderMode + "-active");
            }
            else {
                this._slider.removeClass("e-m-" + modelobj.renderMode + "-active");
                this.element.removeClass("e-m-" + modelobj.renderMode + "-active");
            }
            var data = { state: modelobj.toggleState };
            if (modelobj.touchEnd) this._trigger("touchEnd", data);
            if (modelobj.change) {
                if (this._startstate != modelobj.toggleState)
                    this._trigger("change", data);
            }

        },
        /**
        * To intially place the ToggleButton control 
        * @private
        */
        _setToggleNativePosition: function () {
            var modelobj = this.model;
            this._browser = ej.browser();
            var onStateWidth = this._onstate.removeClass("e-m-onstate").outerWidth();
            var offStateWidth = this._offstate.removeClass("e-m-offstate").outerWidth();
            this._onstate.addClass("e-m-onstate");
            this._offstate.addClass("e-m-offstate");
            var outerWidth = this._innerdiv.width;
            var width = Math.max(onStateWidth, offStateWidth);
            if (width > outerWidth) {
                $(this._innerdiv).width(width + ej.getCurrentPage().find(this._slider, "width") + 20);
                this._onstate.width(width + ej.getCurrentPage().find(this._slider, "width") + 20);
                this._offstate.width(width + ej.getCurrentPage().find(this._slider, "width") + 20);
            }
            var innerWidth = Math.max(this._onstate.width(), this._offstate.width());
            this._flag = false;
            this._innerdiv[0].style[this._browser + 'TransitionProperty'] = '-' + this._browser.toLowerCase() + '-transform';
            this._innerdiv[0].style[this._browser + 'TransitionDuration'] = '0ms';
            this._slider[0].style[this._browser + 'TransitionProperty'] = '-' + this._browser.toLowerCase() + '-transform';
            this._slider[0].style[this._browser + 'TransitionDuration'] = '0ms';
            if (this.model.renderMode == "ios7") this._slider.css("-" + this._browser + "-Transition", " width 0.5s ease");
            this._innerdiv.css("-" + this._browser + '-user-select', "none");
            if (width > outerWidth) this._offstate.css("left", -(width - ej.getDimension(this._slider, "width") / 2 + this._slider.width() + 10));
            (modelobj.toggleState) ? this._onState() : this._offState();
            this._transitionTime(this._innerdiv, this.transtime);
            this.element.css({ "visibility": "visible" });
        },
        /**
        * To get Noraml Value for ToggleButton transition 
        * @private
        */
        _getNormalValue: function (position) {
            var currentLOB, currentLOBPercent, totalValue, currentValue; //currentLOT = current left or bottom
            currentLOB = position.x - this.element.offset().left;
            currentLOBPercent = (currentLOB / this.element[0].offsetWidth);
            totalValue = this.element.width();
            currentValue = currentLOBPercent * totalValue;
            return this._trimValue(currentValue);
        },
        /**
        * To trim Noraml Value for ToggleButton transition 
        * @private
        */
        _trimValue: function (value) {
            var step = 1;
            var stepModValue = (value) % step;
            var correctedValue = value - stepModValue;
            if (Math.abs(stepModValue) * 2 >= step) correctedValue += (stepModValue > 0) ? step : (-step);
            return parseFloat(correctedValue.toFixed(5));
        },
        /**
        * To change the toggle state to false 
        * @private
        */
        _offState: function () {
            modelobj = this.model;
            modelobj.toggleState = false;
            this._input.removeAttr('checked', 'checked').attr("value", false);
            this._onstate.addClass("e-m-default").removeClass("e-m-active");
            this._slider.html("OFF");
            this._onstate.css("opacity", 1);
            this._transitionTime(this._innerdiv, this.transtime);
            if (modelobj.renderMode == "windows") {
                this._translateContent(this._slider, 0);
                this._filler.width("0px");
            }
            else this._translateContent(this._innerdiv, 0);
            this._slider.removeClass("e-m-" + modelobj.renderMode + "-active");
            this.element.removeClass("e-m-" + modelobj.renderMode + "-active");
            this._transitionTime(this._offstate, this.transtime);
            if (this.model.renderMode == "ios7") this._translateContent(this._innerdiv, 0);
        },
        /**
        * To change the toggle state to true 
        * @private
        */
        _onState: function () {
            modelobj = this.model;
            modelobj.toggleState = true;
            this._input.attr('checked', 'checked').attr("value", true);
            this._slider.html("ON");
            this._offstate.css("opacity", 1);
            this._transitionTime(this._innerdiv, this.transtime);
            var transValue = (modelobj.renderMode == "flat") ? 52 : 49;
            if (this.model.renderMode == "windows") {
                this._translateContent(this._slider, 43);
                this._filler.width("39px");
            }
            else this._translateContent(this._innerdiv, transValue);
            this._slider.addClass("e-m-" + modelobj.renderMode + "-active");
            this.element.addClass("e-m-" + modelobj.renderMode + "-active");
            this._onstate.addClass("e-m-active").removeClass("e-m-default");
            this._transitionTime(this._onstate, this.transtime);
            if (this.model.renderMode == "ios7") this._translateContent(this._innerdiv, 22);
        },
        /**
        * To set the tansition time  
        * @private
        */
        _transitionTime: function (element, transtime) {
            element[0].style[ej.transitionDuration] = transtime;
        },
        /**
        * To set the translation distance
        * @private
        */
        _translateContent: function (element, transvalue) {
            element[0].style[ej.transform] = "translateX(" + transvalue + "px)";
        },

        /**
        * SetModel operations for toggle button
        * @private
        */
        _setModel: function (options) {
            var refresh;
            for (var key in options)
                switch (key) {
                    case "theme": this.element.removeClass("e-m-light e-m-dark e-m-default").addClass("e-m-" + options.theme.toLowerCase());
                        break;
                    case "renderMode": (options.renderMode == "auto") ? ej.setRenderMode(this) : this.model.renderMode = options.renderMode;
                        refresh = true;
                        break;
                    case "toggleState": this._setToggleNativePosition(); break;
                    case "animate": refresh = true; break;
                    case "enabled": options.enabled ? this.enable() : this.disable(); break;
                }
            if (refresh) this._refresh();
        },
        /**
        * To refresh toggle button control
        * @private
        */
        _refresh: function () {
            this._clearElement();
            this._renderControl();
            this._wireEvents();
        },
        /**
        * To clear the created toggle button control
        * @private
        */
        _clearElement: function () {
            this._wireEvents(true);
            this.element.removeAttr("class")
            this.element.removeAttr("style")
            this.element.html("");
        },
        /**
        * To destroy toggle button control
        * @private
        */
        _destroy: function () {
            this._cloneElement.insertBefore(this.element).removeClass('e-m-tbutton');
            this.element.remove();
        },


        /*---------------Public Methods---------------*/
        /**
        * To disable the togglebutton.
        * @return jQuery
        * @example 
        * &lt;div id="togglebutton" data-role="ejmtogglebutton"&gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * $(document).ready(function(){
        * // Get the instance of toggle button
        * var toggle = $("#togglebutton").data("ejmToggleButton");
        * toggle.disable(); // Disables the toggle button
        * });
        * &lt;/script&gt;
        * @example 
        * &lt;div id="togglebutton" data-role="ejmtogglebutton"&gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * $(document).ready(function(){
        * // Disable togglebutton
        * $("#togglebutton").ejmToggleButton("disable");	
        * });
        * &lt;/script&gt;
        * @memberof ejmToggleButton
        * @instance
        */
        disable: function () {
            this.element.addClass("e-m-state-disabled");
            this._wireEvents(true);
            this.model.enabled = false;
        },

        /**
        * To enable the togglebutton.
        * @return jQuery
        * @example 
        * &lt;div id="togglebutton" data-role="ejmtogglebutton" &gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * $(document).ready(function(){
        * // Get the instance of toggle button
        * var toggle = $("#togglebutton").data("ejmToggleButton");
        * toggle.enable(); // Enables the toggle button
        * });
        * &lt;/script&gt;
        * @example 
        * &lt;div id="togglebutton" data-role="ejmtogglebutton"&gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * $(document).ready(function(){
        * // Enable togglebutton
        * $("#togglebutton").ejmToggleButton("enable");	
        * });
        * &lt;/script&gt;
        * @memberof ejmToggleButton
        * @instance
        */
        enable: function () {
            this.element.removeClass("e-m-state-disabled");
            this._wireEvents(false);
            this.model.enabled = true;
        }
        /*---------------Public Methods End---------------*/
    });
})(jQuery, Syncfusion);