/**
* @fileOverview Plugin to style the Html Toolbar elements  
* @copyright Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/
(function ($, ej, undefined) {
    /**
    * @namespace ej
    * @class ejmToolbar
    * @requires jQuery
    * @requires ej.mobile.application
    * @requires ej.core
    * @requires ej.unobtrusive
    * @requires ej.mobile.core
    * @requires ej.data
    * @requires ej.touch
    * @requires ej.mobile.menu
    * @requires ej.mobile.scrollbar
    * @requires ej.mobile.scrollpanel
    * @classdesc Custom Design for Html toolbar control.
    * @example 
    * &lt;div id="toolbar" &gt;
    * &lt;ul&gt;
    * &lt;li data-ej-iconname="add" &gt;&lt;/li&gt;
    * &lt;li data-ej-iconname="cut" &gt;&lt;/li&gt;
    * &lt;li data-ej-iconname="copy" &gt;&lt;/li&gt;
    * &lt;/ul &gt;
    * &lt;/div&gt;
    * &lt;script&gt; 
    * // Create toolbar  
    * $("#toolbar").ejmToolbar(); 
    * &lt;/script&gt;
    * @example 
    * &lt;div id="toolbar" data-role="ejmtoolbar"&gt;
    * &lt;ul&gt;
    * &lt;li data-ej-iconname="add" &gt;&lt;/li&gt;
    * &lt;li data-ej-iconname="cut" &gt;&lt;/li&gt;
    * &lt;li data-ej-iconname="copy" &gt;&lt;/li&gt;
    * &lt;/ul &gt;
    * &lt;/div&gt;
    */

    // mToolbar is the plugin name 
    // "m.Toolbar" is "namespace.className" will hold functions and properties

    ej.widget("ejmToolbar", "ej.mobile.Toolbar", {
        _setFirst: true,
        _rootCSS: "e-m-tb",
        // default values of model variables
        defaults: {
            /**		
            * Changes the theme. See {@link Theme}
            * @default auto
            * @type {enum}
            * @example 
            * //Set the theme property in unobtrusive way.
            * &lt;div id="toolbar" data-role="ejmtoolbar" data-ej-theme="auto"&gt;
            * &lt;ul&gt;
            * &lt;li data-ej-iconname="add" &gt;&lt;/li&gt;
            * &lt;li data-ej-iconname="cut" &gt;&lt;/li&gt;
            * &lt;li data-ej-iconname="copy" &gt;&lt;/li&gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;
            * @example 
            * // Set Toolbar theme on initialization. 
            * //To set theme API value 
            * &lt;div id="toolbar"&gt;
            * &lt;ul&gt;
            * &lt;li data-ej-iconname="add" &gt;&lt;/li&gt;
            * &lt;li data-ej-iconname="cut" &gt;&lt;/li&gt;
            * &lt;li data-ej-iconname="copy" &gt;&lt;/li&gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function () {
            * $("#toolbar").ejmToolbar ({ theme: ej.mobile.Theme.Auto });
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the Toolbar theme, after initialization:
            * &lt;script&gt;
            * // Gets the theme API value.		
            *  $("#toolbar").ejmToolbar ("option", "theme");			
            * // Sets the theme API
            * $("#toolbar").ejmToolbar ("option", "theme", ej.mobile.Theme.Auto);            
            * &lt;/script&gt;
            * @memberof ejmToolbar
            * @instance
            */
            theme: "auto",
            /**		
            * Changes the rendering mode. See {@link RenderMode}
            * @default auto
            * @type {enum}
            * @example 
            * //Set the renderMode property in unobtrusive way.
            * &lt;div id="toolbar" data-role="ejmtoolbar" data-ej-rendermode="auto"&gt;
            * &lt;ul&gt;
            * &lt;li data-ej-iconname="add" &gt;&lt;/li&gt;
            * &lt;li data-ej-iconname="cut" &gt;&lt;/li&gt;
            * &lt;li data-ej-iconname="copy" &gt;&lt;/li&gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;
            * @example 
            * // Set Toolbar renderMode on initialization. 
            * //To set renderMode API value 
            * &lt;div id="toolbar"&gt;
            * &lt;ul&gt;
            * &lt;li data-ej-iconname="add" &gt;&lt;/li&gt;
            * &lt;li data-ej-iconname="cut" &gt;&lt;/li&gt;
            * &lt;li data-ej-iconname="copy" &gt;&lt;/li&gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function () {
            * $("#toolbar").ejmToolbar ({ renderMode:ej.mobile.RenderMode.Windows});	
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the Toolbar renderMode, after initialization:
            * &lt;script&gt;
            * // Gets the renderMode API value.		
            *  $("#toolbar").ejmToolbar ("option", "renderMode");			
            * // Sets the renderMode API
            * $("#toolbar").ejmToolbar ("option", "renderMode", ej.mobile.RenderMode.Auto);            
            * &lt;/script&gt;
            * @memberof ejmToolbar
            * @instance
            */
            renderMode: "auto",
            /**    
            * Event triggers when the touch start happens.
            * @event
            * @name ejmToolbar#touchStart 	
            * @param {Object} argument Event parameters from Toolbar     
            * @param {boolean} argument.cancel if the event should be canceled; otherwise, false.
            * @param {Object} argument.model returns the Toolbar model
            * @param {string} argument.type returns the name of the event
            * @param {object} argument.item returns the item of element
            * @param {String} argument.value returns the name of item
            * @example 
            * &lt;div id="toolbar" data-role="ejmtoolbar" data-ej-touchstart="touchstart"&gt;
            * &lt;ul&gt;
            * &lt;li data-ej-iconname="add" &gt;&lt;/li&gt;
            * &lt;li data-ej-iconname="cut" &gt;&lt;/li&gt;
            * &lt;li data-ej-iconname="copy" &gt;&lt;/li&gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;
            * &lt;script&gt; 
            * // TouchStart event for toolbar  
            * function touchstart(args){ //handle the event
            * }
            * &lt;/script&gt;
            * @example 
            * &lt;div id="toolbar" data-role="ejmtoolbar" data-ej-touchstart="touchstart"&gt;
            * &lt;ul&gt;
            * &lt;li data-ej-iconname="add" &gt;&lt;/li&gt;
            * &lt;li data-ej-iconname="cut" &gt;&lt;/li&gt;
            * &lt;li data-ej-iconname="copy" &gt;&lt;/li&gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;
            * //touchStart event for toolbar
            * &lt;script&gt;
            * $("#toolbar").ejmToolbar({
            *   touchstart: function (args) { //handle the event
            * }
            * });       
            * &lt;/script&gt;
            * @memberof ejmToolbar
            * @instance
            */
            touchStart: null,
            /**    
            * Event triggers when the touch end happens.
            * @event
            * @name ejmToolbar#touchEnd 	
            * @param {Object} argument Event parameters from Toolbar     
            * @param {boolean} argument.cancel if the event should be canceled; otherwise, false.
            * @param {Object} argument.model returns the Toolbar model
            * @param {string} argument.type returns the name of the event
            * @param {object} argument.item returns the item of element
            * @param {String} argument.itemName returns the name of item
            * @example 
            * &lt;div id="toolbar" data-role="ejmtoolbar" data-ej-touchend="touchend"&gt;
            * &lt;ul&gt;
            * &lt;li data-ej-iconname="add" &gt;&lt;/li&gt;
            * &lt;li data-ej-iconname="cut" &gt;&lt;/li&gt;
            * &lt;li data-ej-iconname="copy" &gt;&lt;/li&gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;
            * &lt;script&gt; 
            * // TouchEnd event for toolbar  
            * function touchend(args){ //handle the event
            * }
            * &lt;/script&gt;
            * @example 
            * //TouchEnd event for toolbar
            * &lt;div id="toolbar" data-role="ejmtoolbar" data-ej-touchend="touchend"&gt;
            * &lt;ul&gt;
            * &lt;li data-ej-iconname="add" &gt;&lt;/li&gt;
            * &lt;li data-ej-iconname="cut" &gt;&lt;/li&gt;
            * &lt;li data-ej-iconname="copy" &gt;&lt;/li&gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $("#toolbar").ejmToolbar({
            *   touchend: function (args) { //handle the event
            * }
            * });         
            * &lt;/script&gt;
            * @memberof ejmToolbar
            * @instance
            */
            touchEnd: null,
            items: [],
            /**		
            * Specifies the Toolbar template Id.
            * @default null
            * @type {string}
            * @example 
            * //Set the templateId property in unobtrusive way.
            * &lt;div id="toolbar" data-role="ejmtoolbar" data-ej-templateid="sample"&gt;
            * &lt;ul&gt;
            * &lt;li data-ej-iconname="add" &gt;&lt;/li&gt;
            * &lt;li data-ej-iconname="cut" &gt;&lt;/li&gt;
            * &lt;li data-ej-iconname="copy" &gt;&lt;/li&gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;
            * &lt;span id="sample" &gt;Hi, SampleSpan &lt;/span&gt;
            * @example 
            * // Set Toolbar templateId on initialization. 
            * //To set templateId API value 
            * &lt;div id="toolbar" data-role="ejmtoolbar" data-ej-templateid="sample"&gt;
            * &lt;ul&gt;
            * &lt;li data-ej-iconname="add" &gt;&lt;/li&gt;
            * &lt;li data-ej-iconname="cut" &gt;&lt;/li&gt;
            * &lt;li data-ej-iconname="copy" &gt;&lt;/li&gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;
            * &lt;span id="sample" &gt;Hi, SampleSpan &lt;/span&gt;
            * &lt;script&gt;
            * $("#toolbar").ejmToolbar ({ templateId: "sample" });
            * &lt;/script&gt;
            * @example 
            * //Get or set the Toolbar templateId, after initialization:
            * &lt;script&gt;
            * // Gets the templateId API value.		
            *  $("#toolbar").ejmToolbar ("option", "templateId");			
            * // Sets the templateId API
            * $("#toolbar").ejmToolbar ("option", "templateId", "sample");            
            * &lt;script&gt;
            * @memberof ejmToolbar
            * @instance
            */
            templateId: null,
            /**
            * Specifies whether the control is enabled or not.
            * @default true
            * @type {bool}
            * @example 
            * //Set the enabled property in unobtrusive way.
            * &lt;div id="toolbar" data-role="ejmtoolbar" data-ej-enabled=true&gt;
            * &lt;ul&gt;
            * &lt;li data-ej-iconname="add" &gt;&lt;/li&gt;
            * &lt;li data-ej-iconname="cut" &gt;&lt;/li&gt;
            * &lt;li data-ej-iconname="copy" &gt;&lt;/li&gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;
            * @example 
            * // Set Toolbar enabled on initialization. 
            * //To set enabled API value 
            * &lt;div id="toolbar"&gt;
            * &lt;ul&gt;
            * &lt;li data-ej-iconname="add" &gt;&lt;/li&gt;
            * &lt;li data-ej-iconname="cut" &gt;&lt;/li&gt;
            * &lt;li data-ej-iconname="copy" &gt;&lt;/li&gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $("#toolbar").ejmToolbar ({ enabled: true });	
            * &lt;/script&gt;
            * @example 
            * //Get or set the Toolbar enabled, after initialization:
            * &lt;script&gt;
            * // Gets the enabled API value.		
            *  $("#toolbar").ejmToolbar ("option", "enabled");			
            * // Sets the enabled API
            * $("#toolbar").ejmToolbar ("option", "enabled", true);            
            * &lt;/script&gt;
            * @memberof ejmToolbar
            * @instance
            */
            enabled: true,
            /**		
            * Specifies whether the control is in hidden state or not.
            * @default false
            * @type {bool}
            * @example 
            * //Set the hide property in unobtrusive way.
            * &lt;div id="toolbar" data-role="ejmtoolbar" data-ej-hide=false&gt;
            * &lt;ul&gt;
            * &lt;li data-ej-iconname="add" &gt;&lt;/li&gt;
            * &lt;li data-ej-iconname="cut" &gt;&lt;/li&gt;
            * &lt;li data-ej-iconname="copy" &gt;&lt;/li&gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;
            * @example 
            * // Set Toolbar hide on initialization. 
            * //To set hide API value 
            * &lt;div id="toolbar"&gt;
            * &lt;ul&gt;
            * &lt;li data-ej-iconname="add" &gt;&lt;/li&gt;
            * &lt;li data-ej-iconname="cut" &gt;&lt;/li&gt;
            * &lt;li data-ej-iconname="copy" &gt;&lt;/li&gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $("#toolbar").ejmToolbar ({ hide: false });		
            * &lt;/script&gt;
            * @example 
            * //Get or set the Toolbar hide, after initialization:
            * &lt;script&gt;
            * // Gets the hide API value.		
            *  $("#toolbar").ejmToolbar ("option", "hide");			
            * // Sets the hide API
            * $("#toolbar").ejmToolbar ("option", "hide", false);            
            * &lt;/script&gt;
            * @memberof ejmToolbar
            * @instance
            */
            hide: false,
            /**		
            * Specifies position whether it is in fixed or relative to the page. See {@link Position}
            * @default fixed
            * @type {enum}
            * @example 
            * //Set the toolbarPosition property in unobtrusive way.
            * &lt;div id="toolbar" data-role="ejmtoolbar" data-ej-position="fixed"&gt;
            * &lt;ul&gt;
            * &lt;li data-ej-iconname="add" &gt;&lt;/li&gt;
            * &lt;li data-ej-iconname="cut" &gt;&lt;/li&gt;
            * &lt;li data-ej-iconname="copy" &gt;&lt;/li&gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;
            * @example 
            * // Set Toolbar toolbarPosition on initialization. 
            * //To set toolbarPosition API value 
            * &lt;div id="toolbar"&gt;
            * &lt;ul&gt;
            * &lt;li data-ej-iconname="add" &gt;&lt;/li&gt;
            * &lt;li data-ej-iconname="cut" &gt;&lt;/li&gt;
            * &lt;li data-ej-iconname="copy" &gt;&lt;/li&gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function () {
            * $("#toolbar").ejmToolbar ({ position: ej.mobile.Position.Fixed });		
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the Toolbar toolbarPosition, after initialization:
            * &lt;script&gt;
            * // Gets the toolbarPosition API value.		
            *  $("#toolbar").ejmToolbar ("option", "position");			
            * // Sets the toolbarPosition API
            * $("#toolbar").ejmToolbar ("option", "position", ej.mobile.Position.Fixed);            
            * &lt;/script&gt;
            * @memberof ejmToolbar
            * @instance
            */
            position: "fixed",
            /**		
            * Current model value to browser cookies for state maintains. While refresh the Header control page retains the model value apply from browser cookies.
            * @default false
            * @type {boolean}
            * @example 
            * //Set the enablePersistence property in unobtrusive way.
            * &lt;div id="toolbar" data-role="ejmtoolbar" data-ej-enablepersistence=true &gt;
            * &lt;ul&gt;
            * &lt;li data-ej-iconname="add" &gt;&lt;/li&gt;
            * &lt;li data-ej-iconname="cut" &gt;&lt;/li&gt;
            * &lt;li data-ej-iconname="copy" &gt;&lt;/li&gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;
            * @example 
            * // Set Toolbar enablePersistence on initialization. 
            * //To set enablePersistence API value 
            * &lt;div id="toolbar"&gt;
            * &lt;ul&gt;
            * &lt;li data-ej-iconname="add" &gt;&lt;/li&gt;
            * &lt;li data-ej-iconname="cut" &gt;&lt;/li&gt;
            * &lt;li data-ej-iconname="copy" &gt;&lt;/li&gt;
            * &lt;/ul &gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $("#toolbar").ejmToolbar ({ enablePersistence: true });		
            * &lt;/script&gt;
            * @example 
            * //Get or set the Toolbar enablePersistence, after initialization:
            * &lt;script&gt;
            * // Gets the enablePersistence API value.		
            *  $("#toolbar").ejmToolbar ("option", "enablePersistence");			
            * // Sets the enablePersistence API
            * $("#toolbar").ejmToolbar ("option", "enablePersistence", true);            
            * &lt;/script&gt;
            * @memberof ejmToolbar
            * @instance
            */
            enablePersistence: false,
            /**     
            * Section for android rendermode specific functionalities.                      
            * @memberof ejmToolbar
            * @instance
            */
            android: {
                /**  
                * Specifies the android mode Back icon is shown or not.
                * @default false
                * @type {boolean}
                * @alias ejmToolbar#android->showBackNavigator
                * @example 
                * //Set the showBackNavigator property in unobtrusive way.
                * &lt;div id="toolbar" data-role="ejmtoolbar" data-ej-rendermode="android" data-ej-android-showbacknavigator=false &gt;
                * &lt;ul&gt;
                * &lt;li data-ej-iconname="add" &gt;&lt;/li&gt;
                * &lt;li data-ej-iconname="cut" &gt;&lt;/li&gt;
                * &lt;li data-ej-iconname="copy" &gt;&lt;/li&gt;
                * &lt;/ul &gt;
                * &lt;/div&gt;
                * @example 
                * // To set android mode showBackNavigator property API value 
                * &lt;div id="toolbar"&gt;
                * &lt;ul&gt;
                * &lt;li data-ej-iconname="add" &gt;&lt;/li&gt;
                * &lt;li data-ej-iconname="cut" &gt;&lt;/li&gt;
                * &lt;li data-ej-iconname="copy" &gt;&lt;/li&gt;
                * &lt;/ul &gt;
                * &lt;/div&gt;
                * &lt;script&gt;
                * $(function () {
                * $("#toolbar").ejmToolbar({ android:{showBackNavigator: false},renderMode:ej.mobile.RenderMode.Android}); 
                * });
                * &lt;/script&gt;
                * @example 
                * // Get or set the android mode showBackNavigator API, after initialization:
                * &lt;script&gt;
                * // Gets the android mode showBackNavigator value  
                * $("#toolbar").ejmToolbar("option", "android.showBackNavigator");   
                * // Sets the android mode showBackNavigator value 
                * $("#toolbar").ejmToolbar("option", "android.showBackNavigator", false); 
                * &lt;/script&gt;
                * @memberof ejmToolbar
                * @instance
                */
                "showBackNavigator": false,
                /**  
                * Specifies the android mode Title Icon will be shown or not.
                * @default false
                * @type {boolean}
                * @alias ejmToolbar#android->showTitleIcon
                * @example 
                * //Set the showTitleIcon property in unobtrusive way.
                * &lt;div id="toolbar" data-role="ejmtoolbar"  data-ej-rendermode="android" data-ej-android-showTitleIcon=false &gt;
                * &lt;ul&gt;
                * &lt;li data-ej-iconname="add" &gt;&lt;/li&gt;
                * &lt;li data-ej-iconname="cut" &gt;&lt;/li&gt;
                * &lt;li data-ej-iconname="copy" &gt;&lt;/li&gt;
                * &lt;/ul &gt;
                * &lt;/div&gt;
                * @example 
                * // To set android mode showTitleIcon property API value 
                * &lt;div id="toolbar"&gt;
                * &lt;ul&gt;
                * &lt;li data-ej-iconname="add" &gt;&lt;/li&gt;
                * &lt;li data-ej-iconname="cut" &gt;&lt;/li&gt;
                * &lt;li data-ej-iconname="copy" &gt;&lt;/li&gt;
                * &lt;/ul &gt;
                * &lt;/div&gt;
                * &lt;script&gt;
                * $(function () {
                * $("#toolbar").ejmToolbar({ android:{showTitleIcon: false},renderMode: ej.mobile.RenderMode.Android});   
                * });
                * &lt;/script&gt;
                * @example 
                * // Get or set the android mode showTitleIcon API, after initialization:
                * &lt;script&gt;
                * // Gets the android mode showTitleIcon value  
                * $("#toolbar").ejmToolbar("option", "android.showTitleIcon");   
                * // Sets the android mode showTitleIcon value 
                * $("#toolbar").ejmToolbar("option", "android.showTitleIcon", false); 
                * &lt;/script&gt;
                * @memberof ejmToolbar
                * @instance
                */
                "showTitleIcon": false,
                /**  
                * Specifies the android mode split View mode is enabled or not.
                * @default false
                * @type {boolean}
                * @alias ejmToolbar#android->enableSplitView
                * @example 
                * //Set the enableSplitView property in unobtrusive way.
                * &lt;div id="toolbar" data-role="ejmtoolbar" data-ej-rendermode="android" data-ej-android-enablesplitview=false &gt;
                * &lt;ul&gt;
                * &lt;li data-ej-iconname="add" &gt;&lt;/li&gt;
                * &lt;li data-ej-iconname="cut" &gt;&lt;/li&gt;
                * &lt;li data-ej-iconname="copy" &gt;&lt;/li&gt;
                * &lt;/ul &gt;
                * &lt;/div&gt;
                * @example 
                * // To set android mode enableSplitView property API value 
                * &lt;div id="toolbar"&gt;
                * &lt;ul&gt;
                * &lt;li data-ej-iconname="add" &gt;&lt;/li&gt;
                * &lt;li data-ej-iconname="cut" &gt;&lt;/li&gt;
                * &lt;li data-ej-iconname="copy" &gt;&lt;/li&gt;
                * &lt;/ul &gt;
                * &lt;/div&gt;
                * &lt;script&gt;
                * $(function () {
                * $("#toolbar").ejmToolbar({ android:{enableSplitView: false},renderMode:ej.mobile.RenderMode.Android}); 
                * });
                * &lt;/script&gt;
                * @example 
                * // Get or set the android mode enableSplitView API, after initialization:
                * &lt;script&gt;
                * // Gets the android mode enableSplitView value  
                * $("#toolbar").ejmToolbar("option", "android.enableSplitView");   
                * // Sets the android mode enableSplitView value 
                * $("#toolbar").ejmToolbar("option", "android.enableSplitView", false); 
                * &lt;/script&gt;
                * @memberof ejmToolbar
                * @instance
                */
                "enableSplitView": false,
                /**  
                * Specifies the android mode title icon path or location.
                * @default ""
                * @type {string}
                * @alias ejmToolbar#android->titleIconUrl
                * @example 
                * //Set the titleIconUrl property in unobtrusive way.
                * &lt;div id="toolbar" data-role="ejmtoolbar" data-ej-rendermode="android" data-ej-android-titleIconUrl="enter title Icon url here" &gt;
                * &lt;ul&gt;
                * &lt;li data-ej-iconname="add" &gt;&lt;/li&gt;
                * &lt;li data-ej-iconname="cut" &gt;&lt;/li&gt;
                * &lt;li data-ej-iconname="copy" &gt;&lt;/li&gt;
                * &lt;/ul &gt;
                * &lt;/div&gt;
                * @example 
                * // To set android mode titleIconUrl property API value 
                * &lt;div id="toolbar"&gt;
                * &lt;ul&gt;
                * &lt;li data-ej-iconname="add" &gt;&lt;/li&gt;
                * &lt;li data-ej-iconname="cut" &gt;&lt;/li&gt;
                * &lt;li data-ej-iconname="copy" &gt;&lt;/li&gt;
                * &lt;/ul &gt;
                * &lt;/div&gt;
                * &lt;script&gt;
                * $(function () {
                * $("#toolbar").ejmToolbar({ android:{titleIconUrl: "enter title Icon url here"},renderMode:ej.mobile.RenderMode.Android });   
                * });
                * &lt;/script&gt;
                * @example 
                * // Get or set the android mode titleIconUrl API, after initialization:
                * &lt;script&gt;
                * // Gets the android mode titleIconUrl value  
                * $("#toolbar").ejmToolbar("option", "android.titleIconUrl");   
                * // Sets the android mode titleIconUrl value 
                * $("#toolbar").ejmToolbar("option", "android.titleIconUrl", "enter title Icon url here"); 
                * &lt;/script&gt;
                * @memberof ejmToolbar
                * @instance
                */
                "titleIconUrl": "",
                /**  
                * Specifies the android mode Ellipsis icon is shown or not.
                * @default false
                * @type {bool}
                * @alias ejmToolbar#android->showEllipsis
                * @example 
                * //Set the showEllipsis property in unobtrusive way.
                * &lt;div id="toolbar" data-role="ejmtoolbar" data-ej-rendermode="android" data-ej-android-showEllipsis=false &gt;
                * &lt;ul&gt;
                * &lt;li data-ej-iconname="add" &gt;&lt;/li&gt;
                * &lt;li data-ej-iconname="cut" &gt;&lt;/li&gt;
                * &lt;li data-ej-iconname="copy" &gt;&lt;/li&gt;
                * &lt;/ul &gt;
                * &lt;/div&gt;
                * @example 
                * // To set android mode showEllipsis property API value 
                * &lt;div id="toolbar"&gt;
                * &lt;ul&gt;
                * &lt;li data-ej-iconname="add" &gt;&lt;/li&gt;
                * &lt;li data-ej-iconname="cut" &gt;&lt;/li&gt;
                * &lt;li data-ej-iconname="copy" &gt;&lt;/li&gt;
                * &lt;/ul &gt;
                * &lt;/div&gt;
                * &lt;script&gt;
                * $(function () {
                * $("#toolbar").ejmToolbar({ android:{showEllipsis: false},renderMode:ej.mobile.RenderMode.Android });
                * });
                * &lt;/script&gt;
                * @example 
                * // Get or set the android mode showEllipsis API, after initialization:
                * &lt;script&gt;
                * // Gets the android mode showEllipsis value  
                * $("#toolbar").ejmToolbar("option", "android.showEllipsis");   
                * // Sets the android mode showEllipsis value 
                * $("#toolbar").ejmToolbar("option", "android.showEllipsis", false); 
                * &lt;/script&gt;
                * @memberof ejmToolbar
                * @instance
                */
                "showEllipsis": false,
                /**  
                * Specifies the android mode toolbar's title.
                * @default Title
                * @type {string}
                * @alias ejmToolbar#android->title
                * @example 
                * //Set the title property in unobtrusive way.
                * &lt;div id="toolbar" data-role="ejmtoolbar" data-ej-rendermode="android" data-ej-android-title="Title" &gt;
                * &lt;ul&gt;
                * &lt;li data-ej-iconname="add" &gt;&lt;/li&gt;
                * &lt;li data-ej-iconname="cut" &gt;&lt;/li&gt;
                * &lt;li data-ej-iconname="copy" &gt;&lt;/li&gt;
                * &lt;/ul &gt;
                * &lt;/div&gt;
                * @example 
                * // To set android mode title property API value 
                * &lt;div id="toolbar" &gt;
                * &lt;ul&gt;
                * &lt;li data-ej-iconname="add" &gt;&lt;/li&gt;
                * &lt;li data-ej-iconname="cut" &gt;&lt;/li&gt;
                * &lt;li data-ej-iconname="copy" &gt;&lt;/li&gt;
                * &lt;/ul &gt;
                * &lt;/div&gt;
                * &lt;script&gt;
                * $(function () {
                * $("#toolbar").ejmToolbar({ android:{title: "Title"},renderMode:ej.mobile.RenderMode.Android}); 
                * });
                * &lt;/script&gt;
                * @example 
                * // Get or set the android mode title API, after initialization:
                * &lt;script&gt;
                * // Gets the android mode title value  
                * $("#toolbar").ejmToolbar("option", "android.title");   
                * // Sets the android mode title value 
                * $("#toolbar").ejmToolbar("option", "android.title", "Title"); 
                * &lt;/script&gt;
                * @memberof ejmToolbar
                * @instance
                */
                "title": "Title"
            },
            /**     
            * Section for windows rendermode specific functionalities.                      
            * @memberof ejmToolbar
            * @instance
            */
            windows: {
                /**  
                * Specifies whether to render the toolbar based on the windowsphone's current accent color and theme.
                * @default false
                * @type {bool}
                * @alias ejmToolbar#windows->renderDefault
                * @example 
                * //Set the renderDefault property in unobtrusive way.
                * &lt;div id="toolbar" data-role="ejmtoolbar"  data-ej-rendermode="windows" data-ej-windows-renderDefault=false &gt;
                * &lt;ul&gt;
                * &lt;li data-ej-iconname="add" &gt;&lt;/li&gt;
                * &lt;li data-ej-iconname="cut" &gt;&lt;/li&gt;
                * &lt;li data-ej-iconname="copy" &gt;&lt;/li&gt;
                * &lt;/ul &gt;
                * &lt;/div&gt;
                * @example 
                * // To set windows mode renderDefault property API value 
                * &lt;div id="toolbar"&gt;
                * &lt;ul&gt;
                * &lt;li data-ej-iconname="add" &gt;&lt;/li&gt;
                * &lt;li data-ej-iconname="cut" &gt;&lt;/li&gt;
                * &lt;li data-ej-iconname="copy" &gt;&lt;/li&gt;
                * &lt;/ul &gt;
                * &lt;/div&gt;
                * &lt;script&gt;
                * $(function () {
                * $("#toolbar").ejmToolbar({ windows:{renderDefault: false},renderMode:ej.mobile.RenderMode.Windows});
                * });
                * &lt;/script&gt;
                * @example 
                * // Get or set the windows mode renderDefault API, after initialization:
                * &lt;script&gt;
                * // Gets the windows mode renderDefault value  
                * $("#toolbar").ejmToolbar("option", "windows.renderDefault");   
                * // Sets the windows mode renderDefault value 
                * $("#toolbar").ejmToolbar("option", "windows.renderDefault", false); 
                * &lt;/script&gt;
                * @memberof ejmToolbar
                * @instance
                */
                "renderDefault": false
            }
        },
        //datatype of model variables
        dataTypes: {
            theme: "enum",
            renderMode: "enum",
            position: "enum",
            enablePersistence: "boolean",
            android: {
                "showBackNavigator": "boolean",
                "enableSplitView": "boolean",
                "showTitleIcon": "boolean",
                "showEllipsis": "boolean"
            }
        },

        // constructor function
        _init: function () {
            this.model.id = this.element[0].id;
            this._renderControl();
            this._wireEvents(false);
        },
        _renderControl: function () {
            ej.setRenderMode(this);
            ej.setTheme(this);
            this._orgEle = this.element.clone();
            this.element.addClass('e-m-user-select');
            if (!this.model.enabled) {
                this.element.addClass('e-m-state-disabled');
                this._wireEvents(true);
            }
            if (this.model.renderMode == "windows" && this.model.windows.renderDefault)
                this.model.theme = "default";
            this._isMobile = (ej.isMobile() ? true : false);
            this.element.addClass("e-m-" + this.model.renderMode + " e-m-" + this.model.theme);
            this._toolbarContainer = ej.buildTag("div.e-m-tbcontainer");
            this["_" + this.model.renderMode + "ToolbarItems"]();
            if ((ej.isMobile() && this.model.renderMode != "android") || this.model.renderMode == "windows" || this.model.renderMode == "flat")
                this.model.position = "fixed";
            else 
                (this.model.position == "normal") ? this.element.closest('div#' + this.model.id).css('position', 'relative') : "";
            if (this.model.position == "fixed") {
                this.element.closest(".subpage").length ? this.element.closest(".subpage").append(this.element) : App.activePage.append(this.element);
                this.element.addClass('e-m-fixed');
            }
            if (this.model.hide)
                this.element.find(".e-m-tbcontainer").addClass("e-m-state-hide");
        },

        _androidToolbarItems: function () {
            //Prepare Title Container
            var backactionbar = ej.buildTag("div .e-m-backactionbar");
            var elementId = this.element.attr('id');
            elementId = (elementId == undefined) ? "sample" : this.element.attr('id');
            var backimg = ej.buildTag("div.e-m-fontimage e-m-backicon e-m-showback-" + this.model.android.showBackNavigator).appendTo(backactionbar);
            var titleicon = ej.buildTag("img.e-m-titleicon e-m-showtitle-" + this.model.android.showTitleIcon, {}, {}, { "src": this.model.android.titleIconUrl })
                              .appendTo(backactionbar);
            this._backActionBar = backactionbar;
            var actionimg;
            if (this._isMobile && this.model.android.enableSplitView)
                actionimg = ej.buildTag("div#" + elementId + "-overflow").addClass("e-m-fontimage e-m-splitview e-m-ellipsis e-m-showellipsis-" + this.model.android.showEllipsis);
            else
                actionimg = ej.buildTag("div#" + elementId + "-overflow").addClass("e-m-fontimage e-m-ellipsis e-m-showellipsis-" + this.model.android.showEllipsis);
            this._createUlContainer();
            if (this.model.templateId != "" && this.model.templateId != undefined) {
                this._templateProperty();
                if (this._isMobile && this.model.android.enableSplitView) {
                    var splitViewContainer = ej.buildTag('div.e-m-splitviewcontainer').append(actionimg).append(this._ulcontainer);
                    this.element.append(this._toolbarContainer.append(this._templateContainer).append(splitViewContainer));
                }
                else
                    this.element.append(this._toolbarContainer.append(this._templateContainer).append(actionimg).append(this._ulcontainer));
            }
            else {
                this._titlecontainer = ej.buildTag("div.e-m-titlecontainer");
                this._titlecontainer.append(backactionbar).append(ej.buildTag("span.e-m-title-text", this.model.android.title));
                if (this._isMobile && this.model.android.enableSplitView) {
                    var splitViewContainer = ej.buildTag('div.e-m-splitviewcontainer').append(actionimg).append(this._ulcontainer);
                    this.element.append(this._toolbarContainer.append(this._titlecontainer).append(splitViewContainer));
                }
                else
                    this.element.append(this._toolbarContainer.append(this._titlecontainer).append(actionimg).append(this._ulcontainer));
            }
            this._ellipsis = actionimg;
            this._androidOrientationProperties();
            if (this._isMobile && this.model.android.enableSplitView && (this._orgEle.find('li').length <= 3))
                this._ellipsis.removeClass('e-m-showellipsis-true').addClass('e-m-showellipsis-false');
            else if (this._isMobile && this.model.android.enableSplitView && this.model.android.showEllipsis)
                this.element.find('ul').css('width', '80%');
            if (this._Menucontainer != undefined)
                (this._Menucontainer.find('li').length == 0) ? this._ellipsis.removeClass('e-m-showellipsis-true').addClass('e-m-showellipsis-false') : "";
            this._isMenuOpened = false;
        },
        _templateProperty: function () {
            this._templateContainer = ej.buildTag("div.e-m-templatecontainer");
            if (ej.getCurrentPage().find("#" + this.model.templateId).length) {
                var templateContent = ej.getCurrentPage().find("#" + this.model.templateId);
                if (this.model.renderMode == "android")
                    this._templateContainer.append(this._backActionBar).append(ej.buildTag('div.e-m-titletemplate'));
                this._templateContainer.append(templateContent[0].nodeName && templateContent[0].nodeName.toLowerCase() == "script" ? ej.getClearString(templateContent[0].innerHTML) : templateContent);
            }
        },
        _ios7ToolbarItems: function () {
            this._createUlContainer();
            if (this.model.templateId != "" && this.model.templateId != undefined) {
                this._templateProperty();
                this.element.append(this._toolbarContainer.append(this._templateContainer).append(this._ulcontainer));
            }
            else
                this.element.append(this._toolbarContainer.append(this._ulcontainer));
        },

        _renderLiContainer: function (index, ele) {
            // Prepare Ui elements
            var innerdiv = ej.buildTag("div.e-m-tbicondiv");
            var iconname = ej.getAttrVal(ele, 'data-ej-iconname');
            var iconclassname = iconname.replace(/ /g, '').toLowerCase();
            var icontext = ej.getAttrVal(ele, 'data-ej-text');
            if (ej.isMobile() && this.model.android.enableSplitView)
                $(ele).addClass("e-m-splitview e-m-toolbaritem e-m-" + this.model.renderMode + "-" + iconclassname);
            else
                $(ele).addClass("e-m-toolbaritem e-m-" + this.model.renderMode + "-" + iconclassname);
            var iconurl = this.model.iconUrl = ej.getAttrVal(ele, 'data-ej-iconurl');
            if (ele == undefined) iconname = "add";
            if (this.model.iconUrl != undefined) {
                innerdiv.append(ej.buildTag("div.e-m-tbicon e-m-" + this.model.renderMode + "-" + iconclassname).css("background-image", "url('" + iconurl + "')")
                    .css("background-repeat", "no-repeat").css("background-position", "center"));
            }
            else
                innerdiv.append(ej.buildTag("div.e-m-fontimage e-m-tbicon e-m-" + this.model.renderMode + "-" + iconclassname));
            (!this._isMobile) ?
                innerdiv.append(ej.buildTag("div.e-m-tbiconblock ", iconname)) :
                innerdiv.append(ej.buildTag("div.e-m-tbiconblock tbiconblock-unselected", iconname.toLowerCase()));
            this._currentItem = $(ele).append(innerdiv);
        },

        _createUlContainer: function () {
            this._liClone = this.element.find('li').clone();
            this._ulcontainer = (this._isMobile && this.model.android.enableSplitView) ?
                this.element.find("ul").addClass("e-m-splitview e-m-tbulcontainer e-m-clearall") :
                this.element.find("ul").addClass("e-m-tbulcontainer e-m-clearall");
            if (this.model.renderMode == "windows" && this._isMobile && this._ulcontainer.length == 0)
                this._ulcontainer = ej.buildTag("ul").addClass("e-m-tbulcontainer");
            if (this.model.renderMode == "windows" && this._isMobile && $(this.element.find('li')).length > 4)
                this._ellipsisMenu = ej.buildTag("div", ej.buildTag('ul', $($($(this.element.find('li')).get(3)).nextAll())));
            this._toolbarLiElements = this._ulcontainer.find("li");
            var proxy = this;
            this._toolbarLiElements.each(function (index, element) {
                proxy._renderLiContainer(index, element);
            });
            if (this.model.renderMode != "android")
                this._ulcontainer.append(this._toolbarLiElements);
        },
        _androidOrientationProperties: function () {
            if (this.element.find('li').length > 1) {
                if (this._isMobile && !this.model.android.enableSplitView) {
                    if (this.element.find('li').length < 3)
                        this._ellipsis.removeClass('e-m-showellipsis-true').addClass('e-m-showellipsis-false');
                    else {
                        this._overFlowContainer(2);
                        $($(this._ulcontainer.find('li').get(1)).show()).nextAll().remove();
                        if (this.model.android.showEllipsis)
                            this._ellipsis.removeClass('e-m-showellipsis-false').addClass('e-m-showellipsis-true');
                    }
                }
                else if ((this._isMobile && this.model.android.enableSplitView) || !this._isMobile) {
                    if (this.model.android.enableSplitView && this.element.find('li').length <= 3) {
                        this._ellipsis.removeClass('e-m-showellipsis-true').addClass('e-m-showellipsis-false');
                        $(this._ulcontainer.find('li').get(2)).show();
                    }
                    else {
                        this._overFlowContainer(3);
                        $($(this._ulcontainer.find('li').get(2)).show()).nextAll().remove();
                        if (this.model.android.showEllipsis)
                            this._ellipsis.removeClass('e-m-showellipsis-false').addClass('e-m-showellipsis-true');
                    }
                }
            }
        },
        _overFlowContainer: function (index) {
            var liLength = this.element.find('li').length;
            var elementId = this.element.attr('id');
            this._androidMenuId = elementId;
            elementId = (elementId == undefined) ? "sample" : this.element.attr('id');
            if (index <= liLength) {
                this._Menucontainer = ej.buildTag('div#' + this.model.id + "_menu").addClass('e-m-ellipsiscontainer');
                var ulmenucontainer = ej.buildTag('ul').addClass('e-m-ulitem');
                this._tbMenuItems = this._liClone;
                var proxy = this;
                for (var i = index; i < liLength; i++) {
                    proxy.model.iconName = ej.getAttrVal(this._tbMenuItems[i], "data-ej-iconname").toLowerCase();
                    $(this._tbMenuItems[i]).attr("data-ej-text", proxy.model.iconName);
                    ulmenucontainer.append(this._tbMenuItems[i]);
                }
                this._Menucontainer.append(ulmenucontainer).ejmMenu({
                    "targetId": "" + elementId + "-overflow",
                    "renderMode": "android",
                    "android": { "type": "popup" },
                    "theme": this.model.theme,
                    "touchStart": this.model.touchStart,
                    "touchEnd": this.model.touchEnd
                });
            }
        },
        _windowsToolbarItems: function () {
            this._createUlContainer();
            this._ellipsisLi = ej.buildTag("li.e-m-toolbaritem-ellipsis").append(ej.buildTag("div.e-m-fontimage e-m-ellipsis e-m-" + this.model.renderMode + "-overflow"));
            this._isPortrait = ej.isPortrait() ? true : false;
            this._createMenuContainer();
            if (this.model.templateId != "" && this.model.templateId != undefined) {
                this._templateProperty();
                this.element.append(this._toolbarContainer.append(this._templateContainer).append(this._ulcontainer.append(this._ellipsisLi)));
            }
            else if (this._ellipsisMenu) {
                this._ellipsisContainer = this.element.find('div.e-m-ellipsiscontainer');
                this.element.append(this._toolbarContainer.append(this._ulcontainer.append(this._ellipsisLi)).append(this._ellipsisContainer));
            }
            else
                this.element.append(this._toolbarContainer.append(this._ulcontainer.append(this._ellipsisLi)));
            this._isMenuOpened = false;
        },

        _createMenuContainer: function () {
            if (this._ellipsisMenu) {
                //Prepare Ul Tool bar menu item Container
                this._Menucontainer = this._ellipsisMenu.addClass("e-m-ellipsiscontainer e-m-menuitemcontainer-hide");
                if (this.model.renderMode == "windows" && this._Menucontainer.length > 0) {
                    var ulmenucontainer = this._Menucontainer.find("ul").addClass("e-m-clearall");
                    this._tbMenuItems = ulmenucontainer.find("li").addClass("e-m-menuitem e-m-menumode-" + (this._isPortrait ? "portrait" : "landscape"));
                    var proxy = this;
                    this._tbMenuItems.each(function (index, element) {
                        proxy.model.iconName = ej.getAttrVal(element, "data-ej-iconname").toLowerCase();
                        var innerdiv = ej.buildTag("div", proxy.model.iconName);
                        $(element).append(innerdiv);
                    });
                    this.scrollWrapper = ej.buildTag('div#scrollwrapper');
                    this.scrollWrapper.ejmScrollPanel({ 'target': this._ellipsisMenu[0], targetHeight: this._tbMenuItems.length > 1 ? '100' : '50', adjustFixedPosition: false });
                    this.element.append(this._Menucontainer.append(this.scrollWrapper.append(ulmenucontainer.append(this._tbMenuItems))));
                }
            }
        },

        _winrtToolbarItems: function () {
            //Prepare Ul Container
            this._createUlContainer();
            if (this.model.templateId != "" && this.model.templateId != undefined) {
                this._templateProperty();
                this.element.append(this._toolbarContainer.append(this._templateContainer).append(this._ulcontainer));
            }
            else
                this.element.append(this._toolbarContainer.append(this._ulcontainer));
        },

        _flatToolbarItems: function () {
            this._winrtToolbarItems();
        },

        _createDelegates: function () {
            this._orientationChangedDelegate = $.proxy(this._orientationChangedHandler, this);
            this._touchStartDelegate = $.proxy(this._touchStartHandler, this);
            this._touchEndDelegate = $.proxy(this._touchEndHandler, this);
            this._documentTouchDelegate = $.proxy(this._documentTouchHandler, this);
            this._windowsResizeDelegate = $.proxy(this._windowResizeHandler, this);
            this._touchMoveDelegate = $.proxy(this._touchMoveHandler, this);
        },

        _touchStartHandler: function (evt) {
            var eventTarget = $(evt.target);
            if (this.model.renderMode == "windows" && (eventTarget.hasClass("e-m-toolbaritem-ellipsis") || eventTarget.hasClass("e-m-ellipsis")))
                this._touchMethods("ellipsis", "Start", evt);
            else if (this.model.renderMode == "android") {
                if (eventTarget.parent().hasClass('e-m-backactionbar'))
                    this._touchMethods("back", "Start", evt);
                else if (eventTarget.hasClass('e-m-ellipsis'))
                    this._touchMethods("ellipsis", "Start", evt);
                else if (!eventTarget.hasClass("e-m-toolbaritem"))
                    this._touchMethods(undefined, "Start", evt);
            }
            else if (!eventTarget.hasClass("e-m-toolbaritem"))
                this._touchMethods(undefined, "Start", evt);
            this._touchStarted = true;
            ej.listenEvents([document], [ej.moveEvent()], [this._touchMoveDelegate], false);
            targetName = eventTarget.next("div.e-m-tbiconblock").html();
            if (this.model.renderMode == "android") {
                if (eventTarget.hasClass("e-m-backicon"))
                    targetName = "back";
                else if (eventTarget.hasClass("e-m-ellipsis"))
                    targetName = "overflow";
            }
            var data = { "item": eventTarget, "itemname": targetName };
            if (this.model.touchStart)
                this._trigger('touchStart', data);
        },
        _touchEndHandler: function (evt) {
            var eventTarget = $(evt.target);
            this._touchEndProperties(evt);
            if ($(evt.target).parent().hasClass('e-m-backactionbar')) {
                $(".e-m-backactionbar").removeClass("active");
                history.back();
            }
            this._touchStarted = false;
            if (eventTarget.hasClass('e-m-fontimage'))
                targetName = eventTarget.next("div.e-m-tbiconblock").html();
            else
                targetName = eventTarget.html();
            if (this.model.renderMode == "android") {
                if (eventTarget.hasClass("e-m-backicon"))
                    targetName = "back";
                else if (eventTarget.hasClass("e-m-ellipsis"))
                    targetName = "overflow";
            }
            var data = { "item": eventTarget, "itemname": targetName };
            if (this.model.touchEnd)
                this._trigger('touchEnd', data);
            ej.listenEvents([document], [ej.moveEvent()], [this._touchMoveDelegate], true);
        },
        _touchEndProperties: function (evt) {
            var eventTarget = $(evt.target);
            if (this.model.renderMode == "windows" && (eventTarget.hasClass("e-m-toolbaritem-ellipsis") || eventTarget.hasClass("e-m-ellipsis")))
                this._touchMethods("ellipsis", "End", evt);
            else if (this.model.renderMode == "android") {
                if (eventTarget.hasClass('e-m-backicon'))
                    this._touchMethods("back", "End", evt);
                else if (eventTarget.hasClass('e-m-ellipsis'))
                    this._touchMethods("ellipsis", "End", evt);
                else if (!eventTarget.hasClass("e-m-toolbaritem"))
                    this._touchMethods(undefined, "End", evt);
            }
            else if (!eventTarget.hasClass("e-m-toolbaritem"))
                this._touchMethods(undefined, "End", evt);
            this._touchStarted = false;
        },
        _touchMethods: function (name, type, evt) {
            var currentTarget, currentTargetProperty;
            var eventTarget = $(evt.target);
            if (name == undefined) {
                currentTarget = ($((evt.target).parentElement).hasClass("e-m-menuitem")) ?
                     $((evt.target).parentElement) : eventTarget.closest('li.e-m-toolbaritem');
                currentTargetProperty = ej.getAttrVal(currentTarget, 'data-ej-touch' + type.toLowerCase(), (type == "Start" ? this.model.touchStart : this.model.touchEnd));
            }
            else {
                currentTarget = (this.model.renderMode == "windows") ?
                    (eventTarget.hasClass('e-m-ellipsis')) ? eventTarget.closest('div.e-m-ellipsis') : eventTarget.find('div.e-m-ellipsis') :
                    eventTarget.closest('div.e-m-' + name + (name == "back" ? "actionbar" : ""));
                currentTargetProperty = ej.getAttrVal(this.element, 'data-ej-android-' + name + (name == "back" ? "actionbar" : "") + 'touch' + type.toLowerCase());
            }
            if (this._isMobile && this.model.android.enableSplitView) {
                if (!eventTarget.hasClass('e-m-ellipsis') && !eventTarget.hasClass('e-m-backicon'))
                    currentTarget = currentTarget.find("div.e-m-tbicondiv");
            }
            this['_' + (type == 'Start' ? 'add' : 'remove') + 'Selection'](currentTarget);
        },
        _menuEvent: function (add, remove) {
            if (this.model.renderMode == "windows") {
                if (this._ellipsisMenu) {
                    (add == "show") ? this.element.css('height', this._tbMenuItems.length > 1 ? '170px' : '120px') : this.element.css('height', '50px');
                    if (this._Menucontainer.hasClass("e-m-menuitemcontainer-" + remove)) {
                        this._Menucontainer.addClass("e-m-menuitemcontainer-" + add).removeClass("e-m-menuitemcontainer-" + remove);
                        (this._isPortrait) ? this["_" + add + "PortraitMenuAnimation"]() : this["_" + add + "HorizontalMenuAnimation"]();
                    }
                    this.scrollWrapper.ejmScrollPanel("refresh");
                }
                else {
                    (add == "show") ? this.element.css('height', '70px') : this.element.css('height', '50px');
                    var selectvar = add == "show" ? "selected" : "unselected";
                    var unsel = selectvar == "selected" ? "unselected" : "selected";
                    var textblock = ej.getCurrentPage().find("div.e-m-tbiconblock");
                    if ($(textblock).hasClass("tbiconblock-" + unsel)) {
                        $(textblock).addClass("tbiconblock-" + selectvar).removeClass("tbiconblock-" + unsel);
                    }
                }
                (add == "show") ?
                    this.element.find('div.e-m-tbiconblock').css("padding-top", "4px") :
                    this.element.find('div.e-m-tbiconblock').css("padding-top", "10px");
            }
            this._isMenuOpened = add == "show" ? true : false;
            this._preventDocEnd = this._isMenuOpened;
        },
        _touchMoveHandler: function (evt) {
            this._touchMoved = true;
            var eventTarget = $(evt.target);
            if (this.model.renderMode == "android") {
                if ($(evt.target).hasClass("e-m-showellipsis-true active"))
                    $(evt.target).removeClass("active");
                else if ($(evt.target).parent("div.e-m-backactionbar").hasClass("active"))
                    $(evt.target).parent("div.e-m-backactionbar").removeClass("active");
                else
                    $(evt.target).parents("li.e-m-toolbaritem").removeClass("active");
            }
            else {
                if ($(evt.target).hasClass("tbicon-selected"))
                    $(evt.target).removeClass("tbicon-selected");
            }
        },

        _windowResizeHandler: function () {
            if (this.model.renderMode == "ios7" && this._isMobile) {
                var innerLiWidth = window.innerWidth / this._toolbarLiElements.length;
                this._toolbarLiElements.css("width", innerLiWidth).css("max-width", innerLiWidth);
            }
        },
        _documentTouchHandler: function (evt) {
            if (!this._preventDocEnd && this.model.renderMode == "windows") {
                if (this._isMenuOpened)
                    this.hideMenu();
            }
            this._preventDocEnd = false;
        },

        _orientationChangedHandler: function () {
            if ((this.model.renderMode == "windows" && this._isMenuOpened && this._isMobile)) {
                this.hideMenu();
                this._isPortrait = ej.isPortrait() ? true : false;
                this._tbMenuItems.removeClass("e-m-menumode-landscape e-m-menumode-portrait").addClass("e-m-menumode-" + (this._isPortrait ? "portrait" : "landscape"));
            }
        },
        _wireEvents: function (remove) {
            this._ulElement = $(this.element).find("ul");
            this._createDelegates();
            ej.listenEvents([window, window, window, this._ulElement, this._ulElement],
                [ej.tapEvent(), "orientationchange", "resize", ej.startEvent(), ej.endEvent()],
                [this._documentTouchDelegate, this._orientationChangedDelegate, this._windowsResizeDelegate,
                    this._touchStartDelegate, this._touchEndDelegate], remove);
            if (this.model.renderMode == "android") {
                this._liElement = $(this.element).find("li.e-m-toolbaritem");
                this._ellipsis = $(this.element).find("div.e-m-ellipsis");
                this._back = $(this.element).find("div.e-m-backactionbar");
                this._menuElement = $(this.element).find("li.e-m-menuitem");
                ej.listenEvents([this._ellipsis, this._ellipsis, this._back, this._back, this._menuElement, this._menuElement],
                    [ej.startEvent(), ej.endEvent(), ej.startEvent(), ej.endEvent(), ej.startEvent(), ej.endEvent()],
                    [this._touchStartDelegate, this._touchEndDelegate, this._touchStartDelegate, this._touchEndDelegate, this._touchStartDelegate, this._touchEndDelegate], remove);
            }
        },

        _doItemChanges: function (eventname, index, value) {
            this._ulcontainer = this.element.find("ul.e-m-tbulcontainer");
            this._toolbarLiElements = this._ulcontainer.find("li.e-m-toolbaritem");
            var currentItem = this._toolbarLiElements[index];
            var length = 5;
            if (eventname == "add" && (this._orgEle.find('li').length < length || this.model.renderMode == "android")) {
                index = this._orgEle.find('li').length - 1;
                $(this._orgEle.find('li')[index]).after('<li data-ej-iconname="' + value + '"></li>');

                this._refresh();
            }
            else if (eventname == "remove" && this._orgEle.find('li').length > 0 && this._orgEle.find('li').length > index) {
                $(this._orgEle.find('li')[index]).remove();
                this._refresh();
            }
            else if (eventname == "changeicon") {
                $(this._orgEle.find('li')[index]).remove();
                $(this._orgEle.find('li')[index - 1]).after('<li data-ej-iconname="' + value + '"></li>');
                this._refresh();
            }
        },

        _showPortraitMenuAnimation: function () {
            if (this.model.renderMode == "windows") {
                var delay = 0, count = 0;
                this._tbMenuItems.each(function () {
                    var _option = $(this);
                    setTimeout(function () {
                        delay = delay + 0.1;
                        _option.css("transition", "padding 0.5s ease " + delay + "s");
                        _option.css({ "padding-left": "20px", "padding-top": "20px" });
                    }, delay * count - 60);
                });
            }
            else
                this._Menucontainer.show();
        },
        _hidePortraitMenuAnimation: function () {
            if (this.model.renderMode == "windows") {
                this._tbMenuItems.each(function () {
                    $(this).css({ "padding-left": "20px", "padding-top": "40px" });
                });
            }
            else
                this._Menucontainer.hide();
        },
        _showHorizontalMenuAnimation: function () {
            if (this.model.renderMode == "windows") {
                var delay = 0, count = 0;
                this._tbMenuItems.each(function () {
                    var _option = $(this);
                    setTimeout(function () {
                        delay = delay + 0.1;
                        _option.css("transition", "padding 0.5s ease " + delay + "s");
                        _option.css({ "padding-left": "35px", "padding-top": "10px" });
                    }, delay * count - 60);
                });
            }
            else
                this._Menucontainer.show();
        },
        _hideHorizontalMenuAnimation: function () {
            if (this.model.renderMode == "windows") {
                this._tbMenuItems.each(function () {
                    $(this).css({ "padding-left": "0px", "padding-top": "10px" });
                });
            }
            else
                this._Menucontainer.hide();
        },
        _addSelection: function (currenttarget) {
            this._selectionProperties(currenttarget, "add");
        },
        _removeSelection: function (currenttarget) {
            if (currenttarget.hasClass('e-m-ellipsis') && this.model.renderMode == "windows")
                (this._isMenuOpened) ? this.hideMenu() : this.showMenu();
            this._selectionProperties(currenttarget, "remove");
        },
        _selectionProperties: function (currenttarget, selection) {
            if ((this.model.renderMode == "windows" || this.model.renderMode == "flat") || (this.model.renderMode == "ios7" && currenttarget.find("div").hasClass("e-m-tbicon")))
                (selection == "add") ? currenttarget.find('.e-m-tbicon').addClass("tbicon-selected") : currenttarget.find('.e-m-tbicon').removeClass("tbicon-selected");
            (this.model.renderMode == "android") ? ((selection == "add") ? currenttarget.addClass("active") : currenttarget.removeClass("active")) : "";
        },
        _setModel: function (options) {
            var refresh = false;
            for (var property in options) {
                switch (property) {
                    case "enabled": (options.enabled) ? this._enable() : this._disable(); break;
                    case "renderMode": (this.model.enabled) ? refresh = true : ""; break;
                    case "theme": (this.model.enabled) ? this._setTheme(options.theme) : ""; break;
                    case "hide": (options.hide) ? this._hide() : this._show(); break;
                }
                var setModel = "_set" + property.charAt(0).toUpperCase() + property.slice(1) + "Functionalities";
                if (this[setModel])
                    this[setModel](options[property]);
            }
            if (refresh)
                this._refresh();
        },
        _setAndroidFunctionalities: function (options) {
            for (var property in options) {
                switch (property) {
                    case "showBackNavigator": (options.showBackNavigator) ? this._showBackNavigator() : this._hideBackNavigator(); break;
                    case "showTitleIcon": (options.showTitleIcon) ? this._showTitleIconNavigator() : this._hideTitleIconNavigator(); break;
                    case "enableSplitView": (ej.isMobile()) ? this._refresh() : ""; break;
                    case "showEllipsis": (options.showEllipsis) ? this.showEllipsis() : this.hideEllipsis(); break;
                    case "title": (this.model.templateId == null) ? this._changeTitle(options.title) : ""; break;
                    case "titleIconUrl": this._changeImageUrl(options.titleIconUrl); break;
                }
            }
        },
        _changeTitle: function (title) {
            this.model.android.title = title;
            this.element.find("span.e-m-title-text").html(this.model.android.title);
        },
        _changeImageUrl: function (url) {
            this.model.android.titleIconUrl = url;
            this.element.find("img.e-m-titleicon").attr("src", this.model.android.titleIconUrl);
        },
        /**
        * To configure the show property for android mode toolbar back icon		
        * @private
        */
        _showBackNavigator: function () {
            this._back.find(".e-m-backicon").addClass("e-m-showback-true").removeClass("e-m-showback-false");
        },
        /**
        * To configure the hide property for android mode toolbar back icon	
        * @private
        */
        _hideBackNavigator: function () {
            this._back.find(".e-m-backicon").addClass("e-m-showback-false").removeClass("e-m-showback-true");
        },
        /**
        * To configure the show property for android mode toolbar title icon		
        * @private
        */
        _showTitleIconNavigator: function () {
            this._back.find(".e-m-titleicon").addClass("e-m-showtitle-true").removeClass("e-m-showtitle-false");
        },
        /**
        * To configure the hide property for android mode toolbar title icon	
        * @private
        */
        _hideTitleIconNavigator: function () {
            this._back.find(".e-m-titleicon").addClass("e-m-showtitle-false").removeClass("e-m-showtitle-true");
        },

        _setTheme: function (value) {
            if (this.model.enabled) {
                if (value) {
                    this.model.theme = value;
                    this.element.removeClass("e-m-dark e-m-light e-m-default").addClass("e-m-" + this.model.theme);
                    if ((this.model.renderMode == "android" || this.model.renderMode == "windows") && this._ellipsis)
                        this._ellipsis.removeClass("e-m-dark e-m-light").addClass("e-m-" + this.model.theme);
                    if (this.model.renderMode == "android" && this._back)
                        this._back.removeClass("e-m-dark e-m-light").addClass("e-m-" + this.model.theme);
                }
            }
        },
        /**
        * To configure the disabled property for toolbar		
        * @private
        */
        _disable: function () {
            this.element.addClass("e-m-state-disabled");
            this._wireEvents(true);
        },
        /**
        * To configure the disabled property for toolbar		
        * @private
        */
        _enable: function () {
            this.element.removeClass("e-m-state-disabled");
            this._wireEvents();
        },
        /**
        * To configure the hide property for toolbar		
        * @private
        */
        _show: function () {
            this.element.show();
        },
        /**
        * To configure the hide property for toolbar		
        * @private
        */
        _hide: function () {
            this.element.hide();
        },
        /**
        * To configure the refresh property for toolbar		
        * @private
        */
        _refresh: function () {
            this._destroy();
            this.element.addClass("e-m-tb");
            this._renderControl();
            this._wireEvents(false);
        },
        _clearElement: function () {
            this.element.removeAttr("class");
            this.element.html(this._orgEle.html());
            if (this._Menucontainer)
                this._Menucontainer.remove();
        },
        /**
        * To configure the destroy property for toolbar		
        * @private
        */
        _destroy: function () {
            this._wireEvents(true);
            this._clearElement();
        },


        /*---------------Public Methods---------------*/
        /**
        * To remove the toolbar icons by it's index
        * @return jQuery
        * @example 
        * &lt;div id="toolbar"&gt;
        * &lt;ul&gt;
        * &lt;li data-ej-iconname="add" &gt;&lt;/li&gt;
        * &lt;li data-ej-iconname="cut" &gt;&lt;/li&gt;
        * &lt;li data-ej-iconname="copy" &gt;&lt;/li&gt;
        * &lt;/ul &gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // remove the icon by index for toolbar
        * $("#toolbar").ejmToolbar();
        * var toolbar = $("#toolbar").data("ejmToolbar");
        * toolbar.removeItem(1); 
        * &lt;/script&gt;
        *@memberof ejmToolbar
        * @instance
        */
        removeItem: function (index) {
            this._doItemChanges("remove", index, undefined);
        },
        /**
        * To add new item to the toolbar
        * @return jQuery
        * @example 
        * &lt;div id="toolbar"&gt;
        * &lt;ul&gt;
        * &lt;li data-ej-iconname="add" &gt;&lt;/li&gt;
        * &lt;li data-ej-iconname="cut" &gt;&lt;/li&gt;
        * &lt;li data-ej-iconname="copy" &gt;&lt;/li&gt;
        * &lt;/ul &gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // add new icon to the toolbar
        * $("#toolbar").ejmToolbar();
        * var toolbar = $("#toolbar").data("ejmToolbar");
        * toolbar.addItem("paste"); 
        * &lt;/script&gt;
        *@memberof ejmToolbar
        * @instance
        */
        addItem: function (newitem) {
            this._doItemChanges("add", undefined, newitem);
        },
        /**
        * To hide the overflow menu in android
        * @return jQuery
        * @example 
        * &lt;div id="toolbar"&gt;
        * &lt;ul&gt;
        * &lt;li data-ej-iconname="add" &gt;&lt;/li&gt;
        * &lt;li data-ej-iconname="cut" &gt;&lt;/li&gt;
        * &lt;li data-ej-iconname="copy" &gt;&lt;/li&gt;
        * &lt;/ul &gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // add new icon to the toolbar
        * $("#toolbar").ejmToolbar();
        * var toolbar = $("#toolbar").data("ejmToolbar");
        * toolbar.hideMenu(); 
        * &lt;/script&gt;
        *@memberof ejmToolbar
        * @instance
        */
        hideMenu: function () {
            this._menuEvent("hide", "show");
            this._isMenuOpened = false;
        },
        /**
        * To show the overflow menu in android
        * @return jQuery
        * @example 
        * &lt;div id="toolbar"&gt;
        * &lt;ul&gt;
        * &lt;li data-ej-iconname="add" &gt;&lt;/li&gt;
        * &lt;li data-ej-iconname="cut" &gt;&lt;/li&gt;
        * &lt;li data-ej-iconname="copy" &gt;&lt;/li&gt;
        * &lt;/ul &gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // add new icon to the toolbar
        * $("#toolbar").ejmToolbar();
        * var toolbar = $("#toolbar").data("ejmToolbar");
        * toolbar.showMenu(); 
        * &lt;/script&gt;
        *@memberof ejmToolbar
        * @instance
        */
        showMenu: function () {
            this._menuEvent("show", "hide");
            this._isMenuOpened = true;
        },
        /**
        * To show ellipsis for android mode toolbar
        * @return jQuery
        * @example 
        * &lt;div id="toolbar"&gt;
        * &lt;ul&gt;
        * &lt;li data-ej-iconname="add" &gt;&lt;/li&gt;
        * &lt;li data-ej-iconname="cut" &gt;&lt;/li&gt;
        * &lt;li data-ej-iconname="copy" &gt;&lt;/li&gt;
        * &lt;/ul &gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // show ellipsis for android mode toolbar
        * $("#toolbar").ejmToolbar();
        * var toolbar = $("#toolbar").data("ejmToolbar");
        * toolbar.showEllipsis(); 
        * &lt;/script&gt;
        *@memberof ejmToolbar
        * @instance
        */
        showEllipsis: function () {
            this._ellipsis.addClass("e-m-showellipsis-true").removeClass("e-m-showellipsis-false");
        },
        /**
        * To hide ellipsis for android mode toolbar
        * @return jQuery
        * @example 
        * &lt;div id="toolbar"&gt;
        * &lt;ul&gt;
        * &lt;li data-ej-iconname="add" &gt;&lt;/li&gt;
        * &lt;li data-ej-iconname="cut" &gt;&lt;/li&gt;
        * &lt;li data-ej-iconname="copy" &gt;&lt;/li&gt;
        * &lt;/ul &gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // hide ellipsis for android mode toolbar
        * $("#toolbar").ejmToolbar();
        * var toolbar = $("#toolbar").data("ejmToolbar");
        * toolbar.hideEllipsis(); 
        * &lt;/script&gt;
        *@memberof ejmToolbar
        * @instance
        */
        hideEllipsis: function () {
            this._ellipsis.addClass("e-m-showellipsis-false").removeClass("e-m-showellipsis-true");
        },
        /**
        * To disable particular toolbar item by name
        * @return jQuery
        * @example 
        * &lt;div id="toolbar"&gt;
        * &lt;ul&gt;
        * &lt;li data-ej-iconname="add" &gt;&lt;/li&gt;
        * &lt;li data-ej-iconname="cut" &gt;&lt;/li&gt;
        * &lt;li data-ej-iconname="copy" &gt;&lt;/li&gt;
        * &lt;/ul &gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // disable particular icon in toolbar
        * $("#toolbar").ejmToolbar();
        * var toolbar = $("#toolbar").data("ejmToolbar");
        * toolbar.disableItem("add"); 
        * &lt;/script&gt;
        *@memberof ejmToolbar
        * @instance
        */
        disableItem: function (disableIcon) {
            if (this.model.enabled) {
                this.element.find('li.e-m-' + this.model.renderMode + '-' + disableIcon).addClass('e-m-state-disabled');
                this._wireEvents(true);
            }
        },
        /**
        * To enable particular toolbar item by name
        * @return jQuery
        * @example 
        * &lt;div id="toolbar"&gt;
        * &lt;ul&gt;
        * &lt;li data-ej-iconname="add" &gt;&lt;/li&gt;
        * &lt;li data-ej-iconname="cut" &gt;&lt;/li&gt;
        * &lt;li data-ej-iconname="copy" &gt;&lt;/li&gt;
        * &lt;/ul &gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // enable particular icon in toolbar
        * $("#toolbar").ejmToolbar();
        * var toolbar = $("#toolbar").data("ejmToolbar");
        * toolbar.enableItem("add"); 
        * &lt;/script&gt;
        *@memberof ejmToolbar
        * @instance
        */
        enableItem: function (enableIcon) {
            if (this.model.enabled) {
                this.element.find('li.e-m-' + this.model.renderMode + '-' + enableIcon).removeClass('e-m-state-disabled');
                this._wireEvents();
            }
        },
        /**
        * To hide particular toolbar item by name
        * @return jQuery
        * @example 
        * &lt;div id="toolbar"&gt;
        * &lt;ul&gt;
        * &lt;li data-ej-iconname="add" &gt;&lt;/li&gt;
        * &lt;li data-ej-iconname="cut" &gt;&lt;/li&gt;
        * &lt;li data-ej-iconname="copy" &gt;&lt;/li&gt;
        * &lt;/ul &gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // hide particular icon in toolbar
        * $("#toolbar").ejmToolbar();
        * var toolbar = $("#toolbar").data("ejmToolbar");
        * toolbar.hideItem("add"); 
        * &lt;/script&gt;
        *@memberof ejmToolbar
        * @instance
        */
        hideItem: function (iconName) {
            if (this.model.enabled)
                this.element.find('li.e-m-' + this.model.renderMode + '-' + iconName).css('display', 'none');
        },
        /**
        * To show particular toolbar item by name
        * @return jQuery
        * @example 
        * &lt;div id="toolbar"&gt;
        * &lt;ul&gt;
        * &lt;li data-ej-iconname="add" &gt;&lt;/li&gt;
        * &lt;li data-ej-iconname="cut" &gt;&lt;/li&gt;
        * &lt;li data-ej-iconname="copy" &gt;&lt;/li&gt;
        * &lt;/ul &gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // show particular icon in toolbar
        * $("#toolbar").ejmToolbar();
        * var toolbar = $("#toolbar").data("ejmToolbar");
        * toolbar.showItem("add"); 
        * &lt;/script&gt;
        *@memberof ejmToolbar
        * @instance
        */
        showItem: function (iconName) {
            if (this.model.enabled)
                this.element.find('li.e-m-' + this.model.renderMode + '-' + iconName).css('display', 'inline-block');
        }
        /*---------------Public Methods End---------------*/

    });
    /**
    * Enum for toolbar position
    * @enum {string}
    * @global
    */
    ej.mobile.Toolbar.Position = {
        /**
        Enum for relative position for toolbar*/
        Normal: "normal",
        /**
        Enum for fixed position for toolbar*/
        Fixed: "fixed"
    }
    /**
    * Enum for toolbar icon name
    * @enum {string}
    * @global
    */
    ej.mobile.Toolbar.IconName = {
        /**
        Enum for Add toolbar icon*/
        Add: "Add",
        /**
        Enum for Back toolbar icon*/
        Back: "Back",
        /**
        Enum for Bookmark toolbar icon*/
        Bookmark: "Bookmark",
        /**
        Enum for Close toolbar icon*/
        Close: "Close",
        /**
        Enum for Compose toolbar icon*/
        Compose: "Compose",
        /**
        Enum for Copy toolbar icon*/
        Copy: "Copy",
        /**
        Enum for Cut toolbar icon*/
        Cut: "Cut",
        /**
        Enum for Delete toolbar icon*/
        Delete: "Delete",
        /**
        Enum for Done toolbar icon*/
        Done: "Done",
        /**
        Enum for Edit toolbar icon*/
        Edit: "Edit",
        /**
        Enum for Mail toolbar icon*/
        Mail: "Mail",
        /**
        Enum for Next toolbar icon*/
        Next: "Next",
        /**
        Enum for Refresh toolbar icon*/
        Refresh: "Refresh",
        /**
        Enum for Overflow toolbar icon*/
        Overflow: "Overflow",
        /**
        Enum for Paste toolbar icon*/
        Paste: "Paste",
        /**
        Enum for Reply toolbar icon*/
        Reply: "Reply",
        /**
        Enum for Save toolbar icon*/
        Save: "Save",
        /**
        Enum for Search toolbar icon*/
        Search: "Search",
        /**
        Enum for Settings toolbar icon*/
        Settings: "Settings",
        /**
        Enum for Share toolbar icon*/
        Share: "Share"
    }
})(jQuery, Syncfusion);