/*!
*  filename: ej.captcha.js
*  version : 12.3
*  Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
*/

/**
* @fileOverview Plugin to style the Html Captcha elements
* @copyright Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.3 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/

 (function ($, ej, undefined) {
	/**
    * @namespace ej
	* @classdesc Custom Design for Html Captcha control.
	* @class ejCaptcha
	* @param {object} options - settings for Captcha
	* @requires jQuery
	* @requires ej.core.js
    * @requires ej.captcha.js
	* @requires ej.button.js
	* @example 
	* &lt;captcha id="captcha1"&gt;Captcha&lt;/Captcha&gt; <br> 
	* &lt;script&gt;
	* // Create Captcha
    * $('#Captcha1').ejCaptcha(); 	
	* &lt;/script&gt;
	*/
       ej.widget("ejCaptcha", "ej.Captcha", {
        // widget element will be automatically set in this
        element: null,
        // user defined model will be automatically set in this
        model: null,
        validTags: ["div"],
        _setFirst: false,
        //Root Css Class
        _rootCSS: "e-captcha",

        // default model
        defaults: {
            /// <summary>This Contains default property of Captcha </summary>
			/**		
			* Specifies the background patterns for the Captcha.	
			* @default true
			* @type {boolean}
			* @example 
			* &lt;div id="captcha1"&gt;&lt;/div&gt; <br> 
			* &lt;script&gt;
			* //To set target input API value during initialization  
			* 	$("#captcha1").ejCaptcha({  enablePattern: true});	
			* &lt;/script&gt;
			* @memberof ejCaptcha
			* @instance
			*/	
			enablePattern:true,
			/**		
			* Specifies the target input element that will verify the Captcha.	
			* @default null
			* @type {string}
			* @example 
			* &lt;div id="captcha1"&gt;&lt;/div&gt; <br> 
			* &lt;script&gt;
			* //To set target input API value during initialization  
			* 	$("#captcha1").ejCaptcha({  targetInput: "input1"});	
			* &lt;/script&gt;
			* @memberof ejCaptcha
			* @instance
			*/	
            targetInput: "",
			/**		
			* Specifies the target button of the Captcha to validate the entered text and captcha text.	
			* @default null
			* @type {string}
			* @example 
			* &&lt;div id="captcha1"&gt;&lt;/div&gt; <br> 
			* &lt;button id="button1"&gt;Submit&lt;/button&gt; <br>
			* &lt;script&gt;
			* //To set target button API value during initialization  
			* 	$("#captcha1").ejCaptcha({  targetButton: "button1"});	
			* &lt;/script&gt;
			* @memberof ejCaptcha
			* @instance
			*/	
            targetButton:"",
			/**		
			* Specifies the height of the Captcha.
			* @default 50
			* @type {number}
			* @example 
			* &&lt;div id="captcha1"&gt;&lt;/div&gt; <br> 
			* &lt;script&gt;
			* //To set height API value during initialization  
			* 	$("#captcha1").ejCaptcha({  height: 50});	
			* &lt;/script&gt;			
			* @memberof ejCaptcha
			* @instance
			*/
            height :50,
			/**		
			* Specifies the width of the Captcha.
			* @default 150
			* @type {number}
			* @example 
			* &&lt;div id="captcha1"&gt;&lt;/div&gt; <br> 
			* &lt;script&gt;
			* //To set width API value during initialization  
			* 	$("#captcha1").ejCaptcha({  width: 150});	
			* &lt;/script&gt;				
			* @memberof ejCaptcha
			* @instance
			*/
            width :150,
			/**		
			* Specifies the character set of the Captcha that will be used to generate captcha text randomly.
			* @default "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789"
			* @type {string}
			* @example 
			* &&lt;div id="captcha1"&gt;&lt;/div&gt; <br> 
			* &lt;script&gt;
			* //To set character set API value during initialization  
			* 	$("#captcha1").ejCaptcha({  characterSet: "ABCD1234"});	
			* &lt;/script&gt;				
			* @memberof ejCaptcha
			* @instance
			*/
            characterSet : "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789",
			/**		
			* Specifies the maximum number of characters used in the Captcha.
			* @default 8
			* @type {number}
			* @example 
			* &&lt;div id="captcha1"&gt;&lt;/div&gt; <br> 
			* &lt;script&gt;
			* //To set maximum length API value during initialization  
			* 	$("#captcha1").ejCaptcha({  maximumLength: 8});	
			* &lt;/script&gt;				
			* @memberof ejCaptcha
			* @instance
			*/
            maximumLength :8,  
			/**		
			* Specifies the minimum number of characters used in the Captcha.
			* @default 4
			* @type {number}
			* @example 
			* &&lt;div id="captcha1"&gt;&lt;/div&gt; <br> 
			* &lt;script&gt;
			* //To set minimum length API value during initialization  
			* 	$("#captcha1").ejCaptcha({  minimumLength: 6});	
			* &lt;/script&gt;				
			* @memberof ejCaptcha
			* @instance
			*/
            minimumLength:4,
			/**		
			* Specifies the case sensitivity for the characters typed in the Captcha.
			* @default true
			* @type {boolean}
			* @example 
			* &&lt;div id="captcha1"&gt;&lt;/div&gt; <br> 
			* &lt;script&gt;
			* //To set case sensitivity API value during initialization  
			* 	$("#captcha1").ejCaptcha({  enableCaseSensitivity: true});	
			* &lt;/script&gt;				
			* @memberof ejCaptcha
			* @instance
			*/
            enableCaseSensitivity :true,
			/**		
			* Set the Captcha validation automatically.
			* @default false
			* @type {boolean}
			* @example 
			* &&lt;div id="captcha1"&gt;&lt;/div&gt; <br> 
			* &lt;script&gt;
			* //To set auto validation API value during initialization  
			* 	$("#captcha1").ejCaptcha({  enableAutoValidation: true});	
			* &lt;/script&gt;				
			* @memberof ejCaptcha
			* @instance
			*/
            enableAutoValidation:false,
			/**		
			* Specifies the error message to be displayed when the Captcha mismatch.
			* @default null
			* @type {string}
			* @example 
			* &&lt;div id="captcha1"&gt;&lt;/div&gt; <br> 
			* &lt;script&gt;
			* //To set error message API value during initialization  
			* 	$("#captcha1").ejCaptcha({  customErrorMessage: "InValid Captcha"});	
			* &lt;/script&gt;				
			* @memberof ejCaptcha
			* @instance
			*/			
            customErrorMessage: "",
			/**		
			* Sets the Captcha with audio support, that enables to dictate the captcha text.
			* @default false
			* @type {boolean}
			* @example 
			* &&lt;div id="captcha1"&gt;&lt;/div&gt; <br> 
			* &lt;script&gt;
			* //To set enable audio API value during initialization  
			* 	$("#captcha1").ejCaptcha({  showAudioButton: true});	
			* &lt;/script&gt;				
			* @memberof ejCaptcha
			* @instance
			*/
			showAudioButton:false,
			/**		
			* Sets the Captcha with a refresh button.
			* @default false
			* @type {boolean}
			* @example 
			* &&lt;div id="captcha1"&gt;&lt;/div&gt; <br> 
			* &lt;script&gt;
			* //To set enable refresh API value during initialization  
			* 	$("#captcha1").ejCaptcha({  showRefreshButton: true});	
			* &lt;/script&gt;				
			* @memberof ejCaptcha
			* @instance
			*/
			showRefreshButton: false,			
			/**		
			* Sets the Captcha direction as right to left alignment.
			* @default false
			* @type {boolean}
			* @example 
			* &&lt;div id="captcha1"&gt;&lt;/div&gt; <br> 
			* &lt;script&gt;
			* //To set enable RTL API value during initialization  
			* 	$("#captcha1").ejCaptcha({  enableRTL: true});	
			* &lt;/script&gt;				
			* @memberof ejCaptcha
			* @instance
			*/
            enableRTL:false,
			/**		
			* Specifies the method to map values to Captcha.
			* @default null
			* @type {string}
			* @example 
			* &&lt;div id="captcha1"&gt;&lt;/div&gt; <br> 
			* &lt;script&gt;
			* //To set request mapper API value during initialization  
			* 	$("#captcha1").ejCaptcha({  requestMapper: "GetCurrentItem"});	
			* &lt;/script&gt;				
			* @memberof ejCaptcha
			* @instance
			*/
            requestMapper:"",
			/**		
			* Fires when captch refresh begins.
			* @event
			* @name ejCaptcha#refreshBegin 	
			* @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
			* @param {object}  argument.model returns the Captcha model
			* @param {string}  argument.type returns the name of the event		  
			* @example
			* &&lt;div id="captcha1"&gt;&lt;/div&gt; <br> 
			* &lt;script&gt;
			* //Refresh begin event of Captcha control 
			* 	$("#captcha1").ejCaptcha({  
				refreshBegin: function(args) {}
				});	
			* &lt;/script&gt;				
			* @memberof ejCaptcha
			* @instance
			*/
            refreshBegin:"",
			/**		
			* Fires after captch refresh succeeded.
			* @event
			* @name ejCaptcha#refreshSuccess 	
			* @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
			* @param {object}  argument.model returns the Captcha model
			* @param {string}  argument.type returns the name of the event		  
			* @example
			* &&lt;div id="captcha1"&gt;&lt;/div&gt; <br> 
			* &lt;script&gt;
			* //Refresh success event of Captcha control 
			* 	$("#captcha1").ejCaptcha({  
				refreshSuccess: function(args) {}
				});	
			* &lt;/script&gt;				
			* @memberof ejCaptcha
			* @instance
			*/
            refreshSuccess:"",
			/**		
			* Fires when captch refresh fails to load.
			* @event
			* @name ejCaptcha#refreshFailure 	
			* @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
			* @param {object}  argument.model returns the Captcha model
			* @param {string}  argument.type returns the name of the event		  
			* @example
			* &&lt;div id="captcha1"&gt;&lt;/div&gt; <br> 
			* &lt;script&gt;
			* //Refresh failure event of Captcha control 
			* 	$("#captcha1").ejCaptcha({  
				refreshFailure: function(args) {}
				});	
			* &lt;/script&gt;				
			* @memberof ejCaptcha
			* @instance
			*/
            refreshFailure:"",
			/**		
			* Fires after captch refresh completed.
			* @event
			* @name ejCaptcha#refreshComplete 	
			* @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
			* @param {object}  argument.model returns the Captcha model
			* @param {string}  argument.type returns the name of the event		  
			* @example
			* &&lt;div id="captcha1"&gt;&lt;/div&gt; <br> 
			* &lt;script&gt;
			* //Refresh complete event of Captcha control 
			* 	$("#captcha1").ejCaptcha({  
				refreshComplete: function(args) {}
				});	
			* &lt;/script&gt;				
			* @memberof ejCaptcha
			* @instance
			*/
            refreshComplete: "",
			/**		
			* Specifies the method with values to be mapped in the Captcha.
			* @default null
			* @type {string}
			* @example 
			* &&lt;div id="captcha1"&gt;&lt;/div&gt; <br> 
			* &lt;script&gt;
			* //To set mapper API value during initialization  
			* 	$("#captcha1").ejCaptcha({  mapper: "GetCurrentItem"});	
			* &lt;/script&gt;				
			* @memberof ejCaptcha
			* @instance
			*/
            mapper:"",
			/**		
			* Specifies the background apperance for the captcha.
			* @default value set as BackwardDiagonal
			* @type {enum}
			* @example 
			* &&lt;div id="captcha1"&gt;&lt;/div&gt; <br> 
			* &lt;script&gt;
			* //To set mapper API value during initialization  
			* 	$("#captcha1").ejCaptcha({  hatchStyle: "BackwardDiagonal"});	
			* &lt;/script&gt;				
			* @memberof ejCaptcha
			* @instance
			*/
            hatchStyle:"BackwardDiagonal"
        },
        /**	
    * Specify the data types for default properties 
    * @private
    */
        //Data Types
        dataTypes: {
            targetInput: "string",
            targetButton:"string",
            height :"number",
            width :"number",
            characterSet : "string",
            maximumLength :"number",             
            minimumLength:"number",            
            enableCaseSensitivity :"boolean",
            enableAutoValidation :"boolean",            
            customErrorMessage: "string",
            requestMapper: "string",
            showAudioButton: "boolean",
            showRefreshButton:"boolean",
            enableRTL:"boolean",            
            mapper:"string",
            hatchStyle:"enum",
			enablePattern:"boolean"
        },
        /**
* Create the Captcha widget
* @private
*/
        _init: function () {
            /// <summary>This will initialize captcha </summary>
            this._initialize();
            this._wireEvents();
        },       
         
        /*----------------------- Private Methods-----------------------------------------*/
        //initialize the control
        _initialize: function () {         
        $("#"+ this._id + "_RefreshButton").ejButton({size: "normal", showRoundedCorner : true, contentType: "imageonly", prefixIcon: "e-captcha refreshicon",type:"button"});
        $("#"+ this._id + "_PlayAudio").ejButton({size: "normal", showRoundedCorner : true, contentType: "imageonly", prefixIcon: "e-captcha audioicon",type:"button"});
            this._control = $("#" + this._id).get(0);
			if(!this.model.targetInput)
            this.model.targetInput = this._id + "_ValidText";
            this._target  = $("#"+ this.model.targetInput).get(0);
            this._captchaImage = $("#"+ this._id + "_CaptchaImage").get(0);
            this._message = $("#"+ this._id + "_CaptchaMessage").get(0);
            this._refreshButton = $("#"+ this._id + "_RefreshButton").get(0);
            this._form = $(this._target).parents('form')[0];				
            this._audioObject = $("#"+ this._id + "_AudioObject").get(0);
            this._audioButton = $("#"+ this._id + "_PlayAudio").get(0);
            this._audioPluginObject = null;
            this._audioType = "audio/wav";                                       
            this._submitButton=$("#"+this.model.targetButton).get(0);
            if(!this._submitButton)
            this._submitButton=$("[id$="+this.model.targetButton+"]").get(0);
            this._hiddenField = $("#"+ this._id + "_Hidden").get(0);
            
            if (this._audioObject) {
                if (!this._isSupportAudio(this._audioType)) {
                    this._appendAudioPlugin();
                }
            }
        },
        //Wiring Events
        /**
* Wiring the events to Captcha control		
* @private
*/
        _wireEvents: function (val) {            
            this._FormSubmitDelegate = $.proxy(this.formSubmit, this);
            this._CaptchaRefreshDelegate = $.proxy(this.refresh, this);
            this._PlayAudioDelegate = $.proxy(this.playAudio, this);

            if (this._audioButton)
                $(this._audioButton).on('click', this._PlayAudioDelegate);
            if (this._submitButton)
                $(this._submitButton).on('click', this._FormSubmitDelegate);
            if (this._refreshButton)
                $(this._refreshButton).on('click', this._CaptchaRefreshDelegate);
        },  

        //Remove Handlers
        _unwireEvents: function () {
            if (this._audioButton)
                $(this._audioButton).unbind('click', this._PlayAudioDelegate);
            if (this._submitButton)
                $(this._submitButton).unbind('click', this._FormSubmitDelegate);
            if (this._refreshButton)
                $(this._refreshButton).unbind('click', this._CaptchaRefreshDelegate);
        },

         //Play Audio
            playAudio : function(){

                try{
                    if (this._audioPluginObject) {
                        this._audioPluginObject.Play();
                    } else {
                        if (this._audioObject && this._audioObject.play) {                           
                            this._audioObject.play();
                        }
                    }
                } catch (e) { }
            },

            //Is Support audio
            _isSupportAudio: function (type) {
                if (!document.createElement("audio").canPlayType) {
                    return false;
                } else {
                    return document.createElement("audio").canPlayType(type).match(/maybe|probably/i) ? true : false;
                }
            },
            //Append audio plugin 
            _appendAudioPlugin: function () {
                $(this._audioPluginObject).remove();
                var obj = this._createAudioPluginObject();
                this._audioObject.parentNode.appendChild(obj);
                this._audioPluginObject = $("#"+this._id + "_AudioPlugin").get(0);
            },
            //Create Audio Plugin Object
            _createAudioPluginObject : function(){
                var a = document.createElement("embed");
                a.setAttribute("id", this._id + "_AudioPlugin");
                a.setAttribute("src", this.model.audioUrl);
                a.setAttribute("name", "AudioPlugin");
                a.setAttribute("enablejavascript", "true");
                a.setAttribute("type", "audio/wav");
                a.setAttribute("autostart", "false");
                a.setAttribute("pluginspage", "http://www.apple.com/quicktime/download/");
                a.style.top = 0;
                a.style.left = 0;
                a.style.width = "0px";
                a.style.height = "0px";
                a.style.position = "absolute";
                return a;
            },

            //On ajax Success
            _onSuccess: function (captchaResult) {
                var jsonCaptcha;               
                    jsonCaptcha = JSON.parse(captchaResult);
                this._validSuccess(jsonCaptcha);               
            },

             _onSuccessAsp: function (captchaResult) {
                var jsonCaptcha;               
                    jsonCaptcha = JSON.parse(captchaResult.d);

                    this._validSuccess(jsonCaptcha);              
            },

            //To display validation message
            _displayMessages: function () {
                if (this.model.isValid)
                {
                    $("#" + this._id + "_CaptchaMessage").html("");
                }
                else
				{      
                    $("#" + this._id + "_CaptchaMessage").html(this.model.customErrorMessage);
                    $("#" + this._id + "_ValidText").addClass("error");
                }

            },
            _validSuccess: function(jsonCaptcha)
            {
			try {
                    if (this._audioPluginObject) {
                        this._audioPluginObject.Pause();
                    } else if (this._audioObject && this._audioObject.pause) {
                        this._audioObject.pause();
                    }
                } catch (e) { }

                this._captchaImage.src = jsonCaptcha.NewChallenge;
                if(this._audioObject)
                this._audioObject.src = jsonCaptcha.AudioLink;

                this.model.audioURL=jsonCaptcha.AudioLink;

                if (this._audioPluginObject) {
                    this._appendAudioPlugin();
                }

                if (jsonCaptcha.Validation == "false")
                    this.model.isValid = false;
                else
                    this.model.isValid = true;
                if (this.model.enableAutoValidation)
                    this._displayMessages(); 
				if($("#"+this._id + "_ValidText"))
                   $("#"+this._id + "_ValidText").val("");
                   this.model.encryptedCode=jsonCaptcha.Script;
                $(this._hiddenField).val(this.model.encryptedCode);
            },
           _refreshSuccess: function(jsonCaptcha)
           {
              try {
                    if (this._audioPluginObject) {
                        this._audioPluginObject.Pause();
                    } else if (this._audioObject && this._audioObject.pause) {
                        this._audioObject.pause();
                    }
                } catch (e) { }

                this._captchaImage.src = jsonCaptcha.NewChallenge;
                if (this._audioObject) {
                    this._audioObject.src = jsonCaptcha.AudioLink;
                }
                this.model.audioUrl=jsonCaptcha.AudioLink;

                if (this._audioPluginObject) {
                    this._appendAudioPlugin();
                }
                this.model.encryptedCode=jsonCaptcha.EncryptedText;
                $(this._hiddenField).val(jsonCaptcha.EncryptedText);    
           },
            //On captcha refresh ajax Success
            _onRefreshSuccess: function (captchaRefresh) {
                var jsonCaptcha;
                jsonCaptcha = JSON.parse(captchaRefresh);
                  this._refreshSuccess(jsonCaptcha)           

            },
            _onRefreshSuccessAsp: function (captchaRefresh)
            {
            var jsonCaptcha;
                jsonCaptcha = JSON.parse(captchaRefresh.d);
                this._refreshSuccess(jsonCaptcha)             
            },
  
            /*-----------------------Event Handlers -----------------------------------------*/
            //Hanldes the form submit event
            formSubmit: function(event) {
                var proxy = this;
                var data = {
                    Height: this.model.height,
                    Width: this.model.width,
                    CharacterSet: this.model.characterSet,
                    MaximumLength: this.model.maximumLength,                     
                    MinimumLength: this.model.minimumLength,
                    CaseSensitive: this.model.enableCaseSensitivity,
                    ShowRefreshButton: this.model.showRefreshButton,
                    ShowAudioButton: this.model.showAudioButton,
                    ResponseText: $(this._target).val(),
                    EncrytedText: this.model.encryptedCode,
                    Id: this._id,
                    HatchStyle:this.model.hatchStyle,
					EnablePattern:this.model.enablePattern,
                    RequestType: "CaptchaRequest"
                };
                if (this.model.requestMapper) {
				if(this.model.requestMapper.match("^/")!=null)
                url=".."+this.model.requestMapper;
                else
                url=this.model.requestMapper;		
                    $.ajax({
                        type: 'Post',
                        url: url,
                        data: data,
                        dataType: "html",
                        async: false,
                        success: function(CaptchaResult) {
                            proxy._onSuccess(CaptchaResult);
                        },
                        error: function(e) {

                        }
                    });
                }
				else
                {
                    if (this.model.pathName)
                    {                   
                       $.ajax({
                        type: 'POST',
                        url: this.model.pathName+"/"+this.model.mapper,                        
                       data: '{encryptedCode: "'+this.model.encryptedCode+'",characterSet:"'+this.model.characterSet+'",height:"'+this.model.height+'",targerValue:"'+$(this._target).val()+'",minimumLength:"'+this.model.minimumLength+'",maximumLength:"'+this.model.maximumLength+'",hatchStyle:"'+this.model.hatchStyle+'"}',                        
                        contentType: "application/json; charset=utf-8",
                        dataType: "json",         
                        async: false,
                        success: function(CaptchaResult) {
                            proxy._onSuccessAsp(CaptchaResult);
                            return;
                        },
                        error: function(e) {
                        proxy._trigger("refreshFailure");
                            return;
                        }
                    });
                    }
                   }
                //Check if invalid and stop form submit
                if (!this.model.isValid && this.model.enableAutoValidation) {
                    event.preventDefault();
                    event.stopPropagation();
                    return false;
                }
            },
            //Hanlder for captcha refresh event
            refresh : function (event) {
                var proxy = this;
                var data = {
                    Height: this.model.height,
                    Width: this.model.width,
                    CharacterSet: this.model.characterSet,
                    MaximumLength: this.model.maximumLength, 
                    MinimumLength: this.model.minimumLength,                   
                    CaseSensitive: this.model.enableCaseSensitivity,
                    ResponseText: $(this._target).val(),
                    EncrytedText: this.model.encryptedCode,
                    ShowRefreshButton: this.model.showRefreshButton,
                    ShowAudioButton:this.model.showAudioButton,                 
                    Id: this._id,
                    HatchStyle:this.model.hatchStyle,
					EnablePattern:this.model.enablePattern,
                    RequestType: "CaptchaRequest"
                };
                var handler = this.model.refreshBegin;
                var eventArgs = this.model;
                if (handler) {
                    handler(proxy, eventArgs);
                    if (eventArgs.getCancel()) {
                        return false;
                    }
                }
                if (this.model.requestMapper) { 
				if(this.model.requestMapper.match("^/")!=null)
                url=".."+this.model.requestMapper;
                else
                url=this.model.requestMapper;				
                    $.ajax({
                        type: 'Post',
                        url: url,
                        data: data,
                        dataType: "html",
                        async: false,
                        success: function (CaptchaRefresh) {
                            proxy._onRefreshSuccess(CaptchaRefresh);
                            proxy._trigger("refreshSuccess")
                                return;
                        },
                        error: function (errData) {                            
                            proxy._trigger("refreshFailure")
                            return;
                        },
                        complete: function (jqXHR, textStatus) {                           
                            proxy._trigger("refreshComplete")
                            return;
                        }
                    });
                }
                 else 
                 {  
                    if (this.model.pathName)
                     {
                         $.ajax({
                        type: 'POST',
                        url: this.model.pathName+"/"+this.model.mapper,                        
                        data: '{encryptedCode: "'+this.model.encryptedCode+'",characterSet:"'+this.model.characterSet+'",height:"'+this.model.height+'",targerValue:"'+$(this._target).val()+'",minimumLength:"'+this.model.minimumLength+'",maximumLength:"'+this.model.maximumLength+'",hatchStyle:"'+this.model.hatchStyle+'"}',                        
                        contentType: "application/json; charset=utf-8",
                        dataType: "json",                   
                        success: function (CaptchaRefresh) {
                            proxy._onRefreshSuccessAsp(CaptchaRefresh);
                            proxy._trigger("refreshSuccess")
                                return;
                        },
                        error: function (errData) {                            
                            proxy._trigger("refreshFailure")
                            return;
                        },
                        complete: function (jqXHR, textStatus) {                           
                            proxy._trigger("refreshComplete")
                            return;
                        }
                    });
                   }
                 }
            } 
    })      
})(jQuery, Syncfusion);