﻿(function ($, ej, undefined) {
    ej.gridFeatures = ej.gridFeatures || {};
    ej.gridFeatures.selection = {
        /**
         * Select rows in grid.
         * @alias ejGrid#selectRows
         * @return jQuery
         * @param { number } fromIndex It is used to set the starting index of row for selecting rows.
         * @param { number } toIndex It is used to set the ending index of row for selecting rows.
         * @example 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // Selects rows based on the given index
         * gridObj.selectRows(1, 4); 
         * &lt;/script&gt;
         * @example 
         * &lt;script&gt;
         * // Selects rows based on the given index
         * $("#Grid").ejGrid("selectRows", 1, 4);
         * &lt;/script&gt;
         */
        selectRows: function (rowIndex, toIndex, target) {
            if (!this.model.allowSelection)
                return false;
            var $gridRows = $(this.getRows());
            var args = {};  
			var Data = this._currentJsonData[rowIndex];
			if(this.model.scrollSettings.allowVirtualScrolling){			
				var pageSize = this.model.pageSettings.pageSize;
				var nameIndx = this.getRowByIndex(rowIndex).attr("name");                
				var pageIndex = !ej.isNullOrUndefined(nameIndx) ? (parseInt(nameIndx)/pageSize) + 1 : rowIndex;
				var $vLen = this.getRowByIndex(rowIndex).prevAll(".e-virtualrow").length;
				var trIndex = (rowIndex - $vLen)%(pageSize);
				var query = ej.Query().page(pageIndex,pageSize);
				var result = this._dataManager.executeLocal(query);
				Data = result[trIndex];
			}
		    args = { rowIndex: rowIndex, row: $gridRows.eq(rowIndex), data: Data, target: target, prevRow: this.getRowByIndex(this._previousIndex), prevRowIndex : this._previousIndex };
            if (this._trigger("rowSelecting", args))
                return;
            if ((this.model.editSettings.allowEditing || this.model.editSettings.allowAdding) && this.model.isEdit && this.model.enableAutoSaveOnSelectionChange) {
                if (this.model.editSettings.editMode == "externalform" || this.model.editSettings.editMode == "externalformtemplate")
                    $("#" + this._id + "_externalEdit").css("display", "none");
                if (this.endEdit())
                    return;
                var $gridRows = $(this.getRows());
            }
            if (ej.isNullOrUndefined(toIndex) || ej.isNullOrUndefined(rowIndex)) {
                rowIndex = ej.isNullOrUndefined(rowIndex) ? toIndex : rowIndex;
                switch (this.model.selectionType) {
                    case ej.Grid.SelectionType.Multiple:
                        if (this.multiSelectCtrlRequest) {
                            var selectedRowIndex = $.inArray(rowIndex, this.selectedRowsIndexes);
                            selectedRowIndex != -1 && this.clearSelection(rowIndex) && this.selectedRowsIndexes.splice(selectedRowIndex, 0);
                            if (selectedRowIndex == -1) {
                                this.selectedRowsIndexes.push(rowIndex);
                                this.getRowByIndex(rowIndex).attr("aria-selected", "true").find('.e-rowcell, .e-detailrowcollapse, .e-detailrowexpand').addClass("e-selectionbackground e-active");
                            }
                            break;
                        }
                    case ej.Grid.SelectionType.Single:
                        this.clearSelection();
                        this.clearColumnSelection();
                        this.selectedRowsIndexes = [];
                        this.selectedRowsIndexes.push(rowIndex);
                        this.getRowByIndex(rowIndex).attr("aria-selected", "true").find('.e-rowcell, .e-detailrowcollapse, .e-detailrowexpand').addClass("e-selectionbackground e-active");
                        break;
                }
            } else {
                if (this.model.selectionType == ej.Grid.SelectionType.Multiple) {
                    this.clearSelection();
                    this.clearColumnSelection();
                    this.selectedRowsIndexes = [];
                    rows = rowIndex - toIndex < 0 ? this.getRowByIndex(rowIndex, toIndex + 1) : this.getRowByIndex(toIndex, rowIndex + 1);
                    for (var i = 0; i < rows.length; i++)
                        this.selectedRowsIndexes.push(rows[i].rowIndex);
                    $(rows).attr("aria-selected", "true").find('.e-rowcell, .e-detailrowcollapse, .e-detailrowexpand').addClass("e-selectionbackground e-active");
                }
            }
            if (this._selectedRow() !== rowIndex)
                this._selectedRow(rowIndex);
            var args = { rowIndex: this._selectedRow(), row: this.getRowByIndex(this._selectedRow()), data: Data, target: target, prevRow: this.getRowByIndex(this._previousIndex), prevRowIndex : this._previousIndex };
            this._previousIndex = this.selectedRowsIndexes.length ? rowIndex : undefined;
            this._trigger("rowSelected", args);
            // this.multiSelectCtrlRequest = false;
        },

        /**
         * Select cells in grid.
         * @alias ejGrid#selectCells
         * @return jQuery
         * @param { object } rowCellIndexes It is used to set the starting index of row and indexes of cells for that corresponding row for selecting cells.
         * @example 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // Selects cells based on the given index
         * gridObj.selectCells([[1, [4, 3, 2]]]); 
         * &lt;/script&gt;
         * @example 
         * &lt;script&gt;
         * // Selects cells based on the given index
         * $("#Grid").ejGrid("selectCells", [[1, [4, 3, 2]]]);
         * &lt;/script&gt;
         */
        selectCells: function (rowCellIndexes) {
            if (!this.model.allowSelection && !this._allowcellSelection)
                return false;
            var $cell = $(this.getRowByIndex(rowCellIndexes[0][0]).find(".e-rowcell:eq(" + rowCellIndexes[0][1] + ")"));
            if(!ej.isNullOrUndefined(this._previousRowCellIndex))
                var previousRowCell = $(this.getRowByIndex(this._previousRowCellIndex[0][0]).find(".e-rowcell:eq("+this._previousRowCellIndex[0][1]+")"))	
            var args = { currentCell: $cell, cellIndex: rowCellIndexes[0][1], data: this._currentJsonData[rowCellIndexes[0][0]], previousRowCellIndex: this._previousRowCellIndex, previousRowCell: previousRowCell };
            if (this.model.selectionType == "multiple") {
                args["isCtrlPressed"] = this.multiSelectCtrlRequest;
                args["isShiftPressed"] = this._multiSelectShiftRequest;
            }
            if (this._trigger("cellSelecting", args))
                return;
            switch (this.model.selectionType) {
                case ej.Grid.SelectionType.Multiple:
                    if (this.multiSelectCtrlRequest) {
                        var selectedCellIndex = $.inArray(rowCellIndexes[0][0], this._rowIndexesColl);
                        if (selectedCellIndex != -1)
                            this.selectedRowCellIndexes[selectedCellIndex].cellIndex.push(parseInt(rowCellIndexes[0][1].toString()));
                        else {
                            if ($.inArray(rowCellIndexes[0][0], this._rowIndexesColl) == -1)
                                this._rowIndexesColl.push(rowCellIndexes[0][0]);
                            this.selectedRowCellIndexes.push({ rowIndex: rowCellIndexes[0][0], cellIndex: rowCellIndexes[0][1] });
                        }
                        $cell.addClass("e-cellselectionbackground e-activecell");
                        break;
                    }
                    else if (this._multiSelectShiftRequest) {
                        this.clearCellSelection();
                        this.clearColumnSelection();
                        this.selectedRowCellIndexes = [];
                        var previousRowIndex = this._previousRowCellIndex[0][0];
                        var previousCellIndex = parseInt(this._previousRowCellIndex[0][1]);
                        var currentRowIndex = rowCellIndexes[0][0];
                        var currentCellIndex = parseInt(rowCellIndexes[0][1]);
                        var newCellColl = [];
                        var min, max;
                        if (currentRowIndex > previousRowIndex) {
                            for (var i = previousRowIndex; i <= currentRowIndex; i++) {
                                newCellColl = [];
                                min = i == previousRowIndex ? previousCellIndex : 0;
                                max = i == currentRowIndex ? currentCellIndex : this.model.columns.length;
                                for (var j = min; j <= max; j++) {
                                    newCellColl.push(j);
                                    $(this.getRowByIndex(i).find(".e-rowcell:eq(" + j + ")")).addClass("e-cellselectionbackground e-activecell");
                                }
                                this.selectedRowCellIndexes.push({ rowIndex: i, cellIndex: newCellColl });
                            }
                        } else {
                            for (var i = previousRowIndex; i >= currentRowIndex; i--) {
                                newCellColl = [];
                                min = i == previousRowIndex ? previousCellIndex : this.model.columns.length;
                                max = i == currentRowIndex ? currentCellIndex : 0;
                                for (var j = min; j >= max; j--) {
                                    newCellColl.push(j);
                                    $(this.getRowByIndex(i).find(".e-rowcell:eq(" + j + ")")).addClass("e-cellselectionbackground e-activecell");
                                }
                                this.selectedRowCellIndexes.push({ rowIndex: i, cellIndex: newCellColl });
                            }
                        }
                        break;
                    }
                case ej.Grid.SelectionType.Single:
                    this.clearCellSelection();
                    this.clearColumnSelection();
                    this.selectedRowCellIndexes = [];
                    if ($.inArray(rowCellIndexes[0][0], this._rowIndexesColl) == -1)
                       this._rowIndexesColl.push(rowCellIndexes[0][0]);
                    this.selectedRowCellIndexes.push({ rowIndex: rowCellIndexes[0][0], cellIndex: rowCellIndexes[0][1] });
                    $(this.getRowByIndex(rowCellIndexes[0][0]).find(".e-rowcell:eq(" + rowCellIndexes[0][1] + ")")).addClass("e-cellselectionbackground e-activecell");
                    break;
            }
            var args = { currentCell: $cell, cellIndex: rowCellIndexes[0][1], data: this._currentJsonData[rowCellIndexes[0][0]], selectedRowCellIndex: this.selectedRowCellIndexes, previousRowCellIndex: this._previousRowCellIndex, previousRowCell: previousRowCell};
            if (!this._multiSelectShiftRequest) this._previousRowCellIndex = rowCellIndexes;
            if (this._trigger("cellSelected", args))
                return;
        },

        /**
         * Select columns in grid.
         * @alias ejGrid#selectColumns
         * @return jQuery
         * @param { number } fromIndex It is used to set the starting index of column for selecting columns.
         * @example 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // Selects columns based on the given index
         * gridObj.selectColumns(1,4); 
         * &lt;/script&gt;
         * @example 
         * &lt;script&gt;
         * // Selects columns based on the given index
         * $("#Grid").ejGrid("selectColumns", 1, 4);
         * &lt;/script&gt;
         */
        selectColumns: function (columnIndex, toIndex) {
            if (!this.model.allowcolumnSelection && !this.model.allowSelection)
                return false;
            var gridRows = this.getRows();
            var prevColumnHeaderCell = this.getHeaderTable().find("th.e-headercell:visible")[this._previousColumnIndex];
            var args = { columnIndex: columnIndex == undefined ? toIndex : columnIndex, headerCell: $(this.getHeaderTable().find("th.e-headercell:visible")[columnIndex]), column: this.model.columns[columnIndex], previousColumnIndex: this._previousColumnIndex, prevColumnHeaderCell: prevColumnHeaderCell };
            if (this.model.selectionType == "multiple") {
                args["isCtrlPressed"] = this.multiSelectCtrlRequest;
                args["isShiftPressed"] = this._multiSelectShiftRequest;
            }
            if (this._trigger("columnSelecting", args))
                return;
            if (ej.isNullOrUndefined(toIndex) || ej.isNullOrUndefined(columnIndex)) {
                columnIndex = ej.isNullOrUndefined(columnIndex) ? toIndex : columnIndex;
                switch (this.model.selectionType) {
                    case ej.Grid.SelectionType.Multiple:
                        if (this.multiSelectCtrlRequest) {
                            var selectedColumnIndex = $.inArray(columnIndex, this.selectedColumnIndexes);
                            selectedColumnIndex != -1 && this.clearColumnSelection(columnIndex) && this.selectedColumnIndexes.splice(selectedColumnIndex, 0);
                            if (selectedColumnIndex == -1) {
                                this.selectedColumnIndexes.push(columnIndex);
                                for (var i = 0; i < gridRows.length; i++) {
                                    $(gridRows[i].cells[columnIndex]).addClass("e-columnselection");
                                }
                                $(this.getHeaderTable().find("th.e-headercell:visible")[columnIndex]).addClass("e-columnselection");
                            }
                            break;
                        }
                    case ej.Grid.SelectionType.Single:
                        this.clearSelection();
                        this.clearCellSelection();
                        this.clearColumnSelection();
                        this.selectedColumnIndexes = [];
                        this.selectedColumnIndexes.push(columnIndex);
                        for (var i = 0; i < gridRows.length; i++) {
                            $(gridRows[i].cells[columnIndex]).addClass("e-columnselection");
                        }
                        $(this.getHeaderTable().find("th.e-headercell:visible")[columnIndex]).addClass("e-columnselection");
                        break;
                }
            } else {
                if (this.model.selectionType == ej.Grid.SelectionType.Multiple) {
                    this.clearColumnSelection();
                    this.selectedColumnIndexes = [];
                    var startIndex = columnIndex > toIndex ? toIndex : columnIndex;
                    var endIndex = columnIndex > toIndex ? columnIndex + 1 : toIndex + 1;
                    for (var i = startIndex; i < endIndex; i++) {
                        for (var j = 0; j < gridRows.length; j++) {
                            $(gridRows[j].cells[i]).addClass("e-columnselection");
                        }
                        $(this.getHeaderTable().find("th.e-headercell:visible")[i]).addClass("e-columnselection");
                        this.selectedColumnIndexes.push(i);
                    }
                }
            }
            var args = { columnIndex: columnIndex == undefined ? toIndex : columnIndex, headerCell: $(this.getHeaderTable().find("th.e-headercell:visible")[columnIndex]), column: this.model.columns[columnIndex], selectedColumnIndex: this.selectedColumnIndexes, previousColumnIndex: this._previousColumnIndex, prevColumnHeaderCell: prevColumnHeaderCell};
            this._previousColumnIndex = this.selectedColumnIndexes.length ? columnIndex : undefined;
            if (this._trigger("columnSelected", args))
                return;
        },
        /**
         * Clear all the row selection or at specific row selection based on the index provided
         * @alias ejGrid#clearSelection
         * @return jQuery
         * @param {number} [index] If index of the row is specified then it will remove the selection from the particular row else it will clears all of the row selection
         * @example 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * gridObj.clearSelection(2);  // Removes the selection based on the row index
         * gridObj.clearSelection();  // clears all of the row selection
         * &lt;/script&gt;
         * @example 
         * &lt;script&gt;
         * // Removes the selection based on the row index
         * $("#Grid").ejGrid("clearSelection", 2);   
         * // clears all of the row selection
         * $("#Grid").ejGrid("clearSelection");        
         * &lt;/script&gt;
         */
        clearSelection: function (index) {
            if (this._selectedRow() >= -1) {
                var $gridRows = $(this.getRows()), index;
                if (!ej.isNullOrUndefined(index)) {
                    this.getRowByIndex(index).removeAttr("aria-selected").find(".e-selectionbackground").removeClass("e-selectionbackground").removeClass("e-active");
                    index = $.inArray(index, this.selectedRowsIndexes);
                    if (index != -1)
                        this.selectedRowsIndexes.splice(index, 1);
                } else {
                    if (this.model.scrollSettings.frozenColumns > 0)
                        $gridRows = $($gridRows[0]).add($gridRows[1]);
                    $gridRows.removeAttr("aria-selected").find(".e-rowcell, .e-detailrowcollapse, .e-detailrowexpand").removeClass("e-selectionbackground").removeClass("e-active");
                }
                if (!this.selectedRowsIndexes.length)
                    this._selectedRow(-1);
            }
            return true;
        },
        /**
         * It is used to clear all the cell selection.
         * @alias ejGrid#clearCellSelection
         * @return jQuery
         * @example 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * gridObj.clearCellSelection();  // clears all of the cell selection
         * &lt;/script&gt;
         * @example 
         * &lt;script&gt;         
         * // clears all of the cell selection
         * $("#Grid").ejGrid("clearCellSelection");        
         * &lt;/script&gt;
         */
        clearCellSelection: function () {
            if (this._allowcellSelection) {
                var $gridRows = $(this.getRows());
                $gridRows.find(".e-rowcell, .e-detailrowcollapse, .e-detailrowexpand").removeClass("e-cellselectionbackground").removeClass("e-activecell");
                this.selectedRowCellIndexes = [];
                this._rowIndexesColl = [];
            }
            return true;
        },

        /**
        * It is used to clear all the row selection or at specific row selection based on the index provided.
        * @alias ejGrid#clearColumnSelection
        * @return jQuery
        * @param {number} [index] If index of the column is specified then it will remove the selection from the particular column else it will clears all of the column selection
        * @example 
        * &lt;script&gt;
        * // Create grid object.
        * var gridObj = $("#Grid").data("ejGrid");
        * gridObj.clearColumnSelection(2);  // Removes the selection based on the column index
        * gridObj.clearColumnSelection();  // clears all of the column selection
        * &lt;/script&gt;
        * @example 
        * &lt;script&gt;
        * // Removes the selection based on the column index
        * $("#Grid").ejGrid("clearColumnSelection", 2);   
        * // clears all of the column selection
        * $("#Grid").ejGrid("clearColumnSelection");        
        * &lt;/script&gt;
        */
        clearColumnSelection: function (index) {
            if (this._allowcolumnSelection) {
                var $gridRows = $(this.getRows());
                if (!ej.isNullOrUndefined(index)) {
                    for (var i = 0; i < $gridRows.length; i++) {
                        $($gridRows[i].cells[index]).removeClass("e-columnselection");
                    }
                    $(this.getHeaderTable().find("th.e-headercell:visible")[index]).removeClass("e-columnselection");
                    this.selectedColumnIndexes.splice(0, index);

                } else {
                    $gridRows.find(".e-rowcell").removeClass("e-columnselection");
                    $(this.getHeaderTable().find("th.e-headercell:visible")).removeClass("e-columnselection");
                    this.selectedColumnIndexes = [];
                }
            }
            return true;
        },
        /**
         * Get the selected records details in grid.
         * @alias ejGrid#getSelectedRecords
         * @return selectedRecords
         * @example 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // Gets the selected row list
         * gridObj.getSelectedRecords();
         * &lt;/script&gt;
         * @example 
         * &lt;script&gt;
         * // Gets the selected row list
         * $("#Grid").ejGrid("getSelectedRecords");        
         * &lt;/script&gt;
         */
        getSelectedRecords: function () {
            var records = [];
            for (var i = 0; i < this.selectedRowsIndexes.length; i++) {
                if (this.selectedRowsIndexes[i] != -1)
                    records.push(this._currentJsonData[this.selectedRowsIndexes[i]]);
            }
            return records;
        },
        _setCurrentRow: function (requestType) {
            if (requestType == ej.Grid.Actions.Refresh || requestType == ej.Grid.Actions.Filtering || requestType == ej.Grid.Actions.Sorting || requestType == ej.Grid.Actions.Delete || requestType == ej.Grid.Actions.Save || requestType == ej.Grid.Actions.Cancel || requestType == ej.Grid.Actions.Paging) {
                this._selectedRow(-1);
                this.selectedRowsIndexes = [];
            }
        },
        _renderMultiTouchDialog: function () {
            this._customPop = ej.buildTag("div.e-gridpopup", "", { display: "none" });
            var $content = ej.buildTag("div.e-content"), $downTail = ej.buildTag("div.e-downtail e-tail");
            if (this.model.allowMultiSorting) {
                var $selElement = ej.buildTag("span.e-sortdirect e-icon");
                $content.append($selElement);
            }
            if (this.model.selectionType == ej.Grid.SelectionType.Multiple) {
                var $selElement = ej.buildTag("span.e-rowselect e-icon");
                $content.append($selElement);
            }
            this._customPop.append($content);
            this._customPop.append($downTail);
            this.element.append(this._customPop);
        },
    };
})(jQuery, Syncfusion);