﻿/**
* @fileOverview Plugin to style the Html List elements
* @copyright Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/


(function ($, ej, undefined) {
    /**
   * @namespace ej
   * @classdesc The Listbox control provides a list options to make user to choose an item from the list. It is capable of including other html elements such as images, textboxes, check box, radio buttons and so on.
   * @class ejListBox
   * @requires jQuery
   * @requires jquery.easing.1.3.js
   * @requires ej.core.js
   * @requires ej.data.js
   * @requires ej.listbox.js
   * @requires ej.checkbox.js
   * @requires ej.scroller.js
   * @example 
  
   * 
   *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
   *
   * &lt;script&gt;
   * // Create ListBox
   * $('#carsList').ejListBox(); 	
   * &lt;/script&gt; 
   *@example
   * // Another way to render ListBox control, using its targetID.
   *	&lt;ul id="listboxsample"&gt;
   *    &lt;/ul&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   
   *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
   * &lt;script&gt;
    * // Create ListBox
    * $('#listboxsample').ejListBox({targetID: "carlist"}); 	
    * &lt;/script&gt; 
    */
    // ejlistBox is the plugin name 
    // "ej.ListBox" is "namespace.className" will hold functions and properties

	
    ej.widget("ejListBox", "ej.ListBox", {
        // widget element will be automatically set in this
        element: null,
        // user defined model will be automatically set in this
        model: null,
		itemRequest:null,
     	 validTags: ["ul"],
        _setFirst: false,
		//Root Css Class
         _rootCSS: "e-listbox",
        // default model
        defaults: {
	
            itemsCount: 0,
			 /**		
            * Specifies the data source of the ListBox. The data source contains the list of data for generating the List items.	
            * @default null
            * @type {data}
            * @example 
			*  &lt;ul id="countrylist"&gt;  &lt;/ul&gt;
			* &lt;script&gt;		
            * //To set dataSource API value during initialization  
            * 	$("#countrylist").ejListBox({ dataSource: window.countries });			 
            * &lt;/script&gt;
            * @memberof ejListBox
            * @instance
            */
            dataSource: null,
			  /**		
            * Specifies the query to retrieve the data from online server.	
            * @default null
            * @type {object}
            * @example 
			*  &lt;ul id="customerlist"&gt;  &lt;/ul&gt;
			* &lt;script&gt;		
            * //To set query API value during initialization  
            * var dataManger = ej.DataManager({       url: "http://mvc.syncfusion.com/Services/Northwnd.svc/"});
            * var queryString = ej.Query().from("Suppliers").select("Customers");
            * 	$("#customerlist").ejListBox({ dataSource: dataManger, query: queryString, fields: { text: "CustomerID" }});
            * &lt;/script&gt;
            * @memberof ejListBox
            * @instance
            */
            query: null,
			itemRequest:null,
			 /**		
            * Specifies mapping fields for the data items of the ListBox.	
            * @default null
            * @type {object}
            * @example 
			*  &lt;ul id="countrylist"&gt;  &lt;/ul&gt;
			* &lt;script&gt;		
            * //To set fields API value during initialization  
            * 	$("#countrylist").ejListBox({ dataSource: window.countriesField,   fields: { text: "name", value: "key" }});
             * &lt;/script&gt;
            * @memberof ejListBox
            * @instance
            */
            fields: { 
				/**		
                 * Defines id for the tag.
				 * @alias ejListBox#fields->id
				 * @type String
                 */
			id: null, 
				/**		
                 * Defines the text content for the tag.
				 * @alias ejListBox#fields->text
				 * @type String
                 */
			text: null,  
			/**		
                 * Defines the imageURL for the image location. 
				 * @alias ejListBox#fields->imageUrl
				 * @type String
                 */
			imageUrl: null,
			 /**		
                 * Defines the image attributes such as height, width, styles and so on.
				 * @alias ejListBox#fields->imageAttributes
				 * @type String
                 */	
			imageAttributes: null, 
			/**		
                 * Defines the sprite css for the image tag.
				 * @alias ejListBox#fields->spriteCssClass
				 * @type String
                 */
			spriteCssClass: null, 
			/**		
                 * Defines the html attributes such as id, class, styles for the item.
				 * @alias ejListBox#fields->htmlAttributes
				 * @type Object
                 */
			htmlAttributes: null, 
				/**		
                 * Defines the tooltip text to be displayed for the data list item.
				 * @alias ejListBox#fields->toolTipText
				 * @type Object
                 */
			toolTipText:null,
				/**		
                 * Defines the tag value to be selected initially
				 * @alias ejListBox#fields->selected
				 * @type String
                 */
			selected: null,
			/**		
                 * Defines the category for data item.
				 * @alias ejListBox#fields->category
				 * @type String
                 */
			category: null,
			/**		
                 * Defines the table name for tag value or display text while render with remote data.
				 * @alias ejListBox#fields->tableName
				 * @type String
                 */
			tableName: null
			},
                  /**		
            * Defines the height of the ListBox.
            * @default Null
            * @type {string | number}
            * @example 
			   *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
   *
   * &lt;script&gt;
     * //Initialize the ListBox height property with the  value specified
   * $('#carsList').ejListBox({ height: "300"}); 	
   * &lt;/script&gt; 
		  
            * @memberof ejListBox
            * @instance
            */      
                 
            height: "272",  
            /**		
            * Defines the width of the ListBox.
            * @default Null
            * @type {string | number}
            * @example 
			   *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
   *
   * &lt;script&gt;
     * //Initialize the ListBox width property with the  value specified
   * $('#carsList').ejListBox({ width: "220"}); 	
   * &lt;/script&gt; 
		  
            * @memberof ejListBox
            * @instance
            */   			
            width: "200",   
 /**		
            * Specifies the template for ListBox.
            * @default null
            * @type {string}
            * @example <br/> 
			* &lt;ul id="carsList" /&gt; &lt;/ul&gt; <br> 
			* &lt;script&gt;		
            * // To set template API value during initialization  . 	
            * $("#carsList").ejListBox({ dataSource: window.carsListempList, template: '&lt;img class="eimg" src="styles/images/Employee/${eimg}.png" alt="employee" height="50px" width="50px"/&gt;' +
            *   '&lt;div class="ename"&gt; ${text} &lt;/div&gt;&lt;div class="desig"&gt; ${desig} &lt;/div&gt;&lt;div class="cont"&gt; ${country} &lt;/div&gt;'});
            * &lt;/script&gt;
            * @memberof ejListBox
            * @instance
            */			
            template: null,  
			text:"",
			            /**		
            * Specifies the selectedItemIndex   for ListBox.
            * @default null
            * @type {number}
            * @example 
		  *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
   *
   * &lt;script&gt;
 * // To set selectedItemIndex   API value during initialization  . 	
   * $('#carsList').ejListBox({selectedItemIndex  : 2}); 	
   * &lt;/script&gt; 
            * @memberof ejListBox
            * @instance
            */
            selectedItemIndex:null,
			
            selectedItems: [],
		
            checkedItems:[],
				            /**		
            * Specifies the checkedItemlist for ListBox.
	
            * @default []
            * @type {integerarray}
            * @example 
		 *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
   *
   * &lt;script&gt;
 * // To sets the checked item  API value during initialization  . 	
   * $('#carsList').ejListBox({ showCheckbox:true,checkedItemlist  : [1,2] }); 	
   * &lt;/script&gt; 
            * @memberof ejListBox
            * @instance
            */
            checkedItemlist: [],
					            /**		
            * Specifies the selectedItems  for ListBox.
	
            * @default []
            * @type {integerarray}
            * @example 
		 *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
   *
   * &lt;script&gt;
 * // To set selectedItemlist   API value during initialization  . 	
   * $('#carsList').ejListBox({ allowMultiSelection:true,selectedItemlist  : [1,2] }); 	
   * &lt;/script&gt; 
            * @memberof ejListBox
            * @instance
            */
            selectedItemlist: [],
			 /**		
            * cascadeTo is used in cascading ListBox scenario, to map the child ListBox list widget in the parent ListBox list widget. By selecting an option in the parent ListBox, the child ListBox has to load the corresponding value regarding the parent ListBox. 
            * @default null
            * @type {string}
            * @example 
			* &lt;div style="float: left;"&gt;
			*       &lt;span class="txt"&gt;Select Group&lt;/span&gt;
			*   &lt;ul id="groupsList" /&gt; &lt;/ul&gt;
			* &lt;/div&gt;
			*
			* &lt;div style="float: right;"&gt;
			*        &lt;span class="txt"&gt;Select Country&lt;/span&gt;
			*        &lt;ul id="countryList" /&gt; &lt;/ul&gt;
			* &lt;/div&gt;
			* &lt;script&gt;
			*  var groups = [
			*          { parentId: 'a', text: "Group A" },
			*          { parentId: 'b', text: "Group B" },
			*          { parentId: 'c', text: "Group C" },
			*          { parentId: 'd', text: "Group D" },
			*          { parentId: 'e', text: "Group E" }]
			*            //first level child
			*            var countries = [{ value: 11, parentId: 'a', text: "Algeria", sprite: "flag-dz" },
			*           { value: 12, parentId: 'a', text: "Armenia", sprite: "flag-am" },
			*           { value: 13, parentId: 'a', text: "Bangladesh", sprite: "flag-bd" },
			*           { value: 14, parentId: 'a', text: "Cuba", sprite: "flag-cu" },
			*           { value: 15, parentId: 'b', text: "Denmark", sprite: "flag-dk" },
			*           { value: 16, parentId: 'b', text: "Egypt", sprite: "flag-eg" },
			*           { value: 17, parentId: 'c', text: "Finland", sprite: "flag-fi" },
			*           { value: 18, parentId: 'c', text: "India", sprite: "flag-in" },
			*           { value: 19, parentId: 'c', text: "Malaysia", sprite: "flag-my" },
			*           { value: 20, parentId: 'd', text: "New Zealand", sprite: "flag-nz" },
			*           { value: 21, parentId: 'd', text: "Norway", sprite: "flag-no" },
			*           { value: 22, parentId: 'd', text: "Poland", sprite: "flag-pl" },
			*           { value: 23, parentId: 'e', text: "Romania", sprite: "flag-ro" },
			*           { value: 24, parentId: 'e', text: "Singapore", sprite: "flag-sg" },
			*           { value: 25, parentId: 'e', text: "Thailand", sprite: "flag-th" },
			*           { value: 26, parentId: 'e', text: "Ukraine", sprite: "flag-ua" }]
			* // To set cascadeTo API value during initialization  . 
			*            $('#groupsList').ejListBox({
			*                dataSource: groups,
			*                fields: { value: "parentId" },
			*                cascadeTo: 'countryList'
			*            });
			*            $('#countryList').ejListBox({
			*                dataSource: countries,
			*                enabled:false
			*            });
            * &lt;/script&gt;
            * @memberof ejListBox
            * @instance
            */
            cascadeTo: null,
			
			value: "",
			  /**		
            * Sets the root class for ListBox theme. This cssClass API helps to use custom skinning option for ListBox control. By defining the root class using this API, we need to include this root class in CSS.
            * @default "gradient-lime"
            * @type {string}
            * @example 
			* 
			*  &lt;div id="carsList"&gt;
			*    &lt;ul&gt;
			*       &lt;li&gt;Audi A4&lt;/li&gt;
			*       &lt;li&gt;Audi A5&lt;/li&gt;
			*       &lt;li&gt;Audi A6&lt;/li&gt;
			*       &lt;li&gt;Audi A7&lt;/li&gt;
			*       &lt;li&gt;Audi A8&lt;/li&gt;
			*    &lt;/ul&gt;
			*  &lt;/div&gt;<br/>
			* &lt;script&gt;
            * //Initialize the ListBox with the cssClass value specified
            * 	$("#carsList").ejListBox({ targetID: "carsList",cssClass: 'gradient-lime'});
            * &lt;/script&gt;
            * @memberof ejListBox
            * @instance
            */
			cssClass:"",
			     /**		
            * ListBox textbox to be displayed with rounded corner style.
            * @default true
            * @type {boolean}
            * @example 
			   *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
   *
   * &lt;script&gt;
* // Initialize the ListBox with the showRoundedCorner value specified.
   * $('#carsList').ejListBox({ showRoundedCorner: true }); 	
   * &lt;/script&gt; 
            * @memberof ejListBox
            * @instance
            */
            showRoundedCorner: false,
			     /**		
            * Sets the ListBox textbox direction as right to left alignment.
            * @default false
            * @type {boolean}
            * @example 
			  *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
   *
   * &lt;script&gt;
 * // Initialize the ListBox with the enableRTL  value specified.
   * $('#carsList').ejListBox({enableRTL : true  }); 	
   * &lt;/script&gt; 
            * @memberof ejListBox
            * @instance
            */
            enableRTL: false,
				     /**		
            * Sets to enable tooltip text for ListBox.
            * @default false
            * @type {boolean}
            * @example 
			  *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
   *
   * &lt;script&gt;
 * // Initialize the ListBox with the enableRTL  value specified.
   * $('#carsList').ejListBox({enableTooltip : true  }); 	
   * &lt;/script&gt; 
            * @memberof ejListBox
            * @instance
            */
			enableTooltip: false,
			      /**		
            * When this property sets to false, it disables the ListBox control.
            * @default true
            * @type {boolean}
            * @example 
		 * 
   *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
   *
   * &lt;script&gt;
 * // Initialize the ListBox with the enabled  value specified.
   * $('#carsList').ejListBox({enabled : false  }); 	
   * &lt;/script&gt; 
            * @memberof ejListBox
            * @instance
            */
            enabled: true,
			    /**		
            * Specifies the multi selection option in ListBox with the help of checkbox control. For this we have to set showCheckbox option true.
            * @default false
            * @type {boolean}
            * @example 
			   *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
   *
   * &lt;script&gt;
 * // Initialize the ListBox with the showCheckbox value specified.
   * $('#carsList').ejListBox({showCheckbox: true }); 	
   * &lt;/script&gt; 
            * @memberof ejListBox
            * @instance
            */
            showCheckbox: false,
					    /**		
            * Specifies the grouping option in ListBox. 
            * @default false
            * @type {boolean}
            * @example 
			   *    &lt;ul id="select1"&gt;    &lt;/ul&gt;
		*
		* &lt;script&gt;
		*  	    var skillset = [
		*           { skill: "Bahrain", category: "B" }, { skill: "Brazil", category: "B" }, { skill: "Argentina", category: "A" },
        *        { skill: "Bangladesh", category: "B" }, { skill: "Burma", category: "B" }, { skill: "Afghanistan", category: "A" }, { skill: "Antigua and Barbuda", category: "A" },
        *        { skill: "Barbados", category: "B" }, { skill: "Botswana", category: "B" }, { skill: "Albania", category: "A" }, { skill: "Andorra", category: "A" },
        *        { skill: "Belarus", category: "B" }, { skill: "Bolivia", category: "B" }, { skill: "Algeria", category: "A" }, { skill: "Angola", category: "A" }
        *        ];
	
		* // Initialize the ListBox with the allowGrouping value specified.
		*  	  $("#select1").ejListBox({
        *        dataSource: skillset,
        *          fields: { text: "skill", category: "category" },allowGrouping:true
             });
		* &lt;/script&gt; 
            * @memberof ejListBox
            * @instance
            */
            allowGrouping:false,
			     /**		
            * Specifies to select all the items of ListBox can be done with the help of this checkAll property, it supports only when the showCheckbox property true.
			* @remarks
			* If We would use the checkAll option,we will follow this:
            *  1.To enable the checkbox option as true{showCheckbox:true}See {@link ejListBox#showCheckbox}
            * @default false
            * @type {boolean}
            * @example 
			  *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
   *
   * &lt;script&gt;
// Initialize the ListBox with the checkAll value specified.
   * $('#carsList').ejListBox({showCheckbox: true, checkAll: true  }); 	
   * &lt;/script&gt; 
            * @memberof ejListBox
            * @instance
            */
            checkAll: false,
			  /**		
            * Specifies to uncheck all the items of ListBox can be done with the help of this unCheckAll property, it supports only when the showCheckbox property true.
			* @remarks
			* If We would use the uncheckAll option,we will follow this:
            *  1.To enable the checkbox option as true{showCheckbox:true}See {@link ejListBox#showCheckbox}
            * @default false
            * @type {boolean}
            * @example 
			*    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
   *
   * &lt;script&gt;
   * // Initialize the ListBox with the uncheckAll value specified.
   * $('#carsList').ejListBox({showCheckbox: true,  uncheckAll: true  }); 	
   * &lt;/script&gt; 

            * @memberof ejListBox
            * @instance
            */
            unCheckAll: false,
				 /**		
            * Specifies to enable Load data items onDemand for the ListBox.	
             * @default false
            * @type {boolean}
            * @example 
			*  &lt;ul id="countrylist"&gt;  &lt;/ul&gt;
			* &lt;script&gt;		
            * //To set fields API value during initialization  
            * 	$("#countrylist").ejListBox({ dataSource: window.countriesField, enableLoadOnDemand:true,  fields: { text: "name", value: "key" }});
             * &lt;/script&gt;
            * @memberof ejListBox
            * @instance
            */
		
				
            enableLoadOnDemand:false,
				 /**		
            * Specifies to enable virtual scrolling behavior along with Load data items onDemand for the ListBox.	
             * @default false
            * @type {boolean}
            * @example 
			*  &lt;ul id="countrylist"&gt;  &lt;/ul&gt;
			* &lt;script&gt;		
            * //To set fields API value during initialization  
            * 	$("#countrylist").ejListBox({ dataSource: window.countriesField, enableLoadOnDemand:true,enableVirtualScrolling:true,  fields: { text: "name", value: "key" }});
             * &lt;/script&gt;
            * @memberof ejListBox
            * @instance
            */
			enableVirtualScrolling:false,
			/**		
            * Save current model value to browser cookies for state maintains. While refresh the ListBox control page retains the model value apply from browser cookies.  
            * @default false
            * @type {boolean}
            * @example 
			  *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
   *
   * &lt;script&gt;
* // Initialize the ListBox with the enablePersistence  value specified.
   * $('#carsList').ejListBox({enablePersistence : false}); 	
   * &lt;/script&gt;
            * @memberof ejListBox
            * @instance
            */
            enablePersistence: false,
 /**		
            * To allow multiple selection of list items
			* @remarks
			* If We would use the uncheckAll option,we will follow this:
            *  1.To enable the checkbox option as true{showCheckbox:true}See {@link ejListBox#showCheckbox}
            * @default true
            * @type {boolean}
            * @example 
		  *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
   *
   * &lt;script&gt;
 * // Initialize the allowMultiSelection with the value specified.
   * $('#carsList').ejListBox({allowMultiSelection: true}); 	
   * &lt;/script&gt; 
            * @memberof ejListBox
            * @instance
            */			
            allowMultiSelection: false,
			/**		
            * To enable the drag and drop nodes. 
			* @remarks
	
            * @default true
            * @type {boolean}
            * @example 
		   *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
   *
   * &lt;script&gt;
 * // Initialize the with the allowDragAndDrop value specified.
   * $('#carsList').ejListBox({allowDragAndDrop: true}); 	
   * &lt;/script&gt; 
            * @memberof ejListBox
            * @instance
            */
				
            allowDragAndDrop: false,
			   /**     
           * Fires when create successfully.
           * @event
           * @name ejListBox#create 	
           * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
           * @param {object}  argument.model returns the ListBox model
           * @param {string}  argument.type returns the name of the event
           * @example 
		    *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
   *
   * &lt;script&gt;
 * //create event for ListBox
   * $('#carsList').ejListBox({	create: function(args) {}}); 	
   * &lt;/script&gt; 	   
           * @memberof ejListBox
           * @instance
           */
            create: null,  
			   /**     
           * Fires when selected list item Index Changed successfully.
           * @event
           * @name ejListBox#selectIndexChanged 	
           * @param {object}  argument.model returns the ListBox model
           * @param {string}  argument.type returns the name of the event
           * @example 
		    *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
   *
   * &lt;script&gt;
 * //selectIndexChanged event for ListBox
   * $('#carsList').ejListBox({	selectIndexChanged: function(args) {}}); 	
   * &lt;/script&gt; 	   
           * @memberof ejListBox
           * @instance
           */
            selectIndexChanged: null,
			   /**     
           * Fires when list item gets selected successfully.
           * @event
           * @name ejListBox#selected 	
		   * @param {object}  argument.model returns the ListBox model
           * @param {string}  argument.type returns the name of the event

           * @example 
		    *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
   *
   * &lt;script&gt;
 * //selected event for ListBox
   * $('#carsList').ejListBox({	selected: function(args) {}}); 	
   * &lt;/script&gt; 	   
           * @memberof ejListBox
           * @instance
           */
            selected: null,
			   /**     
           * Fires when  list item started to drag successfully.
           * @event
           * @name ejListBox#itemDragStart 	
		   * @param {object}  argument.model returns the ListBox model
           * @param {string}  argument.type returns the name of the event

           * @example 
		    *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
   *
   * &lt;script&gt;
 * //itemDragStart event for ListBox
   * $('#carsList').ejListBox({	itemDragStart: function(args) {}}); 	
   * &lt;/script&gt; 	   
           * @memberof ejListBox
           * @instance
           */
            itemDragStart: null,
			 /**     
           * Fires when  list item is being dragged successfully.
           * @event
           * @name ejListBox#itemDrag 	
		   * @param {object}  argument.model returns the ListBox model
           * @param {string}  argument.type returns the name of the event

           * @example 
		    *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
   *
   * &lt;script&gt;
 * //itemDrag event for ListBox
   * $('#carsList').ejListBox({	itemDrag: function(args) {}}); 	
   * &lt;/script&gt; 	   
           * @memberof ejListBox
           * @instance
           */
            itemDrag: null,
			 /**     
           * Fires when  list item stopped dragging successfully.
           * @event
           * @name ejListBox#itemDragStop 	
		   * @param {object}  argument.model returns the ListBox model
           * @param {string}  argument.type returns the name of the event

           * @example 
		    *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
   *
   * &lt;script&gt;
 * //itemDragStop event for ListBox
   * $('#carsList').ejListBox({	itemDragStop: function(args) {}}); 	
   * &lt;/script&gt; 	   
           * @memberof ejListBox
           * @instance
           */
            itemDragStop: null,
			 /**     
           * Fires when  list item stopped dropping successfully.
           * @event
           * @name ejListBox#itemDropped 
		   * @param {object}  argument.model returns the ListBox model
           * @param {string}  argument.type returns the name of the event		   

           * @example 
		    *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
   *
   * &lt;script&gt;
 * //itemDropped event for ListBox
   * $('#carsList').ejListBox({	itemDropped: function(args) {}}); 	
   * &lt;/script&gt; 	   
           * @memberof ejListBox
           * @instance
           */
            itemDropped:null,
			/**     
           * Fires when check state of an list item changed successfully.
           * @event
           * @name ejListBox#checkChange 
		   * @param {object}  argument.model returns the ListBox model
           * @param {string}  argument.type returns the name of the event		   

           * @example 
		    *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
   *
   * &lt;script&gt;
 * //checkChange event for ListBox
   * $('#carsList').ejListBox({	showCheckbox:true,checkChange: function(args) {}}); 	
   * &lt;/script&gt; 	   
           * @memberof ejListBox
           * @instance
           */
            checkChange: null,
			/**     
          * Fires when destroy successfully.
          * @event
          * @name ejListBox#destroy 	

          * @example 
		   *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
   *
   * &lt;script&gt;
 * //create event for ListBox
   * $('#carsList').ejListBox({	destroy: function(args) {}}); 	
   * &lt;/script&gt; 	  
          * @memberof ejListBox
          * @instance
          */
            destroy: null
        },
        /**
         * Specify the data types for default properties 
		 * @private
         */
        dataTypes: {
            cssClass: "string",
            itemsCount: "number",
            allowDragAndDrop: "boolean",
            height: "string",
            width: "string",
            template: "string",
            selectedItemIndex: "number",
            cascadeTo: "string",
            showRoundedCorner: "boolean",
            enableRTL: "boolean",
			enableTooltip:"boolean",
            enablePersistence: "boolean",
            enabled: "boolean",
            allowMultiSelection: "boolean",
            dataSource: "data",
            selectedItems: "data",
            checkedItems: "data",
            checkedItemlist: "data",
            selectedItemlist: "data"
        },

        observables: ["value"],
        value: ej.util.valueFunction("value"),
       
        //public methods
		
		  /**
      * To enable the ListBox  
      * @return jQuery
      * @example 
         *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
			* &lt;script&gt;
      * // Create ListBox
	   * $('#carsList').ejListBox(); 	
      * var ListBoxObj  = $("#carsList").data("ejListBox");
      * ListBoxObj.enable(); // enable the ListBox
      * &lt;/script&gt;
      * @example 
           *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
			* &lt;script&gt;
      * // Create ListBox
	  * $('#carsList').ejListBox();
      * $('#carsList').ejListBox("enable"); 	
      * &lt;/script&gt;
      *@memberof ejListBox
      * @instance
      */
        enable: function () {
            if (this.listContainer.hasClass("e-disable")) {
                this.target.disabled = false;
                this.model.enabled = true;
                this.listContainer.removeClass('e-disable');
                if (this.model.allowMultiSelection) this.listContainer.removeClass("e-disable");
				 this.scrollerObj.enable();
            }
        },
          /**
      * To disable the ListBox  
      * @return jQuery
      * @example 
         *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
			* &lt;script&gt;
      * // Create ListBox
	   * $('#carsList').ejListBox(); 	
      * var ListBoxObj  = $("#carsList").data("ejListBox");
      * ListBoxObj.disable(); // disable the ListBox
      * &lt;/script&gt;
      * @example 
           *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
			* &lt;script&gt;
      * // Create ListBox
	  * $('#carsList').ejListBox();
      * $('#carsList').ejListBox("disable"); 	
      * &lt;/script&gt;
      *@memberof ejListBox
      * @instance
      */
        disable: function () {
            if (!this.listContainer.hasClass("e-disable")) {
                this.target.disabled = true;
                this.model.enabled = false;
                this.listContainer.addClass('e-disable');
                if (this.model.allowMultiSelection) this.listContainer.addClass("e-disable");
				this.scrollerObj.disable();
            }
        },
   
        /**
     * To select an Item using its index in the ListBox  
     * @return jQuery
     * @example 
           *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
			* &lt;script&gt;
     * // Create ListBox
	   * $('#carsList').ejListBox(); 	
     * var ListBoxObj  = $("#carsList").data("ejListBox");
     * ListBoxObj.selectItemByIndex(2); //selects the item in the ListBox
     * &lt;/script&gt;
     * @example 
       *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
			* &lt;script&gt;
     * // Create ListBox
   * $('#carsList').ejListBox(); 	
     * $('#carsList').ejListBox("selectItemByIndex" ,"2"); 	
     * &lt;/script&gt;
     *@memberof ejListBox
     * @instance
     */
        selectItemByIndex: function (index) {
		index=parseInt(index);
            if (!this.model.enabled) return false;
            if (index != null) {
                this._activeItem = index;
                if (this._activeItem <= 0) {
                    this._activeItem = 0;
                }
                else if (this._activeItem == this._listSize - 1) {
                    this._activeItem = this._listSize - 1;
                }
                    var activeitem = $(this.element.children("li")[this._activeItem]);
                    if (this._activeItem != this._aselectedItem) {
                        this.element.children("li").removeClass('e-hover');
                        activeitem.addClass('e-select');
                } 
            }
        },
		   /**
     * To select all the list items in the ListBox  
     * @return jQuery
     * @example 
           *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
			* &lt;script&gt;
     * // Create ListBox
	   * $('#carsList').ejListBox(); 	
     * var ListBoxObj  = $("#carsList").data("ejListBox");
     * ListBoxObj.selectAll(); // selects all the list items in the ListBox
     * &lt;/script&gt;
     * @example 
       *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
			* &lt;script&gt;
     * // Create ListBox
   * $('#carsList').ejListBox(); 	
     * $('#carsList').ejListBox("selectAll"); 	
     * &lt;/script&gt;
     *@memberof ejListBox
     * @instance
     */
		selectAll: function(){
		this.element.children("li").addClass("e-hover");
		this.element.children("li").addClass("e-select");
		},
			   /**
     * To unselect all the list items in the ListBox  
     * @return jQuery
     * @example 
           *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
			* &lt;script&gt;
     * // Create ListBox
	   * $('#carsList').ejListBox(); 	
     * var ListBoxObj  = $("#carsList").data("ejListBox");
     * ListBoxObj.unSelectAll(); // unselect all the items in the ListBox
     * &lt;/script&gt;
     * @example 
       *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
			* &lt;script&gt;
     * // Create ListBox
   * $('#carsList').ejListBox(); 	
     * $('#carsList').ejListBox("unSelectAll"); 	
     * &lt;/script&gt;
     *@memberof ejListBox
     * @instance
     */
		unSelectAll: function(){
		this._removeListHover();
		},
			   /**
     * To select a list items through index in the ListBox  
     * @return jQuery
     * @example 
           *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
			* &lt;script&gt;
     * // Create ListBox
	   * $('#carsList').ejListBox(); 	
     * var ListBoxObj  = $("#carsList").data("ejListBox");
     * ListBoxObj.selectItemsByIndex(2,3); // selects the specified items the ListBox
     * &lt;/script&gt;
     * @example 
       *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
			* &lt;script&gt;
     * // Create ListBox
   * $('#carsList').ejListBox(); 	
     * $('#carsList').ejListBox("selectItemsByIndex","2,3"); 	
     * &lt;/script&gt;
     *@memberof ejListBox
     * @instance
     */
	    selectItemsByIndex: function (value) {
            if (!this.model.enabled) return false;
			var selectitems = value.split(',');
			for(var i=0;i<selectitems.length; i++){
            if (selectitems[i] != null) {
				 var index=parseInt(selectitems[i]);
                this._activeItem = index;
                if (this._activeItem < 0) {
                    this._activeItem = 0;
                }
                else if (this._activeItem == this._listSize - 1) {
                    this._activeItem = this._listSize - 1;
                }
                    var activeitem = $(this.element.children("li")[this._activeItem]);
                    if (this._activeItem != this._aselectedItem) {
                        this.element.children("li").removeClass('e-hover');
                        activeitem.addClass('e-select');
                } 
            }
			}
        },
			   /**
     * To unselect set of list items in the ListBox  
     * @return jQuery
     * @example 
           *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
			* &lt;script&gt;
     * // Create ListBox
	   * $('#carsList').ejListBox(); 	
     * var ListBoxObj  = $("#carsList").data("ejListBox");
     * ListBoxObj.unselectItemsByIndex(2,3); // unselectItems specified the ListBox
     * &lt;/script&gt;
     * @example 
       *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
			* &lt;script&gt;
     * // Create ListBox
   * $('#carsList').ejListBox(); 	
     * $('#carsList').ejListBox("unselectItemsByIndex","2,3"); 	
     * &lt;/script&gt;
     *@memberof ejListBox
     * @instance
     */
		unselectItemsByIndex: function (value) {
            if (!this.model.enabled) return false;
			var selectitems = value.split(',');
			for(var i=0;i<selectitems.length; i++){
            if (selectitems[i] != null) {
			 var index=parseInt(selectitems[i]);
				var activeitem = $(this.element.children("li")[index]);
                this._activeItem = index;
				activeitem.removeClass('e-active');
				activeitem.removeClass('e-select');
            }
			}
        },
			   /**
     * To unselect a list item in the ListBox  
     * @return jQuery
     * @example 
           *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
			* &lt;script&gt;
     * // Create ListBox
	   * $('#carsList').ejListBox(); 	
     * var ListBoxObj  = $("#carsList").data("ejListBox");
     * ListBoxObj.unselectItemByIndex(2); // unselects the list item specified in the index  in the ListBox
     * &lt;/script&gt;
     * @example 
       *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
			* &lt;script&gt;
     * // Create ListBox
   * $('#carsList').ejListBox(); 	
     * $('#carsList').ejListBox("unselectItemByIndex","2"); 	
     * &lt;/script&gt;
     *@memberof ejListBox
     * @instance
     */
        unselectItemByIndex: function (index) {
		index=parseInt(index);
            if (!this.model.enabled) return false;
			var unselectitem = $(this.element.children("li")[index]);
            if(unselectitem.hasClass('e-select')){
				unselectitem.removeClass('e-active');
				unselectitem.removeClass('e-select');
            }
        },
		   /**
     * To get the selected list item in the ListBox  
     * @return jQuery
     * @example 
           *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
			* &lt;script&gt;
     * // Create ListBox
	   * $('#carsList').ejListBox(); 	
     * var ListBoxObj  = $("#carsList").data("ejListBox");
     * ListBoxObj.getSelectedItem(); // gets the selected item from the ListBox
     * &lt;/script&gt;
     * @example 
       *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
			* &lt;script&gt;
     * // Create ListBox
   * $('#carsList').ejListBox(); 	
     * $('#carsList').ejListBox("getSelectedItem"); 	
     * &lt;/script&gt;
     *@memberof ejListBox
     * @instance
     */
        getSelectedItem: function () {
            return this.model._aselectedItem;
        },
			   /**
     * To get the list of selected list items in the ListBox  
     * @return jQuery
     * @example 
           *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
			* &lt;script&gt;
     * // Create ListBox
	   * $('#carsList').ejListBox(); 	
     * var ListBoxObj  = $("#carsList").data("ejListBox");
     * ListBoxObj.getSelectedItems(); // gets the list of selected list items from the ListBox
     * &lt;/script&gt;
     * @example 
       *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
			* &lt;script&gt;
     * // Create ListBox
   * $('#carsList').ejListBox(); 	
     * $('#carsList').ejListBox("getSelectedItems"); 	
     * &lt;/script&gt;
     *@memberof ejListBox
     * @instance
     */
        getSelectedItems: function () {
            return this.model.selectedItems;
        },
			   /**
     * To get the list of checked list items in the ListBox  
     * @return jQuery
     * @example 
           *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
			* &lt;script&gt;
     * // Create ListBox
	   * $('#carsList').ejListBox(); 	
     * var ListBoxObj  = $("#carsList").data("ejListBox");
     * ListBoxObj.getCheckedItems(); // get the list of checked items the ListBox
     * &lt;/script&gt;
     * @example 
       *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
			* &lt;script&gt;
     * // Create ListBox
   * $('#carsList').ejListBox(); 	
     * $('#carsList').ejListBox("getCheckedItems"); 	
     * &lt;/script&gt;
     *@memberof ejListBox
     * @instance
     */
        getCheckedItems: function () {
            return this.model.checkedItems;
        },
				   /**
     * To remove an list item in the ListBox  
     * @return jQuery
     * @example 
           *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
			* &lt;script&gt;
     * // Create ListBox
	   * $('#carsList').ejListBox(); 	
     * var ListBoxObj  = $("#carsList").data("ejListBox");
     * ListBoxObj.removeItem(); // removes the selected item from the ListBox
     * &lt;/script&gt;
     * @example 
       *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
			* &lt;script&gt;
     * // Create ListBox
   * $('#carsList').ejListBox(); 	
     * $('#carsList').ejListBox("removeItem"); 	
     * &lt;/script&gt;
     *@memberof ejListBox
     * @instance
     */
		 removeItem: function () {
		 if(this.model.enabled){
			this._getItem(this._selectedItemindex()).remove();
            this._refreshItems();
			}
        },
				   /**
     * To disable an list item in the ListBox  
     * @return jQuery
     * @example 
           *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
			* &lt;script&gt;
     * // Create ListBox
	   * $('#carsList').ejListBox(); 	
     * var ListBoxObj  = $("#carsList").data("ejListBox");
     * ListBoxObj.disableItem(); // disable selected item in the ListBox
     * &lt;/script&gt;
     * @example 
       *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
			* &lt;script&gt;
     * // Create ListBox
   * $('#carsList').ejListBox(); 	
     * $('#carsList').ejListBox("disableItem"); 	
     * &lt;/script&gt;
     *@memberof ejListBox
     * @instance
     */
        disableItem: function () {
            this._getItem(this._selectedItemindex()).addClass("e-disable");
        },
		   /**
     * To move the selected list item one step Up in the ListBox  
     * @return jQuery
     * @example 
           *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
			* &lt;script&gt;
     * // Create ListBox
	   * $('#carsList').ejListBox(); 	
     * var ListBoxObj  = $("#carsList").data("ejListBox");
     * ListBoxObj.moveUp(); // moves up selected item in the ListBox
     * &lt;/script&gt;
     * @example 
       *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
			* &lt;script&gt;
     * // Create ListBox
   * $('#carsList').ejListBox(); 	
     * $('#carsList').ejListBox("moveUp"); 	
     * &lt;/script&gt;
     *@memberof ejListBox
     * @instance
     */
        moveUp: function () {
            var PreviousItem = this._getItem(this._selectedItemindex()).prev();
            var selectedItem = this._getItem(this._selectedItemindex());
            var previndex = this._selectedItemindex()-1;
            var selectedindex = this._selectedItemindex();
			this._addListHover();
            PreviousItem.insertAfter(selectedItem);
			//this._refreshContainer();
			this._trigger('indexchange', {  data: this.model });
        },
		/**
     * To move the selected list item one step Down in the ListBox  
     * @return jQuery
     * @example 
           *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
			* &lt;script&gt;
     * // Create ListBox
	   * $('#carsList').ejListBox(); 	
     * var ListBoxObj  = $("#carsList").data("ejListBox");
     * ListBoxObj.moveDown(); //moves down the selected item in the ListBox
     * &lt;/script&gt;
     * @example 
       *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
			* &lt;script&gt;
     * // Create ListBox
   * $('#carsList').ejListBox(); 	
     * $('#carsList').ejListBox("moveDown"); 	
     * &lt;/script&gt;
     *@memberof ejListBox
     * @instance
     */
        moveDown: function () {
            var nextItem = this._getItem(this._selectedItemindex()).next();
            var selectedItem = this._getItem(this._selectedItemindex());
            var nextindex = this._selectedItemindex() + 1;
            var selectedindex = this._selectedItemindex();
			this._addListHover();
            nextItem.insertBefore(selectedItem);
           // this._refreshContainer();
			this._trigger('indexchange', {  data: this.model });
        },
		/**
     * To check all the list items in the ListBox  
     * @return jQuery
     * @example 
           *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
			* &lt;script&gt;
     * // Create ListBox
	   * $('#carsList').ejListBox({showCheckbox:true}); 	
     * var ListBoxObj  = $("#carsList").data("ejListBox");
     * ListBoxObj.checkAll(); // checks all the list items in the ListBox
     * &lt;/script&gt;
     * @example 
       *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
			* &lt;script&gt;
     * // Create ListBox
   * $('#carsList').ejListBox({showCheckbox:true}); 	
     * $('#carsList').ejListBox("checkAll"); 	
     * &lt;/script&gt;
     *@memberof ejListBox
     * @instance
     */
		checkAll: function () {
            if (!this.model.enabled) return false;
            for (i = 0; i < this.listitems.length; i++) {
			 if (!($(this.listitems[i].firstChild).find('.listcheckbox').ejCheckBox('isChecked'))) {
                    $(this.listitems[i].firstChild).find('.listcheckbox').ejCheckBox('option', 'checked', true);
                    this.model.checkedItems.push(this.listitems[i]);
				   }
                }
        },
		/**
     * To check items in the checkitemslist in the ListBox  
     * @return jQuery
     * @example 
           *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
			* &lt;script&gt;
     * // Create ListBox
	   * $('#carsList').ejListBox({showCheckbox:true}); 	
     * var ListBoxObj  = $("#carsList").data("ejListBox");
     * ListBoxObj.checkitems(); // checks all the list items in the checkedItemlist
     * &lt;/script&gt;
     * @example 
       *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
			* &lt;script&gt;
     * // Create ListBox
   * $('#carsList').ejListBox({showCheckbox:true}); 	
     * $('#carsList').ejListBox("checkitems"); 	
     * &lt;/script&gt;
     *@memberof ejListBox
     * @instance
     */
		checkitems: function () {
		    if (!this.model.enabled) return false;
		    if (this.model.showCheckbox) {
		         for (i = 0; i < this.model.checkedItemlist.length; i++) {
			var item =this.model.checkedItemlist[i];
			 if (!($(this.listitems[item].firstChild).find('.listcheckbox').ejCheckBox('isChecked'))) {
                    $(this.listitems[item].firstChild).find('.listcheckbox').ejCheckBox('option', 'checked', true);
                    this.model.checkedItems.push(this.listitems[item]);
				   }
                }
		    }
		    else {
		        if(this.model.allowMultiSelection){
		        for (i = 0; i < this.model.selectedItemlist.length; i++) {
		            var item = this.model.selectedItemlist[i];
		            if (!($(this.listitem[item]).hasClass("e-select"))) {
		                $(this.listitem[item]).addClass("e-select")
		                this.model.selectedItems.push($(this.listitem[item]));
		            }
		            else {
		                $(this.listitem[item]).removeClass("e-select")
		                this.model.selectedItems.pop($(this.listitem[item]));
		            }
		        }
		    }
		        else {
		            this.unSelectAll();
		            if (!($(this.listitem[this.model.selectedItemIndex]).hasClass("e-select")))
		            $(this.listitem[this.model.selectedItemIndex]).addClass("e-select");
		            this.model.selectedItems.push($(this.listitem[this.model.selectedItemIndex]));
		         }
		    }
		    //this._refreshContainer();
        },
	/**
     * To uncheck all the list items in the ListBox  
     * @return jQuery
     * @example 
           *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
			* &lt;script&gt;
     * // Create ListBox
	   * $('#carsList').ejListBox({showCheckbox:true}); 	
     * var ListBoxObj  = $("#carsList").data("ejListBox");
     * ListBoxObj.unCheckAll(); // Unchecks all the list items in the ListBox
     * &lt;/script&gt;
     * @example 
       *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
			* &lt;script&gt;
     * // Create ListBox
   * $('#carsList').ejListBox({showCheckbox:true}); 	
     * $('#carsList').ejListBox("unCheckAll"); 	
     * &lt;/script&gt;
     *@memberof ejListBox
     * @instance
     */
        unCheckAll: function () {
            if (!this.model.enabled) return false;
            for (i = 0; i < this.listitems.length; i++) {
                if ($(this.listitems[i].firstChild).find('.listcheckbox').ejCheckBox('isChecked')) {
                    $(this.listitems[i].firstChild).find('.listcheckbox').ejCheckBox('option', 'checked', false);
                }
                this.model.checkedItems.pop(this.listitems[i]);
            }
        },
		   /**
     * To add an list item in the ListBox  
     * @return jQuery
     * @example 
           *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
			* &lt;script&gt;
     * // Create ListBox
	   * $('#carsList').ejListBox(); 	
     * var ListBoxObj  = $("#carsList").data("ejListBox");
     * ListBoxObj.addItem("Java"); // add an new item in the ListBox
     * &lt;/script&gt;
     * @example 
       *    &lt;ul id="carsList"&gt;
   *       &lt;li&gt;Audi A4&lt;/li&gt;
   *       &lt;li&gt;Audi A5&lt;/li&gt;
   *       &lt;li&gt;Audi A6&lt;/li&gt;
   *       &lt;li&gt;Audi A7&lt;/li&gt;
   *       &lt;li&gt;Audi A8&lt;/li&gt;
   *	   &lt;li&gt;BMW 501&lt;/li&gt;
   *       &lt;li&gt;BMW 502&lt;/li&gt;
   *       &lt;li&gt;BMW 503&lt;/li&gt;
   *       &lt;li&gt;BMW 507&lt;/li&gt;
   *       &lt;li&gt;BMW 3200&lt;/li&gt;
   *    &lt;/ul&gt;
			* &lt;script&gt;
     * // Create ListBox
   * $('#carsList').ejListBox(); 	
     * $('#carsList').ejListBox("addItem","Java"); 	
     * &lt;/script&gt;
     *@memberof ejListBox
     * @instance
     */
		addItem:function(val){
		if(this.model.enabled){
            this.listitem=  this.listContainer.find('ul').append('<li role="option">'+val+'</li>');
            this._refreshItems();
			}
        },
        _checkContains: function (Value) {
            var chkValue = Value;
            var values = this.element[0].value.split(",");
            this.contains = false;
            for (var i = 0; i < values.length; i++) {
                if (values[i] == chkValue)
                    this.contains = true;
            }
            return this.contains;
        },
        _init: function () {
            	this._id=this.element[0].id;
                this._initialize();
                this._render();
                this._enabled(this.model.enabled);
                this._wireEvents();
                this._initValue = false;
        },
       
        _changeSkin: function (skin) {
            if (this.model.cssClass != skin) {
                this.listContainer.removeClass(this.model.cssClass).addClass(skin);
            }
        },

        _setRTL: function (boolean) {
            this.listContainer.addClass("e-rtl");
        },
     	_setText: function (text) {
		var len=this.listitems.length;
		for(i=0;i<len;i++){
		if($(this.element.children("li")[i]).text() == text){
		this.unSelectAll();
		this.selectItemByIndex(i);
		}
		}
        },
        /**
       * To configure the properties at runtime using SetModel		
       * @private
       */
        _setModel: function (options) {
            if (!(this.model.enabled) && ej.isNullOrUndefined(options["enabled"])) return false;
            var option;
            for (option in options) {
                switch (option) {

                    case "dataSource": this._checkModelDataBinding(options[option]); break;
                    case "query": this._queryCheck(options[option]); break;
                    case "fields": this.model.fields = options[option]; this._checkModelDataBinding(this.model.dataSource); break;
                    case "template": this.model.template = options[option]; this._checkModelDataBinding(this.model.dataSource); break;
                    case "value": this._setText(ej.util.getVal(options[option])); break;
                    case "enableRTL": this._setRTL(options[option]); break;
                    case "enabled": this._enabled(options[option]); break;
                    case "height": this.model.Height = options[option]; this._setListHeight(options[option]); break;
                    case "width": this.model.Width = options[option]; this._setListWidth(); break;
                    case "cssClass": this._changeSkin(options[option]); break;
                    case "showCheckbox": this.checkboxHideShow(options[option]); break;
                    case "checkAll": this._setCheckAll(options[option]); break;
                    case "uncheckAll": this._setUncheckAll(options[option]); break;
                    case "showRoundedCorner": this._roundedCorner(options[option]); this.model.showRoundedCorner = options[option]; break;
                    case "selectedItemIndex": this.selectItemByIndex(options[option]); break;
                    case "selectedItems": this._selectCheckedItem(options[option]); this.model.selectedItems = options[option]; break;
                    case "checkedItems": this._selectCheckedItem(options[option]); this.model.checkedItems = options[option]; break;
                    case "checkedItemlist": this.model.checkedItemlist = options[option]; break;
                    case "selectedItemlist": this.model.selectedItemlist = options[option]; break;
                    case "allowMultiSelection": this.model.allowMultiSelection = options[option];
                        options[option] ? this._renderBoxModel() : this._destroyBoxModel();
                        break;
                    case "allowDragAndDrop":
                        {
                            if (options[key])
                                this._enableDargDrop();
                            break;
                        }
		
                }
            }
        },
        
        _destroy: function () {
            this.element[0].value = "";
			var predecessor =$(this.element.parents()[2]);
             this.element.removeClass("e-listbox e-js e-ul");
            if (this.model.dataSource != null){
			
			this.element.children().remove();
			predecessor.append(this.element.parents().first().html());
                this.listContainer.remove();
				}
            else {
			predecessor.append(this.element.parents().first().html());
                this.listContainer.remove();
            }
			$(window).unbind("resize", $.proxy(this._OnWindowResize, this));
        },
        /* cookie */

        _finalize: function () {
            if (this.model.selectedItemIndex != null) {
                this.selectItemByIndex(this.model.selectedItemIndex);
            } else if ((this.model.showCheckbox == true) && (this.model.selectedItems.length > 0)) {
                this._selectCheckedItem(this.model.selectedItems);
            }
        },

        /**/
        _initialize: function () {
            this.target = this.element[0];
            this._queryString = null;
            this._itemId = null;
            this.checkedStatus = false;
            this._incqueryString = "";
            this._activeItem = null;
            this._initValue = true;
        },
      


        _render: function () {
            this._renderContainer();
            this._initDataSource(this.model.dataSource);
            this._showFullList();
            this._addDragableClass();
            this._finalize();
        },

        _queryCheck: function (value) {
            this.model.query = value;
            this._checkModelDataBinding(this.model.dataSource);
        },

        _checkModelDataBinding: function (source) {
            this.model.dataSource = source;
            if (source != null) {
                if (ej.DataManager && source instanceof ej.DataManager) {
                    this._initDataSource(source);
                } else {
                    this._showFullList();
                }
            }
            else {
                this.element.empty();
            }
        },
        _initDataSource: function (source) {
            var proxy = this;
            if (ej.DataManager && source instanceof ej.DataManager) {
			query = this.model.query.take(11);
                proxy.listitems = proxy.model.dataSource;
                proxy._addLoadingClass();
                var queryPromise = source.executeQuery(query);
                queryPromise.done(function (e) {
                    proxy.listitems = e.result;
                    proxy._removeLoadingClass();
                    proxy._showFullList();

                }).fail(function (e) {
                    proxy.model.dataSource = null;
                    proxy._addLoadingClass();
                });
            }
        },


     
        _getQuery: function () {
            if (ej.isNullOrUndefined(this.model.query)) {
                var column = [], queryManager = ej.Query(), mapper = this.model.fields;
                for (var col in mapper) {
                    if (col !== "tableName")
                        column.push(mapper[col]);
                }
                if (column.length > 0)
                    queryManager.select(column);
                if (!this.model.dataSource.dataSource.url.match(mapper.tableName + "$"))
                    !ej.isNullOrUndefined(mapper.tableName) && queryManager.from(mapper.tableName);
            }
            else queryManager = this.model.query;
            return queryManager;
        },
        _addDragableClass: function () {
            if (this.model.allowDragAndDrop) {
			this.element.css("cursor","pointer");
			this.listContainer.addClass("e-droppable");
			this.listBoxScroller.addClass("e-droppable");
                this.element.children("li").each(function (index) {
                    ($(this).addClass("e-draggable e-droppable"));
                });
            }
        },
     
        _enableDargDrop: function () {
            if (this.model.allowDragAndDrop) {
                this._drag();
            }
        },
        _addLoadingClass: function () {
            this.listContainer.addClass("e-load");
            //this.drpbtnspan.removeClass("e-icon e-down-arrow");
            //this.model.readOnly = true;
        },

        _removeLoadingClass: function () {
            this.listContainer.removeClass("e-load");
        },

        _checkNameAttr: function () {
			if (this.element.attr("name"))
                this._hiddenInput.attr("name", this.element.attr("name"));
            else {
                this._hiddenInput.attr("name", this._id);
				this.element.attr("name", this._id);
			}
        },
     
        //render listBox pannel wrapper
        _renderContainer: function () {
            //render listBox 
			 this.listContainer = ej.buildTag("div.e-ddl-popup e-box e-popup e-widget " + this.model.cssClass + "#" + this._id + "_container", "", { "visibility": "hidden" }, { "tabIndex": 0 });
            this.listBoxScroller = ej.buildTag("div"); this.ultag = ej.buildTag("ul.e-ul", "", {}, { "role": "listbox" });
			this.element= this.element.addClass("e-ul");
			this.listContainer.append(this.listBoxScroller);
			this.listContainer.insertAfter(this.element);
			this.listBoxScroller.append(this.element);
			 this.element.attr('unselectable', 'on')
             this.element.css('user-select', 'none')
             this.element.on('selectstart', false);
        },
        //render listContainer
        _renderlistContainer: function () {
		this.hold=false;
		this.item="";
		this.touchhold=false;
		this.startime=0;
            var list = this.listitems, i, ulempty, ulno, litag, _id, _txt, mapper = this.model.fields, predecessor;
			this.lastScrollTop = -1;
            this.dummyUl = $();
            if (this.model.enableRTL)
                this.listContainer.addClass("e-rtl");
            if (this.model.dataSource == null || this.model.dataSource.length < 1) {
                predecessor = this.element.parents().last();
				 if (this.model.targetID)
				   this.docbdy = predecessor.find("#" + this.model.targetID);
                else
				this.docbdy = predecessor.find("#" + this._id);
				this.itemsContainer = this.docbdy;
                this.itemsContainer.children("ol,ul").remove();
                this.items = this.itemsContainer.children('li');
                this.items.children("img").addClass("e-align");
                this.items.children("div").addClass("e-align");
                //this.itemsContainer.children("span").addClass("e-ghead");
                //This will append the list with the listContainerwrapper
                this.element.append(this.itemsContainer.children());
            }
            else if (this.model.dataSource != null && typeof list[0] != "object") {
                //if (list.length > 0) {
                
               // }
            }
            else {
                this.mapFld = { _id: null, _imageUrl: null, _imageAttributes: null,_toolTipText:null, _spriteCSS: null, _text: null, _value: null, _htmlAttributes: null, _selected: null };
                this.mapFld._id = (mapper && mapper.id) ? mapper["id"] : "id";
                this.mapFld._imageUrl = (mapper && mapper.imageUrl) ? mapper["imageUrl"] : "imageUrl";
				this.mapFld._toolTipText = (mapper && mapper.toolTipText) ? mapper["toolTipText"] : "toolTipText";
                this.mapFld._imageAttributes = (mapper && mapper.imageAttributes) ? mapper["imageAttributes"] : "imageAttributes";
                this.mapFld._spriteCSS = (mapper && mapper.spriteCssClass) ? mapper["spriteCssClass"] : "spriteCssClass";
                this.mapFld._text = (mapper && mapper.text) ? mapper["text"] : "text";
                this.mapFld._value = (mapper && mapper.value) ? mapper["value"] : "value";
                this.mapFld._htmlAttributes = (mapper && mapper.htmlAttributes) ? mapper["htmlAttributes"] : "htmlAttributes";
                this.mapFld._selected = (mapper && mapper.selected) ? mapper["selected"] : "selected";
                var mapCateg = (mapper && mapper.category) ? mapper["category"] : "category", groupedList, _query;
                _query = ej.Query();
                 if (this.model.enableLoadOnDemand) {
				if(!this.model.enableVirtualScrolling){
					_query = ej.Query().take(11); 
                	this.realUllength=0;
				   	query = this.model.query.take(11);
					var proxy=this;
					if (ej.DataManager && this.model.dataSource instanceof ej.DataManager) {
					proxy.listitems = proxy.model.dataSource;
					var queryPromise = this.model.dataSource.executeQuery(query);
					queryPromise.done(function (e) {
                    proxy.listitems = e.result;
                });
				}
				 for (i = 0; i < this.model.itemsCount; i++) {
                        litag = ej.buildTag("li", list[i]);
						litag.css("height", "20px");
                        this.dummyUl.push(litag[0]);
                    }
                    this.displayeditem = 2;
					 this.element.append(this.dummyUl);
					   for (var i = 0; i < this.listitems.length; i++) {
                        var litag = ej.buildTag('li');
                        litag.css("height", "20px");
                        this.dummyUl.push(litag[0]);
                    }
                    this.element.append(this.dummyUl);
					}
					this.realUllength=0;
                    _query = _query.range(0, 11);
                    this.displayeditem = 2;
                    groupedList = ej.DataManager(list).executeLocal(_query);
                    this._loadlist(groupedList);
                }
				else if(this.model.enableVirtualScrolling){
				this.realUllength=0;
                    _query = _query.range(0, 11);
                    this.displayeditem = 2;
                    groupedList = ej.DataManager(list).executeLocal(_query);
                    this._loadlist(groupedList);
					}
                else {
                groupedList = ej.DataManager(list).executeLocal(_query);
                  if (groupedList.length > 0) {
                    if (this.model.template != null) {  //Template binding
                        for (i = 0; i < list.length; i++) {
                           litag = ej.buildTag("li", list[i]);
                           if (this.model.template) litag.append(this._getTemplatedString(list[i]));
                           this.dummyUl.push(litag[0]);
                       }
                       this.element.append(this.dummyUl);
                    } else {
                        _query = ej.Query().group(mapCateg); // Grouping with Category
                        groupedList = ej.DataManager(list).executeLocal(_query);
                        if (this.model.allowGrouping) {
                            for (i = 0; i < groupedList.length; i++) {
                                var spantag = ej.buildTag('span');
                                spantag.append(groupedList[i].key);
                                spantag.addClass("e-ghead");
                                this.dummyUl.push(spantag[0]);
                                this._loadlist(groupedList[i].items);
                            }
                        }
                        else {
						this.realUllength =0;
                            this._loadlist(groupedList[0].items);
							}
						} 
				  }
				}

            }
	
			
            this.element.children('li').attr({ "role": "option" }).css("list-style","none");
            this._setListWidth();
            this._setListHeight();
            this._setListPosition();
            this.listContainer.css("height", ""); this.listBoxScroller.css({ "height": "", "width": "" });
            this.listContainer.ejScroller({ height: this.listContainer.height(), width: 0, scrollerSize: 20 });
            this.scrollerObj = this.listContainer.ejScroller("instance");
			this._setListHeight();
            this.listContainer.css({ 'display': 'none', 'visibility': 'visible' });
            this.checkboxHideShow(this.model.showCheckbox);
            this._setCheckAll(this.model.checkAll);
            this._setUncheckAll(this.model.uncheckAll);
			this.checkitems();
            this._showResult();
        },
        _loadlist: function (sublist) {
		if(this.element !=null){
                for (var j = 0; j < sublist.length; j++) {
                    var _did = this._getField(sublist[j], this.mapFld._id);
                    var _dimageUrl = this._getField(sublist[j], this.mapFld._imageUrl);
                    var _dimageAttributes = this._getField(sublist[j], this.mapFld._imageAttributes);
                    var _dspriteCss = this._getField(sublist[j], this.mapFld._spriteCSS);
                    var _dtext = this._getField(sublist[j], this.mapFld._text);
                    var _dvalue = this._getField(sublist[j], this.mapFld._value);
                    var _dhtmlAttributes = this._getField(sublist[j], this.mapFld._htmlAttributes);
                    var _dselected = this._getField(sublist[j], this.mapFld._selected);
					var _dtoolTipText = this._getField(sublist[j], this.mapFld._toolTipText);
					var k =this.realUllength;                   
					 if ((_dvalue) && (_dvalue != ""))
                        litag = ej.buildTag('li', "", {}, { value: _dvalue });
                    else
                        litag = ej.buildTag('li');
                    if (_did)
                        litag.attr('id', _did);
                    if ((_dimageUrl) && (_dimageUrl != "")) {
                        //Creating the image tag
                        imgtag = ej.buildTag('img.e-align', '', {}, { 'src': _dimageUrl, 'alt': _dtext });
                        if ((_dimageAttributes) && (_dimageAttributes != ""))
                            imgtag.attr(_dimageAttributes);
                        litag.append(imgtag);
                    }
                    if ((_dspriteCss) && (_dspriteCss != "")) {
                        //Creating the Sprite image tag
                        divtag = ej.buildTag('div.e-align ' + _dspriteCss + ' sprite-image');
                        litag.append(divtag);
                    }
                    if ((_dtext) && (_dtext != "")) {
                        //Creating text Content inside the  tag
                        litag.append(_dtext);
                    }
                    if ((_dhtmlAttributes) && (_dhtmlAttributes != ""))
                        litag.attr(_dhtmlAttributes);
					if ((_dtoolTipText) && (_dtoolTipText != "")  && this.model.enableTooltip)
                        litag.attr('title',_dtoolTipText);
                    if (_dselected) {
                        litag.addClass("chkselect");
                    }
					if(this.element.children()[k] !=null && this.model.enableLoadOnDemand && $(this.element.children()[k]).text()== "" ){
					$(this.element.children()[k]).replaceWith(litag[0]);
					}
					else
					this.dummyUl.push(litag[0]);
					this.realUllength +=1;
                }
		   if(!this.model.enableLoadOnDemand)
				 this.element.children().remove();
           if(this.element.children()[k] ==null && (!this.model.enableLoadOnDemand ||this.model.enableVirtualScrolling))
           this.element.append(this.dummyUl);
            }  
        },
        //get object
        _getField: function (obj, fieldName) {
            return ej.pvt.getObject(fieldName, obj);
        },
        //template
        _getTemplatedString: function (list) {
            var str = this.model.template, start = str.indexOf("${"), end = str.indexOf("}");
            while (start != -1 && end != -1) {
                var content = str.substring(start, end + 1);
                var field = content.replace("${", "").replace("}", "");
                str = str.replace(content, this._getField(list, field));
                start = str.indexOf("${"), end = str.indexOf("}");
            }
            return str;
        },
   
        //checkbox properties
        checkboxHideShow: function (value) {
            if (value) {
                this._createCheckbox();
            } else {
                this._removeCheckbox();
            }
            this.model.showCheckbox = value;
        },
        _createCheckbox: function () {
            var i, _extchk, chklist, me = this;
            this.listitems = this.listContainer.find("ol,ul").children("li");
            chklist = this.listitems.find('input[type=checkbox]');
            if (chklist.length == 0) {
                for (i = 0; i < this.listitems.length; i++) {
                    $checkbox = ej.buildTag("input.listcheckbox e-align#popuplist" + i + "_" + this._id, "", {}, { type: "checkbox", name: "list" + i });
                    $(this.listitems[i]).prepend($checkbox);
                }
                this.listContainer.find(".listcheckbox").ejCheckBox({ cssClass: this.model.cssClass, change: $.proxy(this._OnClickCheckList, this) });
                for (i = 0; i < this.listitems.length; i++) {
                    if ($(this.listitems[i]).hasClass('chkselect')) {
                        $(this.listitems[i]).find(".listcheckbox").ejCheckBox({ "checked": true });
                        this._activeItem = i;
                        this.checkedStatus = true;
                        if (!this._initValue)
                            this._trigger('checkChange', { isChecked: this.checkedStatus, data: this.model });
                           $(this.listitems[i]).removeClass('chkselect');
                    }
                }
            }
        },

        _removeCheckbox: function () {
            var i, checkbox;
            this.listitem = this.listContainer.find("ol,ul").children("li");
            checkbox = this.listitem.find('.listcheckbox');
            if (checkbox.length > 0) {
                this.listitem.find('.listcheckbox').ejCheckBox('destroy');
                this.listitem.find('input[type=checkbox]').remove();
				this.model.checkedItems =[];
            }
        },
        _setCheckAll: function (value) {
            //Check all the nodes on CheckAll = true
            if ((this.model.showCheckbox) && (value))
                this.checkAll();
        },
        _setUncheckAll: function (value) {
            //UnCheck all the nodes on UnCheckAll = true
            if ((this.model.showCheckbox) && (value))
                this.unCheckAll();
        },
 
        _selectCheckedItem: function (chkitems) {
            if (chkitems.length > 0) {
                for (i = 0; i < chkitems.length; i++) {
              this.model.selectedItems.push(chkitems[i]);
                }
            }
        },
        
     
        //List Properties
        _refreshScroller: function () {
		if(this.model.enableVirtualScrolling){
		  this.listContainer.find(".e-content, .e-vhandle").removeAttr("style");
            this.listContainer.find(".e-vhandle div").removeAttr("style");
            this.listContainer.css({ "display": "block" });  // For get the height of the popup
            this.scrollerObj.model.height = this.listContainer.height();
            this.scrollerObj.refresh();
            this.scrollerObj.option("scrollTop", 0);
		}
		else{
            this.listContainer.find(".e-vhandle div").removeAttr("style");
			var listboxcontent = this.listBoxScroller.height();
            this.listContainer.css({ "display": "block" });
				// For get the height of the listBox
            this.scrollerObj.model.height = this.listContainer.height();
            this.scrollerObj.refresh();
			this.listBoxScroller.css("height","");	
		 this.listBoxScroller.css("height","100%");		
		 //this.element.css("height","");	
		 
			}
        },
         _setListWidth: function () {
            var width = this.model.width;
            this.listContainer.css({ "width": width });
        },

        _setListHeight: function () {
		 var height = this.model.height;
		 this.listContainer.css({ "height": height });
        },
        _refreshContainer: function () {           
            this.listContainer.css({ "width": this.model.width });
            this._setListPosition();
			this._setListHeight();
			this._roundedCorner();
            this._refreshScroller();
        },
        _setListPosition: function () {
            this.listContainer.css({
                "position":"relative"
            });
        },

        //dragEventHandler()
        _drag: function () {
            var proxy = this;
            var pre = false;
            var _clonedElement = null;
            var dragContainment = null;
            this._listitem = this.element.parent();
            $(this._listitem).find("li").not(".e-js").ejDraggable({
                dragArea: dragContainment,
                clone: true,
                dragStart: function (args) {
				var targetid = this.element.parent()[0].id; // to get id of the dragged control
            var draggedobj = $("#" + targetid).data("ejListBox");
			draggedobj ._refreshItems();
                    var data = { target: args.target, event: args.event };
                    if (proxy._onDragStarts(data)) {
                        args.cancel = true;
                        _clonedElement && _clonedElement.remove();
                        return false;
                    }
                },
                drag: function (args) {
                    var target = args.target;
                    var data = { target: target, event: args.event };
                    if (proxy._onDrag(data))
                        return false;
                    if ($(target).hasClass('e-droppable') || $(target).parent().hasClass('e-droppable')) {
                        document.body.style.cursor = '';
                        $(target).addClass("allowDrop");
                    }
                },
                dragStop: function (args) {
                    if (!args.element.dropped) {
                        _clonedElement && _clonedElement.remove();
                        document.body.style.cursor = '';
                    }
                    var target = args.target;
                    var targetObj = proxy;
                    var position = pre ? "Before" : "After";
                    var data = { target: target, position: position, event: args.event };
                    if (proxy._onDragStop(data))
                        return false;
                    $(args.element).removeClass("e-active");
                 
                        if (target.nodeName == 'UL')
                            target = $(target).children()[0];
                        if (target.nodeName != 'LI')
                            target = $(target).parent('.e-droppable')[0] || $(target).parent();
                        if (target.nodeName == 'LI' && $(target).hasClass('e-droppable')) 
                               proxy._dropItem(target, args.element, pre, args.event);
						else if ($(target).hasClass('e-droppable')) 
                               proxy._dropItemContainer(target, args.element, pre, args.event);
           
                    $(".allowDrop").removeClass("allowDrop");
                    var data = { target: target, event: args.event, dropedElement: args.element };
                    if (proxy._onDropped(data))
                        return false;
                    document.body.style.cursor = '';
				
                },
                helper: function (event, ui) {
                    _clonedElement = $(event.sender.target).clone().addClass("dragClone dragClonelist");
                    return _clonedElement.appendTo($("body"));
                }
            });
        },

        //Drop list Item
        _dropItem: function (target, element, pre, event) {
            var li = $(element);
            pre ? $(li).insertBefore(target) : $(li).insertAfter(target);
            this._refreshItems();
            var targetid = $(target).parents('div')[1].id.replace('_container', ''); // to get id of the dropped control
            var droppedobj = $("#" + targetid).data("ejListBox");
			droppedobj._refreshItems();
        },
		
		_dropItemContainer: function (target, element, pre, event) { // when dropped into listcontainer
            var li = $(element);
			$(li).insertAfter($($(target).find('li')).last());
			$(target).find('ul').append($(li))
            this._refreshItems();
            var targetid = $(target)[0].id.replace('_container', ''); // to get id of the dropped control
            var droppedobj = $("#" + targetid).data("ejListBox");
			droppedobj._refreshItems();
        },
        //listContainerstatus
        _showResult: function () {
            var proxy = this;
            this._refreshContainer();
            this.element.attr({ "aria-expanded": true }); var _ListItemsContainer = this.element.children("li");
            this._listSize = _ListItemsContainer.size();
			_ListItemsContainer.unbind("contextmenu", $.proxy(this._OnMouseContext, this));
			_ListItemsContainer.unbind("mouseup", $.proxy(this._OnMouseClick, this));
			_ListItemsContainer.unbind("touchstart mouseenter", $.proxy(this._OnMouseEnter, this));
            _ListItemsContainer.unbind("touchend mouseleave", $.proxy(this._OnMouseLeave, this));
			 $(window).unbind("resize", $.proxy(this._OnWindowResize, this));
				this._off($(this.listContainer), "DOMMouseScroll", this._onScroll);
				this._on($(this.listContainer), "DOMMouseScroll", this._onScroll);
			_ListItemsContainer.bind("touchstart mouseenter", $.proxy(this._OnMouseEnter, this));
			_ListItemsContainer.bind("touchend mouseleave", $.proxy(this._OnMouseLeave, this));
			_ListItemsContainer.bind("mouseup", $.proxy(this._OnMouseClick, this));
		    _ListItemsContainer.bind("contextmenu", $.proxy(this._OnMouseContext, this));
          
			 $(window).bind("resize", $.proxy(this._OnWindowResize, this));
			 	 
        },

        _OnWindowResize: function (e) {
            this._refreshContainer();
            this.listContainer.css("display", "block");
        },
        _removeActive: function () {
            this._ulBox.children("li").removeClass("e-active");
        },
      
        _removeListHover: function () {
		this.model.selectedItems =[];
            this.element.children("li").removeClass("e-hover");
			 this.element.children("li").removeClass("e-select");
        },

        _addListHover: function () {
			this._activeItem=this._selectedItem;
            var activeItem = this._getItem(this._selectedItem);
            activeItem.addClass("e-select");
			activeItem.addClass("e-hover");
            this.scrollerObj.setModel({ "scrollTop": this._calcScrollTop() });
            activeItem.focus();
			this._OnListSelect(this.prevselectedItem, this._selectedItem);
        },
 
        _calcScrollTop: function () {
            var ulH = this.element.outerHeight(), li = this.element.find("li"), liH = 0, index, top, i;
            index = this.element.find("li.e-select").index();
			if(this.model.enableVirtualScrolling)
			index =  this.displayeditem;
            for (i = 0; i < index; i++) { liH += li.eq(i).outerHeight(); }
            top = liH - ((this.listContainer.outerHeight() - li.eq(index).outerHeight()) / 2);
            return top;
        },
     
        _refreshItems: function () {
            this.listBoxScroller.append(this.element);
            this.listContainer.append(this.listBoxScroller);
            this._refreshContainer();
            this._showResult();
        },
       
        _selectedItemindex: function () {
            var selectItem;
            this.element.children("li").each(function (index) {
              if ($(this).hasClass("e-select")) {
                    selectItem = index;
                    return false;
                }
            });
            this._selectedItem = selectItem;
            return selectItem;
        },
        _getActiveItem: function () {		
		   return $(this.element.children("li")[this._activeItem]);          
        },
        _getItem: function (val) {
            return $(this.element.children("li")[val]);
        },
        _roundedCorner: function (val) {
            if (this.model.showRoundedCorner) {
               this.listContainer.addClass("e-corner-all");
            }
        },

        _enabled: function (boolean) {
            if (boolean) this.enable();
            else this.disable();
        },

        _showFullList: function () {
            if (this.model.dataSource != null) {
                if (!(ej.DataManager && this.model.dataSource instanceof ej.DataManager)) {
                    this.listitems = this.model.dataSource;
                }
            }
            this._renderlistContainer();
			this._addDragableClass();
			this._enableDargDrop();
        },

        // cascade options
        _cascadeAction: function () {
            if (this.model.cascadeTo) {
                this._currentValue = this._getField(this.listitems[this._activeItem], this.mapFld._value);
                this.selectDropObj = $('#' + this.model.cascadeTo).ejListBox('instance');
                if (ej.isNullOrUndefined(this._dSource))
                    this._dSource = this.selectDropObj.model.dataSource;
                    this._performJsonDataInit();
              
            }
        },
        _performJsonDataInit: function () {
            this._changedSource = ej.DataManager(this._dSource).executeLocal(ej.Query().where(this.mapFld._value, "==", this._currentValue));
            this.selectDropObj.setModel({ dataSource: this._changedSource, enabled: true, value:"" });
        },
        //Events
		_OnMouseContext:function (e){
		this.touchhold=true;
		e.preventDefault();
		return false;
		},
        _OnMouseEnter: function (e) {	
		this.startime = 0;
		this.item="";
		if(e.type =="touchstart"){
		this.item = $(e.target).text() ;
		this.startime = new Date().getTime();
		}
		if(this.model.enabled){
            var targetEle;
            this.element.children("li").removeClass("e-hover");
            if ($(e.target).is("li")) { $(e.target).addClass("e-hover"); }
            else if (e.target.tagName != "li") {
                targetEle = $(e.target).parents("li");
                $(targetEle).addClass("e-hover");
            }
            var activeItem = 0, selectItem=0;
            this.element.children("li").each(function (index) {
                if ($(this).hasClass("e-hover")) {
                    activeItem = index;
                    return false;
                }
            });
            this._activeItem = activeItem;
			}
        },
    
        _OnMouseLeave: function (e) {
		  this.element.children("li").removeClass("e-hover");
			this.endtime = new Date().getTime();
	  if((((this.endtime-this.startime)/200)>2)){
		  if((this.item ==$(e.target).text()))
		  	 this.hold=(((this.endtime-this.startime)/200)>2);
		}
        },
        _OnMouseClick: function (e) {
		if(e.which ==3)
		{
		this.hold=true;
		}
	this.endtime = new Date().getTime();
	
		if((((this.endtime-this.startime)/200)>2)){
		 if((this.item ==$(e.target).text())  &&(!this.hold))
		 {
	 this.hold=(((this.endtime-this.startime)/200)>2);
	
	 }
	 }
		if(this.model.enabled){
            if (!this.model.showCheckbox) {
                this.prevselectedItem = this._selectedItemindex();
                var activeitem = $(this.element.children("li")[this._activeItem]);
			  if (!this.model.allowMultiSelection || (!(e.ctrlKey||this.touchhold ||this.hold) && !e.shiftKey)) {
                    this._removeListHover();
                }
              
                this.element.children("li").removeClass('e-hover');
                if (!activeitem.hasClass('e-select')) {
                    activeitem.addClass('e-select');
					this.model.selectedItems.push(activeitem);
					this.model.selectedItemlist.push(this._activeItem);
                    if(e.shiftKey &&(this.model.allowMultiSelection)){var initial,last;
                        if( this.prevselectedItem<this._activeItem){
                            initial=this.prevselectedItem;
                            last=this._activeItem
                        }
                        else{
                            initial=this._activeItem
                            last=this.prevselectedItem;
                        }
                        for(var i=initial;i<=last;i++){
                            activeitem = $(this.element.children("li")[i])
                            if (!activeitem.hasClass('e-select')) 
                                activeitem.addClass('e-select');
                            this.model.selectedItems.push(activeitem);
							this.model.selectedItemlist.push(this._activeItem);
                        }
                    }
                }
                else {
                    activeitem.removeClass('e-select');
                    this.model.selectedItems.pop(activeitem);
					this.model.selectedItemlist.pop(this._activeItem);
                }

                this._selectedItem = this._selectedItemindex();
                this._cascadeAction();
				var selecteditem =$(this.element.children("li")[this._selectedItem]);
			if($(selecteditem).text() != ""){
			this.element.val($(selecteditem).text());
			this.value($(selecteditem).text());
			this.element.attr({ "value": "this.element.val()" });
			}
				this.model.selectedText=activeitem.text();
				var data = { selectedText: this.model.selectedText, args: (this.model.selectedItemIndex, this.model.selectedItems, this.model.selectedItemlist, this.model.checkedItemlist) };
				 this.model.selectedItemIndex = this._selectedItem;
                this._trigger("selected", data);
               
              } else {
                if (($(e.currentTarget).is("li")) && ($(e.target).is("li"))) {
                    if ($(e.currentTarget.firstChild).find('.listcheckbox').ejCheckBox('isChecked')) {
                        $(e.currentTarget.firstChild).find('.listcheckbox').ejCheckBox('option', 'checked', false);
                        var index=this.model.checkedItems.indexOf(e.currentTarget)
						this.model.checkedItems.splice( index, 1);
						this.model.checkedItemlist.pop(this._selectedItem);
                    
                    } else {
                        $(e.currentTarget.firstChild).find('.listcheckbox').ejCheckBox('option', 'checked', true);
                        this.model.checkedItems.push(e.currentTarget);
						this.model.checkedItemlist.push(this._activeItem);
                    }
                }
				else if($(e.currentTarget).is("li")){
				if (!($(e.currentTarget.firstChild).find('.listcheckbox').ejCheckBox('isChecked'))) {
				    	this.model.checkedItems.push(e.currentTarget);
						this.model.checkedItemlist.push(this._activeItem);
						}
				else{
					var index=this.model.checkedItems.indexOf(e.currentTarget)
					this.model.checkedItems.splice( index, 1);
					this.model.checkedItemlist.pop(this._activeItem);
					}
				}
				else{
				return false;
				}
                if (!this.element.hasClass("e-disable")) {
                    var args = { status: this.model.enabled };
                    this._trigger("checkChange", args);
                }
                 }
            this._OnListSelect(this.prevselectedItem,this._activeItem);
			}
	
        },
        _OnClickCheckList: function (e) {
            if (e.isChecked) {
                this.checkedStatus = true;
               
            } else {
                this.checkedStatus = false;
       
            }
            if (!this._initValue)
                this._trigger('checkChange', { isChecked: this.checkedStatus, data: this.model });

        },
        _OnListSelect: function (previtem, selecteditem) {
            if (previtem != selecteditem)
                this._trigger('selectIndexChanged', { data: this.model });
        },
        //keyboard events
    
        _OnKeyDown: function (e) {
		if(this.model.enabled){
            if ((!this.model.enabled)) return false;
            this._itemId = null;
            var _ListItemsContainer = this.element.children("li");
            this._listSize = this.element.children("li").size();

            switch (e.keyCode) {
                case 38:    //Up arrow 
                    this.prevselectedItem = this._selectedItemindex();
                    if ((!e.ctrlKey && !e.shiftKey) || !this.model.allowMultiSelection) {
                            this._removeListHover();
                    } 
                            this.element.children("li").removeClass('e-active');
                            if ((this._selectedItem <= 0) || (this._selectedItem == null) || (this._selectedItem > this._listSize - 1))
                                this._selectedItem = this._listSize - 1;
                            else
                                this._selectedItem -= 1;
                            this._addListHover();
                            e.preventDefault();
                            return false;
                   
                    break;

                case 40:    //Down arrow
				
                    this.prevselectedItem = this._selectedItemindex();
					 var selecteditem =0; 
					this.element.children("li").each(function (index) {
					if ($(this).hasClass("e-select"))
                     selecteditem = index;
					});
                    if ((!e.ctrlKey && !e.shiftKey) || !this.model.allowMultiSelection) {
                            this._removeListHover();
                    }                   
					
					this.element.children("li").removeClass('e-active');
					this._selectedItem=selecteditem;
                            if ((this._selectedItem >= this._listSize - 1) || (this._selectedItem == null) || (this._selectedItem < 0))
                                this._selectedItem = 0;
                            else
                                this._selectedItem += 1;
                            this._addListHover();
							e.preventDefault();
							 if (this.model.enableLoadOnDemand){
							this._onScroll();
							this.element.focus();
							}
							return false;
                                   break;
                case 37:// Left Key equals up
                    this.prevselectedItem = this._selectedItemindex();
                    if ((!e.ctrlKey && !e.shiftKey) || !this.model.allowMultiSelection) {
                        this._removeListHover();
                    } 
                        this.element.children("li").removeClass('e-active');
                        if ((this._selectedItem <= 0) || (this._selectedItem == null) || (this._selectedItem > this._listSize - 1))
                            this._selectedItem = this._listSize - 1;
                        else
                            this._selectedItem -= 1;
                        this._addListHover();
                 
                    e.preventDefault();
                    return false;
                    break;  // Left Key

                case 39:// Right Key equals down
                    this.prevselectedItem = this._selectedItemindex();
					 var selecteditem =0; 
					this.element.children("li").each(function (index) {
					if ($(this).hasClass("e-select"))
                     selecteditem = index;
					});
					
                    if ((!e.ctrlKey && !e.shiftKey) || !this.model.allowMultiSelection) {
                        this._removeListHover();
                    }
					this.element.children("li").removeClass('e-active');
					this._selectedItem=selecteditem;
                        this.element.children("li").removeClass('e-active');
                        if ((this._selectedItem >= this._listSize - 1) || (this._selectedItem == null) || (this._selectedItem < 0))
                            this._selectedItem = 0;
                        else
                            this._selectedItem += 1;
                        this._addListHover();
                    e.preventDefault();
					 if (this.model.enableLoadOnDemand){
							this._onScroll();
							this.element.focus();
							}
                    return false;
                    break;  // Right Key

                case 8:    // Backspace key
                    if ((this.model.allowMultiSelection == true) && (this.model.showCheckbox)) {
                        this._deleteLastBox();
                    }
                    e.preventDefault();
                    return false;
                    break;
                case 9:    // Tab key
                    break;
                case 33:
                    break;//up key
                case 34:
                    break;//down key

                case 35:
                    this.prevselectedItem = this._selectedItemindex();
                    this._removeListHover();
                        this.element.children("li").removeClass('e-active');
                        this._selectedItem = this._listSize - 1;
                        this._addListHover();
                   
                    e.preventDefault();
                    return false;
                    break;  // End Key
				case 13:    // Enter Key
                    
				e.preventDefault();
                this._OnMouseClick(e);
				break;
				
                case 36:
                    this.prevselectedItem = this._selectedItemindex();
                    this._removeListHover();
                        this.element.children("li").removeClass('e-active');
                        this._selectedItem = 0;
                        this._addListHover();
                    e.preventDefault();
                    return false;
                    break;  // Home Key
                case 18:    // Alt key
                    break;
                case 32:    // space Key
                    e.preventDefault();
                    return false;
                    break;
            }
            }
        },
		_onmousedown:function (){
		this._on($(document), "mouseup", this._onScroll);
		},
        //scroll event
        _onScroll: function () {
		if(this.model.enableLoadOnDemand && !this.model.enableVirtualScrolling){
		if(this.scrollerObj.scrollTop() >0){
		var listitemheight = $(this.element.find('li')[0]).outerHeight();
					var end =parseInt((this.scrollerObj.scrollTop()/listitemheight) +20);
		    var start = parseInt((this.scrollerObj.scrollTop()/listitemheight) );
			this.realUllength=start;
			this.realUllength=start;

      
			var args = { start: start };
			 this._trigger('itemRequest',args);
			if (ej.DataManager && this.model.dataSource instanceof ej.DataManager) {
				 var proxy = this;
				 proxy._addLoadingClass();
                var queryPromise = this.model.dataSource.executeQuery(this.model.query);
                queryPromise.done(function (e) {
				proxy.realUllength=start;
					proxy._loadlist(e.result);
					 proxy._removeLoadingClass();
                });
            } 
		}
		}
			else if(this.model.enableVirtualScrolling)	{
			if(this.scrollerObj.model.scrollTop <= this.scrollerObj._vScrollbar._scrollData.scrollable){
			   var st = this.scrollerObj.model.scrollTop;
			if(st > this.lastScrollTop){
				    var _query = this.model.query;
			
            var end = this.element.children().length + 10;
            var start = this.element.children().length;
           	var args = { start: start };
			
			 this._trigger('itemRequest',args);
			 			if (arguments[0].originalEvent.detail < 0) {
                    this.displayeditem -= (this.model.itemsCount -1);
                }
                else{
                    this.displayeditem += (this.model.itemsCount -1);
                }
			if (ej.DataManager && this.model.dataSource instanceof ej.DataManager) {
				 var proxy = this;
				  proxy._addLoadingClass();
                var queryPromise = this.model.dataSource.executeQuery(this.model.query);
                queryPromise.done(function (e) {
				proxy.realUllength=start;
					proxy._loadlist(e.result);
					proxy._removeLoadingClass();
				 proxy.scrollerObj.option("scrollTop", proxy._calcScrollTop());
               proxy.scrollerObj.refresh();
                });
			
            } 
              
				
			}
			 this.lastScrollTop = this.scrollerObj.scrollTop();
			 }
			 this._refreshItems();
                 this.listContainer.css("height", "auto");
                this.listContainer.css({ "display": "block" });  // For get the height of the popup
                this.scrollerObj.model.height = this.listContainer.height();
                this.scrollerObj.refresh();
             this.scrollerObj.option("scrollTop", this._calcScrollTop());

 this.listContainer.css("height", "auto");
                this.listContainer.css({ "display": "block" });  // For get the height of the popup
                this.scrollerObj.model.height = this.listContainer.height();
                this.scrollerObj.refresh();
			}
			this._off($(document), "mouseup", this._onScroll);
			
 	
        },
       
        //trigger client side events
      
        _onDragStarts: function (data) {
            return this._trigger("itemDragStart", data);
        },
        _onDrag: function (data) {
            return this._trigger("itemDrag", data);
        },
        _onDragStop: function (data) {
            return this._trigger("itemDragStop", data);
        },
        _onDropped: function (data) {
            return this._trigger("itemDropped", data);
        },


        //-------------------- Event Wire-up -------------------------//
        _wireEvents: function () {
            this._on(this.listContainer, "keydown", this._OnKeyDown);
	
	  this._on(this.listContainer, "DOMMouseScroll",this._onScroll);
         	this._on(this.listContainer, "mousedown", this._onmousedown);
			this._on($(".e-vhandle"), "mousedown", this._onmousedown);
			this._on($(".e-vhandlespace"), "mousedown", this._onmousedown);
			this._on(this.listContainer, "mousewheel", this._onScroll);
            this._enableDargDrop();
        }
    });
})(jQuery, Syncfusion);
