/*!
*  filename: ej.navigationdrawer.js
*  version : 12.1
*  Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
*/

/**
* @fileOverview Plugin to style the Html Navigation Drawer elements
* @copyright Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/
(function ($, ej, undefined) {
    /**
    * @namespace ej
    * @class ejNavigationDrawer
    * @requires jQuery
    * @requires ej.core.js
    * @requires ej.navigationdrawer.js
    * @requires ej.listview.js
    * @classdesc Custom Design for Html Navigation Drawer control.
    * @example 
    * //create Navigation Drawer in Obtrusive way
    * &lt;div id="home" class="navsubpage"&gt;
    * &lt;div align="center" class="content"&gt;
    * &lt;h2 class="title"&gt;
    * Home&lt;/h2&gt;
    * &lt;p&gt;
    * Founded by industry experts in 2001,Syncfusion, Inc. provides the broadest range of enterprise-class software components and tools for the Microsoft .NET platform.
    * &lt;/p&gt;
    * &lt;/div&gt;
    * &lt;/div&gt;
    * &lt;style&gt;
    * .list {
    *   border-bottom: 1px solid;
    *   line-height: 50px;
    *   text-align: center;
    *   width:200px;
    *   }
    * &lt;/style&gt;
    * &lt;div &gt;
    * &lt;div class="list"&gt; Home &lt;/div&gt;
    * &lt;div class="list"&gt; Communities &lt;/div&gt;
    * &lt;/div&gt;
    * &lt;script&gt;
    * $(function () {
    * $("#navpane").ejNavigationDrawer();	
    * });
    * &lt;/script&gt;
    **/
    ej.widget("ejNavigationDrawer", "ej.NavigationDrawer", {

        _setFirst: false,
        validTags: ["div"],
        _rootCSS: "e-nb",
        _prefixClass: "e-",
        defaults: {

        },

        dataTypes: {

        },

        _init: function () {
            this._load();
            this._renderControl();
            this._renderEJMControls();
            this._createDelegate();
            this._wireEvents();
        },

        _load: function () {
            this._browser = this._browser();
            if (this.model.position == "normal") {
                this._elementWrapper = ej.buildTag("div#" + this._id + "_WrapContainer", {}, {}, { "class": this._rootCSS + " e-nb-container" });
                this.element.wrapAll(this._elementWrapper);
                this._nbHome = $("#" + this._id + "_WrapContainer").parent();
            }
            else {
                this._nbHome = $("body");
                this.element.appendTo(this._nbHome);
            }
        },

        _renderEJMControls: function () {
            if (this.model.enableListView) {
                this._lb = ej.buildTag("div#" + this._id + "_listbox", {}, {}, { "class": "e-nb-listbox" });
                this.element.find(">ul").wrapAll(this._lb);
                this._lb = $("#" + this._id + "_listbox");
                if (!this.model.listViewSettings["width"])
                    this.model.listViewSettings["width"] = 240;
                this._lb.ejListView(this.model.listViewSettings);
                this._lb.ejListView({ loadComplete: $.proxy(this._setLayout, this) });
            }

        },

        _setModel: function (options) {
            var refresh = false;
            for (var prop in options) {
                switch (prop) {
                    case "width":
                        this._setWidth();
                        this._setLayout();
                        break;
                    case "direction":
                        this._setLayout();
                        break;
                    case "type":
                        this._transform(0, 0, true);
                        this._transform(0, 0, false);
                        break;
                    default:
                        refresh = true;
                }
                if (refresh) { this._refresh(); }
            }
        },

        _destroyEJMPlugin: function () {
            this._lb.ejListView("destroy");
            if (this._lb) this._lb.unwrap();
        },

        _browser: function () {
            return (/webkit/i).test(navigator.appVersion) ? 'webkit' : (/firefox/i).test(navigator.userAgent) ? 'Moz' : (/trident/i).test(navigator.userAgent) ? 'ms' : 'opera' in window ? 'O' : '';
        }

    });
    $.extend(true, ej.NavigationDrawer.prototype, ej.NavigationDrawerBase.prototype);
    $.extend(true, ej.NavigationDrawer.prototype.defaults.listViewSettings, ej.ListView.prototype.defaults);

})(jQuery, Syncfusion);
