/**
* @fileOverview Pivot Schema Designer control to list out and analyze the data
* @copyright Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/

(function ($, ej, undefined) {

    /**
    * @namespace ej
    * @class ejPivotSchemaDesigner
    * @requires jQuery
    * @requires ej.common.all
    * @requires ej.tools.js
    * @classdesc Custom Design for Pivot Schema Designer control.
    * @example 
    * &lt;div id="PivotSchemaDesigner"&gt; &lt;/div&gt; <br> 
    * &lt;script&gt;
    * // Create Pivot Schema Designer
    * $("#PivotSchemaDesigner").ejPivotSchemaDesigner(...); 	
    * &lt;/script&gt;
    */
    ej.widget("ejPivotSchemaDesigner", "ej.PivotSchemaDesigner", {

        // Root Css Class
        _rootCSS: "e-pivotschemadesigner",

        // Widget element will be automatically set in this
        element: null,

        // User-defined model will be automatically set in this
        model: null,

        validTags: ["div", "span"],

        defaults: {
            //properties
            /**		
            * Connects the service using the specified URL for any server updates.	See {@link url}
            * @default ""
            * @type {String}
            * @example 
            * //To set service url during initialization  
            * $("#PivotSchemaDesigner").ejPivotSchemaDesigner({url: "/wcf/PivotService.svc"});
            * @example 
            * //Get or set the size API, after initialization:<br>
            * //Gets the url value  
            * $("#PivotSchemaDesigner").ejPivotSchemaDesigner("option","url");<br>   
            * //Sets the url value 
            * $("#PivotSchemaDesigner").ejPivotSchemaDesigner("option","url", "/wcf/PivotService.svc" ); 
            * @memberof ejPivotSchemaDesigner
            * @instance
            */
            url: "",

            /**		
            * Sets the CSS name for custom operation.
            * @default ""
            * @type {String}
            * @example 
            * //To set the CSS name during initialization  
            * $("#PivotSchemaDesigner").ejPivotSchemaDesigner({cssClass: "gradient-lime"});	
            * @example 
            * //Get or set css class for initialization:<br>
            *	// Gets the css name.		
            *	$("#PivotSchemaDesigner").ejPivotSchemaDesigner("option", "cssClass");			
            *	// Sets the css class to PivotSchemaDesigner
            *	$("#PivotSchemaDesigner").ejPivotSchemaDesigner("option", "cssClass",  "gradient-lime" ); 		
            * @memberof ejPivotSchemaDesigner
            * @instance
            */
            cssClass: "",
			
            /**		
            * Sets the height for PivotSchemaDesigner.
            * @default ""
            * @type {String}
            * @example 
            * //To set the height during initialization  
            * $("#PivotSchemaDesigner").ejPivotSchemaDesigner({height: "630px"});	
            * @example 
            * //Get or set height for initialization:<br>
            *	// Gets the height.		
            *	$("#PivotSchemaDesigner").ejPivotSchemaDesigner("option", "height");			
            *	// Sets the height to PivotSchemaDesigner
            *	$("#PivotSchemaDesigner").ejPivotSchemaDesigner("option", "height",  "630px" ); 		
            * @memberof ejPivotSchemaDesigner
            * @instance
            */
            height: "630px",
			
			/**		
            * Sets the width for PivotSchemaDesigner.
            * @default ""
            * @type {String}
            * @example 
            * //To set the width during initialization  
            * $("#PivotSchemaDesigner").ejPivotSchemaDesigner({width: "415px"});	
            * @example 
            * //Get or set width for initialization:<br>
            *	// Gets the width.		
            *	$("#PivotSchemaDesigner").ejPivotSchemaDesigner("option", "width");			
            *	// Sets the width to PivotSchemaDesigner
            *	$("#PivotSchemaDesigner").ejPivotSchemaDesigner("option", "width",  "415px" ); 		
            * @memberof ejPivotSchemaDesigner
            * @instance
            */
            width: "415px",
			
            layout: "normal",

            /**		
            * Sets the pivot control bounds with the Pivot Schema Designer.
            * @default null
            * @type {object}
            * @example 
            * //To set the pivot control during initialization  
            * var control = $("#PivotSchemaDesigner").data("ejPivotSchemaDesigner");
            * $("#PivotSchemaDesigner").ejPivotSchemaDesigner({pivotControl: control});
            * @example 
            * //Get or set the pivot control, after initialization:<br>
            *	//Gets the pivot control value
            *	$("#PivotSchemaDesigner").ejPivotSchemaDesigner("option", "pivotControl");<br>			
            *	//Sets the pivot control
            *	$("#PivotSchemaDesigner").ejPivotSchemaDesigner("option", "pivotControl", control);			* 		
            * @memberof ejPivotSchemaDesigner
            * @instance
            */
            pivotControl: null,

            /**		
            * Allows the user to Pivot Table Field List to Pivot Schema Designer.
            * @default new Array()
            * @type {Array}
            * @example 
            * //To set the Pivot Table Field List during initialization  
            * $("#PivotSchemaDesigner").ejPivotSchemaDesigner({pivotTableFieldList: });
            * @example 
            * //Get or set the Pivot Table Field List, after initialization:<br>
            *	//Gets the virtual calling state
            *	$("#PivotSchemaDesigner").ejPivotSchemaDesigner("option", "pivotTableFieldList");<br>		
            *	//Sets the Pivot Table Field List 
            *	$("#PivotSchemaDesigner").ejPivotSchemaDesigner("option", "pivotTableFieldList","true");			* 		
            * @memberof ejPivotSchemaDesigner
            * @instance
            */
            pivotTableFields: [],

            /**		
            * Allows the user to set Pivot Calculation List.
            * @default new Array()
            * @type {Array}
            * @example 
            * //To set the pivot calculation cist during initialization  
            * $("#PivotSchemaDesigner").ejPivotSchemaDesigner({pivotTableFieldList: });
            * @example 
            * //Get or set the pivot calculation list, after initialization:<br>
            *	//Gets the cell context state
            *	$("#PivotSchemaDesigner").ejPivotSchemaDesigner("option", "pivotTableFieldList");<br>			
            *	//Sets the pivot calculation list value
            *	$("#PivotSchemaDesigner").ejPivotSchemaDesigner("option", "pivotTableFieldList","true");			* 		
            * @memberof ejPivotSchemaDesigner
            * @instance
            */
            pivotCalculations: [],

            /**		
            * Allows the user to set the pivot column list.
            * @default new Array()
            * @type {Array}
            * @example 
            * //To set the pivot column list during initialization  
            * $("#PivotSchemaDesigner").ejPivotSchemaDesigner({pivotTableFieldList: true});
            * @example 
            * //Get or set the pivot column list, after initialization:<br>
            *	//Gets the pivot column list
            *	$("#PivotSchemaDesigner").ejPivotSchemaDesigner("option", "pivotTableFieldList");<br>			
            *	//Sets the pivot column list value
            *	$("#PivotSchemaDesigner").ejPivotSchemaDesigner("option", "pivotTableFieldList","true");			* 		
            * @memberof ejPivotSchemaDesigner
            * @instance
            */
            pivotColumns: [],

            /**		
            * Allows the user to set the pivot row list.
            * @default new Array()
            * @type {Array}
            * @example 
            * //To set the pivot row list during initialization  
            * $("#PivotSchemaDesigner").ejPivotSchemaDesigner({pivotRowList: true});
            * @example 
            * //Get or set the pivot row list, after initialization:<br>
            *	//Gets the pivot row list
            *	$("#PivotSchemaDesigner").ejPivotSchemaDesigner("option", "pivotRowList");<br>		
            *	//Sets the pivot row list
            *	$("#PivotSchemaDesigner").ejPivotSchemaDesigner("option", "pivotRowList","true");			* 		
            * @memberof ejPivotSchemaDesigner
            * @instance
            */
            pivotRows: [],

            /**		
            * Allows the user to set the filter list.
            * @default new Array()
            * @type {Array}
            * @example 
            * //To set the filter list during initialization  
            * $("#PivotSchemaDesigner").ejPivotSchemaDesigner({filterList: true});
            * @example 
            * //Get or set the filter list, after initialization:<br>
            *	//Gets the filter list
            *	$("#PivotSchemaDesigner").ejPivotSchemaDesigner("option", "filterList");<br>   				
            *	//Sets the filter list
            *	$("#PivotSchemaDesigner").ejPivotSchemaDesigner("option", "filterList","true");			* 		
            * @memberof ejPivotSchemaDesigner
            * @instance
            */
            filters: [],
            enableWrapper: false,

            serviceMethods: {
                fetchMembers: "FetchMembers", nodeStateModified: "NodeStateModified",
                nodeDropped: "NodeDropped", removeButton: "RemoveButton", memberExpand: "MemberExpanded", filtering: "filtering"
            },
        },

        /**
        * Provides information about the properties of type Array and Object.
        *
        * @private
        */
        dataTypes: {
            serviceMethods: "data",
            customObject: "data",
            pivotControl: "data",
            pivotTableFieldList: "array",
            pivotCalculationList: "array",
            pivotColumnList: "array",
            pivotRowList: "array",
            filterList: "array"
        },

        /**
        * Initializes the variables and loads the widget. 
        *
        * @private
        */
        _init: function () {
            this._initPrivateProperties();
            this._load();
        },

        /**
        * Destroys the widget while it's no longer required. 
        *
        * @private
        */
        _destroy: function () {
            this.element.empty().removeClass("e-pivotschemadesigner" + this.model.cssClass);
        },

        /**
        * Initializes the local variables. 
        *
        * @private
        */
        _initPrivateProperties: function () {
            this._id = this.element.attr("id");
            this._dialogTitle = "";
            this._currentMembers = new Array();
            this._memberTreeObj = null;
            this._tableTreeObj = null;
            this._dialogOKBtnObj = null;
            this._curFilteredText = "";
            this._curFilteredAxis = "";
            this._tempFilterData = null;
            this._droppedClass = "";
            this._selectedTreeNode = null;
            this._selectedMember = "";
            this._isDragging = false;
            this._dataModel = "";
            this._droppedPosition = "";
            this._currentCubeName = "";
            _pivotProxy = this;
            this._nodeDropedParams = "";
        },

        /**
        * This function is the point were loading/rendering of the Pivot Grid widget is initiated.
        *
        * @private  
        */
        _load: function () {
           var itemProps = "", report;
            if (this.model.pivotControl!=null && !jQuery.isEmptyObject(this.model.pivotControl.getOlapReport())) {
                itemProps = JSON.parse(JSON.parse(this.model.pivotControl.getOlapReport()).ItemsProperties);
                report = JSON.parse(this.model.pivotControl.getOlapReport());
                this._setTableFields(itemProps);
                this._setPivotRows(report.PivotRows);
                this._setPivotColumns(report.PivotColumns);
                this._setPivotCalculations(report.PivotCalculations);
                this._setFilters(report.Filters);
                this._dataModel = report.DataModel;
                this._currentCubeName = report.CurrentCube;
                $("#" + this._id).ejWaitingPopup({ showOnInit: true });
                pschemaDesignerWaitingPopup = $("#" + this._id).data("ejWaitingPopup");
                pschemaDesignerWaitingPopup.hide();
            }
            if (this.model.enableWrapper == false)
            {
            var fieldTable = ej.buildTag("table.headerTable", ej.buildTag("tr", ej.buildTag("td", ej.buildTag("div.listHeader", ej.buildTag("span.headerText", "PivotTable Field List", {})[0].outerHTML, {})[0].outerHTML + ej.buildTag("div.listSubhead", ej.buildTag("span.subheadText", "Choose fields to add to report:", {})[0].outerHTML, {})[0].outerHTML, {}).attr("valign", "top")[0].outerHTML, {})[0].outerHTML, {}).attr("width", "100%").attr("height", "10%")[0].outerHTML + ej.buildTag("table.fieldTable", ej.buildTag("tbody", ej.buildTag("tr", ej.buildTag("td", ej.buildTag("div.schemaFieldList", ej.buildTag("div.schemaFieldTree#schemaFieldTree")[0].outerHTML)[0].outerHTML).attr("valign", "top")[0].outerHTML, {})[0].outerHTML, {})[0].outerHTML, {}).attr("width", "95%").attr("height", "30%")[0].outerHTML,
            axisTable = ej.buildTag("table.axisTable", ej.buildTag("tbody", ej.buildTag("tr", ej.buildTag("td", ej.buildTag("div.pivotHeader", ej.buildTag("span.headerText", "Report Filter", {})[0].outerHTML, {})[0].outerHTML + ej.buildTag("div.schemaFilter", this._createPivotButtons(this.model.filters, "filter"))[0].outerHTML, {}).attr("width", "50%").attr("height", "50%").attr("valign", "top")[0].outerHTML + ej.buildTag("td", ej.buildTag("div.rPivotHeader", ej.buildTag("span.headerText", "Column Label", {})[0].outerHTML, {})[0].outerHTML + ej.buildTag("div.schemaColumn", this._createPivotButtons(this.model.pivotColumns, "column"), {})[0].outerHTML, {}).attr("width", "50%").attr("height", "50%").attr("valign", "top")[0].outerHTML, {})[0].outerHTML + ej.buildTag("tr", ej.buildTag("td", ej.buildTag("div.pivotHeader", ej.buildTag("span.headerText", "Row Label", {})[0].outerHTML, {})[0].outerHTML + ej.buildTag("div.schemaRow", this._createPivotButtons(this.model.pivotRows, "row"), {})[0].outerHTML, {}).attr("width", "50%").attr("height", "50%").attr("valign", "top")[0].outerHTML + ej.buildTag("td", ej.buildTag("div.rPivotHeader", ej.buildTag("span.headerText", "Values", {})[0].outerHTML, {})[0].outerHTML + ej.buildTag("div.schemaValue", this._createPivotButtons(this.model.pivotCalculations, "values"), {})[0].outerHTML, {}).attr("width", "50%").attr("height", "50%").attr("valign", "top")[0].outerHTML, {})[0].outerHTML, {})[0].outerHTML, {}).attr("width", "100%").attr("height", "46%")[0].outerHTML,
            htmlTag = fieldTable + ej.buildTag("div.centerDiv")[0].outerHTML + ej.buildTag("div.centerHead", "Drag fields between areas below:")[0].outerHTML + axisTable;
            $(htmlTag).appendTo("#" + this._id);
            }
            else if(this.model.enableWrapper == true)
            {
            this._setFilters(report.Filters);
            this.element.find(".axisTable .schemaFilter").append(this._createPivotButtons(this.model.filters, "filter"));
            this.element.find(".axisTable .schemaRow").append(this._createPivotButtons(this.model.pivotRows, "row"));
            this.element.find(".axisTable .schemaColumn").append(this._createPivotButtons(this.model.pivotColumns, "column"));
            this.element.find(".axisTable .schemaValue").append(this._createPivotButtons(this.model.pivotCalculations, "values"));
            this.element.find(".pivotButton .pvtBtn").ejButton({ size: "normal" }).ejDraggable({
                handle: 'button', clone: true,
                cursorAt: { left: -5, top: -5 },
                dragStart: ej.proxy(function (args) {
                    this._isDragging = true;
                }, this),
                dragStop: ej.proxy(this._onPvtBtnDropped, this),
                helper: ej.proxy(function (event, ui) {
                    if (event.sender.target.className.indexOf("e-btn") > -1)
                        return $(event.sender.target).clone().addClass("dragClone").appendTo(this.element);
                    else
                        return false;
                }, this)
            });
            }
            this.element.width(this.model.width).height(this.model.height);
            this.element.find(".pivotButton .pvtBtn").ejButton({ size: "normal"}).ejDraggable({
                handle: 'button', clone: true,
                cursorAt: { left: -5, top: -5 },
                dragStart: ej.proxy(function (args) {
                    this._isDragging = true;
                }, this),
                dragStop: ej.proxy(this._onPvtBtnDropped, this),
                helper: ej.proxy(function (event, ui) {
                    if (event.sender.target.className.indexOf("e-btn") > -1)
                        return $(event.sender.target).clone().addClass("dragClone").appendTo(this.element);
                    else
                        return false;
                }, this)
            });

            this.element.find(".pivotButton .filterBtn").ejButton({
                size: "normal",
                contentType: "imageonly",
                prefixIcon: "filter"
            });
            this.element.find(".pivotButton input").ejToggleButton({
                size: "normal",
                contentType: "imageonly",
                defaultPrefixIcon: "ascending",
                activePrefixIcon: "descending",
                click: ej.proxy(this._onSortBtnClick, this)
            });
            this.element.find(".schemaFieldTree").ejTreeView({
                showCheckbox: true,
                fields: { id: "id", parentId: "pid", text: "name", isChecked: "isSelected", spriteCssClass: "spriteCssClass", dataSource: this.model.pivotTableFields },
                allowDragAndDrop: true,
                allowDropChild: false,
                allowDropSibling: false,
                dragAndDropAcrossControl: true,
                nodeDropped: ej.proxy(this._onNodeDropped, this),
                nodeDragStart: ej.proxy(this._onNodeDrag, this)
            });
            this._tableTreeObj = this.element.find(".schemaFieldTree").data("ejTreeView");
            this._tableTreeObj.element.find(".measureGroupCDB").siblings(".e-chkbox-wrap").remove();
            this._tableTreeObj.element.find(".folderCDB").siblings(".e-chkbox-wrap").remove();
            this._tableTreeObj.element.find(".dimensionCDB").siblings(".e-chkbox-wrap").remove();
            this._tableTreeObj.element.find(".measureGroupCDB").parents("li").append(ej.buildTag("span.elementSeparator")[0].outerHTML);
            this._tableTreeObj.element.find(".dimensionCDB").parents("li").append(ej.buildTag("span.elementSeparator")[0].outerHTML);
            var treeViewElements = this._tableTreeObj.element.find("li");
            for (var i = 0; i < treeViewElements.length; i++) {
                treeViewElements[i].setAttribute("tag", this.model.pivotTableFields[i].tag);
                var checkedBoxNode = $(treeViewElements[i]).find(".e-chkbox-wrap");
                if (checkedBoxNode[0].attributes[4].value == "true" && $($(treeViewElements[i])).find(".folderCDB").length <= 0 && $(treeViewElements[i]).attr("tag").indexOf("[Measures]") == -1) {
                    var dropSpan = ej.buildTag("span.e-icon").css("display","none").addClass("treeDrop")[0].outerHTML;
                    $($(treeViewElements[i]).find(".e-text")[0]).after(dropSpan);
                }
            }
            this._tableTreeObj.model.nodeCheck = ej.proxy(this._onCheckedStateModified, this);
            this._tableTreeObj.model.nodeUncheck = ej.proxy(this._onCheckedStateModified, this);
            this._tableTreeObj.element.find(".attributeCDB").parent().siblings("ul").remove();
            this._tableTreeObj.element.find(".attributeCDB").siblings(".e-plus").remove();
            this._tableTreeObj.element.find(".hierarchyCDB").parent().siblings("ul").find(".e-chkbox-wrap").remove();
			if(this._tableTreeObj.element.find(".e-plus").length == 0){
             this._tableTreeObj.element.find(".e-item").css("padding","0px");
             } 
            this.element.find(".schemaFilter, .schemaColumn, .schemaRow, .schemaValue").ejDroppable({
            });
            var contextTag = ej.buildTag("ul.pivotTreeContext#pivotTreeContext", ej.buildTag("li", ej.buildTag("a", "Add to Report Filter")[0].outerHTML)[0].outerHTML + ej.buildTag("li", ej.buildTag("a", "Add to Row Labels")[0].outerHTML)[0].outerHTML + ej.buildTag("li", ej.buildTag("a", "Add to Column Labels")[0].outerHTML)[0].outerHTML + ej.buildTag("li", ej.buildTag("a", "Add to Values")[0].outerHTML)[0].outerHTML)[0].outerHTML;
            $(this.element).append(contextTag);
            $("#pivotTreeContext").ejMenu({
                menuType: ej.MenuType.ContextMenu,
                openOnClick: false,
                contextMenuTarget: this._tableTreeObj.element[0],
                click: ej.proxy(this._onTreeContextClick, this),
                beforeOpen: ej.proxy(this._onContextOpen, this)
            });
            this._unWireEvents();
            this._wireEvents();
        },

        _setFirst: true,

        /**
        * To configure the properties at runtime using SetModel		
        * @private
        */
        _setModel: function (options) {
            for (var key in options) {
                switch (key) {
                    case "OlapReport": this.setOlapReport(options[key]); break;
                }
            }
        },

        /**
        * This function is invoked to wire the events for UI interaction.
        *
        * @private  
        */
        _wireEvents: function () {
            if (this.model.layout != "excel") {
                this._on(this.element, "mouseover", ".pivotButton .pvtBtn", ej.proxy(function (evt) {
                    $(evt.target.parentNode).find("span.removePivotBtn").css("display", "inline-block");
                }, this));
                this._on(this.element, "mouseleave", ".pivotButton", ej.proxy(function (evt) {
                    this.element.find(".pivotButton > span.removePivotBtn").css("display", "none");
                }, this));
            }
            else {
                this._on(this.element, "mouseover", ".pivotButton .pvtBtn", ej.proxy(function (evt) {
                    if (this._isDragging) {
                        this.element.find(".dropIndicator").removeClass("dropIndicatorHover");
                        $(evt.target).siblings(".dropIndicator").addClass("dropIndicatorHover");
                    }
                }, this));
                this._on(this.element, "mouseleave", ".pivotButton", ej.proxy(function (evt) {
                    if (this._isDragging)
                        $(evt.target).siblings(".dropIndicator").removeClass("dropIndicatorHover");
                }, this));
            }
            this._tableTreeObj.element.find("li").mouseover(ej.proxy(function (evt) {
                $(evt.target).siblings("span.e-icon.treeDrop:eq(0)").length > 0 ? $(evt.target).siblings("span.e-icon.treeDrop:eq(0)").css({ display: "inline-block", color: "#5c5c5c", "margin-left": "-20px", "margin-top": "3px", "position": "absolute" }) : $(evt.target).find("span.e-icon.treeDrop:eq(0)").length > 0 ? $(evt.target).find("span.e-icon.treeDrop:eq(0)").css({ display: "inline", color: "#5c5c5c" }) : $(evt.target).parentsUntil("li").find("span.e-icon.treeDrop:eq(0)").css({ display: "inline", color: "#5c5c5c" });
                if ($(evt.target).parent().find(".measureGroupCDB, .dimensionCDB, .folderCDB").length > 0)
                    $(evt.target).css("cursor", "default");
            }, this))
          .mouseout(ej.proxy(function (evt) {
              $(this._tableTreeObj.element).find("span.e-icon.treeDrop").css({ display: "none" });
          }, this));
            this._on(this.element, "click", ".filterBtn", ej.proxy(this._onFilterBtnClick, this));
            this._on(this.element, "click", ".removePivotBtn", ej.proxy(this._onRemoveBtnClick, this));
            this._on(this._tableTreeObj.element, "click", ".treeDrop", ej.proxy(this._onFilterBtnClick, this));
        },

        /**
        * This function is invoked to unwire the events registered for UI interaction.
        *
        * @private  
        */
        _unWireEvents: function () {
            this._off(this.element, "click", ".filterBtn");
            this._off(this.element, "mouseover", ".pivotButton");
            this._off(this.element, "mouseover", ".pivotButton .pvtBtn");
            this._off(this.element, "mouseleave", ".pivotButton");
            this._off(this.element, "mouseover", ".schemaFieldTree li");
            this._off(this.element, "mouseout", ".schemaFieldTree li");
            this._off(this._tableTreeObj.element, "click", ".treeDrop");
        },

        /**
        * To get the localized labels.
        * @private
        */
        //get Localization text
        _getLocalizedLabels: function (property) {
            return ej.PivotGrid.localization[this.localization()][property] === undefined ? ej.PivotGrid.localization["en-US"][property] : ej.PivotGrid.localization[this.localization()][property];
        },

        _setTableFields: function (items) {
            if (!ej.isNullOrUndefined(items))
                this.model.pivotTableFields = items;
        },

        _setPivotRows: function (items) {
            if (!ej.isNullOrUndefined(items))
                this.model.pivotRows = items;
        },

        _setPivotColumns: function (items) {
            if (!ej.isNullOrUndefined(items))
                this.model.pivotColumns = items;
        },

        _setPivotCalculations: function (items) {
            if (!ej.isNullOrUndefined(items))
                this.model.pivotCalculations = items;
        },

        _setFilters: function (items) {
            if (!ej.isNullOrUndefined(items))
                this.model.filters = items;
        },

        _getSortedHeaders: function () {
            var labels = this.element.find(".descending").parents("label"), headers = "";
            for (var i = 0; i < labels.length; i++)
                headers += $(labels[i]).attr("for").replace("toggleBtn", "") + "##";
            return headers;
        },

        _onContextOpen: function (args) {
            if ($(args.target.parentElement).find(".measureGroupCDB").length > 0 || $(args.target.parentElement).find(".folderCDB").length > 0 || $(args.target.parentElement).find(".dimensionCDB").length > 0)
                return false;
            else if (this._dataModel == "Olap")
                this._selectedMember = $(args.target).parents("li:eq(0)").attr("tag");
            else if (this._dataModel == "Pivot")
                this._selectedMember = args.target.text;
        },

        _onNodeDrag: function (args) {
            this._isDragging = true;
            if ($(args.target.parentElement).find(".measureGroupCDB").length > 0 || $(args.target.parentElement).find(".folderCDB").length > 0 || $(args.target.parentElement).find(".dimensionCDB").length > 0)
                return false;
        },

        _onTreeContextClick: function (args) {
            var headerTag, filterTag, filterItems = "",
            selectedPvtBtn = this.element.find(".pivotButton:contains(" + this._selectedMember + ")"),
            isFiltered = $(selectedPvtBtn).find(".filterIndicator").length > 0 ? true : false,
            isSorted = $(selectedPvtBtn).find("~ span:eq(0) span.descending").length > 0 ? true : false, report, axisName,
            params, eventArgs;
            selectedTreeNode = _pivotProxy._getNodeByUniqueName(this._selectedMember);
            this._droppedClass = args.events.text == "Add to Report Filter" ? "schemaFilter" : args.events.text == "Add to Row Labels" ? "schemaRow" :
            args.events.text == "Add to Column Labels" ? "schemaColumn" : args.events.text == "Add to Values" ? "schemaValue" : "";
            for (var i = 0; i < this.model.pivotTableFields.length; i++) {
                if (this.model.pivotTableFields[i].name == this._selectedMember) {
                    this.model.pivotTableFields[i].isSelected = true;
                    headerTag = this.model.pivotTableFields[i];
                }
            }
            if (!ej.isNullOrUndefined(this._tempFilterData)) {
                for (var i = 0; i < this._tempFilterData.length; i++) {
                    if (!ej.isNullOrUndefined(this._tempFilterData[i][this._selectedMember])) {
                        for (var j = 0; j < this._tempFilterData[i][this._selectedMember].length; j++)
                            filterItems += "##" + this._tempFilterData[i][this._selectedMember][j];
                    }
                }
            }
            if (selectedPvtBtn.length > 1)
                for (var i = 0; i < selectedElement.length; i++) {
                    if ($(selectedPvtBtn[i]).text() == this._selectedMember)
                        $(selectedPvtBtn[i]).remove();
                }
            else
                $(selectedPvtBtn).remove();
            try {
                report = JSON.parse(this.model.pivotControl.getOlapReport()).Report;
            }
            catch (err) {
                report = this.model.pivotControl.getOlapReport();
            }
            if (this._dataModel == "Olap") {
                _pivotProxy._nodeDropedParams = this._droppedClass == "schemaFilter" ? "Slicer" : this._droppedClass == "schemaColumn" ? "Categorical" : this._droppedClass == "schemaRow" ? "Series" : "";
                if (this._droppedClass == "schemaValue") {
                    var tempAxis = this.element.find(".pivotButton:contains('Measures')").parents(".e-droppable").className.split(" ")[0];
                    _pivotProxy._nodeDropedParams = tempAxis == "schemaColumn" ? "Categorical" : tempAxis == "schemaRow" ? "Series" : "";
                }
                this._tableTreeObj.checkNode(selectedTreeNode);
                _pivotProxy._nodeDropedParams = "";
            }
            else {
                if (selectedTreeNode.find(".e-chk-inact").length > 0)
                    this._tableTreeObj.checkNode(selectedTreeNode);
                else {
                    this._createPivotButton(this._selectedMember, this._droppedClass == "schemaRow" ? "row" : this._droppedClass == "schemaColumn" ? "column" : this._droppedClass == "schemaFilter" ? "filter" : this._droppedClass == "schemaValue" ? "value" : "", isFiltered, isSorted, "");
                    eventArgs = JSON.stringify({ "action": "nodeDropped", "dropAxis": this._droppedClass + "::", "headerTag": JSON.stringify(headerTag), "sortedHeaders": this._getSortedHeaders(), "currentReport": report });
                    if (!ej.isNullOrUndefined(ogridWaitingPopup))
                        ogridWaitingPopup.show();
                    this.model.pivotControl.doAjaxPost("POST", this.model.pivotControl.model.url + "/" + this.model.serviceMethods.nodeDropped, eventArgs, this.model.pivotControl._renderControlSuccess);
                }
            }
        },

        _onSortBtnClick: function (args) {
            var serializedCustomObject = JSON.stringify(this.model.customObject),
            headers = this._getSortedHeaders();
            var eventArgs = this.model.customObject != {} && headers != "" ? JSON.stringify({ "action": "sorting", "sortedHeaders": headers, "currentReport": this.model.pivotControl.getOlapReport(), "customObject": serializedCustomObject }) :
            this.model.customObject != {} ? JSON.stringify({ "action": "sorting", "currentReport": this.model.pivotControl.getOlapReport(), "customObject": serializedCustomObject }) :
            headers != "" ? JSON.stringify({ "action": "sorting", "sortedHeaders": headers, "currentReport": this.model.pivotControl.getOlapReport() }) : JSON.stringify({ "action": "sorting" });
            if (!ej.isNullOrUndefined(ogridWaitingPopup))
                ogridWaitingPopup.show();
            this.model.pivotControl.doAjaxPost("POST", this.model.pivotControl.model.url + "/" + this.model.pivotControl.model.serviceMethods.sorting, eventArgs, this.model.pivotControl._renderControlSuccess);
        },

        _onFilterBtnClick: function (args) {
            $(this._tableTreeObj.element).find("span.e-icon.treeDrop").css({ display: "none" });
            this._selectedTreeNode = $($(args.target).parent()).parent();
            if (args.target.tagName.toLowerCase() == "span") {
                this.model.layout != "excel" ? this._curFilteredText = $($(args.target).parents(".pivotButton")).find(".pvtBtn").text() : this._curFilteredText = $(args.target).parent().text();
                if ($(args.target).parents("li:eq(1)").children().children("span").hasClass("hierarchyCDB")) {
                    this._curFilteredText = $($(args.target).parents("li:eq(1)")).children().find(".e-text")[0].innerHTML;
                }
                if (this._dataModel == "Pivot")
                this._curFilteredAxis = !ej.isNullOrUndefined(this.element.find(".e-btn:contains('" + this._curFilteredText + "')").parents(".e-droppable")[0]) ? this.element.find(".e-btn:contains('" + this._curFilteredText + "')").parents(".e-droppable")[0].className.split(" ")[0] : "";
                this._dialogTitle = this._dataModel == "Olap" ? $(this.element.find(".pivotButton:contains('" + $(args.target).parent().text() + "')")[0]).attr("tag") : $(args.target).parent().text() || args.target.id.replace("filterBtn", "") || $(args.target).parents(".filterBtn")[0].id.replace("filterBtn", "");
                if (this._dataModel == "Olap")
                for (var btnCount = 0 ; btnCount < this.element.find(".e-btn").length; btnCount++) {
                    if (!ej.isNullOrUndefined($($($(this.element.find(".e-btn"))[btnCount]).parent()[0]).attr("tag")) && $($($(this.element.find(".e-btn"))[btnCount]).parent()[0]).attr("tag").indexOf(this._curFilteredText) > -1) {
                        this._curFilteredAxis = !ej.isNullOrUndefined($($(this.element.find(".e-btn"))[0]).parents(".e-droppable")[0]) ? $($(this.element.find(".e-btn"))[0]).parents(".e-droppable")[0].className.split(" ")[0] : "";
                        this._dialogTitle = $($($(this.element.find(".e-btn"))[btnCount]).parent()[0]).attr("tag");
                    }
                }
                var report;
                try {
                    report = JSON.parse(this.model.pivotControl.getOlapReport()).Report;
                }
                catch (err) {
                    report = this.model.pivotControl.getOlapReport();
                }
                sortedHeaders = this._getSortedHeaders();
                eventArgs = JSON.stringify({ "action": "fetchMembers", "headerTag": this._dialogTitle || "UniqueName##" + $($(args.target).parents("li")[0]).attr("tag"), "sortedHeaders": sortedHeaders, "currentReport": report });
                if (!ej.isNullOrUndefined(pschemaDesignerWaitingPopup))
                    pschemaDesignerWaitingPopup.show();
                this.doAjaxPost("POST", this.model.pivotControl.model.url + "/" + this.model.serviceMethods.fetchMembers, eventArgs, this._fetchMemberSuccess);
            }
        },

        _onRemoveBtnClick: function (args) {
            var headerText = $(args.target.parentElement).text(),
            selectedTreeNode = $($(this._tableTreeObj.element).find("div:contains(" + headerText + ")>span")[1]).find(".e-chk-act"),
            headerTag;
            $(selectedTreeNode).removeClass("e-chk-act").addClass("e-chk-inact");
            $(selectedTreeNode).children("e-chk-activeicon").removeClass("e-chk-activeicon");
            for (var i = 0; i < this.model.pivotTableFields.length; i++) {
                if (this.model.pivotTableFields[i].FieldHeader == headerText) {
                    this.model.pivotTableFields[i].IsSelected = false;
                    headerTag = this.model.pivotTableFields[i];
                }
            }
            $(args.target.parentElement).remove();
            var eventArgs = JSON.stringify({ "action": "nodeStateModified", "headerTag": JSON.stringify(headerTag), "sortedHeaders": this._getSortedHeaders(), "currentReport": this.model.pivotControl.getOlapReport() });
            if (!ej.isNullOrUndefined(ogridWaitingPopup))
                ogridWaitingPopup.show();
            this.model.pivotControl.doAjaxPost("POST", this.model.pivotControl.model.url + "/" + this.model.serviceMethods.nodeStateModified, eventArgs, this.model.pivotControl._renderControlSuccess);
        },

        _onNodeCheckChanges: function (args) {
            if (args.value == "(All)" && args.type == "nodeUncheck") {
                this._memberTreeObj.model.nodeCheck = "";
                this._memberTreeObj.model.nodeUncheck = "";
                this.element.find(".editorTreeView").ejTreeView("unCheckAll");
                this._memberTreeObj.model.nodeCheck = ej.proxy(this._onNodeCheckChanges, this);
                this._memberTreeObj.model.nodeUncheck = ej.proxy(this._onNodeCheckChanges, this);
                this._dialogOKBtnObj.disable();
            }
            else if (args.value == "(All)" && args.type == "nodeCheck") {
                this._memberTreeObj.model.nodeCheck = "";
                this._memberTreeObj.model.nodeUncheck = "";
                this.element.find(".editorTreeView").ejTreeView("checkAll");
                $(this._memberTreeObj.element.find("li:first")).find("div .e-chkbox-small > span > span:eq(0)").removeClass("e-chk-indetericon");
                this._memberTreeObj.model.nodeCheck = ej.proxy(this._onNodeCheckChanges, this);
                this._memberTreeObj.model.nodeUncheck = ej.proxy(this._onNodeCheckChanges, this);
                this._dialogOKBtnObj.enable();
            }
            else if (args.value != "(All)") {
                var uncheckedNodes = this._memberTreeObj.element.find(":input:gt(0).nodecheckbox:not(:checked)"),
                firstNode = $(this._memberTreeObj.element.find("li:first")).find("div .e-chkbox-small > span > span:eq(0)");
                if (uncheckedNodes.length == 0 || (uncheckedNodes.length == 1 && uncheckedNodes[0].id[uncheckedNodes[0].id.length - 1] == 0)) {
                    $(firstNode).parent().removeClass("e-chk-inact").removeClass("e-chk-ind").addClass("e-chk-act");
                    firstNode.removeClass("e-chk-indetericon").addClass("e-chk-activeicon");
                }
                else if (args.type == "check" && uncheckedNodes.length == 1 && uncheckedNodes[0].id[uncheckedNodes[0].id.length - 1] == 0)
                    firstNode.removeClass("e-chk-indetericon").addClass("e-chk-activeicon");
                else if (uncheckedNodes.length > 0)
                    firstNode.removeClass("e-chk-activeicon").addClass("e-chk-indetericon");
                this._dialogOKBtnObj.enable();
                if (args.type == "uncheck" && uncheckedNodes.length + 1 == this._memberTreeObj.element.find("li").length) {
                    firstNode.removeClass("e-chk-activeicon").removeClass("e-chk-indetericon");
                    this._dialogOKBtnObj.disable();
                }
            }
        },

        _onCheckedStateModified: function (args) {
            var headerText = $(args.currentElement).find("a")[0].textContent, filterTag = "", filterItems = "", selectedElement = "", headerTag = "", uniqueName = "";
            if (this._dataModel == "Olap") {
                if (!args.currentElement[0].id.indexOf("[Measures]") > -1)
                for (var i = 0; i < _pivotProxy.element.find(".pivotButton").length; i++) {
                    headerTag = $(_pivotProxy.element.find(".pivotButton")[i]).attr("tag"); uniqueName = "";
                    uniqueName = ((headerTag.indexOf("[Measures]") > -1) || (headerTag.indexOf("[") > -1)) ? headerTag.split(":")[1] : this._getNodeUniqueName(headerTag);
                    if ($(args.currentElement).attr("tag") == uniqueName) {
                        selectedElement = $(_pivotProxy.element.find(".pivotButton")[i]);
                        break;
                    }
                }
                else
                    selectedElement = _pivotProxy.element.find(".pivotButton:contains(" + headerText + ")"), headerTag, report;
            }
            else
                selectedElement = _pivotProxy.element.find(".pivotButton:contains(" + headerText + ")"), headerTag, report;
            var isFiltered = selectedElement.length > 0 && $(selectedElement).siblings(".filterIndicator").length > 0 ? true : false,
            isSorted = args.currentElement.find("~ span:eq(0) span.descending").length > 0 ? true : false;
            for (var i = 0; i < _pivotProxy.model.pivotTableFields.length; i++) {
                if (_pivotProxy.model.pivotTableFields[i].name == headerText && args.type == "nodeCheck") {
                    _pivotProxy.model.pivotTableFields[i].isSelected = true;
                    headerTag = _pivotProxy.model.pivotTableFields[i];
                }
                else if (this.model.pivotTableFields[i].name == headerText && args.type == "nodeUncheck") {
                    _pivotProxy.model.pivotTableFields[i].isSelected = false;
                    headerTag = _pivotProxy.model.pivotTableFields[i];
                }
            }
            if (ej.isNullOrUndefined(headerTag))
                headerTag = $(args.currentElement).attr("tag");

            if (args.type == "nodeUncheck") {
                if (selectedElement.length > 1)
                    for (var i = 0; i < selectedElement.length; i++) {
                        if ($(selectedElement[i]).text() == headerText)
                            $(selectedElement[i]).remove();
                    }
                else
                    $(selectedElement).remove();
            }
            else {
                if (this._droppedClass != "")
                    this._createPivotButton(headerText, this._droppedClass == "schemaColumn" ? "column" : this._droppedClass == "schemaRow" ? "row" : this._droppedClass == "schemaValue" ? "value" : this._droppedClass == "schemaFilter" ? "filter" : "", isFiltered, isSorted, "");
                else
                    this._createPivotButton(headerText, ((this._dataModel == "Olap" && $(args.currentElement).attr("tag").indexOf("[Measures]") < 0) || (this._dataModel == "Pivot" && headerTag.pivotType == "PivotItem")) ? "row" : "value", isFiltered, isSorted, "");
            }
            if (!ej.isNullOrUndefined(this._tempFilterData)) {
                for (var i = 0; i < this._tempFilterData.length; i++) {
                    if (!ej.isNullOrUndefined(this._tempFilterData[i][headerText])) {
                        for (var j = 0; j < this._tempFilterData[i][headerText].length; j++)
                            filterItems += "##" + this._tempFilterData[i][headerText][j];
                    }
                }
            }
            try {
                report = JSON.parse(this.model.pivotControl.getOlapReport()).Report;
            }
            catch (err) {
                report = this.model.pivotControl.getOlapReport();
            }
            filterTag = "schemaRow::" + headerText + "::FILTERED" + filterItems;
            var dropAxis = this._droppedClass != "" ? this._droppedClass : headerTag.pivotType == "PivotItem" ? "schemaRow" : "schemaValue", eventArgs, axisName, params;
            this._droppedClass = "";
            if (!ej.isNullOrUndefined(ogridWaitingPopup))
                ogridWaitingPopup.show();
            if (!(args.type == "nodeCheck") && !(args.type == "nodeUncheck") && dropAxis != "") {
                if (_pivotProxy._dataModel == "Pivote") {
                    eventArgs = JSON.stringify({ "action": "nodeStateModified", "headerTag": JSON.stringify(headerTag), "dropAxis": dropAxis + "::" + this._droppedPosition, "sortedHeaders": this._getSortedHeaders(), "filterParams": filterTag, "currentReport": report });
                    _pivotProxy._droppedPosition = "";
                    _pivotProxy.model.pivotControl.doAjaxPost("POST", this.model.pivotControl.model.url + "/" + this.model.serviceMethods.nodeStateModified, eventArgs, this.model.pivotControl._renderControlSuccess);
                }
                else {
                    if ($(args.currentElement).attr("tag").indexOf("[Measures]") == -1) {
                        var dropSpan = ej.buildTag("span.e-icon", { "display": "none" }).addClass("treeDrop")[0].outerHTML;
                        $(args.currentElement.find(".e-text")[0]).after(dropSpan);
                    }
                    headerTag = $(args.currentElement).attr("tag");
                    axisName = this._nodeDropedParams == "" ? ($(args.currentElement).attr("tag").indexOf("[Measures]") >= 0 ? "Categorical" : "Series") : this._nodeDropedParams;
                    params = this._currentCubeName + "--" + headerTag + "--" + axisName + "--", report;
                    eventArgs = JSON.stringify({ "action": "nodeDropped", "dropType": "TreeNode", "nodeInfo": params, "currentReport": report });
                    this.doAjaxPost("POST", this.model.pivotControl.model.url + "/" + this.model.serviceMethods.nodeDropped, eventArgs, this._onDroppedSuccess);
                }
            }
            else if (args.type == "nodeCheck") {
                if (this._dataModel == "Olap") {
                    if ($(args.currentElement).attr("tag").indexOf("[Measures]") == -1) {
                        var dropSpan = ej.buildTag("span.e-icon", { "display": "none" }).addClass("treeDrop")[0].outerHTML;
                        $(args.currentElement.find(".e-text")[0]).after(dropSpan);
                    }
                    headerTag = $(args.currentElement).attr("tag");
                    axisName = this._nodeDropedParams == "" ? ($(args.currentElement).attr("tag").indexOf("[Measures]") >= 0 ? "Categorical" : "Series") : this._nodeDropedParams;
                    params = this._currentCubeName + "--" + headerTag + "--" + axisName + "--", report;
                    eventArgs = JSON.stringify({ "action": "nodeDropped", "dropType": "TreeNode", "nodeInfo": params, "currentReport": report });
                    this.doAjaxPost("POST", this.model.pivotControl.model.url + "/" + this.model.serviceMethods.nodeDropped, eventArgs, this._onDroppedSuccess);
                }
                else {
                    eventArgs = JSON.stringify({ "action": "nodeStateModified", "headerTag": JSON.stringify(headerTag), "dropAxis": dropAxis + "::", "sortedHeaders": this._getSortedHeaders(), "filterParams": filterTag, "currentReport": report });
                    this.model.pivotControl.doAjaxPost("POST", this.model.pivotControl.model.url + "/" + this.model.serviceMethods.nodeStateModified, eventArgs, this.model.pivotControl._renderControlSuccess);
                }
            }
            else if (args.type == "nodeUncheck") {
                if (this._dataModel == "Olap") {
                    $(args.currentElement.find(".treeDrop")).remove();
                    $(args.currentElement.find(".e-icon")).remove();
                    $(args.currentElement).removeClass("filter");
                    var headerTag = $(selectedElement).attr("tag"), report, eventArgs;
                    eventArgs = JSON.stringify({ "action": "removeButton", "headerInfo": headerTag, "currentReport": report });
                    if (ej.isNullOrUndefined(headerTag))
                        return false;
                    if ( headerTag.indexOf("[Measures]") >= 0 && _pivotProxy.element.find(".schemaValue .pivotButton").length == 0) {
                        var tmp = headerTag.split(":"),
                        tempAxis = tmp[0] == "Rows" ? ".schemaRow" : tmp[0] == "Columns" ? ".schemaColumn" : "";
                        _pivotProxy.element.find(tempAxis + " .pivotButton:contains('Measures')").remove();
                    }
                    else if (headerTag.indexOf("[Measures]") < 0 && headerTag.indexOf("Measures") >= 0)
                        _pivotProxy.element.find(".schemaValue .pivotButton").remove();
                    this.model.pivotControl.doAjaxPost("POST", _pivotProxy.model.pivotControl.model.url + "/" + _pivotProxy.model.serviceMethods.removeButton, eventArgs, _pivotProxy.model.pivotControl._renderControlSuccess)
                }
                else {
                    eventArgs = JSON.stringify({ "action": "nodeStateModified", "headerTag": JSON.stringify(headerTag), "dropAxis": dropAxis + "::", "sortedHeaders": _pivotProxy._getSortedHeaders(), "filterParams": filterTag, "currentReport": report });
                    _pivotProxy.model.pivotControl.doAjaxPost("POST", _pivotProxy.model.pivotControl.model.url + "/" + _pivotProxy.model.serviceMethods.nodeStateModified, eventArgs, _pivotProxy.model.pivotControl._renderControlSuccess);
                }
            }
        },

        _onNodeDropped: function (args) {
            if (args.target.context.className.indexOf("e-droppable") >= 0) {
                this._isDragging = false;
                this.element.find(".dropIndicator").removeClass("dropIndicatorHover");
                var headerTag = $(args.dropedElement).parents("li:eq(0)").attr("tag"), headerText = args.dropedElement.text(), filterTag, filterItems = "", report,
                    selectedPvtBtn = this.element.find(".pivotButton:contains(" + headerText + ")"),
                    selectedTreeNode = this._tableTreeObj.element.find("li:contains('" + headerText + "'):last"),
                    isFiltered = $(selectedPvtBtn).find(".filterIndicator").length > 0 ? true : false,
                    isSorted = $(selectedPvtBtn).find("~ span:eq(0) span.descending").length > 0 ? true : false;

                this._droppedClass = args.event.target.className.split(" ")[0];
                if (this._dataModel == "Olap") {
                    selectedTreeNode = this._tableTreeObj.element.find("li[tag='" + headerTag + "']")
                }
                if (headerTag.split('.').length > 2) {
                    var tagName = headerTag.split('.')[0] + "." + headerTag.split('.')[1];
                    selectedTreeNode = this._tableTreeObj.element.find("li[tag='" + tagName + "']");
                }

                if (selectedTreeNode.find(".e-chk-inact").length > 0 && (this._droppedClass != "" && (this._droppedClass == "schemaRow" || this._droppedClass == "schemaColumn" || this._droppedClass == "schemaFilter" || this._droppedClass == "schemaValue"))) {
                    this._tableTreeObj.checkNode(selectedTreeNode);
                    return false;
                }
                if (ej.isNullOrUndefined(headerTag))
                    for (var i = 0; i < this.model.pivotTableFields.length; i++) {
                        if (this.model.pivotTableFields[i].name == headerText) {
                            this.model.pivotTableFields[i].isSelected = true;
                            headerTag = this.model.pivotTableFields[i];
                        }
                    }
                if (!ej.isNullOrUndefined(this._tempFilterData))
                    for (var i = 0; i < this._tempFilterData.length; i++) {
                        if (!ej.isNullOrUndefined(this._tempFilterData[i][headerText])) {
                            for (var j = 0; j < this._tempFilterData[i][headerText].length; j++)
                                filterItems += "##" + this._tempFilterData[i][headerText][j];
                        }
                    }
                if (args.dropedElement[0].tagName.toLowerCase() == "button") {
                    if (selectedPvtBtn.length > 1)
                        for (var i = 0; i < selectedPvtBtn.length; i++) {
                            if ($(selectedPvtBtn[i]).text() == headerText)
                                $(selectedPvtBtn[i]).remove();
                        }
                    else
                        $(selectedPvtBtn).remove();
                }
                try {
                    report = JSON.parse(this.model.pivotControl.getOlapReport()).Report;
                }
                catch (err) {
                    report = this.model.pivotControl.getOlapReport();
                }
                if (this._dataModel == "Pivot") {
                    if (ej.isNullOrUndefined(headerTag) || headerTag == "undefined")
                        for (var i = 0; i < this.model.pivotTableFields.length; i++) {
                            if (this.model.pivotTableFields[i].name == headerText) {
                                this.model.pivotTableFields[i].isSelected = true;
                                headerTag = this.model.pivotTableFields[i];
                                $(selectedPvtBtn).remove();
                                break;
                            }
                        }
                    var droppedPosition = this._droppedPosition = this._setSplitBtnTargetPos(args.event);
                    this._createPivotButton(headerText, this._droppedClass == "schemaRow" ? "row" : this._droppedClass == "schemaColumn" ? "column" : this._droppedClass == "schemaFilter" ? "filter" : this._droppedClass == "schemaValue" ? "value" : "", isFiltered, isSorted, droppedPosition);
                    if (selectedTreeNode.find(".e-chk-inact").length > 0 && (this._droppedClass != "" && (this._droppedClass == "schemaRow" || this._droppedClass == "schemaColumn" || this._droppedClass == "schemaFilter" || this._droppedClass == "schemaValue")))
                        this._tableTreeObj.checkNode(selectedTreeNode);
                    else {
                    var eventArgs = JSON.stringify({ "action": "nodeDropped", "dropAxis": this._droppedClass + "::" + droppedPosition, "headerTag": JSON.stringify(headerTag), "sortedHeaders": this._getSortedHeaders(), "currentReport": report });
                        if (!ej.isNullOrUndefined(ogridWaitingPopup))
                            ogridWaitingPopup.show();
                        this.model.pivotControl.doAjaxPost("POST", this.model.pivotControl.model.url + "/" + this.model.serviceMethods.nodeDropped, eventArgs, this.model.pivotControl._renderControlSuccess);
                    }
                }
                else {
                    var axis = args.target[0].className == "pivotButton" ? $(args.target).parents()[0] : args.target[0].tagName.toLowerCase() == "td" ? args.target.children(":last")[0] : args.target;
                    this._droppedClass = axis.className.split(" ")[0];
                    var axisName = axis.className.split(" ")[0] == "schemaColumn" ? "Categorical" : axis.className.split(" ")[0] == "schemaRow" ? "Series" : axis.className.split(" ")[0] == "schemaFilter" ? "Slicer" : "";
                    if (axisName == "" && args.dropedElement.parents("li:eq(0)").attr("tag").toUpperCase().indexOf("[MEASURES]") > -1)
                        axisName = (this.element.find(".schemaRow .pivotButton:contains('Measures')").length > 0 || this.element.find(".schemaRow .pivotButton:contains('MEASURES')").length > 0) ? "Series" : "Categorical";
                    var droppedPosition = this._setSplitBtnTargetPos(args.event);
                    //this._createPivotButton(headerText, this._droppedClass == "schemaRow" ? "row" : this._droppedClass == "schemaColumn" ? "column" : this._droppedClass == "schemaFilter" ? "filter" : this._droppedClass == "schemaValue" ? "value" : "", isFiltered, isSorted, droppedPosition);
                    var params = this._currentCubeName + "--" + headerTag + "--" + axisName + "--" + droppedPosition, filterParams = "";
                    var eventArgs = JSON.stringify({ "action": "nodeDropped", "dropType": "TreeNode", "nodeInfo": params, "filterParams": filterParams, "currentReport": report, "layout": this.model.pivotControl.model.layout });
                    if (!ej.isNullOrUndefined(ogridWaitingPopup))
                        ogridWaitingPopup.show();
                    this.doAjaxPost("POST", this.model.pivotControl.model.url + "/" + this.model.serviceMethods.nodeDropped, eventArgs, this._onDroppedSuccess);
                }
			}
        },

        _onPvtBtnDropped: function (args) {
            this._isDragging = false;
            this.element.find(".dropIndicator").removeClass("dropIndicatorHover");
            var axis = null, axisName = "", headerTag = "", headerText, droppedClass, isFiltered = false, isSorted = false;
            if (this._dataModel == "Olap") {
                axis = args.target.className.indexOf("pvtBtn") > -1 ? $(args.target).parents(".e-droppable")[0] : args.target.className.indexOf("e-droppable") ? args.target : args.target[0].tagName.toLowerCase() == "td" ? args.target.children(":last")[0] : args.target;
                axisName = axis.className.split(" ")[0] == "schemaColumn" ? "Categorical" : axis.className.split(" ")[0] == "schemaRow" ? "Series" : axis.className.split(" ")[0] == "schemaFilter" ? "Slicer" : "";
                if (axisName == "" && args.element.parent().attr("tag").indexOf("[Measures]") > -1)
                    axisName = this.element.find(".schemaRow .pivotButton:contains('Measures')").length > 0 ? "Series" : "Categorical";
                headerTag = $(args.element.parent()[0]).attr("tag");
                droppedClass = axis.className.split(" ")[0];
            }
            else {
                headerText = args.element.text(), droppedClass = args.target.className.indexOf("e-droppable") >= 0 ? args.target.className.split(" ")[0] : "",
                    headerTag, isFiltered = args.element.find("~ .filterIndicator").length > 0 ? true : false,
                    isSorted = args.element.find("~ span:eq(0) span.descending").length > 0 ? true : false;
                for (var i = 0; i < this.model.pivotTableFields.length; i++) {
                    if (this.model.pivotTableFields[i].name == headerText) {
                        this.model.pivotTableFields[i].isSelected = true;
                        headerTag = this.model.pivotTableFields[i];
                    }
                }
            }
            this.element.find(".dragClone").remove();
            if (droppedClass == "schemaValue" || droppedClass == "schemaRow" || droppedClass == "schemaColumn" || droppedClass == "schemaFilter") {
                var droppedPosition = this._setSplitBtnTargetPos(args.event), params, report, eventArgs;
                try {
                    report = JSON.parse(this.model.pivotControl.getOlapReport()).Report;
                }
                catch (err) {
                    report = this.model.pivotControl.getOlapReport();
                }
                $(args.element.parent()).remove();
                if (!ej.isNullOrUndefined(ogridWaitingPopup))
                    ogridWaitingPopup.show();
                if (this._dataModel == "Olap") {
                    params = this._currentCubeName + "--" + headerTag + "--" + axisName + "--" + droppedPosition;
                    eventArgs = JSON.stringify({ "action": "nodeDropped", "dropType": "SplitButton", "nodeInfo": params, "currentReport": report });
                    this.doAjaxPost("POST", this.model.pivotControl.model.url + "/" + this.model.serviceMethods.nodeDropped, eventArgs, this._onDroppedSuccess);
                }
                else {
                    this._createPivotButton(headerText, droppedClass == "schemaRow" ? "row" : droppedClass == "schemaColumn" ? "column" : droppedClass == "schemaFilter" ? "filter" : droppedClass == "schemaValue" ? "value" : "", isFiltered, isSorted, droppedPosition);
                    eventArgs = JSON.stringify({ "action": "nodeDropped", "dropAxis": droppedClass + "::" + droppedPosition, "headerTag": JSON.stringify(headerTag), "sortedHeaders": this._getSortedHeaders(), "currentReport": report });
                    successMethod = this.model.pivotControl._renderControlSuccess;
                    this.model.pivotControl.doAjaxPost("POST", this.model.pivotControl.model.url + "/" + this.model.serviceMethods.nodeDropped, eventArgs, this.model.pivotControl._renderControlSuccess);
                }
            }
            else
                this._removePvtBtn(args);
        },

        _dialogBtnClick: function (args) {
            this.element.find(".e-dialog, .clientDialog").hide();
            var unselectedNodes = "", enableFilterIndigator;
            if (args.model.text.toLowerCase() != "cancel") {
                var uncheckedNodes = this._dataModel == "Olap" ? unselectedNodes = this._getUnSelectedNodes() + "FILTERED" + this._getSelectedNodes(this._curFilteredAxis == "Filter" ? true : false) : this._memberTreeObj.element.find(":input:gt(0).nodecheckbox:not(:checked)"), isFiltered = false,
                filterParams = this._dataModel == "Olap" ? uncheckedNodes : this._curFilteredAxis + "::" + this._curFilteredText + "::FILTERED";
                var text = this._curFilteredText, textArr = new Array(), obj = {};
                enableFilterIndigator = this._getUnSelectedNodes() != "" ? true : false;
                if (this._dataModel == "Pivot") {
                    for (var i = 0; i < uncheckedNodes.length; i++)
                        textArr.push($(uncheckedNodes[i].parentElement).siblings("a").text());
                    obj[text] = textArr;
                    if (ej.isNullOrUndefined(this._tempFilterData))
                        this._tempFilterData = new Array();
                    for (var i = 0; i < this._tempFilterData.length; i++) {
                        if (!ej.isNullOrUndefined(this._tempFilterData[i][text])) {
                            this._tempFilterData[i][text] = textArr;
                            isFiltered = true;
                        }
                    }
                    if (!isFiltered)
                        this._tempFilterData.push(obj);
                    if (ej.isNullOrUndefined(this._curFilteredAxis) || this._curFilteredAxis != "") {
                        for (var i = 0; i < uncheckedNodes.length; i++)
                            filterParams += "##" + $(uncheckedNodes[i].parentElement).siblings("a").text();
                    }
                }
                else {
                    obj[this._curFilteredText] = filterParams;
                    if (ej.isNullOrUndefined(this._tempFilterData))
                        this._tempFilterData = new Array();
                    for (var i = 0; i < this._tempFilterData.length; i++) {
                        if (!ej.isNullOrUndefined(this._tempFilterData[i][this._curFilteredText])) {
                            this._tempFilterData[i][this._curFilteredText] = textArr;
                            isFiltered = true;
                        }
                    }
                    if (!isFiltered)
                        this._tempFilterData.push(obj);
                }
                var sortedHeaders = this._getSortedHeaders(),
                filteredBtn = this.model.layout == "excel" ? this.element.find(".schemaFieldTree li:contains('" + this._curFilteredText + "')") : this.element.find("." + this._curFilteredAxis + " .pivotButton:contains(" + this._curFilteredText + ") .filterBtn");
                if (this.model.layout == "excel") {
                    if ($(_pivotProxy._selectedTreeNode).parents("li:eq(0)").children().children("span").hasClass("hierarchyCDB")) {
                        _pivotProxy._selectedTreeNode = $($(_pivotProxy._selectedTreeNode).parents("li:eq(0)"));
                    }
                    if (enableFilterIndigator && $($(_pivotProxy._selectedTreeNode)).find(".filter").length <= 0) {
                        var filterSpan = ej.buildTag("span.e-icon", { "display": "none" }).addClass("filter")[0].outerHTML;
                        $($(_pivotProxy._selectedTreeNode).find(".e-text")[0]).after(filterSpan);
                    }
                    else if (!enableFilterIndigator)
                        $(_pivotProxy._selectedTreeNode).find(".filter").remove();
                    if (this._curFilteredAxis == "")
                        return false;
                }
                var report;
                try {
                    report = JSON.parse(this.model.pivotControl.getOlapReport()).Report;
                }
                catch (err) {
                    report = this.model.pivotControl.getOlapReport();
                }
                var serializedCustomObject = JSON.stringify(this.model.pivotControl.model.customObject),
                eventArgs = this.model.pivotControl.model.customObject != {} && filterParams != "" ? JSON.stringify({ "action": "filtering", "filterParams": filterParams, "sortedHeaders": sortedHeaders, "currentReport": report, "customObject": serializedCustomObject }) :
            this.model.pivotControl.model.customObject != {} ? JSON.stringify({ "action": "filtering", "currentReport": report, "customObject": serializedCustomObject }) :
            filterParams != "" ? JSON.stringify({ "action": "filtering", "filterParams": filterParams, "sortedHeaders": sortedHeaders, "currentReport": report }) : JSON.stringify({ "action": "filtering" });
                if (!ej.isNullOrUndefined(ogridWaitingPopup))
                    ogridWaitingPopup.show();
                this.model.pivotControl.doAjaxPost("POST", this.model.pivotControl.model.url + "/" + this.model.serviceMethods.filtering, eventArgs, this.model.pivotControl._renderControlSuccess);
            }
            _pivotProxy._selectedTreeNode = null;
        },

        _onNodeExpand: function (args) {
            var selectedItem = (args.event.originalEvent != undefined && args.event.originalEvent.target != undefined) ? args.event.originalEvent.target : args.event.target; var tagInfo, dimenName ="";
            var childCount = $(selectedItem).parents("li").first().children().find("li").length;
            if (selectedItem.className.indexOf("e-plus") > -1 && childCount == 0) {
                var checkedState = $(selectedItem).parent().find("input[type=checkbox]").prop("checked"), report;
                var tagInfo = $(selectedItem).parents("li").first().attr("tag");
                this.pNode = selectedItem;
                try {
                    report = JSON.parse(this.model.pivotControl.getOlapReport()).Report;
                }
                catch (err) {
                    report = this.model.pivotControl.getOlapReport();
                }
                var pivotButtons = this.element.find(".pivotButton"), parentTag;
                for (var bt = 0; bt < pivotButtons.length > 0; bt++) {
                    if ($(pivotButtons[bt]).attr("tag").indexOf(this._curFilteredText)>-1)
                        dimenName = $(pivotButtons[bt]).attr("tag");
                }
                //eventArgs = JSON.stringify({ "action": "fetchMembers", "headerTag": this._dialogTitle || "UniqueName##" + $($(args.target).parents("li")[0]).attr("tag"), "sortedHeaders": sortedHeaders, "currentReport": report });
                this.doAjaxPost("POST", this.model.pivotControl.model.url + "/" + this.model.serviceMethods.memberExpand, JSON.stringify({
                    "action": "memberExpanded", "checkedStatus": checkedState, "parentNode": $(selectedItem).parents("li")[0].id, "tag": tagInfo, "cubeName": this._currentCubeName + "##" + dimenName, "currentReport": report
                }), this._fetchChildNodeSuccess);
            }
        },

        _fetchChildNodeSuccess: function (data) {
            var newDataSource; var parentNode;
            if (data.length > 1 && data[0] != undefined)
                newDataSource = JSON.parse(data[0].Value);
            else if (data.d != undefined)
                newDataSource = JSON.parse(data.d[0].Value);
            else
                newDataSource = JSON.parse(data.ChildNodes);

            var mapper = { id: "id", parentId: "pid", hasChild: "hasChildren", text: "name", isChecked: "checkedStatus" };
            if ($(this.pNode).parents("li").length > 1)
                parentNode = $(this.pNode).parents("li").first();
            else
                parentNode = $(this.pNode).parents("li");
            $($(parentNode).find('input.nodecheckbox')[0]).ejCheckBox({ checked: false })
            this._memberTreeObj._createSubNodesWhenLoadOnDemand(newDataSource, this.pNode, mapper);
            $.each($(parentNode).children().find("li"), function (index, value) {
                value.setAttribute("tag", newDataSource[index].tag);
            });
           // this._memberTreeObj._expandCollapseAction(this.pNode);
        },

        _fetchMemberSuccess: function (msg) {
            if (msg[0] != undefined && msg.length > 0) {
                this._currentMembers = msg[0].Value;
            }
            else if (msg.d != undefined && msg.d.length > 0) {
                this._currentMembers = msg.d[0].Value;
            }
            else if (msg != undefined && msg.length > 0) {
                this._currentMembers = msg.MemberList;
            }
            this._createDialog(this._dialogTitle, this._currentMembers);
        },

        _onDroppedSuccess: function (args) {
            var report = null;
            if (!ej.isNullOrUndefined(args[0]) && args.length > 0)
                report = JSON.parse(args[1].Value);
            else if (!ej.isNullOrUndefined(args.d) && args.d.length > 0)
                report = JSON.parse(args.d[1].Value);
            else if (!ej.isNullOrUndefined(args) && args.length > 0)
                report = JSON.parse(args.OlapReport);
            this.element.find(".axisTable .pivotButton").remove();
            this._setPivotRows(report.PivotRows);
            this._setPivotColumns(report.PivotColumns);
            this._setPivotCalculations(report.PivotCalculations);
            this._setFilters(report.Filters);
            this.element.find(".axisTable .schemaFilter").append(this._createPivotButtons(this.model.filters, "filter"));
            this.element.find(".axisTable .schemaRow").append(this._createPivotButtons(this.model.pivotRows, "row"));
            this.element.find(".axisTable .schemaColumn").append(this._createPivotButtons(this.model.pivotColumns, "column"));
            this.element.find(".axisTable .schemaValue").append(this._createPivotButtons(this.model.pivotCalculations, "values"));
            this.element.find(".pivotButton .pvtBtn").ejButton({ size: "normal" }).ejDraggable({
                handle: 'button', clone: true,
                cursorAt: { left: -5, top: -5 },
                dragStart: ej.proxy(function (args) {
                    this._isDragging = true;
                }, this),
                dragStop: ej.proxy(this._onPvtBtnDropped, this),
                helper: ej.proxy(function (event, ui) {
                    if (event.sender.target.className.indexOf("e-btn") > -1)
                        return $(event.sender.target).clone().addClass("dragClone").appendTo(this.element);
                    else
                        return false;
                }, this)
            });
            this._unWireEvents();
            this._wireEvents();
            this.model.pivotControl._renderControlSuccess(args);
        },

        /**
        * 	This function is used to create the toolbar, member editor and measure editor dialogs
        *
        * @private
        */
        _removePvtBtn: function (args) {
            var headerText = args.element.text(), headerTag = args.element.parent().attr("tag"), report, eventArgs;
            try {
                report = JSON.parse(this.model.pivotControl.getOlapReport()).Report;
            }
            catch (err) {
                report = this.model.pivotControl.getOlapReport();
            }
            if (this._dataModel == "Olap") {
                var uniqueName = ((headerTag.indexOf("[Measures]") > -1) || (headerTag.indexOf("[") > -1)) ? headerTag.split(":")[1] : this._getNodeUniqueName(headerTag);
                selectedTreeNode = this._getNodeByUniqueName(uniqueName);               
                this._tableTreeObj.unCheckNode(selectedTreeNode);               
            }
            else {
                selectedTreeNode = this._tableTreeObj.element.find("li:contains('" + headerText + "')");
                this._tableTreeObj.unCheckNode(selectedTreeNode);
            }
        },

        _createDialog: function (title, treeViewData) {
            this.element.find(".e-dialog, .clientDialog").remove();
            var dialogContent = ej.buildTag("div#EditorDiv.editorDiv", ej.buildTag("div", ej.buildTag("div.memberEditorDiv", ej.buildTag("div#editorTreeView.editorTreeView")[0].outerHTML)[0].outerHTML)[0].outerHTML)[0].outerHTML + "</br>",
            dialogFooter = ej.buildTag("div", ej.buildTag("button#OKBtn.dialogOKBtn", "OK")[0].outerHTML + ej.buildTag("button#CancelBtn.dialogCancelBtn", "Cancel")[0].outerHTML, { "float": "right", "margin": "-5px 0 6px" })[0].outerHTML,
            ejDialog = ej.buildTag("div#clientDialog.clientDialog", dialogContent + dialogFooter, { "opacity": "1" }).attr("title", title)[0].outerHTML,
            treeViewData = JSON.parse(treeViewData);
            var selectedData;
            if (!ej.isNullOrUndefined(this._tempFilterData)) {
                for (var i = 0; i < this._tempFilterData.length; i++) {
                    if (!ej.isNullOrUndefined(this._tempFilterData[i][title]))
                        selectedData = this._tempFilterData[i][title];
                }
                if (!ej.isNullOrUndefined(selectedData)) {
                    for (var i = 0; i < selectedData.length; i++) {
                        for (var j = 0; j < treeViewData.length; j++) {
                            if (selectedData[i] == treeViewData[j].name)
                                treeViewData[j].checkedStatus = false;
                        }
                    }
                }
            }
            $(ejDialog).appendTo("#" + this._id);
            this.element.find(".editorTreeView").ejTreeView({
                showCheckbox: true,
                loadOnDemand: true,
                height: $(".memberEditorDiv").height(),
                fields: { id: "id", text: "name", isChecked: "checkedStatus", hasChild: "hasChildren", dataSource: treeViewData },
                nodeClick: ej.proxy(this._onNodeExpand, this)
            });
            var treeViewElements = this.element.find(".editorTreeView").find("li");
            for (var i = 0; i < treeViewElements.length; i++) {
                treeViewElements[i].setAttribute("tag", treeViewData[i].tag);
            }
            this.element.find(".dialogOKBtn, .dialogCancelBtn").ejButton({ type: ej.ButtonType.Button, click: ej.proxy(this._dialogBtnClick, this) });
            this._dialogOKBtnObj = this.element.find(".dialogOKBtn").data("ejButton");
            this._memberTreeObj = this.element.find(".editorTreeView").data("ejTreeView");
            var treeViewLi = this.element.find(".editorTreeView li:gt(0)"),
            uncheckedNodes = $(treeViewLi).find(":input.nodecheckbox:not(:checked)");
            if (uncheckedNodes.length > 0) {
                var firstNode = $(this._memberTreeObj.element.find("li:first")).find("div .e-chkbox-small > span > span:eq(0)");
                $(firstNode).removeClass("e-chk-activeicon").addClass("e-chk-indetericon");
            }
            this.element.find(".clientDialog").ejDialog({ width: 265, content: "#" + this._id, enableResize: false });
            this._memberTreeObj.model.nodeCheck = ej.proxy(this._onNodeCheckChanges, this);
            this._memberTreeObj.model.nodeUncheck = ej.proxy(this._onNodeCheckChanges, this);
			if(this._memberTreeObj.element.find(".e-plus").length == 0){
             this._memberTreeObj.element.find(".e-item").css("padding","0px");
            } 
            this._unWireEvents();
            this._wireEvents();
            if (!ej.isNullOrUndefined(pschemaDesignerWaitingPopup))
                pschemaDesignerWaitingPopup.hide();
        },
        _createPivotButton: function (text, axis, isFiltered, isSorted, dropPostion) {
            var pvtAxis = axis == "row" ? ".schemaRow" : axis == "column" ? ".schemaColumn" : axis == "value" ? ".schemaValue" : ".schemaFilter";
            var sortBtn = (axis == "column" || axis == "row") && this.model.layout != "excel" ? ej.buildTag("input#toggleBtn" + text, {}).attr("type", "checkbox")[0].outerHTML : "",
                    filterBtn = (axis == "column" || axis == "row" || axis == "filter") && this.model.layout != "excel" ? ej.buildTag("button.filterBtn#filterBtn" + text, {}).addClass(isFiltered ? "filterIndicator" : "")[0].outerHTML : "",

            rowBtn = ej.buildTag("div.pivotButton", ej.buildTag("div.dropIndicator")[0].outerHTML + ej.buildTag("button.pvtBtn#pivotButton" + text, text)[0].outerHTML +
                    sortBtn + filterBtn + ej.buildTag("span.removePivotBtn", "", { "display": "none" }).addClass("e-icon")[0].outerHTML)[0].outerHTML;
            if (typeof (dropPostion) == "number" && $(this.element.find(pvtAxis + " .pivotButton")[dropPostion]).length > 0)
                axis == "row" ? $(this.element.find(".schemaRow .pivotButton")[dropPostion]).before(rowBtn) : axis == "column" ? $(this.element.find(".schemaColumn .pivotButton")[dropPostion]).before(rowBtn) :
            axis == "value" ? $(this.element.find(".schemaValue .pivotButton")[dropPostion]).before(rowBtn) : axis == "filter" ? $(this.element.find(".schemaFilter .pivotButton")[dropPostion]).before(rowBtn) : "";
            else
                axis == "row" ? this.element.find(".schemaRow").append(rowBtn) : axis == "column" ? this.element.find(".schemaColumn").append(rowBtn) :
            axis == "value" ? this.element.find(".schemaValue").append(rowBtn) : axis == "filter" ? this.element.find(".schemaFilter").append(rowBtn) : "";
            var pvtExp = (typeof (dropPostion) != "number" && dropPostion == "") ? " .pivotButton .pvtBtn:last" : " .pivotButton .pvtBtn:eq(" + dropPostion + ")";
            this.element.find(pvtAxis + pvtExp).ejButton({ size: "normal" }).ejDraggable({
                handle: 'button', clone: true,
                cursorAt: { left: -5, top: -5 },
                dragStart: ej.proxy(function (args) {
                    this._isDragging = true;
                }, this),
                dragStop: ej.proxy(this._onPvtBtnDropped, this),
                helper: ej.proxy(function (event, ui) {
                    if (event.sender.target.className.indexOf("e-btn") > -1)
                        return $(event.sender.target).clone().addClass("dragClone").appendTo(this.element);
                    else
                        return false;
                }, this)
            });
            this.element.find(pvtAxis + " .pivotButton .filterBtn:last").ejButton({
                size: "normal",
                contentType: "imageonly",
                prefixIcon: "filter"
            });
            this.element.find(pvtAxis + " .pivotButton input:last").ejToggleButton({
                size: "normal",
                contentType: "imageonly",
                defaultPrefixIcon: "ascending",
                activePrefixIcon: "descending",
                click: ej.proxy(this._onSortBtnClick, this)
            });
            if (isSorted) {
                this.element.find(pvtAxis + " .pivotButton:contains(" + text + ") span:eq(0) span").removeClass("ascending").addClass("descending");
                this.element.find(pvtAxis + " .pivotButton:contains(" + text + ") span:eq(0) button").addClass("e-active");
            }
            this.element.find(".dropIndicator").removeClass("dropIndicatorHover");
        },

        _createPivotButtons: function (rows, axis) {
            if (!ej.isNullOrUndefined(rows)) {
                var rowBtns = "", tagAxis = axis == "column" ? "Columns" : axis == "row" ? "Rows" : axis == "filter" ? "Slicers" : "";
                if (tagAxis == "" && axis == "values") {
                    var tempAxis = this.element.find(".pivotButton:contains('Measures')").length > 0 ? this.element.find(".pivotButton:contains('Measures')").parent()[0].className.split(" ")[0] : "schemaColumn";
                    tagAxis = tempAxis == "schemaColumn" ? "Columns" : "Rows";
                }
                for (var i = 0; i < rows.length; i++) {
                    var sortBtn = (axis == "column" || axis == "row") && this.model.layout != "excel" ? ej.buildTag("input#toggleBtn" + rows[i].FieldHeader || rows[i].FieldName, {}).attr("type", "checkbox")[0].outerHTML : "",
                    filterBtn = (axis == "column" || axis == "row" || axis == "filter") && this.model.layout != "excel" ? ej.buildTag("button.filterBtn#filterBtn" + (rows[i].FieldHeader || rows[i].FieldName || rows[i].Name || rows[i].DimensionName), {})[0].outerHTML : "";
                    rowBtns += ej.buildTag("div.pivotButton", ej.buildTag("div.dropIndicator")[0].outerHTML + ej.buildTag("button.pvtBtn#pivotButton" + rows[i].FieldHeader || rows[i].FieldName || rows[i].Name || rows[i].DimensionName, rows[i].FieldHeader || rows[i].FieldName || rows[i].Name || rows[i].DimensionName)[0].outerHTML +
                    sortBtn + filterBtn + ej.buildTag("span.removePivotBtn", "", { "display": "none" }).addClass("e-icon")[0].outerHTML).attr("tag", tagAxis + ":" + rows[i].Tag)[0].outerHTML;
                }
                return rowBtns;
            }
        },

        _setSplitBtnTargetPos: function (event) {
            var targetPosition = ""; var AEBdiv; var targetSplitBtn; var className;
            if (event.event != undefined && event.event.type == "touchend") {
                targetSplitBtn = event.event.originalEvent.target != null ? $(event.event.originalEvent.target).parents(".pivotButton") : $(event.event.originalEvent.srcElement).parents(".pivotButton");
                className = event.event.originalEvent.target != null ? event.event.originalEvent.target.className : event.event.originalEvent.srcElement.className;
            }
            else {
                targetSplitBtn = event.originalEvent.target != null ? $(event.originalEvent.target).parents(".pivotButton") : $(event.originalEvent.srcElement).parents(".pivotButton");
                className = event.originalEvent.target != null ? event.originalEvent.target.className : event.originalEvent.srcElement.className;
            }
            this._droppedClass = targetSplitBtn.length > 0 ? $(targetSplitBtn[0]).parent()[0].className.split(" ")[0] : className.split(" ")[0];
            if (targetSplitBtn[0] || (className != undefined && className != null && jQuery.type(className) == "string" && className.indexOf("pivotButton") > -1)) {
                targetSplitBtn = targetSplitBtn[0] ? targetSplitBtn[0] : event.originalEvent.target != null ? event.originalEvent.target : event.originalEvent.srcElement;
                if (event.event != undefined && event.event.type == "touchend")
                    AEBdiv = event.target;
                else if (this._droppedClass != null && this._droppedClass != undefined && this._droppedClass != "")
                    AEBdiv = this.element.find("." + this._droppedClass)[0];
                else
                    AEBdiv = targetSplitBtn.parentNode;
                for (var i = 0; i < AEBdiv.children.length; i++) {
                    if ($(AEBdiv.childNodes[i]).attr("tag") == $(targetSplitBtn).attr("tag"))
                        targetPosition = i;
                }
            }
            return targetPosition;
        },

        _getUnSelectedNodes: function () {
            var treeElement = this.element.find(".editorTreeView")[0];
            var unselectedNodes = "";
            var data = $(treeElement).find(":input.nodecheckbox:not(:checked)");
            for (var i = 0; i < data.length; i++) {
                if (!($(data[i].parentElement).find('span:nth-child(1)').attr('class').indexOf("e-chk-act") > -1) && $(data[i].parentElement).attr('aria-checked') != 'mixed') {
                    var parentNode = $(data[i]).parents('li:eq(0)');
                    unselectedNodes += "::" + parentNode[0].id + "||" + $(parentNode).attr('tag');
                }
            }
            return unselectedNodes;
        },

        _getSelectedNodes: function (isSlicer) {
            if (isSlicer) {
                var treeElement = this.element.find(".editorTreeView")[0].childNodes[0];
                var selectedNodes = new Array();
                var data = $(treeElement).children();
                for (var i = 0; i < data.length; i++) {
                    var parentNode = data[i];
                    var nodeInfo = { caption: $(parentNode.firstChild).find("a").text(), parentId: parentNode.parentElement.parentElement.className.indexOf("editorTreeView") > -1 ? "None" : $(parentNode).parents()[1].id, id: parentNode.id, checked: $(parentNode).find(':input.nodecheckbox')[0].checked, expanded: $(parentNode.firstChild).find(".e-minus").length > 0 ? true : false, childNodes: new Array(), tag: $(parentNode).attr('tag') };
                    if ($(parentNode).find("ul:first").children().length > 0) {
                        var liElements = $(parentNode).find("ul:first").children();
                        for (var j = 0; j < liElements.length; j++) {
                            nodeInfo.childNodes.push(this._getNodeInfo(liElements[j]));
                        }
                    }
                    selectedNodes.push(nodeInfo);
                }
                return JSON.stringify(selectedNodes);
            }
            else {
                var treeElement = $(".editorTreeView");
                var selectedNodes = "";
                var data = $(treeElement).find(':input.nodecheckbox');
                for (var i = 0; i < data.length; i++) {
                    if (data[i].checked || $(data[i].parentElement).attr('aria-checked') == 'mixed') {
                        var parentNode = $(data[i]).parents('li:eq(0)');
                        selectedNodes += "::" + parentNode[0].id + "||" + $(parentNode).attr('tag');
                    }
                }
                return selectedNodes;
            }
        },
        _getNodeUniqueName: function (headerTag) {
            var uniqueName = "", selectedTreeNode = null;
            for (var i = 0; i < (headerTag.split(':')[1]).split('.').length; i++) {
                if (uniqueName != "")
                    uniqueName += ".";
                uniqueName += "[" + ((headerTag.split(':')[1]).split('.')[i]) + "]";
            }
            return uniqueName;
        },
        _getNodeByUniqueName: function (nodeUniqueName) {
            for (var i = 0; i < $(_pivotProxy._tableTreeObj.element.find("li")).length; i++) {
                if ($(_pivotProxy._tableTreeObj.element.find("li")[i]).attr("tag") == nodeUniqueName)
                    selectedTreeNode = $((_pivotProxy._tableTreeObj.element.find("li"))[i]);
            }
           
            return selectedTreeNode;
        },

        /**
        * Perform an asynchronous HTTP (Ajax) request.
        * @return jQuery
        * @example 
        * &lt;div id="PivotSchemaDesigner"&gt;&lt;/div&gt; <br> 
        * &lt;script&gt;
        * // Create PivotSchemaDesigner
        * $('#PivotSchemaDesigner').ejPivotSchemaDesigner({
        *       url: "PivotGridService.svc",
        *   });
        * var gridObj = $("#PivotSchemaDesigner").data("ejPivotSchemaDesigner");
        * gridObj.doAjaxPost("POST", "/PivotGridService.svc/Initialize", {"key", "Hello World"}, "_renderControlSuccess", null);
        * // Initiate an Ajax request.
        * &lt;/script&gt;
        * @memberof ejPivotSchemaDesigner
        * @instance
        */
        doAjaxPost: function (type, url, data, onSuccess, onComplete) {
            $.ajax({
                type: type,
                url: url,
                contentType: 'application/json; charset=utf-8',
                dataType: 'json',
                data: data,
                success: $.proxy(onSuccess, this),
                complete: $.proxy(onComplete, this),
                error: function (msg, textStatus, errorThrown) {
                    if (_proxy.model.progressMode != "infinite") {
                        window.clearInterval(oGridTimer);
                        if (_proxy.model.progressMode == "progress")
                            $("#" + _proxy._id + "progressText")[0].innerHTML = _proxy._getLocalizedLabels("MDXqueryExecutionFailed") + "!!!";
                        $("#" + ogridProgressBar._id).show();
                        ogridProgressBar.setModel({ value: 0, text: errorThrown });
                    }
                    else
                        ogridWaitingPopup.hide();
                }
            });
        }
    });

    ej.PivotSchemaDesigner.localization = {};
    ej.PivotSchemaDesigner.localization["en-US"] = {
        SeriesPage: "Series Page",
        CategoricalPage: "Categorical Page",
        MDXqueryExecutionFailed: "MDX query execution failed",
        PreparingAndExecutingMDXquery: "Preparing and executing MDX query",
        MDXqueryExecutedSuccessfully: "MDX query executed successfully",
        RenderingStarted: "Rendering Started",
        RenderingSucceeded: "Rendering Succeeded",
        RenderingFailed: "Rendering failed"
    };

    /**
    * Enum for Progress Mode. Allows the user to select a appropriate progress indicator. 
    *
    * @enum {String}
    * @global
    */
    ej.PivotSchemaDesigner.Layouts = {
        Excel: "excel",
        Normal: "normal"
    };

})(jQuery, Syncfusion); 