/**
* @fileOverview Plugin to style the Html Radial Menu elements
* @copyright Copyright Syncfusion Inc. 2001 - 2014. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/
(function ($, ej, undefined) {
    /**
    * @namespace ej
    * @class ejRadialMenu
    * @requires jQuery
    * @requires ej.core
    * @requires ej.unobtrusive
    * @requires ej.data
    * @requires ej.touch
    * @classdesc Custom Design for Html radialmenu control.
    * @example
    * // Create radialmenu in obtrusive way
    * &lt;script&gt; 
    * $(function(){
    * $("#defaultradialmenu").ejRadialMenu(); 
    * });
    * &lt;/script&gt;
    * &lt;div &gt;
    * &lt;br /&gt;
    * &lt;p&gt;
    * Syncfusion is the enterprise technology partner of choice for Windows development
    * &lt;/p&gt;
    * &lt;/div&gt;  
    * &lt;div id="defaultradialmenu"&gt;
    * &lt;ul&gt;
    * &lt;li data-ej-imageurl="../themes/sample/radialmenu/social.png"
    * data-ej-text="social"&gt;&lt;/li&gt;
    * &lt;li data-ej-imageurl="../themes/sample/radialmenu/music.png" 
    * data-ej-text="music"&gt;&lt;/li&gt;
    * &lt;li data-ej-imageurl="../themes/sample/radialmenu/direction.png" 
    * data-ej-text="direction"&gt;&lt;/li&gt;
    * &lt;li data-ej-imageurl="../themes/sample/radialmenu/message.png" 
    * data-ej-text="message"&gt;&lt;/li&gt;
    * &lt;li data-ej-imageurl="../themes/sample/radialmenu/browser.png" 
    * data-ej-text="browser"&gt;&lt;/li&gt;
    * &lt;/ul&gt;
    * &lt;/div&gt;
    */
    ej.widget("ejRadialMenu", "ej.RadialMenu", {
        _rootCSS: "e-radialmenu",
        // widget element will be automatically set in this
        element: null,
        // user defined model will be automatically set in this
        model: null,
        _setFirst: true,
        // default model
        defaults: {
            /**		
            * Renders the Image for Radial using Class.
            * @default e-radialimage
            * @type {string}
            * @example 
            * // Set Radialmenu Image on initialization. 
            * //To set image API  
            * &lt;div &gt;
            * &lt;br /&gt;
            * &lt;p&gt;
            * Syncfusion is the enterprise technology partner of choice for Windows development
            * &lt;/p&gt;
            * &lt;/div&gt;  
            * &lt;div id="defaultradialmenu"&gt;
            * &lt;ul&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/social.png"
            * data-ej-text="social"&gt;&lt;/li&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/music.png" 
            * data-ej-text="music"&gt;&lt;/li&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/direction.png" 
            * data-ej-text="direction"&gt;&lt;/li&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/message.png" 
            * data-ej-text="message"&gt;&lt;/li&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/browser.png" 
            * data-ej-text="browser"&gt;&lt;/li&gt;
            * &lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function () {
            * $("#defaultradialmenu").ejRadialMenu({ "imageClass":"e-radialimage" });	
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the Radialmenu Image, after initialization:
            * &lt;script&gt;
            * // Gets the Image API.		
            *  $("#radialmenu").ejRadialMenu ("option", "imageClass");			
            * // Sets the Width API
            * $("#radialmenu").ejRadialMenu ("option", "imageClass", "e-radialimage");            
            * &lt;/script&gt;
            * @memberof ejRadialMenu
            * @instance
            */
            imageClass: "e-radialimage",
            /**		
            * Renders the back button Image for Radial using class.
            * @default e-backimage
            * @type {string}
            * @example 
            * // Set Radialmenu back button Image on initialization. 
            * //To set back button image API 
            * &lt;div &gt;
            * &lt;br /&gt;
            * &lt;p&gt;
            * Syncfusion is the enterprise technology partner of choice for Windows development
            * &lt;/p&gt;
            * &lt;/div&gt;  
            * &lt;div id="defaultradialmenu"&gt;
            * &lt;ul&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/social.png"
            * data-ej-text="social"&gt;&lt;/li&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/music.png" 
            * data-ej-text="music"&gt;&lt;/li&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/direction.png" 
            * data-ej-text="direction"&gt;&lt;/li&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/message.png" 
            * data-ej-text="message"&gt;&lt;/li&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/browser.png" 
            * data-ej-text="browser"&gt;&lt;/li&gt;
            * &lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function () {
            * $("#defaultradialmenu").ejRadialMenu({ "backImageClass":"e-backimage" });	
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the Radialmenu back button Image, after initialization:
            * &lt;script&gt;
            * // Gets the back button Image API.		
            * $("#defaultradialmenu").ejRadialMenu ("option", "backImageClass");			
            * // Sets the Width API
            * $("#defaultradialmenu").ejRadialMenu ("option", "backImageClass", "e-backimage");            
            * &lt;/script&gt;
            * @memberof ejRadialMenu
            * @instance
            */
            backImageClass: "e-backimage",
            /**		
            * To show the Radial while clicking given target element.
            * @default null
            * @type {string}
            * @example 
            * // Set Radialmenu targetelementid on initialization. 
            * //To set targetelementid API 
            * &lt;div &gt;
            * &lt;br /&gt;
            * &lt;p&gt;
            * Syncfusion is the enterprise technology partner of choice for Windows development
            * &lt;/p&gt;
            * &lt;/div&gt;  
            * &lt;div id="defaultradialmenu"&gt;
            * &lt;ul&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/social.png"
            * data-ej-text="social"&gt;&lt;/li&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/music.png" 
            * data-ej-text="music"&gt;&lt;/li&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/direction.png" 
            * data-ej-text="direction"&gt;&lt;/li&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/message.png" 
            * data-ej-text="message"&gt;&lt;/li&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/browser.png" 
            * data-ej-text="browser"&gt;&lt;/li&gt;
            * &lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function () {
            * $("#defaultradialmenu").ejRadialMenu({ "targetElementId":"target" });	
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the Radialmenu targetelementid, after initialization:
            * &lt;script&gt;
            * // Gets the targetelementid API.		
            * $("#defaultradialmenu").ejRadialMenu ("option", "targetElementId");			
            * // Sets the Width API
            * $("#defaultradialmenu").ejRadialMenu ("option", "targetElementId", "target");            
            * &lt;/script&gt;
            * @memberof ejRadialMenu
            * @instance
            */
            targetElementId: null,
            /**    
            * Event triggers when the mouse down happens.
            * @event
            * @name ejRadialMenu#mouseDown 	
            * @param {Object} argument Event parameters from Radialmenu     
            * @param {boolean} argument.cancel if the event should be canceled; otherwise, false.
            * @param {Object} argument.model returns the Radialmenu model
            * @param {string} argument.type returns the name of the event
            * @param {object} argument.item returns the item of element
            * @param {String} argument.itemName returns the name of item
            * @example 
            * //MouseDown event for Radialmenu
            * &lt;div &gt;
            * &lt;br /&gt;
            * &lt;p&gt;
            * Syncfusion is the enterprise technology partner of choice for Windows development
            * &lt;/p&gt;
            * &lt;/div&gt;  
            * &lt;div id="defaultradialmenu"&gt;
            * &lt;ul&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/social.png"
            * data-ej-text="social"&gt;&lt;/li&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/music.png" 
            * data-ej-text="music"&gt;&lt;/li&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/direction.png" 
            * data-ej-text="direction"&gt;&lt;/li&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/message.png" 
            * data-ej-text="message"&gt;&lt;/li&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/browser.png" 
            * data-ej-text="browser"&gt;&lt;/li&gt;
            * &lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $("#defaultradialmenu").ejRadialMenu({
            *   mousedown: function (args) { //handle the event
            * }
            * });         
            * &lt;/script&gt;
            * @memberof ejRadialMenu
            * @instance
            */
            mouseDown: null,
            /**    
            * Event triggers when the mouse up happens.
            * @event
            * @name ejRadialMenu#mouseUp 	
            * @param {Object} argument Event parameters from Radialmenu     
            * @param {boolean} argument.cancel if the event should be canceled; otherwise, false.
            * @param {Object} argument.model returns the Radialmenu model
            * @param {string} argument.type returns the name of the event
            * @param {object} argument.item returns the item of element
            * @param {String} argument.itemName returns the name of item
            * @example 
            * //MouseUp event for Radialmenu
            * &lt;div &gt;
            * &lt;br /&gt;
            * &lt;p&gt;
            * Syncfusion is the enterprise technology partner of choice for Windows development
            * &lt;/p&gt;
            * &lt;/div&gt;  
            * &lt;div id="defaultradialmenu"&gt;
            * &lt;ul&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/social.png"
            * data-ej-text="social"&gt;&lt;/li&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/music.png" 
            * data-ej-text="music"&gt;&lt;/li&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/direction.png" 
            * data-ej-text="direction"&gt;&lt;/li&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/message.png" 
            * data-ej-text="message"&gt;&lt;/li&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/browser.png" 
            * data-ej-text="browser"&gt;&lt;/li&gt;
            * &lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $("#defaultradialmenu").ejRadialMenu({
            *   mouseup: function (args) { //handle the event
            * }
            * });         
            * &lt;/script&gt;
            * @memberof ejRadialMenu
            * @instance
            */
            mouseUp: null,
            /**    
            * Event triggers when we select an item.
            * @event
            * @name ejRadialMenu#select 	
            * @param {Object} argument Event parameters from Radialmenu     
            * @param {boolean} argument.cancel if the event should be canceled; otherwise, false.
            * @param {Object} argument.model returns the Radialmenu model
            * @param {string} argument.type returns the name of the event
            * @param {object} argument.item returns the item of element
            * @param {String} argument.itemName returns the name of item
            * @example 
            * //select event for Radialmenu
            * &lt;div &gt;
            * &lt;br /&gt;
            * &lt;p&gt;
            * Syncfusion is the enterprise technology partner of choice for Windows development
            * &lt;/p&gt;
            * &lt;/div&gt;  
            * &lt;div id="defaultradialmenu"&gt;
            * &lt;ul&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/social.png"
            * data-ej-text="social"&gt;&lt;/li&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/music.png" 
            * data-ej-text="music"&gt;&lt;/li&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/direction.png" 
            * data-ej-text="direction"&gt;&lt;/li&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/message.png" 
            * data-ej-text="message"&gt;&lt;/li&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/browser.png" 
            * data-ej-text="browser"&gt;&lt;/li&gt;
            * &lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $("#defaultradialmenu").ejRadialMenu({
            *   select: function (args) { //handle the event
            * }
            * });         
            * &lt;/script&gt;
            * @memberof ejRadialMenu
            * @instance
            */
            select: null,
            /**		
            * To show the Radial in intial render.
            * @default false
            * @type {boolean}
            * @example 
            * // Set Radialmenu autoOpen on initialization. 
            * //To set autoOpen API 
            * &lt;div &gt;
            * &lt;br /&gt;
            * &lt;p&gt;
            * Syncfusion is the enterprise technology partner of choice for Windows development
            * &lt;/p&gt;
            * &lt;/div&gt;  
            * &lt;div id="defaultradialmenu"&gt;
            * &lt;ul&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/social.png"
            * data-ej-text="social"&gt;&lt;/li&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/music.png" 
            * data-ej-text="music"&gt;&lt;/li&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/direction.png" 
            * data-ej-text="direction"&gt;&lt;/li&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/message.png" 
            * data-ej-text="message"&gt;&lt;/li&gt;
            * &lt;li data-ej-imageurl="../themes/sample/radialmenu/browser.png" 
            * data-ej-text="browser"&gt;&lt;/li&gt;
            * &lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(function () {
            * $("#defaultradialmenu").ejRadialMenu({ "autoOpen":true });	
            * });
            * &lt;/script&gt;
            * @example 
            * //Get or set the Radialmenu autoOpen, after initialization:
            * &lt;script&gt;
            * // Gets the autoOpen API.		
            * $("#defaultradialmenu").ejRadialMenu ("option", "autoOpen");			
            * // Sets the Width API
            * $("#defaultradialmenu").ejRadialMenu ("option", "autoOpen", true);            
            * &lt;/script&gt;
            * @memberof ejRadialMenu
            * @instance
            */
            autoOpen: false
        },
        dataTypes: {
            autoOpen: "boolean"
        },
        _init: function () {
            if (!(ej.browserInfo().name == "msie" && ej.browserInfo().version < 9)) {
                this._initialization();
                this._prefix = "e-";
                this._renderRadial();
                this._wireEvents();
            }
        },
        /**
        * Render the Radialmenu control
        * @private
        */
        _renderRadial: function () {
            this._radial = ej.buildTag("div.e-radial e-abs " + this.model.imageClass + "").css({ "left": this._startXY - 22 + "px", "top": this._startXY - 22 + "px" });
            this._radialContainer = ej.buildTag("div.e-rel").css({ "height": this.model.width, "width": this.model.width });
            this.element.append(this._radialContainer.append(this._radial)).addClass("e-radialmenu e-overlow e-user-select");
            this.model.autoOpen ? this.show() : this.hide();
            this._renderRadialMenu();
            this._arcOver = $.proxy(this._arcOverHandler, this);
            this._itemOver = $.proxy(this._itemOverHandler, this);
            var childArc = this._childArcGroup.children(),
                polygon = this._polygonGroup.children(),
                group = this._menuItemsGroup.children(),
                path = this._menuItemsPaths.children(),
                arcPath = this._menuItemsArcGroup.children();
            ej.listenEvents([childArc, childArc, polygon], ["mouseenter", "mouseleave", "mouseenter"], [this._arcOver, this._arcOver, this._arcOver], false);
            ej.listenEvents([group, path, path, arcPath, arcPath], ["mouseenter", "mouseenter", "mouseleave", "mouseenter", "mouseleave"], [this._itemOver, this._itemOver, this._itemOver, this._itemOver, this._itemOver], false);
        },
        /**
        * To wire the events for Radial Menu	
        * @private
        */
        _wireEvents: function () {
            this._radialClick = $.proxy(this._radialClickHandler, this);
            this._targetClick = $.proxy(this._targetClickHandler, this);
            this._mouseDown = $.proxy(this._mouseDownHandler, this);
            this._mouseUp = $.proxy(this._mouseUpHandler, this);
            ej.listenEvents([this._radial, this._radialSVGDiv, this._radialSVGDiv, $(document)], [ej.endEvent(), ej.startEvent(), ej.endEvent(), ej.endEvent()], [this._radialClick, this._mouseDown, this._mouseUp, this._targetClick], false);
        },
        _radialClickHandler: function (e) {
            if (this._radial.hasClass("e-backarrow")) {
                this._radial.removeClass("e-backarrow " + this.model.backImageClass + "").addClass(this.model.imageClass);
                if (this.model.enableAnimation) {
                    this._menuChildSVGDiv.removeClass("e-scaleshow").addClass("e-scalehide");
                    setTimeout(function () { $("#menuchildsvgdiv.e-abs").remove(); }, 150);
                    setTimeout(function () { $("#radialchildsvgdiv.e-abs").removeClass("e-scalehide e-displaynone").addClass("e-scaleshow"); }, 200);
                }
                else {
                    this._menuChildSVGDiv.remove();
                    this._radialChildSVGDiv.removeClass("e-displaynone");
                }
            }
            else {
                if (this._radialCircleSVGDiv.hasClass("e-displaynone")) {
                    if (this.model.enableAnimation) {
                        this._radialCircleSVGDiv.removeClass("e-displaynone e-radialhide").addClass("e-radialshow");
                        this._radialChildSVGDiv.removeClass("e-displaynone e-radialhide").addClass("e-radialshow");
                    }
                    else {
                        this._radialCircleSVGDiv.removeClass("e-displaynone");
                        this._radialChildSVGDiv.removeClass("e-displaynone");
                    }
                }
                else {
                    if (this.model.enableAnimation) {
                        this._radialCircleSVGDiv.removeClass("e-radialshow").addClass("e-radialhide");
                        this._radialChildSVGDiv.removeClass("e-radialshow e-scaleshow").addClass("e-radialhide");
                        setTimeout(function () { $("#radialcirclesvgdiv.e-abs").addClass("e-displaynone"); $("#radialchildsvgdiv.e-abs").addClass("e-displaynone"); }, 160);
                    }
                    else {
                        this._radialCircleSVGDiv.addClass("e-displaynone");
                        this._radialChildSVGDiv.addClass("e-displaynone");
                    }
                }
            }
            this._childTarget = false;
        },
        /**
        * To configure Menu Mouse Down handler
        * @private
        */
        _mouseDownHandler: function (e) {
            this._eventAction(e);
            if (this._event && this.model.mouseDown)
                this._trigger("mouseDown", this._data);
            this._event = false;
        },
        /**
        * To configure Menu Mouse Up handler
        * @private
        */
        _mouseUpHandler: function (e) {
            var targetEle = $(e.target);
            if (targetEle.attr("class") == "e-active" || e.target.tagName == "polygon") {
                this._index = parseInt(targetEle.attr("index"))
                this._renderRadialChildMenu(this._index);
                this._childTarget = true;
                var group = this._childItemsGroup.children(),
                    path = this._childItemsPaths.children(),
                    arcPath = this._childItemArcGroup.children();
                ej.listenEvents([group, path, path, arcPath, arcPath], ["mouseenter", "mouseleave", "mouseenter", "mouseleave", "mouseenter"], [this._itemOver, this._itemOver, this._itemOver, this._itemOver, this._itemOver], false);
            }
            this._eventAction(e);
            if (this._event && this.model.mouseUp)
                this._trigger("mouseUp", this._data);
            if (this._event && this.model.select)
                this._trigger("select", this._data);
            this._event = false;
        },
        _eventAction: function (e) {
            var targetEle = $(e.target);
            if (targetEle.attr("class") == "e-itembgcolor" || targetEle.attr("class") == "e-default") {
                var index = targetEle.index(),
                    text = !this._childTarget ? $(this._menuItemsGroup.children()[targetEle.index()]).text() : $(this._childItemsGroup.children()[targetEle.index()]).text();
                this._event = true;
                this._data = !this._childTarget ? { index: index, text: text} : { index: this._index, childIndex: index, text: text };
            }
            else if (e.target.tagName == "text" || e.target.tagName == "image") {
                var index = targetEle.parent().index(),
                    text = targetEle.parent().text();
                this._event = true;
                this._data = !this._childTarget ? { index: index, text: text} : { index: this._index, childIndex: index, text: text };
            }
        },
        _radialChildAnimate: function () {
            setTimeout(function () {
                $("#radialchildsvgdiv.e-abs").removeClass("e-scalehide e-scaleshow").addClass("e-displaynone");
            }, 150);
        },
        _arcOverHandler: function (e) {
            var targetEle = $(e.target),
                index = parseInt(targetEle.attr("index")),
                targetGroupEle = $('#childarcgroup path[index=' + index + ']');
            if (e.type == "mouseenter") {
                if (targetEle.attr("class") == "e-childdefault")
                    targetEle.attr("class", "e-active");
                else
                    targetGroupEle.attr("class", "e-active");
            }
            else {
                if (targetEle.attr("class") == "e-active")
                    targetEle.attr("class", "e-childdefault");
                else
                    targetGroupEle.attr("class", "e-childdefault");
            }
        },
        _itemOverHandler: function (e) {
            var index = $(e.currentTarget).index();
            var targetEle = !this._childTarget ? $(this._menuItemsArcPaths.children()[index]) : $(this._childItemsArcPaths.children()[index]);
            if (e.type == "mouseenter")
                targetEle.attr("class", "e-childdefault");
            else
                targetEle.attr("class", "e-arcbgcolor");
        },
        _targetClickHandler: function (e) {
            var targetEle = $(e.target), x = e.clientX, y = e.clientY, width, height,
                radialTarget = $("#" + this.model.targetElementId + ""),
                menuTarget = $(targetEle.closest(".e-radialmenu")).length,
                menuState = $("#radialcirclesvgdiv.e-abs").hasClass("e-displaynone");
            if (this.model.targetElementId) {
                width = radialTarget.width();
                height = radialTarget.height();
            }
            else {
                width = window.innerWidth;
                height = window.innerHeight;
            }
            if (menuTarget == 0 && $(targetEle.closest(radialTarget)).length == 0 && this.model.targetElementId) {
                menuState ? this.hide() : this.menuHide();
            }
            else if ($(targetEle.closest("div.e-radial")).length == 0 && menuState) {
                var left = x > width - this.model.width / 2 ? width - this.model.width : (x > this.model.width / 2 ? x - this.model.width / 2 : 0),
                    top = y > height - this.model.width / 2 ? height - this.model.width : (y > this.model.width / 2 ? y - this.model.width / 2 : 0);
                this.model.autoOpen ? this.show() : this.hide();
                this.element.css({ "position": "absolute", "top": top + "px", "left": left + "px" });
            }
            else if (menuTarget == 0)
                this.menuHide();
        },
        // public methods
        /**
        * To Show the redialmenu 
        * @return jQuery
        * @example 
        * &lt;div &gt;
        * &lt;br /&gt;
        * &lt;p&gt;
        * Syncfusion is the enterprise technology partner of choice for Windows development
        * &lt;/p&gt;
        * &lt;/div&gt;  
        * &lt;div id="defaultradialmenu"&gt;
        * &lt;ul&gt;
        * &lt;li data-ej-imageurl="../themes/sample/radialmenu/social.png"
        * data-ej-text="social"&gt;&lt;/li&gt;
        * &lt;li data-ej-imageurl="../themes/sample/radialmenu/music.png" 
        * data-ej-text="music"&gt;&lt;/li&gt;
        * &lt;li data-ej-imageurl="../themes/sample/radialmenu/direction.png" 
        * data-ej-text="direction"&gt;&lt;/li&gt;
        * &lt;li data-ej-imageurl="../themes/sample/radialmenu/message.png" 
        * data-ej-text="message"&gt;&lt;/li&gt;
        * &lt;li data-ej-imageurl="../themes/sample/radialmenu/browser.png" 
        * data-ej-text="browser"&gt;&lt;/li&gt;
        * &lt;/ul&gt;
        * &lt;/div&gt;
        * @example 
        * &lt;script&gt;
        * $("#defaultradialmenu").ejRadialMenu ("show");
        * &lt;/script&gt;
        * @memberof ejRadialMenu
        * @instance
        */
        show: function () {
            this.element.removeClass("e-displaynone");
        },
        /**
        * To hide the redialmenu 
        * @return jQuery
        * @example 
        * &lt;div &gt;
        * &lt;br /&gt;
        * &lt;p&gt;
        * Syncfusion is the enterprise technology partner of choice for Windows development
        * &lt;/p&gt;
        * &lt;/div&gt;  
        * &lt;div id="defaultradialmenu"&gt;
        * &lt;ul&gt;
        * &lt;li data-ej-imageurl="../themes/sample/radialmenu/social.png"
        * data-ej-text="social"&gt;&lt;/li&gt;
        * &lt;li data-ej-imageurl="../themes/sample/radialmenu/music.png" 
        * data-ej-text="music"&gt;&lt;/li&gt;
        * &lt;li data-ej-imageurl="../themes/sample/radialmenu/direction.png" 
        * data-ej-text="direction"&gt;&lt;/li&gt;
        * &lt;li data-ej-imageurl="../themes/sample/radialmenu/message.png" 
        * data-ej-text="message"&gt;&lt;/li&gt;
        * &lt;li data-ej-imageurl="../themes/sample/radialmenu/browser.png" 
        * data-ej-text="browser"&gt;&lt;/li&gt;
        * &lt;/ul&gt;
        * &lt;/div&gt;
        * @example 
        * &lt;script&gt;
        * $("#defaultradialmenu").ejRadialMenu ("hide");
        * &lt;/script&gt;
        * @memberof ejRadialMenu
        * @instance
        */
        hide: function () {
            this.element.addClass("e-displaynone");
        },
        /**
        * To hide the redialmenu items
        * @return jQuery
        * @example 
        * &lt;div &gt;
        * &lt;br /&gt;
        * &lt;p&gt;
        * Syncfusion is the enterprise technology partner of choice for Windows development
        * &lt;/p&gt;
        * &lt;/div&gt;  
        * &lt;div id="defaultradialmenu"&gt;
        * &lt;ul&gt;
        * &lt;li data-ej-imageurl="../themes/sample/radialmenu/social.png"
        * data-ej-text="social"&gt;&lt;/li&gt;
        * &lt;li data-ej-imageurl="../themes/sample/radialmenu/music.png" 
        * data-ej-text="music"&gt;&lt;/li&gt;
        * &lt;li data-ej-imageurl="../themes/sample/radialmenu/direction.png" 
        * data-ej-text="direction"&gt;&lt;/li&gt;
        * &lt;li data-ej-imageurl="../themes/sample/radialmenu/message.png" 
        * data-ej-text="message"&gt;&lt;/li&gt;
        * &lt;li data-ej-imageurl="../themes/sample/radialmenu/browser.png" 
        * data-ej-text="browser"&gt;&lt;/li&gt;
        * &lt;/ul&gt;
        * &lt;/div&gt;
        * @example 
        * &lt;script&gt;
        * $("#defaultradialmenu").ejRadialMenu ("menuHide");
        * &lt;/script&gt;
        * @memberof ejRadialMenu
        * @instance
        */
        menuHide: function () {
            if ($("#menuchildsvgdiv.e-abs").length != 0) {
                this._radial.removeClass("e-backarrow " + this.model.backImageClass + "").addClass(this.model.imageClass);
                if (this.model.enableAnimation) {
                    this._radialCircleSVGDiv.removeClass("e-radialshow e-radialhide e-scaleshow e-scalehide").addClass("e-displaynone");
                    this._radialChildSVGDiv.removeClass("e-radialshow e-radialhide e-scaleshow e-scalehide").addClass("e-displaynone");
                    this._menuChildSVGDiv.removeClass("e-scaleshow").addClass("e-radialhide");
                    setTimeout(function () { $("#menuchildsvgdiv.e-abs").removeClass("e-radialhide").remove(); }, 150);
                }
                else {
                    this._radialCircleSVGDiv.addClass("e-displaynone");
                    this._radialChildSVGDiv.addClass("e-displaynone");
                    this._menuChildSVGDiv.remove();
                }
            }
            else {
                if (this.model.enableAnimation) {
                    this._radialCircleSVGDiv.removeClass("e-radialshow").addClass("e-radialhide");
                    this._radialChildSVGDiv.removeClass("e-radialshow e-scaleshow").addClass("e-radialhide");
                    setTimeout(function () {
                        $("#radialcirclesvgdiv.e-abs").addClass("e-displaynone").removeClass("e-radialshow e-radialhide e-scaleshow e-scalehide");
                        $("#radialchildsvgdiv.e-abs").addClass("e-displaynone").removeClass("e-radialshow e-radialhide e-scaleshow e-scalehide");
                    }, 160);
                }
                else {
                    this._radialCircleSVGDiv.addClass("e-displaynone");
                    this._radialChildSVGDiv.addClass("e-displaynone");
                }
            }
        }
    });
    $.extend(true, ej.RadialMenu.prototype, ej.RadialMenuBase.prototype);
})(jQuery, Syncfusion);