(function ($, ej, undefined) {
    // ejSample is the plugin name 
    // "ej.Sample" is "namespace.className" will hold functions and properties
    /**
    * @namespace ej
    * @classdesc The ribbon can be easily configured to the DOM element, such as div. you can create a ribbon with a highly customizable look and feel.
    * @class ejRibbon
    * @param {object} options - settings for ribbon 
    * @requires jQuery
    * @requires jquery.easing.min.js
    * @requires jquery.globalize.min.js    
    * @requires ej.core.js
    * @requires ej.data.js
    * @requires ej.dropdownlist.js
    * @requires ej.button.js
    * @requires ej.tab.js
    * @requires ej.splitbutton.js
    * @requires ej.ribbon.js
    * @requires ej.menu.js 
	* @requires ej.scroller.js
    * @requires ej.checkbox.js 
	* @requires ej.togglebutton.js 
	* @example
    * &lt;div id="Ribbon"&gt;&lt;/div&gt; 
    * &lt;script&gt;
    * // Create Ribbon
    * $('#Ribbon').ejRibbon();         
    * &lt;/script&gt;
    */   
    ej.widget("ejRibbon", "ej.Ribbon", {
        element: null,
        model: null,
        _rootCSS: "e-ribbon",
        defaults: {
		/**		
        * Specify the width to the ribbon control.we can set width in string or number format. 
        * @default null
		* @alias ejRibbon#width
        * @type { string | number}
        * @example 
       *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;/button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         }]
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
            width: "",
			/**		
        * Specify the application tab to contain application menu in the ribbon control.
        * @default Object
		* @alias ejRibbon#applicationTab
        * @type {object}
        * @example 
        *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;/button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         }]
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
            applicationTab: {
			/**		
        * To specify the type of application tab item.Specify the type of application tab as "ApplicationMenu" in the ribbon control.
        * @default null
		* @alias ejRibbon#applicationTab->Type
        * @type {string}
        * @example 
         *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;/button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         }]
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
			        Type:"",
					/**		
        * Specify the ID of 'ul' list to create application menu in the ribbon control.
        * @default null
		* @alias ejRibbon#applicationTab->itemID
        * @type {string}
        * @example 
         *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button &lt;/button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         }]
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
					itemID: "",
					/**		
        * Specify the menu members,events using the menu settings for the menu in the application tab.
        * @default object
		* @alias ejRibbon#applicationTab->menuSettings
        * @type {object}
        * @example 
                 *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;/button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         }]
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
					menuSettings:{}
			},
			/**		
        * Specify the tabs and its groups,controls to the ribbon control.
        * @default array
		* @alias ejRibbon#tabs
        * @type {array}
        * @example 
                 *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;/button&gt;
	   *&lt;button id="insert"&gt;Insert button&lt;/button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         },
	            {
				id: "insert", text: "INSERT", groups: [{
       *                 text: "Insert group", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"insert"
       *            }]
	            }
	   ]
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
            tabs: [{
			/**		
        * Specify the ID for each tab's content panel.
        * @default null
		* @alias ejRibbon#tabs->id
        * @type {string}
        * @example 
       *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;/button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         }]
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
			   id:null,
			   /**		
        * Specify the text of the tab in the ribbon control.
        * @default null
		* @alias ejRibbon#tabs->text
        * @type {string}
        * @example 
        *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;/button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         }]
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
			   text:null,
			   /**		
        * Specify single group or multiple groups and its contents to each tab in the ribbon control.
        * @default array
		* @alias ejRibbon#tabs->groups
        * @type {array}
        * @example 
        *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;/button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         }]
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
			   groups:[{
			     /**		
        * Specify the text to the groups in the ribbon control.
        * @default null
		* @alias ejRibbon#tabs->groups->text
        * @type {string}
        * @example 
        *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;/button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         }]
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
			   text:null,
			    /**		
        * Specify the custom items such as div,table,controls using the type "custom".
        * @default null
		* @alias ejRibbon#tabs->groups->type
        * @type {string}
        * @example 
		*&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;/button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         }]
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
			   type:null,
			    /**		
        * Specify the ID of custom items to place into the groups.
        * @default null
		* @alias ejRibbon#tabs->groups->contentID
        * @type {string}
        * @example 
		*&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;/button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         }]
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
			   contentID:null,
			   /**		
        * Specify the HTML contents to place into the groups.
        * @default null
		* @alias ejRibbon#tabs->groups->customContent
        * @type {string}
        * @example 
		*&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", type: "custom", customContent: "&lt;button id='customContent'&gt;Custom Content&lt;/button&gt;"
       *            }]
       *         }]
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
			   customContent:null,
			   /**		
        * Specify the alignment of controls in the groups in 'row' type or 'column' type.Value for row type is "ej.Ribbon.alignType.rows" and Value for column type is "ej.Ribbon.alignType.columns".
        * @default ej.Ribbon.alignType.rows
		* @alias ejRibbon#tabs->groups->alignType
        * @type {enum}
        * @example 
        *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;/button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         }]
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
			   alignType:null,
			     /**		
        * Specify the group expander for groups in the ribbon control.Set "true" to enable the group expander.
        * @default false
		* @alias ejRibbon#tabs->groups->enableGroupExpander
        * @type {boolean}
        * @example 
        *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;/button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",enableGroupExpander: true,contentID:"btn"
       *            }]
       *         }]
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
			   enableGroupExpander:false,
			    /**		
        * Specify the syncfusion button,split button,dropdown list controls to the groups in the ribbon control.
        * @default array
		* @alias ejRibbon#tabs->groups->content
        * @type {array}
        * @example 
       *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,content: [{
       *                     groups: [{
       *                         id: "new",
       *                         text: "New",
	   *                         toolTip: "New",
       *                         type: ej.Ribbon.type.button,
       *                         buttonSettings: {
       *                         width: 160,
       *                         height: 50
       *                         }
       *                     }]
       *                 }]
       *            }]
       *         }]
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
			   content:[{
			   /**		
        * Specify the controls such as syncfusion button,split button,dropdown list,toggle button,custom controls in the subgroup of the ribbon tab .
        * @default array
		* @alias ejRibbon#tabs->groups->content->groups
        * @type {array}
        * @example 
			   *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,content: [{
       *                     groups: [{
       *                         id: "new",
       *                         text: "New",
	   *                         toolTip: "New",
       *                         type: ej.Ribbon.type.button,
       *                         buttonSettings: {
       *                         width: 160,
       *                         height: 50
       *                         }
       *                     }]
       *                 }]
       *            }]
       *         }]
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
			   groups:[{
			    /**		
        * Specify the Id for button,split button,dropdown list controls in the sub groups.
        * @default null
		* @alias ejRibbon#tabs->groups->content->groups->id
        * @type {string}
        * @example 
        *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,content: [{
       *                     groups: [{
       *                         id: "new",
       *                         text: "New",
	   *                         toolTip: "New",
       *                         type: ej.Ribbon.type.button,
       *                         buttonSettings: {
       *                         width: 160,
       *                         height: 50
       *                         }
       *                     }]
       *                 }]
       *            }]
       *         }]
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
	           id:null,
			   /**		
        * Specify the text for button,split button controls in the sub groups.
        * @default null
		* @alias ejRibbon#tabs->groups->content->groups->text
        * @type {string}
        * @example 
       *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,content: [{
       *                     groups: [{
       *                         id: "new",
       *                         text: "New",
	   *                         toolTip: "New",
       *                         type: ej.Ribbon.type.button,
       *                         buttonSettings: {
       *                         width: 160,
       *                         height: 50
       *                         }
       *                     }]
       *                 }]
       *            }]
       *         }]
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
			   text:null,
			    /**		
        * Specify the tooltip for button,split,dropdown controls in the sub groups.
        * @default null
		* @alias ejRibbon#tabs->groups->content->groups->toolTip
        * @type {string}
        * @example 
        *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,content: [{
       *                     groups: [{
       *                         id: "new",
       *                         text: "New",
	   *                         toolTip: "New",
       *                         type: ej.Ribbon.type.button,
       *                         buttonSettings: {
       *                         width: 160,
       *                         height: 50
       *                         }
       *                     }]
       *                 }]
       *            }]
       *         }]
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
			   toolTip:null,
			    /**		
        * Specify the type as "ej.Ribbon.type.button" or "ej.Ribbon.type.splitButton" or "ej.Ribbon.type.dropDownList" or "ej.Ribbon.type.toggleButton" or "ej.Ribbon.type.custom" to render button,split,dropdown,toggle button,custom controls.
        * @default ej.Ribbon.type.button
		* @alias ejRibbon#tabs->groups->content->groups->type
        * @type {enum}
        * @example 
        *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,content: [{
       *                     groups: [{
       *                         id: "new",
       *                         text: "New",
	   *                         toolTip: "New",
       *                         type: ej.Ribbon.type.button,
       *                         buttonSettings: {
       *                         width: 160,
       *                         height: 50
       *                         }
       *                     }]
       *                 }]
       *            }]
       *         }]
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
			   type:null,
		/**		
        * Specify the custom items such as div,table,controls as custom controls with the type "ej.Ribbon.type.custom" in the groups.
        * @default null
		* @alias ejRibbon#tabs->groups->content->groups->contentID
        * @type {string}
        * @example 
        *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;input id="fontcolor"/&gt; 
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,content: [{
       *                     groups: [{
       *                         id: "new",
       *                         text: "New",
	   *                         toolTip: "New",
       *                         type: ej.Ribbon.type.button,
       *                         buttonSettings: {
       *                         width: 160,
       *                         height: 50
       *                         }
       *                     },
	   *                      {
	   *					     id: "fontcolor",
	   *					     text: "Font Color",
	   *					     toolTip: "Font Color",
	   *					     type: ej.Ribbon.type.custom,
	   *					     contentID:"fontcolor"
	   *					 }]
       *                 }]
       *            }]
       *         }],
	   *         create: "createControl",
       *   });
       * });	        
	   *   function createControl(args) {
       *    $("#fontcolor").ejColorPicker({ value: "#FFFF00", modelType: "palette", cssClass: "e-ribbon", 
	   *      toolIcon: "e-icon e-fontcoloricon"});
       *    }
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */	   
			   contentID:null,
			      /**		
        * Specify the separator to the control which is in row type group.The separator separate the control from the next control in the group.Set "true" to enable the separator. 
        * @default false
		* @alias ejRibbon#tabs->groups->content->groups->enableSeparator
        * @type {boolean}
        * @example 
        *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,content: [{
       *                     groups: [{
       *                         id: "new",
       *                         text: "New",
	   *                         toolTip: "New",
       *                         enableSeparator: true,
       *                          buttonSettings: {
       *                          width: 100,
       *                          }
       *                     },
	   * 						{
       *                         id: "font",
       *                         text: "Font",
	   *                         toolTip: "Font",
       *                         buttonSettings: {
       *                         width: 150,
       *                         }
       *                     }],
	   *						 defaults: {
       *                        type: ej.Ribbon.type.button,
       *                        height: 70
       *                    }
       *                 }]
       *            }]
       *         }]
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
			   enableSeparator:false,
			   /**		
        * Specify the size for button,split button controls.set "true" for big size and "false" for small size.
        * @default null
		* @alias ejRibbon#tabs->groups->content->groups->isBig
        * @type {boolean}
        * @example 
        *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,content: [{
       *                     groups: [{
       *                         id: "new",
       *                         text: "New",
	   *                         toolTip: "New",
	   *                         isBig:true,
       *                         type: ej.Ribbon.type.button,
       *                         buttonSettings: {
       *                         width: 100
       *                         }
       *                     }]
       *                 }]
       *            }]
       *         }]
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
			   isBig:null,
			     /**		
        * Specify the css class property to apply styles to the button,split,dropdown controls in the groups.
        * @default null
		* @alias ejRibbon#tabs->groups->content->groups->cssClass
        * @type {string}
        * @example 
        *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;style&gt;
       *.e-cssclass {
       *      margin-left: 20px;
       *}
       *&lt;/style&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,content: [{
       *                     groups: [{
       *                         id: "new",
       *                         text: "New",
	   *                         toolTip: "New",
	   *                         cssClass:"e-cssclass",
	   *                         isBig:true,
       *                         type: ej.Ribbon.type.button,
       *                         buttonSettings: {
       *                         width: 100,
       *                         }
       *                     }]
       *                 }]
       *            }]
       *         }]
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
			   cssClass:null,
			   /**		
        * Specify the syncfusion button members,events using this buttonSettings.
        * @default object
		* @alias ejRibbon#tabs->groups->content->groups->buttonSettings
        * @type {object}
        * @example 
        *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,content: [{
       *                     groups: [{
       *                         id: "new",
       *                         text: "New",
	   *                         toolTip: "New",
	   *                         isBig:true,
       *                         type: ej.Ribbon.type.button,
       *                         buttonSettings: {
       *                         width: 100,
       *                         }
       *                     }]
       *                 }]
       *            }]
       *         }]
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
			   buttonSettings:{},
			    /**		
        * Specify the syncfusion split button members,events using this splitButtonSettings.
        * @default object
		* @alias ejRibbon#tabs->groups->content->groups->splitButtonSettings
        * @type {object}
        * @example 
        *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;ul id="split"&gt;
       *&lt;li&gt;&lt;span&gt;Paste&lt;/span&gt;&lt;/li&gt;
       *&lt;/ul&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,content: [{
       *                     groups: [{
       *                         id: "new",
       *                         text: "New",
	   *                         toolTip: "New",
	   *                         isBig:true,
       *                         type: ej.Ribbon.type.splitButton,
       *                         splitButtonSettings: {
       *                         targetID: "split",
       *                         buttonMode: "dropdown",
       *                         arrowPosition:"bottom"
       *                         }
       *                     }]
       *                 }]
       *            }]
       *         }]
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
			   splitButtonSettings:{},
			   /**		
        * Specify the syncfusion toggle button members,events using this toggleButtonSettings.
        * @default object
		* @alias ejRibbon#tabs->groups->content->groups->toggleButtonSettings
        * @type {object}
        * @example 
        *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,content: [{
       *                     groups: [{
       *                         id: "bold",
	   *                         toolTip: "Bold",
	   *                         isBig:true,
       *                         type: ej.Ribbon.type.toggleButton,
       *                         toggleButtonSettings: {
       *                         defaultText: "Bold",
       *                         activeText: "BoldTog"
       *                         }
       *                     }]
       *                 }]
       *            }]
       *         }]
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
			   toggleButtonSettings:{},
			     /**		
        * Specify the syncfusion dropdown list members,events using this dropdownSettings.
        * @default object
		* @alias ejRibbon#tabs->groups->content->groups->dropdownSettings
        * @type {object}
        * @example 
        *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;style&gt;
       *.e-cssclass {
       *      margin-left: 20px;
       *}
       *&lt;/style&gt;
       *&lt;script type="text/javascript"&gt;  
       *var fontfamily = ["Segoe UI", "Arial", "Times New Roman", "Tahoma", "Helvetica"];	   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,content: [{
       *                     groups: [{
       *                        id: "fontfamily",
       *                        toolTip: "Font",
	   *						type: ej.Ribbon.type.dropDownList,
       *                        dropdownSettings: {
       *                             dataSource: fontfamily,
       *                             value: "Segoe UI",
       *                             width: 150
       *                         }
       *                     }]
       *                 }]
       *            }]
       *         }]
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
			   dropdownSettings:{},
			   }],
			     /**		
        * Specify the height,width,type,isBig property to the controls in the group commonly.
        * @default object
		* @alias ejRibbon#tabs->groups->content->defaults
        * @type {object}
        * @example 
       *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,content: [{
       *                     groups: [{
       *                         id: "new",
       *                         text: "New",
	   *                         toolTip: "New",
       *                          buttonSettings: {
       *                          width: 100,
       *                          }
       *                     },
	   * 						{
       *                         id: "font",
       *                         text: "Font",
	   *                         toolTip: "Font",
       *                         buttonSettings: {
       *                         width: 150,
       *                         }
       *                     }],
	   *						 defaults: {
       *                        type: ej.Ribbon.type.button,
       *                        height: 70
       *                    }
       *                 }]
       *            }]
       *         }]
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
			   defaults:{},
			   }],
			   }]
			}],
			   /**		
        * Specify the contextual tabs and tabset to the ribbon control with the background color and border color.Please refer the tabs section for adding tabs into the contextual tab and contextual tab set.
        * @default array
		* @alias ejRibbon#contextualTabs
        * @type {array}
		* @example 
       *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;/button&gt;
	   *&lt;button id="design"&gt;Design button&lt;/button&gt;
	   *&lt;button id="div1"&gt;First button&lt;/button&gt;
	   *&lt;button id="div2"&gt;Second button&lt;/button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         }],
	   *         contextualTabs:
       *                      [{
	   *                           backgroundColor:"#FCFBEB",borderColor: "#F2CC1C",
	   *                           tabs:[{
       *                           id: "Design", text: "DESIGN",groups: [{
       *                                     text: "Table Style Options", type: "custom", contentID: "design"
       *                                 }
       *                                 ]
	   *                               }]
       *                        },
       *                         {
       *                            borderColor: "lightblue",backgroundColor:"blue",
       *                             tabs:[{
       *                                 id: "tabset1", text: "Tabset1", 
       *                                 groups: [
       *                                 { text: "Tabset1 Styles", type: "custom", contentID: "div1"
       *                                 }]
       *                            },
       *                             {
       *                                 id: "tabset2", text: "Tabset2",
       *                                 groups: [
       *                                     { text: "Tabset2 Styles", type: "custom", contentID: "div2"
       *                                     }
       *                                 ]
       *                            }]
       * }]
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
            contextualTabs: [{
							  /**		
        * Specify the backgroundColor of the contextual tabs and tabset in the ribbon control.
        * @default null
		* @alias ejRibbon#contextualTabs->backgroundColor
        * @type {string}
		* @example 
       *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;/button&gt;
	   *&lt;button id="design"&gt;Design button&lt;/button&gt;
	   *&lt;button id="div1"&gt;First button&lt;/button&gt;
	   *&lt;button id="div2"&gt;Second button&lt;/button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         }],
	   *         contextualTabs:
       *                      [{
	   *                           backgroundColor:"#FCFBEB",borderColor: "#F2CC1C",
	   *                           tabs:[{
       *                           id: "Design", text: "DESIGN",groups: [{
       *                                     text: "Table Style Options", type: "custom", contentID: "design"
       *                                 }
       *                                 ]
	   *                               }]
       *                        },
       *                         {
       *                            borderColor: "lightblue",backgroundColor:"blue",
       *                             tabs:[{
       *                                 id: "tabset1", text: "Tabset1", 
       *                                 groups: [
       *                                 { text: "Tabset1 Styles", type: "custom", contentID: "div1"
       *                                 }]
       *                            },
       *                             {
       *                                 id: "tabset2", text: "Tabset2",
       *                                 groups: [
       *                                     { text: "Tabset2 Styles", type: "custom", contentID: "div2"
       *                                     }
       *                                 ]
       *                            }]
       * }]
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
							backgroundColor:null,
							   /**		
        * Specify the borderColor of the contextual tabs and tabset in the ribbon control.
        * @default null
		* @alias ejRibbon#contextualTabs->borderColor
        * @type {string}
		* @example 
       *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;/button&gt;
	   *&lt;button id="design"&gt;Design button&lt;/button&gt;
	   *&lt;button id="div1"&gt;First button&lt;/button&gt;
	   *&lt;button id="div2"&gt;Second button&lt;/button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         }],
	   *         contextualTabs:
       *                      [{
	   *                           backgroundColor:"#FCFBEB",borderColor: "#F2CC1C",
	   *                           tabs:[{
       *                           id: "Design", text: "DESIGN",groups: [{
       *                                     text: "Table Style Options", type: "custom", contentID: "design"
       *                                 }
       *                                 ]
	   *                               }]
       *                        },
       *                         {
       *                            borderColor: "lightblue",backgroundColor:"blue",
       *                             tabs:[{
       *                                 id: "tabset1", text: "Tabset1", 
       *                                 groups: [
       *                                 { text: "Tabset1 Styles", type: "custom", contentID: "div1"
       *                                 }]
       *                            },
       *                             {
       *                                 id: "tabset2", text: "Tabset2",
       *                                 groups: [
       *                                     { text: "Tabset2 Styles", type: "custom", contentID: "div2"
       *                                     }
       *                                 ]
       *                            }]
       * }]
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
			                borderColor:null,
							/**	
			 * Specify the tabs to present in the contectual tabs and tab set.Please refer the tabs section for adding tabs into the contextual tabs and tab set.
           * @default array
		   * @alias ejRibbon#contextualTabs->tabs
           * @type {array}
			* @example 
       *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;/button&gt;
	   *&lt;button id="design"&gt;Design button&lt;/button&gt;
	   *&lt;button id="div1"&gt;First button&lt;/button&gt;
	   *&lt;button id="div2"&gt;Second button&lt;/button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         }],
	   *         contextualTabs:
       *                      [{
	   *                           backgroundColor:"#FCFBEB",borderColor: "#F2CC1C",
	   *                           tabs:[{
       *                           id: "Design", text: "DESIGN",groups: [{
       *                                     text: "Table Style Options", type: "custom", contentID: "design"
       *                                 }
       *                                 ]
	   *                               }]
       *                        },
       *                         {
       *                            borderColor: "lightblue",backgroundColor:"blue",
       *                             tabs:[{
       *                                 id: "tabset1", text: "Tabset1", 
       *                                 groups: [
       *                                 { text: "Tabset1 Styles", type: "custom", contentID: "div1"
       *                                 }]
       *                            },
       *                             {
       *                                 id: "tabset2", text: "Tabset2",
       *                                 groups: [
       *                                     { text: "Tabset2 Styles", type: "custom", contentID: "div2"
       *                                     }
       *                                 ]
       *                            }]
       * }]
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
							tabs:[]
			}],
			/**     
    * Triggered after the ribbon tab item selected in the ribbon control.
    * @event
    * @name ejRibbon#onTabSelect   
    * @param {Object} argument Event parameters from button     
    * @param {boolean} argument.cancel if the event should be canceled; otherwise, false.
    * @param {object}  argument.model returns the ribbon model.
    * @param {string}  argument.type returns the name of the event.
    * @param {object}  argument.prevActiveHeader returns previous active tab header.
     * @param {number}  argument.prevActiveIndex returns previous active index.
     * @param {object}  argument.activeHeader returns current active tab header .
     * @param {number}  argument.activeIndex returns current active index.
    * @example 
      *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;/button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         }],
	   *     onTabSelect: function (args) {}
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
            onTabSelect: null,
	   /**     
	   * Triggered when tab is clicked successfully in the ribbon control.
	   * @event
	   * @name ejRibbon#onTabClick 	
	   * @param {Object} argument Event parameters from button     
	   * @param {boolean} argument.cancel if the event should be canceled; otherwise, false.
	   * @param {object}  argument.model returns the ribbon model.
	   * @param {string}  argument.type returns the name of the event.
	   * @param {object}  argument.prevActiveHeader returns previous active tab header.
	   * @param {number}  argument.prevActiveIndex returns previous active index.
	   * @param {object}  argument.activeHeader returns current active tab header .
	   * @param {number}  argument.activeIndex returns current active index.
	   * @example 
       *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;/button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         }],
	   *      onTabClick: function (args) {}
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
            onTabClick: null,
			/**     
			 * Triggered after the new ribbon tab item add.
			 * @event
			 * @name ejRibbon#onTabAdd 	
			 * @param {Object} argument Event parameters from button     
			 * @param {boolean} argument.cancel if the event should be canceled; otherwise, false.
			 * @param {object}  argument.model returns the ribbon model.
			 * @param {string}  argument.type returns the name of the event.
			 * @param {object}  argument.tabHeader returns new added tab header.
			 * @param {object}  argument.tabContent returns new added tab content panel.
			 * @example 
     *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;/button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         }],
	   *       onTabAdd: function (args) {}
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
            onTabAdd: null,
			/**     
			 * Triggered after the tab item removed from the ribbon control.
			 * @event
			 * @name ejRibbon#onTabRemove 	
			 * @param {Object} argument Event parameters from button     
			 * @param {boolean} argument.cancel if the event should be canceled; otherwise, false.
			 * @param {object}  argument.model returns the ribbon model.
			 * @param {string}  argument.type returns the name of the event.
			 * @param {object}  argument.removedTab returns removed tab header.
			 * @param {object}  argument.removedPanel returns removed tab content panel.
			 * @example 
      *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;/button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         }],
	   *       onTabRemove: function (args) {}
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
            onTabRemove: null,
			/**     
			 * Triggered before the ribbon tab item remove.
			 * @event
			 * @name ejRibbon#beforeTabRemove 	
			 * @param {Object} argument Event parameters from button.     
			 * @param {boolean} argument.cancel if the event should be canceled; otherwise, false.
			 * @param {object}  argument.model returns the ribbon model.
			 * @param {string}  argument.type returns the name of the event.
			 * @param {number}  argument.index returns current tab item index in the ribbon control.		
			 * @example 
      *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;/button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         }],
	   *       beforeTabRemove: function (args) {}
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
            beforeTabRemove: null,
			  /**     
    * Triggered before the ribbon tab create.
    * @event
    * @name ejRibbon#onTabCreate   
    * @param {Object} argument Event parameters from button.     
    * @param {boolean} argument.cancel if the event should be canceled; otherwise, false.
    * @param {object}  argument.model returns the ribbon model.
    * @param {string}  argument.type returns the name of the event.
    * @param {number}  argument.deleteIndex returns current ribbon tab item index     
    * @example 
      *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;/button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         }],
	   *       onTabCreate: function (args) {}
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
	        onTabCreate:null,
			 /**     
    * Triggered before the ribbon control create.
    * @event
    * @name ejRibbon#create   
    * @param {Object} argument Event parameters from Ribbon.     
    * @param {boolean} argument.cancel if the event should be canceled; otherwise, false.
    * @param {object}  argument.model returns the ribbon model.
    * @param {string}  argument.type returns the name of the event.  
    * @example 
      *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;/button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         }],
	   *       create: function (args) {}
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
            create: null,
			/**     
			 * Triggered when the control in the group is clicked successfully .
			 * @event
			 * @name ejRibbon#groupClick 	   
			 * @param {boolean} argument.cancel if the event should be canceled; otherwise, false.
			 * @param {object}  argument.model returns the ribbon model.
			 * @param {string}  argument.type returns the name of the event.
			 * @param {number}  argument.target returns the control clicked in the group.		
			 * @example 
      *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;/button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         }],
	   *       groupClick: function (args) {}
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
            groupClick: null,
			/**     
			 * Triggered when the expand/collapse button is clicked successfully .
			 * @event
			 * @name ejRibbon#onToggleButtonClick 	   
			 * @param {boolean} argument.cancel if the event should be canceled; otherwise, false.
			 * @param {object}  argument.model returns the ribbon model.
			 * @param {string}  argument.type returns the name of the event.
			 * @param {number}  argument.target returns the expand/collapse button.		
			 * @example 
      *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;/button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         }],
	   *       onToggleButtonClick: function (args) {}
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
            onToggleButtonClick: null,
			/**     
			 * Triggered when the groupexpander in the group is clicked successfully .
			 * @event
			 * @name ejRibbon#groupExpand 	   
			 * @param {boolean} argument.cancel if the event should be canceled; otherwise, false.
			 * @param {object}  argument.model returns the ribbon model.
			 * @param {string}  argument.type returns the name of the event.
			 * @param {number}  argument.target returns the clicked groupexpander.		
			 * @example 
      *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;/button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         }],
	   *       groupExpand: function (args) {}
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
            groupExpand: null,
            applicationTabClick: null,
			/**		
        * Specify the index of the ribbon tab to select the given index tab item in the ribbon control.
        * @default 1
		* @alias ejRibbon#selectedItemIndex
        * @type {number}
        * @example 
		*&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
       *      width: "100%",
	   * // Set the selectedItemIndex during initialization. 
	   *        selectedItemIndex : 2,
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         },
	   *        {
	   *		id: "insert", text: "INSERT", groups: [{
       *                 text: "Insert group", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"insert"
       *            }]
	   *        }
	   *       ]
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
            selectedItemIndex: 1,
			/**		
        * Specify the index or indexes to enable the given index tab or indexes tabs in the ribbon control.
        * @default null
		* @alias ejRibbon#enabledItemIndex
        * @type {array}
        * @example 
		*&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;button&gt;
	   *&lt;button id="insert"&gt;Insert button&lt;/button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         },
	   *        {
	   *		id: "insert", text: "INSERT", groups: [{
       *                 text: "Insert group", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"insert"
       *            }]
	   *        }
	   *]
       *   });
       * });	        
	   * //initialize the Ribbon object
       *	var ribbonObj = $("#Ribbon").data("ejRibbon");
	   *    ribbonObj.option({ disabledItemIndex: [1, 2] });
       *	// Enable the required ribbon tab from the ribbon control.
       *	ribbonObj.option({ enabledItemIndex: [1] });
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
            enabledItemIndex: [],
			/**		
        * Specify the index or indexes to disable the given index tab or indexes tabs in the ribbon control.
        * @default 0
		* @alias ejRibbon#disabledItemIndex
        * @type {array}
        * @example 
        *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;button&gt;
	   *&lt;button id="insert"&gt;Insert button&lt;/button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
       *      width: "100%",
	   * // Set the disabledItemIndex during initialization. 
	   *  disabledItemIndex: [1,2],
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         },
	   *        {
	   *		id: "insert", text: "INSERT", groups: [{
       *                 text: "Insert group", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"insert"
       *            }]
	   *        }
	   *]
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
            disabledItemIndex: [0],            
            locale: "en-US",
			/**     
   * Triggered before the ribbon control destroy.
   * @event
   * @name ejRibbon#destroy   
   * @param {Object} argument Event parameters from button.     
   * @param {boolean} argument.cancel if the event should be canceled; otherwise, false.
   * @param {object}  argument.model returns the ribbon model.
   * @param {string}  argument.type returns the name of the event.
   * @param {number}  argument.deleteIndex returns current ribbon tab item index     
   * @example 
       *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;/button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         }],
	   *        destroy: function (args) {}
       *   });
       * });	        
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
            destory: null,
        },
        dataTypes: {
            tabs: "array",  
            contextualTabs: "array", 		
            disabledItemIndex: "data",
            enabledItemIndex: "data",
            selectedItemIndex: "number",
        },
		/**
         * destroy the ribbon widget
		 * all events bound using this._on will be unbind automatically and bring the control to pre-init state.
		 * @alias ejRibbon#destroy
		 * @return jQuery
		 * @example 
		 * &lt;script&gt;
		 * var ribbonObj = $("#Ribbon").data("ejRibbon");
		 * ribbonObj.destroy(); // destroy the ribbon
		 * &lt;/script&gt;
		 * @example 
		 * &lt;script&gt;
		 * // destroy the ribbon
		 * $("#Ribbon").ejRibbon("destroy");        
		 * &lt;/script&gt;
         */
        _destroy: function () {
            this.element.ejTab('destroy');
            this.element.find('.e-contextul').removeAttr("style");
        },
        _tags: [{
            tag: "tabs", attr: ["id", "text", [{
                tag: "groups", attr: ["text", "alignType", "type", "contentID", [{
                    tag: "content", attr: ["defaults.type", "defaults.width", "defaults.height", "defaults.isBig", [{
                        tag: "groups", attr: ["id", "contentID", "text", "type", "toolTip", "width", "enableSeparator", "buttonSettings.contentType",
                                                    "buttonSettings.imagePosition", "buttonSettings.prefixIcon", "buttonSettings.click", "buttonSettings.width",
                                                    "splitButtonSettings.contentType", "splitButtonSettings.prefixIcon", "splitButtonSettings.targetID",
                                                    "splitButtonSettings.buttonMode", "splitButtonSettings.arrowPosition", "splitButtonSettings.click",
                                                    "dropdownSettings.dataSource", "dropdownSettings.text", "dropdownSettings.value", "dropdownSettings.select", "dropdownSettings.width",
                                                    "toggleButtonSettings.contentType", "toggleButtonSettings.defaultText", "toggleButtonSettings.activeText",
                                                    "toggleButtonSettings.defaultPrefixIcon", "toggleButtonSettings.activePrefixIcon", "toggleButtonSettings.click"]
                    }]]
                }]]
            }]]
        }, {
            tag: "contextualTabs", attr: ["backgroundColor", "borderColor", [{
                tag: "tabs", attr: ["id", "text", [{
                    tag: "groups", attr: ["text", "alignType", "type", "contentID", [{
                        tag: "content", attr: ["defaults.type", "defaults.width", "defaults.height", "defaults.isBig", [{
                            tag: "groups", attr: ["id", "contentID", "text", "type", "toolTip", "width", "enableSeparator", "buttonSettings.contentType",
                                                        "buttonSettings.imagePosition", "buttonSettings.prefixIcon", "buttonSettings.click", "buttonSettings.width",
                                                        "splitButtonSettings.contentType", "splitButtonSettings.prefixIcon", "splitButtonSettings.targetID",
                                                        "splitButtonSettings.buttonMode", "splitButtonSettings.arrowPosition", "splitButtonSettings.click",
                                                        "dropdownSettings.dataSource", "dropdownSettings.text", "dropdownSettings.value", "dropdownSettings.select", "dropdownSettings.width",
                                                        "toggleButtonSettings.contentType", "toggleButtonSettings.defaultText", "toggleButtonSettings.activeText",
                                                        "toggleButtonSettings.defaultPrefixIcon", "toggleButtonSettings.activePrefixIcon", "toggleButtonSettings.click"]
                        }]]
                    }]]
                }]]
            }]
            ]
        }],
        _setModel: function (options) {
            for (var key in options) {
                switch (key) {
                    case "selectedItemIndex":
                        if (this.model.selectedItemIndex > 0 && this._tabObj.model.disabledItemIndex.indexOf(this.model.selectedItemIndex) === -1 && this._ribbonTabs.eq(this.model.selectedItemIndex).is(':visible'))
                            this._tabObj.option({ selectedItemIndex: this.model.selectedItemIndex });
                        break;
                    case "disabledItemIndex":
                        var conParent, disableLen = this.model.disabledItemIndex.length;
                        var curDisabled = this.model.disabledItemIndex, aTag = this.element.find('.e-link'), activeTab;
                        this.model.disabledItemIndex.push(0);
                        this._tabObj.option({ disabledItemIndex: this.model.disabledItemIndex });
                        for (var k = 0; k < disableLen; k++) {
                            conParent = this._ribbonTabs.eq(curDisabled[k]).parent().parent();
                            if (conParent.hasClass('e-contextli') || conParent.hasClass('e-contextliset'))
                                conParent.addClass("e-disable");
                            if (this._tabObj.model.selectedItemIndex !=0 && this._tabObj.model.selectedItemIndex === curDisabled[k]) {
                                activeTab = aTag.eq(curDisabled[k]).attr("href");
                                $(activeTab).append($("#" + this._id + "_disabled"));
                                $(activeTab).css("position", "relative");
                                $("#" + this._id + "_disabled").show();
                            }
                        }
                        break;
                    case "enabledItemIndex":
                        var conParent, enableLen = this.model.enabledItemIndex.length;
                        for (var k = 0; k < enableLen; k++) {
                            if (this.model.enabledItemIndex[k] === 0 || !(this._ribbonTabs.eq(this.model.enabledItemIndex[k]).is(':visible'))) {
                                this.model.enabledItemIndex.splice(k, 1);
                                --enableLen;
                                --k;
                            }
                        }
                         						    
                        this._conTabsRemove();
                        this._tabObj.option({ enabledItemIndex: this.model.enabledItemIndex });
                        this._contextualTabs();
                        for (var i = 0; i < this.model.enabledItemIndex.length; i++) {
                            this._tabText.eq(this.model.enabledItemIndex[i]).parent().removeClass("e-disable");
                            this._tabText.eq(this.model.enabledItemIndex[i]).parent().css("position", "");
                            conParent = this._ribbonTabs.eq(this.model.enabledItemIndex[i]).parent().parent();
                            if (conParent.hasClass('e-contextli') || conParent.hasClass('e-contextliset'))
                                conParent.removeClass("e-disable");
						    if(this.model.enabledItemIndex[i]==this._tabObj.model.selectedItemIndex)
							 $("#" + this._id + "_disabled").hide();
                        }
                        break;
                }
            }
        },
		
		_setTabContentHeight: function()
		{
			var contents = this.element.find(".e-groupdiv"), contentHeight = [];
			for(var i = 0; i < contents.length; i++)
				contentHeight.push($(contents[i]).height());
			contentHeight.sort();
			this.element.find(".e-content").height(contentHeight[contentHeight.length - 1]);
		},
		
        _init: function () {
            if (!ej.isNullOrUndefined(this.element)) {
                this._render();
                this._wireEvents();
            }
        },
        _render: function () {
            this._renderTab();
            this._initPrivateProperties();
            this._groupingControls();
            this._customization();
			$("#" + this._id).append(ej.buildTag("div#" + this._id + "_disabled"));
    	    var content = $("#" + this._id).find(".e-content");
            $("#" + this._id + "_disabled").height($(content).height()).width(this.model.width);
			$("#" + this._id + "_disabled").css({top:0, left:0 , position: "absolute"}).addClass("e-disable");
			$("#" + this._id + "_disabled").hide();
			if(this.model.disabledItemIndex.length===0){
            this.model.disabledItemIndex.push(0);
            this._tabObj.option({ disabledItemIndex: this.model.disabledItemIndex });
            }
        },
        _onGroupClick: function (args) {
            this._trigger("groupClick", args);
			if (ej.raiseWebFormsServerEvents && !ej.isNullOrUndefined(this.model.serverEvents)) {
			if (this.model.serverEvents.indexOf("groupClick") != -1) {
              var modelRibbon = $.extend(true, {}, this.model),controlId;
              controlId=(args.target.id)?args.target.id:args.target.parentNode.id;
		      var argsRibbon = { model: modelRibbon, originalEventType: "groupClick",id:controlId};
              var clientArgs = { model: modelRibbon,id:controlId};
              ej.raiseWebFormsServerEvents("groupClick", argsRibbon, clientArgs);
			}
			}
        },
        _onTabClick: function (args) {
            var expandCollapse = this.element.find('.e-rarrowdown-2x'), active = this.element.find('li.e-active');
            var collapse = this.element.find('.e-collapseactive'), aTag, href;
            var activeContent = this.element.find('.e-active-content');

            if (active.length > 0) {
                active.removeClass("e-active");
                activeContent.removeClass("e-active-content").hide();
            }
            else {
                if (collapse.length > 0) {
                    if (args.activeHeader.textContent === collapse.find('.e-link').text()) {
                        collapse.addClass("e-active").removeClass("e-collapseactive");
                        activeContent.removeClass("e-collapse-content").slideDown("slow");
                    }
                    else {
                        aTag = this.element.find('.e-link');
                        collapse.removeClass("e-collapseactive");
                        this.element.find('.e-collapse-content').removeClass("e-collapse-content");
                        activeContent.removeClass("e-active-content");
                        href = aTag.eq(args.activeIndex).attr("href");
                        aTag.eq(args.activeIndex).addClass("e-active");
                        $(href).slideDown("slow");
                    }
                }
            }
            if (expandCollapse.length > 0) {
                expandCollapse.parent().removeClass("e-collapsed").addClass("e-expanded");
                expandCollapse.removeClass("e-rarrowdown-2x").addClass("e-rarrowup-2x");
                this._isCollapsed = false;
            }
            this._trigger("onTabClick", args);
        },
		_onTabSelect: function (args) {
		    var active = this.element.find('li.e-active'),aTag,href,disable;
		    this.model.selectedItemIndex=args.activeIndex;
			if(!active.hasClass("e-disable"))
			  {
			   aTag = this.element.find('.e-link');
			   href = aTag.eq(args.activeIndex).attr("href");
			   disable=$(href).find("#" + this._id + "_disabled");
			   if(disable)
			    $("#" + this._id + "_disabled").hide();
			  }
			this._trigger("onTabSelect", args);
			
			 if (ej.isOnWebForms && ej.raiseWebFormsServerEvents && !ej.isNullOrUndefined(this.model.serverEvents)) {
			if (this.model.serverEvents.indexOf("onTabSelect") != -1) {
              var modelRibbon = $.extend(true, {}, this.model);
		      var argsRibbon = { model: modelRibbon, originalEventType: "onTabSelect",activeIndex:args.activeIndex,prevActiveIndex:args.prevActiveIndex};
              var clientArgs = { model: modelRibbon, activeIndex:args.activeIndex,prevActiveIndex:args.prevActiveIndex};
              ej.raiseWebFormsServerEvents("onTabSelect", argsRibbon, clientArgs);
			}
			}
		},
		_onTabAdd: function (args) {
			this._trigger("onTabAdd", args);
		},
		_onTabRemove: function (args) {
			this._trigger("onTabRemove", args);
		},
		_beforeTabRemove: function (args) {
			this._trigger("beforeTabRemove", args);
		},
		_create: function (args) {
			this._trigger("onTabCreate", args);
		},
		 _OnKeyDown: function (e) {
		 if(e.keyCode === 38 || e.keyCode === 39){
		   if(this.model.tabs.length===this._tabObj.model.selectedItemIndex)
			  e.stopImmediatePropagation();
			}
        },
        collapse: function () {
            var activeContent = this.element.find('.e-active-content'), togglecontent = this.element.find("#" + this._id + "_togglebutton");
            activeContent.slideUp("fast", "swing");
            this.element.find('li.e-active').removeClass("e-active").addClass("e-collapseactive e-select");
            activeContent.addClass("e-collapse-content");
			this._tabObj.option({ selectedItemIndex: 0 });
            togglecontent.removeClass("e-expanded").addClass("e-collapsed");
            togglecontent.find("span").removeClass("e-rarrowup-2x").addClass("e-rarrowdown-2x");
            this._isCollapsed = true;
        },
        expand: function () {
            var activeContent = this.element.find('.e-active-content'), togglecontent = this.element.find("#" + this._id + "_togglebutton");
            activeContent.slideDown("fast", "swing");
            this.element.find('.e-collapseactive').addClass("e-active").removeClass("e-collapseactive");
            activeContent.removeClass("e-collapse-content");
            togglecontent.removeClass("e-collapsed").addClass("e-expanded");
            togglecontent.find("span").removeClass("e-rarrowdown-2x").addClass("e-rarrowup-2x");
            this._isCollapsed = false;
        },
        _onGroupExpandClick: function (e) {
            this._trigger("groupExpand", e);
        },
        _onApplicationTabClick: function (args) {
            this._trigger("applicationTabClick", args);
        },
        _initPrivateProperties: function () {
            this._tabUl = this.element.find('.e-header');
            this._applicationTab = this.element.find('.e-apptab');
            this._ribbonTabs = this._tabUl.find(":not('a')");
            this._tabText = this.element.find('.e-link');
            this._id = this.element.attr("id");
            this._tabObj = this.element.data("ejTab");
            this._isCollapsed = false;
			this._contextualTabSet = "";
        },
        _getLocalizedLabels: function (property) {
            return ej.Ribbon.Locale[this.model.locale][property] === undefined ? ej.Ribbon.Locale["en-US"][property] : ej.Ribbon.Locale[this.model.locale][property];
        },
       _customization: function () {
            var toggleelm, model = {},li;
            this._contextualTabs();
            toggleelm = '<div id=' + this._id + '_togglebutton class="e-expanded"><span class="e-icon e-rarrowup-2x"></span></div>';
            li = ej.buildTag("li#" + this._id + "_" + "expandCollapse.e-expandcollapse", toggleelm);
            this._tabUl.append(li);
            this._applicationTab.click($.proxy(this._onApplicationTabClick, this));
			this._applicationTab.find('.e-link').hide();
            if (this.model.applicationTab.menuSettings)
                model = this.model.applicationTab.menuSettings;
            $("#" + this.model.applicationTab.itemID).appendTo(this._applicationTab);
            $("#" + this.model.applicationTab.itemID).ejMenu(model);            
            $("#" + this._id + "_" + this.model.applicationTab.Type.replace(/\s/g, '')).hide();
            this.element.find('.e-content').css("box-sizing","content-box");
        },
		_conTabsRemove:function () {
			var cntxTabs=this.element.find(".e-contextli,.e-contextliset"),$cntxTab;
			for(var i=0;i<cntxTabs.length;i++){
				$cntxTab = $(cntxTabs[i]);
				$cntxTab.is(":visible") ? $cntxTab.find("li").insertAfter($cntxTab.eq(0)) : $cntxTab.find("li").hide().insertAfter($cntxTab.eq(0));
				$cntxTab.remove();
			}				
	    },
		_contextualTabs:function () {
			var curcontextualTabSet, li, ul;
			
			 if (this.model.contextualTabs) {
                for (var i = 0; i < this.model.contextualTabs.length; i++) {
                    curcontextualTabSet = this.model.contextualTabs[i];
                     if(curcontextualTabSet.tabs.length>0){
                    li = ej.buildTag("li.e-contextliset"); //.hide();
                    this._contextualTabSet = this._tabUl.children('.e-contextualtabset').filter(function (index) { return $(this).text() === curcontextualTabSet.tabs[0].text; });
					this._contextualTabSet.before(li);
					this._tabUl.children('.e-contextualtabset').find('a').css("color",curcontextualTabSet.borderColor);
                    ul = ej.buildTag("ul.e-contextul", "", {
                        'background': curcontextualTabSet.backgroundColor,
						'border-top-color':curcontextualTabSet.borderColor
                    });
                    for (var j = 0; j < curcontextualTabSet.tabs.length; j++) {
                        ul.append(this._tabUl.children('.e-contextualtabset').filter(function (index) { return $(this).text() === 
						curcontextualTabSet.tabs[j].text; }));
                    }
                    ul.appendTo(li);
                    }
                }
            }
		},
        showContextualTab: function (text) {
            this.element.find(".e-contexttitle").filter(function (index) { return $(this).text() === text; }).parent().parent().show();
        },
        hideContextualTab: function (text) {
            this.element.find(".e-contexttitle").filter(function (index) { return $(this).text() === text; }).parent().parent().hide();
            this._tabObj.option({ selectedItemIndex: this._tabObj.model.selectedItemIndex + 1 });
        },
		  /**
       * It is used to hide the given text tab in the ribbon control.
       * @alias hideTab
       * @return jQuery
	   * @param {srting} string  text of the tab item.  
       * @example 	   
       *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;/button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         }]
       *   });
       * });	        
       * //initialize the Ribbon object
       *	var ribbonObj = $("#Ribbon").data("ejRibbon");
       *	// hide the given text tab item in the ribbon control.
       *	ribbonObj.hideTab("HOME");
       * &lt;/script&gt;  
       * @example 
	   *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;/button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         }]
       *   });
       * });	               
       * $("#Ribbon").ejRibbon("hideTab","HOME"); 
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
        hideTab: function (text) {
			var index = this._tabText.map(function (index) { if($(this).text() === text)return index; })[0], updatedindex,disLen=this._tabObj.model.disabledItemIndex.length,hide=true;
			for(var i=0;i<disLen;i++){
			if(this._tabObj.model.disabledItemIndex[i]===index)
			  hide=false;
			}
			if(hide){
			if(this._isContextualTab(index))
				this._tabText.filter(function (index) { return $(this).text() === text; }).parents(".e-contextli").first().hide();						
			else
				this._tabText.filter(function (index) { return $(this).text() === text; }).parent().hide();
			updatedindex = this._getVisibleItemIndex(this._tabText);
			}
			if(updatedindex)
				this._tabObj.option("selectedItemIndex", updatedindex);			
        },
		 /**
       * It is used to show the given text tab in the ribbon control.
       * @alias showTab
       * @return jQuery
	   * @param {srting} string  text of the tab item.  
       * @example 	   
       *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;/button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         }]
       *   });
       * });	        
       * //initialize the ribbon object
       *	var ribbonObj = $("#Ribbon").data("ejRibbon");
       *	// hide the given text tab item in the ribbon control.
       *	ribbonObj.showTab("HOME");
       * &lt;/script&gt;  
       * @example 
	  *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;/button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         }]
       *   });
       * });	               
       * $("#Ribbon").ejRibbon("showTab","HOME"); 
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
		showTab: function (text) {
			var index = this._tabText.map(function (index) { if($(this).text() === text)return index; })[0];
			if(this._isContextualTab(index))
				this._tabText.filter(function (index) { return $(this).text() === text; }).parents(".e-contextli").first().show();						
			else
				this._tabText.filter(function (index) { return $(this).text() === text; }).parent().show();
        },
		_getVisibleItemIndex:function(items){
			var i = 0;   
			while(i < items.length){
			if($(items[i]).is(":visible"))
				return i;
			i++;
			}			
		},
		_isContextualTab:function(index){
		     var contextualtabs = this.model.contextualTabs.tabs, i=0;
			 if(contextualtabs){
			     while(i < contextualtabs.length){
					if(this.model.tabs[index-1].id === contextualtabs[i].id)
						return true;
					i++;
				 }
			 }
			 return false;
		},
		/**
       * It is used to remove the given index tab item from the ribbon control.
       * @alias removeTab
       * @return jQuery
	   * @param {number} index  index of tab item.  
       * @example 	   
       *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;/button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         }]
       *   });
       * });	        
       * //initialize the Ribbon object
       *	var ribbonObj = $("#Ribbon").data("ejRibbon");
       *	// Remove the given index tab item from the ribbon control.
       *	ribbonObj.removeTab(1);
       * &lt;/script&gt;  
       * @example 
	  *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;/button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         }]
       *   });
       * });	               
       * $("#Ribbon").ejRibbon("removeTab",1); 
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
        removeTab: function (tabIndex) {
            var curTab, href;
            if (this._tabObj.model) {
                if (tabIndex > 0) {
                    this._ribbonTabs = this._tabUl.find(".e-link").parent();
                    href = this._ribbonTabs.eq(tabIndex).children().attr("href");
                    curTab = this._ribbonTabs.eq(tabIndex);
                    if (curTab.hasClass("e-contextualtab"))
                        curTab.parent().remove();
                    else if (curTab.hasClass("e-contextualtabset")) {
                        if (curTab.siblings('.e-contextualtabset').length === 0)
                            curTab.parent().remove();
                        else
                            curTab.remove();
                    }
                    else
                        curTab.remove();
                    $(href).remove();
                    if (this._tabObj.model.selectedItemIndex === tabIndex) {
                        this._ribbonTabs = this._tabUl.find(".e-link").parent();
                        curTab = this._ribbonTabs.eq(tabIndex);
                        curTab.addClass("e-active");
                        href = curTab.children().attr("href");
                        $(href).addClass("e-active-content e-activetop").show();
                    }
                }
            }
        },
		addTab: function (tabText,ribbonGroups,index) {
		    var rTab={id: tabText.replace(/\s/g, ''), text: tabText, groups:ribbonGroups},tabLen=this.model.tabs.length,ribbonModel;
		    if(ej.isNullOrUndefined(index))
		     index=this._tabUl.find(".e-select,.e-active").length;
			if(index>0){
			this._conTabsRemove();
            this._tabObj.addItem("#"+this._id+"_"+tabText.replace(/\s/g, ''),tabText,index);
			this._contextualTabs();
			this._tabUl.find(".e-select,.e-active").eq(index).addClass("e-tab");
			this._tabUl.find(".e-select > a,.e-active > a ").eq(index).addClass("e-link");
			this.model.tabs[tabLen]=rTab;
			ribbonModel=$.extend(true,{},this.model);
			for(var i=0;i<tabLen;i++)
			{
			  this.model.tabs[i].groups=[];
			}
			for(var i=0;i<this.model.contextualTabs.length;i++)
			{
			for(var j=0;j<this.model.contextualTabs[i].tabs.length;j++)
			{
			  this.model.contextualTabs[i].tabs[j].groups=[];
			}
			}
			this._groupingControls();
			this.model=ribbonModel;
			this.element.find('.e-content').css("box-sizing","content-box");
			}
	    },
		addContextualTabSet: function (contextualTabSet,index) {
		 var tabSetLen=this.model.contextualTabs.length,ribbonModel;
		 if(ej.isNullOrUndefined(index))
		  index=this._tabUl.find(".e-select,.e-active").length;
		  if(index>0){
		  this._conTabsRemove();
		   for(var i=0;i<contextualTabSet.tabs.length;i++)
			{
			this._tabObj.addItem("#"+this._id+"_"+contextualTabSet.tabs[i].id,contextualTabSet.tabs[i].text,index);
			this._tabUl.find(".e-select,.e-active").eq(index).addClass("e-contextualtabset");
			this._tabUl.find(".e-select > a ,.e-active > a ").eq(index).addClass("e-link");
			++index;
			}
			if(this.model.contextualTabs[0].tabs.length > 0)
			 this.model.contextualTabs[tabSetLen]=contextualTabSet;
			else
			 this.model.contextualTabs[0]=contextualTabSet;
			this._contextualTabs();
            ribbonModel=$.extend(true,{},this.model);
			for(var i=0;i<this.model.tabs.length;i++)
			{
			  this.model.tabs[i].groups=[];
			}
			if(this.model.contextualTabs[0].tabs.length > 0){
			for(var i=0;i<tabSetLen;i++)
			{
			if(i!=tabSetLen-1){
			for(var j=0;j<this.model.contextualTabs[i].tabs.length;j++)
			{
			  this.model.contextualTabs[i].tabs[j].groups=[];
			}
			}
			}
			}
			this._groupingControls();
			this.model=ribbonModel;		
            this.element.find('.e-content').css("box-sizing","content-box");	
         }			
		},
		/**
       * It is used to set new text to the given text tab in the ribbon control.
       * @alias setTabText
       * @return jQuery
	   * @param {string} string  current text of the tab item.  
	   * @param {string} string  new text of the tab item.  
       * @example 	   
       *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;/button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         }]
       *   });
       * });	        
       * //initialize the Ribbon object
       *	var ribbonObj = $("#Ribbon").data("ejRibbon");
       *	// Set new text to the given text tab in the ribbon control.
       *	ribbonObj.setTabText("HOME","NEW");
       * &lt;/script&gt;  
       * @example 
	   *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;/button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         }]
       *   });
       * });	               
       * $("#Ribbon").ejRibbon("setTabText","HOME","NEW"); 
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
        setTabText: function (oldText, newText) {
            this._tabText.filter(function (index) { return $(this).text() === oldText; }).text(newText);
        },
		 /**
       * It is used to get text of the given index tab in the ribbon control.
       * @alias getTabText
       * @return Text of the given index tab in the ribbon control.
	   * @param {number} index  index of the tab item.  
       * @example 	   
       *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;/button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         }]
       *   });
       * });	        
       * //initialize the Ribbon object
       *	var ribbonObj = $("#Ribbon").data("ejRibbon");
       *	// To get text of the given index tab in the ribbon control.
       *	ribbonObj.getTabText(1);
       * &lt;/script&gt;  
       * @example 
	   *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;/button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         }]
       *   });
       * });	            
       * $("#Ribbon").ejRibbon("getTabText",1); 
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
        getTabText: function (index) {
            var tabText = this._tabText.eq(index).text();
            return tabText;
        },
		 /**
       * It is used to check given text tab in the ribbon control is visible or not.
       * @alias isVisible
       * @return true if it is visible,false if it is invisible
	   * @param {srting} string  text of the tab item.  
       * @example 	   
       *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;/button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         }]
       *   });
       * });	        
       * //initialize the Ribbon object
       *	var ribbonObj = $("#Ribbon").data("ejRibbon");
       *	//  To check given text tab in the ribbon control is visible or not.
       *	ribbonObj.isVisible("HOME");
       * &lt;/script&gt;  
       * @example 
	  *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;/button&gt;
       *&lt;script type="text/javascript"&gt;  
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         }]
       *   });
       * });	              
       * $("#Ribbon").ejRibbon("isVisible","HOME"); 
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
        isVisible: function (text) {
            var tab = this._tabText.filter(function (index) { return $(this).text() === text; }).parent();
            return (tab.is(':visible'));
        },
		 /**
       * It is used to check given text tab in the ribbon control is enabled or not.
       * @alias isEnable
       * @return true if it is in enabled state,false if it is in disabled state.
	   * @param {srting} string  text of the tab item.  
       * @example 	   
       *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;/button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         }]
       *   });
       * });	        
       * //initialize the Ribbon object
       *	var ribbonObj = $("#Ribbon").data("ejRibbon");
       *	//  To check given text tab in the ribbon control is enabled or not.
       *	ribbonObj.isEnable("HOME");
       * &lt;/script&gt;  
       * @example 
	   *&lt;ul id="menu"&gt;
	   *&lt;li&gt;&lt;a&gt;FILE &lt;/a&gt;
       *&lt;ul&gt;
       *&lt;li&gt;&lt;a&gt;New&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Open&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Save as&lt;/a&gt;&lt;/li&gt;
       *&lt;li&gt;&lt;a&gt;Print&lt;/a&gt;&lt;/li&gt;
	   *&lt;/ul&gt;&lt;/li&gt;&lt;/ul&gt;
       *&lt;div id="Ribbon"&gt;&lt;/div&gt; 
	   *&lt;button id="btn"&gt;Home button&lt;/button&gt;
       *&lt;script type="text/javascript"&gt;   
       *$(function () {
       *     $("#Ribbon").ejRibbon({
	   * // Set the width during initialization. 	
       *      width: "100%",
       *        applicationTab: { Type: "ApplicationMenu", itemID: "menu", menuSettings: { openOnClick: false } },
       *        tabs: [{
       *            id: "home", text: "HOME", groups: [{
       *                 text: "New", alignType: ej.Ribbon.alignType.rows,type:"custom",contentID:"btn"
       *            }]
       *         }]
       *   });
       * });	           
       * $("#Ribbon").ejRibbon("isEnable","HOME"); 
       * &lt;/script&gt;  
       * @memberof ejRibbon
       * @instance
       */
        isEnable: function (text) {
            var isEnable = true, tabIndex = this._tabText.filter(function (index) { return $(this).text() === text; }).parent().index();
            for (var i = 0; i < this.model.disabledItemIndex.length; i++) {
                if (this.model.disabledItemIndex[i] == tabIndex)
                    isEnable = false;
            }
            return isEnable;
        },
        _renderTab: function () {
            var ul = ej.buildTag("ul"), li, aTag, appTab = this.model.applicationTab.Type, tabs,contextualTabs,contextualTabSet, i, j;
            aTag = ej.buildTag("a", "", {}, { href: "#" + this._id + "_" + appTab.replace(/\s/g, '') });
            li = ej.buildTag("li.e-apptab", aTag);
            ul.append(li);

            for (i = 0; i < this.model.tabs.length; i++) {
                tabs = this.model.tabs[i];
                aTag = ej.buildTag("a", tabs.text, {}, { href: "#" + this._id + "_" + tabs.id });
                li = ej.buildTag("li", aTag).addClass("e-tab");
                ul.append(li);
            }
             if (this.model.contextualTabs) {
                for (i = 0; i < this.model.contextualTabs.length; i++) {
                  if(this.model.contextualTabs[i].tabs){
                    for (j = 0; j < this.model.contextualTabs[i].tabs.length; j++) {
                        contextualTabSet = this.model.contextualTabs[i].tabs[j];
                        aTag = ej.buildTag("a", contextualTabSet.text, {}, { href: "#" + this._id + "_" + contextualTabSet.id });
                        li = ej.buildTag("li", aTag).addClass("e-contextualtabset");
                        ul.append(li);
                        }
                   }
                }
            }
            this.element.append(ul);
            this.element.ejTab({ width:this.model.width,disabledItemIndex: this.model.disabledItemIndex, enabledItemIndex: this.model.enabledItemIndex, itemActive: $.proxy(this._onTabSelect, this), beforeActive: $.proxy(this._onTabClick, this), itemAdd: $.proxy(this._onTabAdd, this), itemRemove: $.proxy(this._onTabRemove, this), beforeItemRemove: $.proxy(this._beforeTabRemove, this), create: $.proxy(this._create, this), selectedItemIndex: this.model.selectedItemIndex });
        },
        _groupingControls: function () {
            var tabLen = this.model.tabs.length, contextualTab, tabs, groupDiv, innerDiv, innerDivCustom, innerDivChild, contDiv, centerAlign = false, groupexpander, captionArea,contentbottom,model = {},tabcont;
            var m = 0, split, button, dropdown,custom,toggle,separatorDiv, lastControl, t, k, l, i, j,tabGroupText,ribbonModel=$.extend(true,{},this.model);
			if (this.model.contextualTabs) {
			for (var k = 0; k < this.model.contextualTabs.length; k++) {
			    contextualTab = this.model.contextualTabs[k];
                 if(contextualTab.tabs){
				for (var l = 0; l < contextualTab.tabs.length; l++) {
				   if(contextualTab.tabs[l].groups.length > 0){
					this.model.tabs[tabLen] = contextualTab.tabs[l];
					++tabLen;
					}
                  }
				}
			  }
			}
            for (i = 0; i < this.model.tabs.length; i++) {
                tabs = this.model.tabs[i];
                for (j = 0; j < tabs.groups.length; j++) {
				 if (!ej.isNullOrUndefined(tabs.groups[j])){
				    tabGroupText =ej.isNullOrUndefined(tabs.groups[j].text) ? tabs.groups[j].text : tabs.groups[j].text.replace(/\s/g, '');
                    contDiv = ej.buildTag("div#" + this._id + "_" + tabs.id + "_" + tabGroupText + "_content");
                    if (tabs.groups[j].type === "custom") {
                        if (!tabs.groups[j].contentID)
                            innerDivCustom = ej.buildTag("div#" + this._id + "_" + tabs.id + "_" + tabGroupText + "_" + tabs.groups[j].type + "_" + j, tabs.groups[j].customContent).addClass("e-innerdiv");
                        else {
                            innerDivCustom = ej.buildTag("div#" + this._id + "_" + tabs.id + "_" + tabGroupText + "_" + tabs.groups[j].type + "_" + j).addClass("e-innerdiv");
                            $("#" + tabs.groups[j].contentID).appendTo(innerDivCustom);
                        }
                        contDiv.append(innerDivCustom);
                    }
                    else {
                        if (tabs.groups[j].content) {
                            for (var l = 0; l < tabs.groups[j].content.length; l++) {
							  if(tabs.groups[j].content[l]!=undefined){
                                var subGroup = tabs.groups[j].content[l].groups;
                                var defaults = tabs.groups[j].content[l].defaults;
                                if (tabs.groups[j].content.length == 1)
                                    centerAlign = true;
								 if(ej.isNullOrUndefined(tabs.groups[j].alignType))
								   tabs.groups[j].alignType = ej.Ribbon.alignType.rows;
                                if (tabs.groups[j].alignType === ej.Ribbon.alignType.columns)
                                    innerDiv = ej.buildTag("div#" + this._id + "_" + tabs.id + "_" + tabGroupText + "_" + m).addClass("e-innerdiv");
                                else if (tabs.groups[j].alignType === ej.Ribbon.alignType.rows) {
                                    innerDiv = ej.buildTag("div#" + this._id + "_" + tabs.id + "_" + tabGroupText + "_" + m).addClass("e-innerdivrow");
                                    ++m;
                                }
                                for (var m = 0; m < subGroup.length; m++) {
								 if (!ej.isNullOrUndefined(subGroup[m])){
                                    if (!ej.isNullOrUndefined(defaults))
									  {
									  if(!ej.isNullOrUndefined(defaults.type))
                                        subGroup[m].type = defaults.type;
										}
                                    if (ej.isNullOrUndefined(subGroup[m].type))
									  subGroup[m].type=ej.Ribbon.type.button;
                                    if (ej.isNullOrUndefined(subGroup[m].isBig) && !ej.isNullOrUndefined(defaults))
                                        subGroup[m].isBig = defaults.isBig;
                                    if (ej.isNullOrUndefined(subGroup[m].height) && !ej.isNullOrUndefined(defaults))
                                        subGroup[m].height = defaults.height;
                                    if (ej.isNullOrUndefined(subGroup[m].width) && !ej.isNullOrUndefined(defaults))
                                        subGroup[m].width = defaults.width;
								    if (subGroup[m].type === ej.Ribbon.type.custom) {
									    custom=subGroup[m];
									    if (tabs.groups[j].alignType === ej.Ribbon.alignType.columns){
                                            innerDivChild = ej.buildTag("div#" + this._id + "_" + tabs.id + "_" + tabGroupText + "_" + custom.toolTip).addClass("e-controlpadding").attr("title", custom.toolTip);
											$("#" + custom.contentID).appendTo(innerDivChild);
											}
                                        else if (tabs.groups[j].alignType === ej.Ribbon.alignType.rows){
                                            innerDivChild = ej.buildTag("div#" + this._id + "_" + tabs.id + "_" + tabGroupText + "_" +custom.toolTip).addClass("e-innerdivchild e-controlpadding").attr("title", custom.toolTip);
											$("#" + custom.contentID).appendTo(innerDivChild);
                                        }
									    if (!ej.isNullOrUndefined(defaults)) {
									        if (!ej.isNullOrUndefined(defaults.height))
									            innerDivChild.children().height(defaults.height);
									        if (!ej.isNullOrUndefined(defaults.width))
									            innerDivChild.children().width(defaults.width);
									    }
											if(!ej.isNullOrUndefined(custom.isBig))
										{
                                        (custom.isBig) ? innerDivChild.children().addClass("e-big") : innerDivChild.children().addClass("e-small");
										}
											innerDiv.append(innerDivChild);
											if (subGroup[m].enableSeparator) {
                                            if (tabs.groups[j].alignType === ej.Ribbon.alignType.rows) {
                                                separatorDiv = ej.buildTag("div#" + this._id + "_" + "separator" + "_" + custom.toolTip).addClass("e-separatordivrow");
												if(!ej.isNullOrUndefined(defaults)){
												(!ej.isNullOrUndefined(defaults.height))?separatorDiv.height(defaults.height):(custom.isBig) ? separatorDiv.addClass("e-big") : separatorDiv.addClass("e-small");
												}
												else
												 separatorDiv.addClass("e-small");
                                                innerDiv.append(separatorDiv);
                                            }
                                        }
									 }
                                     else if (subGroup[m].type === ej.Ribbon.type.splitButton) {
                                        split = subGroup[m];
                                        this._splitButtonControl = ej.buildTag("button#" + this._id + "_" + split.id, split.text,{},{ type: "button"}).addClass(split.cssClass);
                                        if (tabs.groups[j].alignType === ej.Ribbon.alignType.columns)
                                            innerDivChild = ej.buildTag("div#" + this._id + "_" + tabs.id + "_" + tabGroupText + "_" + split.id, this._splitButtonControl).addClass("e-controlpadding").attr("title", split.toolTip);
                                        else if (tabs.groups[j].alignType === ej.Ribbon.alignType.rows)
                                            innerDivChild = ej.buildTag("div#" + this._id + "_" + tabs.id + "_" + tabGroupText + "_" + split.id, this._splitButtonControl).addClass("e-innerdivchild e-controlpadding").attr("title", split.toolTip);
                                         model = {}
                                        if (split.splitButtonSettings)
                                            model = split.splitButtonSettings;
                                         model.height = ej.isNullOrUndefined(model.height)?  subGroup[m].height :model.height;
                                        model.width = ej.isNullOrUndefined(model.width)? subGroup[m].width:model.width;
                                        this._splitButtonControl.ejSplitButton(model);
                                        if(!ej.isNullOrUndefined(split.isBig))
										{
                                        (split.isBig) ? innerDivChild.children().removeAttr("style").addClass("e-big") : innerDivChild.children().removeAttr("style").addClass("e-small");
										}
                                        innerDiv.append(innerDivChild);
                                        if (subGroup[m].enableSeparator) {
                                            if (tabs.groups[j].alignType === ej.Ribbon.alignType.rows) {
                                                separatorDiv = ej.buildTag("div#" + this._id + "_" + "separator" + "_" + split.id).addClass("e-separatordivrow");
												(!ej.isNullOrUndefined(model.height))?separatorDiv.height(model.height):(split.isBig) ? separatorDiv.addClass("e-big") : separatorDiv.addClass("e-small");
                                                innerDiv.append(separatorDiv);
                                            }
                                        }
                                    }
									 else if (subGroup[m].type === ej.Ribbon.type.toggleButton) {
                                        toggle = subGroup[m];
										this._toggleButtonControl = ej.buildTag("input#" + this._id + "_" + toggle.id, "", "", { type: "checkbox" }).addClass(toggle.cssClass);
                                        if (tabs.groups[j].alignType === ej.Ribbon.alignType.columns)
                                            innerDivChild = ej.buildTag("div#" + this._id + "_" + tabs.id + "_" + tabGroupText + "_" + toggle.id, this._toggleButtonControl).addClass("e-controlpadding").attr("title", toggle.toolTip);
                                        else if (tabs.groups[j].alignType === ej.Ribbon.alignType.rows)
                                            innerDivChild = ej.buildTag("div#" + this._id + "_" + tabs.id + "_" + tabGroupText + "_" + toggle.id, this._toggleButtonControl).addClass("e-innerdivchild e-controlpadding").attr("title", toggle.toolTip);
                                         model = {}
                                        if (toggle.toggleButtonSettings)
                                            model = toggle.toggleButtonSettings;
                                         model.height = ej.isNullOrUndefined(model.height)?  subGroup[m].height :model.height;
                                        model.width = ej.isNullOrUndefined(model.width)? subGroup[m].width:model.width;
                                        this._toggleButtonControl.ejToggleButton(model);
                                        if(!ej.isNullOrUndefined(toggle.isBig))
										{
                                        (toggle.isBig) ? innerDivChild.find('.e-togglebutton.e-tbtn.e-btn').addClass("e-big") : innerDivChild.find('.e-togglebutton.e-tbtn.e-btn').addClass("e-small");
										}
                                        innerDiv.append(innerDivChild);
                                        if (subGroup[m].enableSeparator) {
                                            if (tabs.groups[j].alignType === ej.Ribbon.alignType.rows) {
                                                separatorDiv = ej.buildTag("div#" + this._id + "_" + "separator" + "_" + toggle.id).addClass("e-separatordivrow");
												(!ej.isNullOrUndefined(model.height))?separatorDiv.height(model.height):(toggle.isBig) ? separatorDiv.addClass("e-big") : separatorDiv.addClass("e-small");
                                                innerDiv.append(separatorDiv);
                                            }
                                        }
                                    }
                                    else if (subGroup[m].type === ej.Ribbon.type.button) {
                                        button = subGroup[m];
                                        if(button.buttonSettings){
                                        if(button.buttonSettings.type)
                                         this._buttonControl = ej.buildTag("button#" + this._id + "_" + button.id, button.text,{},{ type: button.buttonSettings.type}).addClass(button.cssClass);
										else
										 this._buttonControl = ej.buildTag("button#" + this._id + "_" + button.id, button.text).addClass(button.cssClass);
										 }
										 else
										    this._buttonControl = ej.buildTag("button#" + this._id + "_" + button.id, button.text).addClass(button.cssClass);
                                        if (tabs.groups[j].alignType === ej.Ribbon.alignType.columns)
                                            innerDivChild = ej.buildTag("div#" + this._id + "_" + tabs.id + "_" + tabGroupText + "_" + button.id, this._buttonControl).addClass("e-controlpadding").attr("title", button.toolTip);
                                        else if (tabs.groups[j].alignType === ej.Ribbon.alignType.rows)
                                            innerDivChild = ej.buildTag("div#" + this._id + "_" + tabs.id + "_" + tabGroupText + "_" + button.id, this._buttonControl).addClass("e-innerdivchild e-controlpadding").attr("title", button.toolTip);
                                         model = {}
                                        if (button.buttonSettings)
                                            model = button.buttonSettings;
                                         model.height = ej.isNullOrUndefined(model.height)?  subGroup[m].height :model.height;
                                        model.width = ej.isNullOrUndefined(model.width)? subGroup[m].width:model.width;
                                        this._buttonControl.ejButton(model);
                                       if(!ej.isNullOrUndefined(button.isBig))
										{
                                        (button.isBig) ? innerDivChild.children().addClass("e-big") : innerDivChild.children().addClass("e-small");
										}
                                        innerDiv.append(innerDivChild);
                                        if (subGroup[m].enableSeparator) {
                                            if (tabs.groups[j].alignType === ej.Ribbon.alignType.rows) {
                                                separatorDiv = ej.buildTag("div#" + this._id + "_" + "separator" + "_" + button.id).addClass("e-separatordivrow");
												(!ej.isNullOrUndefined(model.height))?separatorDiv.height(model.height):(button.isBig) ? separatorDiv.addClass("e-big") : separatorDiv.addClass("e-small");
                                                innerDiv.append(separatorDiv);
                                            }
                                        }
                                    }
                                    else if (subGroup[m].type === ej.Ribbon.type.dropDownList) {
                                        dropdown = subGroup[m];
                                        this._dropdownControl = ej.buildTag("input#" + this._id + "_" + dropdown.id, { type: "text" }).addClass(dropdown.cssClass);
                                        var innerDivChild;
                                        if (tabs.groups[j].alignType === ej.Ribbon.alignType.columns && dropdown.dropdownSettings)
                                            innerDivChild = ej.buildTag("div#" + this._id + "_" + tabs.id + "_" + tabGroupText + "_" + dropdown.id, this._dropdownControl).append($("#" + dropdown.dropdownSettings.targetID)).addClass("e-controlpadding").attr("title", dropdown.toolTip);
                                        else if (tabs.groups[j].alignType === ej.Ribbon.alignType.rows && dropdown.dropdownSettings)
                                            innerDivChild = ej.buildTag("div#" + this._id + "_" + tabs.id + "_" + tabGroupText + "_" + dropdown.id, this._dropdownControl).append($("#" + dropdown.dropdownSettings.targetID)).addClass("e-innerdivchild e-controlpadding").attr("title", dropdown.toolTip);
                                         model = {};
                                        if (dropdown.dropdownSettings)
                                            model = dropdown.dropdownSettings;
                                          model.height = ej.isNullOrUndefined(model.height)?  subGroup[m].height :model.height;
                                        model.width = ej.isNullOrUndefined(model.width)? subGroup[m].width:model.width;
                                        this._dropdownControl.ejDropDownList(model);
                                        innerDiv.append(innerDivChild);
                                        if (subGroup[m].enableSeparator) {
                                            if (tabs.groups[j].alignType === ej.Ribbon.alignType.rows) {
                                                separatorDiv = ej.buildTag("div#" + this._id + "_" + "separator" + "_" + dropdown.id).addClass("e-separatordivrow");
												(!ej.isNullOrUndefined(model.height))?separatorDiv.height(model.height):separatorDiv.addClass("e-small");
                                                innerDiv.append(separatorDiv);
                                            }
                                        }
                                    }
                                    contDiv.append(innerDiv);
                                }
							  }
                            }
						  }
                        }
                    }
                    contentbottom = ej.buildTag("div.e-contentbottom");
                    captionArea = ej.buildTag("div.e-captionarea", this.model.tabs[i].groups[j].text);
                    contentbottom.append(captionArea);
                    if (this.model.tabs[i].groups[j].enableGroupExpander) {
                        groupexpander = ej.buildTag("div#" + this._id + "_" + this.model.tabs[i].groups[j].text + "_e-groupexpander.e-icon e-expander e-groupexpander");
                        contentbottom.append(groupexpander);
                    }
                    groupDiv = ej.buildTag("div#" + this._id + "_" + tabs.id + "_" + tabGroupText).addClass("e-groupdiv").click($.proxy(this._onGroupClick, this));
                    if (centerAlign) {
                        groupDiv.addClass("e-centeralign");
                        centerAlign == false;
                    }
                    tabs.groups[j].width && groupDiv.width(tabs.groups[j].width);
                    groupDiv.append(contDiv);
                    groupDiv.append(contentbottom);
                    tabcont = this.element.find("#" + this._id + "_" + tabs.id);
					tabcont.append(groupDiv).addClass("e-parentdiv");
                }
			  }
            }
			this._setTabContentHeight();
			this.model=ribbonModel;
        },

        _tabExpandCollapse: function (e) {
            var target, args, action;
            target = e.target.tagName == "div" ? e.target : e.target.parentNode;
            action = target.className == "e-expanded" ? "collapse" : "expand";
            args = { target: $(target), type: e.type, action: action, cancel: false };
            this._trigger("onToggleButtonClick", args);
            if (args.cancel)
                return;
            target.className == "e-expanded" ? this.collapse() : this.expand();
        },

        _wireEvents: function () {
		    this._on(this.element, "keydown", this._OnKeyDown);
            this._on(this.element.find("#" + this._id + "_togglebutton"), ej.eventType.click, this._tabExpandCollapse);
            this._on(this.element.find(".e-groupexpander"), ej.eventType.click, this._onGroupExpandClick);
        }
    });
    ej.Ribbon.alignType = {
        rows: "rows",
        columns: "columns"
    };
    ej.Ribbon.type = {
        button: "button",
        splitButton: "splitbutton",
        dropDownList: "dropdownlist",
		custom:"custom",
		toggleButton:"togglebutton"
    };
    ej.Ribbon.Locale = {};

    ej.Ribbon.Locale["en-US"] = {
        ExpandCollapse: "Expand Collapse"
    };
})(jQuery, Syncfusion);