/*!
*  filename: ej.gantt.js
*  version : 12.3
*  Copyright Syncfusion Inc. 2001 - 2014. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
*/
(function (fn) {
    typeof define === 'function' && define.amd ? define(["./../common/ej.core","./../common/ej.data","./../common/ej.draggable","./../common/ej.scroller","./ej.button","./ej.splitter","./ej.dialog","./ej.datepicker","./ej.checkbox","./ej.dropdownlist","./ej.editor","./ej.toolbar"], fn) : fn();
})
(function () {
	
/**
* @fileOverview Plugin to create the Gantt
* @copyright Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/

(function ($, ej, undefined) {
    /**
* @namespace ej
* @class ejGantt
* @requires jQuery
* @requires jquery.globalize.js
* @requires jquery.easing.1.3.js
* @requires jsrender.js
* @requires ej.web.all.js
* @classdesc Custom Design for Html Gantt control.
* @example 
* &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
* &lt;script&gt;
* // Create Gantt
* $('#gantt').ejGantt(); 	
* &lt;/script&gt;
*/
   
    ej.widget("ejGantt", "ej.Gantt", {

        // widget element will be automatically set in this
        _rootCSS: "e-gantt",

        element: null,

        validTags: ["div"],
        // user defined model will be automatically set in this
        model: null,
        _tags: [{
            tag: "holidays",
            attr: ["day", "background", "label"],
            content: "template"
        },
        {
            tag: "stripLines",
            attr: ["day", "label", "lineStyle", "lineColor", "lineWidth"],
            content: "template"
        },
         {
             tag: "editDialogFields",
             attr: ["field", "editType"],
             content: "template"
         },
         {
             tag: "addDialogFields",
             attr: ["field", "editType"],
             content: "template"
         },
         {
            tag: "sortSettings.sortedColumns",
            attr: ["field","direction"]
         }
        ],
        _holidays: function (index, property, value, old) {
            $("div.e-secondary-canvas-holiday").remove();
            this._$ganttchartHelper.ejGanttChart("refreshHolidays");
            this._trigger("refresh");
        },
        _stripLines: function (index, property, value, old) {
            $("div.e-stripLines").remove();
            this._$ganttchartHelper.ejGanttChart("refreshStripLines");
            this._trigger("refresh");
        },
        _editDialogFields: function (index, property, value, old) {
            this._trigger("refresh");
        },
        _addDialogFields: function (index, property, value, old) {
            this._trigger("refresh");
        },
        defaults: {
            /**		
            * Enables or disables sorting. When enabled, we can sort the column by clicking on the column.
            * @default false
            * @type {boolean}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;        
            * 	$("#gantt").ejGantt({ allowSorting:  true });            
            * &lt;/script&gt;
            * @memberof ejGantt
			* @instance
            */
            allowSorting: false,

            /**		
            * Enables or disables the ability to resize column.
            * @default false
            * @type {boolean}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;                   
            * 	$("#gantt").ejGantt({ allowColumnResize:  true });			* 
            * &lt;/script&gt;
            * @memberof ejGantt
			* @instance
            */
            allowColumnResize: false,

            /**		
            * Enables or disables the interactive selection of a row.
            * @default true
            * @type {boolean}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;   
            * 	$("#gantt").ejGantt({ allowSelection:  true });			* 
            * &lt;/script&gt;
            * @memberof ejGantt
			* @instance
            */
            allowSelection: true,

            /**		
            * Collection of data or hierarchical data  to represent in gantt
            * @default 
            * @type {array}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt; 		
            * 	$("#gantt").ejGantt(
            *  {
            *     dataSource:[{Id:2,TaskName:"Testing",startDate:"12/1/2000",Duration:5 }]	
            *  });		
            * &lt;/script&gt;
            * @memberof ejGantt
			* @instance
            */
            dataSource:null,

            /**		
            * It receives query to retrieve data from the table (query is same as SQL). 
            * @default 
            * @type {object}
            * @example
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;  			
            * 	$("#gantt").ejGantt(
            *  {
            *     query:ej.Query().from("Categories").select("CategoryID,CategoryName").take(3);	
            *  });		
            * &lt;/script&gt;
            * @memberof ejGantt
			* @instance
            */
            query: null,

           /**		
           * Specifies the mapping property path for task Id in datasource
           * @default ""
           * @type {string}
           * @example 
           * &lt;div id="gantt"&gt;&lt;/div&gt; 
           * &lt;script&gt;  				
           * 	$("#gantt").ejGantt({  taskIdMapping : "ID" });	
           * &lt;/script&gt;
           * @memberof ejGantt
			* @instance
           */
            taskIdMapping: "",

            /**		
            * Specifies the mapping property path for parent task Id in selfreference datasource
            * @default ""
            * @type {string}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;  		
            * 	$("#gantt").ejGantt({  parentTaskIdMapping : "ID" });	            
            * &lt;/script&gt;
            * @memberof ejGantt
			* @instance
            */
            parentTaskIdMapping: "",
            
            /**		
            * Specifies the mapping property path for task name in datasource
            * @default ""
            * @type {string}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;		
            * 	$("#gantt").ejGantt({  taskNameMapping : "Name" });	
            * &lt;/script&gt;
            * @memberof ejGantt
			* @instance
            */
            taskNameMapping: "",

            /**		
            * Specifies the mapping property path for start date of a task  in datasource
            * @default ""
            * @type {string}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;		 			
            * 	$("#gantt").ejGantt({  startDateMapping : "startdate" });	         
            * &lt;/script&gt;
            * @memberof ejGantt
			* @instance
            */
            startDateMapping: "",

            /**		
           * Specifies the mapping property path for end Date of a task  in datasource
           * @default ""
           * @type {string}
           * @example 
           * &lt;div id="gantt"&gt;&lt;/div&gt; 
           * &lt;script&gt;				
           * 	$("#gantt").ejGantt({  endDateMapping : "EndDate" });	
           * &lt;/script&gt;
           * @memberof ejGantt
		   * @instance
           */
            endDateMapping: "",

            /**		
           * Specifies the mapping property path for baseline start date of a task  in datasource
           * @default ""
           * @type { string}
           * @example 
           * &lt;div id="gantt"&gt;&lt;/div&gt; 
           * &lt;script&gt;			
           * 	$("#gantt").ejGantt({  baselineStartDateMapping : "BaselineStartDate" });		
           * &lt;/script&gt;
           * @memberof ejGantt
			* @instance
           */
            baselineStartDateMapping: "",

            /**		
            *Specifies the mapping property path for baseline end date in datasource
            * @default ""
            * @type {string}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#gantt").ejGantt({  baselineEndDateMapping : "BaselineEndDate" });
            * &lt;/script&gt;
            * @memberof ejGantt
			* @instance
            */
            baselineEndDateMapping: "",

            /**		
            * Specifies the mapping property path for sub tasks in datasource 
            * @default ""
            * @type {string}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;				
            * 	$("#gantt").ejGantt({  childMapping : "Children" });
            * &lt;/script&gt;
            * @memberof ejGantt
			* @instance
            */
            childMapping: "",

           /**		
           * Specifies the mapping property path for duration of a task in datasource
           * @default ""
           * @type {string}
           * @example 
           * &lt;div id="gantt"&gt;&lt;/div&gt; 
           * &lt;script&gt;		
           * 	$("#gantt").ejGantt({  durationMapping : "Duration" });
           * &lt;/script&gt;
           * @memberof ejGantt
			* @instance
           */
            durationMapping: "",

            /**		
           * Specifies the mapping property path for milestone in datasource
           * @default ""
           * @type {string}
           * @example 
           * &lt;div id="gantt"&gt;&lt;/div&gt; 
           * &lt;script&gt;				
           * 	$("#gantt").ejGantt({  milestoneMapping : "milestone" });	
           * &lt;/script&gt;
           * @memberof ejGantt
			* @instance
           */
            milestoneMapping: "",

           /**		
           *Specifies the mapping property path for  progress percentage  of a task in datasource
           * @default ""
           * @type {string}
           * @example 
           * &lt;div id="gantt"&gt;&lt;/div&gt; 
           * &lt;script&gt;			
           * 	$("#gantt").ejGantt({  progressMapping : "progress" });			
           * &lt;/script&gt;
           * @memberof ejGantt
			* @instance
           */
            progressMapping: "Progress",

            /**		
           *Specifies the mapping property path for predecessors  of a task in datasource
           * @default ""
           * @type {string}
           * @example 
           * &lt;div id="gantt"&gt;&lt;/div&gt; 
           * &lt;script&gt;				
           * 	$("#gantt").ejGantt({  predecessorMapping : "predecessor" });		
           * &lt;/script&gt;
           * @memberof ejGantt
			* @instance
           */
            predecessorMapping: "",

            /**		
            * Specifies the mapping property path for resources of a task in datasource
            * @default ""
            * @type {string}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;				
            * 	$("#gantt").ejGantt({  resourceInfoMapping : "resources" });	
            * &lt;/script&gt;
            * @memberof ejGantt
			* @instance
            */
            resourceInfoMapping: "",

            /**		
           * Collection of data  regarding resources involved in entire project       
           * @default []
           * @type {array}
           * @example 
           * &lt;div id="gantt"&gt;&lt;/div&gt; 
           * &lt;script&gt;			
           * 	$("#gantt").ejGantt(
           *  {
           *    resources:[{id:1; name:"jack" }]	
           *  });		
           * &lt;/script&gt;
           * @memberof ejGantt
			* @instance
           */
            resources: [],

            /**		
           * Collection of holidays with date, background and label information to be displayed in gantt. 
           * @default []
           * @type {array}
           * @example 
           * &lt;div id="gantt"&gt;&lt;/div&gt; 
           * &lt;script&gt;				
           * 	$("#gantt").ejGantt(
           *  {
           *    holidays:[{day:"12/2/2000",background:"cyan",label:"local holiday" }]	
           *  });		
           * &lt;/script&gt;
           * @memberof ejGantt
		   * @instance
           */
            holidays: [],


            /**		
           * Specifies whether to highlight the weekends in gantt .
           * @default true
           * @type {boolean}
           * @example 
           * &lt;div id="gantt"&gt;&lt;/div&gt; 
           * &lt;script&gt;	
           * 	$("#gantt").ejGantt({ highlightWeekends:  true });			* 
           * &lt;/script&gt;
           * @memberof ejGantt
			* @instance
           */
            highlightWeekends: true,

            /**		
           * Specifies start date of the gantt schedule. By default, start date will be rounded to its previous Sunday.
           * @default null
           * @type {string}
           * @example 
           * &lt;div id="gantt"&gt;&lt;/div&gt; 
           * &lt;script&gt;				
           * 	$("#gantt").ejGantt(
           *  {
           *     scheduleStartDate:"12/2/2000"
           *  });		
           * &lt;/script&gt;
           * @memberof ejGantt
			* @instance
           */
            scheduleStartDate: null,


            /**		
           * Specifies end date of the gantt schedule. By default, end date will be rounded to its next Saturday.
           * @default null
           * @type {string}
           * @example 
           * &lt;div id="gantt"&gt;&lt;/div&gt; 
           * &lt;script&gt;	 			
           * 	$("#gantt").ejGantt(
           *  {
           *     scheduleEndDate:"12/2/2000"
           *  });		
           * &lt;/script&gt;
           * @memberof ejGantt
			* @instance
           */
            scheduleEndDate: null,

            /**		
           * Indicates whether we can edit the progress of a task interactively in gantt chart.
           * @default true
           * @type {boolean}
           * @example 
           * &lt;div id="gantt"&gt;&lt;/div&gt; 
           * &lt;script&gt;	
           * 	$("#gantt").ejGantt({ enableProgressBarResizing:  true });			
           * &lt;/script&gt;
           * @memberof ejGantt
			* @instance
           */
            enableProgressBarResizing: true,

            /**		
           * Specifies the height of a single row in gantt. Also, we need to set same height in the CSS style with class name e-rowcell. 
           * @default "30"
           * @type {number}
           * @example 
           * &lt;div id="gantt"&gt;&lt;/div&gt; 
           * &lt;script&gt;				
           * 	$("#gantt").ejGantt({  
           *			rowHeight : 30,
           * 			});
           * &lt;/script&gt;
           * @memberof ejGantt
			* @instance
           */
            rowHeight: 30,

           /**		
           * Specifies whether to include weekends while calculating the duration of a task. 
           * @default true
           * @type {boolean}
           * @example 
           * &lt;div id="gantt"&gt;&lt;/div&gt; 
           * &lt;script&gt;	
           * 	$("#gantt").ejGantt({ includeWeekend:  true });			
           * &lt;/script&gt;
           * @memberof ejGantt
			* @instance
           */
            includeWeekend: true,

            /**		
			* Specifies the toolbarSettings options.
			* @type {object}
            * @memberof ejGantt
			* @instance
			*/
            toolbarSettings: {

                /**		
                * Specifies the state of enabling or disabling toolbar
                 * @alias ejGantt#toolbarSettings->showToolBar
                * @default true
                * @type {boolean}
                * @example 
                * &lt;div id="gantt"&gt;&lt;/div&gt; 
                * &lt;script&gt;	
                * 	$("#gantt").ejGantt({ showToolBar:  true });			 
                * &lt;/script&gt;
                * @memberof ejGantt
			    * @instance
                */
                showToolbar: false,


                /**		
                * Specifies the list of toolbar items to rendered in toolbar
                * @alias ejGantt#toolbarSettings->toolbarItems
                * @default []
                * @type {array}
                * @example 
                * &lt;div id="gantt"&gt;&lt;/div&gt; 
                * &lt;script&gt;	
                * 	$("#gantt").ejGantt({ toolbarItems: [ej.Gantt.ToolbarItems.Add,ej.Gantt.ToolbarItems.Edit] });			 
                * &lt;/script&gt;
                * @memberof ejGantt
			    * @instance
                */
                toolbarItems: []
            },

            /**		
            * Specifies the options for striplines
            * @default "[]"
            * @type {string}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#gantt").ejGantt(stripLines: [
            *    {
            *     day: "12/2/2000,
            *     label: "Project Release",
            *     lineStyle: "dotted",
            *     lineColor: "Darkblue",
            *     lineWidth: 2
            *   }
            * ]); 
            * &lt;/script&gt;
            * @memberof ejGantt
			* @instance
            */
            stripLines: [],            
            /**		
            * Specifies the working time schedule fo day           
            * @default "TimeScale24"
            * @type {enum}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;				
            * 	$("#gantt").ejGantt({  
            *			workingTimeScale : "TimeScale24Hours" 
            });
            * &lt;/script&gt;
            * @memberof ejGantt
			* @instance
            */
            workingTimeScale: 'TimeScale8Hours',


            /**		
            * Specifies whether rounding off the day working time edits
          
            * @default "true"   
            * @type {boolean}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;				
            * 	$("#gantt").ejGantt({  
            *			roundOffDayworkingTime : true });
            * &lt;/script&gt;
            * @memberof ejGantt
            * @instance
            */
            roundOffDayworkingTime: true,

            /**		
            * Specifies the duration unit for each tasks whether days or hours
           
            * @default "day"
            * @type {enum}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;				
            * 	$("#gantt").ejGantt({  
            *			durationUnit : day });
            * &lt;/script&gt;
            * @memberof ejGantt
            * @instance
            */
            durationUnit: 'day',
            /**		
            * Specified the format for weekview for schedule header
            * @alias ejGantt#scheduleHeaderSettings->weekHeaderFormat
            * @default "MMM dd , yyyy"
            * @type {string}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;				
            * 	$("#gantt").ejGantt({  
            *			scheduleHeaderSettings:{weekHeaderFormat : "MMM dd , yyyy" }
            });
            * &lt;/script&gt;              
            */
            /**		
			* Specifies the options for customizing schedule header. 
			* @type {object}
            * @memberof ejGantt
			* @instance
			*/
            scheduleHeaderSettings:
            {
                /**		
               * Specified the format for week view in schedule header
               * @alias ejGantt#scheduleHeaderSettings->weekHeaderFormat
               * @default "ddd"
               * @type {string}
               * @example 
               * &lt;div id="gantt"&gt;&lt;/div&gt; 
               * &lt;script&gt;				
               * 	$("#gantt").ejGantt({  
               *			scheduleHeaderSettings:{weekHeaderFormat : "MMM dd , yyyy" }
               });
               * &lt;/script&gt;                                  */
                
                weekHeaderFormat: "MMM dd , yyyy",

                /**		
                * Specified the format for day view in schedule header
                * @alias ejGantt#scheduleHeaderSettings->dayHeaderFormat
                * @default "ddd"
                * @type {string}
                * @example 
                * &lt;div id="gantt"&gt;&lt;/div&gt; 
                * &lt;script&gt;				
                * 	$("#gantt").ejGantt({  
                *			scheduleHeaderSettings:{dayHeaderFormat : "ddd" }
                });
                * &lt;/script&gt;              
		
                */
                dayHeaderFormat: "ddd",

                /**		
               * Specified the format for year view in schedule header
               * @alias ejGantt#scheduleHeaderSettings->yearHeaderFormat
               * @default "yyyy"
               * @type {string}
               * @example 
               * &lt;div id="gantt"&gt;&lt;/div&gt; 
               * &lt;script&gt;				
               * 	$("#gantt").ejGantt({  
               *			scheduleHeaderSettings:{yearHeaderFormat : "yyyy" }
               });
               * &lt;/script&gt;               
               */
                yearHeaderFormat: "yyyy",

                /**		
               * Specified the format for month view in schedule header
               * @alias ejGantt#scheduleHeaderSettings->monthHeaderFormat
               * @default "MMM"
               * @type {string}
               * @example 
               * &lt;div id="gantt"&gt;&lt;/div&gt; 
               * &lt;script&gt;				
               * 	$("#gantt").ejGantt({  
               *			scheduleHeaderSettings:{monthHeaderFormat : "MMM" }
               });
               * &lt;/script&gt;              
               */
                monthHeaderFormat: "MMM",


                /**		
                * Specified the background for weekends in gantt
                * @alias ejGantt#scheduleHeaderSettings->hourHeaderFormat
                * @default "#F2F2F2"
                * @type {string}
                * @example 
                * &lt;div id="gantt"&gt;&lt;/div&gt; 
                * &lt;script&gt;			
                * 	$("#gantt").ejGantt({  
                *			scheduleHeaderSettings:{hourHeaderFormat : 'HH'}
                });
                * &lt;/script&gt;               
                */
                hourHeaderFormat: 'HH',

                /**		
               * Specifies the schedule mode
               * @alias ejGantt#scheduleHeaderSettings->scheduleHeaderType
               * @default "week"
               * @type {enum}
               * @example 
               * &lt;div id="gantt"&gt;&lt;/div&gt; 
               * &lt;script&gt;				
               * 	$("#gantt").ejGantt({  
               *			scheduleHeaderSettings:{scheduleHeaderType : "week"}
               });
               * &lt;/script&gt;              
               */
                scheduleHeaderType: 'week',


                /**		
                * Specified the background for weekends in gantt
                * @alias ejGantt#scheduleHeaderSettings->weekendBackground
                * @default "#F2F2F2"
                * @type {string}
                * @example 
                * &lt;div id="gantt"&gt;&lt;/div&gt; 
                * &lt;script&gt;			
                * 	$("#gantt").ejGantt({  
                *			scheduleHeaderSettings:{weekendBackground : "#F2F2F2"}});
                * &lt;/script&gt;
                */
                weekendBackground: '#F2F2F2'


            },

            /**		
            * Specifies the background of the taskbar in gantt
            * @default ""
            * @type {string}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;	
            * 	$("#gantt").ejGantt({  
            *			taskbarBackground : "#F2F2F2"});
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            taskbarBackground: "",

            /**		
            *Specifies the background of progressbar in gantt
            * @default ""
            * @type {string}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;	
            * 	$("#gantt").ejGantt({  
            *			progressbarBackground : "#F2F2F2"});
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            progressbarBackground: "",

            /**		
            * Specifies the background of connector lines in Gantt
            * @default ""
            * @type {string}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;				
            * 	$("#gantt").ejGantt({  
            *			connectorLineBackground : "#F2F2F2"});
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            connectorLineBackground: "",

            /**		
            * Specifies the background of parent taskbar in gantt
            * @default ""
            * @type {string}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#gantt").ejGantt({  
            *			parentTaskbarBackground : "#F2F2F2"});
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            parentTaskbarBackground: "",

            /**		
            *Specifies the background of parent progressbar in gantt
            * @default ""
            * @type {string}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#gantt").ejGantt({  
            *			parentProgressbarBackground : "#F2F2F2"});
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */

            parentProgressbarBackground: "",

            /**		
            * Specifies the width of the connector lines in gantt
            * @default "1"
            * @type {number}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt; 			
            * 	$("#gantt").ejGantt({  
            *			connectorlineWidth : 1 });
             * &lt;/script&gt;
             * @memberof ejGantt
			   * @instance
            */
            connectorlineWidth: 1,

            /**		
            *Specifies whether to display task name beside task bar.
            * @default "true"
            * @type {boolean}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#gantt").ejGantt({  
            *			showTaskNames : true});
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            showTaskNames: true,


            /**		
            *Specifies whether to show grid cell tooltip.
            * @default "true"
            * @type {boolean}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt; 			
            * 	$("#gantt").ejGantt({  
            *			showGridCellTooltip : true});
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            showGridCellTooltip: false,

            /**		
            *Specifies whether to show grid cell tooltip over expander cell alone.
            * @default "true"
            * @type {boolean}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#gantt").ejGantt({  
            *			showGridExpandCellTooltip : true});
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            showGridExpandCellTooltip: false,

            /**		
            * Specifies whether display task progress inside taskbar.
            * @default "true"
            * @type {boolean}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#gantt").ejGantt({  
            *			showProgressStatus : true});
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            showProgressStatus: true,

            /**		
            * Specifies whether to display resource names for a task beside taskbar.
            * @default "true"
            * @type {boolean}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt; 			
            * 	$("#gantt").ejGantt({  
            *			showResourceNames : true});
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            showResourceNames: true,

            /**		
            * Enables or disables tooltip while editing (dragging/resizing) the taskbar.
            * @default "true"
            * @type {boolean}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt; 			
            * 	$("#gantt").ejGantt({  
            *			enableTaskbarDragTooltip : true});
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            enableTaskbarDragTooltip: true,

            /**		
            * Enables or disables tooltip for taskbar.
            * @default true
            * @type {boolean}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#gantt").ejGantt({  enableTaskbarTooltip : true });	
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            enableTaskbarTooltip: true,

            /**		
            * Specifies the editSettings options in gantt. 
            * @type {object}
            * @memberof ejGantt
			   * @instance
            */
            editSettings: {

            /**		
            * specifies the option for enabling / disablig editing in gantt grid part
            * @alias ejGantt#editSettings->allowEditing
            * @default false
            * @type {boolean}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#gantt").ejGantt({  editSettings:{allowEditing : true} });	
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
              allowEditing: false,

            /**		
            * enables/disables add gantt in toolbar
            * @alias ejGantt#editSettings->allowAdding
            * @default false
            * @type {boolean}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt; 			
            * 	$("#gantt").ejGantt({  editSettings:{allowAdding : true} });
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            allowAdding: false,

            /**		
            * enables/disables delete gantt in toolbar
            * @alias ejGantt#editSettings->allowDeleting
            * @default false
            * @type {boolean}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#gantt").ejGantt({  editSettings:{allowDeleting : true} });	
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
             allowDeleting: false,


            /**		
            * specifies the editmode in gantt , "normal" is for dialog editing ,"cellEditing" is for cell type editing
            * @alias ejGantt#editSettings->editMode
            * @default normal
            * @type {string}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#gantt").ejGantt({  editSettings:{editMode : "normal"} });
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
                editMode: "normal",
            },

            ganttRecords: [],
            parentRecords: [],

            /**		
            * Enables/Disables Keyboard navigation in gantt
            * @default true
            * @type {boolean}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt; 			
            * 	$("#gantt").ejGantt({ allowKeyboardNavigation : true});			
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            allowKeyboardNavigation: true,

            /**		
             * Specify the CSS class to gantt to achieve custom theme.
             * @default ""
             * @type {string}
             * @example 
             * &lt;div id="gantt"&gt;&lt;/div&gt; 
             * &lt;script&gt;		
             * 	$("#gantt").ejGantt({  cssClass : "gradient-lime" });
             * &lt;/script&gt;
             * @memberof ejGantt
			   * @instance
            */
            cssClass: "",

            /**		
            * Specify the locale for gantt
            * @default "en-US"
            * @type {string}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;		
            * 	$("#gantt").ejGantt({  locale : "it-IT" });
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            locale: "en-US",

            /**		
            * Specifies enabling / diabling multiple soting for gantt columns
            * @default false
            * @type {boolean}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#gantt").ejGantt({ allowMultiSorting : true});			
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            allowMultiSorting: false,

            /**		
            *  Specifes the sorting options for gantt.
            * @type {object}
            * @memberof ejGantt
			   * @instance
            */
            sortSettings: {
           /**		
           * Specifes the sorted columns columns for gantt
           * @alias ejGantt#sortSettings->sortedColumns
           * @default []
           * @type {array}
           * @example 
           * &lt;div id="gantt"&gt;&lt;/div&gt; 
           * &lt;script&gt;		
           * 	$("#gantt").ejGantt({ sortSettings{sortedColumns : []}});	           
           * &lt;/script&gt;
           * @memberof ejGantt
			   * @instance
            */
                sortedColumns: []
            },

           
            /**		
            * Enables/Disables enableAltRow row effect in gantt
            * @default true
            * @type {boolean}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#gantt").ejGantt({ enableAltRow : true});			
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            enableAltRow: true,

            /**		
            * Enables/Disables virtualization for rendering gantt items.
            * @default false
            * @type {boolean}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#gantt").ejGantt({ enableVirtualization : true});			
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            enableVirtualization: false,

            /**		
             * Specified the height of the progressbar in taskbar
             * @default "100"
             * @type {number}
             * @example 
             * &lt;div id="gantt"&gt;&lt;/div&gt; 
             * &lt;script&gt;		
             * 	$("#gantt").ejGantt({  
             *			progressbarHeight : 100 });
             * &lt;/script&gt;
             * @memberof ejGantt
			   * @instance
            */
            progressbarHeight: 100,

            /**		
             * Specifies the template for tooltip on mouseaction on taskbars
             * @default null
             * @type {string}
             * @example 
             * &lt;div id="gantt"&gt;&lt;/div&gt; 
             * &lt;script&gt;			
             * 	$("#gantt").ejGantt(
             *  {
             *     taskbarTooltipTemplate: ""
             *  });		
             * &lt;/script&gt;
             * @memberof ejGantt
			   * @instance
            */
            taskbarTooltipTemplate: null,

            /**		
             * Specifies the template for tooltip on resizing progressbar
             * @default null
             * @type {string}
             * @example 
             * &lt;div id="gantt"&gt;&lt;/div&gt; 
             * &lt;script&gt;		
             * 	$("#gantt").ejGantt(
             *  {
             *     progressbarTooltipTemplate: ""
             *  });		
             * &lt;/script&gt;
             * @memberof ejGantt
			   * @instance
            */
            progressbarTooltipTemplate: null,

            /**		
             * Specifies the template for tooltip on mouseaction on taskbars
             * @default null
             * @type {string}
             * @example 
             * &lt;div id="gantt"&gt;&lt;/div&gt; 
             * &lt;script&gt;		
             * 	$("#gantt").ejGantt(
             *  {
             *     taskbarTooltipTemplateId: ""
             *  });		
             * &lt;/script&gt;
             * @memberof ejGantt
			   * @instance
            */
            taskbarTooltipTemplateId: null,
            /**		
            * Specifies the dateFormat for gantt , given format is displayed in tooltip , grid .
            * @default ""
            * @type {string}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;		
            * 	$("#gantt").ejGantt(
            *  {
            *     dateFormat: "dd/MM/yyyy"
            *  });		
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            dateFormat: "",

            /**		
            * Specifies the mapping property name for resource ID in resource Collection in gantt
            * @default ""
            * @type {string}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;	
            * 	$("#gantt").ejGantt(
            *  {
            *     resourceIdMapping: "peopleID"
            *  });		
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            resourceIdMapping: "",

            /**		
            * Specifies the mapping property path for resource name of a task in gantt
            * @default ""
            * @type {string}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;		
            * 	$("#gantt").ejGantt(
            *  {
            *     resourceNameMapping: "EmployeeName"
            *  });		
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            resourceNameMapping: "",

             /**		
             * Specifies the template ID for customized tooltip for progressbar editing in gantt
             * @default null
             * @type {string}
             * @example 
             * &lt;div id="gantt"&gt;&lt;/div&gt; 
             * &lt;script&gt;	
             * 	$("#gantt").ejGantt(
             *  {
             *     progressbarTooltipTemplateId: "tooltiptemplateID"
             *  });		
             * &lt;/script&gt;
             * @memberof ejGantt
			   * @instance
             */
            progressbarTooltipTemplateId: null,

            /**		
            * Specifies the template Id for customized tooltip for taskbar editing in gantt
            * @default null
            * @type {string}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;		
            * 	$("#gantt").ejGantt(
            *  {
            *     taskbarEditingTooltipTemplateId: "TooltipTemplateId"
            *  });		
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            taskbarEditingTooltipTemplateId: null,

            /**		
            * Specifies the template Id for customized tooltip for taskbar editing in gantt
            * @default null
            * @type {string}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#gantt").ejGantt(
            *  {
            *     taskbarEditingTooltipTemplate: "tooltiptemplate"
            *  });		
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            taskbarEditingTooltipTemplate: null,

          /**		
          * Specifies the selected row Index in gantt , the row with given index is highlighted
          * @default  "-1"
          * @type {number}
          * @example 
          * &lt;div id="gantt"&gt;&lt;/div&gt; 
          * &lt;script&gt;			
          * 	$("#gantt").ejGantt(
          *  {
          *     selectedRowIndex:2
          *  });		
          * &lt;/script&gt;
          * @memberof ejGantt
			   * @instance
          */
          selectedRowIndex: -1,


         /**		
         * Enables or Disables gantt chart editing in gantt
         * @default  "true"
         * @type {boolean}
         * @example 
         * &lt;div id="gantt"&gt;&lt;/div&gt; 
         * &lt;script&gt;		
         * 	$("#gantt").ejGantt(
         *  {
         *     allowGanttChartEditing:true
         *  });		
         * &lt;/script&gt;
         * @memberof ejGantt
			   * @instance
         */
            allowGanttChartEditing: true,

         /**		
         * Specifies the size option of gantt control.
         * @type {object}
         * @memberof ejGantt
			   * @instance
         */
            sizeSettings: {
                /**		
                * Specifies the height of gantt control
                * @alias ejGantt#sizeSettings->height
                * @default  "450px"
                * @type {string}
                * @example 
                * &lt;div id="gantt"&gt;&lt;/div&gt; 
                * &lt;script&gt;			
                * 	$("#gantt").ejGantt(
                *  {
                *     sizeSettings:{height: "700px"}
                *  });		
                * &lt;/script&gt;
               
                */
                height: null,

                /**		
                * Specifies the width of gantt control
                * @alias ejGantt#sizeSettings->width
                * @default  "1000px"
                * @type {string}
                *  @example 
                * &lt;div id="gantt"&gt;&lt;/div&gt; 
                * &lt;script&gt;		
                * 	$("#gantt").ejGantt(
                *  {
                *     sizeSettings:{width: "700px"}
                *  });		
                * &lt;/script&gt;
              
                */
                width: null,
            },

          /**		
           * Specifies the selected row index in gantt
           * @default  null
           * @type {number}
           * @example 
           * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;	
           * 	$("#gantt").ejGantt(
           *  {
           *     selectedItem: 2
           *  });		
           * &lt;/script&gt;
           * @memberof ejGantt
			   * @instance
           */
           selectedItem: null,

          /**		
          * Specifies the weekendBackground color in gantt
          * @default  "#F2F2F2"
          * @type {string}
          * @example 
          * &lt;div id="gantt"&gt;&lt;/div&gt; 
          * &lt;script&gt;		
          * 	$("#gantt").ejGantt(
          *  {
          *     weekendBackground: "blue"
          *  });		
          * &lt;/script&gt;
          * @memberof ejGantt
			   * @instance
          */
            weekendBackground: '#F2F2F2',

            /**		
           * Specifies the baseline background color in gantt
           * @default  "#fba41c"
           * @type {string}
           * @example 
           * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;	
           * 	$("#gantt").ejGantt(
           *  {
           *     baselineColor: "blue"
           *  });		
           * &lt;/script&gt;
           * @memberof ejGantt
			   * @instance
           */
            baselineColor: '#fba41c',

            /**		
           * Specifies the tree expander column in gantt
           * @default  0
           * @type {number}
           * @example 
           * &lt;div id="gantt"&gt;&lt;/div&gt; 
           * &lt;script&gt;		
           * 	$("#gantt").ejGantt(
           *  {
           *     treeColumnIndex: 1
           *  });		
           * &lt;/script&gt;
           * @memberof ejGantt
		   * @instance
           */
            treeColumnIndex: 0,
            
            /**		
           * Specifies the fields to be included in the edit dialog in gantt
           * @default  []
           * @type {Array}
           * @example 
           * &lt;div id="gantt"&gt;&lt;/div&gt; 
           * &lt;script&gt;			
           * 	$("#gantt").ejGantt(
           *  {
           *     editDialogFields: [{ field: "taskId", editType: "stringedit" }]
           *  });		
           * &lt;/script&gt;
           * @memberof ejGantt
			   * @instance
           */
            editDialogFields: [],
            

             /**		
           * Specifies the fields to be included in the add dialog in gantt
           * @default  []
           * @type {Array}
           * @example 
           * &lt;div id="gantt"&gt;&lt;/div&gt; 
           * &lt;script&gt;			
           * 	$("#gantt").ejGantt(
           *  {
           *     addDialogFields: [{ field: "taskId", editType: "stringedit" }]
           *  });		
           * &lt;/script&gt;
           * @memberof ejGantt
			   * @instance
           */
            addDialogFields: [],
            /**		
            * Enables or Disables rendering baselines in Gantt , when enabled baseline is rendered in gantt
            * @default  "false"
            * @type {boolean}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;		
            * 	$("#gantt").ejGantt(
            *  {
            *     renderBaseline: false
            *  });		
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            renderBaseline: false,

            /**		
            * Enables or disables the contextmenu for gantt , when enabled contextmenu appears on right clicking gantt
            * @default  "false"
            * @type {boolean}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#gantt").ejGantt(
            *  {
            *     enableContextMenu: false
            *  });		
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            enableContextMenu: false,

           

            /**		
            * Enables or disables the option for dynamically updating the Gantt size on window resizing
            * @default  "false"
            * @type {boolean}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#gantt").ejGantt(
            *  {
            *     enableResize: false
            *  });		
            * &lt;/script&gt;
            * @memberof ejGantt
		    * @instance
            */
            enableResize:false,

            /**		
            * Enables or disables the collapse all tasks for gantt , when enabled all sub tasks will disappears in gantt
            * @default  "false"
            * @type {boolean}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#gantt").ejGantt(
            *  {
            *     enableCollapseAll: false
            *  });		
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            enableCollapseAll: false,
            /**    
			* Triggered before the row is going to be selected.
			* @event
			* @name ejGantt#rowSelecting 
			* @param {Object} argument Arguments when rowSelecting event is triggered.  
			* @param {boolean} argument.cancel Returns the cancel option value.
			* @param {object} argument.rowElement Returns the selecting row element.
			* @param {string} argument.recordIndex Returns the index of selecting row record.
			* @param {object} argument.data Returns the data selecting record.
			* @example 
			* &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;
			* $("#gantt").ejGantt({
			*    rowSelecting: function (args) {}
			* });
			* &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            rowSelecting: null,

            /**    
			* Triggered after the row is selected.
			* @event
			* @name ejGantt#rowSelected 
			* @param {Object} argument Arguments when rowSelected event is triggered.  
			* @param {boolean} argument.cancel Returns the cancel option value.
			* @param {object} argument.rowElement Returns the selecting row element.
			* @param {string} argument.recordIndex Returns the index of selecting row record.
			* @param {object} argument.data Returns the data of selected record.
			* @example 
			* &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;
			* $("#gantt").ejGantt({
			*    rowSelected: function (args) {}
			* });
			* &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            rowSelected: null,

            /**    
            * Triggered while rendering each cell in the grid tree
            * @event
            * @name ejGantt#queryCellInfo 
            * @param {Object} argument Arguments when queryCellInfo event is triggered.  
            * @param {boolean} argument.cancel Returns the cancel option value.
            * @param {object} argument.rowElement Returns the selecting row element.
            * @param {string} argument.cellValue Returns the value of cell.
            * @param {object} argument.data Returns the data of current cell record.
            * @param {object} argument.column Returns the column of cell belongs.
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#gantt").ejGantt({
            *    queryCellInfo: function (args) {}
            * });
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            queryCellInfo: null,

            /**    
            * Triggered while rendering each taskbar in the gantt chart
            * @event
            * @name ejGantt#queryTaskbarInfo 
            * @param {Object} argument Arguments when queryTaskbarInfo event is triggered.  
            * @param {boolean} argument.cancel Returns the cancel option value.
            * @param {object} argument.TaskbarBackground Returns the taskbar background of current item.
            * @param {string} argument.ProgressbarBackground Returns the progressbar background of current item.
            * @param {object} argument.data Returns the data of the record.
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#gantt").ejGantt({
            *    queryTaskbarInfo: function (args) {}
            * });
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            queryTaskbarInfo: null,

            /**    
            * Triggered while enter the edit mode in the grid tree cell
            * @event
            * @name ejGantt#beginEdit 
            * @param {Object} argument Arguments when beginEdit event is triggered.  
            * @param {boolean} argument.cancel Returns the cancel option value.
            * @param {object} argument.rowElement Returns the row element of editing cell.
            * @param {object} argument.cellElement Returns the Element of editing cell.
            * @param {object} argument.data Returns the data of current cell record.
            * @param {number} argument.columnIndex Returns the column Index of cell belongs.
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#gantt").ejGantt({
            *    beginEdit: function (args) {}
            * });
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            beginEdit: null,

            /**    
            * Triggered after save the modified cellValue in treegrid
            * @event
            * @name ejGantt#endEdit 
            * @param {Object} argument Arguments when endEdit event is triggered.  
            * @param {boolean} argument.cancel Returns the cancel option value.
            * @param {object} argument.rowElement Returns the row element of editing cell.
            * @param {object} argument.cellElement Returns the Element of editing cell.
            * @param {object} argument.data Returns the data of edited cell record.
            * @param {string} argument.columnName Returns the column name of edited cell belongs.
            * @param {object} argument.columnObject Returns the column object of edited cell belongs.
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#gantt").ejGantt({
            *    endEdit: function (args) {}
            * });
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            endEdit: null,


            /**    
            * Triggered while rendering each row
            * @event
            * @name ejGantt#rowDataBound 
            * @param {Object} argument Arguments when rowDataBound event is triggered.  
            * @param {boolean} argument.cancel Returns the cancel option value.
            * @param {object} argument.rowElement Returns the row element of editing cell.
            * @param {object} argument.data Returns the data of edited cell record..
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#gantt").ejGantt({
            *    rowDataBound: function (args) {}
            * });
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            rowDataBound: null,

            /**    
            * Triggered  while expanding the gantt record
            * @event
            * @name ejGantt#expanding 
            * @param {Object} argument Arguments when expanding event is triggered.  
            * @param {boolean} argument.cancel Returns the cancel option value.
            * @param {object} argument.recordIndex Returns the row index of record.
            * @param {object} argument.data Returns the data of edited cell record..
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#gantt").ejGantt({
            *    expanding: function (args) {}
            * });
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            expanding: null,


            /**    
            * Triggered  after expand the record
            * @event
            * @name ejGantt#expanded 
            * @param {Object} argument Arguments when expanded event is triggered.  
            * @param {boolean} argument.cancel Returns the cancel option value.
            * @param {object} argument.recordIndex Returns the row index of record.
            * @param {object} argument.data Returns the data of edited cell record..
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#gantt").ejGantt({
            *    expanded: function (args) {}
            * });
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            expanded: null,

            /**    
            * Triggered while collapsing the gantt record
            * @event
            * @name ejGantt#collapsing 
            * @param {Object} argument Arguments when collapsing event is triggered.  
            * @param {boolean} argument.cancel Returns the cancel option value.
            * @param {object} argument.recordIndex Returns the row index of collapsing record.
            * @param {object} argument.data Returns the data of edited cell record..
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#gantt").ejGantt({
            *    collapsing: function (args) {}
            * });
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            collapsing: null,

            /**    
            * Triggered after collapsing the gantt record
            * @event
            * @name ejGantt#collapsed 
            * @param {Object} argument Arguments when collapsed event is triggered.  
            * @param {boolean} argument.cancel Returns the cancel option value.
            * @param {object} argument.recordIndex Returns the row index of collapsed record.
            * @param {object} argument.data Returns the data of edited cell record..
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#gantt").ejGantt({
            *    collapsed: function (args) {}
            * });
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            collapsed: null,


            /**    
            * Triggered after collapsing the gantt record
            * @event
            * @name ejGantt#actionBegin 
            * @param {Object} argument Event parameters when gantt is initialized:          
			* @param {boolean}  argument.cancel Returns the cancel option value.
			* @param {object}  argument.model Returns the grid model.
			* @param {string}  argument.type Returns the name of the event.

            * @param {Object} argument Event parameters while perform sorting in grid tree action starts:
            * @param {boolean}  argument.cancel Returns the cancel option value.
            * @param {string}  argument.columnName Returns the current grouped column field name.
			* @param {object}  argument.model Returns the gantt model.
            * @param {string}  argument.requestType Returns request type.
            * @param {string}  argument.type Returns the name of the event. 
            * @param {string}  argument.columnSortDirection Returns the direction of sorting ascending or descending
            
            * @param {Object} argument Event parameters while searching action starts:
            * @param {boolean}  argument.cancel Returns the cancel option value.
            * @param {string}  argument.keyValue Returns the value of searching element.
			* @param {object}  argument.model Returns the gantt model.
            * @param {string}  argument.requestType Returns request type.
            * @param {string}  argument.type Returns the name of the event. 
             
            * @param {Object} argument Event parameterswhile performing the delete operation starts:
            * @param {boolean}  argument.cancel Returns the cancel option value.
            * @param {string}  argument.data Returns the data od deleting element.
			* @param {object}  argument.model Returns the gantt model.
            * @param {string}  argument.requestType Returns request type.
            * @param {string}  argument.type Returns the name of the event. 

            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#gantt").ejGantt({
            *    actionBegin: function (args) {}
            * });
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            actionBegin: null,

            /**    
            * Triggered after collapsing the gantt record
            * @event
            * @name ejGantt#actionComplete 
            * @param {Object} argument Event parameters when gantt is initialized:          
			* @param {boolean}  argument.cancel Returns the cancel option value.
			* @param {object}  argument.model Returns the grid model.
			* @param {string}  argument.type Returns the name of the event.

            * @param {Object} argument Event parameters after perform the sorting in grid tree is completed:
            * @param {boolean}  argument.cancel Returns the cancel option value.
            * @param {string}  argument.columnName Returns the current grouped column field name.
			* @param {object}  argument.model Returns the gantt model.
            * @param {string}  argument.requestType Returns request type.
            * @param {string}  argument.type Returns the name of the event. 
            * @param {string}  argument.columnSortDirection Returns the direction of sorting ascending or descending
            
            * @param {Object} argument Event parameters after searching completed:
            * @param {boolean}  argument.cancel Returns the cancel option value.
            * @param {string}  argument.keyValue Returns the value of searched element.
			* @param {object}  argument.model Returns the gantt model.
            * @param {string}  argument.requestType Returns request type.
            * @param {string}  argument.type Returns the name of the event. 
             
            * @param {Object} argument Event parameterswhile performing after completing the delete operation is completed:
            * @param {boolean}  argument.cancel Returns the cancel option value.
            * @param {string}  argument.data Returns the data od deleted element.
			* @param {object}  argument.model Returns the gantt model.
            * @param {string}  argument.requestType Returns request type.
            * @param {string}  argument.type Returns the name of the event. 

            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#gantt").ejGantt({
            *    actionComplete: function (args) {}
            * });
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            actionComplete: null,

            /**    
            * Triggered while editing the gantt chart (dragging, resizing the taskbar )
            * @event
            * @name ejGantt#taskbarEditing 
            * @param {Object} argument Arguments when taskbarEditing event is triggered.  
            * @param {boolean} argument.cancel Returns the cancel option value.
			* @param {object}  argument.model Returns the gantt model.
			* @param {object}  argument.rowData Returns the row object being edited.
			* @param {object}  argument.editingFields Returns the field values of record being edited.
            * @param {string}  argument.type Returns the name of the event. 
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#gantt").ejGantt({
            *    taskbarEditing: function (args) {}
            * });
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            taskbarEditing: null,

            /**    
            * Triggered while after completing the editing operation in taskbar
            * @event
            * @name ejGantt#taskbarEdited 
            * @param {Object} argument Arguments when taskbarEdited event is triggered.  
            * @param {boolean} argument.cancel Returns the cancel option value.
            * @param {object} argument.data Returns the data of edited record.
            * @param {object} argument.previousData Returns the previous data value of edited record.  
            * @param {boolean} argument.dragging Returns 'true' if taskbar is dragged.  
            * @param {boolean} argument.leftResizing Returns 'true' if taskbar is left resized.  
            * @param {boolean} argument.rightResizing Returns 'true' if taskbar is right resized.  
            * @param {boolean} argument.progressResizing Returns 'true' if taskbar is progress resized.  
			* @param {object}  argument.editingFields Returns the field values of record being edited.
			* @param {object}  argument.model Returns the gantt model.
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#gantt").ejGantt({
            *    taskbarEdited: function (args) {}
            * });
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            taskbarEdited: null,

            /**    
            * Triggered while gantt is loaded
            * @event
            * @name ejGantt#load 
            * @param {Object} argument Arguments when load event is triggered.             
            * @param {boolean} argument.cancel Returns the cancel option value.
			* @param {object}  argument.model Returns the gantt model
            * @param {string}  argument.type Returns the name of the event. 
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#gantt").ejGantt({
            *    load: function (args) {}
            * });
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            load: null,

            /**    
            * Triggered while Context Menu is rendered in Gantt control
            * @event
            * @name ejGantt#contextMenuOpen 
            * @param {Object} argument Arguments when context menu is rendered.  
            * @param {boolean} argument.cancel Returns the cancel option value.
            * @param {boolean} argument.contextMenuItems Returns the default context menu items to which we add custom items.
			* @param {object}  argument.model Returns the gantt model.
            * @param {string}  argument.requestType Returns request type.
            * @param {string}  argument.type Returns the name of the event. 
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#gantt").ejGantt({
            *    contextMenuOpen: function (args) {}
            * });
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            contextMenuOpen: null,

        },

        dataTypes: {
            allowSorting: "boolean",
            allowColumnResize: "boolean",
            allowSelection: "boolean",
            dataSource: "data", //inline or remote data
            taskIdMapping: "string",
            taskNameMapping: "string",
            startDateMapping: "string",
            endDateMapping: "string",
            baselineStartDateMapping: "string",
            baselineEndDateMapping: "string",
            childMapping: "string",
            durationMapping: "string",
            milestoneMapping: "string",
            progressMapping: "string",
            predecessorMapping: "string",
            resourceInfoMapping: "string",
            resources: "array",
            holidays: "array",
            highlightWeekends: "boolean",
            enableProgressBarResizing: "boolean",
            rowHeight: "number",
            includeWeekend: "boolean",
            toolbarSettings: {
                toolbarItems: "array"
            },
            stripLines: "array",
            scheduleHeaderSettings: "data",
            taskbarBackground: "string",
            progressbarBackground: "string",
            connectorLineBackground: "string",
            parentTaskbarBackground: "string",
            parentProgressbarBackground: "string",
            connectorlineWidth: "number",
            showTaskNames: "boolean",
            showProgressStatus: "boolean",
            showResourceNames: "boolean",
            enableTaskbarDragTooltip: "boolean",
            enableTaskbarTooltip: "boolean",
            editSettings: "data",
            ganttRecords: "array",
            parentRecords: "array",
            allowKeyboardNavigation: "boolean",
            cssClass: "string",
            locale: "string",
            allowMultiSorting: "boolean",
            showGridExpandCellTooltip: "boolean",
            sortSettings: {
                sortedColumns: "array"
            },
            enableAltRow: "boolean",
            enableVirtualization: "boolean",
            progressbarHeight: "number",
            dateFormat: "string",
            resourceIdMapping: "string",
            resourceNameMapping: "string",
          //  selectedRowIndex: "number",
            allowGanttChartEditing: "boolean",
            size: {
                height: "string",
                width: "string"
            },
            selectedItem: "data",
            weekendBackground: "string",
            baselineColor: "string",
            renderBaseline: "boolean",
            showGridCellTooltip: "boolean",
            treeColumnIndex: "number",
            editDialogFields: "array",
            enableResize:"boolean"
        },

        observables: ["selectedItem", "selectedRowIndex","dataSource"],
        selectedItem: ej.util.valueFunction("selectedItem"),
        selectedRowIndex: ej.util.valueFunction("selectedRowIndex"),
        dataSource: ej.util.valueFunction("dataSource"),

        getColumns: function() {
            return this._columns;
        },

        setColumns: function(value) {
            this._columns = value;
        },

        _init: function () {
            var proxy = this,
                model = proxy.model, startDate, endDate;
            proxy._initPrivateProperties();
            proxy._setCultureInfo();
            proxy.element.addClass("e-gantt-core");

            if (model.isdesignMode) {
                model.taskIdMapping = "Id";
                model.taskNameMapping = "Name";
                model.startDateMapping = "StartDate";
                model.durationMapping = "Duration";
                model.progressMapping = "Progress";
                model.scheduleStartDate = "02/23/2014";
                model.scheduleEndDate = "03/10/2014";
                this.dataSource ([{ Id: 1, Name: "Task 1", StartDate: "02/23/2014", Duration: 5, Progress: 40 },
                { Id: 2, Name: "Task 2", StartDate: "02/24/2014",Duration:5,Progress:40 },
                { Id: 3, Name: "Task 3", StartDate: "02/25/2014", Duration: 5, Progress: 40 }]); 
            }
            
            if (model.durationUnit == "hours") {
                model.durationUnit = "hour";
            }
            if (this.dataSource() !== null) {
                this._checkDataBinding();
            }
            else {
                proxy.setColumns(proxy.createTreeGridColumns());
                proxy._initialize();
            }
            //
            //Call collapse All
            if (model.enableCollapseAll) {
                if (this.selectedRowIndex() != -1) {
                    proxy._deSelectRowItem();
                }
                proxy._collapseAll();
            }
            if (model.selectedRowIndex >= 0 && model.selectedRowIndex < proxy._updatedGanttRecords.length) {
                var args = {};
                args.target = "ejTreeGrid";
                model.selectedItem = args.data = proxy._updatedGanttRecords[model.selectedRowIndex];
                args.recordIndex = model.selectedRowIndex;
                proxy.rowSelected(args);
                proxy._$treegrid.focus();
            }
        },

        _deSelectRowItem: function () {
            var proxy = this, model = proxy.model;
            proxy._$ganttchartHelper.ejGanttChart("selectRows", -1);
            proxy._$treegridHelper.ejTreeGrid("selectRows", -1);
            this.selectedRowIndex(-1);
            model.selectedItem = null;
        },
        
        _checkDataBinding: function () {
            var proxy = this, model = proxy.model;

            if (this.dataSource() instanceof ej.DataManager) {
                this._initDataSource();
            }
            else if (this.dataSource().length > 0) {
                if ((model.taskIdMapping.length > 0) && (model.parentTaskIdMapping.length > 0)) {

                    //cloning the datasource
                    var dataArray = this.dataSource().slice(0);
                    var data = [];
                    $.each(dataArray, function (indx, value) {
                        data.push(jQuery.extend(true, {}, value));
                    });
                    proxy._reconstructDatasource(data);
                    proxy._createGanttRecords(proxy.secondaryDatasource);
                }
                else {
                    proxy._createGanttRecords(this.dataSource());
                }
                proxy._initialize();
            }
        },

        _initDataSource: function () {
            var proxy = this, model = proxy.model;     
            var query = this._columnToSelect();
            var proxy = this;
            var queryPromise = this.dataSource().executeQuery(query);
            queryPromise.done(ej.proxy(function (e) {
                if (proxy.dataSource().dataSource.offline) {
                    proxy._retrivedData = proxy.dataSource().dataSource.json;
                } else {
                    proxy._retrivedData = e.result;
                }
                if ((model.taskIdMapping.length > 0) && (model.parentTaskIdMapping.length > 0)) {
                    //cloning the datasource
                    var dataArray = e.result.slice(0);
                    var data = [];
                    $.each(dataArray, function (indx, value) {
                        data.push(jQuery.extend(true, {}, value));
                    });
                    proxy._reconstructDatasource(data);
                }
                else {
                    proxy._reconstructDatasource(e.result);
                }
                proxy._createGanttRecords(proxy.secondaryDatasource);
                proxy._initialize();
            }));
        },

        _columnToSelect: function (mapper) {
            var proxy = this,
                model = proxy.model,
                column = [], queryManager = ej.Query();

                queryManager = model.query;
            return queryManager;
        },

        _reconstructDatasource: function (datasource) {
            var proxy = this, model = proxy.model,
                childItems, data,tempRecord=[];
            
            for (var i = 0; i < datasource.length; i++) {
                var data = {};
                data = ej.DataManager(datasource).executeLocal(ej.Query().where(model.parentTaskIdMapping,
                    ej.FilterOperators.equal,
                    datasource[i][model.taskIdMapping]));
               

                if ((ej.isNullOrUndefined(datasource[i][model.parentTaskIdMapping]) || datasource[i][model.parentTaskIdMapping] == 0)
                    && data.length > 0) {
                    datasource[i][model.childMapping] = data;
                    proxy.secondaryDatasource.push(datasource[i]);
                }
                else if (ej.isNullOrUndefined(datasource[i][model.parentTaskIdMapping]) && !(data && data.length > 0)) {
                    proxy.secondaryDatasource.push(datasource[i]);
                }

                else if (data && data.length > 0 && !(ej.isNullOrUndefined(data[0][model.parentTaskIdMapping]))) {
                    proxy._appendChildDataItems(proxy.secondaryDatasource, data);
                }
                else if ((ej.isNullOrUndefined(datasource[i][model.parentTaskIdMapping]) || datasource[i][model.parentTaskIdMapping] == 0)
                    && data.length == 0) {
                    proxy.secondaryDatasource.push(datasource[i]);
                }

                if (data && data.length > 0) {

                    proxy._datasourceChildItems = proxy._reconstructDatasource(data);
                    if (ej.isNullOrUndefined(datasource[i][model.childMapping])) {
                        datasource[i][model.childMapping] = proxy._datasourceChildItems;
                        proxy._getParentIndex(datasource);
                    }
                    proxy._datasourceChildItems = [];

                }
                
                else if (!(ej.isNullOrUndefined(datasource[i][model.parentTaskIdMapping]))) {
                    tempRecord.push(datasource[i]);
                }
            }

            if (tempRecord && tempRecord.length > 0) {
                return tempRecord;
            }
        },


        _appendChildDataItems: function (parentDatasource, data) {
            var proxy = this,
                model = proxy.model;

            for (var count = 0; count < parentDatasource.length; count++) {

                if (parentDatasource[count][model.taskIdMapping] === data[0][model.parentTaskIdMapping]) {
                    parentDatasource[count][model.childMapping] = data;
                }
                else if (!(ej.isNullOrUndefined(parentDatasource[count][model.childMapping])) &&
                    parentDatasource[count][model.childMapping].length > 0) {
                    proxy._appendChildDataItems(parentDatasource[count], data);
                }
            }

            if ((ej.isNullOrUndefined(parentDatasource.length)) && parentDatasource) {
                if (parentDatasource[model.taskIdMapping] === data[0][model.parentTaskIdMapping]) {
                    parentDatasource[model.childMapping] = data;
                }
                else if (!(ej.isNullOrUndefined(parentDatasource[model.childMapping])) &&
                    parentDatasource[model.childMapping].length > 0) {
                    proxy._appendChildDataItems(parentDatasource[model.childMapping], data);
                }
            }

        },
        _getParentIndex: function (datasource) {
            var proxy = this, model = proxy.model,
                dataArr = proxy.secondaryDatasource, parentIndex = 0;

            if (datasource.length > 0) {
                parentIndex = datasource[0][model.parentTaskIdMapping];
            }
            for (var i = 0; i < dataArr.length; i++) {
                if (dataArr[i][model.taskIdMapping] == parentIndex && ej.isNullOrUndefined(dataArr[i][model.childMapping])) {
                    dataArr[i][model.childMapping] = (datasource);
                    return true;
                }
                else {
                    var childItems = dataArr[i][model.childMapping];
                    if (childItems) {
                        for (var i = 0; i < childItems.length; i++) {
                            if (childItems[i][model.taskIdMapping] == parentIndex && ej.isNullOrUndefined(childItems[i][model.childMapping])) {
                                childItems[i][model.childMapping] = (datasource);
                                return true;
                            }
                        }
                    }
                }
            }

        },

        //refresh the chart with updated schedule dates
        updateScheduleDates: function (startDate, endDate) {
            
            var proxy = this, model = this.model;
                model.scheduleStartDate = startDate;
                model.scheduleEndDate = endDate;
                proxy._scheduleDays = [];
                proxy._scheduleMonths = [];
                proxy._scheduleWeeks = [];
                proxy._scheduleYears = [];
                proxy._calculateHeaderDates();
                var chartObject = $("#ejGanttChart" + proxy._id).ejGanttChart("instance");
                var chartModel = chartObject.model;
                proxy._updateLeftValue();
                chartModel.projectStartDate = proxy._getDateFromFormat(proxy._projectStartDate);
                chartModel.projectEndDate = proxy._getDateFromFormat(proxy._projectEndDate);
                chartModel.scheduleDays = proxy._scheduleDays;
                chartModel.scheduleMonths = proxy._scheduleMonths;
                chartModel.scheduleWeeks = proxy._scheduleWeeks;
                chartModel.scheduleYears = proxy._scheduleYears;
                chartModel.renderBaseline = model.renderBaseline;
                $("#ejGanttChart" + proxy._id).ejGanttChart("refreshChartHeader", proxy._getDateFromFormat(startDate), proxy._getDateFromFormat(endDate));
                $("#ejGanttChart" + proxy._id).ejGanttChart("refreshContainersWidth");
                proxy._$ganttchartHelper.ejGanttChart("refreshHelper", proxy._currentViewData, proxy._updatedGanttRecords, proxy._totalCollapseRecordCount);
                if (model.predecessorMapping) {
                    proxy._$ganttchartHelper.ejGanttChart("clearConnectorLines");
                    proxy._connectorlineIds = [];
                    proxy._connectorLinesCollection = [];
                    proxy._isValidationEnabled = false;
                    proxy._createConnectorLinesCollection();
                    proxy._isValidationEnabled = true;
                }
                chartObject._$bodyContainer.ejScroller("refresh");
        },
        reRenderChart: function (scheduleMode) {
            var proxy = this, model = proxy.model,
                startDate = proxy._getDateFromFormat(model.scheduleStartDate),
                endDate = proxy._getDateFromFormat(model.scheduleEndDate);
            model.ganttRecords = [];
            model.parentRecords = [];
            $("#ejGanttChart" + proxy._id).empty();

            switch (scheduleMode) {
                case ej.Gantt.ScheduleHeaderType.Week:
                    model.scheduleHeaderSettings.scheduleHeaderType = ej.Gantt.ScheduleHeaderType.Week;
                    proxy._perDayWidth = 30;
                    proxy._calculateWeekSplit(startDate, endDate);
                    break;

                case ej.Gantt.ScheduleHeaderType.Day:
                    model.scheduleHeaderSettings.scheduleHeaderType = ej.Gantt.ScheduleHeaderType.Day;
                    model.scheduleHeaderSettings.dayHeaderFormat = "dd, MMM yy";
                    proxy._perHourWidth = 20;
                    if (model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale24Hours)
                        proxy._perDayWidth = (proxy._perHourWidth * 24);//24 hours
                    else if (model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale8Hours)
                        proxy._perDayWidth = (proxy._perHourWidth * 24);//9 hours
                    proxy._calculateDaySplit(startDate, endDate);
                    break;

                case ej.Gantt.ScheduleHeaderType.Month:
                    model.scheduleHeaderSettings.scheduleHeaderType = ej.Gantt.ScheduleHeaderType.Month;
                    model.scheduleHeaderSettings.monthHeaderFormat = "MMM yyyy";
                    model.scheduleHeaderSettings.weekHeaderFormat = "M/dd";
                    proxy._perDayWidth = 10;
                    proxy._perWeekWidth = 70;
                    proxy._calculateMonthSplit(startDate, endDate);
                    break;

                case ej.Gantt.ScheduleHeaderType.Year:
                    model.scheduleHeaderSettings.scheduleHeaderType = ej.Gantt.ScheduleHeaderType.Year;
                    proxy._perDayWidth = 3;
                    proxy._perMonthWidth = 90;
                    proxy._calculateYearSplit(startDate, endDate);
                    break;
            }

            proxy.element.ejGantt("destroy").ejGantt(model)
            proxy._isTreeGridRendered = false;
            proxy._isGanttChartRendered = false;

        },

        _updateGanttRecords: function() {
            var proxy = this, model = proxy.model, count = model.ganttRecords.length;
            for (var i = 0; i < count; i++) {
                model.ganttRecords[i].left = (model.ganttRecords[i].left/proxy._prevDayWidth)*proxy._perDayWidth;
                model.ganttRecords[i].width = (model.ganttRecords[i].width / proxy._prevDayWidth) * proxy._perDayWidth;
                model.ganttRecords[i].width = model.ganttRecords[i].isMilestone == true ? 26 : model.ganttRecords[i].width,
                model.ganttRecords[i].progressWidth = model.ganttRecords[i]._calculateProgressWidth(model.ganttRecords[i].width, model.ganttRecords[i].status);
            }

        },
        
        _initPrivateProperties: function () {

            var proxy = this;
            model = proxy.model;
            scheduleMode = model.scheduleHeaderSettings.scheduleHeaderType;
            proxy._isFromGantt = true;
            proxy._disabledToolItems = [],
            proxy._id = proxy.element.attr('id'),
            proxy._scheduleWeeks = [],
            proxy._duplicate = false,          
            proxy._wrongenddate=false,
            proxy._scheduleYears = [],//new property for year schedule modes

            proxy._scheduleMonths = [], //new property for month

            proxy._scheduleYears = [],//property for schedule years
            proxy._scheduleDays = [],//property for schedule days

            proxy._projectStartDate, //property instead of scheduleWeeks[0] and scheduleYears[0]
            proxy._projectEndDate,

            proxy._columns = [],
            proxy._rows = [],
            proxy._storedIndex = -1,
            proxy._perDayWidth,
            proxy._prevDayWidth = 0,


            proxy._perMonthWidth,//new property for month
            proxy._perWeekWidth,//new property for month-week schedule

            proxy._$treegridPane = null,
            proxy._$ganttchartPane = null,
            proxy._$treegrid = null,
            proxy._$ganttchart = null,
            proxy._$ejGantt = null,
            proxy._$treegridHelper = null,
            proxy._$ganttchartHelper = null;
            proxy._tdsOffsetWidth = [];
            proxy._ids = [];
            proxy._predecessorsCollection = [];
            proxy._connectorLinesCollection = [];            
            proxy._updatedConnectorLineCollection = [];
            proxy._connectorlineIds = [];
            proxy._updatedGanttRecords = [];
            proxy._currentViewData = [];
            proxy._gridRows = null;

            //variables used for ExpandCollapse action in non Virtualization 
            proxy._collapsedRecordCount = 0;
            proxy._expandedRecordsCount = 0;
            proxy._totalCollapseRecordCount = 0;
            proxy._isInExpandCollapse = false;

            proxy._hiddenRecordCount = 0;
            
            proxy.prevPredecessorTO = null;
            proxy.prevPredecessorFrom = null;
            proxy.prevPredecessorcount = 0;
            proxy._isValidationEnabled = true;
            proxy._isTreeGridRendered = false;//indicate treegrid part is rendered or not for refresh row
            proxy._isGanttChartRendered = false;//indicate gantChart part is rendered or not
            proxy._holidaysList = proxy._getHoliday();
            proxy._stringHolidays = proxy._getStringHolidays();
            proxy._isinBeginEdit = false;
            proxy._isMileStoneEdited = false;
            proxy._cellEditType = null;
            proxy._isinAddnewRecord = false;

            //variables for context menu items
            proxy._contextMenuItems = proxy._getContextMenuItems();
            proxy._subContextMenuItems = proxy._getsubContextMenuItems();
            proxy._totalBorderWidth = 2;//Left and Right border width
            proxy._totalBorderHeight = model.toolbarSettings.showToolbar ? 3 : 2,//top,bottom,toolbar div
            //private variable decalartion for localization
            proxy._columnHeaderTexts = null;
            proxy._editDialogTexts = null;
            proxy._months = null;  
            proxy._days = null;
            proxy._emptyRecordText = null;
            proxy._commonColumnWidth = 150;
            proxy._searchString = "",
            proxy._emptyDataColumns = [],
            proxy.secondaryDatasource = [];
            proxy._datasourceChildItems = [];
            proxy._$predecessorTable = null;
            proxy._mappingItems = [];
            proxy._editedDialogRecord = null;
            proxy._calculateDimensions();
            proxy._retrivedData = this.dataSource();
            if (scheduleMode == "week") {
                proxy._perDayWidth = 30;
            }
            else if (scheduleMode == "year") {
                proxy._perDayWidth = 3;
                proxy._perMonthWidth = 90;
            }
            else if (scheduleMode == "month") {
                proxy._perDayWidth = 10;
                proxy._perWeekWidth = 70;
            }
            else if (scheduleMode == "day") {
                proxy._perHourWidth = 20;
                if (model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale24Hours)
                    proxy._perDayWidth = (proxy._perHourWidth * 24);//24 hours
                else if (model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale8Hours)
                    proxy._perDayWidth = (proxy._perHourWidth * 24);//9 hours
            }
        },
        //calculate height and width for gantt at load time
        _calculateDimensions: function ()
        {
            var proxy = this,
                sizeSettingHeight = this.model.sizeSettings.height,
                sizeSettingsWidth = this.model.sizeSettings.width,
                elementStyleHeight = proxy.element[0].style.height,
                parentHeight=$(proxy.element).parent().height(),
                parentWidth=$(proxy.element).parent().width();
            proxy._ganttHeight = ej.isNullOrUndefined(sizeSettingHeight) ? (elementStyleHeight ? proxy.element.height() : "450px") : sizeSettingHeight,
            proxy._ganttWidth = ej.isNullOrUndefined(sizeSettingsWidth) ? proxy.element.width() : sizeSettingsWidth,
            proxy._ganttHeight = proxy._ganttHeight.toString().indexOf('%') !== -1 ? (parentHeight * parseInt(proxy._ganttHeight) / 100) :parseInt(proxy._ganttHeight),
            proxy._ganttWidth = proxy._ganttWidth.toString().indexOf('%') !== -1 ? (parentWidth * parseInt(proxy._ganttWidth) / 100) : parseInt(proxy._ganttWidth);
        },
        _setCultureInfo:function() {
             var proxy = this,
                model = proxy.model,
                culture = model.locale;

            model.dateFormat = !model.dateFormat ? ((ej.Gantt.localization[culture] && ej.Gantt.localization[culture]["calendars"] &&
                    ej.Gantt.localization[culture]["calendars"]["standard"]["patterns"]) ?
                (ej.Gantt.localization[culture]["calendars"]["standard"]["patterns"]["d"]) :
                Globalize.culture(culture) ? Globalize.culture(culture)["calendars"]["standard"]["patterns"]["d"] :
                    ej.Gantt.localization["en-US"]["calendars"]["standard"]["patterns"]["d"]) : model.dateFormat;

            
            //EmptyRecord text to be displayed with dataSource is null
            proxy._emptyRecordText = ej.Gantt.localization[culture] ?
                ej.Gantt.localization[culture]["emptyRecord"] :
                ej.Gantt.localization["en-US"]["emptyRecord"];
            
            //ColumnHeaderText to be displayed in treegrid
            proxy._columnHeaderTexts = ej.Gantt.localization[culture] ?
                ej.Gantt.localization[culture]["columnHeaderTexts"] :
                ej.Gantt.localization["en-US"]["columnHeaderTexts"];
            
            //EditDialog Text to be displayed in popup window
            proxy._editDialogTexts = ej.Gantt.localization[culture] ?
                ej.Gantt.localization[culture]["editDialogTexts"] :
                ej.Gantt.localization["en-US"]["editDialogTexts"];
            
            //Month names to be displayed in schedule
            proxy._months = (ej.Gantt.localization[culture] && ej.Gantt.localization[culture]["calendars"]) ?
                ej.Gantt.localization[culture]["calendars"]["standard"]["months"]["namesAbbr"] :
                Globalize.culture(culture) ? Globalize.culture(culture)["calendars"]["standard"]["months"]["namesAbbr"] :
                ej.Gantt.localization["en-US"]["calendars"]["standard"]["months"]["namesAbbr"];
            
            //Day names to displayed in schedule
            proxy._days = (ej.Gantt.localization[culture] && ej.Gantt.localization[culture]["calendars"]) ?
                ej.Gantt.localization[culture]["calendars"]["standard"]["months"]["namesAbbr"] :
                Globalize.culture(culture) ? Globalize.culture(culture)["calendars"]["standard"]["days"]["namesAbbr"] :
                ej.Gantt.localization["en-US"]["calendars"]["standard"]["days"]["namesAbbr"];

        },

        //Populate available fields
        _getMappingItems: function () {
            var proxy = this,
                model = proxy.model,
                mappingItems = [],
                length = proxy._columns.length;

            for (var i = 0; i < length; i++) {
                mappingItems.push(proxy._columns[i].mappingName);
            }
            return mappingItems;
        },

        //populate the context menu with items
        _getContextMenuItems: function () {
            var contextMenuItems = [];

            contextMenuItems = [{
                headerText: "Task Details...",
                eventHandler: null,
                isDefault:true,

            }, {
                headerText: "Add New Task",
                eventHandler: null,
                isDefault: true
            }
            , {
                headerText: "Indent",
                eventHandler: null,
                isDefault: true
            }, {
                headerText: "Outdent",
                eventHandler: null,
                isDefault: true
            }, {
                headerText: "Delete",
                eventHandler: null,
                isDefault: true
            }         
           ];
            return contextMenuItems;
        },

        //populate sub context menu items
        _getsubContextMenuItems: function () {
            var contextMenuItems = [];

            contextMenuItems = [{
                iconPath: null,
                headerText: "Above",
                eventHandler: null
            }, {
                iconPath: null,
                headerText: "Below",
                eventHandler: null
            }
            ];
            return contextMenuItems;
        },


        _initialize: function () {
            var proxy = this, model = proxy.model,
            startDate, endDate;

            proxy._$treegridPane = ej.buildTag('div.e-treegridPane');
            proxy._$ganttchartPane = ej.buildTag('div.e-ganttchartPane');
            proxy._$ejGantt = ej.buildTag('div.e-gantt-Spliter#e-ejSpliter' + proxy._id, "", {}, { 'unselectable': "on" });     

            proxy.setColumns(proxy.createTreeGridColumns());
            model.predecessorMapping && proxy._updatePredecessors();

            proxy._trigger("load");
            proxy._render();
            proxy._isTreeGridRendered = true;
            proxy._updatedGanttRecords = proxy.getUpdatedRecords();
            proxy._currentViewData = proxy.getCurrentViewData();
            proxy._enableCreateCollection = false;
            proxy._connectorLinesCollection = [];
            model.predecessorMapping && proxy._createConnectorLinesCollection("Load");//validation dones here 
            proxy._calculateScheduleDates();
            proxy._calculateHeaderDates();
            proxy._updateLeftValue();
            proxy._enableCreateCollection = true;//
            proxy._connectorLinesCollection = [];
            proxy._isValidationEnabled = false;          //no validation require here
            model.predecessorMapping && proxy._createConnectorLinesCollection();//connectorline oboject creates here
            proxy._isValidationEnabled = true;//reassign this value
           // proxy._$treegridHelper.ejTreeGrid("renderRecords");
            proxy._renderGanttChart();
            model.predecessorMapping && proxy._$ganttchartHelper && proxy._$ganttchartHelper.ejGanttChart("renderConnectorLines", proxy._connectorLinesCollection);
            proxy._isGanttChartRendered = true;
            proxy._gridRows = proxy.getRows();
            proxy._ganttChartRows = proxy.getGanttChartRows();
            proxy._createSubContextMenuTemplate();
            proxy._createContextMenuTemplate();
            proxy._wireEvents();
        },

        _render: function() {
            var proxy = this, element = proxy.element, model = proxy.model;
            if (proxy.model.toolbarSettings.showToolbar) {
                element.append(proxy._renderToolBar());
            }
            proxy._ganttHeight = parseInt(proxy._ganttHeight) - proxy._getToolBarHeight() - proxy._totalBorderHeight;
            proxy._$treegrid = ej.buildTag("div.ejTreeGrid#ejTreeGrid" + proxy._id, "", { "height": proxy._ganttHeight }, {});
            proxy._$ganttchart = ej.buildTag("div.ejGanttChart#ejGanttChart" + proxy._id, "", { "height": proxy._ganttHeight }, {});
            proxy._$ganttchartPane.append(proxy._$ganttchart);
            proxy._$treegridPane.append(proxy._$treegrid);
            proxy._$ejGantt.append(proxy._$treegridPane);
            proxy._$ejGantt.append(proxy._$ganttchartPane);    
            
            element.append(proxy._$ejGantt);
            proxy._renderGantt();
            proxy._renderTreeGrid();
            proxy._$treegridPane.css({ 'overflow': 'hidden' });
            if (model.editSettings.allowEditing || model.editSettings.editMode == "normal" || model.editSettings.editMode == "dialogTemplate") {
                proxy.editDialogTemplate();
                element.append(proxy._renderDialog());
            }
            if (model.editSettings.allowAdding) {
                proxy.addDialogTemplate();
                var $dialog = ej.buildTag("div.e-dialog e-dialog-content e-shadow e-widget-content", "", { display: "none" }, { id: this._id + "_dialogAdd" });
                element.append($dialog);
            }
        },

        _renderDialog: function () {
            var $dialog = ej.buildTag("div.e-dialog e-dialog-content e-shadow e-widget-content", "", { display: "none" }, { id: this._id + "_dialogEdit" });
            return $dialog;
        },

        editDialogTemplate: function () {

            var proxy = this,
                model = proxy.model,
                columns = proxy._columns,
                length = columns.length,
                emptyDataColumns = [], model = proxy.model,column,predecessorColoumnIndex;

            proxy._mappingItems = proxy._getMappingItems();

            if (length == 0)
                return;

            if (model.editDialogFields.length > 0) {
                var filteredColumns = [];
                var count=0,resultColumn;
                for(;count<model.editDialogFields.length;count++)
                {
                    resultColumn = $.grep(proxy._columns, function (val) {
                        return val.mappingName === model.editDialogFields[count].field;
                    });
                    resultColumn.length && filteredColumns.push(resultColumn[0]);
                } 
                columns = filteredColumns;
            }
           
            var $tbody = ej.buildTag('div', "", {}, { 'unselectable': 'on' });
            $form = ej.buildTag('form', "", { 'height': 'auto', 'width': 'auto', 'font-family': 'Segoe UI', 'font-size': '14px' }, { id: proxy._id + "EditForm" });
            $table = ej.buildTag('table', "", { width: "500px" }, { 'unselectable': "on" });
            $tr = ej.buildTag('tr');
            for (var i = 0; i < columns.length; i++) {
                if ($.inArray(columns[i].mappingName, proxy._mappingItems) != -1) {
                    if (columns[i].mappingName !== model.predecessorMapping)
                    {
                        if ($tr.children("td").length < 2) {
                            $td = ej.buildTag('td', "", { "text-align": "left", 'padding': '5px 15px 0', 'font-weight': 'normal', "outline": "none" }, { 'unselectable': "on" });
                            $innerTable = ej.buildTag('table', "", { "outline": "none" }, { 'unselectable': "on" });

                            $inTr = ej.buildTag('tr');

                            $inTd = ej.buildTag('td.editLabel', "", { "outline": "none" }, { 'unselectable': "on" });
                            $inTd.append("<label for='" + columns[i].field + "' style='font-weight:normal;'>" + proxy._columnHeaderTexts[columns[i].field] + "</label>");

                            $inTr.append($inTd);

                            $innerTable.append($inTr);

                            $inTr2 = ej.buildTag('tr');
                            $inTd2 = ej.buildTag('td.e-editValue');

                            //column = ej.TreeGrid.getColumnByField(proxy._columns, columns[i].field);
                            column = columns[i];
                            proxy.initCellEditType(column, $inTd2);

                            $inTr2.append($inTd2);
                            $innerTable.append($inTr2);

                            $td.append($innerTable);
                            $tr.append($td);

                            //if (i % 2 === 0 && proxy._columnHeaderTexts[columns[i].field] === "Resources") {
                            //    $td.attr("colspan", "2");
                            //    $table.append($tr);
                            //    $tr = $tempTr = ej.buildTag('tr');
                            //}
                        }
                        else {
                            $table.append($tr);
                            $tr = $tempTr = ej.buildTag('tr');
                            i--;
                        }
                    }else
                    {
                        predecessorColoumnIndex=i;
                    }
                }
            }
            $table.append($tr);
            //      $("body").append($table);
            $tr = ej.buildTag("tr");

            if (model.predecessorMapping && predecessorColoumnIndex) {

                $td = ej.buildTag('td', "", { "text-align": "left", 'padding': '10px 15px 0', 'font-weight': 'normal',"outline":"none" }, { colspan: 2, 'unselectable': "on" });

                $innerTable = ej.buildTag('table#predecessoreditTable', "", { "width": "100%", "outline": "none" }, { 'unselectable': "on" });

                $inTr = ej.buildTag('tr');
                $inTd = ej.buildTag('td.editLabel', "", {"outline":"none"}, { 'unselectable': "on" });
                
                $inTd.append("<span class='e-addpre e-icon e-enable e-edit-dialog' style='cursor:pointer'>Add New</span>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<span class='e-deletepre e-icon e-disable e-edit-dialog' style='cursor:pointer'>&nbsp;&nbsp;Remove</span>");

                $inTr.append($inTd);
                $innerTable.append($inTr);

                $inTr2 = ej.buildTag('tr');
                $inTd2 = ej.buildTag('td.e-editValue');

                $preDiv = ej.buildTag("div#treegrid" + proxy._id + "predecessoredit", "", { "width": "100%", "height": "150px" }, {});

                $inTd2.append($preDiv);
             
                $inTr2.append($inTd2);
                $innerTable.append($inTr2);

                $td.append($innerTable);
                $tr.append($td);
                $table.append($tr);
            }

            
            $form.append($table);
            $form.appendTo($tbody);
           
            $tbody = proxy.renderDiaglogButton($form, $tbody);
            $.templates(proxy._id + "_JSONDialogEditingTemplate", $tbody.html());
        },
        addDialogTemplate: function () {

            var proxy = this,
                model = proxy.model,
                columns = proxy._columns,
                length = columns.length,
                emptyDataColumns = [], model = proxy.model, column, predecessorColoumnIndex;

            proxy._mappingItems = proxy._getMappingItems();

            if (length == 0)
                return;

            if (model.addDialogFields.length > 0) {
                var filteredColumns = [];
                var count = 0, resultColumn;
                for (; count < model.addDialogFields.length; count++) {
                    resultColumn = $.grep(proxy._columns, function (val) {
                        return val.mappingName === model.addDialogFields[count].field;
                    });
                    resultColumn.length && filteredColumns.push(resultColumn[0]);
                }
                columns = filteredColumns;
            }

            var $tbody = ej.buildTag('div', "", {}, { 'unselectable': 'on' });
            $form = ej.buildTag('form', "", { 'height': 'auto', 'width': 'auto', 'font-family': 'Segoe UI', 'font-size': '14px' }, { id: proxy._id + "AddForm" });
            $table = ej.buildTag('table', "", { width: "500px" }, { 'unselectable': "on" });
            $tr = ej.buildTag('tr');
            for (var i = 0; i < columns.length; i++) {
                if ($.inArray(columns[i].mappingName, proxy._mappingItems) != -1) {
                    if (columns[i].mappingName !== model.predecessorMapping) {
                        if ($tr.children("td").length < 2) {
                            $td = ej.buildTag('td', "", { "text-align": "left", 'padding': '5px 15px 0', 'font-weight': 'normal', "outline": "none" }, { 'unselectable': "on" });
                            $innerTable = ej.buildTag('table', "", { "outline": "none" }, { 'unselectable': "on" });

                            $inTr = ej.buildTag('tr');

                            $inTd = ej.buildTag('td.editLabel', "", { "outline": "none" }, { 'unselectable': "on" });
                            $inTd.append("<label for='" + columns[i].field + "' style='font-weight:normal;'>" + proxy._columnHeaderTexts[columns[i].field] + "</label>");

                            $inTr.append($inTd);

                            $innerTable.append($inTr);

                            $inTr2 = ej.buildTag('tr');
                            $inTd2 = ej.buildTag('td.e-editValue');

                            column = columns[i];
                            proxy.initCellEditType(column, $inTd2,"Add");

                            $inTr2.append($inTd2);
                            $innerTable.append($inTr2);

                            $td.append($innerTable);
                            $tr.append($td);

                        }
                        else {
                            $table.append($tr);
                            $tr = $tempTr = ej.buildTag('tr');
                            i--;
                        }
                    } else {
                        predecessorColoumnIndex = i;
                    }
                }
            }
            $table.append($tr);

            $tr = ej.buildTag("tr");

            if (model.predecessorMapping && predecessorColoumnIndex) {

                $td = ej.buildTag('td', "", { "text-align": "left", 'padding': '10px 15px 0', 'font-weight': 'normal', "outline": "none" }, { colspan: 2, 'unselectable': "on" });

                $innerTable = ej.buildTag('table#predecessoreditTable', "", { "width": "100%", "outline": "none" }, { 'unselectable': "on" });

                $inTr = ej.buildTag('tr');
                $inTd = ej.buildTag('td.editLabel', "", { "outline": "none" }, { 'unselectable': "on" });

                $inTd.append("<span class='e-addpre e-icon e-enable e-add-dialog' style='cursor:pointer'>Add New</span>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<span class='e-deletepre e-icon e-disable e-add-dialog' style='cursor:pointer'>&nbsp;&nbsp;Remove</span>");

                $inTr.append($inTd);
                $innerTable.append($inTr);

                $inTr2 = ej.buildTag('tr');
                $inTd2 = ej.buildTag('td.e-editValue');

                $preDiv = ej.buildTag("div#treegrid" + proxy._id + "predecessorAdd", "", { "width": "100%", "height": "150px" }, {});

                $inTd2.append($preDiv);

                $inTr2.append($inTd2);
                $innerTable.append($inTr2);

                $td.append($innerTable);
                $tr.append($td);
                $table.append($tr);
            }


            $form.append($table);
            $form.appendTo($tbody);

            $tbody = proxy.renderDiaglogButton($form, $tbody);
            $.templates(proxy._id + "_JSONDialogAddingTemplate", $tbody.html());
        },
        _clearContextMenu: function () {
            //variables for context menu items
         
            $('.e-contextmenu').remove();
            $('.e-innerContextmenu').remove();
        },

        //JSRender Template for ContextMenu
        _createContextMenuTemplate: function () {
            var proxy = this;
            helpers = {
                getHeaderName: $.proxy(proxy._getHeaderName, proxy),
            };
            $.views.helpers(helpers);
            var menuItemList = "<li style='list-style-type:none;width:150px;height:25px;display:inline-block;'>";
            var listChild = "<div class='e-menuitem' id={{:headerText}}  style='left:0px;padding-top:3px;height:25px;width:150px;cursor:pointer;display:block;position:absolute;'  {{if !isDefault}}onClick='{{:eventHandler}}'{{/if}}>" +
                            "<div class='e-icon' style='left:10px;top:4px;height:20px;position:absolute;" +
                            "background-image:{{:iconPath}};background-repeat:no-repeat;'/>" +
                            "<div style='left:35px;position:absolute;'>" +
                            "<span style='font-family:Segoe UI;font-size:12px;padding-left:5px;'>{{:headerText}}</span></div>" +
                            "{{if ~getHeaderName(#data)}}<span class='e-icon e-expander' style='height:16px;width:16px;right:5px;top:7px;position:absolute;'></span>{{/if}}";

            menuItemList += listChild;
            menuItemList += "</div></li>";
            var templates = {};
            templates[proxy._id + "contextMenuTemplate"] = menuItemList;
            $.templates(templates);
        },

        //helper methods for context menu template
        _getHeaderName: function (data) {
            if (data.headerText == "Add New Task" && this._subContextMenuItems.length > 0) {
                return true;
            }
            return false;
        },

        //JSRender Template for Inner Context Menu
        _createSubContextMenuTemplate: function () {
            var proxy = this,
                helpers = {
                    getHeaderName: proxy._getHeaderName
                };
            $.views.helpers(helpers);

            var menuItemList = "<li style='list-style-type:none;width:120px;height:25px;display:inline-block;'>";
            var listChild = "<div class='e-menuitem' id={{:headerText}} style='left:0px;padding-top:3px;" +
                "height:25px;width:120px;cursor: pointer;display:block;position:absolute;'>" +
                "<div style='left:10px;height:20px;width:16px;position:absolute;padding-top:5px;" +
                "background-image:{{:iconPath}};background-repeat:no-repeat;'/>" +
               "<div style='left:10px;position:absolute;'>" +
                "<span style='font-family:Segoe UI;font-size:12px;padding-left:5px;'>{{:headerText}}" +
                "</span></div></div>";


            menuItemList += listChild;
            menuItemList += "</li>";

            var templates = {};
            templates[proxy._id + "subContextMenuTemplate"] = menuItemList;
            $.templates(templates);
        },

        initCellEditType: function (column, element,editTarget) {

            var proxy = this,
                model = proxy.model,
                id,    
                helpers = {};
            id = editTarget ? editTarget : "";
            if (ej.isNullOrUndefined(column["editType"]))
                column["editType"] = "stringedit";

            switch (column["editType"]) {
                case "stringedit":
                    if (column.mappingName === model.predecessorMapping) {
                        helpers["_" + proxy._id + "predecessor"] = proxy._getPredecessorsValue;
                        $.views.helpers(helpers);
                        element.html(ej.buildTag('input.e-field e-ejinputtext', "", {}, { value: "{{:~_" + proxy._id + "predecessor('" + proxy._id + "Object','" + model.predecessorMapping + "','" + column.field + "')}}", id: proxy._id + column.field, name: column.field }));
                    } else {
                        element.html(ej.buildTag('input.e-field e-ejinputtext', "", {}, { value: "{{:#data['" + column.field + "']}}", id: proxy._id + column.field + id, name: column.field, dialog: editTarget }));
                    }
                    break;
                case "booleanedit":
                    element.html('{{if ' + column.field + '}} <input class="e-field e-checkbox" type ="checkbox" id=' + proxy._id + column.field + ' name=' + column.field + ' checked="checked"></input>{{else}} <input class="e-field e-checkbox" type ="checkbox" id=' + proxy._id + column.field + ' name=' + column.field + ' > {{/if}}');
                    break;
                case "numericedit":
                    var $numericText = ej.buildTag('input.e-numerictextbox e-field', "", {}, { type: "text", value: "{{:#data['" + column.field + "']}}", id: proxy._id + column.field + id, name: column.field, dialog: editTarget });
                    element.append($numericText);
                    break;
                case "datepicker":
                case "datetimepicker":
                    var $datePicker = ej.buildTag('input.e-' + column["editType"] + ' e-field', "", {}, { type: "text", value: "{{:#data['" + column.field + "']}}", id: proxy._id + column.field + id, name: column.field, dialog: editTarget });
                    element.append($datePicker);
                    break;
                case "dropdownedit":
                    var $dropDownList = ej.buildTag('input.e-field e-dropdownlist' + ' e-field', "", {}, { type: "text", value: "{{:#data['" + column.field + "']}}", id: proxy._id + column.field + id, name: column.field, dialog: editTarget });
                    element.append($dropDownList);                    
                    break;
            }
        },


        _getPredecessorsValue: function (gridObject, mappingName) {
            return this.data.item ? this.data.item[mappingName] : "";
        },

        _updateEditFormData:function()
        {
            var proxy = this;
        },
        _onHoliDayCheckBefore: function (startDate) {
            var proxy = this,
                holidays = proxy.model.holidays,
                includeWeekend = proxy.model.includeWeekend;


            if (holidays && holidays.length) {
                var holidayIndex = 0,
                    holidayslength = holidays.length,
                    holiday, flag;
                    for (holidayIndex = 0; holidayIndex < holidayslength; holidayIndex++) {
                        holiday = proxy._getDateFromFormat(holidays[holidayIndex].day);
                        if (holiday.getTime() == startDate.getTime()) {
                            startDate.setDate(startDate.getDate() - 1);
                            if (this.model.includeWeekend === false) {
                                proxy._setBeforeWeekend(startDate);
                            }
                        }
                        else {
                            return startDate;
                        }
                    }
            }
            else {
                return startDate;
            }
        },
        _onHoliDayCheck: function (startDate)
        {
            var proxy = this,
                holidays = proxy.model.holidays,
                includeWeekend = proxy.model.includeWeekend;
                

            if (holidays && holidays.length) {
                var holidayIndex = 0,
                    holidayslength = holidays.length,
                    holiday, flag;
                do {
                    for (holidayIndex = 0; holidayIndex < holidayslength; holidayIndex++) {
                        holiday = proxy._getDateFromFormat(holidays[holidayIndex].day);
                        if (holiday.getTime()==startDate.getTime()) {
                            startDate.setDate(startDate.getDate() + 1);
                            if (this.model.includeWeekend === false) {
                                if (startDate.getDay() == 0) {
                                    startDate.setDate(startDate.getDate() + 1);
                                } else if (startDate.getDay() == 6) {
                                    startDate.setDate(startDate.getDate() + 2);
                                }
                            }
                        }
                        else
                        {
                            return startDate;
                        }
                    }
                }while(1);

            }
            else
            {
                return startDate;
            }
        },
        _editStartDateChange:function(element,args)
        {
            var proxy = this,
                id = proxy._id,
                model = proxy.model,
                targetId = element.attr("id"),
                holidays = this.model.holidays,
                dialog = element.attr("dialog"),
                selectedItem = this.selectedItem(),
                editedObj = this._editedDialogRecord,
                startDateId, endDateId, durationId;
               

                if (dialog === "Add")
                {
                    startDateId = "#" + id + "startDateAdd";
                    endDateId = "#" + id + "endDateAdd";
                    durationId = "#" + id + "durationAdd";
                }
                else
                {
                    startDateId = "#" + id + "startDate";
                    endDateId = "#" + id + "endDate";
                    durationId = "#" + id + "duration";
                }

                var startDate = $(startDateId).val();
                endDate = $(endDateId).val();
                duration = parseInt($(durationId).val());

                if (!startDate)
                {
                    startDate = editedObj?editedObj.startDate:undefined;
                }
                if (isNaN(duration)) {
                    duration = editedObj ? editedObj.duration : undefined;
                }
                if (!endDate) {
                    endDate = editedObj ? editedObj.endDate : undefined;
                }

                if ((targetId === id + "startDate") || (targetId === id + "startDateAdd"))
                { 
                    startDate = proxy._getDateFromFormat(args.value);
                    var tempEndDate = new Date();
                    stratDate=proxy._onHoliDayCheck(startDate);
                    //check start date is in week end days
                    if (this.model.includeWeekend === false) {
                        if (startDate.getDay() === 0) {
                            startDate.setDate(startDate.getDate() + 1);
                        }
                        else if (startDate.getDay() === 6) {
                            startDate.setDate(startDate.getDate() + 2);
                        }
                    }
                    tempEndDate = startDate;
                    startDate = Globalize.format(startDate, this.model.dateFormat);
                    //$("#" + id + "startDate").val(startDate);
                    if (editedObj)
                        editedObj.startDate = startDate;

                if (model.dateFormat.indexOf("hh")!=-1)
                    $(startDateId).ejDateTimePicker("option", "value", startDate);
                else
                    $(startDateId).ejDatePicker("option", "value", startDate);

                if (!endDate || isNaN(duration))
                    return;

                if (model.durationMapping) {

                    //check week end is inside the period

                    if (this.model.includeWeekend === false) {
                        for (count = 1; count < duration; count++) {
                            if (tempEndDate.getDay() == 0)
                                tempEndDate.setDate(tempEndDate.getDate() + 1);
                            else if (tempEndDate.getDay() == 6)
                                tempEndDate.setDate(tempEndDate.getDate() + 2);
                            tempEndDate.setDate(tempEndDate.getDate() + 1);
                        }
                    } else {
                        tempEndDate.setDate(tempEndDate.getDate() + duration - 1);
                    }

                    if (this.model.includeWeekend === false) {
                        if (tempEndDate.getDay() == 0)
                            tempEndDate.setDate(tempEndDate.getDate() + 1);
                        else if (tempEndDate.getDay() == 6)
                            tempEndDate.setDate(tempEndDate.getDate() + 2);
                    }

                    //holiday collection checking in end date
                    if (holidays && holidays.length) {
                        var holidayIndex = 0,
                            holidayslength = holidays.length,
                            holiday;
                        for (holidayIndex = 0; holidayIndex < holidayslength; holidayIndex++) {
                            holiday = new Date(holidays[holidayIndex].day);
                            if (holiday >= proxy._getDateFromFormat(new Date(startDate), this.model.dateFormat) && holiday <= tempEndDate) {
                                tempEndDate.setDate(tempEndDate.getDate() + 1);
                                if (this.model.includeWeekend === false) {
                                    if (tempEndDate.getDay() == 0) {
                                        tempEndDate.setDate(tempEndDate.getDate() + 1);
                                    } else if (tempEndDate.getDay() == 6) {
                                        tempEndDate.setDate(tempEndDate.getDate() + 2);
                                    }
                                }
                            }
                        }
                    }

                    if (this.model.includeWeekend === false) {
                        if (tempEndDate.getDay() == 0)
                            tempEndDate.setDate(tempEndDate.getDate() + 1);
                        else if (tempEndDate.getDay() == 6)
                            tempEndDate.setDate(tempEndDate.getDate() + 2);
                    }

                    tempEndDate = Globalize.format(tempEndDate, this.model.dateFormat);
                    //temp =this._calculateFormatedDate(temp, this.model.dateFormat);
                    if (editedObj)
                        editedObj.endDate = tempEndDate;

                    if (model.dateFormat.indexOf("hh") != -1)
                        $(endDateId).ejDateTimePicker("option", "value", new Date(tempEndDate));
                    else
                        $(endDateId).ejDatePicker("option", "value", new Date(tempEndDate));

                    //$("#" + id + "endDate").val(tempEndDate);
                    //$("#" + id + "endDate").attr("value", tempEndDate);
                }
                else {
                    var dateDiff = proxy._daydiff(proxy._getDateFromFormat(this.selectedItem().startDate), proxy._getDateFromFormat(editedObj.startDate));
                    editedObj.duration -= dateDiff;
                }
            }

            else if((targetId=== id + "endDate") ||(targetId===id + "endDateAdd"))
            {
                endDate = proxy._getDateFromFormat(args.value);

                endDate = proxy._onHoliDayCheck(endDate);
                if (this.model.includeWeekend === false) {
                    if (endDate.getDay() === 0) {
                        endDate.setDate(endDate.getDate() - 2);
                    }
                    else if (endDate.getDay() === 6) {
                        endDate.setDate(endDate.getDate() - 1);
                    }
                }
                endDate = Globalize.format(endDate, this.model.dateFormat);

                if (editedObj)
                    editedObj.endDate = endDate;

                if (model.dateFormat.indexOf("hh") != -1)
                    $(endDateId).ejDateTimePicker("option", "value", new Date(endDate));
                else
                    $(endDateId).ejDatePicker("option", "value", new Date(endDate));
             
                if (!startDate || isNaN(duration))
                    return;

                startDate = proxy._getDateFromFormat(startDate);
                endDate = proxy._getDateFromFormat(endDate);

                if (startDate.getTime() <= endDate.getTime())
                {
                        
                    var tempDuration = 0;
                    dateDiff = proxy._daydiff(proxy._getDateFromFormat(startDate), proxy._getDateFromFormat(endDate));

                    if (this.model.includeWeekend === false) {
                        offset = proxy._calculateDateDifference(new Date(startDate), dateDiff);
                        offset += 1;
                    }
                    else
                        offset = dateDiff + 1;

                    for (var count = 0; count < holidays.length; count++) {
                        if (new Date(holidays[count].day) >= new Date(startDate) && new Date(holidays[count].day) <= new Date(endDate)) {
                            offset--;
                        }
                    }
                    tempDuration = offset;
                    if (editedObj)
                        editedObj.duration = tempDuration;

                    $(durationId).ejNumericTextbox("option", "value", tempDuration);
                }
                else {
                    if (editedObj)
                        editedObj.endDate = args.prevDate;

                    if (model.dateFormat.indexOf("hh") != -1)
                        $(endDateId).ejDateTimePicker("option", "value", new Date(args.prevDate));
                    else
                        $(endDateId).ejDatePicker("option", "value", new Date(args.prevDate));

                }
            }
            else if ((targetId === id + "duration") || (targetId === id + "durationAdd"))
            {
                startDate = proxy._getDateFromFormat(startDate);
                var tempEndDate = new Date(startDate);

                if (!endDate || !startDate)
                    return;

                duration = args.value;

                //check week end is inside the period
                if (this.model.includeWeekend === false) {
                    for (count = 1; count < duration; count++) {
                        if (tempEndDate.getDay() == 0)
                            tempEndDate.setDate(tempEndDate.getDate() + 1);
                        else if (tempEndDate.getDay() == 6)
                            tempEndDate.setDate(tempEndDate.getDate() + 2);
                        tempEndDate.setDate(tempEndDate.getDate() + 1);
                    }
                } else {
                    tempEndDate.setDate(tempEndDate.getDate() + duration - 1);
                }

                if (this.model.includeWeekend === false) {
                    if (tempEndDate.getDay() == 0)
                        tempEndDate.setDate(tempEndDate.getDate() + 1);
                    else if (tempEndDate.getDay() == 6)
                        tempEndDate.setDate(tempEndDate.getDate() + 2);
                }
                //holiday collection checking in end date
                if (holidays && holidays.length) {
                    var holidayIndex = 0,
                        holidayslength = holidays.length,
                        holiday;
                    for (holidayIndex = 0; holidayIndex < holidayslength; holidayIndex++) {
                        holiday = new Date(holidays[holidayIndex].day);
                        if (holiday >= proxy._getDateFromFormat(startDate, this.model.dateFormat) && holiday <= tempEndDate) {
                            tempEndDate.setDate(tempEndDate.getDate() + 1);
                            if (this.model.includeWeekend === false) {
                                if (tempEndDate.getDay() == 0) {
                                    tempEndDate.setDate(tempEndDate.getDate() + 1);
                                } else if (tempEndDate.getDay() == 6) {
                                    tempEndDate.setDate(tempEndDate.getDate() + 2);
                                }
                            }
                        }
                    }
                }

                if (this.model.includeWeekend === false) {
                    if (tempEndDate.getDay() == 0)
                        tempEndDate.setDate(tempEndDate.getDate() + 1);
                    else if (tempEndDate.getDay() == 6)
                        tempEndDate.setDate(tempEndDate.getDate() + 2);
                }
                tempEndDate = Globalize.format(tempEndDate, this.model.dateFormat);

                if (editedObj) {
                    editedObj.endDate = tempEndDate;
                    editedObj.duration = duration;
                }
                if (model.dateFormat.indexOf("hh") != -1)
                    $(endDateId).ejDateTimePicker("option", "value", new Date(tempEndDate));
                else
                    $(endDateId).ejDatePicker("option", "value", new Date(tempEndDate));
            }
        },

        _taskNameCollection:function()
        {
            var proxy = this,
            records = proxy._updatedGanttRecords,
            names = [];
            for(var i=0;i<records.length;i++)
            {
               
                var temp = { id: records[i].taskId.toString(), text: (records[i].taskId.toString()+"-"+records[i].taskName), value: records[i].taskName };
                names.push(temp);
            }
            return names;
        }
        ,

        _idFromPredecessor:function(pre)
        {
            var str = "123FS+2";
            var preArray = pre.split(',');
            var preIdArray = [];
           

            for (var j = 0; j < preArray.length; j++)
            {
                var strArray = [];
                for (var i = 0; i < preArray[j].length; i++) {
                    if (!isNaN(preArray[j].charAt(i))) {
                        strArray.push(preArray[j].charAt(i));
                    }
                    else {
                        break;
                    }
                }
                preIdArray.push((strArray.join('')));
            }
            return preIdArray;
        },
        _preIdChangByName:function()
        {
            var proxy = this;
            var $form = $("#" + proxy._id + "PreEditForm");
            $targetTr = $form.closest("tr");
            $val = $form.find(".onEdit");
            var temp = $val.val();
            var names = proxy._taskNameCollection();

            var id = $.map(names, function (obj, index) {
                if (obj.text === $val.val()) {
                    return obj.id;
                }
            });
            id = id[0];
            $targetTr.find(".id").html(id);
        },
        _preBeginEdit:function(args)
        {
            if (args.columnIndex === 0)
                args.cancel = true;
        },
        _preEndEdit:function(editDialogId,args)
        {
            var proxy = this;
            if (args.columnName === "name")
            {
                var ds = args.model.dataSource;
                var names = proxy._taskNameCollection();
                var id = $.map(names, function (obj, index) {
                    if (obj.value === args.value) {
                        return obj.id;
                    }
                });
                id = id[0];
                args.model.selectedItem.id = id;
                
                var curent = args.model.dataSource.indexOf(args.model.selectedItem.item);

                if (curent === -1) {
                    args.model.dataSource.push(args.model.selectedItem.item);
                    curent = args.model.dataSource.indexOf(args.model.selectedItem.item);
                }
                args.model.dataSource[curent].id = id;
                if (!args.model.selectedItem.type) {
                    args.model.selectedItem.type = "Finish-Start";
                    args.model.dataSource[curent].type = "Finish-Start";
                }
                $(editDialogId).ejTreeGrid("refreshRow", args.model.selectedRowIndex);
                $(editDialogId).ejTreeGrid("selectRows", args.model.selectedRowIndex);

                proxy.enbleDisableAddPreButton('enable');
            }
        },
        _deleteDisableEnable:function(args)
        {
            var proxy = this;
            $(".e-deletepre").unbind("click", $.proxy(proxy._deletepredecessor, proxy));
            $(".e-deletepre").bind("click", $.proxy(proxy._deletepredecessor, proxy));
            $(".e-deletepre").removeClass("e-disable");
            $(".e-deletepre").addClass("e-enable");
        },
        _preDblClickHandler:function(e)
        {
            var proxy = this;
            $target = $(e.target);
            $sample = $("#" + proxy._id + "PreEditForm");
            //proxy._on(proxy.element, "click", ".e-tdprecontent", proxy._preClickHandler);
            // proxy._off(proxy.element, "dblclick", ".e-tdprecontent", proxy._preDblClickHandler);
            if ($sample.length === 0)
            {
                $form = ej.buildTag("form.#" + proxy._id + "PreEditForm", "", {}, {});
                $form.submit(function (event) { event.preventDefault()});
                var s = $target.attr("edittype");
                var field = $target.attr("field");
                var types = [{ id: "SS", text: "Start-Start", value: "Start-Start" }, { id: "SF", text: "Start-Finish", value: "Start-Finish" }, { id: "FS", text: "Finish-Start", value: "Finish-Start" }, { id: "FF", text: "Finish-Finish", value: "Finish-Finish" }];

                switch(field)
                {
                    case "taskName":
                        $attchelemet = ej.buildTag("input.e-field e-dropdownlist e-field onEdit", "", {}, { type: "text", id: proxy._id + 'taskNameEdit',value:e.target.innerHTML });
                        $form.append($attchelemet);
                        $target.empty().append($form);
                        $target.addClass("onEdit");
                        $attchelemet.ejDropDownList({
                            dataSource:proxy._taskNameCollection(),
                            width: "auto",
                            change: $.proxy(proxy._preIdChangByName, proxy),
                        });
                        $attchelemet.focus();
                        break;
                    case "type":
                        $attchelemet = ej.buildTag("input.e-field e-dropdownlist e-field onEdit", "", {}, { type: "text", id: proxy._id + 'TyepeEdit', value: e.target.innerHTML });
                        $form.append($attchelemet);
                        $target.empty().append($form);
                        $target.addClass("onEdit");
                        $attchelemet.ejDropDownList({
                            dataSource:types,
                            width: "auto"
                        });
                        $attchelemet.focus();
                        break;
                    case "offset":
                        $attchelemet = ej.buildTag('input.e-numerictextbox e-field onEdit', "", {}, { type: "text", id: proxy._id + 'OffsetEdit' });
                        var cellValue;
                        if (isNaN(parseInt(e.target.innerHTML))) {
                            cellValue = 0;
                        }
                        else
                            cellValue = parseInt(e.target.innerHTML);
                        $form.append($attchelemet);
                        $target.empty().append($form);
                        $target.addClass("onEdit");
                        $attchelemet.ejNumericTextbox({
                            width:"auto",                  
                            showSpinButton: true,
                            value: cellValue
                        });

                        $attchelemet.focus();
                        break;
                    case "id":
                        break;

                }
            }
        },
        _predecessorEditCollection:function(){
        
            var proxy = this,
               model = proxy.model;
            var gridId = "#" + proxy._id + "predecessor";
            var types = [{ id: "SS", text: "Start-Start", value: "Start-Start" }, { id: "SF", text: "Start-Finish", value: "Start-Finish" }, { id: "FS", text: "Finish-Start", value: "Finish-Start" }, { id: "FF", text: "Finish-Finish", value: "Finish-Finish" } ];
            var data = [];
            var selectedItem = model.selectedItem;
            var names = proxy._taskNameCollection();
            if (!ej.isNullOrUndefined(selectedItem) && !ej.isNullOrUndefined(selectedItem.predecessor) && !ej.isNullOrUndefined(selectedItem.item[model.predecessorMapping]))
            {
                var predecessor = selectedItem.predecessor;
                //var item = selectedItem.item;
                //var prede = proxy._idFromPredecessor(item.predecessor);

                for (var i = 0; i < predecessor.length; i++) {
                    var id = predecessor[i].from;

                    if (selectedItem.taskId.toString()!==id.toString())
                    {
                        var taskName, type, lags = 0;
                        for (var j = 0; j < names.length; j++) {
                            if (names[j].id === id) {
                                taskName = names[j].text;
                                break;
                            }
                        }
                        for (var k = 0; k < types.length; k++) {
                            if (types[k].id == predecessor[i].predecessorsType) {
                                type = types[k].text;
                            }
                        }
                        lags = predecessor[i].offset;
                        var obj = { id: id, name: taskName, type: type, offset: lags };
                        data.push(obj);
                    }
                }
            }
            return data;
        },
        _refreshEditForm: function (args) {
            var proxy = this,
                elementFocused = false,
                $formElement,
                percent = 86,
                i = 0, form, length,
                $element,
                inputWidth = "165px",
                model = proxy.model,
                width,
                params = {},
                value,
                column,
                customParams,
                toformat, newIdInstant,
                formatVal, editTreeGridId;
            selectedItem = model.selectedItem;
            
          
            if (args.requestType == "add") {
                form = document.getElementById(proxy._id + "AddForm");
                editTreeGridId = "#treegrid" + proxy._id + "predecessorAdd";
            }
            else {
                form = document.getElementById(proxy._id + "EditForm");
                editTreeGridId = "#treegrid" + proxy._id + "predecessoredit";
            }

            $formElement = $(form).find("input,select");
            length = $formElement.length;
            for (i; i < length; i++) {
                $element = $formElement.eq(i);
                //  inputWidth = proxy._tdsOffsetWidth[i] * (percent / 100);
                params = {};
                inputWidth = 210;
                if ($element.hasClass("e-numerictextbox")) {
               
                    width = inputWidth;
                    value = $element.val();
                    params.width = width;                    
                    params.showSpinButton = true;
                    params.cssClass = model.cssClass;
                    //for parent editing 
                    var tempId = $element[0].id;
                    tempId=tempId.replace(proxy._id, '');
                    if (selectedItem !== null && selectedItem.hasChildRecords && (tempId == "duration" || tempId == "status"))
                    {
                        params.readOnly = true;
                    }
                    if (tempId == "status") {
                        params.maxValue = 100;
                    }
                    else {
                        params.maxValue = 100000;
                        params.change = $.proxy(proxy._editStartDateChange, proxy, $element);
                    }
                    params.minValue = 0;
                    if (value.length)
                        params.value = parseFloat(value);
                    else
                        params.value = 0;
                    customParams = ej.TreeGrid.getColumnByField(proxy._columns, $element.prop("name"));
                    if (!ej.isNullOrUndefined(customParams["editParams"]))
                        $.extend(params, customParams["editParams"]);
                    $element.ejNumericTextbox(params);
                    $element.prop("name", $element.prop("name").replace(proxy._id, ""));
                }
                else if ($element.hasClass("e-datepicker")) {
                    width = inputWidth;
                    params.width = width;                    
                    params.cssClass = model.cssClass;
                    params.dateFormat = model.dateFormat;
                    params.locale = model.locale;
                    params.displayDefaultDate = true;
                    var tempId = $element[0].id;
                    tempId = tempId.replace(proxy._id, '');
                    if (selectedItem !== null && selectedItem.hasChildRecords && (tempId == "startDate" || tempId == "endDate") && args.requestType !== "add" ) {
                        params.readOnly = true;
                    }
                    params.select = $.proxy(proxy._editStartDateChange, proxy, $element);

                    if ($element.val().length)
                        params.value = proxy._getDateFromFormat($element.val());
                    else
                        params.value = proxy._getDateFromFormat(model.scheduleStartDate);

                    column = ej.TreeGrid.getColumnByField(proxy._columns, $element.prop("name"));
                    if (column["format"] !== undefined && column.format.length > 0) {
                        toformat = new RegExp("\\{0(:([^\\}]+))?\\}", "gm");
                        formatVal = toformat.exec(column.format);
                        params.dateFormat = formatVal[2];
                    }
                    if (!ej.isNullOrUndefined(column["editParams"]))
                        $.extend(params, column["editParams"]);

                    if (model.dateFormat.indexOf("hh") != -1)
                        $element.ejDateTimePicker(params);
                    else
                        $element.ejDatePicker(params);
                }
                else if ($element.hasClass("e-datetimepicker")) {
                    width = inputWidth;
                    params = {
                         width: width,
                        rtl: model.rtl,
                        locale:model.locale,
                        cssClass: model.css,
                        showButton: false
                    };
                    if ($element.val().length)
                        params.value = proxy._getDateFromFormat($element.val());
                    else
                        params.value = new Date();
                    column = ej.TreeGrid.getColumnByField(proxy._columns, $element.prop("name"));
                    if (column["format"] !== undefined && column.format.length > 0) {
                        toformat = new RegExp("\\{0(:([^\\}]+))?\\}", "gm");
                        formatVal = toformat.exec(column.format);
                        params.dateTimeFormat = formatVal[2];
                    }
                    if (!ej.isNullOrUndefined(column["editParams"]))
                        $.extend(params, column["editParams"]);

                    if (model.dateFormat.indexOf("hh") != -1)
                        $element.ejDateTimePicker(params);
                    else
                        $element.ejDatePicker(params);

                }
                else if ($element.hasClass("e-dropdownlist")) {
                    column = ej.TreeGrid.getColumnByField(proxy._columns, $element.prop("name"));
                    var dataSource = column.dropdownData;
                    var checkReadonly=false;
                    if (selectedItem !== null && selectedItem.hasChildRecords && args.requestType !== "add")
                    {
                        checkReadonly=true;
                    }

                    $element.ejDropDownList({
                        width:inputWidth,
                        showCheckbox: true,
                        dataSource: dataSource,
                        readOnly: checkReadonly,
                        fields: { id: model.resourceIdMapping, text: model.resourceNameMapping, value: model.resourceNameMapping },
                        selectedItems: proxy.getIndexofresourceInfo(dataSource,args.data)
                    });
                    $element.ejDropDownList("setSelectedValue", $element.val());
                } else {
                    switch ($element.prop('tagName')) {
                        case "INPUT":

                            if ($element.attr("type") != "checkbox") {
                                //For ID field id is read only

                                if ($element.attr("name") === "taskId") {
                                    if (args.requestType !== "add") {
                                        $element.attr("readonly", "readonly");
                                    }
                                    else if (args.requestType === "add") {
                                        newIdInstant = proxy._updatedGanttRecords.length;
                                        newIdInstant = proxy._getNewTaskIdFordialogEdit(newIdInstant);
                                        $element.val(newIdInstant);
                                    }
                                }
                                else if ($element.attr("name") === "taskName" && args.requestType === "add") {
                                    $element.val("New Task" + newIdInstant);
                                }

                                var tempId = $element[0].id;
                                tempId = tempId.replace(proxy._id, '');

                                $element.css("text-align", $element.attr("name") != null && ej.TreeGrid.getColumnByField(proxy._columns, $element.prop("name")) != null ?
                                    ej.TreeGrid.getColumnByField(proxy._columns, $element.attr("name")).textAlign : "center");
                                $element.outerWidth(inputWidth).height(25);
                            } else
                                $element.width("165px");//(inputWidth > 0 ? ($element.width() > inputWidth ? inputWidth : $element.width()) : 1);
                            break;

                        case "SELECT":
                            $element.width(inputWidth).height(23);
                            break;
                    }
                }
                if (!$element.is(":disabled") && !elementFocused && (!$element.is(":hidden") || typeof $element.data("ejDropDownList") == "object")) {
                    if (!proxy._isEnterKeyPressed) {
                        proxy._focusElements($element.closest('td'));
                        elementFocused = true;
                    }
                }
            }
           

            //render prdecessor table in edit dialog
            if (model.predecessorMapping && $(editTreeGridId).length) {
                var types = [{ id: "SS", text: "Start-Start", value: "Start-Start" }, { id: "SF", text: "Start-Finish", value: "Start-Finish" }, { id: "FS", text: "Finish-Start", value: "Finish-Start" }, { id: "FF", text: "Finish-Finish", value: "Finish-Finish" }];
                var ds = [];
                if (args.requestType !== "add")
                {
                    ds=proxy._predecessorEditCollection();
                }
                $(editTreeGridId).ejTreeGrid({
                    dataSource:ds,
                    allowSorting: false,
                    allowAdding: true,
                    columns: [{ headerText: "ID", field: "id", width: "50px",allowEditing:false },
                        { headerText: "TaskName", field: "name", editType: ej.TreeGrid.EditingType.Dropdown, dropdownData: proxy._taskNameCollection(), width: "170px" },
                        { headerText: "Type", field: "type", editType: ej.TreeGrid.EditingType.Dropdown, dropdownData: types, width: "80px" },
                        { headerText: "Offset", field: "offset", editType: ej.TreeGrid.EditingType.Numeric, width: "50px" }],
                    enableAltRow: true,
                    editSettings: {
                        allowAdding: true,
                        allowDeleting: true,
                        allowEditing: true,
                        editMode: "cellEditing",
                    },
                    endEdit: $.proxy(proxy._preEndEdit, proxy, editTreeGridId),
                    beginEdit: $.proxy(proxy._preBeginEdit, proxy),
                    rowSelected: $.proxy(proxy._deleteDisableEnable, proxy),
                    treeColumnIndex:5,
                });
                
                if (model.selectedItem && model.selectedItem.hasChildRecords && args.requestType!=="add")
                {
                    proxy.enbleDisableDeletePreButton('disable');
                    proxy.enbleDisableAddPreButton('disable');
                }
                else {
                    proxy.enbleDisableDeletePreButton('disable');
                    proxy.enbleDisableAddPreButton('enable');
                }
            }
        },

        enbleDisableDeletePreButton:function(args)
        {
            var proxy = this;
            if(args==="enable")
            {
                $(".e-deletepre").unbind("click", $.proxy(proxy._deletepredecessor, proxy));
                $(".e-deletepre").bind("click", $.proxy(proxy._deletepredecessor, proxy));
                $('.e-deletepre').addClass('e-enable');
                $('.e-deletepre').removeClass('e-disable');
            }
            else {
                $(".e-deletepre").unbind("click", $.proxy(proxy._deletepredecessor, proxy));
                $('.e-deletepre').addClass('e-disable');
                $('.e-deletepre').removeClass('e-enable');
            }
        },
        enbleDisableAddPreButton:function(args)
        {
            var proxy = this;
            if (args === "enable") {
               $(".e-addpre").unbind("click", $.proxy(proxy._addpredecessor, proxy));
               $(".e-addpre").bind("click", $.proxy(proxy._addpredecessor, proxy));
                $('.e-addpre').addClass('e-enable');
                $('.e-addpre').removeClass('e-disable');
            }
            else {
                $(".e-addpre").unbind("click", $.proxy(proxy._addpredecessor, proxy));
                $('.e-addpre').addClass('e-disable');
                $('.e-addpre').removeClass('e-enable');
            }
        },
        _disableAddButton: function (treeGridId) {
            var proxy = this;
            var table = $(treeGridId +"e-table");
            var flag = false;
            var len = table[0].rows.length;
            proxy.enbleDisableAddPreButton('disable');
            for (var j = 0; j < len; j++)
            {
                var currentRow = table[0].rows[j];
                if(currentRow.cells.length===4)
                if(currentRow.cells[1].innerText==="")
                {
                    flag = true;
                }
            }
            if (!flag) {
                proxy.enbleDisableAddPreButton('enable');
            }
        },
        _addpredecessor: function (e) {
            var proxy = this;
            var args = {},treeGridId;
            args["requestType"] = ej.TreeGrid.Actions.Save;
            args["_cAddedRecord"] = {item:{ id: "", name: "", type: "", offset: "" },hasChildRecords:false,level:0};
            proxy.enbleDisableAddPreButton('disable');
            if ($(e.target).hasClass("e-edit-dialog"))
                treeGridId="#treegrid" + proxy._id + "predecessoredit";
            else
                treeGridId = "#treegrid" + proxy._id + "predecessorAdd";

            var selectedIndex = $(treeGridId).ejTreeGrid("option", "selectedRowIndex");
            $(treeGridId).ejTreeGrid("clearSelection", selectedIndex);
            $(treeGridId).ejTreeGrid("processBindings", args);
            proxy.enbleDisableDeletePreButton("disable");
        },

        _deletepredecessor:function(e)
        {
            var proxy = this, treeGridId;

            if ($(e.target).hasClass("e-edit-dialog"))
                treeGridId = "#treegrid" + proxy._id + "predecessoredit";
            else
                treeGridId = "#treegrid" + proxy._id + "predecessorAdd";

            var selectedItem = $(treeGridId).ejTreeGrid("option", "selectedRowIndex");
            var args = {};
            args["requestType"] = ej.TreeGrid.Actions.Delete;
            if (selectedItem !== -1) {
                $(treeGridId).ejTreeGrid("deleteRow");
                proxy.enbleDisableDeletePreButton('disable');
            }
            proxy._disableAddButton(treeGridId);
        },


        getColumnIndexByField: function (field) {

            var proxy = this,
                columns = proxy.model.columns,
                length = columns.length,
                column = 0;

            for (column; column < length; column++) {

                if (columns[column]["field"] == field) break;

            }

            return column;
        },

        getIndexofresourceInfo: function (dataSource,data) {
            var resourceInfo = data.resourceInfo,
                count = 0, length = resourceInfo && resourceInfo.length, resourceIndex = [];

            for (count; count < length; count++)
                resourceIndex.push(dataSource.indexOf(resourceInfo[count]));

            return resourceIndex;

        },
        
        _focusElements: function ($currentCell) {
            if ($currentCell.length) {
                $currentCell.focus();
                var $childElem = $currentCell.children();
                if ($childElem[0].tagName.toLowerCase() == "select" || $childElem[0].tagName.toLowerCase() == "input") {
                    $childElem.focus().select();
                    $childElem[0].focus();
                }
                else if ($childElem.find(".e-field.e-dropdownlist").length)
                    $childElem.find(".e-ddl").focus();
                else
                    $childElem.find('input,select').select().focus();
            }
        },

        renderDiaglogButton: function (form, tbody) {

            var btnId,
                proxy = this,
                model = proxy.model;
            if (form[0].id === (proxy._id + "EditForm"))
                btnId = "EditDialog_";
            else
                btnId = "AddDialog_";

            var savebtn = ej.buildTag('input', "",
                 {
                     'border-radius':'3px'
                 },
                 { type: "button", id: btnId + proxy._id + "_Save" }),
             saveText = proxy._editDialogTexts["saveButton"];
            
            savebtn.ejButton(
                {
                    cssClass: model.cssClass,
                    text: saveText,
                    width: "70"
                });

            var cancelText = proxy._editDialogTexts["cancelButton"],
             cancelbtn = ej.buildTag('input', "",
                 {
                     'margin-left': '20px',
                     'border-radius': '3px'
                 },
                 {
                     type: "button",
                     id: btnId + proxy._id + "_Cancel"
                 });
            
            cancelbtn.ejButton(
                {
                    cssClass: model.cssClass,
                    text: cancelText,
                    width: "70"
                });

            //Sample delete button
            var delbtn = ej.buildTag('input', "",
                {
                    'margin-left': '20px',
                    'border-radius': '3px'
                },
                {
                    type: "button",
                    id: "EditDialog_" + proxy._id + "_Delete"
                });

            delbtn.ejButton(
                {
                    cssClass: model.cssClass,
                    text: "Delete",
                    width: "70"
                });



            var btnDiv = ej.buildTag('div', "", { 'margin-top': '20px','float':'right','margin-bottom':'15px' ,'margin-right':'15px'}, { 'class': "e-editform-btn" });

            btnDiv.append(savebtn);
            if(form[0].id===(proxy._id+"EditForm") && model.editSettings.allowDeleting)
                btnDiv.append(delbtn);
            btnDiv.append(cancelbtn);
            form.appendTo(tbody);
            btnDiv.appendTo(tbody);
            
            return tbody;
        },
        _toolbarItemLeave:function(args)
        {
            var i = 0;
        },
        _renderToolBar: function() {
            var proxy = this,
                model = proxy.model,
                $div = ej.buildTag("div.e-gantttoolbar#e-gantttoolbar" + proxy._id, "", { 'height': '50px'}, { id: proxy._id + "_toolbarItems"}),
                $ul = ej.buildTag("ul", "", { 'width': proxy._ganttWidth - proxy._totalBorderWidth }, {});
            (!ej.isNullOrUndefined(model.toolbarSettings.toolbarItems) && model.toolbarSettings.toolbarItems.length) && proxy._renderLi($ul);
            $div.append($ul);
            var $customUl = ej.buildTag("ul");
            $div.append($customUl);
            var helper = {};
            helper.click = proxy._toolBarClick;
            helper.cssClass = "";
            helper.rtl = false;
            helper.itemSeparator = false;
            helper.itemLeave = proxy._toolbarItemLeave
            helper.width = proxy._ganttWidth - proxy._totalBorderWidth;
            helper.fields = {
                id: "",
                tooltipText: "",
                imageUrl: "",
                text: "",
                imageAttributes: "",
                spriteCSS: "",
                htmlAttributes: "",
            };
            $div.ejToolbar(helper);
            $div.ejToolbar("disableItem", proxy._disabledToolItems);
            proxy._disabledToolItems = $();
            return $div;
        },

        _renderLi: function ($ul) {
            var proxy = this,
                toolBarItems = proxy.model.toolbarSettings.toolbarItems,
                length = toolBarItems.length,
                i = 0,
                $li;
            for (i; i < length; i++) {

                $li = ej.buildTag("li", "", {}, {
                    id: proxy._id + "_" + toolBarItems[i],                    
                    "tabindex": "0"
                });

                if (toolBarItems[i] !== "search")
                    $li.css({ 'width': '30px', 'height': '24px' });

                proxy._renderLiContent($li, toolBarItems[i]);
                $ul.append($li);
            }
        },

        _renderLiContent: function ($li, item) {
            var $a, $input;
            var selectedRowIndex = this.model.selectedRowIndex;
            var editSetting = this.model.editSettings;
            switch (item) {

                case "add":
                    $a = ej.buildTag("span.e-addnewitem e-toolbaricons e-icon e-gantt-add", "", {});
                    //title: toolBarItems[i],
                    $li.attr("title","Add");
                    if (!this.model.editSettings.allowAdding)
                        this._disabledToolItems.push($li.get(0));
                    break;

                case "edit":
                    $a = ej.buildTag("span.e-edititem e-toolbaricons e-icon e-gantt-edit", "", {});
                    $li.attr("title", "Edit");
                    if (!this.model.editSettings.allowEditing || selectedRowIndex == -1) {
                        this._disabledToolItems.push($li.get(0));
                    }
                    
                    break;

                case "delete":
                    $li.attr("title", "Delete");
                    $a = ej.buildTag("span.e-deleteitem e-toolbaricons e-icon e-gantt-delete", "", {});
                    
                    if (!this.model.editSettings.allowDeleting || selectedRowIndex == -1) {
                        this._disabledToolItems.push($li.get(0));
                    }
                    
                    break;

                case "update":
                    $li.attr("title", "Update");
                    $a = ej.buildTag("span.e-saveitem e-toolbaricons e-icon e-gantt-save e-disabletool", "", {});
                    this._disabledToolItems.push($li.get(0));
                    break;

                case "cancel":
                    $li.attr("title", "Cancel");
                    $a = ej.buildTag("span.e-cancel e-toolbaricons e-icon e-gantt-cancel e-disabletool", "", {});
                    this._disabledToolItems.push($li.get(0));
                    break;

                case "indent":
                    $li.attr("title", "Indent");
                    $input = ej.buildTag("span.e-indent e-toolbaricons e-icon e-disabletool e-gantt-indent", "", {}, {});
                    $li.append($input);
                    this._disabledToolItems.push($li.get(0));
                    break;

                case "outdent":
                    $li.attr("title", "Outdent");
                    $input = ej.buildTag("span.e-outdent e-toolbaricons e-icon e-disabletool e-gantt-outdent", "", {}, {});
                    $li.append($input);
                    this._disabledToolItems.push($li.get(0));
                    break;

                case "expandAll":
                    $li.attr("title", "ExpandAll");
                    $input = ej.buildTag("span.e-expandall e-toolbaricons e-icon e-gantt-expandall", "", {}, {});
                    $li.append($input);
                    break;

                case "collapseAll":
                    $li.attr("title", "CollapseAll");
                    $input = ej.buildTag("span.e-collapseall e-toolbaricons e-icon e-gantt-collapseall", "", {}, {});
                    $li.append($input); 
                    break;
                case "prevTimeSpan":
                    $li.attr("title", "Previous Timespan");
                    $input = ej.buildTag("span.e-prevtimespan e-toolbaricons e-icon e-gantt-prevtimespan", "", {}, {});
                    $li.append($input);
                    break;
                case "nextTimeSpan":
                    $li.attr("title", "Next Timespan");
                    $input = ej.buildTag("span.e-nexttimespan e-toolbaricons e-icon e-gantt-nexttimespan", "", {}, {});
                    $li.append($input);
                    break;
                case "search":
                    $input = ej.buildTag("input.e-ejinputtext", "", { 'margin': '4px','text-indent':'4px' }, { type: "text", placeholder: "Search" }, { 'color': "#E8E9E9" });
                    $li.css({ 'float': 'right', 'padding': '2px' });
                    $li.attr("title", "Search");
                    $li.addClass('e-search');
                    $li.append($input);
                    this.model.allowSearching = true;

                    $input.keydown($.proxy(this._keyDown, this));

                    break;
            }
            $li.append($a);
        },


        _keyDown: function (e) {

            if (e.which ===13) { //13 is key code for Enter Key 
                this._searchString = e.currentTarget.value;

                this._toolbarOperation(this._id + "_search", e.currentTarget.value);
				e.preventDefault();
				return false;//prevent post back
            }          
        },

        
        _updateToolbarOptions:function(searchString){

            var proxy = this,
                model = proxy.model,
                $addElement = $($('.e-addnewitem')[0]).parent(),
                $editElement = $($('.e-edititem')[0]).parent(),
                $deleteElement = $($('.e-deleteitem')[0]).parent(),
                $indentElement = $($('.e-indent')[0]).parent(),
                $outdentElement = $($('.e-outdent')[0]).parent();
                

            if (searchString.length) {

                var disabledItems = [];

                if (model.editSettings.allowAdding) {
                    $addElement && disabledItems.push($addElement.removeClass('e-disable')[0]);
                }

                if (model.editSettings.allowEditing) {
                    $editElement && disabledItems.push($editElement.removeClass('e-disable')[0]);
                }

                if (model.editSettings.allowDeleting) {
                    $deleteElement && disabledItems.push($deleteElement.removeClass('e-disable')[0]);
                }

                
                if ($indentElement && $indentElement.length)
                    $indentElement && disabledItems.push($indentElement.removeClass('e-disable')[0]);

                if ($outdentElement && $outdentElement.length)
                    $outdentElement && disabledItems.push($outdentElement.removeClass('e-disable')[0]);

                $('.e-gantttoolbar').ejToolbar('disableItem', disabledItems);

            } else {
                var enabledItems = [];

                if (model.editSettings.allowAdding) {
                    $addElement && enabledItems.push($addElement[0]);
                }

                if (model.selectedItem) {

                    if (model.editSettings.allowEditing) {
                        $editElement && enabledItems.push($editElement[0]);
                    }

                    if (model.editSettings.allowDeleting) {
                        $deleteElement && enabledItems.push($deleteElement[0]);
                    }

                    proxy.updateIndentOutdentOption(model.selectedItem);
                }

                $('.e-gantttoolbar').ejToolbar('enableItem', enabledItems);
            }
        },

        _renderGantt: function() {
            
            var proxy = this,                                                                                
                leftPaneSize,
                rightPaneSize,
                ganttWidth = parseInt(proxy._ganttWidth) - proxy._totalBorderWidth;

            //calculate treegrid pane size
            leftPaneSize = (2*proxy._commonColumnWidth+3) / ganttWidth * 100;
            leftPaneSize = leftPaneSize < 30 ? leftPaneSize : 30;

            //Here 7 is the splitter span width
            rightPaneSize = 100 - leftPaneSize - (7 / ganttWidth * 100);

            $("#e-ejSpliter" + proxy._id).ejSplitter({
                //border width and height excluded
                height: proxy._ganttHeight,
                width: proxy._ganttWidth - proxy._totalBorderWidth,
                orientation: ej.Orientation.Horizontal,
                properties: [{ paneSize: leftPaneSize + "%",collapsible:false }, { paneSize: rightPaneSize + "%",collapsible:false }],
                enableAutoResize: false,
                resize: $.proxy(proxy._onResize,proxy)
            });
        },

        _renderTreeGrid: function() {
            var proxy = this, model = proxy.model;
            proxy._$treegridHelper = $("#ejTreeGrid" + proxy._id).ejTreeGrid({
                enableAltRow: model.enableAltRow,
                allowColumnResize: model.allowColumnResize,
                enableVirtualization: model.enableVirtualization,
                allowSorting: model.allowSorting,
                allowMultiSorting: model.allowMultiSorting,
                sortSettings: model.sortSettings,
                allowSelection: model.allowSelection,
                selectionType:"single",
                selectedRowIndex: this.selectedRowIndex(),
                allowSearching: model.allowSearching,
                parentIdMapping:model.parentTaskIdMapping,
                allowKeyboardNavigation: model.allowKeyboardNavigation,
                cssClass: model.cssClass,
                locale: model.locale,
                editSettings: model.editSettings,
                toolbarSettings:model.toolbarSettings,
                rowTemplate: model.rowTemplate,
                rowDataBound: model.rowDataBound,
                queryCellInfo: model.queryCellInfo,
                dataSource:this.dataSource(),
                flatRecords: model.ganttRecords,
                parentRecords: model.parentRecords,
                records: proxy._rows,
                ids: proxy._ids,
                columns: proxy._columns,
                dateFormat: model.dateFormat,
                resourceInfoMapping: model.resourceInfoMapping,
                resourceNameMapping: model.resourceNameMapping,
                resourceIdMapping:model.resourceIdMapping,
                taskIdMapping: model.taskIdMapping,
                showGridCellTooltip: model.showGridCellTooltip,
                showGridExpandCellTooltip: model.showGridExpandCellTooltip,
                taskNameMapping: model.taskNameMapping,
                startDateMapping: model.startDateMapping,
                endDateMapping: model.endDateMapping,
                childMapping: model.childMapping,
                durationMapping: model.durationMapping,
                progressMapping: model.progressMapping,
                predecessorMapping: model.predecessorMapping,
                rowHeight: model.rowHeight,
                emptyRecordText: proxy._emptyRecordText,
                isFromGantt: proxy._isFromGantt,
                treeColumnIndex: model.treeColumnIndex,
                workingTimeScale:model.workingTimeScale,
            });
        },

        _renderGanttChart: function() {
            var proxy = this,
                model = this.model;
            proxy._$ganttchartHelper = $("#ejGanttChart" + proxy._id).ejGanttChart(
                {
                    dataSource: this.dataSource(),
                    scheduleStartDate: model.scheduleStartDate,
                    scheduleEndDate: model.scheduleEndDate,
                    startDateMapping: model.startDateMapping,
                    endDateMapping: model.endDateMapping,
                    progressMapping: model.progressMapping,
                    durationMapping: model.durationMapping,
                    childPropertyName: model.childMapping,
                    predecessorMapping: model.predecessorMapping,
                    enableVirtualization: model.enableVirtualization,
                    highlightWeekends: model.highlightWeekends,
                    milestoneMapping: model.milestoneMapping,
                    enableRowHover: model.enableRowHover,
                    perDayWidth: proxy._perDayWidth,
                    workingTimeScale: model.workingTimeScale,
                    roundOffDayworkingTime: model.roundOffDayworkingTime,
                    durationUnit: model.durationUnit,
                    
                    perMonthWidth: proxy._perMonthWidth,//new property for year - month schedule
                    perWeekWidth: proxy._perWeekWidth,//new property for week - month schedule
                    perHourWidth: proxy._perHourWidth,

                    includeWeekend: model.includeWeekend,
                    connectorlineWidth: model.connectorlineWidth,
                    scheduleHeaderSettings: model.scheduleHeaderSettings,
                    taskbarBackground: model.taskbarBackground,
                    progressbarBackground: model.progressbarBackground,
                    connectorLineBackground: model.connectorLineBackground,
                    parentTaskbarBackground: model.parentTaskbarBackground,
                    parentProgressbarBackground: model.parentProgressbarBackground,
                    holidays: model.holidays,
                    dateFormat: model.dateFormat,
                    locale: model.locale,
                    enableTaskbarTooltip: model.enableTaskbarTooltip,
                    enableTaskbarDragTooltip:model.enableTaskbarDragTooltip,
                    ganttRecords: model.ganttRecords,
                    parentRecords: model.parentRecords,
                    rows: proxy._rows,
                    scheduleWeeks: proxy._scheduleWeeks,

                    projectStartDate: proxy._projectStartDate, //new property instead of scheduleWeeks[0] and scheduleYears[0]
                    projectEndDate: proxy._projectEndDate,

                    scheduleYears: proxy._scheduleYears, //new property for year
                    scheduleMonths: proxy._scheduleMonths, //new property for month
                    scheduleDays:proxy._scheduleDays,
                    progressbarHeight: model.progressbarHeight,
                    tooltipTemplate: model.taskbarTooltipTemplate,
                    tooltipTemplateId: model.taskbarTooltipTemplateId,
                    progressbarTooltipTemplate: model.progressbarTooltipTemplate,
                    progressbarTooltipTemplateId: model.progressbarTooltipTemplateId,
                    queryTaskbarInfo: model.queryTaskbarInfo,
                    showTaskNames: model.showTaskNames,
                    showProgressStatus: model.showProgressStatus,
                    showResourceNames: model.showResourceNames,
                    resourceInfoMapping: model.resourceInfoMapping,
                    resourceNameMapping: model.resourceNameMapping,
                    enableProgressBarResizing: model.enableProgressBarResizing,
                    allowGanttChartEditing: model.allowGanttChartEditing,
                    taskbarEditingTooltipTemplateId: model.taskbarEditingTooltipTemplateId,
                    taskbarEditingTooltipTemplate:model.taskbarEditingTooltipTemplate,
                    _ids: proxy._ids,
                    stripLines: model.stripLines,
                    _predecessorCollection: proxy._predecessorsCollection,
                    weekendBackground: model.weekendBackground,
                    allowKeyboardNavigation: model.allowKeyboardNavigation,
                    updatedGanttRecords: proxy._updatedGanttRecords,
                    renderBaseline: model.renderBaseline,
                    baselineColor:model.baselineColor,
                    editSettings: model.editSettings,
                    columnHeaderTexts: proxy._columnHeaderTexts,
                    localizedDays: proxy._days,
                    localizedMonths:proxy._months,
                    rowHeight: model.rowHeight,
                    allowSelection:model.allowSelection
                });
        },

        createTreeGridColumns: function () {

            var proxy = this, model = proxy.model, column, columns = [];

            var mapping = (model.taskIdMapping)//?model.taskIdMapping:"Task Id";

            if (mapping.length) {
                column = {
                    field: "taskId",
                    headerText: proxy._columnHeaderTexts["taskId"],
                    width: 30,
                    editType: ej.Gantt.EditingType.String,
                    mappingName: mapping
                };

                columns.push(column);
                //proxy._emptyDataColumns.push(column.field);
            }

            mapping = model.taskNameMapping;// "Task Name";

            if (mapping.length) {
                column = {
                    field: "taskName",
                    headerText: proxy._columnHeaderTexts["taskName"],
                    width: 150,
                    editType: ej.Gantt.EditingType.String,
                    mappingName: mapping
                };

                columns.push(column);
                //proxy._emptyDataColumns.push(column.field);
            }

            mapping = model.startDateMapping;// "Start Date";

            if (mapping.length) {
                column = {
                    field: "startDate",
                    headerText:proxy._columnHeaderTexts["startDate"],
                    width: 150,
                    editType: ej.Gantt.EditingType.DatePicker,
                    mappingName: mapping
                };

                columns.push(column);
                //proxy._emptyDataColumns.push(column.field);
            }


            mapping = model.endDateMapping;// "End Date";

            if (mapping.length) {
                column = {
                    field: "endDate",
                    headerText: proxy._columnHeaderTexts["endDate"],
                    width: 150,
                    editType: ej.Gantt.EditingType.DatePicker,
                    mappingName:mapping
                };

                columns.push(column);
                //proxy._emptyDataColumns.push(column.field);
            }

            mapping = model.resourceInfoMapping;//"Resources";

            if (mapping.length) {
                column = {
                    field: "resourceInfo",
                    headerText:proxy._columnHeaderTexts["resourceInfo"],
                    width: 150,
                    editType: ej.Gantt.EditingType.Dropdown,
                    mappingName: mapping,
                    dropdownData: model.resources //model.resources is null
                };
                columns.push(column);
                //proxy._emptyDataColumns.push(column.field);
            }

            mapping = model.durationMapping;// "Duration";

            if (mapping.length) {
                column = {
                    field: "duration",
                    headerText: proxy._columnHeaderTexts["duration"],
                    width: 150,
                    editType: ej.Gantt.EditingType.Numeric,
                    mappingName:mapping
                };

                columns.push(column);
                //proxy._emptyDataColumns.push(column.field);
            }

            mapping = model.progressMapping;// "Progress";

            if (mapping.length) {
                column = {
                    field: "status",
                    headerText: proxy._columnHeaderTexts["status"],
                    width: 150,
                    editType: ej.Gantt.EditingType.Numeric,
                    mappingName:mapping
                };
                columns.push(column);
                //proxy._emptyDataColumns.push(column.field);
            }
            mapping = model.predecessorMapping;//)?model.predecessorMapping: "Predecessor";

            if (mapping.length) {
                column = {
                    field: "predecessor",
                    headerText:proxy._columnHeaderTexts["predecessor"],
                    width: 150,
                    editType: ej.Gantt.EditingType.String,
                    mappingName: mapping
                };
                columns.push(column);
                //proxy._emptyDataColumns.push(column.field);
            }
            
            //mapping = (model.baselineStartDateMapping )?model.baselineStartDateMapping: "Baseline StartDate";

            //if (mapping.length) {
            //    column = {
            //        field: "baselineStartDate",
            //        headerText: proxy._columnHeaderTexts["baselineStartDate"],
            //        width: 150,
            //        editType: ej.Gantt.EditingType.DatePicker,
            //        mappingName: mapping
            //    };
            //    columns.push(column);
            //    proxy._emptyDataColumns.push(column.field);
            //}
            //mapping = (model.baselineEndDateMapping)?model.baselineEndDateMapping: "Baseline EndDate";

            //if (mapping.length) {
            //    column = {
            //        field: "baselineEndDate",
            //        headerText:proxy._columnHeaderTexts["baselineEndDate"],
            //        width: 150,
            //        editType: ej.Gantt.EditingType.DatePicker,
            //        mappingName: mapping
            //    };
            //    columns.push(column);
            //    proxy._emptyDataColumns.push(column.field);
            //}
            return columns;
        },
        

        _createGanttRecords: function(data) {
            var proxy = this,
                model = proxy.model,
                ganttRecords = model.ganttRecords,
                length = data.length,
                count = 0,
                parentGanttRecord,
                parentRecords = model.parentRecords,
                enableSorting = model.allowSorting,
                enableAltRow = model.enableAltRow,
                rows = proxy._rows,
                ids = proxy._ids;


            for (count; count < length; count++) {
                parentGanttRecord = proxy._createGanttRecord(data[count], 0, null,undefined,"Load");
                proxy._storedIndex++;
                //if (enableAltRow)
                parentGanttRecord.isAltRow = proxy._storedIndex % 2 == 0 ? false : true;
                parentGanttRecord.index = proxy._storedIndex;
                rows[proxy._storedIndex] = parentGanttRecord;
                ids[proxy._storedIndex] = parentGanttRecord["taskId"].toString();
                ganttRecords.push(parentGanttRecord);
                //if (enableSorting)
                parentRecords.push(parentGanttRecord);
                parentGanttRecord.childRecords && proxy._addNestedGanttRecords(parentGanttRecord.childRecords);
            }

            for (var i = 0; i < ganttRecords.length; i++) {
                
                if (ganttRecords[i].isMilestone) {
                    if (ganttRecords[i].parentItem) {
                        ganttRecords[i].startDate = ganttRecords[i].parentItem.endDate;
                    } else {
                        ganttRecords[i].startDate = ganttRecords[i - 1].endDate;
                    }
                }

                if (ganttRecords[i].parentItem) {
                        proxy._updateParentItem(ganttRecords[i]);
                }
                
            }
        },
        
        //Update left value on scheduleDate changes
        _updateLeftValue:function()
        {
            var proxy = this, model = this.model, records = model.ganttRecords;
            $.each(records, function (index,ganttRecord ) {
                ganttRecord.left = ganttRecord._calculateLeft(proxy._projectStartDate, proxy._perDayWidth, proxy._holidaysList, model);
                if (model.renderBaseline && ganttRecord.baselineStartDate && ganttRecord.baselineEndDate) {
                    ganttRecord.baselineLeft = ganttRecord._calculateBaselineLeft(proxy._projectStartDate, proxy._perDayWidth, model.includeWeekend, model.dateFormat, model.endDateMapping, proxy._holidaysList);
                }
            });
        },
        //Calculate schedule dates from GanttRecord Collections
        _calculateScheduleDates:function(editArgs)
        {
            var proxy = this,
                minStartDate,
                maxEndDate,
                tempStartDate,
                tempEndDate,
                model = this.model,
                records = model.ganttRecords,
                updatedDates;
            if (((!model.scheduleEndDate || !model.scheduleStartDate) && records.length > 0)  || editArgs) {

                $.each(records, function (index, value) {
                        tempStartDate = proxy._getDateFromFormat(value.startDate);
                        tempEndDate = proxy._getDateFromFormat(value.endDate);
                        baseLineStartDate = value.baselineStartDate ? proxy._getDateFromFormat(value.baselineStartDate) : null;
                        baseLineEndDate = value.baselineEndDate ? proxy._getDateFromFormat(value.baselineEndDate) : null;
                        //minimum startDate
                        if (minStartDate) {
                            if (minStartDate.getTime() >= tempStartDate.getTime()) {
                                minStartDate = tempStartDate;
                            }
                            if (baseLineStartDate && model.renderBaseline && (minStartDate.getTime() >= baseLineStartDate.getTime())) {
                                minStartDate = baseLineStartDate;
                            }
                        } else {
                            if (baseLineStartDate && model.renderBaseline && tempStartDate.getTime() >= baseLineStartDate.getTime())
                                minStartDate = baseLineStartDate;
                            else
                                minStartDate = tempStartDate;
                        }
                        //Maximum endDate
                        if (maxEndDate) {
                            if (maxEndDate.getTime() <= tempEndDate.getTime()) {
                                maxEndDate = tempEndDate;
                            }
                            if (baseLineEndDate && model.renderBaseline && (maxEndDate.getTime() <= baseLineEndDate.getTime())) {
                                maxEndDate = baseLineEndDate;
                            }

                        } else {
                            if (baseLineEndDate && model.renderBaseline && tempEndDate.getTime() <= baseLineEndDate.getTime())
                                maxEndDate = baseLineEndDate;
                            else
                                maxEndDate = tempEndDate;
                        }
                });
                updatedDates = proxy._updateScheduleDatesByTaskLables(minStartDate, maxEndDate);
                minStartDate = updatedDates.minStartDate;
                maxEndDate = updatedDates.maxEndDate;
            }
            else if ((!model.scheduleEndDate || !model.scheduleStartDate) && records.length === 0) {
                minStartDate = proxy._getDateFromFormat(new Date());
                maxEndDate = proxy._getDateFromFormat(new Date(minStartDate));
                maxEndDate.setDate(maxEndDate.getDate() + 20);
            }
            if (!editArgs) {
                model.scheduleStartDate = minStartDate ? proxy.getFormatedDate(minStartDate) : model.scheduleStartDate;
                model.scheduleEndDate = maxEndDate ? proxy.getFormatedDate(maxEndDate) : model.scheduleEndDate;
            }
            else {
                editArgs.minStartDate = minStartDate;
                editArgs.maxEndDate = maxEndDate;
            }

        },

        //update schedule dates as per showTaskName and showResourceName values  and 
        //holidays collection and strip line collections at loadtime and edit time
        _updateScheduleDatesByTaskLables:function(startDate,endDate)
        {
            var proxy = this,
                model = this.model,
                scheduleEndDate,
                scheduleHeaderType = model.scheduleHeaderSettings.scheduleHeaderType,
                resourceStringWidth = proxy._getResourceStringWidth(),
                numOfDays, returnValues = {},
                scheduleEndDate = model.scheduleEndDate && this._getDateFromFormat(model.scheduleEndDate);
              
            if (scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Week) {
                //if (model.showTaskNames) {
                //    startDate.setDate(startDate.getDate() - 7);//one week before
                //}
                if (!model.scheduleEndDate || (scheduleEndDate.getTime() !== endDate.getTime()))
                {
                    numOfDays = resourceStringWidth > 0 ? (resourceStringWidth / proxy._perDayWidth)+7 : 7;//one week after
                    endDate.setDate(endDate.getDate() + numOfDays);
                }
            }
            if (scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Year) {
                //if (model.showTaskNames) {
                //    startDate.setMonth(startDate.getMonth() - 2);//2 month before
                //}
                if (!model.scheduleEndDate || (scheduleEndDate.getTime() !== endDate.getTime())) {
                    numOfDays = resourceStringWidth > 0 ? (resourceStringWidth / proxy._perMonthWidth) + 1 : 1;//1 month after
                    endDate.setMonth(endDate.getMonth() + numOfDays);
                }
            }
             

            if (scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Month) {
                //if (model.showTaskNames) {
                //    startDate.setDate(startDate.getDate() - 14);//two week before
                //}
                if (!model.scheduleEndDate || (scheduleEndDate.getTime() !== endDate.getTime())) {
                    numOfDays = resourceStringWidth > 0 ? (resourceStringWidth / proxy._perDayWidth) + 7 : 7;//one week after
                    endDate.setDate(endDate.getDate() + numOfDays);
                }
            }


            if (scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Day) {
                //if (model.showTaskNames) {
                //    startDate.setHours(startDate.getHours() - 8);//8hrs before
                //}
                if (!model.scheduleEndDate || (scheduleEndDate.getTime() !== endDate.getTime())) {
                    numOfDays = resourceStringWidth > 0 ? (resourceStringWidth / proxy._perHourWidth) + 7 : 7;//7hrs after
                    endDate.setHours(endDate.getHours() + numOfDays);
                }
            }


            //Check striplines are in range of schedule dates
            if (model.stripLines.length > 0) {
                $.each(model.stripLines, function (idx, value) {
                    var currentValue = proxy._getDateFromFormat(value.day)
                    if (!(currentValue.getTime() > startDate.getTime()) || !(currentValue.getTime() < endDate.getTime())) {
                        if (currentValue.getTime() < startDate.getTime())
                            startDate = currentValue;
                        else
                            endDate = currentValue;
                    }
                });
            }
            //Check holidays are in range of schedule dates
            if (proxy._holidaysList.length > 0) {
                $.each(proxy._holidaysList, function (idx, value) {
                    if (!(value.getTime() > startDate.getTime()) || !(value.getTime() < endDate.getTime())) {
                        if (value.getTime() < startDate.getTime())
                            startDate = value;
                        else
                            endDate = value;
                    }
                });
            }


            returnValues.minStartDate = startDate;
            returnValues.maxEndDate = endDate;
           
            return returnValues;

        },

        //Get reosurce collections width
        _getResourceStringWidth:function(){
            var proxy = this,
                model = this.model,
                resource = model.resources,
                totalString = "",width;
            if (resource.length > 0 && model.showResourceNames) {
                for (var count = 0; count < resource.length; count++) {
                    totalString += resource[count][model.resourceNameMapping] + " ,";
                }
                var $span = ej.buildTag("span", "", { "font-family": "Segoe UI", "font-size": "12px" }, {});
                $span.text(totalString);
                $(document.body).append($span);
                width = $span.width();
                $span.remove();
                return width;
            } else {
                return 0;
            }
        },

        //calculate project dates by schedule mode types
        _calculateHeaderDates: function () {

            var proxy = this,
                model=this.model,
                startDate = proxy._getDateFromFormat(model.scheduleStartDate),
                endDate = proxy._getDateFromFormat(model.scheduleEndDate);

            if (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Week)
                proxy._calculateWeekSplit(startDate, endDate);

            if (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Year) {
                proxy._calculateYearSplit(startDate, endDate);//method for year split
            }

            if (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Month)
                proxy._calculateMonthSplit(startDate, endDate);//method for Month split

            if (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Day)
                proxy._calculateDaySplit(startDate, endDate);
        },
        //AddNested Gantt Records
        _addNestedGanttRecords: function (data) {
            var proxy = this,
                rows = proxy._rows,
                ids = proxy._ids,
                model = proxy.model,
                ganttRecords = model.ganttRecords,
                count = 0,
                length = data.length,
                records = [],
                record,
                enableAltRow = model.enableAltRow;
            
            for (count; count < length; count++) {
                record = data[count];
                proxy._storedIndex++;
                //if (enableAltRow)
                record.isAltRow = proxy._storedIndex % 2 == 0 ? false : true;;
                record.index = proxy._storedIndex;
                rows[proxy._storedIndex] = record;
                ids[proxy._storedIndex] = record["taskId"].toString();
                ganttRecords.push(record);
                records = record.childRecords;
                if (records) {
                    var j = 0, recordlength = records.length, childGanttRecord = null;
                    for (j; j < recordlength; j++) {
                        childGanttRecord = records[j];
                        proxy._storedIndex++;
                        //if (enableAltRow)
                        childGanttRecord.isAltRow = proxy._storedIndex % 2 == 0 ? false : true;
                        childGanttRecord.index = proxy._storedIndex;
                        rows[proxy._storedIndex] = childGanttRecord;
                        ids[proxy._storedIndex] = childGanttRecord["taskId"].toString();
                        ganttRecords.push(childGanttRecord);
                        childGanttRecord.childRecords && proxy._addNestedGanttRecords(childGanttRecord.childRecords);
                    }
                }

            }
            
        },
        
        _createGanttRecord: function(data, level, parentItem, expanded,creatAt) {
            var proxy = this, ganttRecord, model = proxy.model, //column = proxy._emptyDataColumns,
                child = data[model.childMapping],
                startDate = data[model.startDateMapping],
                endDate = data[model.endDateMapping],
                duration = data[model.durationMapping] ? data[model.durationMapping] : 0,
                status =data[model.progressMapping]?data[model.progressMapping]:0,
                startDateType = proxy._getDateFromFormat(startDate),
                endDateType = proxy._getDateFromFormat(endDate),
                resourceInfo = data[model.resourceInfoMapping],
                predecessors = data[model.predecessorMapping],
                baselineStartDate = data[model.baselineStartDateMapping],
                baselineStartDateType = proxy._getDateFromFormat(baselineStartDate, model.dateFormat),
                baselineEndDate = data[model.baselineEndDateMapping],
                baselineEndDateType = proxy._getDateFromFormat(baselineEndDate, model.dateFormat);
            resourceName = [];
            predecessorscol = [];
            var sTime = startDateType ? new Date(startDateType.getFullYear(), startDateType.getMonth(), startDateType.getDate()).getTime() : null,
                eTime = endDateType ? new Date(endDateType.getFullYear(), endDateType.getMonth(), endDateType.getDate()).getTime() : null;

            ganttRecord = new ej.Gantt.GanttRecord();
            ganttRecord.taskId = data[model.taskIdMapping],
            ganttRecord.taskName = data[model.taskNameMapping],
            ganttRecord.startDate = proxy.getFormatedDate(startDateType),
            ganttRecord.endDate = proxy.getFormatedDate(endDateType),

            ganttRecord.taskbarBackground = null,
            ganttRecord.progressbarBackground = null,
            ganttRecord.parentProgressbarBackground = null,
            ganttRecord.parentTaskbarBackground = null,

            ganttRecord.cellBackgroundColor = null,
            ganttRecord.rowBackgroundColor = null,
            ganttRecord.treeMappingName = [],

            ganttRecord.baselineStartDate = proxy.getFormatedDate(baselineStartDateType),
            ganttRecord.baselineEndDate = proxy.getFormatedDate(baselineEndDateType),
            ganttRecord.duration = duration;
            if (endDateType && (ej.isNullOrUndefined(duration) || sTime != eTime)) {
                ganttRecord._calculateDuration(startDateType, endDateType, model.includeWeekend, model.holidays, data[model.milestoneMapping],model);
                duration = ganttRecord.duration;
            }
            ganttRecord.isMilestone = duration == 0 ? true : (data[model.milestoneMapping]) ? data[model.milestoneMapping] : false,
            ganttRecord.duration = (ganttRecord.isMilestone && duration != 0) ? 0 : duration,
            ganttRecord.status = status,
            ganttRecord.predecessor = predecessors && ganttRecord._calculatePredecessor(predecessors);

            if (ganttRecord.predecessor)
            {
                for (var i = 0; i < ganttRecord.predecessor.length; i++) {
                    predecessorscol[i] = ganttRecord.predecessor[i].from.toString() + ganttRecord.predecessor[i].predecessorsType.toString();                  //&& ganttRecord.predecessor[i].predecessorsType && ganttRecord.predecessor[i].to;                    
                }
                ganttRecord.predecessorsName = predecessorscol.join(' ');
            }
            ganttRecord.resourceInfo = resourceInfo && ganttRecord._setResourceInfo(data[(model.resourceInfoMapping)], model.resourceIdMapping, model.resourceNameMapping, model.resources);
          
            if (ganttRecord.resourceInfo) {
                for(var i=0;i<ganttRecord.resourceInfo.length;i++)
                    resourceName[i] = ganttRecord.resourceInfo[i].resourceName;
                ganttRecord.resourceNames = resourceName.join(' ');
            }
            ganttRecord.parentItem = parentItem;
            var tempData;
            if (model.parentTaskIdMapping && creatAt)
            {
                tempData = ej.DataManager(proxy._retrivedData).executeLocal(ej.Query().where(model.taskIdMapping,
                ej.FilterOperators.equal,
                ganttRecord.taskId));
                ganttRecord.item = tempData[0];
            }
            else
            {
                if (this.dataSource() instanceof ej.DataManager && this.dataSource().dataSource.json && this.dataSource().dataSource.offline && creatAt) {
                var tempData = ej.DataManager(proxy._retrivedData).executeLocal(ej.Query().where(model.taskIdMapping,
                ej.FilterOperators.equal,
                ganttRecord.taskId));
                if (tempData.length > 0) {
                    ganttRecord.item = tempData[0];
                } else {
                    ganttRecord.item = data;
                }
                }
                else {
                    ganttRecord.item = data;
                }
            }
            ganttRecord.isSelected = proxy.selectedItem() ? proxy.selectedItem()[(model.taskIdMapping) ? model.taskIdMapping : "Task Id"] == ganttRecord.taskId ? true : false : false,
            ganttRecord.level = level;
            if(!ganttRecord.endDate)
            {
                ganttRecord._calculateEndDate(model.includeWeekend, this._holidaysList, model, proxy._perDayWidth);
            }

            ganttRecord.width = ganttRecord._calculateWidth(proxy._perDayWidth, proxy._holidaysList,model),
            ganttRecord.width = ganttRecord.width == 0 ? 26 : ganttRecord.width,
            ganttRecord.progressWidth = ganttRecord._calculateProgressWidth(ganttRecord.width, status),
            ganttRecord.childRecords = child && proxy._createChildRecords(child, level + 1, ganttRecord),
            ganttRecord.hasChildRecords = child ? true : false,
            ganttRecord.expanded = expanded !== undefined ? expanded : child ? child.length > 0 : false;
            if (model.enableVirtualization === false)
            {
                ganttRecord.isExpanded=true;
            }

            if (!creatAt) {
                ganttRecord.left = ganttRecord._calculateLeft(proxy._projectStartDate,
                                   proxy._perDayWidth, proxy._holidaysList, model);
                if (model.renderBaseline && ganttRecord.baselineStartDate && ganttRecord.baselineEndDate)
                    ganttRecord.baselineLeft = ganttRecord._calculateBaselineLeft(proxy._projectStartDate, proxy._perDayWidth, model.includeWeekend, model.dateFormat, model.endDateMapping, proxy._holidaysList);
            }
            if (model.renderBaseline && ganttRecord.baselineStartDate && ganttRecord.baselineEndDate) {
                ganttRecord.baselineWidth = ganttRecord._calculateBaseLineWidth(proxy._perDayWidth, model);
            }
            else
                model.renderBaseline = false;
           

            if (predecessors)
                proxy._predecessorsCollection.push(ganttRecord);
            
            return ganttRecord;
        },
        
        _getHoliday: function () {
            if (this.model.holidays != null) {
                var holidayList = this.model.holidays,
                    holidays = [],
                    holidayLength = holidayList.length;
                if (holidayLength > 0) {
                    for (var i = 0; i < holidayLength; i++) {
                        holidays[i] = this.getDateType(holidayList[i].day);
                    }
                    return holidays;
                }
            }
            return false;
        },

        _getStringHolidays: function() {
            if (this._holidaysList != null && this._holidaysList.length > 0) {
                var holidayList = this._holidaysList,
                    holidays = [],
                    holidayLength = holidayList.length;
                if (holidayLength > 0) {
                    for (var i = 0; i < holidayLength; i++) {
                        holidays[i] = Globalize.format(holidayList[i], this.model.dateFormat);
                    }
                    return holidays;
                }
            }
            return false;
        },
        
        //create childRecords for particular GanttRecord
        _createChildRecords: function (data, level, parentItem) {
            var ganttRecords = [],
                proxy = this,
                i = 0,
                length = data.length;

            for (i = 0; i < length; i++) {
                if (data[i]) {
                    var parentRecord = proxy._createGanttRecord(data[i], level, parentItem,undefined,"Load");
                    ganttRecords.push(parentRecord);
                }
            }
            return ganttRecords;
        },

        _createResourceInfoCollection: function (data) {
            var proxy = this,
                count = 0,
                length = data.length;
            for (count; count < length; count++) {
                proxy._resourceInfoCollection.push(proxy._createResourceInfo(data[count]));
            }
        },

        _createResourceInfo: function (data) {
            var model = this.model, resourceInfo = {};
            resourceInfo.resourceId = data[model.resourceIdMapping];
            resourceInfo.resourceName = data[model.resourceNameMapping];
            return resourceInfo;
        },

        _calculateWeekSplit: function (startdate, enddate) {
            var proxy = this;
            var roundOffStartDate = startdate.getDay() == 0 ? (startdate.getDate()) - 7 :
                (startdate.getDate()) - startdate.getDay();
            startdate.setDate(roundOffStartDate);
            do {
                proxy._scheduleWeeks.push(new Date(startdate));
                startdate.setDate(startdate.getDate() + 7);
            } while (!(startdate > enddate));

            proxy._projectStartDate= new Date(proxy._scheduleWeeks[0]);
            proxy._projectEndDate = new Date(proxy._scheduleWeeks[proxy._scheduleWeeks.length - 1]);
        },

        //method for calculatting years (year-month schedule mode)
        _calculateYearSplit: function (startdate, enddate) {
            var proxy = this;
            startdate.setMonth(0);
            startdate.setDate(1);
            do {
                proxy._scheduleYears.push(new Date(startdate));
                startdate.setMonth(startdate.getMonth() + 12);
            } while (!(startdate >= enddate));

            var projectStartDate, projectEndDate;
            projectStartDate = new Date(proxy._scheduleYears[0].getFullYear(), 0, 1);
            projectEndDate = new Date(proxy._scheduleYears[proxy._scheduleYears.length - 1].getFullYear(), 11, 31);
            proxy._projectStartDate = projectStartDate;
            proxy._projectEndDate = projectEndDate;
        },

        //Method for calculating days (day-hour schedule mode)
        _calculateDaySplit: function (startdate, enddate) {
            var proxy = this;
            startdate.setHours(0);
            do {
                proxy._scheduleDays.push(new Date(startdate));
                startdate.setDate(startdate.getDate() + 1);
            } while ((startdate <= enddate));
            proxy._projectStartDate = new Date(proxy._scheduleDays[0]);
            proxy._projectEndDate = new Date(proxy._scheduleDays[proxy._scheduleDays.length - 1]);
        },

        //new method for calculatting months
        _calculateMonthSplit: function (startdate, enddate) {
            var proxy = this;
            dt = new Date(startdate.getFullYear(), startdate.getMonth() - 1, 1);
            startdate = dt;

            do {
                proxy._scheduleMonths.push(new Date(startdate));
                if (startdate.getMonth() == 0 || startdate.getMonth() == 2 || startdate.getMonth() == 4 || startdate.getMonth() == 6 || startdate.getMonth() == 7 || startdate.getMonth() == 9 || startdate.getMonth() == 11)
                    startdate.setDate(startdate.getDate() + 31);
                else if (startdate.getMonth() == 3 || startdate.getMonth() == 5 || startdate.getMonth() == 8 || startdate.getMonth() == 10)
                    startdate.setDate(startdate.getDate() + 30);
                else if (startdate.getMonth() == 1) {
                    if(startdate.getFullYear()%4==0)
                        startdate.setDate(startdate.getDate() + 29);
                    else
                        startdate.setDate(startdate.getDate() + 28);
                }
            } while (!(startdate >= enddate));

            var projectStartDate, projectEndDate;
            projectStartDate = new Date(proxy._scheduleMonths[0]);
            projectEndDate = new Date(proxy._scheduleMonths[proxy._scheduleMonths.length - 1]);
            projectEndDate = new Date(projectEndDate.getFullYear(), projectEndDate.getMonth() + 1, 0);
            proxy._projectStartDate = projectStartDate;
            proxy._projectEndDate = projectEndDate;
        },



        _updatePredecessors: function () {
            var proxy = this,
                count = 0,
                predecessorsCollection = proxy._predecessorsCollection,
                length = predecessorsCollection.length,
                ganttRecord,
                connectorsCollection,
            i = 0,
            successorGanttRecord,
            connectorCount;
            for (count; count < length; count++) {
                ganttRecord = predecessorsCollection[count];
                connectorsCollection = ganttRecord["predecessor"];
                connectorCount = connectorsCollection.length;
                for (i=0; i < connectorCount; i++) {
                    var connector = connectorsCollection[i];
                    successorGanttRecord = proxy.model.ganttRecords[proxy._ids.indexOf(connector.from)];
                    connector.to = ganttRecord['taskId'].toString();
                    if (successorGanttRecord) {
                        if (successorGanttRecord.predecessor) {
                            successorGanttRecord.predecessor.push(connector);
                        } else {
                            successorGanttRecord.predecessor = [];
                            successorGanttRecord.predecessor.push(connector);
                            predecessorsCollection.push(successorGanttRecord);
                        }
                    }

                }                
            }
        },
        
        getDateType: function (date) {
            if (date != null) {
                if (typeof (date) == "object") {
                    return date;
                }
                else {
                    var hyphenRegex = new RegExp("\\-", "g"),
                    dotRegex = new RegExp("\\.", "g");
                    date = date.replace(hyphenRegex, "/");
                    date = date.replace(dotRegex, "/");
                    return new Date(date);
                }
            }
            return null;
        },

        getFormatedDate: function(date) {
            return Globalize.format(date, this.model.dateFormat);
        },

        _getProgressWidth: function (parentwidth, percent) {
            return (parentwidth * percent) / 100;
        },

        
        _wireEvents: function () {
            var proxy = this,
                model=proxy.model,
                treeGrid = $("#ejTreeGrid" + proxy._id),
                ganttChart = $("#ejGanttChart" + proxy._id),
                gantt = proxy._$ejGantt;

            proxy._on(proxy.element, "click", proxy.clickHandler);
            proxy._on(proxy.element, "contextmenu", proxy._rightClick);
            if (model.enableResize) {
                proxy._on($(window), "resize", proxy.windowResize);
            }
            //proxy._on(proxy.element, "dblclick", ".e-tdprecontent", proxy._preDblClickHandler);
            //proxy._on(proxy.element, "click", ".e-tdprecontent", proxy._preClickHandler);
            treeGrid.ejTreeGrid({ rowSelecting: $.proxy(proxy.rowSelecting, proxy) });
            treeGrid.ejTreeGrid({ rowSelected: $.proxy(proxy.rowSelected, proxy) });
            //treeGrid.ejTreeGrid({ rowHover: $.proxy(proxy._treeGridRowHover, proxy) });
            treeGrid.ejTreeGrid({ actionBegin: $.proxy(proxy.actionBegin, proxy) });
            treeGrid.ejTreeGrid({ actionComplete: $.proxy(proxy.actionComplete, proxy) });

            if (model.queryCellInfo) {
                treeGrid.ejTreeGrid({ queryCellInfo: $.proxy(proxy._queryCellInfo, proxy) });
            }
            
            if (model.rowDataBound) {
                treeGrid.ejTreeGrid({ rowDataBound: $.proxy(proxy._rowDataBound, proxy) });
            }
            
            treeGrid.ejTreeGrid({ beginEdit: $.proxy(proxy._beginEdit, proxy) });
            treeGrid.ejTreeGrid({ endEdit: $.proxy(proxy._endEdit, proxy) });            
            
            treeGrid.ejTreeGrid({ expanding: $.proxy(proxy.expanding, proxy) });
            treeGrid.ejTreeGrid({ collapsing: $.proxy(proxy.collapsing, proxy) });
            treeGrid.ejTreeGrid({ expanded: $.proxy(proxy.expanded, proxy) });
            treeGrid.ejTreeGrid({ collapsed: $.proxy(proxy.collapsed, proxy) });
            treeGrid.ejTreeGrid({ refreshRow: $.proxy(proxy.refreshRow, proxy) });
            treeGrid.ejTreeGrid({ cancelEditCell: $.proxy(proxy.cancelEditCell, proxy) });
            
            
            ganttChart.ejGanttChart({ rowSelecting: $.proxy(proxy.rowSelecting, proxy) });
            ganttChart.ejGanttChart({ rowSelected: $.proxy(proxy.rowSelected, proxy) });
            ganttChart.ejGanttChart({ rowHover: $.proxy(proxy._ganttChartRowHover, proxy) });
            ganttChart.ejGanttChart({ actionBegin: $.proxy(proxy.actionBegin, proxy) });
            ganttChart.ejGanttChart({ actionComplete: $.proxy(proxy.chartactionComplete, proxy) });
            ganttChart.ejGanttChart({ refreshRow: $.proxy(proxy.refreshRowData, proxy) }); 
            ganttChart.ejGanttChart({ zooming: $.proxy(proxy.zoomingChart, proxy) });
            ganttChart.ejGanttChart({ queryTaskbarInfo: $.proxy(proxy.queryTaskbarInfo, proxy) });
            ganttChart.ejGanttChart({ expanding: $.proxy(proxy.expanding, proxy) });
            ganttChart.ejGanttChart({ collapsing: $.proxy(proxy.collapsing, proxy) });
            ganttChart.ejGanttChart({ expanded: $.proxy(proxy.expanded, proxy) });
            ganttChart.ejGanttChart({ collapsed: $.proxy(proxy.collapsed, proxy) });

            ganttChart.ejGanttChart({ taskbarEditing: $.proxy(proxy.taskbarEditing, proxy) });
            ganttChart.ejGanttChart({ taskbarEdited: $.proxy(proxy.taskbarEdited, proxy) });

            gantt.ejSplitter({ allowResizing: $.proxy(proxy._onResize, proxy) });
            
            proxy._enableEditingEvents();
        },
 

        _onResize:function(args){
            var proxy = this;
            
            proxy._$treegridHelper.ejTreeGrid("refreshScroller", args.prevPane.size);
            proxy._$ganttchartHelper.ejGanttChart("refreshScroller", args.nextPane.size);

        },

        clickHandler: function (e) {
            var proxy = this;
            var $target = $(e.target);

            //if ($target.closest(".e-popup").length == 0 &&
            //  $target.closest(".e-rowcell").find("#" + proxy._id + "EditForm").length == 0) {
                
            //}


            proxy._clearContextMenu();

            if (e.toElement) {
                e.toElement.tabIndex = 0;
                e.toElement.focus();
            }
            //Skip the scroll bar click in Gantt.
            if ($target.hasClass("e-vhandle") || $target.hasClass("e-vscrollbar") || $target.hasClass("e-vup") || $target.hasClass("e-vhandlespace") || $target.hasClass("e-vdown"))
                return;
            if ($target.hasClass("e-hhandle") || $target.hasClass("e-hscrollbar") || $target.hasClass("e-hup") || $target.hasClass("e-hdown") || $target.hasClass("e-hhandlespace"))
                return;
            if (proxy._isinBeginEdit) {

                if (!$target.closest('td').hasClass("e-editedcell") && !$target.hasClass('e-date') && !$target.hasClass('e-arrow') && !$target.hasClass('e-down-arrow') && $target.closest("form#ejTreeGrid" + proxy._id + "EditForm").length == 0) {
                    proxy._$treegridHelper.ejTreeGrid("cancelEditCell");
                    proxy._isinBeginEdit = false;
                }
                else if ($target.closest('td').hasClass("e-editedcell") && !$target.hasClass('e-date') && !$target.hasClass('e-arrow') && !$target.hasClass('e-down-arrow'))
                {
                    $target.focus();
                }
            }
        },

        windowResize: function (e) {
            var proxy = this,
                ejGanttSplit = ("#e-ejSpliter" + this._id),
                toolbar = ("#" + this._id + "_toolbarItems"),
                ganttchart = ("#ejGanttChart" + this._id),
                treegrid = ("#ejTreeGrid" + this._id),
                ganttbody = (".e-ganttviewerbodyContianer"),
                gantthead = (".e-ganttviewerheaderContainer"),
                treegridhelp = ("#ejTreeGrid" + this._id),
                treegridcontent = ("#ejTreeGrid" + this._id + "e-gridcontent"),
                sizeSettingsWidth = proxy.model.sizeSettings.width,
                sizeSettingsHeight = proxy.model.sizeSettings.height,
                elementStyleHeight = proxy.element[0].style.height,
                elementStyleWidth = proxy.element[0].style.width,
                width, height, maxScrollWidth;
            //Width calculation
            if ((sizeSettingsWidth && sizeSettingsWidth.indexOf("%") != -1) || elementStyleWidth.indexOf("%") != -1) {

                var ganttWidth = sizeSettingsWidth ? sizeSettingsWidth : elementStyleWidth;
                var containerWidth = $(proxy.element).parent().width() ? $(proxy.element).parent().width() : $(proxy.element).width();
                width = (containerWidth / 100) * parseInt(ganttWidth);
                
            }
            else
                width = $(proxy.element).width();
            //height calculation
            if ((sizeSettingsHeight && sizeSettingsHeight.indexOf("%") != -1 ) || elementStyleHeight.indexOf("%") != -1) {
                var ganttHeight = sizeSettingsHeight ? sizeSettingsHeight : elementStyleHeight;
                var containerHeight = $(proxy.element).parent().height() ? $(proxy.element).parent().height() : $(proxy.element).height();
                var tempHeight;
                if ($(proxy.element).parent().height())
                    tempHeight = (containerHeight / 100) * parseInt(ganttHeight);
                else
                    tempHeight = $(proxy.element).height();
                height = tempHeight;
            }
            else
                height = $(proxy.element).height();

            //Exclude bordor from width and height
            height = height - proxy._totalBorderHeight;
            width = width - proxy._totalBorderWidth;
            width = Math.round(width);

            var ganttWidth, treeGridWidth, top,left;
            $(ejGanttSplit).width(width);
            $(ejGanttSplit).height(height - $(toolbar).height());
            $(ejGanttSplit).ejSplitter("refresh");
            $(toolbar).width(width);
            $(toolbar).children(".e-ul:first-child").width(width);

            ganttWidth = $(ganttchart).width();
            treeGridWidth = $(treegrid).width();
            $(ganttchart).height(height - $(toolbar).height());

            top = $(ganttbody).ejScroller("option", "scrollTop");
            left = $(ganttbody).ejScroller("option", "scrollLeft");
            //set height for scroller div
            $(ganttbody).ejScroller({
                width: ganttWidth,
                height: (height - $(toolbar).height() - $(gantthead).height() - proxy._totalBorderHeight),
            });
            $(ganttbody).ejScroller("refresh");
            maxScrollWidth = proxy._$ganttchartHelper.ejGanttChart("getMaxScrollWidth");
            if (left > maxScrollWidth)
                left = maxScrollWidth > 0 ? maxScrollWidth : 0;

            $(ganttbody).ejScroller("option", "scrollTop", top);
            $(ganttbody).ejScroller("option", "scrollLeft", left);

            $(treegridhelp).height(height - $(toolbar).height());
            $(treegridcontent).height((height - $(toolbar).height() - $(gantthead).height() - proxy._totalBorderHeight));
            left = $(treegridcontent).ejScroller("option", "scrollLeft");
            $(treegridcontent).ejScroller({
                width: treeGridWidth,
            });
            $(treegridcontent).ejScroller("refresh");
            maxScrollWidth = proxy._$treegridHelper.ejTreeGrid("getMaxScrollWidth");
            if (left > maxScrollWidth)
                left = maxScrollWidth > 0 ? maxScrollWidth : 0;

            $(treegridcontent).ejScroller("option", "scrollLeft", left);

            proxy._$treegridHelper.ejTreeGrid("updateViewPortHeight");
            proxy._$ganttchartHelper.ejGanttChart("updateViewPortHeight");
            if(proxy.model.enableVirtualization)
            {
                proxy._$treegridHelper.ejTreeGrid("processBindings");
                var tempArgs = {};
                tempArgs.requestType = ej.TreeGrid.Actions.Refresh;
                proxy._$treegridHelper.ejTreeGrid("sendDataRenderingRequest", tempArgs);
                proxy._$ganttchartHelper.ejGanttChart("refreshHelper", proxy._currentViewData, proxy._updatedGanttRecords);
                proxy._$ganttchartHelper.ejGanttChart("onScrollHelper", top);
            }
        },

        
        // handler for mouse right click
        _rightClick: function (e) {
            var proxy = this,
                $target = $(e.target),
                div = $target[0].parentNode,
                $ganttGridRows,
                row,
                recordIndexr,
                item,selectIndex,
                args = {};
            proxy._$treegridHelper.ejTreeGrid("disableTooltip");
           
            if ($(div).hasClass("e-chartcell") || $(div).hasClass("e-ganttrowcell")) {
                $ganttGridRows = proxy._$ganttchartHelper.ejGanttChart("getGanttChartRows");
                args.target = "ejTreeGrid";
            } else {
                $ganttGridRows = $(proxy._$treegridHelper.ejTreeGrid("getRows"));
                args.target = "ejGanttChart";
            }
            row = $target.closest('tr');
            recordIndexr = $ganttGridRows.index(row);
            proxy._currentViewData = proxy.getCurrentViewData();
            item = proxy._currentViewData[recordIndexr];
            recordIndexr = proxy._updatedGanttRecords.indexOf(item);
            args.data = item;
            args.recordIndex = recordIndexr;

            if (item && proxy.model.enableContextMenu) {
                e.preventDefault();
                proxy._contextMenuItems = [];
                proxy._contextMenuItems = proxy._getContextMenuItems();
                proxy._subContextMenuItems = [];
                proxy._subContextMenuItems = proxy._getsubContextMenuItems();
                proxy._updateIndentOutdentContextmenuOption(recordIndexr, item);
                proxy._clearContextMenu();
                if (proxy._contextMenuItems.length > 0)
                    proxy._renderContextMenu(e, recordIndexr, item);

                proxy.rowSelected(args);
                proxy._$treegridHelper.ejTreeGrid("selectRows", recordIndexr);
                proxy._$ganttchartHelper.ejGanttChart("selectRows", recordIndexr);
            }
            else if (proxy.dataSource()==null || proxy.dataSource().length == 0) {
                proxy._contextMenuItems = [];
                proxy._subContextMenuItems = [];
                proxy._contextMenuItems = proxy._getContextMenuItems();
                proxy._updateIndentOutdentContextmenuOption(recordIndexr, item);
                proxy._clearContextMenu();
                if (proxy._contextMenuItems.length > 0)
                    proxy._renderContextMenu(e, recordIndexr, item);
            }
        },

        _updateIndentOutdentContextmenuOption: function (recordIndex, ganttRecord) {
            var proxy = this;
            if (recordIndex === 0) {;
                proxy._contextMenuItems.splice(2, 2);
            }
            else if(recordIndex>0){
                if (ganttRecord.level === 0) {
                    proxy._contextMenuItems.splice(3, 1);
                }
                else {
                    var previousGanttRecord = proxy._updatedGanttRecords[recordIndex - 1];
                    if (ganttRecord.level - previousGanttRecord.level === 1) {
                        proxy._contextMenuItems.splice(2, 1);
                    }
                    if(ganttRecord.isMilestone)
                        proxy._contextMenuItems.splice(3, 1);
                    if(previousGanttRecord.isMilestone)
                        proxy._contextMenuItems.splice(2, 1);
                }
            }
            else if (recordIndex < 0) {
                proxy._contextMenuItems.splice(0, 1);
                proxy._contextMenuItems.splice(1, 3);
            }

            var addIndex = -1, editIndex = -1, deleteIndex = -1;

            if (!model.editSettings.allowAdding) {
                $.each(proxy._contextMenuItems, function (idx, val) {
                    if (val.headerText === "Add New Task") {
                        addIndex = idx;
                    }
                });
                if(addIndex !== -1)
                    proxy._contextMenuItems.splice(addIndex, 1);
            }

            if (!model.editSettings.allowDeleting)
            {
                $.each(proxy._contextMenuItems, function (idx, val) {
                    if (val.headerText === "Delete") {
                        deleteIndex = idx;
                    }
                });
                if (deleteIndex !== -1)
                    proxy._contextMenuItems.splice(deleteIndex, 1);
            }

            if (!model.editSettings.allowEditing)
            {
                $.each(proxy._contextMenuItems, function (idx, val) {
                    if (val.headerText === "Task Details...") {
                        editIndex = idx;
                    }});
                proxy._contextMenuItems.splice(editIndex, 1);
            }

            if( proxy._searchString.length>0 && addIndex!==-1)
            {
                proxy._contextMenuItems.splice(addIndex, 1);
            }


        },
      
        queryTaskbarInfo: function (args) {        
            this._trigger("queryTaskbarInfo", args);
        },
        

        zoomingChart: function (args) {
            var proxy = this;
            proxy.reRenderChart(args.delta);
        },

        refreshRowData: function (args) {
            var proxy = this;
            proxy._$treegridHelper.ejTreeGrid("refreshRow", args.index);
        },

        expanding: function (args) {
            var proxy = this;           
            if (!proxy._trigger("expanding", args)) {
                if (proxy.model.enableVirtualization) {                    
                    ej.TreeGrid.sendExpandCollapseRequest(proxy, args);
                } else {
                    proxy._isInExpandCollapse = true;
                    
                    ej.TreeGrid.sendExpandCollapseRequest(proxy, args);
                    proxy._isInExpandCollapse = false;
                    var expandedCount = proxy._expandedRecordsCount;
                    proxy._$ganttchartHelper.ejGanttChart("reRenderGanttGridLinesTable", expandedCount);
                }
            }
        },

        collapsing: function (args) {
            var proxy = this;
            if (!proxy._trigger("collapsing", args)) {
                if (proxy.model.enableVirtualization) {                    
                    ej.TreeGrid.sendExpandCollapseRequest(proxy,args);
                } else {
                    proxy._gridRows = proxy.getRows();
                    proxy._isInExpandCollapse = true;
                    //proxy.sendExpandCollapseRequest(args);
                    ej.TreeGrid.sendExpandCollapseRequest(proxy, args);
                    proxy._isInExpandCollapse = false;
                    var collapsedCount = proxy._collapsedRecordCount;                       
                    proxy._$ganttchartHelper.ejGanttChart("reRenderGanttGridLinesTable", -collapsedCount);
                }
                var selectItem = proxy.selectedItem();
                if (!args.expanded && selectItem) {
                    var expanded = proxy.getExpandStatus(selectItem);
                    if (!expanded) {
                        proxy._deSelectRowItem();
                        if (proxy.model.toolbarSettings.showToolbar) {
                            if (proxy.model.toolbarSettings.toolbarItems.indexOf("delete") !== -1) {
                                $('.e-gantttoolbar').ejToolbar('disableItem', $($('.e-deleteitem')[0]).parent()[0]);
                                if (proxy.model.toolbarSettings.toolbarItems.indexOf("indent") !== -1)
                                    $('.e-gantttoolbar').ejToolbar('disableItem', $($('.e-indent')[0]).parent()[0]);
                                if (proxy.model.toolbarSettings.toolbarItems.indexOf("outdent") !== -1)
                                    $('.e-gantttoolbar').ejToolbar('disableItem', $($('.e-outdent')[0]).parent()[0]);
                                if (proxy.model.toolbarSettings.toolbarItems.indexOf("edit") !== -1)
                                    $('.e-gantttoolbar').ejToolbar('disableItem', $($('.e-edititem')[0]).parent()[0]);
                            }
                        }
                    }
                }
            }
        },

        expanded: function (args) {
            var proxy = this;            
            proxy._updatedGanttRecords = proxy.getUpdatedRecords();
            proxy._currentViewData = proxy.getCurrentViewData();
            if (proxy.model.enableVirtualization) {
                if (proxy.model.predecessorMapping) {
                    proxy._isValidationEnabled = false;
                    proxy._$ganttchartHelper.ejGanttChart("clearConnectorLines");
                    proxy._connectorlineIds = [];
                    proxy._connectorLinesCollection = [];
                    proxy._createConnectorLinesCollection();
                }
                proxy._$ganttchartHelper.ejGanttChart("refreshHelper", proxy._currentViewData, proxy._updatedGanttRecords);
            }
            proxy._trigger("expanded", args);
        },

        collapsed: function (args) {
            var proxy = this;
            proxy._updatedGanttRecords = proxy.getUpdatedRecords();
            proxy._currentViewData = proxy.getCurrentViewData();
            if (proxy.model.enableVirtualization) {
                if (proxy.model.predecessorMapping) {
                    proxy._isValidationEnabled = false;
                    proxy._connectorlineIds = [];
                    proxy._connectorLinesCollection = [];
                    proxy._$ganttchartHelper.ejGanttChart("clearConnectorLines");
                    proxy._createConnectorLinesCollection();
                }
                proxy._$ganttchartHelper.ejGanttChart("refreshHelper", proxy._currentViewData, proxy._updatedGanttRecords);
            }
            proxy._trigger("collapsed", args);
        },

        refreshRow: function (args) {
            var proxy = this;
            proxy._$ganttchartHelper.ejGanttChart("refreshRow", args.recordIndex);
        },

        _enableEditingEvents: function () {
            var proxy = this,
                model = proxy.model;

            if (model.editSettings.allowEditing|| model.editSettings.editMode == "dialogTemplate" ||
                (model.toolbarSettings.showToolbar && ((model.editSettings.allowAdding && model.toolbarSettings.toolbarItems.indexOf("add") !== -1) ||
                    (model.editSettings.allowEditing && model.toolbarSettings.toolbarItems.indexOf("index") !== -1)))) {
                
                proxy._on($("#" + proxy._id + "_dialogEdit"),
                    "click keypress", "#EditDialog_" + proxy._id + "_Save ,#EditDialog_" + proxy._id + "_Cancel,#EditDialog_" + proxy._id + "_Delete", proxy._buttonClick);

                proxy._on($("#" + proxy._id + "_dialogAdd"),
                   "click keypress", "#AddDialog_" + proxy._id + "_Save ,#AddDialog_" + proxy._id + "_Cancel", proxy._buttonClick);
                // $(proxy.element).on("click", ".e-icon", $.proxy(proxy._buttonClick, proxy));
            }
        },
        
        cancelEditCell: function () {

            var proxy = this;
            
            if (proxy.model.toolbarSettings.toolbarItems.indexOf("cancel") !== -1) {
                proxy._disabledToolItems.push($($('.e-cancel')[0]).parent()[0]);
            }

            if (proxy.model.toolbarSettings.toolbarItems.indexOf("save") !== -1) {
                proxy._disabledToolItems.push($($('.e-saveitem')[0]).parent()[0]);
            }

            $('.e-gantttoolbar').ejToolbar('disableItem', proxy._disabledToolItems);
        },

        _keyPressed: function (action, target, e) {
        },

        _buttonClick: function (e) {

            if (e.keyCode !== undefined && e.keyCode != 13)
                return true;
            
            var proxy = this,   
                model = proxy.model,
                args = {};
            
            if (model.editSettings.allowEditing || model.editSettings.editMode == "dialogTemplate" ||
                (model.toolbarSettings.showToolbar && ((model.editSettings.allowAdding && model.toolbarSettings.toolbarItems.indexOf("add") !== -1) ||
                    (model.editSettings.allowEditing && model.toolbarSettings.toolbarItems.indexOf("index") !== -1)))) {

                if (e.target.id == "EditDialog_" + proxy._id + "_Save") {
                    if (!proxy._sendSaveRequest("Edit"))
                        $("#" + proxy._id + "_dialogEdit").ejDialog("close");
                } else if (e.target.id == "EditDialog_" + proxy._id + "_Cancel") {
                    $("#" + proxy._id + "_dialogEdit").ejDialog("close");
                }
                    //For delete option in editing dialog window
                else if (e.target.id == "EditDialog_" + proxy._id + "_Delete") {

                    proxy._$treegridHelper.ejTreeGrid("deleteRow");
                    $("#" + proxy._id + "_dialogEdit").ejDialog("close");
                }
                else if (e.target.id == "AddDialog_" + proxy._id + "_Save") {
                    if (!proxy._sendSaveRequest("Add"))
                        if (!this._duplicate&&!this._wrongenddate) {
                            $("#" + proxy._id + "_dialogAdd").ejDialog("close");                            
                        }
                }
                else if (e.target.id == "AddDialog_" + proxy._id + "_Cancel") {
                  //  proxy._ids.splice(proxy._ids.length - 1, 1);
                    $("#" + proxy._id + "_dialogAdd").ejDialog("close");
                }
            }
            else {
                proxy._sendCancelRequest();
            }

            return false;
        },

        rowSelecting: function (args) {
            var proxy = this;
            if (proxy.model.rowSelecting) {
                if (proxy._trigger("rowSelecting", args))
                    return true;
            }
            return true;
        },

        rowSelected:function(args){
            var proxy = this;
            if (args.target == "ejTreeGrid")
                proxy._$ganttchartHelper.ejGanttChart("selectRows", args.recordIndex);
            if (args.target == "ejGanttChart")
                proxy._$treegridHelper.ejTreeGrid("selectRows", args.recordIndex);
            var idx = args.recordIndex;
            this.selectedItem(args.data);
            this.selectedRowIndex(idx);
            if (proxy.model.toolbarSettings.showToolbar) {

                if (proxy.model.toolbarSettings.toolbarItems.indexOf("indent") !== -1 || proxy.model.toolbarSettings.toolbarItems.indexOf("outdent") !== -1) {

                    proxy.updateIndentOutdentOption(args.data);
                }

                var enableItems = [];

                if (proxy.model.editSettings.allowDeleting) {
                    if (proxy.model.toolbarSettings.toolbarItems.indexOf("delete") !== -1)
                        enableItems.push($($('.e-deleteitem')[0]).parent()[0]);
                }
                if (proxy.model.editSettings.allowAdding) {
                    if (proxy.model.toolbarSettings.toolbarItems.indexOf("add") !== -1)
                        enableItems.push($($('.e-addnewitem')[0]).parent()[0]);
                }
                if (proxy.model.editSettings.allowEditing) {
                    if (proxy.model.toolbarSettings.toolbarItems.indexOf("edit") !== -1)
                        enableItems.push($($('.e-edititem')[0]).parent()[0]);
                }

                $('.e-gantttoolbar').ejToolbar('enableItem', enableItems);
            }

            if (proxy.model.rowSelected)
                proxy._trigger("rowSelected", args);           
        },

        _treeGridRowHover: function (args) {
            var proxy = this;
            if (args.reason == "mouseenter")
                proxy._$ganttchartHelper.ejGanttChart("addRowHover", args.index);
            else if (args.reason == "mouseleave")
                proxy._$ganttchartHelper.ejGanttChart("removeRowHover");
        },

        updateIndentOutdentOption: function (ganttRecord) {
            var proxy = this;
            proxy._updatedGanttRecords = proxy.getUpdatedRecords();
            var recordIndex = proxy._updatedGanttRecords.indexOf(ganttRecord),
                previousGanttRecord;

            var indentIconElement =  $($('.e-indent')[0]).parent()[0],
                outentIconElement = $($('.e-outdent')[0]).parent()[0],
                disabledItems = [];

            if (recordIndex === 0) {
                if (indentIconElement)
                    $('.e-gantttoolbar').ejToolbar('disableItem', indentIconElement);

                if (outentIconElement)
                    $('.e-gantttoolbar').ejToolbar('disableItem', outentIconElement);
                
                $('.e-gantttoolbar').ejToolbar('disableItem', disabledItems);
            }
            else {
                if (ganttRecord.level === 0) {
                    if (indentIconElement)
                        $('.e-gantttoolbar').ejToolbar('enableItem', indentIconElement);
                    if (outentIconElement)
                        $('.e-gantttoolbar').ejToolbar('disableItem', outentIconElement);
                }
                else {
                    previousGanttRecord = proxy._updatedGanttRecords[recordIndex - 1];
                    if (ganttRecord.level - previousGanttRecord.level === 1) {
                        if (outentIconElement)
                            $('.e-gantttoolbar').ejToolbar('enableItem', outentIconElement);
                        if (indentIconElement)
                            $('.e-gantttoolbar').ejToolbar('disableItem', indentIconElement);
                    }
                    else {
                        if (indentIconElement)
                            $('.e-gantttoolbar').ejToolbar('enableItem', indentIconElement);
                        if (outentIconElement)
                            $('.e-gantttoolbar').ejToolbar('enableItem', outentIconElement);
                    }
                    
                }
            }
        },

        _ganttChartRowHover: function (args) {
            var proxy = this;
            if (args.reason == "mouseenter")
                proxy._$treegridHelper.ejTreeGrid("addRowHover", args.index);
            else if (args.reason == "mouseleave")
                proxy._$treegridHelper.ejTreeGrid("removeRowHover");
        },
        _removeChildRecordsPredecessor:function(record)
        {
            var proxy = this;
            if (record.hasChildRecords) {
                var length = record.childRecords.length, index = 0;
                for (index; index < length; index++) {
                    record.childRecords[index].predecessor && proxy._removePredecessor(record.childRecords[index].predecessor, record.childRecords[index]);
                    if(record.childRecords[index].hasChildRecords)
                    {
                        proxy._removeChildRecordsPredecessor(record.childRecords[index]);
                    }
                }
            }
        },
        getExpandedRecordCount: function (record, count)
        {
            var currentRecord, proxy = this;
            if (!record.hasChildRecords)
                return 0;
            for (var i = 0; i < record.childRecords.length; i++) {
                currentRecord = record.childRecords[i];
                if (proxy.getExpandStatus(currentRecord))
                    count++;
                
                if (currentRecord.hasChildRecords) {
                    count = proxy.getExpandedRecordCount(currentRecord, count);
                }
            }
            return count;
        },

        _updateExpandStatus:function()
        {
            var proxy = this,
                records = proxy._rows,
            length = records.length, oldValue;
            //proxy._totalCollapseRecordCount = 0;
            for (var i = 0; i < length; i++) {
                oldValue = records[i].isExpanded;
                if (proxy.getExpandStatus(records[i]) !== records[i].isExpanded) {
                    records[i].isExpanded = proxy.getExpandStatus(records[i]);
                    if (records[i].isExpanded) {
                        proxy._totalCollapseRecordCount--;
                    }
                    else {
                        proxy._totalCollapseRecordCount++;
                    }
                }
            }
        },
        actionComplete: function (args) {
            var proxy = this,model = proxy.model;
            proxy._updatedGanttRecords = proxy.getUpdatedRecords();
            proxy._currentViewData = proxy.getCurrentViewData();
            proxy._gridRows = proxy.getRows();
            proxy._ganttChartRows = proxy.getGanttChartRows();
            if (args.requestType === "searching" || args.requestType === "sorting") {
                proxy._$ganttchartHelper.ejGanttChart("clearConnectorLines");
               
                var visibleRecordCount = proxy._$ganttchartHelper.ejGanttChart("getVisibleRecordsCount");
                if (!model.enableVirtualization)
                {
                    proxy._updateExpandStatus();
                    var filteredCollapseCount = 0;
                    filteredCollapseCount = proxy._currentViewData.filter(function (record) {
                        return (proxy.getExpandStatus(record) === false);
                    });
                    if (args.requestType === "searching" || proxy._searchString)
                    {
                        
                        proxy._$ganttchartHelper.ejGanttChart("refreshHelper", proxy._currentViewData, proxy._updatedGanttRecords, filteredCollapseCount.length);
                        proxy._$ganttchartHelper.ejGanttChart("refrehGridLinesTable", (proxy._currentViewData.length - filteredCollapseCount.length));
                    }
                    else
                    {
                        proxy._$ganttchartHelper.ejGanttChart("refreshHelper", proxy._currentViewData, proxy._updatedGanttRecords, filteredCollapseCount.length);
                        proxy._$ganttchartHelper.ejGanttChart("refrehGridLinesTable", (proxy._currentViewData.length - proxy._totalCollapseRecordCount));
                    }
                    proxy._$treegridHelper.ejTreeGrid("updateHeight", (proxy._updatedGanttRecords.length - filteredCollapseCount.length) * proxy.model.rowHeight);
                    proxy._$ganttchart.ejGanttChart("setCollapsedRecordCount", filteredCollapseCount.length);
                    proxy._$treegridHelper.ejTreeGrid("setCollapsedRecordCount", filteredCollapseCount.length);
                }
                else
                {
                    proxy._$ganttchartHelper.ejGanttChart("refreshHelper", proxy._currentViewData, proxy._updatedGanttRecords);
                }


                proxy._isValidationEnabled = false;
                proxy._connectorlineIds = [];
                proxy._connectorLinesCollection = [];
                proxy._createConnectorLinesCollection();
            }

            if (args.requestType === "delete") {

                this.dataSource(proxy._$treegridHelper.ejTreeGrid("getDataSource"));


                model.selectedItem = null;
                this.selectedRowIndex(-1);
                var childCount = 0,
                    expandedRecordCount=0;
                //Collapse record counts
                if (!model.enableVirtualization) {
                    if (args.data.hasChildRecords) {
                        childCount = proxy._$treegridHelper.ejTreeGrid("getChildCount", args.data, 0);
                        expandedRecordCount = proxy.getExpandedRecordCount(args.data, 0);
                        if (!args.data.expanded) {
                            proxy._$ganttchartHelper.ejGanttChart("reRenderGanttGridLinesTable", -1);
                            proxy._totalCollapseRecordCount -= (childCount - expandedRecordCount);
                        }
                        else {
                            proxy._$ganttchartHelper.ejGanttChart("reRenderGanttGridLinesTable", -(expandedRecordCount+1));
                            proxy._totalCollapseRecordCount -= (childCount - expandedRecordCount);
                        }
                    }
                    else {
                        proxy._$ganttchartHelper.ejGanttChart("reRenderGanttGridLinesTable", -1);
                    }
                }
                //Delete from parent collection if item is in parentsCollection
                if (model.parentRecords.indexOf(args.data) !== -1) {
                    model.parentRecords.splice(model.parentRecords.indexOf(args.data), 1);
                }
                //Delete predecessor from child records
                if (args.data.hasChildRecords) {
                    proxy._removeChildRecordsPredecessor(args.data)
                }

                //Delete Predecessor from record
                args.data.predecessor && proxy._removePredecessor(args.data.predecessor, args.data);

                //Update parent item if item has parent
                if (args.data.parentItem)
                {
                    parentRecord=args.data.parentItem;
                    if(args.data.parentItem.childRecords.length>0)
                    {
                        proxy._updateParentItem(args.data);
                    }else
                    {
                        parentRecord.expanded=false;
                        parentRecord.hasChildRecords = false;
                        proxy.refreshGanttRecord(parentRecord);
                    }
                }
                proxy._rows = proxy._$treegridHelper.ejTreeGrid("getFlatRecords");
                proxy._ids = proxy._ids = proxy._$treegridHelper.ejTreeGrid("getUpdatedIds");
                proxy._isValidationEnabled = false;
                if (proxy.model.predecessorMapping) {
                    proxy._connectorlineIds = [];
                    proxy._connectorLinesCollection = [];
                    proxy._predecessorsCollection = [];
                    proxy._$ganttchartHelper.ejGanttChart("clearConnectorLines");
                    proxy._createConnectorLinesCollection();
                }
                //Scroller is not correctly updated before connector line cleared.
                proxy._$ganttchartHelper.ejGanttChart("refreshHelper", proxy.getCurrentViewData(), proxy.getUpdatedRecords(), proxy._totalCollapseRecordCount);


                if (proxy.model.toolbarSettings.showToolbar) {
                    if (proxy.model.toolbarSettings.toolbarItems.indexOf("delete") !== -1) {
                        $('.e-gantttoolbar').ejToolbar('disableItem', $($('.e-deleteitem')[0]).parent()[0]);
                        if (proxy.model.toolbarSettings.toolbarItems.indexOf("indent") !== -1) 
                            $('.e-gantttoolbar').ejToolbar('disableItem', $($('.e-indent')[0]).parent()[0]);
                        if (proxy.model.toolbarSettings.toolbarItems.indexOf("outdent") !== -1) 
                            $('.e-gantttoolbar').ejToolbar('disableItem', $($('.e-outdent')[0]).parent()[0]);
                        if (proxy.model.toolbarSettings.toolbarItems.indexOf("edit") !== -1)
                            $('.e-gantttoolbar').ejToolbar('disableItem', $($('.e-edititem')[0]).parent()[0]);

                    }
                }
                proxy.updateAltRow(proxy.getUpdatedRecords, 0, 1);//for set e-alt-row style after deletion of element
                
            }

            if (args.requestType === "selection") {
                proxy._$ganttchartHelper.ejGanttChart("selectRows", args.recordIndex);
            }

            if (args.requestType === "rowHover") {
                proxy._$ganttchartHelper.ejGanttChart("addRowHover", args.index);
            }
            
            if (args.requestType === "scroll") {
                
                proxy._$ganttchartHelper.ejGanttChart("onScrollHelper", args.delta);
            }

            if (args.requestType === "save") {
                if (args._cAddedRecord) {

                    //For change the id collection after new record is created//
                    proxy._$treegridHelper.ejTreeGrid("renderRecord", args);

                    //if records are sorted or searched then sort newly added record
                    treegridobj = proxy._$treegridHelper.ejTreeGrid("instance");
                    if (treegridobj.model.sortSettings.sortedColumns.length > 0 || (treegridobj.model.allowSearching && treegridobj._searchString.length > 0)) {
                        var evgArgs = {};
                        proxy._$treegridHelper.ejTreeGrid("processBindings", evgArgs);
                        var tempArgs = {};
                        tempArgs.requestType = ej.TreeGrid.Actions.Refresh;
                        proxy._$treegridHelper.ejTreeGrid("sendDataRenderingRequest", tempArgs);
                    }
                    //get all records from treegrid
                    this.dataSource(proxy._$treegridHelper.ejTreeGrid("getDataSource"));
                    proxy._ids = proxy._$treegridHelper.ejTreeGrid("getUpdatedIds");
                    proxy.model.ganttRecords = proxy._$treegridHelper.ejTreeGrid("getFlatRecords");
                    proxy._updatedGanttRecords = proxy._$treegridHelper.ejTreeGrid("getUpdatedRecords");
                    proxy._rows = proxy._$treegridHelper.ejTreeGrid("getFlatRecords");
                    proxy._currentViewData = proxy._$treegridHelper.ejTreeGrid("getCurrentViewData");
                    proxy._$ganttchartHelper.ejGanttChart("setUpdatedRecords", proxy._currentViewData, proxy._updatedGanttRecords, proxy._rows, proxy._ids);

                    if (treegridobj.model.sortSettings.sortedColumns.length > 0 || (treegridobj.model.allowSearching && treegridobj._searchString.length > 0)) {
                        proxy._$ganttchartHelper.ejGanttChart("refreshHelper", proxy.getCurrentViewData(), proxy.getUpdatedRecords(), proxy._totalCollapseRecordCount);
                        if (!model.enableVirtualization) {
                            var filteredCollapseCount = 0;
                            filteredCollapseCount = proxy._updatedGanttRecords.filter(function (record) {
                                return (proxy.getExpandStatus(record) === false);
                            });
                            proxy._$ganttchartHelper.ejGanttChart("refrehGridLinesTable", (proxy._currentViewData.length - filteredCollapseCount.length));
                        }
                    }
                    else {
                        proxy._$ganttchartHelper.ejGanttChart("renderRecord", args, proxy._totalCollapseRecordCount);
                        //update grid lines as per new records parent item
                        if (proxy.model.selectedItem) {
                            if (!proxy.model.selectedItem.expanded && proxy.model.selectedItem.childRecords) {
                                if (!args.position)
                                    proxy._totalCollapseRecordCount++;
                                else if (args.position == "Above" && proxy._currentViewData.length != 1)
                                    proxy._$ganttchartHelper.ejGanttChart("reRenderGanttGridLinesTable", 1);

                            }
                            else if (proxy._currentViewData.length != 1)
                                proxy._$ganttchartHelper.ejGanttChart("reRenderGanttGridLinesTable", 1);
                        }
                        else if (proxy._currentViewData.length != 1)
                            proxy._$ganttchartHelper.ejGanttChart("reRenderGanttGridLinesTable", 1);
                    }
                    //for soritng
                    if (!args._cAddedRecord.parentItem)
                        model.parentRecords.splice(args._cAddedRecord.index, 0, args._cAddedRecord);
                    else
                        proxy._updateParentItem(args._cAddedRecord);

                    proxy.refreshGanttRecord(args._cAddedRecord)
                } else if (args._cModifiedData) {
                    args._cModifiedData.left = args._cModifiedData._calculateLeft(proxy._projectStartDate, proxy._perDayWidth, proxy._holidaysList, model);
                    args._cModifiedData.width = args._cModifiedData._calculateWidth(proxy._perDayWidth, proxy._holidaysList, model);
                    args._cModifiedData.progressWidth = args._cModifiedData._getProgressWidth(args._cModifiedData.width, args._cModifiedData.status);
                    
                    proxy.refreshGanttRecord(args._cModifiedData);

                    if (args._cModifiedData.parentItem)
                        proxy._updateParentItem(args._cModifiedData);

                    if (args._cModifiedData.predecessor) {
                        if (args.previousValue) {
                            proxy._removeConnectorLine(args.previousValue, args._cModifiedData);
                        }
                    }
                }
                
                if (proxy.model.predecessorMapping) {

                    if ((args._cAddedRecord && args._cAddedRecord.predecessor)
                        || (args._cModifiedData && args._cModifiedData.predecessor)) {
                        proxy._isValidationEnabled = true;
                    }
                    else
                        proxy._isValidationEnabled = false;
                    if (args._cAddedRecord) {
                      
                        proxy._$ganttchartHelper.ejGanttChart("clearConnectorLines");
                        proxy._connectorlineIds = [];
                        proxy._connectorLinesCollection = [];
                        proxy._createConnectorLinesCollection();
                        proxy._addConnectorLine(args._cAddedRecord);
                    } else {
                        if (args._cModifiedData) {
                            if (args.previousValue) {
                                proxy._removeConnectorLine(args.previousValue, args._cModifiedData);
                            }
                            proxy._addConnectorLine(args._cModifiedData);
                            if (args._cModifiedData.predecessor) {
                                proxy._isMileStoneEdited = args._cModifiedData.isMilestone;
                                proxy._updatedConnectorLineCollection = [];
                                proxy._connectorlineIds = [];
                                proxy._validatePredecessor(args._cModifiedData);
                                if (proxy._updatedConnectorLineCollection.length > 0) {
                                    proxy._$ganttchartHelper.ejGanttChart("appendConnectorLine", proxy._updatedConnectorLineCollection);
                                }
                            }
                            if (args._cModifiedData.parentItem)
                                proxy._updateParentItem(args._cModifiedData);
                        }
                    }
                }
            }

            if (args.requestType === "validatePredecessor") {
                var result = proxy._editedPredecessorValidation(args);
                args.result = result;
                return;
            }
            proxy._ganttActionCompleteTrigger(args);
        },

        chartactionComplete: function (args) {
            var proxy = this;

            proxy._updatedGanttRecords = proxy.getUpdatedRecords();
            proxy._currentViewData = proxy.getCurrentViewData();

            if (args.requestType === "updateConnectors") {
                if (proxy.model.predecessorMapping) {
                    proxy._isValidationEnabled = false;
                    proxy._connectorlineIds = [];
                    proxy._connectorLinesCollection = [];
                    proxy._$ganttchartHelper.ejGanttChart("clearConnectorLines");
                    proxy._createConnectorLinesCollection();
                }
            }

            if (args.requestType === "rowHover") {
                proxy._$treegridHelper.ejTreeGrid('addRowHover', args.index);
            }
            
            if (args.requestType === "scroll") {

                proxy._isTreeGridRendered = false;
                proxy._isGanttChartRendered = false;
                if (args.vscrollExsist && args.delta !== undefined)
                    proxy._$treegridHelper.ejTreeGrid('onScrollHelper', args.delta);

                proxy._updatedGanttRecords = proxy.getUpdatedRecords();
                proxy._currentViewData = proxy.getCurrentViewData();

                if (proxy.model.enableVirtualization) {

                    if (proxy.model.predecessorMapping) {

                        if (proxy._connectorLinesCollection.length > 0) {
                            proxy._$ganttchartHelper.ejGanttChart("clearConnectorLines");
                        }
                        proxy._isValidationEnabled = false;
                        proxy._connectorlineIds = [];
                        proxy._connectorLinesCollection = [];
                        proxy._createConnectorLinesCollection();
                    }
                }
                proxy._isTreeGridRendered = true;
                proxy._isGanttChartRendered = true;
            }
            
            if (args.requestType === "selection") {
                proxy._$treegridHelper.ejTreeGrid("selectRows", args.recordIndex);
            }
            //for validate the predecessor on mouse hover and mouse up of second drag point
            if (args.requestType === "validatePredecessor") {
                args.data[this.model.taskIdMapping] = args.data.taskID;
                var flag= proxy._editedPredecessorValidation(args);
                args.predecessorValidation = flag;
            }

            //on mouse up if validation is true then draw connector line
            if (args.requestType === "drawConnectorLine") {

                var currentPredecessor = args.toItem._calculatePredecessor(args.predecessor);
                args.toItem.item[proxy.model.predecessorMapping] = args.predecessorString[0];

                if (!args.fromItem.predecessor) {// for parent item
                    args.fromItem['predecessor'] = currentPredecessor;
                }
                else {
                    args.fromItem.predecessor.push(currentPredecessor[0]);
                }
                if (args.toItem.predecessor)
                {
                    args.toItem.predecessor.push(currentPredecessor[0]);
                }
                else
                {
                    args.toItem.predecessor=[];
                    args.toItem.predecessor.push(currentPredecessor[0]);
                }

                proxy._isMileStoneEdited = args.toItem.isMilestone;
                proxy._updatedConnectorLineCollection = [];
                proxy._connectorlineIds = [];
                proxy._validatePredecessor(args.toItem);
                if (proxy._updatedConnectorLineCollection.length > 0) {
                    proxy._$ganttchartHelper.ejGanttChart("appendConnectorLine", proxy._updatedConnectorLineCollection);
                }
            }
            
            proxy._ganttActionCompleteTrigger(args);
        },

        _clearConnectorLines: function () {
            var proxy = this,
                count = 0,
                length = proxy._connectorLinesCollection.length,
                connectorLine,
                childId,
                childGanttRecord,
                predecessors,
                predecessorslength,
                i = 0,
                predecessor;
            
            for (count; count < length; count++) {

                connectorLine = proxy._connectorLinesCollection[count];
                childId = connectorLine && connectorLine.ConnectorLineId.split("child")[1];
                childGanttRecord = proxy._rows[proxy._ids.indexOf(childId)];
                predecessors = childGanttRecord.predecessor;
                predecessorslength =predecessors&& predecessors.length;
                
                for (i = 0; i < predecessorslength; i++) {

                    predecessor = predecessors[i];

                    if (predecessor.to === childId && predecessor.isdrawn) {
                        predecessor.isdrawn = false;
                    }
                }
            }
            
            proxy._$ganttchartHelper.ejGanttChart("clearConnectorLines");
        },
        

        taskbarEditing: function (args) {
            
            this._trigger("taskbarEditing", args);
        },
        
        _refreshParent: function (item) {
            this.refreshGanttRecord(item);
            if (item.parentItem) {
                this._refreshParent(item.parentItem);
            }
        },

        taskbarEdited: function (args) {
            var proxy = this,
                ganttRecord = args.data, model = proxy.model,
                projectStartDate = new Date(proxy._projectStartDate),
                remainDays,
                day,
                offset = 0;
            
            proxy._isValidationEnabled = false;
            
            if (args.dragging) {
                if (args.previousData.left !== ganttRecord.left) {
                    remainDays = ganttRecord.left % proxy._perDayWidth,
                           day = (ganttRecord.left - remainDays) / proxy._perDayWidth,
                           offset = 0;
                    
                    if (remainDays > 0 && (model.workingTimeScale != ej.Gantt.workingTimeScale.TimeScale24Hours)) {
                        offset = remainDays >= proxy._perDayWidth / 2 ? 1 : 0;
                    }
                    var remainingHours = Math.round(remainDays / (proxy._perDayWidth / 24));//Hour calculation

                    projectStartDate.setDate(projectStartDate.getDate() + day + offset);
                    if (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Day) {
                        projectStartDate.setHours(remainingHours);
                    }
                    else if (model.dateFormat.indexOf("hh:") &&
                     model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale8Hours) {
                        var remainingHours = Math.round(remainDays / (proxy._perDayWidth / 9));
                        projectStartDate.setHours(8);
                    }
                      
                    if ((model.workingTimeScale != ej.Gantt.workingTimeScale.TimeScale24Hours)) {
                        if (remainDays >= (proxy._perDayWidth / 2)) {
                            ganttRecord.left = ganttRecord.left + proxy._perDayWidth;//- remainDays;
                            if (model.roundOffDayworkingTime)
                                ganttRecord.left -= remainDays;
                        } else {
                            ganttRecord.left = ganttRecord.left;// - remainDays;
                            if (model.roundOffDayworkingTime)
                                ganttRecord.left -= remainDays;
                        }
                    }
                    
                    if (this._stringHolidays &&
                     this._stringHolidays.indexOf(ganttRecord._getFormatedDate(projectStartDate, model.dateFormat)) != -1) {
                        projectStartDate.setDate(projectStartDate.getDate() + 1);
                        ganttRecord.left += proxy._perDayWidth;
                    }
                    
                    if (this.model.includeWeekend == false) {
                        if (projectStartDate.getDay() === 0) {
                            projectStartDate.setDate(projectStartDate.getDate() + 1);
                            ganttRecord.left += proxy._perDayWidth;
                        } else if (projectStartDate.getDay() === 6) {
                            projectStartDate.setDate(projectStartDate.getDate() + 2);
                            ganttRecord.left += (2 * proxy._perDayWidth);
                        }
                    }

                    if (this._stringHolidays &&
                    this._stringHolidays.indexOf(ganttRecord._getFormatedDate(projectStartDate, model.dateFormat)) != -1) {
                        projectStartDate.setDate(projectStartDate.getDate() + 1);
                        ganttRecord.left += proxy._perDayWidth;
                    }
                    
                    ganttRecord.startDate = ganttRecord._getFormatedDate(projectStartDate, model.dateFormat);//_calculateFormatedDate
                    if (model.startDateMapping)
                        ganttRecord.item[model.startDateMapping] = ganttRecord.startDate;
                    ganttRecord._calculateEndDate(model.includeWeekend, this._holidaysList, model, proxy._perDayWidth);
                    ganttRecord.width = ganttRecord._calculateTaskbarWidth(proxy._perDayWidth,model);
                    ganttRecord.progressWidth = ganttRecord._getProgressWidth(ganttRecord.width, ganttRecord.status);
                    proxy._isValidationEnabled = true;
                }

            } else if (args.rightResizing) {
                
                if (args.previousData.width !== ganttRecord.width) {
                    day = ganttRecord.width / proxy._perDayWidth;
                    var rem = ganttRecord.width % proxy._perDayWidth;
                    offset = 0;
                    if (rem > 0 && (model.workingTimeScale != "TimeScale24Hours")) {
                        offset = rem >= (proxy._perDayWidth / 2) ? 1 : 0;
                    }

                    var totalLength = ganttRecord.left + ganttRecord.width;
                    var remainingLength = totalLength % proxy._perDayWidth;

                    var remainingHours = Math.round(remainingLength / (proxy._perDayWidth / 24));//hour calculation

                    var startDate = proxy._getDateFromFormat(ganttRecord.startDate);

                    if ((model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Day &&
                        model.durationUnit == ej.Gantt.DurationUnit.Hour)) {//model.dateFormat.indexOf("hh") == -1
                        var startDateHour = (ganttRecord.left % proxy._perDayWidth) / proxy._perHourWidth;
                        var hours = Math.round(totalLength / (proxy._perHourWidth));
                        hours -= startDateHour;

                        var endDate = ganttRecord._dateUpdate(startDate, 0, hours);
                        startDate.setHours(startDateHour);
                    }

                    else if ((model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Week
                         && model.dateFormat.indexOf("hh") != -1)) {
                        if (model.durationUnit == ej.Gantt.DurationUnit.Hour) {
                            var startDateHour = Math.round((ganttRecord.left % proxy._perDayWidth) / (proxy._perDayWidth / 24));
                            var remainingHourDiff = Math.round(totalLength / (proxy._perDayWidth / 24));
                            remainingHourDiff -= startDateHour;
                            endDate = ganttRecord._dateUpdate(startDate, 0, remainingHourDiff);
                        }
                    }

                    else
                        var endDate = ganttRecord._dateUpdate(startDate, day - 1 + offset, 0);

                    if (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Day ||
                        (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Week && model.dateFormat.indexOf("hh") != -1))
                        endDate.setHours(Math.round(remainingHours));
                    else if (model.dateFormat.indexOf("hh:") &&
                       model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale8Hours) {
                        endDate.setHours(Math.round(17));
                    }

                    if (model.holidays && model.holidays.length) {
                        var holidayIndex = 0,
                            holidayslength = model.holidays.length,
                            holiday;
                        for (holidayIndex = 0; holidayIndex < holidayslength; holidayIndex++) {
                            holiday = new Date(this._holidaysList[holidayIndex]);
                            if (endDate === holiday) {
                                endDate.setDate(endDate.getDate() - 1);
                            }
                        }
                    }

                    if (this.model.includeWeekend == false) {
                        if (endDate.getDay() == 0) {
                            endDate.setDate(endDate.getDate() - 2);
                        } else if (endDate.getDay() == 6) {
                            endDate.setDate(endDate.getDate() - 1);
                        }
                    }
                    
                    if (this._stringHolidays &&
                   this._stringHolidays.indexOf(ganttRecord._getFormatedDate(endDate, model.dateFormat)) != -1) {
                        endDate.setDate(endDate.getDate() + 1);
                        if (endDate.getDay() == 6) {
                            endDate.setDate(endDate.getDate() + 2);
                        }
                    }
                    
                    ganttRecord.endDate = ganttRecord._calculateFormatedDate(endDate, model.dateFormat);
                    if (model.endDateMapping)
                        ganttRecord.item[model.endDateMapping] = ganttRecord.endDate;
                    ganttRecord._calculateDuration(startDate, endDate, model.includeWeekend, model.holidays, ganttRecord.isMilestone,model);
                    ganttRecord.width = ganttRecord._calculateTaskbarWidth(proxy._perDayWidth,model);
                    ganttRecord.progressWidth = ganttRecord._getProgressWidth(ganttRecord.width, ganttRecord.status);
                    proxy._isValidationEnabled = true;
                }

            } else if (args.leftResizing) {
                if (args.previousData.left !== ganttRecord.left) {
                    remainDays = ganttRecord.left % proxy._perDayWidth;
                    day = (ganttRecord.left - remainDays) / proxy._perDayWidth;
                    offset = 0;
                    if (remainDays > 0 && (model.workingTimeScale != "TimeScale24Hours")) {
                        offset = remainDays >= proxy._perDayWidth / 2 ? 1 : 0;
                    }
                    var remainingHours = Math.round(remainDays / (proxy._perDayWidth / 24));//Hour calculation

                    projectStartDate.setDate(projectStartDate.getDate() + day + offset);

                    if (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Day ||
                        (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Week && model.dateFormat.indexOf("hh") != -1)) {
                        if (model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale8Hours &&
                            (remainingHours >= 17||model.durationUnit==ej.Gantt.DurationUnit.Day))
                            projectStartDate.setHours(8);
                        else
                            projectStartDate.setHours(remainingHours);
                    }
                    else if (model.dateFormat.indexOf("hh:") &&
                       model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale8Hours) {
                        var remainingHours = Math.round(remainDays / (proxy._perDayWidth / 9));
                        projectStartDate.setHours(8);
                    }

                    if (this._stringHolidays &&
                    this._stringHolidays.indexOf(ganttRecord._getFormatedDate(projectStartDate, model.dateFormat)) != -1) {
                        projectStartDate.setDate(projectStartDate.getDate() + 1);
                        ganttRecord.left += proxy._perDayWidth;
                    }
                    
                    if (this.model.includeWeekend == false) {
                        if (projectStartDate.getDay() === 0) {
                            projectStartDate.setDate(projectStartDate.getDate() + 1);
                            ganttRecord.left += proxy._perDayWidth;
                        } else if (projectStartDate.getDay() === 6) {
                            projectStartDate.setDate(projectStartDate.getDate() + 2);
                            ganttRecord.left += (2 * proxy._perDayWidth);
                        }
                    }
                    
                    if (this._stringHolidays &&
                    this._stringHolidays.indexOf(ganttRecord._getFormatedDate(projectStartDate, model.dateFormat)) != -1) {
                        projectStartDate.setDate(projectStartDate.getDate() + 1);
                        ganttRecord.left += proxy._perDayWidth;
                    }

                    
                    if (model.workingTimeScale != ej.Gantt.workingTimeScale.TimeScale24Hours &&
                        model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Day &&
                        model.durationUnit != ej.Gantt.DurationUnit.Hour) {

                        if (remainDays >= (proxy._perDayWidth / 2)) {
                            ganttRecord.left = ganttRecord.left + proxy._perDayWidth;// - remainDays;
                            if (model.roundOffDayworkingTime)
                                ganttRecord.left -= remainDays;
                        } else {
                            ganttRecord.left = ganttRecord.left;//- (remainingHours * 20);
                            if (model.roundOffDayworkingTime)
                                ganttRecord.left -= remainDays;
                        }
                    }
                    else if (model.scheduleHeaderSettings.scheduleHeaderType != ej.Gantt.ScheduleHeaderType.Day &&
                        model.dateFormat.indexOf("hh") == -1) {
                        if (remainDays >= (proxy._perDayWidth / 2)) {
                            ganttRecord.left = ganttRecord.left + proxy._perDayWidth;// - remainDays;
                            if (model.roundOffDayworkingTime)
                                ganttRecord.left -= remainDays;
                        } else {
                            ganttRecord.left = ganttRecord.left;//- (remainingHours * 20);
                            if (model.roundOffDayworkingTime)
                                ganttRecord.left -= remainDays;
                        }
                    }
                      

                    else if (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Day
                        && (model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale8Hours ||
                        model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale24Hours || model.durationUnit == ej.Gantt.DurationUnit.Hour)) {
                        var remainingHourDiff = ganttRecord.left % proxy._perHourWidth;

                        if (remainingHourDiff >= (proxy._perHourWidth / 2)) {
                            ganttRecord.left = ganttRecord.left + proxy._perHourWidth;// - remainDays;

                            ganttRecord.left -= remainingHourDiff;
                        } else {
                            ganttRecord.left -= remainingHourDiff;
                        }
                    }

                    ganttRecord.startDate = ganttRecord._calculateFormatedDate(projectStartDate, model.dateFormat);
                    if (model.startDateMapping)
                        ganttRecord.item[model.startDateMapping] = ganttRecord.startDate;
                    ganttRecord._calculateDuration(projectStartDate, proxy._getDateFromFormat(ganttRecord.endDate), model.includeWeekend, model.holidays, ganttRecord.isMilestone,model);
                    ganttRecord.width = ganttRecord._calculateTaskbarWidth(proxy._perDayWidth, model);
                    ganttRecord.progressWidth = ganttRecord._getProgressWidth(ganttRecord.width, ganttRecord.status);
                    proxy._isValidationEnabled = true;
                }
            } else if (args.progressResizing) {
                ganttRecord.status = ganttRecord._getProgressPercent(ganttRecord.width, ganttRecord.progressWidth);
                if (ganttRecord.parentItem) {
                    ganttRecord._updateParentProgress(ganttRecord.parentItem, model.progressMapping);
                }
                proxy._refreshParent(ganttRecord);
                //proxy.refreshGanttRecord(ganttRecord);
                //proxy.refreshGanttRecord(ganttRecord.parentItem);
            }
            if (proxy._isValidationEnabled) {
                proxy._updateEditedGanttRecord(ganttRecord);
                if (ganttRecord.predecessor) {
                    proxy._isMileStoneEdited = ganttRecord.isMilestone;
                    proxy._updatedConnectorLineCollection = [];
                    proxy._connectorlineIds = [];
                    proxy._editedTaskBarItem = ganttRecord;
                    proxy._validatePredecessor(ganttRecord);
                    //proxy._$ganttchartHelper.ejGanttChart("clearConnectorLines");
                    //proxy._createConnectorLinesCollection();

                    if (proxy._updatedConnectorLineCollection.length > 0) {
                        proxy._$ganttchartHelper.ejGanttChart("appendConnectorLine", proxy._updatedConnectorLineCollection);
                    }
                }
                proxy._editedTaskBarItem = null;
                if (ganttRecord.parentItem)
                    proxy._updateParentItem(ganttRecord);
                proxy.refreshGanttRecord(ganttRecord);
            }
            proxy._trigger("taskbarEdited", args);
            if (!args.cancel && (args.leftResizing || args.rightResizing || args.dragging)) {
                proxy._updateScheduleDatesOnEditing(args);
            }
        },

        actionBegin: function (args) {

            var proxy = this;

            if (!proxy._trigger("actionBegin", args)) {

                if (args.requestType === "beginedit") {
                    proxy._sendEditRequest();
                }   
                
            }

        },

        _ganttActionCompleteTrigger: function (args) {
            this._trigger("actionComplete", args);
            if (!args.cancel && args.requestType === 'save') {
                if (args._cModifiedData) {
                    args.data = args._cModifiedData;
                }
                if (args._cAddedRecord) {
                    args.data = args._cAddedRecord;
                }
                this._updateScheduleDatesOnEditing(args);
            }
        },

        _queryCellInfo: function (args) {
            this._trigger("queryCellInfo", args);
        },

        _beginEdit: function (args) {
            var proxy = this;
            if (!proxy._trigger("beginEdit", args)) {
                proxy._isinBeginEdit = true;
                if (proxy.model.toolbarSettings.showToolbar) {

                    var toolBarEnabledItems = [];

                    var cancelElement = $($('.e-cancel')[0]).parent()[0];
                    var saeveElement = $($('.e-saveitem')[0]).parent()[0];

                    if (cancelElement) {
                        toolBarEnabledItems.push(cancelElement);
                    }

                    if (saeveElement) {
                        toolBarEnabledItems.push(saeveElement);
                    }

                    $('.e-gantttoolbar').ejToolbar('enableItem', toolBarEnabledItems);
                    var disableToolItems = [];
                    if (proxy.model.editSettings.allowAdding && proxy.model.toolbarSettings.toolbarItems.indexOf("add") !== -1)
                        disableToolItems.push($($('.e-addnewitem')[0]).parent()[0]);
                    if (proxy.model.editSettings.allowEditing && proxy.model.toolbarSettings.toolbarItems.indexOf("edit") !== -1)
                        disableToolItems.push($($('.e-edititem')[0]).parent()[0]);
                    if (proxy.model.editSettings.allowDeleting && proxy.model.toolbarSettings.toolbarItems.indexOf("delete") !== -1)
                        disableToolItems.push($($('.e-deleteitem')[0]).parent()[0]);
                    $('.e-gantttoolbar').ejToolbar('disableItem', disableToolItems);
                }
            }
        },

        _endEdit: function (args) {
            var proxy = this,model=this.model;
            
            proxy._isinBeginEdit = false;

            if (proxy._trigger("endEdit", args)) {
                var predecessorString = "";
                args.data[args.columnName] = args.previousValue;
                if (args.columnName === "predecessor") {
                    predecessorString = proxy._predecessorToString(args.data.predecessor, args.data);
                    args.data.item[args.columnObject.mappingName] = predecessorString;
                } else {
                    args.data.item[args.columnObject.mappingName] = args.previousValue;
                }
            }
            else {

                if (args.isModified) {
                    proxy._currentViewData = proxy._$treegridHelper.ejTreeGrid("getCurrentViewData");
                    proxy._isValidationEnabled = true;
                    proxy._updateEditedGanttRecords(args);
                }
            }
            proxy.refreshGanttRecord(args.data);
            
            delete args.isModified;
            if (proxy.model.toolbarSettings.showToolbar) {
                var toolBarDisableItems = [];

                if (proxy.model.toolbarSettings.toolbarItems.indexOf("cancel") !== -1) {
                    toolBarDisableItems.push($($('.e-cancel')[0]).parent()[0]);
                }

                if (proxy.model.toolbarSettings.toolbarItems.indexOf("update") !== -1) {
                    toolBarDisableItems.push($($('.e-saveitem')[0]).parent()[0]);
                }
                
                $('.e-gantttoolbar').ejToolbar('disableItem', toolBarDisableItems);
            }

            if (!args.cancel && (args.columnName === "startDate" || args.columnName === "endDate" || args.columnName === "duration")) {
                proxy._updateScheduleDatesOnEditing(args);
            }


            // proxy._trigger("endEdit", args);
        },

        //updated the schedule dates while cellediting ,taskBarediting and dialogEditing and dialogAdding
        _updateScheduleDatesOnEditing:function(args)
        {
            var proxy = this,
                model = this.model,
                startDate = proxy._getDateFromFormat(args.data.startDate),
                endDate = proxy._getDateFromFormat(args.data.endDate),
                scheduleStartDate = proxy._projectStartDate,    //_getDateFromFormat(model.scheduleStartDate),
                scheduleEndDate = proxy._getDateFromFormat(model.scheduleEndDate),
                minStartDate, maxEndDate,
                isDateChanged = false,
                tempStartDate = model.scheduleStartDate,
                updatedDates,
                tempEndDate = model.scheduleEndDate;
                proxy._calculateDatesForScheduleCheck(startDate);
            if (!model.predecessorMapping) {
                if (!(startDate.getTime() >= scheduleStartDate.getTime()) || !(startDate.getTime() <= scheduleEndDate.getTime())) {
                    if (startDate.getTime() < scheduleStartDate.getTime()) {
                        minStartDate = startDate;
                        scheduleStartDate = startDate;
                    }
                    else {
                        maxEndDate = proxy._getDateFromFormat(args.data.startDate);
                        scheduleEndDate = proxy._getDateFromFormat(args.data.startDate);
                    }
                }
                if (!(endDate.getTime() >= scheduleStartDate.getTime()) || !(endDate.getTime() <= scheduleEndDate.getTime())) {
                    if (endDate.getTime() < scheduleStartDate.getTime())
                        minStartDate = endDate;
                    else
                        maxEndDate = endDate;
                }
                if (maxEndDate) {
                    isDateChanged = true;
                    tempEndDate = args.data._getFormatedDate(maxEndDate, model.dateFormat);
                }
                if (minStartDate) {
                    isDateChanged = true;
                    tempStartDate = args.data._getFormatedDate(minStartDate, model.dateFormat);
                }
                if (isDateChanged) {
                    updatedDates = proxy._updateScheduleDatesByTaskLables(proxy._getDateFromFormat(tempStartDate), proxy._getDateFromFormat(tempEndDate));
                    proxy.updateScheduleDates(args.data._getFormatedDate(updatedDates.minStartDate, model.dateFormat), args.data._getFormatedDate(updatedDates.maxEndDate, model.dateFormat));
                }
            }
            else {
                var editArgs = {};
                editArgs.onEditing = true;
                proxy._calculateScheduleDates(editArgs);
                proxy._calculateDatesForScheduleCheck(editArgs.minStartDate);
                if (editArgs.minStartDate.getTime() < scheduleStartDate || editArgs.maxEndDate.getTime() > scheduleEndDate) {
                    proxy.updateScheduleDates(args.data._getFormatedDate(editArgs.minStartDate, model.dateFormat), args.data._getFormatedDate(editArgs.maxEndDate, model.dateFormat));
                }
            }
        },
        //add dates before edited dates for scheduleupdate 
        _calculateDatesForScheduleCheck:function(startdate)
        {
            var proxy = this;
               
            if (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Week) {

                startdate.setDate(startdate.getDate() - 3);
            }

            if (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Year) {
                startdate.setDate(startdate.getDate() - 5);
            }
            if (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Month) {
                startdate.setDate(startdate.getDate() - 3);
            }

            if (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Day) {
                startdate.setHours(startdate.getHours() - 2);
            }
        }
        ,
        //update schedule dates by tool bar operation
        _updateScheduleDatesByToolBar:function(args)
        {
            var proxy = this,
                 startDate = args === "prevTimeSpan" ? proxy._projectStartDate : proxy._getDateFromFormat(proxy.model.scheduleStartDate);
                 endDate = proxy._getDateFromFormat(proxy.model.scheduleEndDate),
                 chartObject = $("#ejGanttChart" + proxy._id).ejGanttChart("instance"),
                 maxScrollWidth = 0;

            if (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Week) {
                if (args === "prevTimeSpan") {
                    startDate.setDate(startDate.getDate() - 6);
                }
                else {
                    endDate.setDate(endDate.getDate() + 7);
                }
            }

            if (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Year) {
                if (args === "prevTimeSpan")
                    startDate.setDate(startDate.getDate() - 360);
                else
                    endDate.setDate(endDate.getDate() + 365);
            }
            if (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Month) {
                
                if (args === "prevTimeSpan")
                    startDate.setDate(startDate.getDate());
                else
                    endDate.setDate(endDate.getDate() + 30);
            }

            if (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Day) {
                if (args === "prevTimeSpan")
                    startDate.setDate(startDate.getDate() - 1);
                else
                    endDate.setDate(endDate.getDate() + 1);
            }
            if (args === "prevTimeSpan") {
                proxy.updateScheduleDates(proxy._getFormatedDate(startDate, model.dateFormat), proxy._getFormatedDate(endDate, model.dateFormat));
                chartObject._$bodyContainer.ejScroller("scrollX", 0, true);
            }
            else if (args === "nextTimeSpan") {
                proxy.updateScheduleDates(proxy._getFormatedDate(startDate, model.dateFormat), proxy._getFormatedDate(endDate, model.dateFormat));
                maxScrollWidth = chartObject.getMaxScrollWidth();
                chartObject._$bodyContainer.ejScroller("scrollX", maxScrollWidth, true);
            }
        },
        _rowDataBound: function (args) {
            this._trigger("rowDataBound", args);
        },
        _refreshToolBar: function () {
            var $toolbar = $("#" + this._id + "_toolbarItems");
            $toolbar.find("li").removeClass("e-hover");
        },

        _toolBarClick: function (sender) {
            var proxy = this,
                model=proxy.model,
                $gridEle = $(this.itemsContainer).closest(".e-gantt"),
                gridInstance = $gridEle.ejGantt("instance"),
                gridId = $gridEle.attr('id');

            gridInstance._clearContextMenu();
            if (sender.event == undefined && sender.target.tagName == "INPUT" && sender.currentTarget.id == gridId + "_search")
                return false;

            if (gridInstance.model.dateFormat.indexOf("hh") != -1)
                $.isFunction($.fn.ejDateTimePicker) && $("#" + gridId + "EditForm").find(".e-datepicker").ejDateTimePicker("hide");
            else
                $.isFunction($.fn.ejDatePicker) && $("#" + gridId + "EditForm").find(".e-datepicker").ejDatePicker("hide");


            if ($gridEle.ejGantt("instance")._trigger("toolBarClick", sender))
                return false;
            
            switch (sender.currentTarget.id) {

                case gridId + "_add":
                    gridInstance._toolbarOperation(gridId + "_add");
                    break;

                case gridId + "_edit":
                    gridInstance._toolbarOperation(gridId + "_edit");
                    break;

                case gridId + "_delete":
                    gridInstance._toolbarOperation(gridId + "_delete");
                    break;

                case gridId + "_update":
                    gridInstance._toolbarOperation(gridId + "_update");
                    break;

                case gridId + "_cancel":
                    gridInstance._toolbarOperation(gridId + "_cancel");
                    break;

                case gridId + "_search":
                    gridInstance._toolbarOperation(gridId + "_search", $(sender.currentTarget).find("input").val());
                    break;

                case gridId + "_indent":
                    gridInstance._toolbarOperation(gridId + "_indent");
                    break;

                case gridId + "_outdent":
                    gridInstance._toolbarOperation(gridId + "_outdent");
                    break;
                    
                case gridId + "_expandAll":
                    gridInstance._toolbarOperation(gridId + "_expandAll");
                    break;
                 
                case gridId + "_collapseAll":
                    gridInstance._toolbarOperation(gridId + "_collapseAll");
                    break;
                case gridId + "_prevTimeSpan":
                    gridInstance._toolbarOperation(gridId + "_prevTimeSpan");
                    break;
                case gridId + "_nextTimeSpan":
                    gridInstance._toolbarOperation(gridId + "_nextTimeSpan");
                    break;
            }
            return false;
        },

        _toolbarOperation: function (operation, searchEle) {
            var $gridEle = this.element, gridObject = $gridEle.ejGantt("instance"), gridId = $gridEle.attr('id'), proxy = this,
                rowindex = proxy.selectedRowIndex();
            switch (operation) {

                case gridId + "_add":
                    proxy._sendAddRequest();
                    break;

                case gridId + "_edit":
                    proxy._sendEditRequest();
                    break;

                case gridId + "_delete":
                    proxy._$treegridHelper.ejTreeGrid("deleteRow");
                    break;

                case gridId + "_update":
                    proxy._$treegridHelper.ejTreeGrid("endEdit");
                    //gridObject.sendSaveRequest();

                    if (proxy.model.toolbarSettings.toolbarItems.indexOf("cancel") !== -1) {
                        proxy._disabledToolItems.push($($('.e-cancel')[0]).parent()[0]);
                    }

                    if (proxy.model.toolbarSettings.toolbarItems.indexOf("update") !== -1) {
                        proxy._disabledToolItems.push($($('.e-saveitem')[0]).parent()[0]);
                    }
                    $('.e-gantttoolbar').ejToolbar('disableItem', proxy._disabledToolItems);
                    
                    proxy._disabledToolItems = [];
                    
                    break;

                case gridId + "_cancel":
                    proxy._$treegridHelper.ejTreeGrid("cancelEditCell");                                                            
                    break;

                case gridId + "_search":
                    proxy._$treegridHelper.ejTreeGrid("search", searchEle);
                    proxy._searchString = searchEle;

                    proxy._updateToolbarOptions(searchEle);
                    
                    break;

                case gridId + "_indent":
                    proxy._sendIndentRequest();
                    proxy._$treegrid.focus();
                    break;

                case gridId + "_outdent":
                    proxy._sendOutdentRequest();
                    proxy._$treegrid.focus();
                    break;

                case gridId + "_expandAll":
                    proxy._expandAll();
                    proxy._$treegrid.focus();
                    break;

                case gridId + "_collapseAll":                   
                    proxy._deSelectRowItem();
                    proxy._collapseAll();
                    if (proxy.model.toolbarSettings.showToolbar){
                        if (proxy.model.toolbarSettings.toolbarItems.indexOf("delete") !== -1) {
                            $('.e-gantttoolbar').ejToolbar('disableItem', $($('.e-deleteitem')[0]).parent()[0]);
                            if (proxy.model.toolbarSettings.toolbarItems.indexOf("indent") !== -1)
                                $('.e-gantttoolbar').ejToolbar('disableItem', $($('.e-indent')[0]).parent()[0]);
                            if (proxy.model.toolbarSettings.toolbarItems.indexOf("outdent") !== -1)
                                $('.e-gantttoolbar').ejToolbar('disableItem', $($('.e-outdent')[0]).parent()[0]);
                            if (proxy.model.toolbarSettings.toolbarItems.indexOf("edit") !== -1)
                                $('.e-gantttoolbar').ejToolbar('disableItem', $($('.e-edititem')[0]).parent()[0]);                          
                        }
                    }

                    proxy._$treegrid.focus();
                    break;
                case gridId + "_prevTimeSpan":
                    proxy._updateScheduleDatesByToolBar("prevTimeSpan");
                    break;
                case gridId + "_nextTimeSpan":
                    proxy._updateScheduleDatesByToolBar("nextTimeSpan");
                    break;

            }
            proxy._refreshToolBar();
            return false;
        },
        
        _setModel: function (options) {
            
            var proxy = this, option,
                model = proxy.model;
            
            for (option in options) {
                switch (option) {
                    case "sortSettings":
                        proxy._sendSortingRequest(options[option]);
                        break;
                    case "destroy":
                        proxy.destroy();
                        break;
                    case "allowGanttChartEditing":
                        proxy._ganttChartEditing(options[option]);
                        break;
                    case "enableProgressBarResizing":
                        proxy._resizeProgressbar(options[option]);
                        break;
                    case "enableTaskbarTooltip":
                        proxy._showTooltip(options[option]);
                        break;
                    case "enableTaskbarDragTooltip":
                        proxy._showEditingTooltip(options[option]);
                        break;
                    case "enableAltRow":
                        proxy._updateAltRow(options[option]);
                        break;
                    case "locale":
                        model.ganttRecords = [];
                        model.parentRecords = [];
                        proxy._clearContextMenu();
                        model.locale = options[option];
                        proxy.element.ejGantt("destroy").ejGantt(model);
                        break;
                    case "allowSelection":
                        proxy._updateRowSelection(options[option]);
                        break;
                    case "editSettings":
                        $.extend(model.editSettings, options[option]);
                        proxy._updateEditSettings(options[option]);
                        break;
                    case "taskbarBackground":
                        proxy._updateTaskbarBackground(options[option]);
                        break;
                    case "progressbarBackground":
                        proxy._updateProgressbarBackground(options[option]);
                        break;
                    case "parentTaskbarBackground":
                        proxy._updateParentTaskbarBackground(options[option]);
                        break;
                    case "parentProgressbarBackground":
                        proxy._updateParentProgressbarBackground(options[option]);
                        break;
                    case "showTaskNames":
                        proxy._updateRenderTaskNames(options[option]);
                        break;
                    case "showProgressStatus":
                        proxy._updateRendeProgressStatus(options[option]);
                        break;
                    case "showResourceNames":
                        proxy._updateRenderResourceNames(options[option]);
                        break;
                    case "progressbarHeight":
                        proxy._updateProgressbarHeight(options[option]);
                        break;
                    case "baselineColor":
                        proxy._updateBaselineColor(options[option]);
                        break;
                    case "renderBaseline":
                        proxy._updateRenderBaseline(options[option]);
                        break;
                    case "allowColumnResize":
                        proxy._updateAllowColumnResize(options[option]);
                        break;
                    case "allowKeyboardNavigation":
                        proxy._updateAllowKeyboardNavigation(options[option]);
                        break;
                    case "selectedItem":
                        proxy._updateSelectedItem(options[option]);
                        break;
                    case "dataSource":
                        model.dataSource = [];
                        model.ganttRecords = [];
                        model.parentRecords = [];
                        model.scheduleStartDate = null;
                        model.scheduleEndDate = null;
                        model.dataSource = (options[option]);
                        proxy.element.ejGantt("destroy").ejGantt(model);
                        break;
                    case "showGridCellTooltip":
                        proxy._updateShowGridCellTooltip(options[option]);
                        break;
                    case "showGridExpandCellTooltip":
                        proxy._updateShowGridExpandCellTooltip(options[option]);
                        break;
                    case "highlightWeekends":
                        proxy._updateHighlightWeekends(options[option]);
                        break;
                    case "connectorLineBackground":
                        proxy._updateConnectorLineBackground(options[option]);
                        break;
                    case "connectorlineWidth":
                        proxy._updateConnectorlineWidth(options[option]);
                        break;
                    case "weekendBackground":
                        proxy._updateWeekendBackground(options[option]);
                        break;
                    case "enableContextMenu":
                        proxy.model.enableContextMenu = options[option];
                        break;
                    case "enableResize":
                        if (model.enableResize) {
                            proxy.model.enableResize = options[option];
                            proxy._on($(window), "resize", proxy.windowResize);
                        }
                        else {
                            proxy._off($(window), "resize", proxy.windowResize);
                        }
                        break;
                    case "selectedRowIndex":
                        if (this.selectedRowIndex() !== -1 && !ej.isNullOrUndefined(this.selectedRowIndex()) && this.selectedRowIndex() < proxy._updatedGanttRecords.length) {
                            var args = {};
                            args.recordIndex = this.selectedRowIndex();
                            args.data = proxy._updatedGanttRecords[args.recordIndex];
                            args.target = "ejTreeGrid";
                            proxy.rowSelected(args);
                            proxy._$treegridHelper.ejTreeGrid("selectRows", args.recordIndex);
                            proxy._$ganttchartHelper.ejGanttChart("selectRows", args.recordIndex);
                            proxy._$ganttchartHelper.ejGanttChart("updateSelectedItem", args.recordIndex);
                        }
                        else if (this.selectedRowIndex() === -1) {
                            proxy._$treegridHelper.ejTreeGrid("clearSelection");
                        }
                        break;
                }
            }
        },

        _updateWeekendBackground: function (bgcolor) {
            var proxy = this;
            this.model.weekendBackground = bgcolor;
            proxy._$ganttchartHelper.ejGanttChart("updateWeekendBackground", bgcolor);

        },

        _updateConnectorlineWidth: function (lineWidth) {
            var proxy = this;
            this.model.connectorlineWidth = lineWidth;
            proxy._$ganttchartHelper.ejGanttChart("updateConnectorlineWidth", lineWidth);
            proxy._$ganttchartHelper.ejGanttChart("clearConnectorLines");
            proxy._$ganttchartHelper.ejGanttChart("renderConnectorLines",
                proxy._connectorLinesCollection);

        },

        _updateConnectorLineBackground: function (bgcolor) {
            var proxy = this;
            this.model.connectorLineBackground = bgcolor;
            proxy._$ganttchartHelper.ejGanttChart("updateConnectorLineBackground", bgcolor);
            proxy._$ganttchartHelper.ejGanttChart("clearConnectorLines");
            proxy._$ganttchartHelper.ejGanttChart("renderConnectorLines",
                proxy._connectorLinesCollection);

        },

        _updateHighlightWeekends: function (bool) {
            var proxy = this;
            this.model.highlightWeekends = bool;
            proxy._$ganttchartHelper.ejGanttChart("updateHighlightWeekends", bool);
        },

        _updateShowGridCellTooltip: function (bool) {
            var proxy = this;
            proxy._$treegridHelper.ejTreeGrid("updateShowGridCellTooltip", bool);
        },

        _updateShowGridExpandCellTooltip: function (bool) {
            var proxy = this;
            proxy._$treegridHelper.ejTreeGrid("updateShowGridExpandCellTooltip", bool);
        },

        _updateSelectedItem: function (item) {
            var proxy = this,
                args = {};
            if (item[proxy.model.taskIdMapping] != null) {


                args.recordIndex =proxy._ids.indexOf((item[proxy.model.taskIdMapping]).toString());
                args.item = proxy.model.ganttRecords[args.recordIndex];
                args.target = "ejTreeGrid";
                proxy.rowSelected(args);
                proxy._$treegridHelper.ejTreeGrid("selectRows", args.recordIndex);
                proxy._$ganttchartHelper.ejGanttChart("selectRows", args.recordIndex);
                proxy._$ganttchartHelper.ejGanttChart("updateSelectedItem", args.recordIndex);
            }
        },

        _updateAllowKeyboardNavigation: function (bool) {
            var proxy = this;
            proxy._$treegridHelper.ejTreeGrid("updateAllowKeyboardNavigation", bool);
            proxy._$ganttchartHelper.ejGanttChart("updateAllowKeyboardNavigation", height);
        },
        
        _updateAllowColumnResize: function (bool) {
            var proxy = this;
            proxy._$treegridHelper.ejTreeGrid("updateAllowColumnResize", bool);
        },
        
        _updateProgressbarHeight: function (height) {
            var proxy = this;
            this.model.progressbarHeight = height;
            proxy._$ganttchartHelper.ejGanttChart("updateProgressbarHeight", height);
        },
        
        _updateBaselineColor: function (color) {
            var proxy = this;
            this.model.baselineColor = color;
            proxy._$ganttchartHelper.ejGanttChart("updateBaselineColor", color);
        },
        
        _updateRenderBaseline: function (bool) {
            var proxy = this;
            this.model.renderBaseline = bool;
            proxy._$ganttchartHelper.ejGanttChart("updateRenderBaseline", bool);
            proxy._$ganttchartHelper.ejGanttChart("renderConnectorLines",
                proxy._connectorLinesCollection);
        },
        
        _updateRenderTaskNames: function (bool) {
            var proxy = this;
            this.model.showTaskNames = bool;
            proxy._$ganttchartHelper.ejGanttChart("updateRenderTaskNames", bool);
        },
        
        _updateRendeProgressStatus: function (bool) {
            var proxy = this;
            this.model.showProgressStatus = bool;
            proxy._$ganttchartHelper.ejGanttChart("updateRendeProgressStatus", bool);
        },
        
        _updateRenderResourceNames: function (bool) {
            var proxy = this;
            this.model.showResourceNames = bool;
            proxy._$ganttchartHelper.ejGanttChart("updateRenderResourceNames", bool);
        },
        
        _updateTaskbarBackground: function (bgcolor) {
            var proxy = this;
            this.model.taskbarBackground = bgcolor;
            proxy._$ganttchartHelper.ejGanttChart("updateTaskbarBackground", bgcolor);
        },

        _updateProgressbarBackground: function (bgcolor) {
            var proxy = this;
            this.model.progressbarBackground = bgcolor;
            proxy._$ganttchartHelper.ejGanttChart("updateProgressbarBackground", bgcolor);
        },

        _updateParentTaskbarBackground: function (bgcolor) {
            var proxy = this;
            this.model.parentTaskbarBackground = bgcolor;
            proxy._$ganttchartHelper.ejGanttChart("updateParentTaskbarBackground", bgcolor);
        },

        _updateParentProgressbarBackground: function (bgcolor) {
            var proxy = this;
            this.model.parentProgressbarBackground = bgcolor;
            proxy._$ganttchartHelper.ejGanttChart("updateParentProgressbarBackground", bgcolor);
        },
        
        _updateEditSettings: function (edit) {
            var proxy = this;
            proxy._$treegridHelper.ejTreeGrid("updateEditSettings", edit);
            
        },
        
        _updateRowSelection: function (bool) {
            var proxy = this;
            proxy._$treegridHelper.ejTreeGrid("updateRowSelection", bool);
        },

        _updateAltRow: function (bool) {
            var proxy = this;
            proxy._$treegridHelper.ejTreeGrid("updateAltRow", bool);
        },
        
        /**
       * To Open the dialog to add new task to the gantt
       * @return jQuery
       * @example 
       * &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
       * &lt;script&gt;
       * // Create Gantt
       * var ganttObj = $("#gantt").data("ejGantt");
       * gantObj.ejGantt("openAddDialog"); // To open the add dialog
       * &lt;/script&gt;
       * @example 
       *  &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
       * &lt;script&gt;
       * // open Add dialog
       * $("#gantt").ejGantt("openAddDialog");	
       * &lt;/script&gt;
       * @memberof ejGantt
       * @instance
        */
        openAddDialog: function() {
            this._sendAddRequest();
        },

        /**
        * To Open the dialog to edit existing task to the gantt
        * @return jQuery
        * @example 
        * &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
        * &lt;script&gt;
        * // Create Gantt
        * var ganttObj = $("#gantt").data("ejGantt");
        * gantObj.ejGantt("openEditDialog"); // To open the add dialog
        * &lt;/script&gt;
        * @example 
        *  &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
        * &lt;script&gt;
        * // open Add dialog
        * $("#gantt").ejGantt("openEditDialog");	
        * &lt;/script&gt;
        * @memberof ejGantt
        * @instance
         */
        openEditDialog:function() {
            this._sendEditRequest();
        },
        
        /**
        * To search an item with search string provided at the run time
        * @return jQuery
        * @example 
        * &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
        * &lt;script&gt;
        * // Create Gantt
        * var ganttObj = $("#gantt").data("ejGantt");
        * gantObj.ejGantt("searchItem",$("#text").val()); // To search a task
        * &lt;/script&gt;
        * @example 
        *  &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
        * &lt;script&gt;
        * // To search a task
        * $("#gantt").ejGantt("searchItem",$("#text").val());	
        * &lt;/script&gt;
        * @memberof ejGantt
        * @instance
         */
        searchItem: function (searchString) {
            var proxy = this;
            proxy._$treegridHelper.ejTreeGrid("search", searchString);
        },
        

        /**
        * To delete a selected item in gantt
        * @return jQuery
        * @example 
        * &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
        * &lt;script&gt;
        * // Create Gantt
        * var ganttObj = $("#gantt").data("ejGantt");
        * gantObj.ejGantt("deleteItem"); // To delete a task
        * &lt;/script&gt;
        * @example 
        *  &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
        * &lt;script&gt;
        * // To delete an item
        * $("#gantt").ejGantt("deleteItem");	
        * &lt;/script&gt;
        * @memberof ejGantt
        * @instance
         */
        deleteItem: function () {
            var proxy = this;
            proxy._$treegridHelper.ejTreeGrid("deleteRow");
        },


        /**
          * To Expand all the parent items in gantt
          * @return jQuery
          * @example 
          * &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
          * &lt;script&gt;
          * // Create Gantt
          * var ganttObj = $("#gantt").data("ejGantt");
          * gantObj.ejGantt("expandAllItems"); // To expand all parent items in gantt
          * &lt;/script&gt;
          * @example 
          *  &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
          * &lt;script&gt;
          * // To expand all items
          * $("#gantt").ejGantt("expandAllItems");	
          * &lt;/script&gt;
          * @memberof ejGantt
          * @instance
           */

        expandAllItems:function() {
            this._expandAll();
        },

        /**
          * To collapse all the parent items in gantt
          * @return jQuery
          * @example 
          * &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
          * &lt;script&gt;
          * // Create Gantt
          * var ganttObj = $("#gantt").data("ejGantt");
          * gantObj.ejGantt("collapseAllItems"); // To collapse all parent items in gantt
          * &lt;/script&gt;
          * @example 
          *  &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
          * &lt;script&gt;
          * // To expand all items
          * $("#gantt").ejGantt("collapseAllItems");	
          * &lt;/script&gt;
          * @memberof ejGantt
          * @instance
           */
        collapseAllItems:function() {
            this._collapseAll();
        },
        
          /**
          * To indent a selected item in gantt
          * @return jQuery
          * @example 
          * &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
          * &lt;script&gt;
          * // Create Gantt
          * var ganttObj = $("#gantt").data("ejGantt");
          * gantObj.ejGantt("indentItem"); // To indent a selected item in gantt
          * &lt;/script&gt;
          * @example 
          *  &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
          * &lt;script&gt;
          * // To indent a selected item in gantt
          * $("#gantt").ejGantt("indentItem");	
          * &lt;/script&gt;
          * @memberof ejGantt
          * @instance
           */
        indentItem:function() {
            this._sendIndentRequest();
        },

        /**
       * To outdent a selected item in gantt
       * @return jQuery
       * @example 
       * &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
       * &lt;script&gt;
       * // Create Gantt
       * var ganttObj = $("#gantt").data("ejGantt");
       * gantObj.ejGantt("outdentItem"); // To outdent a selected item in gantt
       * &lt;/script&gt;
       * @example 
       *  &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
       * &lt;script&gt;
       * // To outdent a selected item in gantt
       * $("#gantt").ejGantt("outdentItem");	
       * &lt;/script&gt;
       * @memberof ejGantt
       * @instance
        */
        outdentItem:function() {
            this._sendOutdentRequest();
        },
        

        /**
        * To cancel the edited state of an item in gantt
        * @return jQuery
        * @example 
        * &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
        * &lt;script&gt;
        * // Create Gantt
        * var ganttObj = $("#gantt").data("ejGantt");
        * gantObj.ejGantt("cancelEdit"); // To cancel edited
        * &lt;/script&gt;
        * @example 
        *  &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
        * &lt;script&gt;
        * // To outdent a selected item in gantt
        * $("#gantt").ejGantt("cancelEdit");	
        * &lt;/script&gt;
        * @memberof ejGantt
        * @instance
         */
        cancelEdit:function() {
            this.sendCancelRequest();
        },
        

        /**
       * To expand and collapse an item in gantt using item's ID
       * @return jQuery
       * @example 
       * &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
       * &lt;script&gt;
       * // Create Gantt
       * var ganttObj = $("#gantt").data("ejGantt");
       * gantObj.ejGantt("expandCollapseRecord" , "23"); // To expand collapse an item
       * &lt;/script&gt;
       * @example 
       *  &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
       * &lt;script&gt;
       * // To expand collapse an item
       * $("#gantt").ejGantt("expandCollapseRecord" , "23");	
       * &lt;/script&gt;
       * @memberof ejGantt
       * @instance
        */
        expandCollapseRecord: function (taskId) {
            var proxy = this, args = {},
                record = proxy.model.ganttRecords[proxy._ids.indexOf(taskId)],
                expand = record.expanded == true ? false : true;
            args.data = record;
            args.recordIndex = proxy._ids.indexOf(taskId);
            args.expanded = expand;
            args.requestType = "expandCollapse";
            proxy._$treegridHelper.ejTreeGrid("sendExpandCollapseRequest", args);
        },



        /**
       * To save the edited state of an item in gantt
       * @return jQuery
       * @example 
       * &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
       * &lt;script&gt;
       * // Create Gantt
       * var ganttObj = $("#gantt").data("ejGantt");
       * gantObj.ejGantt("saveEdit"); // To save edited state of an item
       * &lt;/script&gt;
       * @example 
       *  &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
       * &lt;script&gt;
       * // To expand collapse an item
       * $("#gantt").ejGantt("saveEdit");	
       * &lt;/script&gt;
       * @memberof ejGantt
       * @instance
        */
        saveEdit: function () {
            var proxy = this;
            proxy._$treegridHelper.ejTreeGrid("endEdit");
        },
        
        _showTooltip: function (boolValue) {
            var proxy = this;
            this.model.enableTaskbarTooltip = boolValue;
            proxy._$ganttchartHelper.ejGanttChart("showTooltip", boolValue);
        },

        _showEditingTooltip: function (boolValue) {
            var proxy = this;
            this.model.enableTaskbarDragTooltip = boolValue;
            proxy._$ganttchartHelper.ejGanttChart("showEditingTooltip", boolValue);
        },
        
        _ganttChartEditing:function(boolValue) {
            var proxy = this;
            proxy.model.allowGanttChartEditing = boolValue;
            proxy._$ganttchartHelper.ejGanttChart("ganttChartEditing", boolValue);
        },
        
        _resizeProgressbar: function (boolValue) {
            var proxy = this;
            proxy.model.enableProgressBarResizing = boolValue;
            proxy._$ganttchartHelper.ejGanttChart("resizeProgressbar", boolValue);

        },
        
        _sendSortingRequest: function(sortSettings) {
            var proxy = this, columnName, columnSortDirection;
            columnName = sortSettings.sortedColumns[0].field;
            columnSortDirection = sortSettings.sortedColumns[0].direction;
            proxy._$treegridHelper.ejTreeGrid("sortColumn", columnName, columnSortDirection);
        },
        
        sendCancelRequest: function () {
            var proxy = this;
            proxy._$treegridHelper.ejTreeGrid("cancelEditCell");

            if (proxy.model.toolbarSettings.toolbarItems.indexOf("cancel") !== -1) {
                proxy._disabledToolItems.push($($('.e-cancel')[0]).parent()[0]);
            }

            if (proxy.model.toolbarSettings.toolbarItems.indexOf("save") !== -1) {
                proxy._disabledToolItems.push($($('.e-saveitem')[0]).parent()[0]);
            }

            $('.e-gantttoolbar').ejToolbar('disableItem', proxy._disabledToolItems);
            proxy._disabledToolItems = [];
        },
        
        _sendAddRequest: function () {
            
            var proxy = this,                
                columns = proxy._columns,
                length = columns.length,
                columnCount = 0,
                cloneData = {},
                args = {};
            proxy._isinAddnewRecord = true;
            
            for (columnCount; columnCount < length; columnCount++)
                cloneData[columns[columnCount].mappingName] = "";

            args.data = cloneData;
            args.requestType = "add";            
          //  proxy._$treegridHelper.ejTreeGrid("clearSelection");
            proxy.renderedEditDialog(args);
        },

        _sendEditRequest: function ($tr) {
            var proxy = this,
                model = proxy.model,
                args,
                data;
            
            if (ej.isNullOrUndefined($tr)) {
                proxy._currentTrIndex = this.selectedRowIndex();
                proxy._$currentTr = $(proxy._$treegridHelper.ejTreeGrid("getRows")).eq(this.selectedRowIndex());
            } else {
                proxy._currentTrIndex = $tr.index();
                proxy._$currentTr = $tr;
            }
            data = proxy.getUpdatedRecords()[this.selectedRowIndex()];

            args = { rowElement: proxy._$currentTr, data: data };
            proxy._trigger("beginEdit", args);
            args.requestType = "beginedit";
            if(args.data)
                proxy.renderedEditDialog(args);
        },
        _updateAddData:function(obj)
        {
            var proxy = this,model=this.model,id,startDate;
            var cloneObj = {};
           
            if (!obj[model.taskIdMapping])
            {
                 id= proxy._updatedGanttRecords.length;
                 id = proxy._getNewTaskId(id);
                 var indx = proxy._ids.indexOf(id.toString());
                 proxy._ids.splice(indx,1);
                 obj[model.taskIdMapping] = id;
            }

            if (model.taskNameMapping && !obj[model.taskNameMapping]) {
                obj[model.taskNameMapping] = "New Task" + obj[model.taskIdMapping];
            }

            if (!obj[model.startDateMapping]) {
                obj[model.startDateMapping] = model.scheduleStartDate;
            }

            if (model.durationMapping && ej.isNullOrUndefined(obj[model.durationMapping])) {
                if (!obj[model.endDateMapping])
                obj[model.durationMapping] = "5";
            }
            if (model.progressMapping) {
                obj[model.progressMapping] = obj[model.progressMapping] > 100 ?
                    100 : obj[model.progressMapping];
            }

            if (!obj[model.endDateMapping] && model.endDateMapping) {

                if (!obj[model.durationMapping]) {
                    var startDate = proxy._getDateFromFormat(model.scheduleStartDate);
                    startDate.setDate(startDate.getDate() + 4);
                    obj[model.endDateMapping] = Globalize.format(startDate, this.model.dateFormat);
                }
            }
        },
        _sendSaveRequest: function (saveType) {
            var obj = {},
                doc = document,
                proxy = this,
                model=proxy.model,
                index = 0,
                formelement,
                length,
                editedRowWrap,
                columnName,
                $element,
                startdate,
                enddate,
                column,
                value,dialogId,treeGridId
            args = {};
            if(saveType==="Add")
            {
                formelement = doc.getElementById(proxy._id + "AddForm");
                length = formelement && formelement.length;
                dialogId = "Add";
                treeGridId = "#treegrid" + proxy._id + "predecessorAdd";
                $element = $("#" + proxy._id + "taskId" + dialogId);             
                column = ej.TreeGrid.getColumnByField(proxy._columns, "taskId");
                proxy._cellEditType = column.editType;
                if (column && $element.length>0)
                    value = proxy.getCurrentEditCellData($element, column.dropdownData);

                if (proxy._ids.indexOf(value) != -1 && value)
                    this._duplicate = true;
                else if (value) {
                    this._duplicate = false;
                }
            }
            else
            {
                formelement = doc.getElementById(proxy._id + "EditForm");
                length = formelement && formelement.length;
                treeGridId = "#treegrid" + proxy._id + "predecessoredit";
                dialogId = "";
            }
            editedRowWrap = $(formelement).closest('div');


            if (!this.editFormValidate())
                return true;            
                      
            if (!this._duplicate) {


                for (var count = 0; count < proxy._columns.length; count++) {
                    $element = $(formelement).find("#" + proxy._id + proxy._columns[count].field + dialogId);
                    if ($element.length > 0) {
                        proxy._cellEditType =proxy._columns[count].editType;
                        value = proxy.getCurrentEditCellData($element, proxy._columns[count].dropdownData); // formelement[index].value;
                        if (proxy._isinAddnewRecord === false && proxy._columns[count].mappingName === proxy.model.predecessorMapping) {
                            args.previousValue = proxy._updatePredecessorValue(obj, value);
                        }
                        if ($element.type != "checkbox")
                            obj[proxy._columns[count].mappingName] = value;
                    }
                }
                date1 = proxy._getDateFromFormat(obj[model.startDateMapping]);
                date2 = proxy._getDateFromFormat(obj[model.endDateMapping]);
                var diffdays=0;
                if (date1 && date2)
                    diffdays = date2.getTime() - date1.getTime();
                if (diffdays < 0)
                    this._wrongenddate = true;
                else
                    this._wrongenddate = false;
                if (!this._wrongenddate) {
                    // when adding new task resource value changes.
                if (obj[model.resourceIdMapping] && editedRowWrap.hasClass("e-addedrow"))
                {
                        var resource = [];
                        $.each(obj[model.resourceIdMapping], function (indx, value) { resource.push(value[model.resourceIdMapping]); })
                        obj[model.resourceIdMapping] = resource;
                    }

                    if (!obj[model.taskIdMapping] && saveType === "Edit")
                        obj[model.taskIdMapping] = proxy._editedDialogRecord.taskId;

                if (saveType === "Add")
                {
                        proxy._updateAddData(obj);
                    }

                    args.data = obj;


                    //getting predecessor from edit dialog table    
                    var prdecessor_validation_flag = false;
                    var results = [], resultFlag = false;;
                if (model.predecessorMapping )
                {
                        if (saveType === "Edit") {
                            resultFlag = model.editDialogFields.length === 0 ? true : false;
                            results = $.grep(model.editDialogFields, function (val, idx) {
                                return (val.field === model.predecessorMapping);
                            });
                    }else if(saveType === "Add")
                    {
                        resultFlag = model.addDialogFields.length=== 0 ? true : false;
                            results = $.grep(model.addDialogFields, function (val, idx) {
                                return (val.field === model.predecessorMapping);
                            });
                        }
                    }

                if (results.length > 0 || resultFlag)
                {
                        var pre = [];
                        var taskNameFlag = true;
                        pre = $(treeGridId).ejTreeGrid("option", "dataSource");
                        $.each(pre, function (idx, value) {
                        if(!(value.id.length>0 && value.name.length && value.type.length))
                        {
                                taskNameFlag = false;
                            }
                        });

                        if (taskNameFlag) {
                            var predecessorColl = [], predecessorString = [];//from,to,offset,predecessorType,isdrawn
                            var types = [{ id: "SS", text: "Start-Start", value: "Start-Start" }, { id: "SF", text: "Start-Finish", value: "Start-Finish" }, { id: "FS", text: "Finish-Start", value: "Finish-Start" }, { id: "FF", text: "Finish-Finish", value: "Finish-Finish" }];
                            var tempType;
                            for (var i = 0; i < pre.length; i++) {
                                var predecessor = {};
                                predecessor["from"] = obj.taskID;
                                predecessor["to"] = pre[i].id;
                                predecessor["isdrawn"] = false;
                            predecessor["offset"] =isNaN(parseInt(pre[i].offset)) ? 0 : parseInt(pre[i].offset);
                                for (var j = 0; j < types.length; j++) {
                                    if (pre[i].type == types[j].text) {
                                        predecessor["predecessorType"] = types[j].id;
                                        tempType = types[j].id;
                                        break;
                                    }
                                }
                                var tem = pre[i].id + tempType//+data[i].lags.toString();
                            pre[i].offset=isNaN(parseInt(pre[i].offset)) ? 0 : parseInt(pre[i].offset);
                                if (pre[i].offset !== 0) {
                                    if (pre[i].offset < 0)
                                        tem += pre[i].offset.toString();
                                    else
                                        tem += "+" + pre[i].offset.toString();
                                }
                                predecessorString.push(tem);
                                predecessorColl.push(predecessor);
                            }
                            args.predecessorString = predecessorString;

                            //befor save validate the edit form data
                            prdecessor_validation_flag = proxy._editedPredecessorValidation(args);

                        } else {
                            //Break here and give notification to users
                            alert("Fill all the columns in predecessor table")
                            return true;
                        }

                        if (prdecessor_validation_flag) {
                            if (proxy._isinAddnewRecord === false) {// && proxy.model.predecessorMapping
                                args.previousValue = proxy._updatePredecessorValue(obj, predecessorString.join(','));
                            }
                            obj[model.predecessorMapping] = predecessorString.join(',');
                        }
                        else {
                            alert("Cyclic Dependency Occured, Please Check The Predecessor");
                            return true;
                        }
                    }

                    args.requestType = ej.TreeGrid.Actions.Save;
                    args.recordIndex = (this.selectedRowIndex() !== -1) ? this.selectedRowIndex() : -1;

                    if (proxy._trigger("actionBegin", args))
                        return true;


                    if (editedRowWrap.hasClass("e-editedrow")) {
                        args._cModifiedData = proxy._updateRecord(obj);
                        if (proxy._editedDialogRecord) {
                            if (!args._cModifiedData.startDate) {
                                args._cModifiedData.startDate = proxy._editedDialogRecord.startDate;
                            }
                            if (!args._cModifiedData.endDate) {
                                args._cModifiedData.endDate = proxy._editedDialogRecord.endDate;
                            }
                            if (!args._cModifiedData.duration) {
                                args._cModifiedData.duration = proxy._editedDialogRecord.duration;
                            }
                            proxy._editedDialogRecord = null;
                        }

                        if (args.data[model.endDateMapping] && !args.data[model.durationMapping]) {
                            args._cModifiedData._calculateDuration(proxy._getDateFromFormat(args._cModifiedData.startDate), proxy._getDateFromFormat(args._cModifiedData.endDate), model.includeWeekend, model.holidays, args._cModifiedData.isMilestone, model);
                        }

                    }
                    else if (editedRowWrap.hasClass("e-addedrow")) {

                        var parentItem, Level = 0, cIndex;
                        if (model.selectedItem) {
                            if (model.selectedItem.hasChildRecords) {//this is parent item
                                Level = model.selectedItem.level + 1
                                parentItem = model.selectedItem;
                                cIndex = 0;
                            }
                            else if ((!model.selectedItem.hasChildRecords && model.selectedItem.parentItem)) {
                                Level = model.selectedItem.level;
                                parentItem = model.selectedItem.parentItem;
                                cIndex = parentItem.childRecords.indexOf(model.selectedItem) + 1;
                            }
                            else {
                                Level = 0;
                                parentItem = null;
                            }
                        }
                        args._cAddedRecord = proxy._createGanttRecord(obj, Level, parentItem, false);
                        if (model.predecessorMapping && args._cAddedRecord.predecessor && args._cAddedRecord.parentItem) {
                            var predecessorIdArray = proxy._idFromPredecessor(args._cAddedRecord.item[model.predecessorMapping]);
                            if (predecessorIdArray.indexOf(args._cAddedRecord.parentItem.taskId.toString()) !== -1) {
                                alert("Cyclic Dependency Occured, Please Check The Predecessor");
                                return true;
                            }
                        }
                    }

                    if (args._cAddedRecord) {
                        args._cAddedRecord.taskId =args._cAddedRecord.taskId;
                        args._cAddedRecord.index = args.recordIndex;
                        //proxy._$treegridHelper.ejTreeGrid("processBindings", args);
                    }

                    proxy.actionComplete(args);
                    proxy._cModifiedData = null;
                    proxy._cAddedRecord = null;
                    proxy._primaryKeyValues = [];
                    proxy._isinAddnewRecord = false;
                    return false;
                }
                else {
                    alert("Invalid End date");                           
                }
            }
            else {
                alert("Duplicate ID");
                         
            }
                
        },

        _recordReturnerByID:function(id)
        {
            var proxy = this,
                records = proxy._rows;
            for (var i = 0; i < records.length; i++) {
                if (records[i].taskId.toString() === id.toString()) {
                    return records[i]
                }
            }
            return null;

        },
        _editedPredecessorValidation: function (args) {

            var proxy = this,
                records = proxy._rows,
                flag = true,
                recordId = args.data[this.model.taskIdMapping],
                predecessor = args.predecessorString.join(','),predecessorIdArray;
            if (predecessor.length > 0) {
                predecessorIdArray = proxy._idFromPredecessor(predecessor);
                for (var count = 0; count < predecessorIdArray.length; count++) {
                    //Check edited item has parent item in predecessor collection
                    var editingData = proxy._recordReturnerByID(recordId);
                    if (editingData && editingData.parentItem) {
                        if (predecessorIdArray.indexOf(editingData.parentItem.taskId.toString()) !== -1) {
                            return false;
                        }
                    }
                    // Check if predecessor exist more then one 
                    var tempIdArray = predecessorIdArray.slice(0),checkArray=[],countFlag=true;
                    $.each(tempIdArray, function (index, value) { 
                        if(checkArray.indexOf(value)===-1)
                            checkArray.push(value);
                        else
                            countFlag = false;
                    });
                    if (countFlag === false) {
                        return false;

                    }
                    //Cyclick check  
                    currentId = predecessorIdArray[count];
                    var visitedIdArray = [];
                    var predecessorCollection = predecessorIdArray.slice(0);
                    predecessorCollection.splice(count, 1);


                    while (currentId !== null) {
                        var currentIdArray = [];
                        if (visitedIdArray.indexOf(currentId) === -1)
                        {
                            currentRecord = proxy._recordReturnerByID(currentId);
                          //  var currentPredecessor="";
                            if (!ej.isNullOrUndefined(currentRecord.predecessor) && currentRecord.predecessor.length>0)
                            {
                                $.each(currentRecord.predecessor, function (index, value) {
                                    if (currentRecord.taskId.toString() !== value.from)
                                        currentIdArray.push(value.from.toString());
                                });
                            //    currentPredecessor=currentRecord.predecessor[0].from
                            }
                            if (recordId.toString() === currentRecord.taskId.toString() || currentIdArray.indexOf(recordId.toString()) !== -1) { // || predecessorCollection.indexOf(currentPredecessor) !== -1
                                //cycylic occurs//break;
                                return false;
                            }
                            visitedIdArray.push(currentId);
                            if (!ej.isNullOrUndefined(currentRecord.predecessor) && currentRecord.predecessor.length > 0) {
                                var result;
                                if (currentIdArray.length > 1) {
                                    result=this._predecessorValidation(currentIdArray, args);
                                }
                                else
                                    currentId = currentRecord.predecessor[0].from;
                                if (result === false) {
                                    return false;
                                }
                            }
                            else
                                break;
                        }
                        else
                        {
                            break;
                        }
                    }
                }
            }
            return flag;
        },

        _predecessorValidation: function (predecessor,args) {
            var proxy = this;
            var recordId=args.data[this.model.taskIdMapping];
            for (var count = 0; count < predecessor.length; count++) {
                currentId = predecessor[count];
                var visitedIdArray = [];
                var predecessorCollection = predecessor.slice(0);
                predecessorCollection.splice(count, 1);

                while (currentId !== null) {
                    var currentIdArray = [];
                    if (visitedIdArray.indexOf(currentId) === -1) {
                        currentRecord = proxy._recordReturnerByID(currentId);
                        //  var currentPredecessor="";
                        if (!ej.isNullOrUndefined(currentRecord.predecessor) && currentRecord.predecessor.length > 0) {
                            $.each(currentRecord.predecessor, function (index, value) {
                                if (currentRecord.taskId.toString() !== value.from)
                                    currentIdArray.push(value.from.toString());
                            });
                            //    currentPredecessor=currentRecord.predecessor[0].from
                        }
                        if (recordId.toString() === currentRecord.taskId.toString() || currentIdArray.indexOf(recordId.toString()) !== -1) { // || predecessorCollection.indexOf(currentPredecessor) !== -1
                            //cycylic occurs//break;
                            return false;
                        }
                        visitedIdArray.push(currentId);
                        if (!ej.isNullOrUndefined(currentRecord.predecessor) && currentRecord.predecessor.length > 0) {
                            currentId = currentRecord.predecessor[0].from;
                        }
                        else
                            break;
                    }
                    else {
                        break;
                    }
                }
            }
            return true;
            
        },
        _sendCancelRequest: function () {
            var proxy = this,
                model=proxy.model,
                args = {};

            if (model.dateFormat.indexOf("hh") != -1)
                $("#" + proxy._id + "EditForm").find(".e-datepicker").ejDateTimePicker("destroy");
            else
                $("#" + proxy._id + "EditForm").find(".e-datepicker").ejDatePicker("destroy");

            args.requestType = ej.TreeGrid.Actions.Cancel;
            proxy.processBindings(args);
            proxy._primaryKeyValues = [];
            proxy.model.currentData = null;
        },
        
        _updatePredecessorValue: function (obj, value) {
            var proxy = this,
                prevPredecessors,
                modifiedPredecessors,
                length=0,
                predecessor,
                ganttPredecessor = [],
                count = 0;
            prevPredecessors = proxy.selectedItem()["predecessor"];

            if (value.length > 0) {
                modifiedPredecessors = proxy.selectedItem()._calculatePredecessor(value);
            }
            if (modifiedPredecessors)
                length = modifiedPredecessors.length;

            var index = 0, prevPrdecessorlength=0;
            if(prevPredecessors)
                prevPrdecessorlength = prevPredecessors.length;


            for (index = 0; index < prevPrdecessorlength; index++) {
                predecessor = prevPredecessors[index];
                if (predecessor.from === proxy.selectedItem().taskId.toString()) {
                    ganttPredecessor.push(predecessor);
                }
            }
            for (count = 0; count < length; count++) {
                ganttPredecessor.push(modifiedPredecessors[count]);
            }
            proxy.selectedItem().predecessor = ganttPredecessor;
            if (proxy.model.predecessorMapping)
                proxy.selectedItem().item[proxy.model.predecessorMapping] = value;

            return prevPredecessors;          //
        },


        getCurrentEditCellData: function ($element, dropdownData) {
            var proxy = this, model = proxy.model, date;
            if ($("#" + proxy._id + "EditForm").length || $("#" + proxy._id + "AddForm").length) {
                var cellValue="";// $element = $("#" + proxy._id + proxy._columnFieldName), 
                switch (proxy._cellEditType) {
                    case ej.TreeGrid.EditingType.String:
                        cellValue = $element.val();
                        break;
                    case ej.TreeGrid.EditingType.Numeric:
                        cellValue = $element.ejNumericTextbox("getValue");
                        $element.ejNumericTextbox("getValue");
                        break;
                    case ej.TreeGrid.EditingType.Dropdown:
                        cellValue = proxy._getSelectedItem($element.ejDropDownList("model.selectedItems"), dropdownData);
                        break;
                    case ej.TreeGrid.EditingType.Boolean:
                        cellValue = $element.is(':checked');
                        break;

                    case ej.TreeGrid.EditingType.DatePicker:
                        if (model.dateFormat.indexOf("hh") != -1)
                            date = $element.ejDateTimePicker("model.value");
                        else
                            date = $element.ejDatePicker("model.value");
                        cellValue = Globalize.format(date, model.dateFormat);
                        break;
                    case ej.TreeGrid.EditingType.DateTimePicker:
                        cellValue = $element.ejDateTimePicker("model.value");
                        break;
                }

                //if (typeof cellValue == "string" && cellValue.length )//&& model.columns[proxy._cellEditingDetails.columnIndex].type == "number")
                //    cellValue = parseFloat(cellValue);
                return cellValue;
            }
            return null;
        },


        _getSelectedItem: function (indexArray, dropDownData) {
            var count = 0,
                length = indexArray.length,
                    selectedItems = [];
            if (dropDownData) {
                for (count = 0; count < length; count++) {
                    $.each(dropDownData, function (index, resourceInfo) {
                        if (indexArray[count] === index) {
                            selectedItems.push(resourceInfo);
                        }
                    });
                }
            }

            return selectedItems;
        },
        _updateRecord: function (data) {
            var proxy = this,model=this.model,
                columns=proxy._columns,
               length,
                index = 0,
                ganttRecord = proxy.getUpdatedRecords()[this.selectedRowIndex()];

            if (model.editDialogFields.length > 0) {
                var filteredColumns = [];
                var count = 0, resultColumn;
                for (; count < model.editDialogFields.length; count++) {
                    resultColumn = $.grep(proxy._columns, function (val) {
                        return val.mappingName === model.editDialogFields[count].field;
                    });
                    resultColumn.length && filteredColumns.push(resultColumn[0]);
                }
                columns = filteredColumns;
            }
            length = columns.length;

            for (index = 0; index < length; index++) {

                if (columns[index].field.toString() === "predecessor")
                    continue;
                    //for predecessor from edit dialog window 
                
                ganttRecord[columns[index].field] = data[columns[index].mappingName];
                ganttRecord.item[columns[index].mappingName] = data[columns[index].mappingName];//field
            }
            
            return ganttRecord;
        },

        _sendIndentRequest: function () {

            var proxy = this,
                model = proxy.model,
                data = proxy.getCurrentData(), args = {}, eveargs = {},
                treegridobj = proxy._$treegridHelper.ejTreeGrid("instance"),
                flatRecords = treegridobj.model.flatRecords;

            if (ej.isNullOrUndefined(data)) {
                alert("There is no gantt Record was not selected to perform the Indent ");
            }
            else {

                proxy._updatedGanttRecords = proxy.getUpdatedRecords();
                var previousGanttRecord = proxy._updatedGanttRecords[this.selectedRowIndex() - 1];
                args.data = data;
                args.requestType = "beginedit"
                if (!proxy._trigger("actionBegin", args)) {

                    if (data.parentItem) {
                        var childIndex = data.parentItem.childRecords.indexOf(data);
                        data.parentItem.childRecords.splice(childIndex, 1);
                        if(!model.parentTaskIdMapping)
                            data.parentItem.item[model.childMapping].splice(childIndex, 1);
                    } else {
                        if (this.dataSource() instanceof ej.DataManager) {
                            if (this.dataSource().dataSource.offline && this.dataSource().dataSource.json) {
                                var dataSourceIndex = this.dataSource().dataSource.json.indexOf(data.item);
                                if (!model.parentTaskIdMapping)
                                    this.dataSource().dataSource.json.splice(dataSourceIndex, 1);
                            }
                        }
                        else {
                            var dataSourceIndex = this.dataSource().indexOf(data.item);
                            if (!model.parentTaskIdMapping)
                                this.dataSource().splice(dataSourceIndex, 1);
                        }
                    }
                    if (data.level === previousGanttRecord.level) {
                        if (previousGanttRecord.childRecords) {
                            if (!previousGanttRecord.expanded) {
                                previousGanttRecord.childRecords.splice(previousGanttRecord.childRecords.length, 0, data);
                                data.parentItem = previousGanttRecord;
                                if (!model.parentTaskIdMapping)
                                    previousGanttRecord.item[model.childMapping].splice(previousGanttRecord.childRecords.length, 0, data.item);
                                else
                                    data.item[model.parentTaskIdMapping] = previousGanttRecord.taskId;
                            }
                        } else {
                            previousGanttRecord.childRecords = [];
                            previousGanttRecord.childRecords.push(data);
                            data.parentItem = previousGanttRecord;
                            previousGanttRecord.item[model.childMapping] = [];
                            if (!model.parentTaskIdMapping)
                                previousGanttRecord.item[model.childMapping].push(data.item);
                            else
                                data.item[model.parentTaskIdMapping] = previousGanttRecord.taskId;
                        }
                    } else if (previousGanttRecord.level - data.level === 1) {
                        previousGanttRecord.parentItem.childRecords.splice(previousGanttRecord.parentItem.childRecords.length, 0, data);
                        if (!model.parentTaskIdMapping)
                            previousGanttRecord.parentItem.item[model.childMapping].splice(previousGanttRecord.parentItem.childRecords.length, 0, data.item);
                        else
                            data.item[model.parentTaskIdMapping] = previousGanttRecord.parentItem.taskId;
                        data.parentItem = previousGanttRecord.parentItem;
                    } else if (previousGanttRecord.level - data.level > 1) {

                        var parentItem = proxy.getParentItem(previousGanttRecord, data.level);
                        parentItem.childRecords.splice(parentItem.childRecords.length, 0, data);
                        if (!model.parentTaskIdMapping)
                            parentItem.item[model.childMapping].splice(parentItem.childRecords.length, 0, data.item);
                        else
                            data.item[model.parentTaskIdMapping] = parentItem.taskId;
                        data.parentItem = parentItem;

                    }
                }
                if (data.parentItem.isMilestone) {
                    data.parentItem.isMilestone = false;
                }
                previousGanttRecord.hasChildRecords = previousGanttRecord.childRecords ? previousGanttRecord.childRecords.length > 0 : false;
                data.level += 1;
                proxy.updateLevel(data, +1);
                proxy.refreshGanttRecord(data);
                proxy.updateIndentOutdentOption(data);
                //update parent recordsCollections
                if (previousGanttRecord.level === 0) {
                    if (model.parentRecords.indexOf(previousGanttRecord) === -1) {
                        model.parentRecords.push(previousGanttRecord);
                    }
                }
                if (data.level > 0) {
                    if (model.parentRecords.indexOf(data) !== -1) {
                        var idx = model.parentRecords.indexOf(data);
                        model.parentRecords.splice(idx, 1);
                        treegridobj.model.parentRecords = model.parentRecords;
                    }
                }
                //Update parentitem
                if (data.parentItem) {
                   // data._updateParentProgress(data.parentItem, model.progressMapping);
                    proxy._updateParentItem(data);
                }
                //Remove child predecessor from Parent item
                if (previousGanttRecord.predecessor && previousGanttRecord.predecessor.length > 0 && proxy.model.predecessorMapping && previousGanttRecord.hasChildRecords) {
                    proxy._updatePredecessorOnIndentOutdent(previousGanttRecord);
                }
                proxy.refreshGanttRecord(previousGanttRecord);
                if (!proxy.getExpandStatus(data)) {
                    var childCount = proxy._$treegridHelper.ejTreeGrid("getChildCount", data, 0);
                    if (model.enableVirtualization) {
                        var flatIndex = flatRecords.indexOf(data);
                        if (childCount > 0 && !data.expanded) {
                            childCount = 0;
                        }
                        flatRecords.splice(flatIndex, childCount + 1);
                    }
                    else {
                        if (childCount>0 && !data.expanded) {
                            childCount = 0;
                        }
                        proxy._totalCollapseRecordCount += (childCount + 1);
                        proxy._$ganttchartHelper.ejGanttChart("reRenderGanttGridLinesTable", -(childCount + 1));
                    }
                    var expanargs = {};
                    expanargs.expanded = true;
                    expanargs.data = data.parentItem;
                    proxy.expanding(expanargs);
                }
                if (proxy.model.predecessorMapping) {
                    proxy._isValidationEnabled = false;
                    proxy._connectorlineIds = [];
                    proxy._connectorLinesCollection = [];
                    proxy._$ganttchartHelper.ejGanttChart("clearConnectorLines");
                    proxy._createConnectorLinesCollection();
                }
                //row selection
                var rowToindex = proxy._updatedGanttRecords.indexOf(data);
                var $ganttChartRows = proxy.getGanttChartRows();
                args = {
                    rowElement: $ganttChartRows.eq(rowToindex),
                    data: proxy.model.selectedItem,
                    recordIndex: rowToindex
                };
                proxy._$ganttchartHelper.ejGanttChart("selectRows", args.recordIndex);
                proxy._$treegridHelper.ejTreeGrid("selectRows", args.recordIndex);
                this.selectedItem(args.data);
                this.selectedRowIndex(args.recordIndex);

                eveargs.data = data;
                eveargs.requestType = "endedit";
                this._trigger("actionComplete", eveargs);
            }
        },
        
        _updatePredecessorOnIndentOutdent:function(parentRecord)
        {

            var proxy = this, len = parentRecord.predecessor.length,
                predecessorCollection = parentRecord.predecessor,
                predecessorIndex,
                childRecord,
                id,
                updatedPredecessor = [];
            for (var count = 0; count < len; count++) {
                //remove predecessor connect with parent item
                if (predecessorCollection[count].to === parentRecord.taskId.toString()) {
                    childRecord = proxy._rows[proxy._ids.indexOf(predecessorCollection[count].from)];
                    predecessorIndex = childRecord.predecessor.indexOf(predecessorCollection[count]);
                    childRecord.predecessor.splice(predecessorIndex, 1);
                    id = "parent" + childRecord['taskId'] + "child" + parentRecord['taskId'];
                    proxy._$ganttchartHelper.ejGanttChart("removeConnectorline", id);
                }
                    //remove predecessor if parent record as predecessor of it's child record
                else if (predecessorCollection[count].from === parentRecord.taskId.toString()) {
                    childRecord = proxy._rows[proxy._ids.indexOf(predecessorCollection[count].to)];
                    if (parentRecord.childRecords.indexOf(childRecord) !== -1) {
                        predecessorIndex = childRecord.predecessor.indexOf(predecessorCollection[count]);
                        childRecord.predecessor.splice(predecessorIndex, 1);
                        var stringPredecessor = proxy._predecessorToString(childRecord.predecessor, childRecord);
                        childRecord.item[model.predecessorMapping] = stringPredecessor;
                        id = "parent" + parentRecord['taskId'] + "child" + childRecord['taskId'];
                        proxy._$ganttchartHelper.ejGanttChart("removeConnectorline", id);
                        proxy.refreshGanttRecord(childRecord);
                    }
                    else
                    {
                        updatedPredecessor.push(predecessorCollection[count]);
                    }
                }
            }
            parentRecord.predecessor = updatedPredecessor;
            parentRecord.item[model.predecessorMapping] = "";

            //if (updatedPredecessor.length > 0) {
            //    proxy._updatedConnectorLineCollection = [];
            //    proxy._connectorlineIds = [];
            //    proxy._validatePredecessor(parentRecord);
            //    if (proxy._updatedConnectorLineCollection.length > 0) {
            //        proxy._$ganttchartHelper.ejGanttChart("appendConnectorLine", proxy._updatedConnectorLineCollection);
            //    }
            //}
        },
        
        _removePredecessor:function(predecessor,record)
        {
            var proxy = this, length = predecessor.length, count = 0, model = proxy.model, parentGanttRecord, childGanttRecord;
            for (count; count < length; count++)
            {
                if (predecessor[count].from !== record.taskId.toString())
                {
                    childGanttRecord = proxy._rows[proxy._ids.indexOf(predecessor[count].from)];  //index st
                }
                else if (predecessor[count].to !== record.taskId.toString())
                {
                    childGanttRecord = proxy._rows[proxy._ids.indexOf(predecessor[count].to)]
                }

                if (childGanttRecord) {
                    var cIndex = childGanttRecord.predecessor.indexOf(predecessor[count]);
                    if (cIndex !== -1)
                        childGanttRecord.predecessor.splice(cIndex, 1);

                    if (childGanttRecord.item[model.predecessorMapping]) {
                        childGanttRecord.item[model.predecessorMapping] = proxy._predecessorToString(childGanttRecord.predecessor, childGanttRecord);
                        proxy.refreshGanttRecord(childGanttRecord);
                    }
                }
            }

        },

        _predecessorToString:function(predecessorCollection,record)
        {
            var proxy = this, predecessorString=[],count=0,length=predecessorCollection.length;
            
            for (count; count < length;count++)
            {
                if(record.taskId.toString()!==predecessorCollection[count].from)
                    {
                        var tem = predecessorCollection[count].from + predecessorCollection[count].predecessorsType;
                        predecessorCollection[count].offset = isNaN(predecessorCollection[count].offset) ? 0 : predecessorCollection[count].offset;

                        if (predecessorCollection[count].offset !== 0) {
                            if (predecessorCollection[count].offset < 0)
                                tem += predecessorCollection[count].offset.toString();
                            else if (predecessorCollection[count].offset > 0)
                                tem += "+" + predecessorCollection[count].offset.toString();
                        }
                        predecessorString.push(tem);
                }
            }
           
            return predecessorString.join(',');
        },
        //get the parentItem of selected ganttRecord to perform the indent operation
        
        getParentItem:function(ganttRecord,level) {

            var proxy = this;

            if (ganttRecord.parentItem.level === level)
                return ganttRecord.parentItem;

            return proxy.getParentItem(ganttRecord.parentItem, level);
        },

        //Change the position or index for the outdent element 
        getSubChangeIndex: function (itemLevel, itemIndex, item) {
            var proxy = this, changetoIndex;
            for (var items = 0; items < proxy._updatedGanttRecords.length; items++) {
                if (proxy._updatedGanttRecords[items].level == itemLevel && proxy._updatedGanttRecords[items].index > itemIndex) {
                    if (item.parentItem && proxy._updatedGanttRecords[items].parentItem.taskId == item.parentItem.taskId)
                        changetoIndex = proxy._updatedGanttRecords[items].index;
                    break;
                }
            }
            return changetoIndex;
        },

        //get the next sample level item from 
        _nextSameLevelItem:function(data,totRecords)
        {
            var proxy = this,
                level = data.parentItem.level, dataIndex = totRecords.indexOf(data), nextItem;
            for (i = dataIndex; i < totRecords.length; i++)
            {
                if (level === totRecords[i].level || level > totRecords[i].level) {
                    nextItem = totRecords[i];
                    break;
                }
            }
            return nextItem;
        },
        _sendOutdentRequest: function () {
            var proxy = this,
                model = proxy.model,
                data = proxy.getCurrentData(),
                args = {},
                eveargs = {},
                updateNextItem,
                rowNextItem,
                updateInsertIndex,
                rowInsertIndex,
                dataUpdatedRecordIndex,
                dataRowIndex,
                childDataIndex,
                insertParentItem,
                rowNextItemChildIndex,
                dataChildCount, splicedRows, splicedUpdatedRows,
                dataFlatIndex,
                flatNextItem,
                flatInsertIndex,
                splicedFlatRows,
                treeGridFlatRecords,
                isFlatRecordChange=false,
                isChangeUpdatedRecords=true,
                treegridobj = proxy._$treegridHelper.ejTreeGrid("instance");

            if (ej.isNullOrUndefined(data)) {
                alert("There is no gantt Record was not selected to perform the Outdent ");
            } else {
                args.data = data;
                args.requestType = "actionBegin";
                if (!proxy._trigger("actionBegin", args)) {

                    if (data.level === 0)
                        return;
                    else {
                        proxy._updatedGanttRecords = proxy.getUpdatedRecords();
                        //find where to insert data
                        updateNextItem = proxy._nextSameLevelItem(data, proxy._updatedGanttRecords);
                        rowNextItem = proxy._nextSameLevelItem(data, proxy._rows);
                        dataUpdatedRecordIndex = proxy._updatedGanttRecords.indexOf(data);
                        dataRowIndex = proxy._rows.indexOf(data);
                        treeGridFlatRecords = treegridobj.model.flatRecords;

                        //find postion of data in flat records
                        if (treeGridFlatRecords !== proxy._updatedGanttRecords) {
                            dataFlatIndex = treeGridFlatRecords.indexOf(data);
                            flatNextItem = proxy._nextSameLevelItem(data, treeGridFlatRecords);
                            isFlatRecordChange = true;
                        }
                        //find child index of record in parentItem
                        childDataIndex = data.parentItem.childRecords.indexOf(data);
                        insertParentItem = data.parentItem.parentItem;
                        rowNextItemChildIndex = insertParentItem && data.parentItem.parentItem.childRecords.indexOf(rowNextItem);

                        //remove data from current parent item
                        data.parentItem.childRecords.splice(childDataIndex, 1);

                        if(!model.parentTaskIdMapping)
                            data.parentItem.item[model.childMapping].splice(childDataIndex, 1);

                        if (data.parentItem.childRecords.length == 0) {

                            data.parentItem.childRecords = null;
                            data.parentItem.expanded = false;
                            data.parentItem.hasChildRecords = false;
                        }
                        else
                        {
                            proxy._updateParentItem(data.parentItem.childRecords[0]);
                        }

                        //add to next parent item
                        if (insertParentItem) {
                            insertParentItem.childRecords.splice(rowNextItemChildIndex, 0, data);
                            if (!model.parentTaskIdMapping)
                                insertParentItem.item[model.childMapping].splice(rowNextItemChildIndex, 0, data.item);
                            data.parentItem = insertParentItem;
                        } else {

                            if (this.dataSource() instanceof ej.DataManager) {
                                if (this.dataSource().dataSource.offline && this.dataSource().dataSource.json) {
                                    if (!model.parentTaskIdMapping)
                                        this.dataSource().dataSource.json.push(data.item);
                                }
                            } else {
                                if (!model.parentTaskIdMapping)
                                    this.dataSource().push(data.item);
                            }
                            data.parentItem = null;
                        }
                        //set value to need to updated the _updatedRecord collections
                        if (treegridobj.model.sortSettings.sortedColumns.length > 0 || (treegridobj.model.allowSearching && treegridobj._searchString.length > 0)) {
                            isChangeUpdatedRecords = false
                        }

                        //Records updates _rows collections
                        dataChildCount = proxy._$treegridHelper.ejTreeGrid("getChildCount", data, 0);
                        splicedRows = proxy._rows.splice(dataRowIndex, dataChildCount + 1);
                        splicedIds = proxy._ids.splice(dataRowIndex, dataChildCount + 1);

                        //Records updates _updatedGanttRecords collections
                        if (isChangeUpdatedRecords) {
                            if ((model.enableVirtualization && data.expanded) || !model.enableVirtualization)
                                splicedUpdatedRows = proxy._updatedGanttRecords.splice(dataUpdatedRecordIndex, dataChildCount + 1);
                            else
                                splicedUpdatedRows = proxy._updatedGanttRecords.splice(dataUpdatedRecordIndex, 1);
                        }

                        //Record update flatrecords
                        if (isFlatRecordChange) {
                            if ((model.enableVirtualization && data.expanded) || !model.enableVirtualization)
                                splicedFlatRows = treeGridFlatRecords.splice(dataFlatIndex, dataChildCount + 1);
                            else
                                splicedFlatRows = treeGridFlatRecords.splice(dataFlatIndex, 1);
                        }

                        if (rowNextItem) {
                            updateInsertIndex = proxy._updatedGanttRecords.indexOf(updateNextItem);
                            rowInsertIndex = proxy._rows.indexOf(rowNextItem);
                            flatInsertIndex = treeGridFlatRecords.indexOf(rowNextItem);
                            //change the position of records in _rows collections
                        }
                        else {
                            updateInsertIndex = proxy._updatedGanttRecords.length;
                            rowInsertIndex = proxy._rows.length;
                            flatInsertIndex = treeGridFlatRecords.length;
                        }

                        if (data.hasChildRecords && data.childRecords.length > 0) {

                            for (i = 0; i < splicedRows.length; i++) {
                                proxy._rows.splice(rowInsertIndex, 0, splicedRows[i]);
                                proxy._ids.splice(rowInsertIndex, 0, splicedIds[i]);
                                splicedRows[i].level -= 1;
                                rowInsertIndex++;
                            }

                            //insert into updated records
                            if (isChangeUpdatedRecords) {
                                if ((model.enableVirtualization && data.expanded) || !model.enableVirtualization) {
                                    for (i = 0; i < splicedUpdatedRows.length; i++) {
                                        proxy._updatedGanttRecords.splice(updateInsertIndex, 0, splicedUpdatedRows[i]);
                                        updateInsertIndex++;
                                    }
                                } else {
                                    proxy._updatedGanttRecords.splice(updateInsertIndex, 0, data);
                                }
                            }
                            //insert into flat records collection
                            if (isFlatRecordChange) {
                                if ((model.enableVirtualization && data.expanded) || !model.enableVirtualization) {
                                    for (i = 0; i < splicedFlatRows.length; i++) {
                                        treeGridFlatRecords.splice(flatInsertIndex, 0, splicedFlatRows[i]);
                                        flatInsertIndex++;
                                    }
                                } else {
                                    treeGridFlatRecords.splice(flatInsertIndex, 0, data);
                                }
                            }
                        }
                        else {
                            proxy._rows.splice(rowInsertIndex, 0, splicedRows[0]);
                            proxy._ids.splice(rowInsertIndex, 0, splicedIds[0]);
                            splicedRows[0].level -= 1;
                            if (isChangeUpdatedRecords) {
                                proxy._updatedGanttRecords.splice(updateInsertIndex, 0, splicedUpdatedRows[0]);
                            }
                            if (isFlatRecordChange) {
                                treeGridFlatRecords.splice(flatInsertIndex, 0, splicedFlatRows[0]);
                            }
                        }
                        //update parentitem of selected item after changing of its child 
                        if (data.parentItem) {
                            //change the structure of milestone after outdent
                            if (data.parentItem.isMilestone) {
                                data.parentItem.isMilestone = false;
                            }

                            data.parentItem.hasChildRecords && proxy._updateParentItem(data.parentItem.childRecords[0]);
                            //proxy.refreshGanttRecord(data.parentItem);
                        }

                        if (data.hasChildRecords) {
                            proxy._updateParentItem(data.childRecords[0]);
                            data._updateParentProgress(data, model.progressMapping);
                        }

                        //update parent recordsCollections
                        if (data.level === 0) {
                            if (model.parentRecords.indexOf(data) === -1) {
                                model.parentRecords.push(data);
                                treegridobj.model.parentRecords = model.parentRecords;
                            }
                        }

                        //update predecessor
                        if (data.predecessor && data.predecessor.length > 0 && proxy.model.predecessorMapping && data.hasChildRecords) {
                            proxy._updatePredecessorOnIndentOutdent(data)
                        }

                        //Refreshing the Gantt and TreeGrid data
                        treegridobj.model.records = proxy._rows;
                        treegridobj.model.ids = proxy._ids;
                        args.requestType = "outdent";
                        proxy._$treegridHelper.ejTreeGrid("processBindings", args);
                        var tempArgs = {};
                        tempArgs.requestType = ej.TreeGrid.Actions.Refresh;
                        proxy._$treegridHelper.ejTreeGrid("sendDataRenderingRequest", tempArgs);
                        proxy._updatedGanttRecords = proxy.getUpdatedRecords();
                        proxy._currentViewData = proxy.getCurrentViewData();

                        if (proxy.model.predecessorMapping) {
                            proxy._isValidationEnabled = false;
                            proxy._connectorlineIds = [];
                            proxy._connectorLinesCollection = [];
                            proxy._$ganttchartHelper.ejGanttChart("clearConnectorLines");
                            proxy._createConnectorLinesCollection();
                        }
                        proxy._$ganttchartHelper.ejGanttChart("refreshHelper", proxy._currentViewData, proxy._updatedGanttRecords, proxy._totalCollapseRecordCount);
                        proxy._$treegridHelper.ejTreeGrid("refreshHeight");
                        proxy.updateAltRow(proxy._updatedGanttRecords, 0, 1);

                        //   Making the outdented row as selected row 
                        var rowToindex = proxy._updatedGanttRecords.indexOf(data);
                        var $ganttChartRows = proxy.getGanttChartRows();
                        args = {
                            rowElement: $ganttChartRows.eq(rowToindex),
                            data: proxy.model.selectedItem,
                            recordIndex: rowToindex
                        };
                        proxy._$ganttchartHelper.ejGanttChart("selectRows", args.recordIndex);
                        proxy._$treegridHelper.ejTreeGrid("selectRows", args.recordIndex);
                        this.selectedItem(args.data);
                        this.selectedRowIndex(args.recordIndex);
                        proxy.updateIndentOutdentOption(data);
                        eveargs.data = data;
                        eveargs.requestType = "actionComplete";
                        this._trigger("actionComplete", eveargs);
                    }
                }
            }
        },
        
        _refreshChildLevel: function (ganttRecord) {

            var proxy = this,
                count = 0,
                childRecords = ganttRecord.childRecords,
                length = childRecords.length,
                record;

            for (count = 0; count < length; count++) {
                record = childRecords[count];                
                proxy.refreshGanttRecord(record);
                if (record.hasChildRecords) {
                    proxy._refreshChildLevel(record);
                }
            }
        },

        _updateChildLevel:function(ganttRecord) {

            var proxy = this,
                count = 0,
                childRecords = ganttRecord.childRecords,
                length = childRecords.length,
                record;
            
            for (count = 0; count < length; count++) {
                record = childRecords[count];                
                record.level = record.level - 1;
               // proxy.refreshGanttRecord(record);
                if (record.hasChildRecords) {
                    proxy._updateChildLevel(record);
                }
            }
        },

        _removeChildRecords:function(ganttRecord,index){

            if (ganttRecord.parentItem) {
                var proxy = this,
                    model = proxy.model,
                    childIndex = 0,
                    record,
                    addedChildGanttRecordCount = 0,
                    length = 0;
                parentChildRecords = ganttRecord.parentItem.childRecords,
                parentChildRecordsLength = parentChildRecords && parentChildRecords.length;

                for (childIndex = index; childIndex < parentChildRecordsLength; childIndex++) {

                    record = parentChildRecords[childIndex];


                    if (record) {

                        if (ganttRecord.childRecords) {

                            length = ganttRecord.childRecords.length;
                            ganttRecord.childRecords.splice(length, 0, record);
                            if (!model.parentTaskIdMapping)
                                ganttRecord.item[model.childMapping].splice(length, 0, record.item);
                            else
                                record.item[model.parentTaskIdMapping] = ganttRecord.taskId;
                        } else {
                            ganttRecord.childRecords = [];
                            ganttRecord.item[model.childMapping] = [];
                            ganttRecord.childRecords.push(record);
                            if (!model.parentTaskIdMapping)
                                ganttRecord.item[model.childMapping].push(record.item);
                            else
                                record.item[model.parentTaskIdMapping] = ganttRecord.taskId;
                        }
                        record.parentItem = ganttRecord;                                             
                        addedChildGanttRecordCount++;
                    }
                }

                if (ganttRecord.parentItem.childRecords) {

                    ganttRecord.parentItem.childRecords.splice(index, addedChildGanttRecordCount);
                    if(!model.parentTaskIdMapping)
                        ganttRecord.parentItem.item[model.childMapping].splice(index, addedChildGanttRecordCount);
                    if (ganttRecord.parentItem.childRecords.length == 0) {
                        ganttRecord.parentItem.childRecords = null;
                        ganttRecord.parentItem.expanded = false;
                        ganttRecord.parentItem.hasChildRecords = false;
                        proxy.refreshGanttRecord(ganttRecord.parentItem);
                    }
                }
            }
        },

        updateChildGanttRecordLevel: function (data,index) {
            var childIndex = 0, proxy = this, model = proxy.model,
                parentChildRecords = data.parentItem&& data.parentItem.parentItem&& data.parentItem.parentItem.childRecords,
                parentChildRecordsLength =parentChildRecords&&parentChildRecords.length,
                addedChildRecordCount = 0;
            for (childIndex = index; childIndex < parentChildRecordsLength; childIndex++) {
                var childGanttRecord = parentChildRecords[childIndex];
                if (childGanttRecord.childRecords) {
                    childGanttRecord.childRecords.splice(childGanttRecord.childRecords.length, 0, childGanttRecord);
                    childGanttRecord.item[model.childMapping].splice(childGanttRecord.childRecords.length, 0, childGanttRecord.item);
                }
                else {
                    childGanttRecord.childRecords = [];
                    childGanttRecord.item[model.childMapping] = [];
                    if (childGanttRecord) {
                        childGanttRecord.childRecords.push(childGanttRecord);
                        childGanttRecord.item[model.childMapping].push(childGanttRecord.item);
                    }
                }
                proxy.refreshGanttRecord(data.parentItem);
                data.parentItem = childGanttRecord;
                ++addedChildGanttRecordCount;
            }
            data.parentItem.childRecords.splice(index, addedChildGanttRecordCount);
            if (data.parentItem.childRecords.length == 0) {
                data.parentItem.childRecords = null;
                data.parentItem.expanded = false;
                data.parentItem.hasChildRecords = false;
            }

            proxy.refreshGanttRecord(data.parentItem);

        },

        updateLevel: function (childGanttRecord,offset) {
            var proxy = this,
                count = 0,
                childRecords = childGanttRecord.childRecords,
                length =childRecords&& childRecords.length,
                ganttRecord;
            for (count; count < length; count++) {
                ganttRecord = childRecords[count];
                ganttRecord.level += offset;
                proxy.refreshGanttRecord(ganttRecord);
                if (ganttRecord.childRecords) 
                    proxy.updateLevel(ganttRecord, offset);                
            }
        },

        addNewGanttRecord:function() {
            var proxy = this, eventArgs = {},newRecord;
            newRecord = this.model.ganttRecords[this.model.ganttRecords.length].item;
            eventArgs.requestType = "save";
            eventArgs._cAddedRecord = jQuery.extend(true, {}, newRecord);
            eventArgs.recordIndex = index + 1;
            proxy.subContextMenuAction(eventArgs);
            proxy._clearContextMenu();
        },
        getExpandStatus: function (record) {

            var parentRecord = record.parentItem;

            if (parentRecord != null) {

                if (parentRecord.expanded === false) {
                    return false;
                } else if (parentRecord.parentItem) {

                    if (parentRecord.parentItem.expanded === false) {
                        return false;
                    } else {
                        return this.getExpandStatus(parentRecord.parentItem);
                    }

                } else return true;
            } else return true;
        },
        subContextMenuAction: function (args) {
            var proxy = this, eventArgs = {}, model = proxy.model, selectionIndex;
            proxy._updatedGanttRecords = proxy.getUpdatedRecords();
            proxy._currentViewData = proxy.getCurrentViewData();
            proxy._gridRows = proxy.getRows();
            proxy._ganttChartRows = proxy.getGanttChartRows();
            if (args.requestType === "save") {

                if (args._cAddedRecord) {

                    eventArgs.selectedItem = model.selectedItem;

                    args._cAddedRecord.predecessor = null;
                    if (proxy.model.predecessorMapping)
                    args._cAddedRecord.item[model.predecessorMapping] = null;//args._cAddedRecord.item.Predecessor

                    eventArgs.data = args._cAddedRecord.item;
                    if (eventArgs.data.duration === 0)
                    {
                        eventArgs.data.duration = 1;
                    }
                    eventArgs.requestType = ej.TreeGrid.Actions.Save;
                    eventArgs.recordIndex = args.recordIndex;

                    eventArgs._cAddedRecord = proxy._createGanttRecord(eventArgs.data, args._cAddedRecord.level, null);//level
                    eventArgs._cAddedRecord.taskId = proxy._getNewTaskId(eventArgs._cAddedRecord.taskId);
                    var index = proxy._ids.indexOf(eventArgs._cAddedRecord.taskId.toString());
                    proxy._ids.splice(index,1);

                    if(model.taskIdMapping)
                    eventArgs._cAddedRecord.item[model.taskIdMapping] = eventArgs._cAddedRecord.taskId;
                    eventArgs._cAddedRecord.taskName = "New Task " + eventArgs._cAddedRecord.taskId;
                    if (model.taskNameMapping)
                    eventArgs._cAddedRecord.item[model.taskNameMapping] = "New Task " + eventArgs._cAddedRecord.taskId;
                    eventArgs._cAddedRecord.item[model.childMapping] = null;

                    if (args._cAddedRecord.hasChildRecords && args.position==="Below" ) { 
                        eventArgs._cAddedRecord.parentItem = model.selectedItem;
                        eventArgs._cAddedRecord.level = model.selectedItem.level + 1;
                        eventArgs._cAddedRecord.expanded = false;
                    }
                    else if (args._cAddedRecord.hasChildRecords && args.position === "Above") {

                        if (args._cAddedRecord.parentItem)
                        {
                            eventArgs._cAddedRecord.parentItem = args._cAddedRecord.parentItem;
                            eventArgs._cAddedRecord.level = args._cAddedRecord.parentItem.level + 1;
                            eventArgs._cAddedRecord.expanded = false;
                        }
                        else
                        {
                            eventArgs._cAddedRecord.parentItem = null;
                            eventArgs._cAddedRecord.expanded = false;
                        }
                        
                    }
                    else if (!args._cAddedRecord.hasChildRecords && args._cAddedRecord.parentItem) {
                        eventArgs._cAddedRecord.parentItem = args._cAddedRecord.parentItem;
                        eventArgs._cAddedRecord.level = args._cAddedRecord.parentItem.level + 1;
                        eventArgs._cAddedRecord.expanded = false;
                    }
                    else
                    {
                        eventArgs._cAddedRecord.parentItem = null;

                    }
                    //if (eventArgs._cAddedRecord.parentItem && !model.enableVirtualization)
                    //{
                    //    eventArgs._cAddedRecord.isExpanded = eventArgs._cAddedRecord.parentItem.expanded;
                    //}




                    //if (args._cAddedRecord.parentItem) {
                    //    eventArgs._cAddedRecord.parentItem = args._cAddedRecord.parentItem;
                    //    eventArgs._cAddedRecord.parentItem.childRecords.push(eventArgs._cAddedRecord);
                    //}
                    eventArgs._cAddedRecord.hasChildRecords = false;
                    eventArgs._cAddedRecord.childRecords = null;
                    eventArgs._cAddedRecord.index = args.recordIndex;
                    eventArgs._cAddedRecord.isAltRow = (eventArgs._cAddedRecord.index+1) % 2 == 0 ? false : true;
                    eventArgs.actionRequestType = ej.TreeGrid.Actions.ContextMenuAdd;
                    eventArgs.position = args.position;

                    if (!model.enableVirtualization) {
                        eventArgs._cAddedRecord.isExpanded = proxy.getExpandStatus(eventArgs._cAddedRecord);
                        if (!eventArgs._cAddedRecord.isExpanded) {
                            proxy._totalCollapseRecordCount += 1;
                        }
                    }

                    proxy.actionComplete(eventArgs);

                    //proxy._$treegridHelper.ejTreeGrid("renderInitialRecord", eventArgs);
                    //proxy._$treegridHelper.ejTreeGrid("renderRecords", eventArgs);

                    //proxy._$ganttchartHelper.ejGanttChart("reRenderGanttGridLinesTable", 1);
                }
            }
            //proxy._connectorlineIds = [];
            //proxy._connectorLinesCollection = [];
            //proxy._$ganttchartHelper.ejGanttChart("clearConnectorLines");
            //proxy._createConnectorLinesCollection();
            //proxy._ganttActionCompleteTrigger(args);
            selectionIndex = proxy._updatedGanttRecords.indexOf(model.selectedItem);
            //if (args.recordIndex != 0 && eventArgs._cAddedRecord.isExpanded)
            //    selectionIndex = args.recordIndex + 1;
            //else
            //    selectionIndex = args.recordIndex;
            proxy._$treegridHelper.ejTreeGrid("selectRows", selectionIndex);
            proxy._$ganttchartHelper.ejGanttChart("selectRows", selectionIndex);
        },

        _getNewTaskId: function (taskId) {
            var proxy = this, tempTaskId;
            if (proxy._ids.indexOf(taskId.toString()) == -1) {
                              proxy._ids.push(taskId.toString());
                                return taskId;
            } else {
                taskId++;
                tempTaskId = proxy._getNewTaskId(taskId);
                return tempTaskId;
            }
        },

        _getNewTaskIdFordialogEdit: function (taskId) {
            var proxy = this, tempTaskId;
            if (proxy._ids.indexOf(taskId.toString()) == -1) {              
                return taskId == 0 ? 1 : taskId;
            } else {
                taskId++;
                tempTaskId = proxy._getNewTaskIdFordialogEdit(taskId);
                return tempTaskId;
            }
        },
        _updateNewTaskId: function () {
            var proxy = this, model = proxy.model;
            proxy._ids = [];
            $.each(proxy._rows, function (index, value) {
                if (value && value.taskId)
                    proxy._ids.push(value.taskId.toString());
            });
        },
        contextMenuAction: function (args) {
            var proxy = this;
            if (args.requestType == "contextMenuAdd")
                proxy._sendAddRequest();
            if (args.requestType == "contextMenuIndent")
                proxy._sendIndentRequest();
            if (args.requestType == "contextMenuOutdent")
                proxy._sendOutdentRequest();
            if (args.requestType == "contextMenuDelete")
                proxy._$treegridHelper.ejTreeGrid("deleteRow");
            if (args.requestType == "contextMenuTaskDetails")
                proxy._sendEditRequest();
        },

        _renderContextMenu: function (e, index, item) {

            var proxy = this,
                eventArgs = {},
                args = {},
                posx,
				subposx,
                posy,
                contextMenu,
                contextMenuUList,
                subContextMenu,
                subContextMenuUList;
            //Initialize the contextmenu item to avoid duplicates
            //proxy._contextMenuItems = proxy._getContextMenuItems();
            //proxy._subContextMenuItems = proxy._getsubContextMenuItems();
            if (!e) e = window.event;
            if (e.pageX || e.pageY) {
                subposx = posx = e.pageX;
                posy = e.pageY;
            } else if (e.clientX || e.clientY) {
                subposx = posx = e.clientX + document.body.scrollLeft
                    + document.documentElement.scrollLeft;
                posy = e.clientY + document.body.scrollTop
                    + document.documentElement.scrollTop;
            }
            if ($(window).width() < posx + 150) {
                posx = posx - 150;
                subposx = posx - 122;
            }
            else
                subposx = subposx + 152;
            if ($(window).height() < posy + (25*proxy._contextMenuItems.length))
                posy = posy - (25 * proxy._contextMenuItems.length);
            args.requestType = "ContextMenuOpen";
            args.contextMenuItems = proxy._contextMenuItems;
            args.innerContextMenuItems = proxy._subContextMenuItems;
            proxy._trigger("contextMenuOpen", args);
            contextMenu = ej.buildTag("div.e-contextmenu", "", {
                'height': 'auto',
                'width': '150px',
                'position': 'absolute',
                'left': posx + 'px',
                'top': posy + 'px',
                'background-color': '#F0F0F0',
                'border': '1px solid #99bce8',
                'z-index': '10',
            }, {});

            contextMenuUList = ej.buildTag("ul", $.render[proxy._id + "contextMenuTemplate"](args.contextMenuItems), {
                'height': 'auto',
                'width': 'auto',
                'top': '0px',
                'display': 'inline'
            }, {
                'data-icon': false,
                'type': 'none',
                'data-role': 'list-divider'
            });

            subContextMenu = ej.buildTag("div.e-innerContextmenu", "", {
                'height': 'auto',
                'width': '120px',
                'position': 'absolute',
                'left': subposx + 'px',
                'top': (posy + 30) + 'px',
                'background-color': '#F0F0F0',
                'border': '1px solid #99bce8',
                'z-index': '10',
                'visibility': 'hidden',
            }, {});

            subContextMenuUList = ej.buildTag("ul", $.render[proxy._id + "subContextMenuTemplate"](args.innerContextMenuItems), {
                'height': 'auto',
                'width': 'auto',
                'top': '0px',
                'display': 'inline'
            }, {
                'data-icon': false,
                'type': 'none',
                'data-role': 'list-divider'
            });
            contextMenu.append(contextMenuUList);
            $(document.body).append(contextMenu);

            if (args.innerContextMenuItems.length > 0) {
                subContextMenu.append(subContextMenuUList);
                $(document.body).append(subContextMenu);
            }
         


            $(contextMenu).css({ 'height': 'auto' });
            proxy._on(contextMenu, "contextmenu", function (argsE) {
                argsE.preventDefault();
            });

            //click event handlers for contextmenu items and subcontextmenu items

                $('.e-menuitem').click(function () { 
                    var choice = $(this).attr('id');
                    switch (choice) {
                        case "Task":
                            eventArgs.requestType = "contextMenuTaskDetails";
                            proxy.contextMenuAction(eventArgs);
                            proxy._clearContextMenu();
                            break;
                        case "Indent": eventArgs.requestType = "contextMenuIndent";
                            proxy.contextMenuAction(eventArgs);
                            proxy._clearContextMenu();
                            break;
                        case "Outdent": eventArgs.requestType = "contextMenuOutdent";
                            proxy.contextMenuAction(eventArgs);
                            proxy._clearContextMenu();
                            break;
                        case "Delete": eventArgs.requestType = "contextMenuDelete";
                            proxy.contextMenuAction(eventArgs);
                            proxy._clearContextMenu();
                            break;
                        case "Above": eventArgs.requestType = "save";
                            eventArgs._cAddedRecord = jQuery.extend(true, {}, item);
                            eventArgs.recordIndex = index == 0 ? 0 : index;
                            eventArgs.position = "Above";
                            proxy.subContextMenuAction(eventArgs);
                            proxy._clearContextMenu();
                            break;
                        case "Below": eventArgs.requestType = "save";
                            eventArgs._cAddedRecord = jQuery.extend(true, {}, item);
                            eventArgs.recordIndex = index;
                            eventArgs.position = "Below";
                            proxy.subContextMenuAction(eventArgs);
                            proxy._clearContextMenu();
                            break;
                        case "Open":
                            eventArgs.requestType = "contextMenuAdd";
                            proxy.contextMenuAction(eventArgs);
                            proxy._clearContextMenu();
                            break;
                        case "Add":
                            proxy._setInitialData();
                            break;
                        default:
                            proxy._clearContextMenu();
                            break;
                    }
                });
            //Mouseenter and mouse leave handler for contextmenu items and Subcontextmenuitems
                $(".e-menuitem").mouseenter(function () {
                    $(this).addClass("e-contextmenu-mouseover");
                    if ($(this).attr('id') == "Add" || $(this).attr('id') == "Above" || $(this).attr('id') == "Below" || $(this).attr('id') == "Open") {
                        $('.e-innerContextmenu').css({ 'visibility': 'visible' });
                        $('#Add').addClass("e-contextmenu-mouseover");
                    }
                    else {
                        $('.e-innerContextmenu').css({ 'visibility': 'hidden' });
                    }
                });
                $(".e-menuitem").mouseleave(function () {
                    $(this).removeClass("e-contextmenu-mouseover");
                });
            e.preventDefault();
        },

        _setInitialData: function () {
            var eventArgs = {}, proxy = this,
                model = proxy.model, data = [], item, initialData = {};
            proxy._ids = [];
            initialData[model.startDateMapping] = model.scheduleStartDate ? model.scheduleStartDate : null;
            initialData[model.durationMapping] = 5;
            initialData[model.taskNameMapping] = "New Task 1";
            initialData[model.taskIdMapping] = "1";
            data.push(initialData);

            if (proxy.dataSource()==null || proxy.dataSource().length == 0) {
                //proxy._createGanttRecords(data);
                item = proxy._createGanttRecord(data[0], 0, null);
                item.index = 0;
                eventArgs.requestType = "save";
                eventArgs._cAddedRecord = jQuery.extend(true, {}, item);
                eventArgs.recordIndex = 0;
                proxy.actionComplete(eventArgs);
                proxy._clearContextMenu();
            }
        },

        sendExpandCollapseRequest: function (args) {
            
            var proxy = this,
                ganttRecord = args.data,
                model = proxy.model,
                index = proxy._currentViewData.indexOf(ganttRecord),
                $row = $($(proxy._gridRows)[index]),
                height = 0,
                isModified = ganttRecord.expanded !== args.expanded;
           
            if (args.expanded) {
                ganttRecord.expanded = args.expanded;
                proxy._expandedRecordsCount = 0;
                proxy.expandGanttRecord(ganttRecord, args.expanded, args);
                if (isModified)
                    proxy._totalCollapseRecordCount -= proxy._expandedRecordsCount;
                //$row.find(".e-treegridcollapse").removeClass('e-treegridcollapse').addClass('e-treegridexpand');
                //$row.removeClass('e-treegridrowcollapse').addClass('e-treegridrowexpand');                
                if (model.enableAltRow)
                    proxy.updateAltRow(ganttRecord, index, 1);
                
            }
            else {
                proxy._collapsedRecordCount = 0;
                proxy.collapseGanttRecord(ganttRecord, args.expanded);
                if (isModified)
                    proxy._totalCollapseRecordCount += proxy._collapsedRecordCount;
                ganttRecord.expanded = args.expanded;
                $row.find(".e-treegridexpand").removeClass('e-treegridexpand').addClass('e-treegridcollapse');
                $row.removeClass('e-treegridrowexpand').addClass('e-treegridrowcollapse');               
                    
                if (model.enableAltRow)
                    proxy.updateAltRow(ganttRecord, index, proxy._collapsedRecordCount + 1);                
            }
            height = (proxy._updatedGanttRecords.length - proxy._totalCollapseRecordCount) * model.rowHeight;
            proxy._$ganttchart.ejGanttChart("updateHeight", height);
            if (args.expanded)
                proxy._trigger("expanded", args);
            else
                proxy._trigger("collapsed", args);
        },

        expandGanttRecord: function (ganttRecord, expanded, args) {
            
            var proxy = this,
                rowClassName = ".gridrowtaskId" + ganttRecord.taskId.toString() + "level" + (ganttRecord.level + 1).toString(),
                $rows = $(rowClassName),
                count = 0,
                length = $rows.length,
                row,
                index,
                record,
                $expandedRows = $(rowClassName),
                index = proxy._currentViewData.indexOf(ganttRecord),
                $row = $($(proxy._gridRows)[index]);

            if (ganttRecord.hasChildRecords && ganttRecord.childRecords.length > 0) {
                $row.find(".e-treegridcollapse").removeClass('e-treegridcollapse').addClass('e-treegridexpand');
                $row.removeClass('e-treegridrowcollapse').addClass('e-treegridrowexpand');
            }
          
            proxy._expandedRecordsCount += $expandedRows.length / 2;
            if ($expandedRows.length === 0) {
                if (proxy.model.allowSearching && proxy._searchString.length>0) {
                    args && proxy._$treegridHelper.ejTreeGrid("sendExpandCollapseRequest", args);
                }
            }

            $expandedRows.css({ 'display': 'table-row' });
            proxy.updateConnectorLines($expandedRows, expanded);
            for (count; count < length / 2; count++) {
                row = $rows[count];
                index = $(proxy._gridRows).index(row);
                if (index !== -1) {
                    record = proxy._updatedGanttRecords[index];
                    record.isExpanded = true;
                    if (record.expanded)
                        proxy.expandGanttRecord(record, expanded);
                }
            }
        },

        updateConnectorLines: function ($gridRows, expanded) {
            var proxy = this,
                length = $gridRows.length / 2,
                count = 0,
                row,
                index,
                record;
            
            for (count = 0; count < length; count++) {
                row = $gridRows[count];
                index = $(proxy._gridRows).index(row);
                if (index !== -1) {
                    record = proxy._currentViewData[index];
                    record.isExpanded = expanded;                  
                }
            }
            proxy._connectorlineIds = [];
            proxy._connectorLinesCollection = [];
            proxy._$ganttchartHelper.ejGanttChart("clearConnectorLines");
            proxy._createConnectorLinesCollection();            
        },

        collapseGanttRecord: function (ganttRecord, expanded) {
            var proxy = this,
                rowClassName = ".gridrowtaskId" + ganttRecord.taskId.toString() + "level" + (ganttRecord.level + 1).toString(),
                $rows = $(rowClassName),
                count = 0,
                length = $rows.length,
                row,
                index,
                record,
                $collapsedRows = $(rowClassName);
            proxy._collapsedRecordCount += $collapsedRows.length / 2;
            $collapsedRows.css({ 'display': 'none' });

            proxy.updateConnectorLines($collapsedRows, expanded);

            for (count; count < length / 2; count++) {
                row = $rows[count];
                index = $(proxy._gridRows).index(row);
                //if (index === -1) {
                //    index = $(proxy._ganttChartRows).index($rows[count + $collapsedRows.length / 2]);
                //    $(row).addClass('e-hide');
                //}
                if (index !== -1) {
                    record = proxy.getUpdatedRecords()[index];
                    if (record.expanded)
                        proxy.collapseGanttRecord(record, expanded);
                }
            }
        },

        updateAltRow: function (ganttRecord, recordIndex, offset) {
            var proxy = this,
                count = 0,
                currentViewData = proxy._currentViewData,
                length = currentViewData.length,
                isAltRow = ganttRecord.isAltRow,
                record,
                $gridRows = $(proxy._gridRows);
            for (count = recordIndex + offset; count < length; count++) {
                if ($($gridRows[count]).css('display') === "none")
                    continue;
                record = currentViewData[count];
                record.isAltRow = !isAltRow;
                isAltRow = record.isAltRow;
                if (isAltRow)
                    $($gridRows[count]).addClass('e-alt-row');
                else
                    $($gridRows[count]).removeClass('e-alt-row');
            }
        },
        renderedEditDialog: function (args) {
            var proxy = this;
            switch (args.requestType) {
                case ej.TreeGrid.Actions.Add:
                    var temp = document.createElement('div');
                    $(temp).addClass("e-addedrow");
                    temp.innerHTML = $.render[proxy._id + "_JSONDialogAddingTemplate"](args.data);
                    $("#" + proxy._id + "_dialogAdd").html($(temp));
                    var evntArgs = {};
                    evntArgs.cssClass = this.model.cssClass,
                    evntArgs.enableModal = true,
                    evntArgs.width = "auto",
                    evntArgs.enableResize = false,
                    evntArgs.contentSelector = "#" + proxy._id,
                    evntArgs.rtl = proxy.model.rtl,
                    evntArgs.allowKeyboardNavigation = false,
                    title = proxy._editDialogTexts["addFormTitle"];
                    evntArgs.title = title;
                    $("#" + proxy._id + "_dialogAdd").ejDialog(evntArgs);
                    $("#" + proxy._id + "_dialogAdd").ejDialog("open");
                    proxy._editedDialogRecord = null;
                    break;
                case ej.TreeGrid.Actions.BeginEdit:
                    temp = document.createElement('div');
                    $(temp).addClass("e-editedrow");
                    temp.innerHTML = $.render[proxy._id + "_JSONDialogEditingTemplate"](args.data);
                    $("#" + proxy._id + "_dialogEdit").html($(temp));
                    var evntArgs = {};
                    evntArgs.cssClass = proxy.model.cssClass;
                    evntArgs.rtl = model.rtl;
                    evntArgs.width = "auto";
                    evntArgs.enableResize = false;
                    evntArgs.contentSelector = "#" + proxy._id;
                    evntArgs.enableModal = true;
                    evntArgs.allowKeyboardNavigation = false;
                    var title = proxy._editDialogTexts["editFormTitle"] + " " + proxy.selectedItem()["taskName"];
                    evntArgs.title = title;
                    $("#" + proxy._id + "_dialogEdit").ejDialog(evntArgs);
                    $("#" + proxy._id + "_dialogEdit").ejDialog("open");
                    proxy._editedDialogRecord=jQuery.extend(true, {}, this.selectedItem());
                    break;                    
            }
            proxy._refreshEditForm(args);
            //proxy.setValidation();
        },

        editFormValidate: function () {
            if ($.isFunction($.validator))
                return $("#" + this._id + "EditForm").validate().form();
            return true;
        },

        addFormValidate: function () {
            if ($.isFunction($.validator))
                return $("#" + this._id + "AddForm").validate().form();
            return true;
        },
        getCurrentData: function () {
            var proxy = this,
                updatedRecords = proxy.getUpdatedRecords();
            return updatedRecords && updatedRecords[this.selectedRowIndex()];
        },

        getCurrentViewData: function () {
            return this._$treegridHelper.ejTreeGrid("getCurrentViewData");
        },

        getUpdatedCurrentViewData: function () {
            return this._$treegridHelper.ejTreeGrid("getUpdatedCurrentViewData");
        },

        getRows: function () {
            return this._$treegridHelper.ejTreeGrid("getRows");
        },
        
        getGanttChartRows: function() {
            return this._$ganttchartHelper.ejGanttChart("getGanttChartRows");
        },

        getUpdatedRecords: function () {
            return this._$treegridHelper.ejTreeGrid("getUpdatedRecords");
        },

        _getToolBarHeight: function () {
            var toolbarH = 0;
            if (this.model.toolbarSettings.showToolbar) {
                toolbarH = $(".e-gantttoolbar").height();
            }
            return toolbarH;
        },

        _initValidator: function () {
            var gridObject = this;
            $("#" + this._id + "EditForm").validate({
                errorClass: 'e-field-validation-error',
                errorElement: 'div',
                wrapper: "div",
                errorPlacement: function (error, element) {
                    var $td = element.closest("td"), $container = $(error).addClass("e-error")
                    , $tail = ej.buildTag("div.e-errortail e-toparrow");
                    $td.find(".e-error").remove();
                    element.hasClass("e-numerictextbox") ? $container.insertAfter(element.closest(".e-numeric")) : $container.insertAfter(element);
                    $container.prepend($tail);
                    gridObject.model.editSettings.editMode != "normal" && $container.offset({ left: element.offset().left });
                    $container.fadeIn("slow");
                },

            });
        },

        setValidation: function () {
            this._initValidator();
            for (var i = 0; i < this._columns.length; i++) {
                if (!ej.isNullOrUndefined(this._columns[i]["validationRules"])) {
                    this.setValidationToField(this._columns[i].field, this._columns[i].validationRules);
                }
            }
        },

        setValidationToField: function (name, rules) {
            var ele = $("#" + this._id + name).length > 0 ? $("#" + this._id + name) : $("#" + name);
            ele.rules("add", rules);
            var validator = $("#" + this._id + "EditForm").validate();
            if (!ej.isNullOrUndefined(rules["required"])) {
                validator.settings.messages["Name"] = {};
                validator.settings.messages["Name"]["required"] = ej.TreeGrid.getColumnByField(proxy._columns, name).headerText + " is required";
            }
        },

        _createConnectorLinesCollection: function (args) {

            var proxy = this,
                recordLength = proxy._currentViewData.length,
                count,
                prdecessorIndex = -1,
                predecessorsCollection,
                ganttRecord,
                connectorLinesCollection = proxy._predecessorsCollection,
                connectorLinesLength = connectorLinesCollection.length,
                x = connectorLinesLength / 2,
                connectorLinesCount,
                enableVirtualization = proxy.model.enableVirtualization,
                record;


            if (model.enableVirtualization && args === "Load") {
                //THis is done for validate all the record during load time
                recordLength = proxy._updatedGanttRecords.length;
                for (count = 0; count < recordLength; count++) {
                    ganttRecord = proxy._updatedGanttRecords[count];
                        predecessorsCollection = ganttRecord["predecessor"];
                        if (predecessorsCollection) {
                            record = ganttRecord;
                            proxy._addPredecessorsCollection(ganttRecord, predecessorsCollection);
                        }
                }
            }
            else {

                for (count = 0; count < recordLength; count++) {
                    ganttRecord = proxy._currentViewData[count];
                    if (enableVirtualization === false && ganttRecord.isExpanded === false)
                        continue;
                    if (proxy._currentViewData.indexOf(ganttRecord) !== -1) {
                        predecessorsCollection = ganttRecord["predecessor"];
                        if (predecessorsCollection) {
                            record = ganttRecord;
                            proxy._addPredecessorsCollection(ganttRecord, predecessorsCollection);
                        }
                    }
                }

            }

            if (proxy._connectorLinesCollection.length > 0) {

                proxy._$ganttchartHelper && proxy._$ganttchartHelper.ejGanttChart("renderConnectorLines", proxy._connectorLinesCollection);

            }
        },

        _addPredecessorsCollection: function (ganttRecord, predecessorsCollection) {
            var proxy = this,
                predecessorsLength,
                predecessorCount,
                predecessor,
                parentGanttRecord,
                childGanttRecord,
                model = proxy.model,
                connectorObj = {},
                predecessorValue = [];
            if (predecessorsCollection) {

                predecessorsLength = predecessorsCollection.length;

                for (predecessorCount = 0; predecessorCount < predecessorsLength; predecessorCount++) {

                    predecessor = predecessorsCollection[predecessorCount];


                        parentGanttRecord = proxy._rows[proxy._ids.indexOf(predecessor.from)];  
                        childGanttRecord = proxy._rows[proxy._ids.indexOf(predecessor.to)];  

                        if (!model.enableVirtualization) {
                            if ((parentGanttRecord && parentGanttRecord.isExpanded === false) || 
                                (childGanttRecord && childGanttRecord.isExpanded === false))
                                continue;
                        }

                        if (proxy._isValidationEnabled && !proxy._isInExpandCollapse && childGanttRecord)
                            proxy._validateChildGanttRecord(parentGanttRecord, childGanttRecord, predecessor);
                }

                //for calculate auto schedule only validation is enough  
                if (!proxy._enableCreateCollection)
                    return;

				// for correct re draw the alreadey created line in multiple predecessor for same task
                var count = 0;
                 $.each(predecessorsCollection, function (inx, value) {

                    if (value.to === ganttRecord.taskId.toString()) {
                        count++;
                    }
                    return count;
                });
				
				
				
                    for (predecessorCount = 0; predecessorCount < predecessorsLength; predecessorCount++) {

                        predecessor = predecessorsCollection[predecessorCount];
						if (count > 1)
                        {
                            predecessor.isdrawn = false;
                        }
						
                        //if (predecessor.isdrawn) {
                        //    predecessor.isdrawn = false;
                        //}
                        //else {

                            parentGanttRecord = proxy._rows[proxy._ids.indexOf(predecessor.from)];
                            childGanttRecord = proxy._rows[proxy._ids.indexOf(predecessor.to)];

                            if (proxy._updatedGanttRecords.indexOf(parentGanttRecord) === -1 || proxy._updatedGanttRecords.indexOf(childGanttRecord) == -1)
                                continue;

                            if (!model.enableVirtualization) {
                                if (parentGanttRecord.isExpanded === false || childGanttRecord.isExpanded === false)
                                    continue;
                            }

                            //if (proxy._isValidationEnabled && !proxy._isInExpandCollapse)
                            //    proxy._validateChildGanttRecord(parentGanttRecord, childGanttRecord, predecessor);

                        if (parentGanttRecord && childGanttRecord) {

                            connectorObj = proxy._createConnectorLineObject(parentGanttRecord, childGanttRecord, predecessor);
                          
                            if (connectorObj) {

                                if (proxy._connectorlineIds.length > 0 && proxy._connectorlineIds.indexOf(connectorObj.ConnectorLineId) == -1) {

                                    proxy._connectorLinesCollection.push(connectorObj);
                                    proxy._connectorlineIds.push(connectorObj.ConnectorLineId);
                                }
                                else if (proxy._connectorlineIds.length == 0) {
                                    proxy._connectorLinesCollection.push(connectorObj);
                                    proxy._connectorlineIds.push(connectorObj.ConnectorLineId);
                                }
                                else if (proxy._connectorlineIds.indexOf(connectorObj.ConnectorLineId) != -1) {
                                    var index = proxy._connectorlineIds.indexOf(connectorObj.ConnectorLineId);
                                    proxy._connectorLinesCollection[index] = connectorObj;
                                }
                                predecessor.isdrawn = true;
                            }
                        }
                   // }
                }

            }
          
        },

        _createConnectorLineObject: function (parentGanttRecord, childGanttRecord, predecessor) {
            var connectorObj = {},
                proxy = this,
                model = proxy.model,
                parentTop,
                childTop,
                parentIndex = proxy._updatedGanttRecords.indexOf(parentGanttRecord),
                childIndex = proxy._updatedGanttRecords.indexOf(childGanttRecord),
                count = 0,
                index = 0;
            
            if (parentIndex === -1 || childIndex === -1){
                return;
            }
            if (!model.enableVirtualization) {
                var collapsedCount = 0;
                if (childIndex > parentIndex) {
                    
                    for (count = 0; count < parentIndex; count++) {
                        if (proxy._updatedGanttRecords[count].isExpanded===false)
                            ++collapsedCount;
                    }
                    index = parentIndex;
                    parentIndex -= collapsedCount;
                    
                    for (index; index < childIndex; index++) {
                        if (proxy._updatedGanttRecords[index].isExpanded === false)
                            ++collapsedCount;
                    }
                    childIndex -= collapsedCount;
                }
                else if (parentIndex > childIndex) {
                    for (count = 0; count < childIndex; count++) {
                        if (proxy._updatedGanttRecords[count].isExpanded === false)
                            ++collapsedCount;
                    }
                    index = childIndex;
                    childIndex -= collapsedCount;
                    
                    for (index ; index < parentIndex; index++) {
                        if (proxy._updatedGanttRecords[index].isExpanded === false)
                            ++collapsedCount;
                    }
                    parentIndex -= collapsedCount;
                }
            }

            if (parentIndex != -1 && childIndex != -1) {
                parentTop = parentIndex * model.rowHeight;
                childTop = childIndex * model.rowHeight;
                connectorObj["ParentLeft"] = parentGanttRecord['left'];
                connectorObj["ChildLeft"] = childGanttRecord['left'];
                connectorObj["ParentWidth"] = parentGanttRecord['width'] == 0 ? 26 : parentGanttRecord['width'];
                connectorObj["ChildWidth"] = childGanttRecord['width'] == 0 ? 26 : childGanttRecord['width'];
                connectorObj["ParentTop"] = parentTop;
                connectorObj["ChildTop"] = childTop;
                connectorObj["Height"] = parentTop > childTop ? parentTop - childTop : childTop - parentTop;
                connectorObj["Type"] = predecessor.predecessorsType;
                connectorObj["ConnectorLineId"] = "parent"+ parentGanttRecord['taskId'] + "child" + childGanttRecord['taskId'];                
                connectorObj["milestoneParent"] = parentGanttRecord.isMilestone ? true : false;
                connectorObj["milestoneChild"] = childGanttRecord.isMilestone ? true : false;
                
                return connectorObj;
            }
        },

        //Validate the child Gantt Record

        _validateChildGanttRecord: function (parentGanttRecord, childGanttRecord, predecessor) {
            var proxy = this,
                model = proxy.model,
                childStartDate,
                parentStartDate,
                childEndDate,
                parentEndDate,
                offset,holiday
                predecessorOffset = 0;
                predecessorOffset = predecessor.offset ? parseInt(predecessor.offset) : 0;

                if (proxy._editedTaskBarItem === childGanttRecord)
                {
                    return;
                }
            switch (predecessor.predecessorsType) {

                case 'SS':

                    parentStartDate = proxy._getDateFromFormat(parentGanttRecord.startDate);
                    childStartDate = proxy._getDateFromFormat(childGanttRecord.startDate);

                        if (childGanttRecord.isMilestone) {
                            parentStartDate.setDate(parentStartDate.getDate() - 1);
                        }

                        if (proxy.model.includeWeekend === false) {
                            proxy._setBeforeWeekend(parentStartDate);
                        }

                        if (predecessorOffset) {

                            parentStartDate.setDate(parentStartDate.getDate() + (Math.floor(predecessorOffset)));

                            if (proxy.model.includeWeekend === false) {

                                if (predecessorOffset < 0) {
                                    proxy._setBeforeWeekend(parentStartDate);
                                }

                                if (predecessorOffset > 0) {
                                    proxy._setAfterWeekend(parentStartDate);
                                }
                            }
                        }

                        if (proxy._stringHolidays &&
                          proxy._stringHolidays.indexOf(childGanttRecord._getFormatedDate(parentStartDate, model.dateFormat)) != -1) {
                            parentStartDate.setDate(parentStartDate.getDate() + 1);
                        }

                        childGanttRecord.startDate = childGanttRecord._getFormatedDate(parentStartDate, model.dateFormat);

                            var currentTaskId = childGanttRecord['taskId'].toString(),
                                 predecessorsCollection = childGanttRecord['predecessor'],
                               childPredecessor = predecessorsCollection.filter(function (data) { return data.to === currentTaskId });

                            if (childPredecessor.length > 1) {

                                var minStartDate = proxy._getPredecessorDate(childGanttRecord, childPredecessor, predecessor.predecessorsType);


                                if (childGanttRecord.isMilestone) {
                                    minStartDate.setDate(minStartDate.getDate() - 1);
                                }

                                if (model.includeWeekend === false) {
                                    proxy._setBeforeWeekend(minStartDate);
                                }
                                childGanttRecord.startDate = childGanttRecord._getFormatedDate(minStartDate, model.dateFormat);

                            }
                            childGanttRecord.left = childGanttRecord._calculateLeft(proxy._projectStartDate,
                                    proxy._perDayWidth, proxy._holidaysList, model);
                        childGanttRecord.width = childGanttRecord._calculateWidth(proxy._perDayWidth, proxy._holidaysList, model);
                    break;

                case 'SF':

                    parentStartDate = proxy._getDateFromFormat(parentGanttRecord.startDate);
                    childEndDate = proxy._getDateFromFormat(childGanttRecord.endDate);                    

                        parentStartDate.setDate(parentStartDate.getDate() - 1);

                        if (proxy.model.includeWeekend === false) {
                            proxy._setBeforeWeekend(parentStartDate);
                        }

                        if (predecessorOffset) {

                            parentStartDate.setDate(parentStartDate.getDate() + (Math.floor(predecessorOffset)));

                            if (proxy.model.includeWeekend === false) {

                                if (predecessorOffset < 0) {
                                    proxy._setBeforeWeekend(parentStartDate);
                                }

                                if (predecessorOffset > 0) {
                                    proxy._setAfterWeekend(parentStartDate);
                                }
                            }
                        }


                        if (proxy._stringHolidays &&
                            proxy._stringHolidays.indexOf(childGanttRecord._getFormatedDate(parentStartDate, model.dateFormat)) != -1) {
                            parentStartDate.setDate(parentStartDate.getDate() + 1);
                        }

                        childGanttRecord.endDate = childGanttRecord._getFormatedDate(parentStartDate, model.dateFormat);

                        if (childGanttRecord.isMilestone)
                            childGanttRecord.startDate = childGanttRecord._getFormatedDate(parentStartDate, model.dateFormat);
                        else
                        {
                            var tempEndDate = proxy._getDateFromFormat(childGanttRecord.endDate);
                            for(var i=0;i<childGanttRecord.duration-1;i++)
                            {
                                tempEndDate.setDate(tempEndDate.getDate() - 1);
                                if (proxy.model.includeWeekend === false) {
                                    if (predecessorOffset < 0) {
                                        proxy._setBeforeWeekend(tempEndDate);
                                    }
                                }
                                tempEndDate=proxy._onHoliDayCheckBefore(tempEndDate);
                            }
                            childGanttRecord.startDate = childGanttRecord._getFormatedDate(tempEndDate, model.dateFormat);
                        }
                            var currentTaskId = childGanttRecord['taskId'].toString(),
                                       predecessorsCollection = childGanttRecord['predecessor'],
                                     childPredecessor = predecessorsCollection.filter(function (data) { return data.to === currentTaskId });

                            if (childPredecessor.length > 0) {

                                var minStartDate = proxy._getPredecessorDate(childGanttRecord, childPredecessor, predecessor.predecessorsType);

                                minStartDate.setDate(minStartDate.getDate() - 1);

                                if (proxy.model.includeWeekend === false) {
                                    proxy._setBeforeWeekend(minStartDate);
                                }

                                childGanttRecord.endDate = childGanttRecord._getFormatedDate(minStartDate, model.dateFormat);
                                if (childGanttRecord.isMilestone)
                                    childGanttRecord.startDate = childGanttRecord._getFormatedDate(minStartDate, model.dateFormat);
                                else {
                                    var tempEndDate = proxy._getDateFromFormat(childGanttRecord.endDate);
                                    for (var i = 0; i < childGanttRecord.duration - 1; i++) {
                                        tempEndDate.setDate(tempEndDate.getDate() - 1);
                                        if (proxy.model.includeWeekend === false) {
                                            if (predecessorOffset < 0) {
                                                proxy._setBeforeWeekend(tempEndDate);
                                            }
                                        }
                                        tempEndDate = proxy._onHoliDayCheckBefore(tempEndDate);
                                    }
                                    childGanttRecord.startDate = childGanttRecord._getFormatedDate(tempEndDate, model.dateFormat);
                                }
                            }
                            childGanttRecord.left = childGanttRecord._calculateLeft(proxy._projectStartDate, proxy._perDayWidth, proxy._holidaysList, model);
                        childGanttRecord.width = childGanttRecord._calculateWidth(proxy._perDayWidth, proxy._holidaysList, model);

                    break;

                case 'FS':

                    parentEndDate = proxy._getDateFromFormat(parentGanttRecord.endDate);
                    childStartDate = proxy._getDateFromFormat(childGanttRecord.startDate);

                        if (!childGanttRecord.isMilestone) {
                            parentEndDate.setDate(parentEndDate.getDate() + 1);
                        }

                        if (predecessorOffset < 0) {
                            predecessorOffset *= -1;
                            offset = -1;
                            if (model.includeWeekend === false) {
                                proxy._setBeforeWeekend(parentEndDate);
                            }
                        } else {

                            if (model.includeWeekend === false) {
                                proxy._setAfterWeekend(parentEndDate);
                            }
                            offset = 1;
                        }


                        if (predecessorOffset) {

                            for (var i = 0; i < predecessorOffset; i++) {

                                if (proxy.model.includeWeekend === false) {
                                    if (offset < 0) {
                                        proxy._setBeforeWeekend(parentEndDate);
                                    }

                                    if (offset > 0) {
                                        proxy._setAfterWeekend(parentEndDate);
                                    }
                                }
                                parentEndDate.setDate(parentEndDate.getDate() + offset);
                            }

                            if (proxy.model.includeWeekend === false) {
                                proxy._setAfterWeekend(parentEndDate);
                            }
                        }

                        if (proxy._stringHolidays &&
                            proxy._stringHolidays.indexOf(childGanttRecord._getFormatedDate(parentEndDate, model.dateFormat)) != -1) {
                            parentEndDate.setDate(parentEndDate.getDate() + 1);
                        }

                        childGanttRecord.startDate = childGanttRecord._getFormatedDate(parentEndDate, model.dateFormat);

                        if (proxy._editedTaskBarItem!==childGanttRecord) {
                            var predecessorsCollection = childGanttRecord['predecessor'],
                                currentTaskId = childGanttRecord['taskId'].toString(),
                                childPredecessor = predecessorsCollection&&predecessorsCollection.filter(function (data) { return data.to === currentTaskId });

                            if (childPredecessor && childPredecessor.length > 1 && offset>0) {

                                var maxEndDate = proxy._getPredecessorDate(childGanttRecord, childPredecessor, predecessor.predecessorsType);

                                if (!childGanttRecord.isMilestone) {
                                    maxEndDate.setDate(maxEndDate.getDate() + 1);
                                }

                                if (model.includeWeekend === false) {
                                    proxy._setAfterWeekend(maxEndDate);
                                }

                                childGanttRecord.startDate = childGanttRecord._getFormatedDate(maxEndDate, model.dateFormat);
                            }
                       }

                            childGanttRecord.left = childGanttRecord._calculateLeft(proxy._projectStartDate, proxy._perDayWidth, proxy._holidaysList, model);
                        childGanttRecord.width = childGanttRecord._calculateWidth(proxy._perDayWidth,proxy._holidaysList, model);
                    break;

                case 'FF':
                    parentEndDate = proxy._getDateFromFormat(parentGanttRecord.endDate);
                    childEndDate = proxy._getDateFromFormat(childGanttRecord.endDate);

                        if (proxy.model.includeWeekend === false) {
                            proxy._setAfterWeekend(parentEndDate);
                        }

                        if (predecessorOffset) {
                            parentEndDate.setDate(parentEndDate.getDate() + (Math.floor(predecessorOffset)));

                            if (proxy.model.includeWeekend === false) {
                                if (predecessorOffset < 0) {
                                    proxy._setBeforeWeekend(parentEndDate);
                                }

                                if (predecessorOffset > 0) {
                                    proxy._setAfterWeekend(parentEndDate);
                                }
                            }
                        }
                        if (proxy._stringHolidays &&
                           proxy._stringHolidays.indexOf(childGanttRecord._getFormatedDate(parentEndDate, model.dateFormat)) != -1) {
                            parentEndDate.setDate(parentEndDate.getDate() + 1);
                        }

                        childGanttRecord.endDate = childGanttRecord._getFormatedDate(parentEndDate, model.dateFormat);
                        //End Date is changed by start date and duration
                        if (childGanttRecord.isMilestone)
                            childGanttRecord.startDate = childGanttRecord._getFormatedDate(parentEndDate, model.dateFormat);
                        else {
                            var tempEndDate = proxy._getDateFromFormat(childGanttRecord.endDate);
                            for (var i = 0; i < childGanttRecord.duration - 1; i++) {
                                tempEndDate.setDate(tempEndDate.getDate() - 1);
                                if (proxy.model.includeWeekend === false) {
                                    if (predecessorOffset < 0) {
                                        proxy._setBeforeWeekend(tempEndDate);
                                    }
                                }
                                tempEndDate = proxy._onHoliDayCheckBefore(tempEndDate);
                            }
                            childGanttRecord.startDate = childGanttRecord._getFormatedDate(tempEndDate, model.dateFormat);
                        }

                            var currentTaskId = childGanttRecord['taskId'].toString(),
                                        predecessorsCollection = childGanttRecord['predecessor'],
                                      childPredecessor =predecessorsCollection&& predecessorsCollection.filter(function (data) { return data.to === currentTaskId });

                            if (childPredecessor && childPredecessor.length > 1) {

                                var maxEndDate = proxy._getPredecessorDate(childGanttRecord, childPredecessor, predecessor.predecessorsType);

                                if (model.includeWeekend === false) {
                                    proxy._setAfterWeekend(maxEndDate);
                                }

                                if (predecessorOffset >= 0 && (maxEndDate.getTime() !== parentEndDate.getTime())) {
                                    childGanttRecord.endDate = childGanttRecord._getFormatedDate(maxEndDate, model.dateFormat);
                                    if (childGanttRecord.isMilestone)
                                        childGanttRecord.startDate = childGanttRecord._getFormatedDate(maxEndDate, model.dateFormat);
                                    else {
                                        var tempEndDate = proxy._getDateFromFormat(childGanttRecord.endDate);
                                        for (var i = 0; i < childGanttRecord.duration - 1; i++) {
                                            tempEndDate.setDate(tempEndDate.getDate() - 1);
                                            if (proxy.model.includeWeekend === false) {
                                                proxy._setBeforeWeekend(tempEndDate);
                                            }
                                            tempEndDate = proxy._onHoliDayCheckBefore(tempEndDate);
                                        }
                                        childGanttRecord.startDate = childGanttRecord._getFormatedDate(tempEndDate, model.dateFormat);
                                    }
                                }
                            }

                            childGanttRecord.left = childGanttRecord._calculateLeft(proxy._projectStartDate, proxy._perDayWidth, proxy._holidaysList, model);
                            childGanttRecord.width = childGanttRecord._calculateWidth(proxy._perDayWidth, proxy._holidaysList, model);
                    break;
            }

            if (childGanttRecord.parentItem)
                proxy._updateParentItem(childGanttRecord);

            if (proxy._isTreeGridRendered || proxy._isGanttChartRendered) {
                proxy.refreshGanttRecord(childGanttRecord);
            }

        },

        _getPredecessorDate: function (ganttRecord, predecessorsCollection, predecessorType) {
            var minStartDate = null, proxy = this, model = proxy.model,
                    maxEndDate = null,
                    tempMaxEndDate = null,
                    length,
                    i,
                    dateDiff = 0,
                    predecessorOffset,
                    connectorLineObject,
                    offset,
                    validatedpredecessor = predecessorsCollection.filter(function (data) {
                        return data.to === ganttRecord.taskId.toString();
                    });


            if (validatedpredecessor) {

                length = validatedpredecessor.length;

                

                    for (i = 0; i < length; i++) {

                        predecessor = validatedpredecessor[i];

                        parentGanttRecord = proxy._rows[proxy._ids.indexOf(predecessor.from)];
                        childGanttRecord = proxy._rows[proxy._ids.indexOf(predecessor.to)];

                        if (minStartDate === null) {
                            minStartDate = proxy._getDateFromFormat(parentGanttRecord.startDate);
                            if (parseInt(predecessor.offset)) {
                                minStartDate.setDate(minStartDate.getDate() + parseInt(predecessor.offset));
                            }
                        }

                        if (maxEndDate === null) {
                            maxEndDate = proxy._getDateFromFormat(parentGanttRecord.endDate);
                            //if (parseInt(predecessor.offset)) {
                            //    maxEndDate.setDate(maxEndDate.getDate() + parseInt(predecessor.offset));
                            //}
                            tempMaxEndDate = proxy._getDateFromFormat(parentGanttRecord.endDate);
                        }

                        if (proxy._getDateFromFormat(parentGanttRecord.startDate).getTime() < minStartDate.getTime()) {
                            minStartDate = proxy._getDateFromFormat(parentGanttRecord.startDate);
                            if (parseInt(predecessor.offset)) {
                                minStartDate.setDate(minStartDate.getDate() + parseInt(predecessor.offset));
                            }
                        }

                        if (proxy._getDateFromFormat(parentGanttRecord.endDate).getTime() > maxEndDate.getTime()) {
                            maxEndDate = proxy._getDateFromFormat(parentGanttRecord.endDate);
                            
                        }
                        tempMaxEndDate.setDate(tempMaxEndDate.getDate() + parseInt(predecessor.offset));
                        var tempMaxDate = proxy._getDateFromFormat(tempMaxEndDate);
                        if (model.includeWeekend === false && tempMaxDate) {
                            proxy._setAfterWeekend(tempMaxDate);
                        }
                        if (parseInt(predecessor.offset)) {
                            if (maxEndDate.getTime() < tempMaxDate.getTime())
                            maxEndDate.setDate(maxEndDate.getDate() + parseInt(predecessor.offset));
                        }
                        (tempMaxEndDate.setDate(tempMaxEndDate.getDate() - parseInt(predecessor.offset)))
                        if (model.includeWeekend === false) {
                            proxy._setAfterWeekend(maxEndDate);
                            proxy._setAfterWeekend(tempMaxEndDate);
                        }
                }
            }
            if (predecessorType == "FS" || predecessorType == "FF") {
                return maxEndDate;
            }
            else if (predecessorType == "SF" || predecessorType == "SS") {
                return minStartDate;
            }

        },

        _renderPredecessor: function (predecessor, item) {
            //var proxy = this,
            //model = proxy.model,
            //length = predecessor.length, predecessorValues = [];

            //for (var i = 0; i < length; i++) {
            //    if (predecessor[i].offset < 0) {
            //        predecessorValues.push(predecessor[i].from + "" + predecessor[i].predecessorsType + ""
            //            + predecessor[i].offset + "d");
            //    }
            //    else if (predecessor[i].offset >= 1) {
            //        predecessorValues.push(predecessor[i].from + "" + predecessor[i].predecessorsType + "+"
            //            + predecessor[i].offset + "d");
            //    }
            //    else {
            //        predecessorValues.push(predecessor[i].from);
            //    }
            //}
            //if (predecessorValues.length > 0) {
            //    item.item[model.predecessorMapping] = predecessorValues.join(',');
            //    //this.refreshRow(itemIndex, false);
            //}
        },

        _setBeforeWeekend: function(date) {
            if (date.getDay() == 0)
                date.setDate(date.getDate() - 2);
            else if (date.getDay() == 6)
                date.setDate(date.getDate() - 1);
        },
        
        _setAfterWeekend: function(date) {
            if (date.getDay() == 0)
                date.setDate(date.getDate() + 1);
            else if (date.getDay() == 6)
                date.setDate(date.getDate() + 2);
        },
        
        _updateEditedGanttRecords: function (args) {
            var proxy = this, model = proxy.model,
                ganttRecord = args.data,
                startDate = proxy._getDateFromFormat(ganttRecord.startDate),
                isPredecessorsModified = false;

            if (args.columnName === "startDate") {
               
                if (this._stringHolidays &&
                      this._stringHolidays.indexOf(ganttRecord._getFormatedDate(startDate, model.dateFormat)) != -1) {
                    startDate.setDate(startDate.getDate() + 1);
                }
                
                if (proxy.model.includeWeekend === false) {
                    this._setAfterWeekend(startDate);
                    if (this._stringHolidays &&
                      this._stringHolidays.indexOf(ganttRecord._getFormatedDate(startDate, model.dateFormat)) != -1) {
                        startDate.setDate(startDate.getDate() + 1);
                    }
                }
                ganttRecord.startDate = proxy.getFormatedDate(startDate);
                ganttRecord.left = ganttRecord._calculateGanttRecordLeft(startDate, proxy._projectStartDate, proxy._perDayWidth);
                ganttRecord.width = ganttRecord._calculateWidth(proxy._perDayWidth, proxy._holidaysList, model);// model.holidays
                ganttRecord.progressWidth = ganttRecord._calculateProgressWidth(ganttRecord.width, ganttRecord.status);
                if (ganttRecord.parentItem)
                    proxy._updateParentItem(ganttRecord);
            }

            else if (args.columnName === "endDate") {
                //validate start date
                var endDate = proxy._getDateFromFormat(ganttRecord.endDate);
                if (startDate.getTime() <= endDate.getTime()) {

                    if (this._stringHolidays &&
                          this._stringHolidays.indexOf(ganttRecord._getFormatedDate(endDate, model.dateFormat)) != -1) {
                        endDate.setDate(endDate.getDate() + 1);
                        if (endDate.getDay() == 6) {
                            endDate.setDate(endDate.getDate() + 2);
                        }
                    }

                    if (model.includeWeekend === false) {
                        if (endDate.getDay() == 0) {
                            endDate.setDate(endDate.getDate() - 2);
                        } else if (endDate.getDay() == 6) {
                            endDate.setDate(endDate.getDate() - 1);
                        }
                    }
                    ganttRecord.endDate = ganttRecord._calculateFormatedDate(endDate, model.dateFormat);
                    ganttRecord._calculateDuration(startDate, endDate, model.includeWeekend, model.holidays, ganttRecord.isMilestone, model);
                    ganttRecord.width = ganttRecord._calculateTaskbarWidth(proxy._perDayWidth, model);
                    ganttRecord.progressWidth = ganttRecord._calculateProgressWidth(ganttRecord.width, ganttRecord.status);
                    if (ganttRecord.parentItem)
                        proxy._updateParentItem(ganttRecord);
                }
                else
                {
                    ganttRecord.endDate = args.previousValue;
                    ganttRecord.item[model.endDateMapping] = args.previousValue;
                }
                if (ganttRecord.duration === 0)
                    ganttRecord.isMilestone = true;
                else
                    ganttRecord.isMilestone = false;
                
            }
            
            else if (args.columnName == "duration") {
                var currentDuration = ganttRecord.duration,
                    offset = currentDuration - args.previousValue,
                modifiedEndDate = proxy._calculateUpdatedDate(proxy._getDateFromFormat(ganttRecord.endDate), offset);

                if (currentDuration === 0) {
                    ganttRecord.isMilestone = true;
                } else {
                    ganttRecord.isMilestone = false;
                }

                ganttRecord.endDate = modifiedEndDate;
                ganttRecord.width = ganttRecord._calculateWidth(proxy._perDayWidth, proxy.holidays, model);
                ganttRecord.progressWidth = ganttRecord._calculateProgressWidth(ganttRecord.width, ganttRecord.status);
                if(model.endDateMapping)
                    ganttRecord.item[model.endDateMapping] = modifiedEndDate;
                if (ganttRecord.parentItem)
                    proxy._updateParentItem(ganttRecord);
            }

            else if (args.columnName == "predecessor") {
                isPredecessorsModified = true;
                if (args.previousValue) {
                    proxy._removeConnectorLine(args.previousValue, ganttRecord);
                }
                proxy._addConnectorLine(ganttRecord);
            }

            else if (args.columnName == "status") {
                ganttRecord.status = ganttRecord.status > 100 ? 100 : ganttRecord.status;
                ganttRecord.progressWidth = proxy._getProgressWidth(ganttRecord.width, ganttRecord.status);
                if (ganttRecord.parentItem) {
                    if (ganttRecord.parentItem)
                        proxy._updateParentItem(ganttRecord);
                    
                }
            }

            //proxy._updateEditedGanttRecord(ganttRecord);
            if (ganttRecord.predecessor) {
                if (!isPredecessorsModified)
                    proxy._$ganttchartHelper.ejGanttChart("updateConnectorLineOffset", ganttRecord);
                proxy._isMileStoneEdited = ganttRecord.isMilestone;
                proxy._updatedConnectorLineCollection = [];
                proxy._connectorlineIds = [];
                proxy._validatePredecessor(ganttRecord);
                if (proxy._updatedConnectorLineCollection.length > 0) {
                    proxy._$ganttchartHelper.ejGanttChart("appendConnectorLine", proxy._updatedConnectorLineCollection);
                }
            }
            proxy._isValidationEnabled = false;
            
            proxy.refreshGanttRecord(ganttRecord);
        },

        _removeConnectorLine: function (predecessor,ganttRecord) {
            var proxy = this,
                connectorLineId,
                parentGanttRecord,
                record,
                i = 0,
                length = predecessor && predecessor.length,
                index = -1;
                
            for (i = 0; i < length; i++) {
                parentGanttRecord = proxy._rows[proxy._ids.indexOf(predecessor[i].from)];
                record = proxy._rows[proxy._ids.indexOf(predecessor[i].to)];
                
                if (ganttRecord.taskId.toString() === predecessor[i].to.toString()) {
                    
                    index = parentGanttRecord.predecessor.indexOf(predecessor[i]);
                    index >= 0 && parentGanttRecord.predecessor.splice(index, 1);
                }

                if (parentGanttRecord && record) {
                    connectorLineId = "parent"+parentGanttRecord['taskId'] + "child" + record['taskId'];
                    proxy._$ganttchartHelper.ejGanttChart("removeConnectorline", connectorLineId);
                }
            }
        },

        _addConnectorLine:function(ganttRecord) {
            var proxy = this,
                count = 0,
                predecessors = ganttRecord.predecessor,
                length,
                predecessor,
                successorGanttRecord;

            if (predecessors) {

                length = predecessors.length;

                for (count = 0; count < length; count++) {

                    predecessor = predecessors[count];
                    
                    if (predecessor.to === ganttRecord.taskId.toString()) {
                        successorGanttRecord = proxy._rows[proxy._ids.indexOf(predecessor.from)];
                    }

                    if (successorGanttRecord) {
                        if (successorGanttRecord.predecessor) {
                            successorGanttRecord.predecessor.push(predecessor);
                        } else {
                            successorGanttRecord.predecessor = [];
                            successorGanttRecord.predecessor.push(predecessor);
                            proxy._predecessorsCollection.push(successorGanttRecord);
                        }
                    }
                }
            }
        },

        _calculateUpdatedDate: function (modifiedDate, offset) {
            var proxy = this, model = proxy.model,
                i = 0;
            if (offset > 0) {
                for (i; i < offset; i++) {
                    if (model.durationUnit == ej.Gantt.DurationUnit.Day) {
                        modifiedDate = proxy.dateUpdate(modifiedDate, 1, 0);
                    }
                    else if (model.durationUnit == ej.Gantt.DurationUnit.Hour) {
                        modifiedDate = proxy.dateUpdate(modifiedDate, 0, 1);
                    }

                    if (modifiedDate.getDay() == 0)
                        modifiedDate.setDate(modifiedDate.getDate() + 1);
                    else if (modifiedDate.getDay() == 6)
                        modifiedDate.setDate(modifiedDate.getDate() + 2);
                }
            } else {
                var dateOffset = (-1) * offset;
                for (i = 0; i < dateOffset; i++) {
                    if (model.durationUnit == ej.Gantt.DurationUnit.Day) {
                        modifiedDate = proxy.dateUpdate(modifiedDate, -1, 0);
                    }
                    else if (model.durationUnit == ej.Gantt.DurationUnit.Hour) {
                        modifiedDate = proxy.dateUpdate(modifiedDate, 0, -1);
                    }

                    if (modifiedDate.getDay() == 0)
                        modifiedDate.setDate(modifiedDate.getDate() - 2);
                    else if (modifiedDate.getDay() == 6)
                        modifiedDate.setDate(modifiedDate.getDate() - 1);
                }
            }
            modifiedDate = proxy.getFormatedDate(modifiedDate);
            return modifiedDate;
        },

        _updateEditedGanttRecord: function (ganttRecord) {
            var proxy = this;
            if (ganttRecord.predecessor) {
                var predecessorsCollection = ganttRecord.predecessor,
                    count = 0,
                    length = predecessorsCollection.length,
                    predecessor,
                    parentGanttRecord,
                    record,
                    connectorLineId,
                    connectorLineObject;
                for (count = 0; count < length; count++) {
                    proxy._updatedConnectorLineCollection = [];
                    proxy._connectorlineIds = [];
                    predecessor = predecessorsCollection[count];
                    if (predecessor.to === ganttRecord['taskId'].toString()) {

                        parentGanttRecord = proxy._rows[proxy._ids.indexOf(predecessor.from)];
                        record = proxy._rows[proxy._ids.indexOf(predecessor.to)];
                        
                        if (parentGanttRecord && record) {
                            connectorLineId = "parent" + parentGanttRecord['taskId'] + "child" + record['taskId'];
                            proxy._$ganttchartHelper.ejGanttChart("removeConnectorline", connectorLineId);
                            connectorLineObject = proxy._createConnectorLineObject(parentGanttRecord, record, predecessor);
                            if (connectorLineObject) {
                                if (proxy._connectorlineIds.length > 0 && proxy._connectorlineIds.indexOf(connectorLineObject.ConnectorLineId) == -1) {

                                    proxy._updatedConnectorLineCollection.push(connectorLineObject);
                                    proxy._connectorlineIds.push(connectorLineObject.ConnectorLineId);
                                }
                                else if (proxy._connectorlineIds.length == 0) {
                                    proxy._updatedConnectorLineCollection.push(connectorLineObject);
                                    proxy._connectorlineIds.push(connectorLineObject.ConnectorLineId);
                                }
                                proxy._$ganttchartHelper.ejGanttChart("appendConnectorLine", proxy._updatedConnectorLineCollection);
                            }
                        }
                        
                    }
                }
            }
        },
        

        _updateGanttRecord: function (ganttRecord) {
            var proxy = this,
                model = proxy.model;            
            ganttRecord.left = ganttRecord._calculateLeft(proxy._projectStartDate, proxy._perDayWidth, proxy.holidays, model);
            ganttRecord.width = ganttRecord._calculateWidth(proxy._perDayWidth,model.holidays, model);
            proxy.refreshGanttRecord(ganttRecord);            
            if (ganttRecord.parentItem)
                proxy._updateParentItem(ganttRecord);
        },

        refreshGanttRecord: function (ganttRecord) {
            var proxy = this;
            if (proxy._isTreeGridRendered) {
                proxy._currentViewData = proxy.getCurrentViewData();
                var index = proxy._currentViewData.indexOf(ganttRecord);
                proxy._$treegridHelper.ejTreeGrid("refreshRow", index);
                if (proxy._isGanttChartRendered) {
                    proxy._$ganttchartHelper.ejGanttChart("refreshRow", index);
                }
            }
        },

        _updateParentItem: function (ganttRecord) {

            var proxy = this,
                parentGanttRecord = ganttRecord.parentItem,                
                model = proxy.model,                
                prevStartDate = proxy._getDateFromFormat(parentGanttRecord.startDate),
                currentStartDate = proxy._getDateFromFormat(ganttRecord.startDate),
                prevEndDate = proxy._getDateFromFormat(parentGanttRecord.endDate),
                currentEndDate = proxy._getDateFromFormat(ganttRecord.endDate);
                            
            
            if (currentStartDate.getTime() < prevStartDate.getTime()) {
                parentGanttRecord.startDate = ganttRecord.startDate;
                if (model.startDateMapping)
                parentGanttRecord.item[model.startDateMapping] = parentGanttRecord.startDate;                
            }

            if (currentEndDate.getTime() > prevEndDate.getTime()) {                
                dateDiff = proxy._daydiff(prevEndDate, currentEndDate);
                parentGanttRecord.endDate = ganttRecord.endDate;
                if(model.endDateMapping)
                    parentGanttRecord.item[model.endDateMapping] = parentGanttRecord.endDate;

            }

            var count = 0,
                childRecords = parentGanttRecord.childRecords,
                length = childRecords && childRecords.length,
                childGanttRecord,
                minStartDate = null,
                maxEndDate = null,
                parentProgress = 0,
                milestoneCount = 0,
                    totalDuration = 0,
                    completedDuration = 0;

            for (count = 0; count < length; count++) {

                childGanttRecord = childRecords[count];

                if (minStartDate === null) {
                    minStartDate =proxy._getDateFromFormat(childGanttRecord.startDate);
                }
                if (maxEndDate === null) {
                    maxEndDate = proxy._getDateFromFormat(childGanttRecord.endDate);
                }
                if (proxy._getDateFromFormat(childGanttRecord.endDate).getTime() > maxEndDate.getTime()) {
                    maxEndDate =proxy._getDateFromFormat(childGanttRecord.endDate);
                }
                if (proxy._getDateFromFormat(childGanttRecord.startDate).getTime() < minStartDate.getTime()) {
                    minStartDate = proxy._getDateFromFormat(childGanttRecord.startDate);
                }

                if (!childGanttRecord.isMilestone) {
                    //converting days into hours .
                    //By now 24 hours is default//...
                    if (model.durationUnit == ej.Gantt.DurationUnit.Hour) {
                        totalDuration += (childGanttRecord.duration*8);
                        //summation of progress done of child
                        completedDuration += ((childGanttRecord.duration*8) * childGanttRecord.status) / 100;
                    }
                    else {
                        totalDuration += (childGanttRecord.duration * 24);
                        //summation of progress done of child
                        completedDuration += ((childGanttRecord.duration * 24) * childGanttRecord.status) / 100;
                    }


                }

                else
                    milestoneCount++;
            }

            if (prevStartDate.getTime() !== minStartDate.getTime()) {
                parentGanttRecord.startDate = parentGanttRecord._getFormatedDate(minStartDate, model.dateFormat);
                if (model.startDateMapping)
                parentGanttRecord.item[model.startDateMapping] = parentGanttRecord.startDate;
            }
            
            if (prevEndDate.getTime() != maxEndDate.getTime()) {                                                       
                parentGanttRecord.endDate = parentGanttRecord._getFormatedDate(maxEndDate, model.dateFormat);
                if(model.endDateMapping)
                    parentGanttRecord.item[model.endDateMapping] = parentGanttRecord.endDate;

            }

            if (!(model.endDateMapping.length==0 && model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale8Hours &&
                model.durationUnit == ej.Gantt.DurationUnit.Hour &&
                model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Day)) {
                parentGanttRecord._calculateDuration(proxy._getDateFromFormat(parentGanttRecord.startDate),
                    proxy._getDateFromFormat(parentGanttRecord.endDate), model.includeWeekend, model.holidays,
                    parentGanttRecord[model.milestoneMapping], model);

            }

            if ((model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale8Hours ||
                model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale24Hours) &&
            model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Day ){
                var beginDate = proxy._getDateFromFormat(parentGanttRecord.startDate);
                //beginDate.setHours(8);
                var diffDate = (beginDate - proxy._projectStartDate) / 86400000;
            }
            else if (model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale8Hours && model.roundOffDayworkingTime) {
                var diffDate = Math.round((proxy._getDateFromFormat(parentGanttRecord.startDate) - proxy._projectStartDate) / 86400000);
            }
            else {
                var diffDate = Math.round((proxy._getDateFromFormat(parentGanttRecord.startDate) - proxy._projectStartDate) / 86400000);
            }
            parentGanttRecord.left = (diffDate * proxy._perDayWidth);
            parentGanttRecord.width = parentGanttRecord._calculateWidth(proxy._perDayWidth,  proxy._holidaysList, model);//model.holidays
            
            //Calculate progressWidth after Left and width calculation
            parentProgress = totalDuration > 0 ? (completedDuration / totalDuration) * 100 : 0;
            parentGanttRecord.progressWidth = proxy._getProgressWidth(parentGanttRecord.width, parentProgress);
            parentGanttRecord.status = Math.round(parentProgress);

            if (model.progressMapping)
                parentGanttRecord.item[model.progressMapping] = parentGanttRecord.status;

            if (proxy._isTreeGridRendered || proxy._isGanttChartRendered)
                proxy.refreshGanttRecord(parentGanttRecord);

            if (parentGanttRecord.parentItem) {
                proxy._updateParentItem(parentGanttRecord);
            }

            
        },

        _validatePredecessor: function (childGanttRecord) {

            var proxy = this,model=proxy.model;

            if (childGanttRecord.predecessor) {

                var predecessorsCollection = childGanttRecord['predecessor'],
                    count,                    
                    parentGanttRecord,
                    record=null,
                    connectorLineId,
                    isValidated = false,
                    predecessor,
                    connectorLineObject,
                    lowestOffset;

                var currentTaskId = childGanttRecord['taskId'].toString(),

                    predecessors = predecessorsCollection.filter(function (data) { return data.to === currentTaskId }),
                    successors = predecessorsCollection.filter(function (data) { return data.from === currentTaskId });
               var predecessorLength = predecessors.length;

                for (count = 0; count < predecessorLength; count++) {
                    predecessor = predecessors[count];
                    parentGanttRecord = proxy._rows[proxy._ids.indexOf(predecessor.from)];//THis is going to exception when id is not corrct order
                    record = proxy._rows[proxy._ids.indexOf(predecessor.to)];
                    connectorLineId = "parent" + parentGanttRecord['taskId'] + "child" + record['taskId'];
                    if (proxy._$ganttchartHelper)
                        proxy._$ganttchartHelper.ejGanttChart("removeConnectorline", connectorLineId);

                    if (childGanttRecord.taskId.toString() === predecessor.to)
                        proxy._validateChildGanttRecord(parentGanttRecord, record, predecessor);


                    if (childGanttRecord.taskId.toString() === predecessor.from)
                        proxy._validateChildGanttRecord(parentGanttRecord, record, predecessor);

                }
                for (count = 0; count < predecessorLength; count++) {
                predecessor = predecessors[count];
                parentGanttRecord = proxy._rows[proxy._ids.indexOf(predecessor.from)];//THis is going to exception when id is not corrct order
                record = proxy._rows[proxy._ids.indexOf(predecessor.to)];
             
					if ((model.enableVirtualization === false && (parentGanttRecord.isExpanded === false || record.isExpanded == false)))//(model.enableVirtualization === false && !parentGanttRecord.isExpanded && record.isExpanded === false)
						continue;
                    connectorLineObject = proxy._createConnectorLineObject(parentGanttRecord, record, predecessor);
                    if (connectorLineObject) {
                        if (proxy._connectorlineIds.length > 0 && proxy._connectorlineIds.indexOf(connectorLineObject.ConnectorLineId) == -1) {

                            proxy._updatedConnectorLineCollection.push(connectorLineObject);
                            proxy._connectorlineIds.push(connectorLineObject.ConnectorLineId);
                        }
                        else if (proxy._connectorlineIds.length == 0) {
                            proxy._updatedConnectorLineCollection.push(connectorLineObject);
                            proxy._connectorlineIds.push(connectorLineObject.ConnectorLineId);
                        }
                        else if (proxy._connectorlineIds.indexOf(connectorLineObject.ConnectorLineId) != -1) {
                            var index = proxy._connectorlineIds.indexOf(connectorLineObject.ConnectorLineId);
                            proxy._updatedConnectorLineCollection[index] = connectorLineObject;
                        }
                    }                   

                }

                var length = successors.length;

                for (count = 0; count < length; count++) {

                    predecessor = successors[count];
                    parentGanttRecord = proxy._rows[proxy._ids.indexOf(predecessor.from)];
                    record = proxy._rows[proxy._ids.indexOf(predecessor.to)];
                    connectorLineId = "parent" + parentGanttRecord['taskId'] + "child" + record['taskId'];
                    if (proxy._$ganttchartHelper)
                        proxy._$ganttchartHelper.ejGanttChart("removeConnectorline", connectorLineId);
                    proxy._validateChildGanttRecord(parentGanttRecord, record, predecessor);
                      if ((model.enableVirtualization === false && (parentGanttRecord.isExpanded === false || record.isExpanded == false)))
                        continue;
					connectorLineObject = proxy._createConnectorLineObject(parentGanttRecord, record, predecessor);
                    if (connectorLineObject) {
                        if (proxy._connectorlineIds.length > 0 && proxy._connectorlineIds.indexOf(connectorLineObject.ConnectorLineId) == -1) {

                            proxy._updatedConnectorLineCollection.push(connectorLineObject);
                            proxy._connectorlineIds.push(connectorLineObject.ConnectorLineId);
                        }
                        else if (proxy._connectorlineIds.length == 0) {
                            proxy._updatedConnectorLineCollection.push(connectorLineObject);
                            proxy._connectorlineIds.push(connectorLineObject.ConnectorLineId);
                        }
                        else if (proxy._connectorlineIds.indexOf(connectorLineObject.ConnectorLineId) != -1) {
                            var index = proxy._connectorlineIds.indexOf(connectorLineObject.ConnectorLineId);
                            proxy._updatedConnectorLineCollection[index] = connectorLineObject;
                        }
                    }

                    record &&  proxy._validatePredecessor(record);

                }                
            }
        },
       
        _calculateDateDifference: function (emptyDate, dateDiff) {
            var differenceCount = dateDiff >= 0 ? dateDiff : (-1 * dateDiff),
                offset = 0;
            
            if (dateDiff > 0)
                offset = differenceCount - this._calculateWeekendCount(emptyDate, dateDiff);
            else
                offset = dateDiff + this._calculateWeekendCount(emptyDate, dateDiff);
            return offset;
        },

        _calculateWeekendCount: function (emptyDate, dateDiff) {
            var differenceCount = dateDiff >= 0 ? dateDiff : (-1 * dateDiff),
                weekendCount = 0,
                i = 0;
            
            if (dateDiff > 0) {
                for (i = 0; i < dateDiff; i++) {
                    if (emptyDate.getDay() == 0) {
                        weekendCount++;
                        emptyDate.setDate(emptyDate.getDate() + 1);
                    }
                    else if (emptyDate.getDay() == 6) {
                        weekendCount += 2;
                        ++i;
                        emptyDate.setDate(emptyDate.getDate() + 2);
                    } else
                        emptyDate.setDate(emptyDate.getDate() + 1);
                }
            }
            else {
                for (i = 0; i < differenceCount; i++) {
                    emptyDate.setDate(emptyDate.getDate() - 1);
                    if (emptyDate.getDay() == 0 || emptyDate.getDay() == 6) {
                        weekendCount += 1;
                    }
                }
            }
            return weekendCount;
        },

        _daydiff: function (first, second) {
            return ((new Date(second) - new Date(first)) / (1000 * 60 * 60 * 24));
        },

        


        dateUpdate: function (date, days, hours) {
            return new Date(
                date.getFullYear(),
                date.getMonth(),
                date.getDate() + days,
                date.getHours() + hours,
                date.getMinutes(),
                date.getSeconds(),
                date.getMilliseconds()
            );
        },
        
        //Method for collapse all the GanttRecords

        _collapseAll: function () {
            var proxy = this,
                model = proxy.model,
                count = 0,
                ganttRecord,
                args = {},
                enableVirtualization = model.enableVirtualization,
                $gridRows = proxy.getRows(),
                $rowElement = null;

            proxy._gridRows = $gridRows;
            proxy._isInExpandCollapse = true;
             
            //loop excecute for iterate the GanttRecords preseent in the Gantt Control            
            for (count = 0; count < proxy.model.parentRecords.length; count++) {
                if (proxy.model.parentRecords[count].expanded) {
                    ganttRecord = proxy.model.parentRecords[count];
                    args.data = ganttRecord;
                    args.recordIndex = count;
                    args.expanded = false;

                    if (enableVirtualization) {
                        if (ganttRecord.hasChildRecords && ganttRecord.expanded) {
                            ej.TreeGrid.sendExpandCollapseRequest(proxy, args);
                        }
                    } else {
                        if (ganttRecord.hasChildRecords && ganttRecord.expanded) {
                            ej.TreeGrid.sendExpandCollapseRequest(proxy, args);
                        }
                        else
                            ej.TreeGrid.sendExpandCollapseRequest(proxy, args);
                        var collapsedCount = proxy._collapsedRecordCount;
                        proxy._$ganttchartHelper.ejGanttChart("reRenderGanttGridLinesTable", -collapsedCount);
                    }
                }
            }

            proxy._isInExpandCollapse = false;
        },
        
        
        //Method for expand all the GanttRecords
        
        _expandAll: function () {
            
            var proxy = this,
                model = proxy.model,
                count = 0,
                ganttRecord,
                args = {},
                enableVirtualization = model.enableVirtualization;

            proxy._isInExpandCollapse = true;

            //loop excecute for iterate the GanttRecords preseent in the Gantt Control

            for (count = 0; count < proxy._updatedGanttRecords.length; count++) {
                ganttRecord = proxy._updatedGanttRecords[count];
                args.data = ganttRecord;
                args.recordIndex = count;
                args.expanded = true;

                if (enableVirtualization) {
                    if (ganttRecord.hasChildRecords && !ganttRecord.expanded) {
                             ej.TreeGrid.sendExpandCollapseRequest(proxy, args);
                    }
                } else {
                    if (ganttRecord.hasChildRecords && !ganttRecord.expanded) {
                        ej.TreeGrid.sendExpandCollapseRequest(proxy, args);
                        var expandedCount = proxy._expandedRecordsCount;
                        proxy._$ganttchartHelper.ejGanttChart("reRenderGanttGridLinesTable", expandedCount);
                    }
                }
            }

            proxy._isInExpandCollapse = false;
        },
        _getDateFromFormat: function (date) {
            
            if (typeof date === "object") {
                return new Date(date);
            }
            if (date) {
                return Globalize.parseDate(date, this.model.dateFormat) == null ?
                    new Date(date) : Globalize.parseDate(date, this.model.dateFormat);
            }
        },
        _getFormatedDate: function (dateObject, dateformat) {
            return Globalize.format(dateObject, dateformat);
        },

        /**
        * destroy the gantt widget
		* all events bound using this._on will be unbind automatically and bring the control to pre-init state.
		* @alias destroy
		* @return jQuery
		* @example 
		* &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
		* &lt;script&gt;
		* // Create gantt
		* var gantt = $("#gantt").data("ejGantt");
		* gantt.destroy(); // destroy the gantt
		* &lt;/script&gt;
		* @example 
		* &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
		* &lt;script&gt;
		* // enable the gantt
		* $("#gantt").ejGantt("destroy");	
		* &lt;/script&gt;
		* @memberof ejGantt
		* @instance
         */
        _destroy: function () {
            var proxy = this;
            proxy.element.empty().removeClass("e-gantt-core e-gantt " + proxy.model.cssClass);
        }
        


    });
    
    ej.Gantt.EditingType = {
        String: "stringedit",
        Boolean: "booleanedit",
        Numeric: "numericedit",
        Dropdown: "dropdownedit",
        DatePicker: "datepicker",
        DateTimePicker:"datetimepicker"
    };

    ej.Gantt.ToolbarItems = {
        Add: "add",
        Edit: "edit",
        Delete: "delete",
        Update: "update",
        Cancel: "cancel",
        Search: "search",
        Indent: "indent",
        Outdent: "outdent",
        ExpandAll: "expandAll",
        CollapseAll: "collapseAll",
        PrevTimeSpan: "prevTimeSpan",
        NextTimeSpan:"nextTimeSpan",
    };

    ej.Gantt.ScheduleHeaderType = {
        Year: "year",
        Month: "month",
        Week: "week",
        Day: "day"
    };

    ej.Gantt.DurationUnit = {
        Day: "day",
        Hour: "hour",
    };

    ej.Gantt.workingTimeScale = {
        TimeScale8Hours: "TimeScale8Hours",
        TimeScale24Hours: "TimeScale24Hours",
    };


    ej.Gantt.localization = {};

    ej.Gantt.localization["en-US"] = {

        //string to display with dataSource contains 0 objects
        emptyRecord: "No records to display",

        //headerText to be displayed in treegrid
        columnHeaderTexts: {
            taskId: "ID",
            taskName: "Task Name",
            startDate: "Start Date",
            endDate: "End Date",
            resourceInfo: "Resources",
            duration: "Duration",
            status: "Progress",
            predecessor: "Predecessor",
            baselineStartDate: "Baseline Start Date",
            baselineEndDate: "Baseline End Date"
        },

        //string to display in dialog 
        editDialogTexts: {
            addFormTitle: "New Task",
            editFormTitle: "Edit Task",
            saveButton: "Save",
            cancelButton: "Cancel"
        },

        calendars: {
            standard: {
                days: {
                    // full name of days
                    names: ["Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday"],
                    // abbreviated names of days
                    namesAbbr: ["Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"],
                },
                months: {
                    // full name of months
                    names: ["January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December"],
                    // abbreviated name of months
                    namesAbbr: ["Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"]
                },

                // set of predefined date and time patterns used by the culture.
                patterns: {
                    d: "M/d/yyyy",
                    D: "dddd, MMMM dd, yyyy",
                    F: "dddd, MMMM dd, yyyy h:mm:ss tt",
                    g: "M/d/yyyy h:mm tt",
                    G: "M/d/yyyy h:mm:ss tt",
                    m: "MMMM dd",
                    M: "MMMM dd",
                    s: "yyyy'-'MM'-'ddTHH':'mm':'ss",
                    t: "h:mm tt",
                    T: "h:mm:ss tt",
                    u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'",
                    y: "MMMM, yyyy",
                    Y: "MMMM, yyyy"
                }
            }
        }
    };

    /*-----Initialize the GanttRecord object--------------*/

    ej.Gantt.GanttRecord = function() {
        var proxy = this;
        proxy.taskId = null,
        proxy.taskName = null,
        proxy.startDate = null,
        proxy.endDate = null,
        proxy.duration = null,
        proxy.isMilestone = false,
        proxy.status = null,
        proxy.predecessor = null,
        proxy.resourceInfo = null,
        proxy.parentItem = null,
        proxy.isSelected = false,
        proxy.childRecords = null,
        proxy.hasChildRecords = false,
        proxy.expanded = false,
        proxy.level = 0,
        proxy.left = 0,
        proxy.width = 0,
        proxy.progressWidth = 0,
        proxy.item = null,
        proxy.baselineLeft = 0,
        proxy.baselineWidth = 0,
        proxy.baselineStartDate = null,
        proxy.baselineEndDate = null,
        proxy.isReadOnly = false;
    }

    ej.Gantt.GanttRecord.prototype = {

        //calculate the left position of the taskbar
        _calculateLeft: function (projectStartDate, dayWidth, holidays, model) {

            var proxy = this,
                diffDate,
                enddatecount = 0,
                beginDate = proxy._getDateFromFormat(proxy.startDate, model.dateFormat),
                endDate = proxy._getDateFromFormat(proxy.endDate, model.dateFormat),
                endDateHours = endDate && endDate.getHours(),
                endDateMinutes = endDate && endDate.getMinutes(),
                duration = 0, timeScale = model.workingTimeScale;

            if (endDate) {
                endDateHours = endDate.getHours();
                endDateMinutes = endDate.getMinutes();
            }

            if (model.durationUnit == ej.Gantt.DurationUnit.Hour) {
                if (model.durationMapping) {
                    if (timeScale == ej.Gantt.workingTimeScale.TimeScale24Hours) {
                        endDateHours = (parseInt(proxy.duration % 24) > 0) ? parseInt(proxy.duration % 24) : 0;
                        duration = endDateHours > 0 ? parseInt(proxy.duration / 24) + 1 : parseInt(proxy.duration / 24);

                    }
                    else if (timeScale == ej.Gantt.workingTimeScale.TimeScale8Hours) {
                        endDateHours = (parseInt(proxy.duration % 8) > 0) ? parseInt(proxy.duration % 8) : 0;
                        duration = endDateHours > 0 ? parseInt(proxy.duration / 8) + 1 : parseInt(proxy.duration / 8);
                    }
                }

            }
            else {
                duration = parseInt(proxy.duration);
            }

            if (endDate == null) {

                endDate = proxy._getDateFromFormat(proxy.startDate, model.dateFormat);
                endDate.setDate(endDate.getDate() + duration);
            }


            if (model.includeWeekend == false) {

                if (beginDate.getDay() == 0) {
                    beginDate.setDate(beginDate.getDate() + 1);
                }
                if (beginDate.getDay() == 6) {
                    beginDate.setDate(beginDate.getDate() - 1);
                }

                proxy._updateHoliday(beginDate, holidays, model.includeWeekend);

                var emptyDate = new Date(beginDate);
                for (var i = 0; i < duration; i++) {
                    if (emptyDate.getDay() == 0) {
                        enddatecount++;
                    } else if (emptyDate.getDay() == 6) {
                        enddatecount += 2;
                        emptyDate.setDate(emptyDate.getDate() + 2);
                    }
                    emptyDate.setDate(emptyDate.getDate() + 1);
                }
                endDate = new Date(beginDate);
                enddatecount = duration === 0 ? 1 : enddatecount;
                endDate.setDate(endDate.getDate() + (duration + enddatecount - 1));


                if (endDate.getDay() == 0) {
                    endDate.setDate(endDate.getDate() + 1);
                }
                if (endDate.getDay() == 6) {
                    endDate.setDate(endDate.getDate() + 2);
                }
            }

            else if (model.includeWeekend == true) {
                proxy._updateHoliday(beginDate, holidays, model.includeWeekend);
                endDate = new Date(beginDate);
                if (duration > 0) {
                    endDate.setDate(endDate.getDate() + (duration - 1));
                }

            }

            if (endDateHours) {
                if ((timeScale == ej.Gantt.workingTimeScale.TimeScale8Hours) &&
                    model.durationUnit == ej.Gantt.DurationUnit.Hour) {
                    if (endDateHours > 0)
                        endDate.setHours(8 + endDateHours);
                    else
                        endDate.setHours(17);
                }
                else
                    endDate.setHours(endDateHours);
            }
            else if ((timeScale == ej.Gantt.workingTimeScale.TimeScale8Hours && model.durationUnit == ej.Gantt.DurationUnit.Hour)) {
                endDate.setHours(17);
            }

            else if ((timeScale == ej.Gantt.workingTimeScale.TimeScale24Hours && model.dateFormat.indexOf("hh") != -1) ||
                (timeScale == ej.Gantt.workingTimeScale.TimeScale24Hours && model.durationUnit == ej.Gantt.DurationUnit.Hour)) {
                endDate.setHours(24);
            }

            // endDate.setMinutes(endDateMinutes);
            proxy.startDate = proxy._getFormatedDate(beginDate, model.dateFormat);
            proxy.endDate = proxy._getFormatedDate(endDate, model.dateFormat);

            if (model.endDateMapping)
                proxy.item[model.endDateMapping] = proxy.endDate;

            if (model.startDateMapping)
                proxy.item[model.startDateMapping] = proxy.startDate;
            diffDate = Math.round((beginDate - projectStartDate) / 86400000);

            if ((timeScale == ej.Gantt.workingTimeScale.TimeScale24Hours)
                && model.scheduleHeaderSettings.scheduleHeaderType != ej.Gantt.ScheduleHeaderType.Day) {
                diffDate = ((beginDate - projectStartDate) / 86400000);
            }

            else if ((timeScale == ej.Gantt.workingTimeScale.TimeScale8Hours ) &&
                model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Day &&
                model.dateFormat.indexOf("hh") == -1) {
                diffDate = ((beginDate - projectStartDate) / 86400000);
            }

            else if ((timeScale == ej.Gantt.workingTimeScale.TimeScale24Hours || timeScale == ej.Gantt.workingTimeScale.TimeScale8Hours) &&
                  model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Day &&
                   model.dateFormat.indexOf("hh") != -1) {

                diffDate = ((beginDate - projectStartDate) / 86400000);
            }

            else if ((timeScale == ej.Gantt.workingTimeScale.TimeScale8Hours) && model.roundOffDayworkingTime) {
                diffDate = Math.round((beginDate - projectStartDate) / 86400000);
            }


            return (diffDate * dayWidth);
        },

        //calculate the left margin of the baseLine element.
        _calculateBaselineLeft: function (projectStartDate, dayWidth, includeWeekend, dateformat) {

            var diffDate,
                proxy = this,
                beginDate = Globalize.parseDate(proxy.baselineStartDate, dateformat),
                duration = parseInt(proxy.duration),
                enddate = proxy.endDate;

            if (enddate == null) {
                enddate = new Date(beginDate);
                enddate.setDate(enddate.getDate() + duration);
            }
            diffDate = Math.ceil((beginDate - projectStartDate) / 86400000);
            return (diffDate * dayWidth);
        },

        _updateHoliday: function (date, holidays, includeWeekend) {
            var j = 0,
                length = holidays && holidays.length;

            if (length > 0) {

                for (j = 0; j < length; j++) {

                    if (holidays[j].getDate() == date.getDate()) {
                        date.setDate(date.getDate() + 1);
                    }

                }

                if ((includeWeekend == false) && (date.getDay() == 6)) {
                    date.setDate(date.getDate() + 2);
                }
            }
        },

        _calculateGanttRecordLeft: function (startDate, projectStartDate, dayWidth) {
            var proxy = this,
                diffDate = proxy._daydiff(projectStartDate, startDate);
            return (diffDate * dayWidth);
        },

        _calculateReverseLeft: function (projectStartDate, dayWidth, includeWeekend, dateformat) {
            var diffDate,
                proxy = this,
                enddatecount = 0,
                startdate = proxy.startDate,
                duration = proxy.duration && parseInt(proxy.duration);

            if (startdate == null) {

                startdate = proxy._getDateFromFormat(proxy.endDate);
                startdate.setDate(startdate.getDate() - duration);
            }
            if (includeWeekend == false) {

                var emptyDate = proxy._getDateFromFormat(proxy.endDate, dateformat);

                for (var i = 0; i < duration; i++) {

                    if (emptyDate.getDay() == 0) {
                        enddatecount += 2;
                        emptyDate.setDate(emptyDate.getDate() - 2);
                    }
                    else if (emptyDate.getDay() == 6) {
                        enddatecount++;
                    }
                    emptyDate.setDate(emptyDate.getDate() - 1);
                }
                startdate = proxy._getDateFromFormat(proxy.endDate, dateformat);
                enddatecount = duration === 0 ? 1 : enddatecount;
                startdate.setDate(startdate.getDate() - (duration + enddatecount - 1));
            }
            proxy.startDate = proxy._getFormatedDate(startdate, dateformat);
            diffDate = Math.ceil((startdate - projectStartDate) / 86400000);
            return (diffDate * dayWidth);
        },

        _calculateReverseWidth: function (dayWidth, dateFormat, includeWeekend, holidays) {

            var proxy = this,
                enddatecount = 0,
                diffDate,
                emptyDate,
                i = 0,
                startdate = proxy.startDate,
                duration = proxy.duration && parseInt(proxy.duration),
                enddate = proxy.endDate;

            if (startdate == null) {
                startdate = proxy._getDateFromFormat(enddate, dateFormat);
                startdate.setDate(startdate.getDate() - duration + 1);

            }

            if (includeWeekend == false) {

                emptyDate = proxy._getDateFromFormat(enddate, dateFormat);

                for (i = 0; i < duration; i++) {

                    if (emptyDate.getDay() == 0) {

                        enddatecount += 2;
                        emptyDate.setDate(emptyDate.getDate() - 2);

                    } else if (emptyDate.getDay() == 6) {
                        enddatecount++;
                    }

                    emptyDate.setDate(emptyDate.getDate() - 1);

                }

                startdate = proxy._getDateFromFormat(enddate, dateFormat);
                startdate.setDate(startdate.getDate() - (duration + enddatecount - 1));
            }

            if (holidays != null && holidays.length > 0) {

                emptyDate = proxy._getDateFromFormat(startdate, dateFormat);

                for (i = 0; i < duration; i++) {

                    emptyDate.setDate(emptyDate.getDate() + 1);

                    for (var j = 0; j < holidays.length; j++) {

                        if (new Date(holidays[j].day).getDate() == emptyDate.getDate()) {
                            enddatecount++;
                        }

                    }

                    if ((includeWeekend == false) && (emptyDate.getDay() == 0 || emptyDate.getDay() == 6)) {
                        enddatecount++;
                    }

                }

                enddate = proxy._getDateFromFormat(proxy.startDate, dateFormat);
                enddate.setDate(enddate.getDate() + (duration + enddatecount - 1));
            }

            diffDate = Math.ceil((proxy._getDateFromFormat(enddate, dateFormat) - proxy._getDateFromFormat(proxy.startDate, dateFormat)) / 86400000) + 1;

            return (diffDate) * dayWidth;
        },

        _calculateWidth: function (dayWidth, holidays, model) {

            var proxy = this,
                diffDate,
                startdate = proxy.startDate,
                enddate = proxy.endDate,
                duration = proxy.duration;

            if (enddate == null) {
                duration = parseInt(duration);
                enddate = proxy._getFormatedDate(startdate, model.dateFormat);
                enddate.setDate(enddate.getDate() + duration - 1);
            }

            proxy._calculateEndDate(model.includeWeekend, holidays, model, dayWidth);

            if (model.durationUnit == ej.Gantt.DurationUnit.Hour) {
                if (model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale24Hours) {
                    if (model.durationUnit == ej.Gantt.DurationUnit.Hour && model.dateFormat.indexOf("hh") == -1) {
                        diffDate = proxy.duration;
                    }
                    else {
                        diffDate = proxy._hourdiff(proxy._getDateFromFormat(proxy.startDate, model.dateFormat),
                        proxy._getDateFromFormat(proxy.endDate, model.dateFormat));
                    }
                }
                else if (model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale8Hours) {
                    if (model.durationUnit == ej.Gantt.DurationUnit.Hour && model.dateFormat.indexOf("hh") == -1) {
                        diffDate = (proxy.duration / 8) * 24 + (proxy.duration % 8);
                    }
                    else {
                        diffDate = proxy._hourdiff(proxy._getDateFromFormat(proxy.startDate, model.dateFormat),
                        proxy._getDateFromFormat(proxy.endDate, model.dateFormat));
                    }
                }
                return (diffDate * (dayWidth / 24));
            }
            else {
                if ((model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale24Hours)
                      && model.scheduleHeaderSettings.scheduleHeaderType != ej.Gantt.ScheduleHeaderType.Day &&
                    (model.dateFormat.indexOf("hh:") != -1)) {
                    diffDate = ((proxy._getDateFromFormat(proxy.endDate, model.dateFormat) -
                        proxy._getDateFromFormat(proxy.startDate, model.dateFormat)) / 86400000);// + 1;//Math.ceil
                }

                else if ((model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale24Hours)
                  && model.scheduleHeaderSettings.scheduleHeaderType != ej.Gantt.ScheduleHeaderType.Day &&
                   (model.dateFormat.indexOf("hh:") == -1)) {
                    diffDate = ((proxy._getDateFromFormat(proxy.endDate, model.dateFormat) -
                        proxy._getDateFromFormat(proxy.startDate, model.dateFormat)) / 86400000) + 1;//Math.ceil
                }
                    //Calculating width for 8 hour timescale  for dateformats without time
                else if ((model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale8Hours) &&
                model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Day &&
                    model.durationUnit != ej.Gantt.DurationUnit.Hour) {

                    var tStartDate = new Date(proxy.startDate),
                        tEndDate = new Date(proxy.endDate);
                    tStartDate.setHours(8);
                    tEndDate.setHours(17);

                    diffDate = ((tEndDate - tStartDate) / 86400000);
                }

                else if ((model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale8Hours) &&
                         model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Day &&
                         model.durationUnit == ej.Gantt.DurationUnit.Hour) {
                    var tStartDate = new Date(proxy.startDate),
                       tEndDate = new Date(proxy.endDate);

                    diffDate = ((tEndDate - tStartDate) / 86400000);
                }

                else if (model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale8Hours || model.roundOffDayworkingTime)
                    diffDate = Math.round((proxy._getDateFromFormat(proxy.endDate, model.dateFormat) -
                        proxy._getDateFromFormat(proxy.startDate, model.dateFormat)) / 86400000) + 1;


                return (diffDate) * dayWidth;
            }
        },


        _calculateTaskbarWidth: function (dayWidth, model) {
            var proxy = this,
                diffDate = 0,
                dateFormat = model.dateFormat,
                timeScale = model.workingTimeScale;

            if (model.durationUnit == ej.Gantt.DurationUnit.Hour) {
                if (model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale24Hours) {

                    if (model.durationUnit == ej.Gantt.DurationUnit.Hour && model.dateFormat.indexOf("hh") == -1) {
                        diffDate = proxy.duration;
                    }
                    else {
                        diffDate = proxy._hourdiff(proxy._getDateFromFormat(proxy.startDate, dateFormat),
                        proxy._getDateFromFormat(proxy.endDate, dateFormat));
                    }
                }
                else if (model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale8Hours) {
                    if (model.durationUnit == ej.Gantt.DurationUnit.Hour && model.dateFormat.indexOf("hh") == -1) {
                        diffDate = proxy.duration;
                    }
                    else {
                        diffDate = proxy._hourdiff(proxy._getDateFromFormat(proxy.startDate, dateFormat),
                        proxy._getDateFromFormat(proxy.endDate, dateFormat));
                    }
                }
                return (diffDate * (dayWidth / 24));
            }
            else {
                if (timeScale == ej.Gantt.workingTimeScale.TimeScale24Hours &&
                    model.scheduleHeaderSettings.scheduleHeaderType != ej.Gantt.ScheduleHeaderType.Day && model.dateFormat.indexOf("hh") == -1) {
                    diffDate = proxy._daydiff(proxy._getDateFromFormat(proxy.startDate, dateFormat),
                    proxy._getDateFromFormat(proxy.endDate, dateFormat)) + 1;

                }

                else if (timeScale == ej.Gantt.workingTimeScale.TimeScale24Hours) {
                    diffDate = proxy._daydiff(proxy._getDateFromFormat(proxy.startDate, dateFormat),
                    proxy._getDateFromFormat(proxy.endDate, dateFormat));
                }//+ 1;

                else if (timeScale == ej.Gantt.workingTimeScale.TimeScale8Hours) {
                    diffDate = Math.round(proxy._daydiff(proxy._getDateFromFormat(proxy.startDate, dateFormat),
                        proxy._getDateFromFormat(proxy.endDate, dateFormat)) + 1);
                }
                else {
                    diffDate = proxy._daydiff(proxy._getDateFromFormat(proxy.startDate, dateFormat),
                        proxy._getDateFromFormat(proxy.endDate, dateFormat));//+ 1;
                }
                return (diffDate * dayWidth);
            }
        },
        _calculateBaseLineWidth: function (dayWidth, model)
        {
            var proxy = this,
                diffDate = 0,
                dateFormat = model.dateFormat,
                timeScale = model.workingTimeScale;

            if (model.durationUnit == ej.Gantt.DurationUnit.Hour) {
                if (model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale24Hours) {

                    if (model.durationUnit == ej.Gantt.DurationUnit.Hour && model.dateFormat.indexOf("hh") == -1) {
                        diffDate = proxy.duration;
                    }
                    else {
                        diffDate = proxy._hourdiff(proxy._getDateFromFormat(proxy.baselineStartDate, dateFormat),
                        proxy._getDateFromFormat(proxy.baselineEndDate, dateFormat));
                    }
                }
                else if (model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale8Hours) {
                    if (model.durationUnit == ej.Gantt.DurationUnit.Hour && model.dateFormat.indexOf("hh") == -1) {
                        diffDate = proxy.duration;
                    }
                    else {
                        diffDate = proxy._hourdiff(proxy._getDateFromFormat(proxy.baselineStartDate, dateFormat),
                        proxy._getDateFromFormat(proxy.baselineEndDate, dateFormat));
                    }
                }
                return (diffDate * (dayWidth / 24));
            }
            else {
                if (timeScale == ej.Gantt.workingTimeScale.TimeScale24Hours &&
                    model.scheduleHeaderSettings.scheduleHeaderType != ej.Gantt.ScheduleHeaderType.Day && model.dateFormat.indexOf("hh") == -1) {
                    diffDate = proxy._daydiff(proxy._getDateFromFormat(proxy.baselineStartDate, dateFormat),
                    proxy._getDateFromFormat(proxy.baselineEndDate, dateFormat)) + 1;

                }

                else if (timeScale == ej.Gantt.workingTimeScale.TimeScale24Hours) {
                    diffDate = proxy._daydiff(proxy._getDateFromFormat(proxy.baselineStartDate, dateFormat),
                    proxy._getDateFromFormat(proxy.baselineEndDate, dateFormat));
                }//+ 1;

                else if (timeScale == ej.Gantt.workingTimeScale.TimeScale8Hours) {
                    diffDate = Math.round(proxy._daydiff(proxy._getDateFromFormat(proxy.baselineStartDate, dateFormat),
                        proxy._getDateFromFormat(proxy.baselineEndDate, dateFormat)) + 1);
                }
                else {
                    diffDate = proxy._daydiff(proxy._getDateFromFormat(proxy.baselineStartDate, dateFormat),
                        proxy._getDateFromFormat(proxy.baselineEndDate, dateFormat));//+ 1;
                }
                return (diffDate * dayWidth);
            }
        },
        _getFormatedDate: function (dateObject, dateformat) {
            return Globalize.format(dateObject, dateformat);
        },

        _getDateFromFormat: function (dateString, dateformat) {
            if (dateString) {
                return Globalize.parseDate(dateString, dateformat) == null ?
                    new Date(dateString) : Globalize.parseDate(dateString, dateformat);
            }
        },

        _calculateProgressWidth: function (parentWidth, percent) {
            return (parentWidth * percent) / 100;
        },

        _setResourceInfo: function (resourceIdcollection, resourceIdMapping, resourceNameMapping, resourcecollection) {

            var count = 0,
            length = resourceIdcollection.length,
            resources = [];

            for (count; count < length; count++) {

                var resource = resourcecollection.filter(function (resourceInfo) {
                    return resourceIdcollection[count] === resourceInfo[resourceIdMapping];
                });

                resource.length && resources.push(resource[0]);
            }
            return resources;
        },

        _updateEndDate: function (prevStartDate, includeWeekend, dateFormat) {
            var proxy = this,
                formatedPrevStartDate = new Date(prevStartDate),
                formatedStartDate = proxy._getDateFromFormat(proxy.startDate, dateFormat),
                diff = proxy._daydiff(formatedPrevStartDate, formatedStartDate),
            endDate = proxy._getDateFromFormat(proxy.endDate, dateFormat),
            weekendCount = 0;

            if (includeWeekend == false) {
                var count = 0;
                for (count; count <= diff; count++) {
                    endDate.setDate(endDate.getDate() + 1);
                    if (endDate.getDay() == 0 || endDate.getDay() == 6)
                        weekendCount += 1;
                }
            }

            var modifiedEndDate = proxy._getDateFromFormat(proxy.endDate, dateFormat);
            modifiedEndDate.setDate(modifiedEndDate.getDate() + diff + weekendCount);
            proxy.endDate = proxy._getFormatedDate(modifiedEndDate, dateFormat);
        },

        _calculateFormatedDate: function (date, format) {
            return Globalize.format(date, format);
        },

        _updateParentProgress: function (parent,progressMapping) {
            var parentProgress = 0,
                childCount = parent.childRecords && parent.childRecords.length,
                totalDuration = 0,
                completedDuration = 0;


            if (parent.childRecords) {
                for (var i = 0; i < childCount; i++) {

                    //converting days into hours .
                    //By now 24 hours is default
                    totalDuration += (parent.childRecords[i].duration * 24);

                    //summation of progress done of child
                    completedDuration += ((parent.childRecords[i].duration * 24) * parent.childRecords[i].status) / 100;
                  
                }

                parentProgress = (completedDuration / totalDuration) * 100;
                if (isNaN(parentProgress))
                    parentProgress = 0;
                parent.progressWidth = this._getProgressWidth(parent.width, parentProgress);
                parent.status = Math.round(parentProgress);
                if (progressMapping)
                    parent.item[progressMapping] = parent.status;

            }
            if (parent.parentItem) {
                this._updateParentProgress(parent.parentItem, progressMapping);
            }
        },


        _getProgressWidth: function (parentwidth, percent) {
            return (parentwidth * percent) / 100;
        },

        _calculatePredecessor: function (string) {
            var collection = [],
                match,
                obj = {},
                values,
                to = this.taskId.toString(),
                offsetvalue;
            string.split(',').forEach(function (el) {
                values = el.split('+');
                offsetvalue = '+';
                if (el.indexOf('-') >= 0) {
                    values = el.split('-');
                    offsetvalue = '-';
                }
                match = values[0].match(/(\d+|[A-z]+)/g);
                obj = {
                    from: match[0],
                    predecessorsType: match.length > 1 ? match[1].toUpperCase() : "FS",
                    offset: values.length > 1 ? offsetvalue + "" + values[1] : "",
                    isdrawn: false,
                    to: to
                };
                collection.push(obj);
            });
            return collection;
        },

        _updateGanttRecord: function (startDateMappingName, endDateMappingName, durationMappingName, includeWeekend, scheduleStartDay, perDayWidth, dateFormat, holidays) {
            var proxy = this,
                remainDays = proxy.left % perDayWidth,
                day = (proxy.left - remainDays) / perDayWidth,holiday
                startDate = new Date(scheduleStartDay);

            startDate.setDate(scheduleStartDay.getDate() + day);

            if (startDate.getDay() == 0)
                startDate.setDate(startDate.getDate() + 1);
            else if (startDate.getDay() == 6)
                startDate.setDate(startDate.getDate() + 2);

            proxy.startDate = proxy._getFormatedDate(startDate, dateFormat);
            proxy.left = proxy._calculateLeft(scheduleStartDay, perDayWidth, includeWeekend, dateFormat, endDateMappingName);
            proxy.width = proxy._calculateWidth(perDayWidth, includeWeekend, holidays, dateFormat);
            if (proxy.parentItem)
                proxy._updateParentItem(proxy, startDateMappingName, endDateMappingName, durationMappingName, includeWeekend, scheduleStartDay, perDayWidth, dateFormat, holidays);
        },

        _calculateUpdatedDate: function (modifiedDate, offset) {
            var proxy = this,
                i = 0;
            if (offset > 0) {
                for (i; i < offset; i++) {
                    modifiedDate = proxy._dataSubtract(modifiedDate, 1);
                    if (modifiedDate.getDay() == 0)
                        modifiedDate.setDate(modifiedDate.getDate() + 1);
                    else if (modifiedDate.getDay() == 6)
                        modifiedDate.setDate(modifiedDate.getDate() + 2);
                }
            } else {
                var dateOffset = (-1) * offset;
                for (i = 0; i < dateOffset; i++) {
                    modifiedDate = proxy._dataSubtract(modifiedDate, -1);
                    if (modifiedDate.getDay() == 0)
                        modifiedDate.setDate(modifiedDate.getDate() - 2);
                    else if (modifiedDate.getDay() == 6)
                        modifiedDate.setDate(modifiedDate.getDate() - 1);
                }
            }
            modifiedDate = proxy._getFormatedDate(modifiedDate);
            return modifiedDate;
        },

        _dataSubtract: function (date, days) {
            return new Date(
                date.getFullYear(),
                date.getMonth(),
                date.getDate() + days,
                date.getHours(),
                date.getMinutes(),
                date.getSeconds(),
                date.getMilliseconds()
            );
        },

        _calculateEndDate: function (includeWeekend, holidays,model, perDayWidth) {
            var proxy = this,
                count = 0,
                startDate = proxy._getDateFromFormat(proxy.startDate, model.dateFormat),
                endDate = proxy._getDateFromFormat(proxy.endDate, model.dateFormat),
                endDateHours = 0, endDateMinutes = 0,
                duration = 0,// proxy.duration && parseInt(proxy.duration),
                remainingHours = 0, totalLength, remainingLength;

            if (endDate) {
                endDateHours = endDate.getHours();
                endDateMinutes = endDate.getMinutes();
            }

            if (model.durationUnit == ej.Gantt.DurationUnit.Hour) {
                if (model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale24Hours) {
                    if (!model.endDateMapping) {
                        var totalHours = startDate.getHours() + proxy.duration;
                        endDateHours = (parseInt(totalHours % 24) > 0) ? parseInt(totalHours % 24) : 0;
                    } else {
                        if (endDate) {
                            endDateHours = endDate.getHours();
                            endDateMinutes = endDate.getMinutes();
                        } else {
                            endDateHours = (parseInt(proxy.duration % 24) > 0) ? parseInt(proxy.duration % 24) : 0;
                        }
                    }
                    duration = endDateHours > 0 ? parseInt((startDate.getHours() + proxy.duration) / 24) + 1 :
                        parseInt(startDate.getHours() + proxy.duration) / 24;
                   
                }
                else if (model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale8Hours) {
                    if (!model.endDateMapping) {
                        var totalHours = startDate.getHours() + proxy.duration;
                        endDateHours = (parseInt(totalHours % 8) > 0) ? parseInt(totalHours % 8) : 0;
                        endDateHours = proxy._calculateTimeScale8Hour(startDate.getHours(), proxy.duration) % 24;
                    }
                    else {
                        if (endDate) {
                            endDateHours = endDate.getHours();
                            endDateMinutes = endDate.getMinutes();
                        } else {
                            endDateHours = proxy._calculateTimeScale8Hour(startDate.getHours(), proxy.duration) % 24;
                        }
                    }
                    var endHour = proxy._calculateTimeScale8Hour(startDate.getHours(), proxy.duration);
                    var calculatedEndHour = parseInt(endHour / 24) < 1 ? 1 : parseInt(endHour / 24);
                    var checkEndDate = proxy._dateUpdate(startDate, 0, (endHour-startDate.getHours()));
                    if (checkEndDate.getHours() >= 8) {
                        calculatedEndHour += 1;
                    }
                    duration = endDateHours > 0 ? Math.round(calculatedEndHour)
                        : parseInt(proxy.duration) / 8;

                }
                 
                //duration = parseInt(proxy.duration);
            }
            else {
                duration = parseInt(proxy.duration);
            }

            
            if (proxy.width > 0) {
                totalLength = proxy.left + proxy.width;
                remainingLength = totalLength % perDayWidth;
                remainingHours = Math.round(remainingLength / (perDayWidth / 24));//hour calculation
            }

            if (duration === 0) {
                proxy.endDate = proxy.startDate;
                return;
            }

            if (includeWeekend === false) {
                for (count = 1; count < duration; count++) {
                    if (startDate.getDay() == 0)
                        startDate.setDate(startDate.getDate() + 1);
                    else if (startDate.getDay() == 6)
                        startDate.setDate(startDate.getDate() + 2);

                    startDate.setDate(startDate.getDate() + 1);
                }
            } else {
                startDate.setDate(startDate.getDate() + duration - 1);
            }

            if (includeWeekend === false) {
                if (startDate.getDay() == 0)
                    startDate.setDate(startDate.getDate() + 1);
                else if (startDate.getDay() == 6)
                    startDate.setDate(startDate.getDate() + 2);
            }

            if (holidays && holidays.length) {
                var holidayIndex = 0,
                    holidayslength = holidays.length,
                    holiday;
                for (holidayIndex = 0; holidayIndex < holidayslength; holidayIndex++) {
                    holiday = new Date(holidays[holidayIndex]);
                    if (holiday >= proxy._getDateFromFormat(proxy.startDate, model.dateFormat) && holiday <= startDate) {
                        startDate.setDate(startDate.getDate() + 1);
                        if (includeWeekend === false) {
                            if (startDate.getDay() == 0) {
                                startDate.setDate(startDate.getDate() + 1);
                            } else if (startDate.getDay() == 6) {
                                startDate.setDate(startDate.getDate() + 2);
                            }
                        }
                    }
                }
            }

            if (includeWeekend === false) {
                if (startDate.getDay() == 0)
                    startDate.setDate(startDate.getDate() + 1);
                else if (startDate.getDay() == 6)
                    startDate.setDate(startDate.getDate() + 2);
            }
            if (remainingHours > 0)
                startDate.setHours(remainingHours);//endDateHours
            if (endDateHours > 0) {
                if ((model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale8Hours) &&
                    model.durationUnit == ej.Gantt.DurationUnit.Hour) {
                    startDate.setHours(endDateHours);
                }
                else
                    startDate.setHours(endDateHours);
            }
            
            if (model.dateFormat.indexOf("hh:") &&
                      model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale8Hours &&
                model.scheduleHeaderSettings.scheduleHeaderType != ej.Gantt.ScheduleHeaderType.Day) {
                startDate.setHours(17);
            }
            else if (model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale24Hours
                && model.durationUnit == ej.Gantt.DurationUnit.Hour) {
                if (endDateHours > 0) {
                    startDate.setHours(endDateHours);
                }
                else
                    startDate.setHours(24);
            }

            
            proxy.endDate = proxy._calculateFormatedDate(startDate, model.dateFormat);
            if (model.endDateMapping)
                proxy.item[model.endDateMapping] = proxy.endDate;
        },

        _calculateTimeScale8Hour: function (startHour, duration) {
            var endHour = startHour;

            do {
                if ((startHour >= 8 && startHour < 13) || (startHour > 13 && startHour <= 17)) {
                    endHour++;
                    duration--;
                    startHour = startHour == 24 ? 0 : startHour + 1;
                }
                else {
                    startHour = startHour == 24 ? 0 : startHour + 1;
                    
                    endHour++;
                }
            } while (duration > 0);

            return endHour;
        },

        _dateUpdate: function (date, days,hours) {
            return new Date(
                date.getFullYear(),
                date.getMonth(),
                date.getDate() + days,
                date.getHours() + hours,
                date.getMinutes(),
                date.getSeconds(),
                date.getMilliseconds()
            );
        },


        _calculateDuration: function (startDate, endDate, includeWeekend, holidays, milestone,model) {
            var proxy = this,
            dateDiff;

            if (model.durationUnit == ej.Gantt.DurationUnit.Hour) {
                dateDiff = proxy._hourdiff(startDate, endDate);
                if (dateDiff < 0) {
                    //dateDiff = dateDiff * -1;
                }
                if (model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale8Hours) {
                }
            }
            else {
                dateDiff = proxy._daydiff(startDate, endDate);
            }

            if (includeWeekend === false)
                offset = proxy._calculateDateDifference(new Date(startDate), dateDiff);
            else {
                if (model.durationUnit != ej.Gantt.DurationUnit.Hour)
                    offset = dateDiff + 1;
                else
                    offset = dateDiff;
            }

            for (var count = 0; count < holidays.length; count++) {
                if (new Date(holidays[count].day) >= startDate && new Date(holidays[count].day) <= endDate) {
                    if (model.durationUnit == ej.Gantt.DurationUnit.Hour)
                        offset -= 24;
                    else
                        offset--;
                }
            }

            if (model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale24Hours ||
                model.durationUnit == ej.Gantt.DurationUnit.Hour) {

                var decimal = (offset - parseInt(offset, 10));
                decimal = (decimal * 10);
                if (decimal == 5) { offset = (parseInt(offset, 10) + 0.5); }

                else {
                    offset = Math.round(offset);
                }
            }
            //else if (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Day) {

            //    offset = Math.round(offset) - 1;
            //}
            else
                offset = Math.round(offset);

            if (ej.isNullOrUndefined(milestone))
                proxy.duration = offset;
            else
                proxy.duration = (offset == 0 && milestone == false) ? 1 : offset;
        },

        _calculateDateDifference: function (emptyDate, dateDiff) {
            var differenceCount = dateDiff >= 0 ? dateDiff : (-1 * dateDiff),
                offset = 0;

            if (dateDiff > 0)
                offset = differenceCount - this._calculateWeekendCount(emptyDate, dateDiff) + 1;
            else
                offset = dateDiff + this._calculateWeekendCount(emptyDate, dateDiff);
            return offset;
        },

        _calculateWeekendCount: function (emptyDate, dateDiff) {
            var differenceCount = dateDiff >= 0 ? dateDiff : (-1 * dateDiff),
                weekendCount = 0,
                i = 0;

            if (dateDiff > 0) {
                for (i = 0; i < dateDiff; i++) {
                    if (emptyDate.getDay() == 0) {
                        weekendCount++;
                        emptyDate.setDate(emptyDate.getDate() + 1);
                    }
                    else if (emptyDate.getDay() == 6) {
                        weekendCount += 2;
                        ++i;
                        emptyDate.setDate(emptyDate.getDate() + 2);
                    } else
                        emptyDate.setDate(emptyDate.getDate() + 1);
                }
            }
            else {
                for (i = 0; i < differenceCount; i++) {
                    emptyDate.setDate(emptyDate.getDate() - 1);
                    if (emptyDate.getDay() == 0 || emptyDate.getDay() == 6) {
                        weekendCount += 1;
                    }
                }
            }
            return weekendCount;
        },

        _daydiff: function (first, second) {
            return ((second - first) / (1000 * 60 * 60 * 24));
        },
               
        _hourdiff: function (first, second) {
            //if(first.getTime()>second.getTime())
            //    return ((first - second) / (1000 * 60 * 60));
            //else
                return ((second - first) / (1000 * 60 * 60));
        },

        _getProgressPercent: function (parentwidth, progresswidth) {
            return Math.ceil(((progresswidth / parentwidth) * 100).toFixed(2));
        },

    };

    ej.Gantt._getPredecessorsValue = function (mappingName) {
        return this.data.item ? this.data.item[mappingName] : "";
    };    

    ej.Gantt._getCellValue = function (columnName) {

        var cellValue = this.data[columnName];

        if (cellValue) {
            return cellValue;
        } else {
            return this.data.item && this.data.item[columnName];
        }


    };

})(jQuery, Syncfusion);;
/**
 * @fileOverview Plugin to style the Html TreeGrid elements
 * @copyright Copyright Syncfusion Inc. 2001 - 2014. All rights reserved.
 *  Use of this code is subject to the terms of our license.
 *  A copy of the current license can be obtained at any time by e-mailing
 *  licensing@syncfusion.com. Any infringement will be prosecuted under
 *  applicable laws. 
 * @version 12.1 
 * @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
 */

(function ($, ej, undefined) {
    /**
* @namespace ej
* @class ejTreeGrid
* @requires jQuery
* @requires jquery.globalize.js
* @requires jquery.easing.1.3.js
* @requires jsrender.js
* @requires ej.web.all.js
* @classdesc Custom Design for Html Tree grid control.
* @example 
* &lt;treegrid id="treegrid"&gt;treegrid&lt;/treegrid&gt; <br> 
* &lt;script&gt;
* // Create TreeGrid
* $('#treegrid').ejTreeGrid(); 	
* &lt;/script&gt;
*/
    ej.widget("ejTreeGrid", "ej.TreeGrid", {
        // widget element will be automatically set in this
        _rootCSS: "e-treegrid",

        // widget element will be automatically set in this
        element: null,

        validTags: ["div"],

        // user defined model will be automatically set in this
        model: null,

        _tags: [
        {
            tag: "columns",
            attr: ["field", "headerText", "allowSorting", "editType", "allowFiltering", "filterEditType","width"],
            content: "template"
        },
        {
            tag: "sortSettings.sortedColumns",
            attr: ["field", "direction"]
        },
        {
            tag: "sizeSettings",
            attr:["height","width"]
        }
        ],
        _columns: function (index, property, value, old){
            var $header = this.element.find(".e-headercelldiv");
            $header[index.columns].innerHTML=value;
            this._trigger("refresh");
        },
            keyConfigs: {
            focus: "e",
            editRecord: "113", //F2
            saveRequest: "13", // enter
            cancelRequest: "27", //Esc         
            firstRowSelection: "36", //"CtrlPlusHome",
            lastRowSelection: "35", //"CtrlPlusEnd",
            leftArrow:"37",//Left arrow
            upArrow: "38", //Up arrow
            rightArrow:"39",//Right arrow
            downArrow: "40", //Down arrow
            moveCellRight: "9", //tab
            moveCellLeft: "shift+9", //shifttab
            selectedRowExpand: "alt+40", //"AltPlusDownArrow",
            totalRowExpand: "ctrl+40", //"CtrlPlusDownArrow",
            selectedRowCollapse: "alt+38", //"AltPlusUpArrow",
            totalRowCollapse: "ctrl+38" //"CtrlPlusUpArrow"
        },
      
        defaults: {
            /**		
			* Enables or disables Filtering fields column wise. 
			* @default false
			* @type {boolean}
			* @example 
			* &lt;treegrid id="treegrid"&gt;treegrid&lt;/treegrid&gt; <br> 
			* &lt;script&gt;
			 * 	$("#treegrid").ejTreeGrid({  allowFiltering : true });
			* &lt;/script&gt;
			* @memberof ejTreeGrid
			* @instance
			*/
            allowFiltering: false,
            /**		
			* To change filterBarMode either immediate or onEnter. 
			* @default immediate
			* @type {enum}
			* @example 
			* &lt;treegrid id="treegrid"&gt;treegrid&lt;/treegrid&gt; <br> 
			* &lt;script&gt;
			 * 	$("#treegrid").ejTreeGrid({  filterBarMode : "onEnter" });
			* &lt;/script&gt;
			* @memberof ejTreeGrid
			* @instance
			*/
            filterBarMode:"immediate",
            /**		
			* Enables or disables sorting. When enabled, we can sort the column by clicking on the column. 
			* @default false
			* @type {boolean}
			* @example 
			* &lt;treegrid id="treegrid"&gt;treegrid&lt;/treegrid&gt; <br> 
			* &lt;script&gt;
			 * 	$("#treegrid").ejTreeGrid({  editSettings:{allowSorting : true} });
			* &lt;/script&gt;
			* @memberof ejTreeGrid
			* @instance
			*/
            allowSorting: false,
            /**		
             * Enables or disables the ability to resize column.
             * @default false
             * @type {boolean}
             * @example 
             * &lt;div id="treegrid"&gt;&lt;/div&gt; 
             * &lt;script&gt;                   
             * 	$("#treegrid").ejTreeGrid({ allowColumnResize:  true });			* 
             * &lt;/script&gt;
             * @memberof ejTreeGrid
             * @instance
             */
            allowColumnResize: false,
           
            /**		
            * Enables or disables the interactive selection of a row.
            * @default true
            * @type {boolean}
            * @example 
            * &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;   
            * 	$("#treegrid").ejTreeGrid({ allowSelection:  true });			* 
            * &lt;/script&gt;
            * @memberof ejTreeGrid
            * @instance
            */
            allowSelection: true,
           
            /**		
           * Collection of data or hierarchical data  to represent in  TreeGrid
           * @default 
           * @type {array}
           * @example 
           * &lt;div id="treegrid"&gt;&lt;/div&gt; 
           * &lt;script&gt; 		
           * 	$("#treegrid").ejTreeGrid(
           *  {
           *     dataSource:[{Id:2,TaskName:"Testing",startDate:"12/1/2000",Duration:5 }]	
           *  });		
           * &lt;/script&gt;
           * @memberof ejTreeGrid
           * @instance
           */

            dataSource: null,
           
            /**		
            * It receives query to retrieve data from the table (query is same as SQL). 
            * @default 
            * @type {object}
            * @example
            * &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;  			
            * 	$("#treegrid").ejTreeGrid(
            *  {
            *     query:ej.Query().from("Categories").select("CategoryID,CategoryName").take(3);	
            *  });		
            * &lt;/script&gt;
            * @memberof ejTreeGrid
            * @instance
            */
            query: ej.Query(),
            /**		
           * Specifies the mapping property path for child Id in self reference datasource
           * @default ""
           * @type {string}
           * @example 
           * &lt;div id="treegrid"&gt;&lt;/div&gt; 
           * &lt;script&gt;  		
           * 	$("#treegrid").ejTreeGrid({  IdMapping : "ID" });	            
           * &lt;/script&gt;
           * @memberof ejTreeGrid
           * @instance
           */
            idMapping: "",


            /**		
            * Specifies the mapping property path for parent Id in self reference datasource
            * @default ""
            * @type {string}
            * @example 
            * &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;  		
            * 	$("#treegrid").ejTreeGrid({  parentIdMapping : "ID" });	            
            * &lt;/script&gt;
            * @memberof ejTreeGrid
            * @instance
            */
            parentIdMapping: "",
            
            /**		
           * Specifies whether to show grid cell tooltip.
           * @default "true"
           * @type {boolean}
           * @example 
           * &lt;div id="treegrid"&gt;&lt;/div&gt; 
           * &lt;script&gt; 			
           * 	$("#treegrid").ejTreeGrid({  
           *			showGridCellTooltip : true});
           * &lt;/script&gt;
           * @memberof ejTreeGrid
           * @instance
           */
            showGridCellTooltip: false,

            /**		
            *Specifies whether to show grid cell tooltip over expander cell alone.
            * @default "true"
            * @type {boolean}
            * @example 
            * &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#treegrid").ejTreeGrid({  
            *			showGridExpandCellTooltip : true});
            * &lt;/script&gt;
            * @memberof ejTreeGrid
            * @instance
            */

            showGridExpandCellTooltip: false,

            /**		
           * Enables/Disables enableAltRow row effect in TreeGrid
           * @default true
           * @type {boolean}
           * @example 
           * &lt;div id="treegrid"&gt;&lt;/div&gt; 
           * &lt;script&gt;			
           * 	$("#treegrid").ejTreeGrid({ enableAltRow : false});			
           * &lt;/script&gt;
		   * @memberof ejTreeGrid
           * @instance
           */
            enableAltRow: true,
			
            /**		
           * Specifies the selected row index.
           * @default null
           * @type {numeric}
           * @example 
           * &lt;div id="treegrid"&gt;&lt;/div&gt; 
           * &lt;script&gt;			
           * 	$("#treegrid").ejTreeGrid({ selectedItem : 2});			
           * &lt;/script&gt;
		   * @memberof ejTreeGrid
           * @instance
           */
            selectedItem: null,

            /**		
           * Specifies the toolbarSettings options.
           * @type {object}
           * @memberof ejTreeGrid
           * @instance
           */
            toolbarSettings: {

                /**		
                * Specifies the state of enabling or disabling toolbar
                 * @alias ejTreeGrid#toolbarSettings->showToolBar
                * @default false
                * @type {boolean}
                * @example 
                * &lt;div id="treegrid"&gt;&lt;/div&gt; 
                * &lt;script&gt;	
                * 	$("#treegrid").ejTreeGrid({ showToolBar:  true });			 
                * &lt;/script&gt;
                * @memberof ejTreeGrid
			    * @instance
                */
                showToolbar: false,


                /**		
                * Specifies the list of toolbar items to rendered in toolbar
                * @alias ejTreeGrid#toolbarSettings->toolbarItems
                * @default []
                * @type {array}
                * @example 
                * &lt;div id="treegrid"&gt;&lt;/div&gt; 
                * &lt;script&gt;	
                * 	$("#treegrid").ejTreeGrid({ toolbarItems: [ej.TreeGrid.ToolbarItems.Add,ej.TreeGrid.ToolbarItems.Edit] });			 
                * &lt;/script&gt;
                * @memberof ejTreeGrid
			    * @instance
                */
                toolbarItems: []
            },
            /* editing API's */
            /**		
            * Specifies the editSettings options in treegrid. 
            * @type {object}
            * @memberof ejTreeGrid
            * @instance
            */
            editSettings: {
                /**		
           * specifies the option for enabling / disablig editing in treegrid part
           * @alias ejTreeGrid#editSettings->allowEditing
           * @default false
           * @type {boolean}
           * @example 
           * &lt;div id="treegrid"&gt;&lt;/div&gt; 
           * &lt;script&gt;			
           * 	$("#treegrid").ejTreeGrid({  editSettings:{allowEditing : true} });	
           * &lt;/script&gt;
           * @memberof ejTreeGrid
           * @instance
           */
                allowEditing: false,
                /**		
           * enables/disables add treegrid in toolbar
           * @alias ejTreeGrid#editSettings->allowAdding
           * @default true
           * @type {boolean}
           * @example 
           * &lt;div id="treegrid"&gt;&lt;/div&gt; 
           * &lt;script&gt; 			
           * 	$("#treegrid").ejTreeGrid({  editSettings:{allowAdding : true} });
           * &lt;/script&gt;
           * @memberof ejTreeGrid
           * @instance
           */
                allowAdding: true,
                /**		
            * enables/disables delete treegrid in toolbar
            * @alias ejTreeGrid#editSettings->allowDeleting
            * @default true
            * @type {boolean}
            * @example 
            * &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#treegrid").ejTreeGrid({  editSettings:{allowDeleting : true} });	
            * &lt;/script&gt;
			* @memberof ejTreeGrid
            * @instance
            */
                allowDeleting: true,
                /**		
            * specifies the editmode in treegrid , "normal" is for dialog editing ,"cellEditing" is for cell type editing
            * @alias ejTreeGrid#editSettings->editMode
            * @default cellEditing
            * @type {string}
            * @example 
            * &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#treegrid").ejTreeGrid({  editSettings:{editMode : "normal"} });
            * &lt;/script&gt;
			* @memberof ejTreeGrid
            * @instance
            */
                editMode: "cellEditing",

				/**  
            * Specifies the position where the newly added row want to add.
			* @alias ejTreeGrid#editSettings->rowPosition
            * @default top
            * @type {string}
            * @example 
            * &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;   
            *  $("#treegrid").ejTreeGrid({  editSettings:{rowPosition : "aboveSelectedRow"} });
            * &lt;/script&gt;
			* @memberof ejTreeGrid
            * @instance
            */
                rowPosition: "top",
            },     
                       
            /**		
            * Enables/Disables virtualization for rendering TreeGrid items.
            * @default false
            * @type {boolean}
            * @example 
            * &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#treegrid").ejTreeGrid({ enableVirtualization : true});			
            * &lt;/script&gt;
            * @memberof ejTreeGrid
            * @instance
            */
            enableVirtualization: false,
                    
            /**		
           * Specifies enabling / diabling multiple sorting for tree grid columns
           * @default false
           * @type {boolean}
           * @example 
           * &lt;div id="treegrid"&gt;&lt;/div&gt; 
           * &lt;script&gt;			
           * 	$("#treegrid").ejTreeGrid({ allowMultiSorting : true});			
           * &lt;/script&gt;
           * @memberof ejTreeGrid
           * @instance
           */
            allowMultiSorting: false,
          
            /**		
            *  Specifes the sorting options for Treegrid.
            * @type {object}
            * @memberof ejTreeGrid
            * @instance
            */
            sortSettings: {
                /**		
           * Specifes the sorted columns for Tree grid
           * @alias ejTreeGrid#sortSettings->sortedColumns
           * @default []
           * @type {array}
           * @example 
           * &lt;div id="treegrid"&gt;&lt;/div&gt; 
           * &lt;script&gt;		
           * 	$("#treegrid").ejTreeGrid({ sortSettings{sortedColumns : []}});	           
           * &lt;/script&gt;
           * @instance
            */
                sortedColumns: []
            },

           

            /**		
           * Specifes the single or multiple row selection           
           * @default "single"
           * @type {string}
           * @example 
           * &lt;div id="treegrid"&gt;&lt;/div&gt; 
           * &lt;script&gt;		
           * 	$("#treegrid").ejTreeGrid({ selectionType:"multiple" });	           
           * &lt;/script&gt;
           * @memberof ejTreeGrid
           * @instance
            */

            selectionType: "single",
           
            /**		
          * Specifies the selected row Index in Treegrid , the row with given index is highlighted
          * @default  "-1"
          * @type {number}
          * @example 
          * &lt;div id="treegrid"&gt;&lt;/div&gt; 
          * &lt;script&gt;			
          * 	$("#treegrid").ejTreeGrid(
          *  {
          *     selectedRowIndex:2
          *  });		
          * &lt;/script&gt;
          * @memberof ejTreeGrid
          * @instance
          */
            selectedRowIndex: -1,
          
            /**		
            * Enables/Disables Keyboard navigation in treegrid
            * @default true
            * @type {boolean}
            * @example 
            * &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt; 			
            * 	$("#treegrid").ejTreeGrid({ allowKeyboardNavigation : true});			
            * &lt;/script&gt;
            * @memberof ejTreeGrid
            * @instance
            */
            
            allowKeyboardNavigation: true,

           
            /**		
             * Specify the CSS class to tree grid to achieve custom theme.
             * @default ""
             * @type {string}
             * @example 
             * &lt;div id="treegrid"&gt;&lt;/div&gt; 
             * &lt;script&gt;		
             * 	$("#treegrid").ejTreeGrid({  cssClass : "gradient-lime" });
             * &lt;/script&gt;
             * @memberof ejTreeGrid
             * @instance
            */
            cssClass: "",
           
            locale: "en-US",

            isEdit: false,

            allowScrolling: false,
            groupSettings: {
                groupedColumns:[]
            },
            /**		
            *  Specifes the size options for Treegrid.
            * @type {object}
            * @memberof ejTreeGrid
            * @instance
            */
            sizeSettings: {
                /**		
             * Specify the height to tree grid.
			 * @alias ejTreeGrid#sizeSettings->height
             * @default "null"
             * @type {string}
             * @example 
             * &lt;div id="treegrid"&gt;&lt;/div&gt; 
             * &lt;script&gt;		
             * 	$("#treegrid").ejTreeGrid({sizeSettings{height:'450px'}});
             * &lt;/script&gt;
             * @memberof ejTreeGrid
             * @instance
            */
                height:null,
                /**		
                * Specify the width to tree grid.
				 * @alias ejTreeGrid#sizeSettings->width
                * @default "null"
                * @type {string}
                * @example 
                * &lt;div id="treegrid"&gt;&lt;/div&gt; 
                * &lt;script&gt;		
                * 	$("#treegrid").ejTreeGrid({sizeSettings{width:'500px'}});
                * &lt;/script&gt;
                * @memberof ejTreeGrid
                * @instance
                */
                width: null,
            },

            /**		
            * Specify the enableResize to tree grid.
            * @default "false"
            * @type {boolean}
            * @example 
            * &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;		
            * 	$("#treegrid").ejTreeGrid({enableResize:true});
            * &lt;/script&gt;
            * @memberof ejTreeGrid
            * @instance
            */
            enableResize:false,
            /* event function */
            /**    
            * Triggered while rendering each row
            * @event
            * @name ejTreeGrid#rowDataBound 
            * @param {Object} argument Arguments when rowDataBound event is triggered.  
            * @param {boolean} argument.cancel Returns the cancel option value.
            * @param {object} argument.rowElement Returns the row element of editing cell.
            * @param {object} argument.data Returns the data of edited cell record..
            * @example 
            * &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#treegrid").ejTreeGrid({
            *    rowDataBound: function (args) {}
            * });
            * &lt;/script&gt;
            * @instance
            */
            rowDataBound: null,

            /**    
            * Triggered while Treegrid is loaded
            * @event
            * @name ejTreeGrid#load 
            * @param {Object} argument Arguments when load event is triggered.             
            * @param {boolean} argument.cancel Returns the cancel option value.
			* @param {object}  argument.model Returns the treegrid model
            * @param {string}  argument.type Returns the name of the event. 
            * @example 
            * &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#treegrid").ejTreeGrid({
            *    load: function (args) {}
            * });
            * &lt;/script&gt;
            * @memberof ejTreeGrid
			   * @instance
            */
            load: null,

            /**    
            * Triggered while rendering each cell in the grid tree
            * @event
            * @name ejTreeGrid#queryCellInfo 
            * @param {Object} argument Arguments when queryCellInfo event is triggered.  
            * @param {boolean} argument.cancel Returns the cancel option value.
            * @param {object} argument.rowElement Returns the selecting row element.
            * @param {string} argument.cellValue Returns the value of cell.
            * @param {object} argument.data Returns the data of current cell record.
            * @param {object} argument.column Returns the column of cell belongs.
            * @example 
            * &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#treegrid").ejTreeGrid({
            *    queryCellInfo: function (args) {}
            * });
            * &lt;/script&gt;
            * @instance
            */
            queryCellInfo: null,

            /**    
			* Triggered before the row is going to be selected.
			* @event
			* @name ejTreeGrid#rowSelecting 
			* @param {Object} argument Arguments when rowSelecting event is triggered.  
			* @param {boolean} argument.cancel Returns the cancel option value.
			* @param {object} argument.rowElement Returns the selecting row element.
			* @param {string} argument.recordIndex Returns the index of selecting row record.
			* @param {object} argument.data Returns the data selecting record.
			* @example 
			* &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;
			* $("#treegrid").ejTreeGrid({
			*    rowSelecting: function (args) {}
			* });
			* &lt;/script&gt;
            * @memberof ejTreeGrid
			   * @instance
            */
            rowSelecting: null,
            /**    
			* Triggered after the row is selected.
			* @event
			* @name ejTreeGrid#rowSelected 
			* @param {Object} argument Arguments when rowSelected event is triggered.  
			* @param {boolean} argument.cancel Returns the cancel option value.
			* @param {object} argument.rowElement Returns the selecting row element.
			* @param {string} argument.recordIndex Returns the index of selecting row record.
			* @param {object} argument.data Returns the data of selected record.
			* @example 
			* &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;
			* $("#treegrid").ejTreeGrid({
			*    rowSelected: function (args) {}
			* });
			* &lt;/script&gt;
            * @memberof ejTreeGrid
			   * @instance
            */
            rowSelected: null,
            /**    
           * Triggered while enter the edit mode in the grid tree cell
           * @event
           * @name ejTreeGrid#beginEdit 
           * @param {Object} argument Arguments when beginEdit event is triggered.  
           * @param {boolean} argument.cancel Returns the cancel option value.
           * @param {object} argument.rowElement Returns the row element of editing cell.
           * @param {object} argument.cellElement Returns the Element of editing cell.
           * @param {object} argument.data Returns the data of current cell record.
           * @param {number} argument.columnIndex Returns the column Index of cell belongs.
           * @example 
           * &lt;div id="treegrid"&gt;&lt;/div&gt; 
           * &lt;script&gt;
           * $("#treegrid").ejTreeGrid({
           *    beginEdit: function (args) {}
           * });
           * &lt;/script&gt;
           * @memberof ejTreeGrid
              * @instance
           */
            beginEdit: null,

            /**    
            * Triggered after the save the modified cellValue in treegrid
            * @event
            * @name ejTreeGrid#endEdit 
            * @param {Object} argument Arguments when endEdit event is triggered.  
            * @param {boolean} argument.cancel Returns the cancel option value.
            * @param {object} argument.rowElement Returns the row element of editing cell.
            * @param {object} argument.cellElement Returns the Element of editing cell.
            * @param {object} argument.data Returns the data of edited cell record.
            * @param {string} argument.columnName Returns the column name of edited cell belongs.
            * @param {object} argument.columnObject Returns the column object of edited cell belongs.
            * @example 
            * &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#treegrid").ejTreeGrid({
            *    endEdit: function (args) {}
            * });
            * &lt;/script&gt;
            * @memberof ejTreeGrid
			   * @instance
            */
            endEdit: null,

            /**    
            * Triggered  while expanding the TreeGrid record
            * @event
            * @name ejTreeGrid#expanding 
            * @param {Object} argument Arguments when expanding event is triggered.  
            * @param {boolean} argument.cancel Returns the cancel option value.
            * @param {object} argument.recordIndex Returns the row index of record.
            * @param {object} argument.data Returns the data of edited cell record..
            * @example 
            * &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#treegrid").ejTreeGrid({
            *    expanding: function (args) {}
            * });
            * &lt;/script&gt;
            * @memberof ejTreeGrid
			   * @instance
            */
            expanding: null,

            /**    
            * Triggered  after expand the record
            * @event
            * @name ejTreeGrid#expanded 
            * @param {Object} argument Arguments when expanded event is triggered.  
            * @param {boolean} argument.cancel Returns the cancel option value.
            * @param {object} argument.recordIndex Returns the row index of record.
            * @param {object} argument.data Returns the data of edited cell record..
            * @example 
            * &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#treegrid").ejTreeGrid({
            *    expanded: function (args) {}
            * });
            * &lt;/script&gt;
            * @memberof ejTreeGrid
			   * @instance
            */
            expanded: null,
            /**    
            * Triggered while collapsing the TreeGrid record
            * @event
            * @name ejTreeGrid#collapsing 
            * @param {Object} argument Arguments when collapsing event is triggered.  
            * @param {boolean} argument.cancel Returns the cancel option value.
            * @param {object} argument.recordIndex Returns the row index of collapsing record.
            * @param {object} argument.data Returns the data of edited cell record..
            * @example 
            * &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#TreeGrid").ejTreeGrid({
            *    collapsing: function (args) {}
            * });
            * &lt;/script&gt;
            * @memberof ejTreeGrid
			   * @instance
            */
            collapsing: null,
            /**    
            * Triggered after collapsed the TreeGrid record
            * @event
            * @name ejTreeGrid#collapsed 
            * @param {Object} argument Arguments when collapsed event is triggered.  
            * @param {boolean} argument.cancel Returns the cancel option value.
            * @param {object} argument.recordIndex Returns the row index of collapsed record.
            * @param {object} argument.data Returns the data of edited cell record..
            * @example 
            * &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#treegrid").ejTreeGrid({
            *    collapsed: function (args) {}
            * });
            * &lt;/script&gt;
            * @memberof ejTreeGrid
			   * @instance
            */
            collapsed: null,

            currentViewData: [],
            flatRecords: [],
            parentRecords: [],
            records: [],

          
            /**		
            * It is to specify data values to the field. 
            * @default 
            * @type {array}
            * @example
            * &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;  			
            * 	$("#treegrid").ejTreeGrid(
            *  {
            *     columns: [{ field: "Name", headerText: "Name", isTemplateColumn: true, templateID: "customColumnTemplate" },
                          { field: "Type", headerText: "Type" },
                          { field: "DateCreated", headerText: "Date Created" },
                          { field: "DateModified", headerText: "Date Modified" }]	
            *  });		
            * &lt;/script&gt;
            * @memberof ejTreeGrid
            * @instance
            */

            columns: [],
            commonWidth: 150,

            

            dateFormat: "MM/dd/yyyy",

          
            /**		
           * Specifies the height of a single row in gantt. Also, we need to set same height in the CSS style with class name e-rowcell. 
           * @default "30"
           * @type {number}
           * @example 
           * &lt;div id="treegrid"&gt;&lt;/div&gt; 
           * &lt;script&gt;				
           * 	$("#treegrid").ejTreeGrid({  
           *			rowHeight : 30,
           * 			});
           * &lt;/script&gt;
		   * @memberof ejTreeGrid
           * @instance
           */
            rowHeight: 30,

            emptyRecordText: "No Records To Display",
            /**		
           * Specifies the tree expander column in tree grid
           * @default  0
           * @type {number}
           * @example 
           * &lt;div id="treegrid"&gt;&lt;/div&gt; 
           * &lt;script&gt;		
           * 	$("#treegrid").ejTreeGrid(
           *  {
           *     treeColumnIndex: 1
           *  });		
           * &lt;/script&gt;
           * @memberof ejTreeGrid
           * @instance
           */
            treeColumnIndex: 0,

            //API for toggle between datepicker and datetimepicker
            workingTimeScale: 'TimeScale8Hours',

            /**		
            * Specifies the mapping property path for sub tasks in datasource 
            * @default ""
            * @type {string}
            * @example 
            * &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;				
            * 	$("#treegrid").ejTreeGrid({  childMapping : "Children" });
            * &lt;/script&gt;
            * @instance
            */
            childMapping: "",           
                      
           
            /**		
             * Enables or disables the collapse all menus for tree grid , when enabled all sub menus will disappears in tree grid
             * @default  "false"
             * @type {boolean}
             * @example 
             * &lt;div id="treegrid"&gt;&lt;/div&gt; 
             * &lt;script&gt;			
             * 	$("#treegrid").ejTreeGrid(
             *  {
             *     enableCollapseAll: false
             *  });		
             * &lt;/script&gt;
             * @memberof ejTreeGrid
                * @instance
             */
            enableCollapseAll:false,

            /**		
            * Specifies the row template for each TreeGrid row
            * @default  ""
            * @type {string}
            * @example 
            * &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#treegrid").ejTreeGrid(
            *  {
            *     rowTemplateID: "customTemplate"
            *  });		
            * &lt;/script&gt;
            * @memberof ejTreeGrid
            * @instance
            */
            rowTemplateID: "",

            /**		
            * Specifies the alternate row template for each alternate TreeGrid row
            * @default  ""
            * @type {string}
            * @example 
            * &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#treegrid").ejTreeGrid(
            *  {
            *     altRowTemplateID: "altRowCustomTemplate"
            *  });		
            * &lt;/script&gt;
            * @memberof ejTreeGrid
            * @instance
            */
            altRowTemplateID: "",
            /**		
            * Specifies the contextMenuSettings options.
            * @type {object}
            * @memberof ejTreeGrid
            * @instance
            */
            contextMenuSettings: {
                /**		
               * Specifies the state of enabling or disabling context menu
               * @alias ejTreeGrid#contextMenuSettings->showContextMenu
               * @default false
               * @type {boolean}
               * @example 
               * &lt;div id="treegrid"&gt;&lt;/div&gt; 
               * &lt;script&gt;	
               * 	$("#treegrid").ejTreeGrid(contextMenuSettings :{ showContextMenu:  true });			 
               * &lt;/script&gt;
               * @memberof ejTreeGrid
               * @instance
               */
                showContextMenu: false,
                /**		
                * Specifies the list of context menu items to rendered in context menu
                * @alias ejTreeGrid#contextMenuSettings->contextMenuItems
                * @default []
                * @type {array}
                * @example 
                * &lt;div id="treegrid"&gt;&lt;/div&gt; 
                * &lt;script&gt;	
                * 	$("#treegrid").ejTreeGrid({ contextMenuItems: [ej.TreeGrid.ContextMenuItems.Add,ej.TreeGrid.ContextMenuItems.Edit] });			 
                * &lt;/script&gt;
                * @memberof ejTreeGrid
			    * @instance
                */
                contextMenuItems: []
        },
            /**    
           * Triggered while Context Menu is rendered in TreeGrid control
           * @event
           * @name ejTreeGrid#contextMenuOpen 
           * @param {Object} argument Arguments when context menu is rendered.  
           * @param {boolean} argument.cancel Returns the cancel option value.
           * @param {boolean} argument.contextMenuItems Returns the default context menu items to which we add custom items.
           * @param {object}  argument.model Returns the treegrid model.
           * @param {string}  argument.requestType Returns request type.
           * @param {string}  argument.type Returns the name of the event. 
           * @example 
           * &lt;div id="treegrid"&gt;&lt;/div&gt; 
           * &lt;script&gt;
           * $("#treegrid").ejTreeGrid({
           *    contextMenuOpen: function (args) {}
           * });
           * &lt;/script&gt;
           * @memberof ejTreeGrid
              * @instance
           */
            contextMenuOpen:null,
        },

        dataTypes: {
            columns: "array",
            sortSettings: {
                sortedColumns: "array"
            },
            dataSource: "data",
            currentViewData: "array",
            flatRecords: "array",
            parentRecords: "array",
            records: "array",
            contextMenuSettings: {
                contextMenuItems: "array"
            },
            toolbarSettings: {
                toolbarItems: "array"
            },
            selectedItem: "data",

        },

        observables: ["selectedRowIndex", "dataSource"],
        selectedItem: ej.util.valueFunction("selectedItem"),
        selectedRowIndex: ej.util.valueFunction("selectedRowIndex"),
        dataSource: ej.util.valueFunction("dataSource"),
        //GET THE GRID HEADER TABLE FOR COLUMNRESIZE
        getHeaderTable: function () {
            return this._$gridHeaderTable;
        },

        //SET THE GRID HEADER TABLE
        setGridHeaderTable: function (value) {
            this._$gridHeaderTable = value;
        },

        //GET THE GRIDHEADERCONTENT
        getHeaderContent: function () {
            return this._$gridHeaderContent;
        },

        //SET THE GRIDHEADERCONTENT
        setGridHeaderContent: function (value) {
            this._$gridHeaderContent = value;
        },

        //GET THE GRID CONTENT TABLE
        getContentTable: function () {
            return this._$gridContentTable;
        },

        getContent: function () {
            return this._$gridContent;
        },
        
        //SET THE GRID CONTENT TABLE
        setGridContentTable: function (value) {
            this._$gridContentTable = value;
        },

        //GET TREEGRID ROWS
        getRows: function () {
            return this._$gridRows;
        },

        //SET TREEGRID ROWS
        setGridRows: function (value) {
            this._$gridRows = value;
        },

        //GET CURRENTVIEWPORT DATA
        getCurrentViewData: function () {
            return this.model.currentViewData;
        },

        //GET UPDATED CURRENT VIEW DATA
        getUpdatedCurrentViewData: function () {
            this._updateCurrentViewData();
            return this.model.currentViewData;
        },

        //GET FLAT RECORDS
        getFlatRecords: function () {
            return this.model.records;
        },

        //SET THE HEIGHT BASED ON THE RECORD COUNT
        setHeight: function (value) {
            this._totalHeight = value;
        },

        //GET THE UPDATEDRECORDS[SORTED,FILTERED,EXPANDCOLLAPSED]
        getUpdatedRecords: function () {
            return this._updatedRecords;
        },

        //GET THE UPDATED DATASOURCE
        getDataSource: function () {
            return this.dataSource();
        },

        //get the ids collection after perform the addition/delete operation
        //GET THE IDS COLLECTION AFTER PERFORM THE ADDITION/DELETE OPERATION
        getUpdatedIds: function () {
            return this.model.ids;
        },

        //GET THE RECORDS COUNT
        getRecordsCount: function () {
            return this._recordsCount;
        },

        //SET THE RECORDS COUNT
        setRecordsCount: function (value) {
            this._recordsCount = value;
        },

        //GET THE EXPANDCOLLAPSE RECORDS COUNT
        getExpandCollapseRecordsCount: function () {
            return this._expandCollapseRecordCount;
        },
        setCollapsedRecordCount:function(value){
            this._totalCollapseRecordCount=value; 
        },
        getCollapsedRecordCount: function () {
            return this._totalCollapseRecordCount;
        },
        
        _colgroupRefresh: function () {
            var gridheaderCol = $(this.getHeaderTable()).find('colgroup')[0];
            var gridcontentCol = $(this.getContentTable()).find('colgroup')[0];
            var headerColClone = $(gridheaderCol).clone();
            var contentColClone = $(gridcontentCol).clone();
            $(gridcontentCol).remove();
            $(gridheaderCol).remove();
            $(headerColClone).prependTo(this.getHeaderTable());
            $(contentColClone).prependTo(this.getContentTable());
        },
		
        /*CONSTRUCTOR FUNCTION*/
        _init: function () {

            var proxy = this;

            proxy._trigger("load");
            proxy._initPrivateProperties();
            
            if (proxy.model.isdesignMode) {

                proxy.element.css({ "height": "250px" });
                if (proxy.model.columns.length === 0) {
                    proxy.model.columns = [
                        { "field": "Column1", "HeaderText": "Column1" },
                        { "field": "Column2", "HeaderText": "Column2" },
                        { "field": "Column3", "HeaderText": "Column3" }
                    ];

                }
                if (proxy.model.childMapping.length == 0) {
                    proxy.model.childMapping = "Children";
                }
            }

            proxy._processEditing();
            proxy._initDatasource();

            proxy._createTooltipTemplate();
       
            //Render Records in collapsed state
            if (!proxy.model.isFromGantt && proxy.model.enableCollapseAll)
            {
                proxy.collapseAll();
            }
            var isSafari = /Safari/.test(navigator.userAgent) && /Apple Computer/.test(navigator.vendor);
            if (isSafari && !proxy.model.isFromGantt) {
                treeGridHeader = proxy._$gridHeaderContent;
                treeGridContent = $("#" + proxy._id + "e-gridcontent");
               sizeSettingsWidth = proxy.model.sizeSettings.width;
                elementStyleWidth = proxy.element[0].style.width;
                var width, height;
                //Width calculation
                if ((sizeSettingsWidth && sizeSettingsWidth.indexOf("%") != -1) || elementStyleWidth.indexOf("%") != -1) {

                    var ganttWidth = sizeSettingsWidth ? sizeSettingsWidth : elementStyleWidth;
                    var containerWidth = $(proxy.element).parent().width() ? $(proxy.element).parent().width() : $(proxy.element).width();
                    var tempWidth = (containerWidth / 100) * parseInt(ganttWidth);
                    width = tempWidth;
                }
                else {
                    width = $(proxy.element).width();
                }
                width = width - proxy._totalBorderWidth;
                proxy._updateScrollCss();
                if ($(treeGridHeader).hasClass("e-scrollcss") && proxy._$gridContent.children(".e-vscrollbar").length > 0) {
                    $(treeGridHeader).width(width - 18);
                }
                else {
                    $(treeGridHeader).width(width);
                }
            }

        },
        //#region RUNTIME UPDATE METHOD FOR TREEGRID
        //METHOD FOR UPDATE THE TREEGRID IN RUN TIME
        _setModel: function (options) {

            var proxy = this,
                model = proxy.model;

            for (var prop in options) {

                switch (prop) {

                    case "enableAltRow":
                        model.enableAltRow = options[prop];
                        proxy._addInitTemplate();
                        proxy.refreshContent();
                        break;

                    case "enableVirtualization":
                        model.enableVirtualization = options[prop];
                        proxy.refreshContent();
                        break;

                    case "allowColumnResize":
                        model.allowColumnResize = options[prop];
                        proxy._enableColumnResizeEvents();
                        break;

                    case "allowSorting":
                        model.allowSorting = options[prop];
                        break;

                    case "sortSettings":
                        $.extend(model.sortSettings, options[prop]);
                        proxy.refreshContent();
                        break;

                    case "allowSelection":
                        proxy.clearSelection();
                        model.allowSelection = options[prop];
                        break;

                    case "selectionType":
                        proxy.clearSelection();
                        model.selectionType = options[prop];
                        break;

                    case "selectedRowIndex":
                        if (this.selectedRowIndex() != -1 && $.inArray(this.selectedRowIndex(), proxy._selctedRowsIndexes == -1) && !ej.isNullOrUndefined(this.selectedRowIndex()))
                            proxy.selectRows(this.selectedRowIndex());
                        break;

                    case "editSettings":
                        $.extend(model.editSettings, options[prop]);
                        proxy._processEditing();
                        proxy._enableEditingEvents();
                        break;

                    case "allowKeyboardNavigation":
                        model.allowKeyboardNavigation = options[prop];
                        break;

                    case "dataSource":
                        proxy._refreshDataSource();
                        break;

                    case "columns":
                        $.extend(model.columns, options[prop]);
                        proxy._addInitTemplate();
                        proxy.refreshContent();
                        proxy._processEditing();
                        //Rerendering the column header with new columns.;
                        proxy._$gridHeaderContent.replaceWith(proxy._renderGridHeader());
                        var args = {};
                        args.requestType = ej.TreeGrid.Actions.Refresh;
                        //Rerendering the content of the tree grid
                        proxy.sendDataRenderingRequest(args);
                        proxy.setWidthToColumns();
                        // Update the scrollbar
                        proxy._$gridContent.ejScroller("refresh");
                        proxy._updateScrollCss();
                        break;
                    
                    case "rowHeight":
                        model.rowHeight = options[prop];
                        proxy._addInitTemplate();
                        proxy.refreshContent();
                        break;

                    case "treeColumnIndex":
                        model.treeColumnIndex = options[prop];
                        proxy._addInitTemplate();
                        proxy.refreshContent();
                        break;

                }

            }

        },
         //refresh data source on set model     
        _refreshDataSource:function()
        {
            var proxy = this,model=this.model;
            proxy.resetModelCollections();
            proxy._createdAt = "load";
            if (this.dataSource() instanceof ej.DataManager) {
                var queryPromise = this.dataSource().executeQuery(model.query);
                queryPromise.done(ej.proxy(function (e) {
                    if (proxy.dataSource().dataSource.offline) {
                        proxy._retrivedData = proxy.dataSource().dataSource.json;
                    } else {
                        proxy._retrivedData = e.result;
                    }
                    if (model.idMapping && model.parentIdMapping) {
                        //cloning the datasource
                        var dataArray = e.result.slice(0);
                        var data = [];
                        $.each(dataArray, function (indx, value) {
                            data.push(jQuery.extend(true, {}, value));
                        });
                        proxy._reconstructDatasource(data);
                    } else {
                        proxy._reconstructDatasource(e.result);
                    }
                    proxy._createRecords(proxy.secondaryDatasource);

                    args = {};
                    args["requestType"] = ej.TreeGrid.Actions.RefreshDataSource;
                    proxy._ensureDataSource(args);
                    if (proxy.selectedRowIndex() !== -1 && proxy.selectedRowIndex() < proxy.model.currentViewData.length) {
                        proxy.selectRows(proxy.selectedRowIndex());
                    }
                    if (this._$gridContent.hasClass("e-scroller"))
                        proxy._$gridContent.ejScroller("refresh");
                    proxy._createdAt = null;
                }));
            }
            else if (this.dataSource()) {
                if (model.idMapping && model.parentIdMapping) {
                    if ((model.idMapping.length > 0) && (model.parentIdMapping.length > 0)) {
                        var dataArray = this.dataSource().slice(0);
                        proxy._reconstructDatasource(dataArray);
                        proxy._createRecords(proxy.secondaryDatasource);
                    }
                }
                else if (model.flatRecords.length === 0 && this.dataSource() !== null) {
                    proxy._createRecords(this.dataSource());
                }
                args = {};
                args["requestType"] = ej.TreeGrid.Actions.RefreshDataSource;
                proxy._ensureDataSource(args);
                if (this.selectedRowIndex() !== -1 && this.selectedRowIndex() < proxy.model.currentViewData.length) {
                    proxy.selectRows(this.selectedRowIndex());
                }
                if (this._$gridContent.hasClass("e-scroller"))
                    proxy._$gridContent.ejScroller("refresh");
                proxy._createdAt = null;
            }
        
            $(".e-tooltiptable").remove();

        },
        //REFRESH THE TREEGRIDCONTENT
       
        refreshContent: function () {

            var proxy = this,
                args = {};     
            args.requestType = ej.TreeGrid.Actions.Refresh;
            proxy.processBindings(args);
        },


        //RESET THE COLLECTIONS WHILE CHANGING THE DATASOURCE
       
        resetModelCollections: function () {

            var proxy = this,
            model = proxy.model;

            // model.sortSettings.sortedColumns = [];
            model.currentViewData = [];
            model.flatRecords = [];
            model.parentRecords = [];
            model.records = [];
            proxy.secondaryDatasource = [];

        },        

        //#endregion

        //DECLARE THE PRIVATE VARIABLES
        _initPrivateProperties: function () {

            var proxy = this;

            proxy._id = proxy.element.attr("id"),
            proxy._columnsWidthCollection = [],
            proxy._cSortedColumn = null,
            proxy._cSortedDirection = null,
            proxy._dataManager = null,
            proxy._disabledSortableColumns = [],
            proxy._filteredRecords = [],
            proxy._disabledToolItems = [],
            proxy._filteredColumns = [],
            proxy_currentFilterColumn = [];
            proxy._fieldColumnNames = [],
            proxy._multiSortRequest = null,
            proxy._$gridContainer = null,
            proxy._$gridContent = null,
            proxy._$gridContentTable = null,
            proxy._$gridHeaderTable = null,
            proxy._$gridHeaderContainer = null,
            proxy._recordsCount = null,
            proxy._$gridRows = null,
            proxy._gridRows = null,
            proxy._calculateDimensions(),
            proxy._headerColumnNames = [],
            proxy._hiddenColumns = [],
            proxy._multiSelectCtrlRequest = false,
            proxy._multiSelectShiftRequest = false,
            proxy._offset = 0,
            proxy._previousIndex = -1,
            proxy._prevRBottom = 0,
            proxy._prevRTop = 0,
            proxy._prevScrollTop = 0,
            proxy._prevScrollLeft = 0,
            proxy._prevVBottom = 0,
            proxy._resizer = null,
            proxy._scrollTop = 0,
            proxy._searchString = "",
            proxy._fieldName="",
            proxy._selectedRowsIndexes = [],
            proxy._sortedRecords = [],
            proxy._storedIndex = -1,
            proxy._$tableContent = null,
            proxy._tempsortedrecords = [],
            proxy._totalHeight = 0,
            proxy._viewPortHeight = 0,
            proxy._recordIndexCount = 0,
            proxy._visibleColumns = [],
            proxy._visibleRange = null,
            proxy._vScrollDir = 1,
            proxy._vScrollDist = 0,
            proxy._cellEditTemplate = $(),
            proxy._totalBorderWidth = 2;//left and right border width
            proxy._totalBorderHeight = 1;
            proxy._cellEditingDetails = {
                cellValue: null,
                rowIndex: -1,
                columnIndex: -1,
                fieldName: null,
                _data: null,
                cellEditType: "",
                cancelSave: false,
                defaultData: null,
                insertedTrCollection: [],
                data: null
            },
            proxy._tdsOffsetWidth = [],
            proxy._isEnterKeyPressed = false,
            proxy._updatedRecords = [],
            proxy._scrollBarHeight = 18,
            proxy._expandCollapseRecordCount = 0,
            proxy._removedCount = 0,
            proxy._$gridHeaderContent = null,
            proxy._expandedRecordsCount = 0,
            proxy._totalCollapseRecordCount = 0,
            proxy._collapsedRecordCount = 0,
            proxy.secondaryDatasource = [],
            //variables for context menu items
            proxy._contextMenuItems = proxy._getContextMenuItems();
            proxy._subContextMenuItems = proxy._getsubContextMenuItems();
            proxy._dropDownTemplate = proxy._compiledDropDownTemplate(),
            proxy._createSubContextMenuTemplate();
            proxy._createContextMenuTemplate();
            proxy._retrivedData = this.dataSource();
            proxy._createdAt = "load";
            proxy._dataManager = proxy.dataSource() instanceof ej.DataManager ? proxy.dataSource() :
                proxy.dataSource() != null ? ej.DataManager(proxy.dataSource()) : null;
        },
        //set size to treegrid core by user values
        _calculateDimensions: function ()
        {
            var proxy = this, model = this.model;

            if (!model.isFromGantt) {
                if (model.sizeSettings.width)
                    proxy.element.css("width", model.sizeSettings.width);

                if (model.sizeSettings.height)
                    proxy.element.css("height", model.sizeSettings.height);
                else
                {
                    if (!proxy.element[0].style.height) {
                        proxy.element.height(350);
                    }
                }
            }
            proxy._gridHeight = proxy.element.height();
            proxy._gridWidth = proxy.element.width();

        },
        //DATASOURCE CHECKING
        _checkDataBinding: function () {

            var proxy = this,
                model = proxy.model;
            proxy._createdAt = null;
            proxy.element.addClass('e-treegrid-core');
            proxy.element.attr("tabindex", "0");
            proxy._renderToolbar();
            proxy._renderAfterColumnInitialize();
            proxy._viewPortHeight = proxy._getViewPortHeight(); 
            proxy._ensureDataSource();
            proxy._initGridRender();
            proxy._$gridContent = $("#" + proxy._id + "e-gridcontent");
            proxy._$gridContainer = $("#" + proxy._id + "e-gridcontainer");
            proxy._$tableContent = $("#" + proxy._id + "e-table");            
            proxy._wireEvents();            
            
            proxy.setWidthToColumns();
            
            proxy._renderScroller();
            proxy._resizeFilteringElements();
            
            if (model.isFromGantt) {
                proxy._addEmptyColumntoGrid();
            }
           
        },

        _initDatasource: function () {
            var proxy = this,
                model = proxy.model,retriveData;
            if (!model.isFromGantt) {
            if (this.dataSource() instanceof ej.DataManager) {

                var queryPromise = this.dataSource().executeQuery(model.query);
                queryPromise.done(ej.proxy(function (e) {
                    if (proxy.dataSource().dataSource.offline) {
                        proxy._retrivedData = proxy.dataSource().dataSource.json;
                    } else {
                        proxy._retrivedData = e.result;
                    }
                    if (model.idMapping && model.parentIdMapping) {
                        //cloning the datasource
                        var dataArray = e.result.slice(0);
                        var data = [];
                        $.each(dataArray, function (indx, value) {
                            data.push(jQuery.extend(true, {}, value));
                        });
                        proxy._reconstructDatasource(data);
                    } else {
                        proxy._reconstructDatasource(e.result);
                    }
                    proxy._createRecords(proxy.secondaryDatasource);
                    proxy._checkDataBinding();
                }));
            }

            else if (this.dataSource()) {
                if (model.idMapping && model.parentIdMapping) {
                        //cloning the datasource
                        var dataArray = this.dataSource().slice(0);
                        var data = [];
                        $.each(dataArray, function (indx, value) {
                            data.push(jQuery.extend(true, {}, value));
                        });
                        proxy._reconstructDatasource(data);
                        proxy._createRecords(proxy.secondaryDatasource);
                }
                else if (model.flatRecords.length === 0 && this.dataSource() !== null) {
                    proxy._createRecords(this.dataSource());
                }
                proxy._checkDataBinding();
            }
             else {
                    proxy._checkDataBinding();
            }
            } else {
                proxy._checkDataBinding();
            }
            
        },

        _reconstructDatasource: function (datasource) {
            var proxy = this, model = proxy.model,
                childItems, data, tempRecord = [];

            for (var i = 0; i < datasource.length; i++) {
                var data = {};
                data = ej.DataManager(datasource).executeLocal(ej.Query().where(model.parentIdMapping,
                    ej.FilterOperators.equal,
                    datasource[i][model.idMapping]));


                if ((ej.isNullOrUndefined(datasource[i][model.parentIdMapping]) || datasource[i][model.parentIdMapping] == 0)
                    && data.length > 0) {
                    datasource[i][model.childMapping] = data;
                    proxy.secondaryDatasource.push(datasource[i]);
                }
                else if (ej.isNullOrUndefined(datasource[i][model.parentIdMapping]) && !(data && data.length > 0)) {
                    proxy.secondaryDatasource.push(datasource[i]);
                }

                else if (data && data.length > 0 && !(ej.isNullOrUndefined(data[0][model.parentIdMapping]))){
                    proxy._appendChildDataItems(proxy.secondaryDatasource, data);
                }
                else if ((ej.isNullOrUndefined(datasource[i][model.parentIdMapping]) || datasource[i][model.parentIdMapping] == 0)
                    && data.length == 0) {
                    proxy.secondaryDatasource.push(datasource[i]);
                }

                if (data && data.length > 0) {

                    proxy._datasourceChildItems = proxy._reconstructDatasource(data);
                    if (ej.isNullOrUndefined(datasource[i][model.childMapping])) {
                        datasource[i][model.childMapping] = proxy._datasourceChildItems;
                        proxy._getParentIndex(datasource);
                    }
                    proxy._datasourceChildItems = [];

                }

                else if (!(ej.isNullOrUndefined(datasource[i][model.parentIdMapping]))) {
                    tempRecord.push(datasource[i]);
                }
            }

            if (tempRecord && tempRecord.length > 0) {
                return tempRecord;
            }
        },

        _appendChildDataItems: function (parentDatasource,data) {
            var proxy = this,
                model = proxy.model;
            
            for (var count = 0; count < parentDatasource.length; count++) {
                
                if (parentDatasource[count][model.idMapping] === data[0][model.parentIdMapping]) {
                    parentDatasource[count][model.childMapping] = data;
                }
                else if (!(ej.isNullOrUndefined(parentDatasource[count][model.childMapping])) &&
                    parentDatasource[count][model.childMapping].length > 0) {
                    proxy._appendChildDataItems(parentDatasource[count], data);
                }
            }

            if ((ej.isNullOrUndefined(parentDatasource.length)) && parentDatasource) {
                if (parentDatasource[model.idMapping] === data[0][model.parentIdMapping]) {
                    parentDatasource[model.childMapping] = data;
                }
                else if (!(ej.isNullOrUndefined(parentDatasource[model.childMapping])) &&
                    parentDatasource[model.childMapping].length > 0) {
                    proxy._appendChildDataItems(parentDatasource[model.childMapping], data);
                }
            }

        },
        
        _getParentIndex: function (datasource) {
            var proxy = this, model = proxy.model,
                dataArr = proxy.secondaryDatasource, parentIndex = 0;

            if (datasource.length > 0) {
                parentIndex = datasource[0][model.parentIdMapping];
            }
            for (var i = 0; i < dataArr.length; i++) {
                if (dataArr[i][model.idMapping] == parentIndex && ej.isNullOrUndefined(dataArr[i][model.childMapping])) {
                    dataArr[i][model.childMapping] = (datasource);
                    return true;
                }
                else {
                    var childItems = dataArr[i][model.childMapping];
                    if (childItems) {
                        for (var i = 0; i < childItems.length; i++) {
                            if (childItems[i][model.idMapping] == parentIndex && ej.isNullOrUndefined(childItems[i][model.childMapping])) {
                                childItems[i][model.childMapping] = (datasource);
                                return true;
                            }
                        }
                    }
                }
            }

        },
        //Window resize event
        _windowResize:function(e)
        {
            var proxy = this,
               treeGridHeader = proxy._$gridHeaderContent,
               treeGridContent = $("#" + proxy._id + "e-gridcontent"),
               treegridToolbar = $("#" + proxy._id + "_toolbarItems"),
               sizeSettingsHeight = proxy.model.sizeSettings.height,
               sizeSettingsWidth = proxy.model.sizeSettings.width,
               elementStyleWidth = proxy.element[0].style.width,
               elementStyleHeight = proxy.element[0].style.height,
               width, height;
            //Width calculation
            if ((sizeSettingsWidth && sizeSettingsWidth.indexOf("%") != -1) || elementStyleWidth.indexOf("%") != -1) {

                var ganttWidth = sizeSettingsWidth ? sizeSettingsWidth : elementStyleWidth;
                var containerWidth = $(proxy.element).parent().width() ? $(proxy.element).parent().width() : $(proxy.element).width();
                var tempWidth = (containerWidth / 100) * parseInt(ganttWidth);
                width = tempWidth;
            }
            else
                width = $(proxy.element).width();
            //height calculation
            if ((sizeSettingsHeight && sizeSettingsHeight.indexOf("%") != -1) || elementStyleHeight.indexOf("%") != -1) {
                var ganttHeight = sizeSettingsHeight ? sizeSettingsHeight : elementStyleHeight;
                var containerHeight = $(proxy.element).parent().height() ? $(proxy.element).parent().height() : $(proxy.element).height();
                var tempHeight;
                if ($(proxy.element).parent().height())
                    tempHeight = (containerHeight / 100) * parseInt(ganttHeight);
                else
                    tempHeight = $(proxy.element).height();
                height = tempHeight;
            }
            else
                height = $(proxy.element).height();

            //excludes border 
            height = height - proxy._totalBorderHeight;
            width = Math.round(width - proxy._totalBorderWidth);
            var treeGridWidth,headerHeight,headerWidth, top, left;
            top = proxy._$gridContent.ejScroller("option", "scrollTop");
            left = proxy._$gridContent.ejScroller("option", "scrollLeft");
            proxy._$gridContent.ejScroller({
                width: width,
                height: height - $(treeGridHeader).outerHeight() - treegridToolbar.outerHeight(),//for border-width of gridcontent
            });
            proxy._updateScrollCss();
            if ($(treeGridHeader).hasClass("e-scrollcss") && proxy._$gridContent.children(".e-vscrollbar").length > 0) {
                $(treeGridHeader).width(width - 18);
            }
            else {
                $(treeGridHeader).width(width);
            }
            if (proxy.model.toolbarSettings.showToolbar && treegridToolbar.length > 0) {
                treegridToolbar.width(width);
                treegridToolbar.children(".e-ul:first-child").width(width);
            }

            proxy._$gridContent.ejScroller("refresh");
            proxy.updateViewPortHeight();
            proxy._$gridContent.ejScroller("option", "scrollTop",top);
            proxy._$gridContent.ejScroller("option", "scrollLeft", left);
            proxy._$gridHeaderContainer.scrollLeft(left);
            if (proxy.model.enableVirtualization) {
                proxy.processBindings();
                var tempArgs = {};
                tempArgs.requestType = ej.TreeGrid.Actions.Refresh;
                proxy.sendDataRenderingRequest(tempArgs);
                if ((proxy.model.currentViewData.length * proxy.model.rowHeight) < proxy._viewPortHeight) {
                    var currentPosition = top - (proxy._viewPortHeight - proxy.model.currentViewData.length * proxy.model.rowHeight);
                    if (currentPosition < 0)
                        currentPosition = 0;
                    proxy._$gridContent.ejScroller("scrollY",currentPosition, true);
                }
            }
            proxy._resizeFilteringElements();
            
        },

        //PROCESSBINDING
        processBindings: function (args) {

            var proxy = this,
                model = proxy.model;

            model.query = new ej.Query();

            if (proxy._trigger("actionBegin", args)) {
                return true;
            }

            proxy._ensureDataSource(args);

        },

        _ensureDataSource: function (args) {

            var proxy = this,
                model = proxy.model,
                sortcolumns = model.sortSettings.sortedColumns,
                isupdatedHeight = false,
                index,
                childIndex;

            //if (model.dataSource == null) {
            //    return;
            //}

            model.query.requiresCount();
            proxy._queryManagar = model.query;

            if ((model.editSettings.allowEditing || model.editSettings.allowAdding) &&
                args && args.requestType == ej.TreeGrid.Actions.Save &&
                (!ej.isNullOrUndefined(args._cModifiedData) || !ej.isNullOrUndefined(args._cAddedRecord))) {

                if (ej.isNullOrUndefined(args._cAddedRecord)) {
                    $.extend(model.flatRecords[$.inArray(model.selectedItem, model.flatRecords)],
                        args._cModifiedData);
                } else {

                    var parentItem;

                    if (this.selectedRowIndex() === -1) {

                        args._cAddedRecord.hasChildRecords = false;
                        model.flatRecords.unshift(args._cAddedRecord);
                        model.records.unshift(args._cAddedRecord);
                        this.dataSource().unshift(args._cAddedRecord.item);

                        if (model.isFromGantt) {
                            model.ids.unshift(args._cAddedRecord.taskId);
                        }
                        args.recordIndex = 0;

                    } else {

                        args._cAddedRecord.level = model.selectedItem.level;
                        index = model.selectedItem ? model.flatRecords.indexOf(model.selectedItem) : 0;

                        if (args._cAddedRecord.level === 0) {
                            index = index > 0 ? index - 1 : index;
                        }

                        if (args.actionRequestType != ej.TreeGrid.Actions.ContextMenuAdd) {
                            args.recordIndex = index > 0 ? index - 1 : 0;
                        }

                        model.flatRecords.splice(index, 0, args._cAddedRecord);

                        var rowIndex = model.records.indexOf(model.selectedItem);
                        model.records.splice(rowIndex, 0, args._cAddedRecord);

                        if (model.isFromGantt) {
                            model.ids.splice(rowIndex, 0, args._cAddedRecord.taskId.toString());
                        }

                        if (args._cAddedRecord.level > 0) {

                            parentItem = model.selectedItem.parentItem;

                            if (parentItem) {

                                childIndex = parentItem.childRecords ?
                                    parentItem.childRecords.indexOf(model.selectedItem) : -1;

                                if (childIndex !== -1) {
                                    childIndex = childIndex === 0 ? 0 : childIndex - 1;
                                }

                                parentItem.childRecords.splice(childIndex, 0, args._cAddedRecord);

                            }
                        }

                        proxy.setRecordsCount(model.flatRecords.length);
                        proxy.setHeight(model.flatRecords.length * model.rowHeight);
                        proxy.updateHeight();
                        isupdatedHeight = true;

                    }
                    proxy._queryManagar.queries = [];
                    model.isEdit = false;
                    proxy._updatedGanttRecords = model.flatRecords;

                }
            }

            if (args && args.requestType === ej.TreeGrid.Actions.ExpandCollapse) {

                isupdatedHeight = true;
                // proxy.clearSelection(proxy.selectedRowIndex());
                proxy._filteredRecords = [];
                proxy._expandCollapseRecordCount = 0;
                proxy.updateExpandCollapseRecords(args.data, args.expanded);
                proxy.setRecordsCount(model.flatRecords.length);
                proxy.setHeight(model.flatRecords.length * model.rowHeight);
                proxy._updatedRecords = model.flatRecords;

                if (!model.enableVirtualization) {
                    if (model.allowSearching && proxy._searchString.length) {
                        proxy._updateFilteredRecords(proxy._tempfilteredrecords);
                        proxy.setRecordsCount(proxy._filteredRecords.length);
                        proxy.setHeight(proxy._filteredRecords * model.rowHeight);
                        proxy._updatedRecords = proxy._filteredRecords;
                    }

                    if (model.allowSorting && model.sortSettings.sortedColumns.length) {
                        proxy._updateExpandCollapseForSortedRecords(args.data, args.expanded);
                        proxy.setHeight(proxy._sortedRecords * model.rowHeight);
                        proxy._updatedRecords = proxy._sortedRecords;
                    }

                }
                proxy.updateHeight();

                if (model.enableAltRow) {
                    proxy._updateAltRow();
                }

            }

            if (model.editSettings.allowDeleting && args && args.requestType === ej.TreeGrid.Actions.Delete) {

                var deletedRow = args.data,
                    recordIndex,
                    rowindex;
                proxy._removedCount = 0;
                var childRecordsCount = proxy._getFilteredChildRecordsCount(deletedRow);
                childRecordsCount += 1;
                proxy._removedCount = 0;

                if (deletedRow.parentItem) {

                    var childRecords = deletedRow.parentItem.childRecords;
                    childIndex = childRecords.indexOf(deletedRow);

                    deletedRow.parentItem.childRecords.splice(childIndex, 1);
                    if(!model.parentIdMapping)
                        deletedRow.parentItem.item[proxy.model.childMapping].splice(childIndex, 1);
                }
                //Delete from parent collection if item is parent
                var parentIndex=model.parentRecords.indexOf(deletedRow);
                if (parentIndex!== -1)
                {
                    model.parentRecords.splice(parentIndex, 1);
                }
                recordIndex = proxy.model.flatRecords.indexOf(deletedRow);
                if (recordIndex!==-1)
                    proxy.model.flatRecords.splice(recordIndex, childRecordsCount);
                proxy.setRecordsCount(model.flatRecords.length);
                proxy.setHeight((model.flatRecords.length - proxy._totalCollapseRecordCount )* model.rowHeight);
                isupdatedHeight = false;
                index = model.records.indexOf(deletedRow);
                var deletedRecordCount = proxy.getChildCount(deletedRow, 0);
                model.records.splice(index, deletedRecordCount + 1);
                model.ids && model.ids.splice(index, deletedRecordCount + 1);
                proxy._updatedRecords = model.flatRecords;
                if(!model.parentIdMapping)
                {
                    if (this.dataSource() instanceof ej.DataManager) {
                        if (this.dataSource().dataSource.offline && this.dataSource().dataSource.json) {
                            rowindex = this.dataSource().dataSource.json.indexOf(deletedRow.item);
                            if (rowindex !== -1)
                                proxy.dataSource().dataSource.json.splice(rowindex, 1);
                        }
                    } else {
                        rowindex = this.dataSource().indexOf(deletedRow.item);
                        if (rowindex !== -1)
                            proxy.dataSource().splice(rowindex, 1);
                    }
                }
                else
                {
                    //remove child item
                    if (deletedRow.hasChildRecords && deletedRow.childRecords.length > 0)
                    {
                        proxy._removeChildItem(deletedRow);
                    }
                    //remove deleting item

                    if (this.dataSource() instanceof ej.DataManager) {
                        if (this.dataSource().dataSource.offline && this.dataSource().dataSource.json) {
                            var idx = this.dataSource().dataSource.json.indexOf(deletedRow.item);
                            if (idx !== -1)
                                this.dataSource().dataSource.json.splice(idx, 1);
                        }
                    }
                    else
                    {
                        var idx = this.dataSource().indexOf(deletedRow.item);
                        if (idx !== -1)
                            this.dataSource().splice(idx, 1);
                    }
                }
                model.selectedItem = null;
                this.selectedRowIndex(-1);
                if (!model.isFromGantt && deletedRow.parentItem)
                    if (deletedRow.parentItem.childRecords.length == 0) {
                        deletedRow.parentItem.expanded = false;
                        deletedRow.parentItem.hasChildRecords = false;
                    }
            }
            // Condition for filtering columns.
            if (model.allowFiltering && !model.isFromGantt && this._filteredColumns.length)
            {
                var predicate, firstFilterCondition = this._filteredColumns[0];
                // Condition to collect the details of filtering column.
                if (!firstFilterCondition.isComplex)
                    predicate = ej.Predicate(firstFilterCondition.field, firstFilterCondition.operator, firstFilterCondition.value, !firstFilterCondition.matchcase);
                else
                    predicate = firstFilterCondition;
                for (var i = 1; i < this._filteredColumns.length; i++) {
                    //Loop to gather all the column condition as array.
                    if (!this._filteredColumns[i].isComplex)
                        predicate = predicate[this._filteredColumns[i].predicate](this._filteredColumns[i].field, this._filteredColumns[i].operator, this._filteredColumns[i].value, !this._filteredColumns[i].matchcase);
                    else
                        predicate = predicate["and"](this._filteredColumns[i]);
                }
                proxy._queryManagar.where(predicate);
                proxy._filteredRecords = model.records.filter(function (record) {
                    return record.hasChildRecords === false;
                });
                var dataManager = new ej.DataManager(proxy._filteredRecords);
                proxy._tempfilteredrecords = dataManager.executeLocal(proxy._queryManagar).result;
                proxy._updateFilteredRecords(proxy._tempfilteredrecords);
                proxy.setRecordsCount(proxy._filteredRecords.length);
                proxy._updatedRecords = proxy._filteredRecords;
                if (model.allowSorting && model.sortSettings.sortedColumns.length > 0) {
                    proxy._sortingRecords();
                }
                proxy.setHeight(proxy._updatedRecords.length * model.rowHeight);
                proxy.updateHeight();
                isupdatedHeight = true;
                if (model.enableAltRow) {

                    proxy._updateAltRow();
                }
            }

            if ((model.allowSearching && proxy._searchString.length) || (args && args.requestType==="searching")) {

                proxy._queryManagar.search(proxy._searchString, proxy.getColumnFieldNames(),
                    ej.FilterOperators.contains, true);

                proxy._filteredRecords = model.records.filter(function (record) {
                    return record.hasChildRecords === false;
                });

                var dataManager = new ej.DataManager(proxy._filteredRecords);
                proxy._tempfilteredrecords = dataManager.executeLocal(proxy._queryManagar).result;
                proxy._updateFilteredRecords(proxy._tempfilteredrecords);
                proxy.setRecordsCount(proxy._filteredRecords.length);
                proxy._updatedRecords = proxy._filteredRecords;

                if (model.allowSorting && model.sortSettings.sortedColumns.length > 0) {
                    proxy._sortingRecords();
                }
                proxy.setHeight(proxy._updatedRecords.length * model.rowHeight);
                proxy.updateHeight();
                isupdatedHeight = true;

                if (model.enableAltRow) {

                    proxy._updateAltRow();
                }

            } else if (model.allowSorting && sortcolumns.length > 0) {

                isupdatedHeight = proxy._sortingRecords();
            }

            if ( args && args.requestType === "outdent") {
                args = {};
                args.requestType = ej.TreeGrid.Actions.Refresh;
                isupdatedHeight = true;
            }

            if (!isupdatedHeight) {

                proxy.setRecordsCount(model.flatRecords.length);
                proxy.setHeight((model.flatRecords.length - proxy._totalCollapseRecordCount) * model.rowHeight);
                proxy._updatedRecords = model.flatRecords;
                proxy.updateHeight();

            }

            if (!args) {
                args = {};
                args.requestType = ej.TreeGrid.Actions.Refresh;
            }

            proxy._updateCurrentViewData();

            if ((!model.isFromGantt && args.requestType === "save") || args.requestType === "sorting" || args.requestType === "searching" || args.requestType === "delete" || args.requestType === "refreshDataSource" ||args.requestType=="filtering") {
                proxy.renderRecords(args);
                proxy._setScrollTop();
                proxy._$gridContent.ejScroller("refresh");
                proxy._updateScrollCss();
            }

        },
        //remove child record in data source on self reference
        _removeChildItem: function (record) {
            var currentRecord, proxy = this;
            for (var i = 0; i < record.childRecords.length; i++) {
                currentRecord = record.childRecords[i];
                if (this.dataSource() instanceof ej.DataManager) {
                    if (this.dataSource().dataSource.offline && this.dataSource().dataSource.json) {
                        var idx = this.dataSource().dataSource.json.indexOf(currentRecord.item);
                        if(idx!==-1)
                            this.dataSource().dataSource.json.splice(idx, 1);

                        if (currentRecord.hasChildRecords) {
                            proxy._removeChildItem(currentRecord);
                        }
                    }
                } else {
                    var idx = this.dataSource().indexOf(currentRecord.item);
                    if (idx !== -1)
                        this.dataSource().splice(idx, 1);

                    if (currentRecord.hasChildRecords) {
                        proxy._removeChildItem(currentRecord);
                    }
                }
            }
        },

        //CHECK EDITING OPTIONS 
        _processEditing:function(){

            var proxy = this,
                model = proxy.model;

            if (model.editSettings.allowEditing || model.editSettings.allowAdding) {
                if (model.editSettings.editMode.toLowerCase() === "cellediting" || model.editSettings.editMode.toLowerCase() === "rowediting") {
                    proxy._addCellEditTemplate();
                }
            }

        },

        _toolBarClick: function (sender) {           
            var proxy = this,
               model = proxy.model,
               $gridEle = $(this.itemsContainer).closest(".e-treegrid"),
               gridInstance = $gridEle.ejTreeGrid("instance"),
               gridId = $gridEle.attr('id');
            
            if (sender.event == undefined && sender.target.tagName == "INPUT" && sender.currentTarget.id == gridId + "_search")
                return false;

            if (gridInstance.model.dateFormat.indexOf("hh") != -1)
                $.isFunction($.fn.ejDateTimePicker) && $("#" + gridId + "EditForm").find(".e-datepicker").ejDateTimePicker("hide");
            else
                $.isFunction($.fn.ejDatePicker) && $("#" + gridId + "EditForm").find(".e-datepicker").ejDatePicker("hide");


            if ($gridEle.ejTreeGrid("instance")._trigger("toolBarClick", sender))
                return false;

            switch (sender.currentTarget.id) {

                case gridId + "_add":
                    gridInstance._toolbarOperation(gridId + "_add", sender);
                    break;

                case gridId + "_edit":
                    gridInstance._toolbarOperation(gridId + "_edit", sender);
                    break;

                case gridId + "_delete":
                    gridInstance._toolbarOperation(gridId + "_delete", sender);
                    break;

                case gridId + "_update":
                    gridInstance._toolbarOperation(gridId + "_update", sender);
                    break;

                case gridId + "_cancel":
                    gridInstance._toolbarOperation(gridId + "_cancel", sender);
                    break;

                case gridId + "_expandAll":
                    gridInstance._toolbarOperation(gridId + "_expandAll", sender);
                    break;

                case gridId + "_collapseAll":
                    gridInstance._toolbarOperation(gridId + "_collapseAll", sender);
                    break;

            }
            return false;
        },
        _toolbarOperation: function (operation, searchEle) {
            var $gridEle = this.element, gridObject = $gridEle.ejTreeGrid("instance"), gridId = $gridEle.attr('id'), proxy = this;
            var selectedrow = this.selectedItem();
            var parentEle = searchEle.target
            var index = this.selectedRowIndex();
            switch (operation) {

                case gridId + "_add":
                    proxy._startAdd(parentEle,null);
                    break;
                    
                case gridId + "_edit":
                    proxy._editRow(index);
                    break;

                case gridId + "_delete":
                    proxy.deleteRow();
                    proxy._cancelSaveTools();
                    break;

                case gridId + "_update":
                    proxy._endEdit();
                    proxy._cancelSaveTools();

                    break;

                case gridId + "_cancel":
                    proxy.cancelRowEditCell();
                    proxy._cancelSaveTools();
                    break;

                case gridId + "_expandAll":
                    proxy._expandAll();
                    break;

                case gridId + "_collapseAll":
                    proxy.collapseAll();
                    break;

            }
            proxy._refreshToolBar();
            return false;
        },
        //Create the instances for newly added row.
        _createNewRowInstance: function (obj) {
            var keys = [];
            for (var key in obj) {
                keys.push(key);
            }
            return keys;
        },

         /* Public method for appending a new row in Treegrid
         *  arguments rowPosition for providing the position of newly added row
         */
        addRow:function(rowPosition){
            var proxy = this, model = proxy.model;
            if (model.selectedItem) {
                proxy._startAdd(null, rowPosition);
            }

        },

        _startAdd: function (parentEle, rowPos) {
            var proxy = this;            
            var rowIndex = this.selectedRowIndex();          
            var rowPosition = rowPos ? rowPos : proxy.model.editSettings.rowPosition;
            var length = proxy.model.currentViewData.length;
            var refindex;

            var headerColumn = proxy._headerColumnNames,
                    item = {};
            var columnitems = proxy._createNewRowInstance(headerColumn);
            for (var column = 0; column < columnitems.length; column++) {
                item[columnitems[column]] = null;
            }

            if (length>0) {                
                if (rowIndex == -1 && rowPosition != "bottom")
                    rowPosition = "top";
                //GET INDEX AND REFERENCE INDEX TO ADD A NEW ROW.
                if (rowPosition == "bottom") {
                    index = length;
                    refindex = length - 1;
                }
                else if (rowIndex != -1 && rowPosition == "aboveSelectedRow") {
                    index = rowIndex;
                    refindex = rowIndex;
                }
                else if (rowIndex != -1 && rowPosition == "belowSelectedRow") {
                    index = rowIndex + 1;
                    refindex = rowIndex;
                }
                else {
                    index = 0;
                    refindex = 0;
                }

                var ref = proxy.model.currentViewData[refindex];
                var getKeys = proxy._createNewRowInstance(ref);
                var addrow = {};                
                //TO EXPANDS AND COLLAPSES THE NEW ADDED ROW
                if (ref.parentItem || rowPosition=="bottom") {                   
                    var addrow = proxy._createRecord(item);                   
                    addrow.parentItem = ref.parentItem;
                    addrow.level = ref.level;
                    addrow.isAltRow = ref.isAltRow;
                    addrow.index = length + 1;
                    if (ref.fromEmpty)
                        addrow.fromEmpty = true;
                    //TO SORT NEWLY ADDED ROW IN CHILDRECORDS OF THE PARENTITEM.
                    if (ref.hasChildRecords) {
                        if (rowPosition == "belowSelectedRow") {
                            addrow.parentItem = ref;
                            addrow.level = ref.level + 1;
                            ref.childRecords.splice(0, 0, addrow);
                        }
                        else if (rowPosition == "aboveSelectedRow") {
                            var refabove = proxy.model.currentViewData[refindex - 1];
                            if (refabove.hasChildRecords) {
                                addrow.parentItem = ref.parentItem;
                                addrow.level = ref.level;
                                refabove.childRecords.splice(0, 0, addrow);
                            }
                            else {
                                addrow.parentItem = refabove.parentItem;
                                addrow.level = refabove.level;
                               refabove.parentItem.childRecords.splice(index, 0, addrow);
                            }
                        }                                               
                    }
                    else {
                        if (!ref.fromEmpty) {
                            ref.parentItem.childRecords.splice(index, 0, addrow);
                            ref.parentItem[proxy.model.childMapping].splice(index, 0, addrow.item);
                        }
                    }

                }
                if (!ref.parentItem) {
                    if (refindex != 0 && rowPosition == "aboveSelectedRow") {
                        var addrow = proxy._createRecord(item);                        
                        refabove = proxy.model.currentViewData[refindex - 1];
                        if (ref.fromEmpty) {
                            addrow.fromEmpty = true;
                            refabove = proxy.model.currentViewData[0];
                        }
                        addrow.parentItem = refabove.parentItem;
                        addrow.level = refabove.level;
                        if (!ref.fromEmpty) {
                            if (refabove.parentItem) {
                                refabove.parentItem.childRecords.splice(index, 0, addrow);
                                refabove.parentItem[proxy.model.childMapping].splice(index, 0, addrow.item);
                            }
                            else
                                //To sort the top most records.
                                proxy.model.parentRecords.splice(index, 0, addrow);
                        }
                    }
                    if (rowPosition == "belowSelectedRow") {
                        var addrow = proxy._createRecord(item);                        
                        refbelow = proxy.model.currentViewData[refindex + 1];
                        if (ref.fromEmpty) {
                            addrow.fromEmpty = true;
                            refbelow = proxy.model.currentViewData[0];
                        }
                        addrow.parentItem = refbelow.parentItem;
                        addrow.level = refbelow.level;
                        if (!ref.fromEmpty && refbelow.parentItem) {
                            refbelow.parentItem.childRecords.splice(index, 0, addrow);
                            refbelow.parentItem[proxy.model.childMapping].splice(index, 0, addrow.item);
                        }
                       
                    }
                   
                    //TO SORT TOP MOST ADDED ROW.
                    if (refindex == 0 && (rowPosition == "top" || rowPosition == "aboveSelectedRow")) {
                        var addrow = proxy._createRecord(item);                        
                        addrow.parentItem = ref.parentItem;
                        addrow.childRecords = undefined;
                        addrow.level = 0;
                        addrow.index = 0;
                        proxy.model.parentRecords.splice(index, 0, addrow);
                    }
                   
                }
                                            
                var previousIndex = proxy._previousIndex;              
                proxy.clearSelection(previousIndex);
                if (previousIndex != -1)
                proxy._updatedRecords[previousIndex].isSelected = false;                              

                proxy.model.currentViewData.splice(index, 0, addrow);                
            }
            else
            {                               
                var addrow = proxy._createRecord(item);
                addrow.parentItem = null;
                addrow.level = 0;
                addrow.index = 0;                
                addrow.fromEmpty = true;
                var index = addrow.index;
                proxy.model.currentViewData.push(addrow);
               
            }
            if (addrow.fromEmpty) {                
                proxy.model.parentRecords.splice(index, 0, addrow);
                var disableToolItems = [];
                if (!$($('.e-expandall')[0]).parent("li").hasClass("e-disable"))
                    disableToolItems.push($($('.e-expandall')[0]).parent()[0]);
                if (!$($('.e-collapseall')[0]).parent("li").hasClass("e-disable"))
                    disableToolItems.push($($('.e-collapseall')[0]).parent()[0]);
                $('.e-treegridtoolbar').ejToolbar('disableItem', disableToolItems);
            }            
           proxy.selectRows(index);
            proxy.renderRecords();           
            proxy._editRow(index, addrow);                      
        },
        //ENABLE AND DISABLE THE CORRESPONDING TOOLS WHILE ADDING AND EDITING THE ROW RECORD.
        _editAddTools: function () {
            var proxy = this;
            var editSettings = proxy.model.editSettings;
            var disableToolItems = [];
            if (editSettings.allowAdding)
                disableToolItems.push($($('.e-addnew')[0]).parent()[0]);
            if (editSettings.allowEditing && !$($('.e-edit')[0]).parent("li").hasClass("e-disable"))
                disableToolItems.push($($('.e-edit')[0]).parent()[0]);
            if (editSettings.allowDeleting && !$($('.e-delete')[0]).parent("li").hasClass("e-disable"))
                disableToolItems.push($($('.e-delete')[0]).parent()[0]);
            $('.e-treegridtoolbar').ejToolbar('disableItem', disableToolItems);

            var enabledToolItems = [];
            enabledToolItems.push($($('.e-cancel')[0]).parent()[0]);
            enabledToolItems.push($($('.e-save')[0]).parent()[0]);
            $('.e-treegridtoolbar').ejToolbar('enableItem', enabledToolItems);

        },
        //ENABLE AND DISABLE THE CORRESPONDING TOOLS WHILE CANCEL AND SAVING THE ROW RECORD.
        _cancelSaveTools: function () {
            var proxy = this;
            var model = proxy.model;
            var editSettings = proxy.model.editSettings;
            if (!model.isFromGantt) {
                var enabledToolItems = [];
                var disableToolItems = [];
                if (editSettings.allowAdding) {
                    if (proxy.model.toolbarSettings.toolbarItems.indexOf("add") !== -1)
                        enabledToolItems.push($($('.e-addnew')[0]).parent()[0]);
                }
                
                if (editSettings.allowEditing && proxy.model.toolbarSettings.toolbarItems.indexOf("edit") !== -1) {
                    if (proxy.model.selectedRowIndex != -1)
                        enabledToolItems.push($($('.e-edit')[0]).parent()[0]);
                   else if (!$($('.e-delete')[0]).parent("li").hasClass("e-disable"))
                        disableToolItems.push($($('.e-edit')[0]).parent()[0]);
                }
                if (editSettings.allowDeleting && proxy.model.toolbarSettings.toolbarItems.indexOf("delete") !== -1) {                   
                        if (proxy.model.selectedRowIndex != -1)
                            enabledToolItems.push($($('.e-delete')[0]).parent()[0]);
                       else if (!$($('.e-delete')[0]).parent("li").hasClass("e-disable"))
                            disableToolItems.push($($('.e-delete')[0]).parent()[0]);
                }
                
               

                if (!$($('.e-cancel')[0]).parent("li").hasClass("e-disable"))
                    disableToolItems.push($($('.e-cancel')[0]).parent()[0]);               
                if (!$($('.e-save')[0]).parent("li").hasClass("e-disable"))
                    disableToolItems.push($($('.e-save')[0]).parent()[0]);               

                $('.e-treegridtoolbar').ejToolbar('disableItem', disableToolItems);
                $('.e-treegridtoolbar').ejToolbar('enableItem', enabledToolItems);
            }
            else {
                var enabledToolItems = [];
                if (editSettings.allowAdding && proxy.model.toolbarSettings.toolbarItems.indexOf("add") !== -1)
                        enabledToolItems.push($($('.e-addnewitem')[0]).parent()[0]);
                
                if (editSettings.allowEditing && proxy.model.toolbarSettings.toolbarItems.indexOf("edit") !== -1) {
                    if (proxy.model.selectedRowIndex != -1)
                        enabledToolItems.push($($('.e-edititem')[0]).parent()[0]);
                }
                if (editSettings.allowDeleting && proxy.model.toolbarSettings.toolbarItems.indexOf("delete") !== -1) {
                    if (proxy.model.selectedRowIndex != -1)
                    enabledToolItems.push($($('.e-deleteitem')[0]).parent()[0]);
                }
                $('.e-gantttoolbar').ejToolbar('enableItem', enabledToolItems);

                var disableToolItems = [];
                if (proxy.model.toolbarSettings.toolbarItems.indexOf("cancel") !== -1)
                    disableToolItems.push($($('.e-cancel')[0]).parent()[0]);
                if (proxy.model.toolbarSettings.toolbarItems.indexOf("update") !== -1)
                    disableToolItems.push($($('.e-saveitem')[0]).parent()[0]);

                $('.e-gantttoolbar').ejToolbar('disableItem', disableToolItems);
            }

        },

        
        _checkIsEmptyRow:function(item){
            for (var key in item) {
                var val = item[key];
                if (val == " " || val == null || val == "")
                    continue;
                    return false;                
            }
            return true;
        },
              
        _beginEdit: function () {
            var proxy = this;
            proxy._trigger("beginEdit", args);
            proxy._isinBeginEdit = true;           
        },
        _endEdit: function () {
            var proxy = this;

            proxy._isinBeginEdit = false;
            proxy._trigger("endEdit");
            var index = this.selectedRowIndex();
            var tr = proxy._$gridRows[index];
            if ($('tr').hasClass("e-addedrow") || $('tr').hasClass("e-rowedit"))
                proxy._saveRow();
            else
                proxy.saveCell();
           // proxy.selectedRowIndex(index);
            proxy.getUpdatedRecords(index);
            
        },

        //Expand the child records from parent.
        _expandAll: function () {

            var proxy = this,
                model = proxy.model,
                count = 0,
                treegridRecord,
                args = {},
                enableVirtualization = model.enableVirtualization;

            proxy._isInExpandCollapse = true;

            //loop excecute for iterate the GanttRecords preseent in the Gantt Control

            for (count = 0; count < proxy._updatedRecords.length; count++) {
                treegridRecord = proxy._updatedRecords[count];
                args.data = treegridRecord;
                args.recordIndex = count;
                args.expanded = true;

                if (enableVirtualization) {
                    if (treegridRecord.hasChildRecords && !treegridRecord.expanded) {
                        ej.TreeGrid.sendExpandCollapseRequest(proxy, args);
                    }
                } else {
                    if (treegridRecord.hasChildRecords && !treegridRecord.expanded) {
                        ej.TreeGrid.sendExpandCollapseRequest(proxy, args);
                    }
                }
            }

            proxy._isInExpandCollapse = false;
            //To cancel the cell edit or row edit mode when expand the all record.
            if (proxy._isRowEdit || proxy.model.isEdit) {
                proxy.cancelRowEditCell();               
                proxy._cancelSaveTools();
            }
        },

           

        _refreshToolBar: function () {
            var $toolbar = $("#" + this._id + "_toolbarItems");
            $toolbar.find("li").removeClass("e-hover");
        },

        //RENDER TOOL BAR
        _renderToolbar: function () {
            var proxy = this,
            model = proxy.model;
            if (!model.isFromGantt) {
                var proxy = this, element = proxy.element, model = proxy.model;
                if (proxy.model.toolbarSettings.showToolbar) {
                    if (proxy.model.toolbarSettings.toolbarItems.length == 0)
                        proxy.model.toolbarSettings.toolbarItems = [ej.TreeGrid.ToolbarItems.Add,
                        ej.TreeGrid.ToolbarItems.Edit, ];
                    element.append(proxy._renderToolbarTemplate());
                }
            }
        },

        //RENDER TOOLBAR TEMPLATE
        _renderToolbarTemplate: function () {
            var proxy = this,
                model = proxy.model,
                $div = ej.buildTag("div.e-treegridtoolbar#" + proxy._id + "_toolbarItems", "", { 'height': '36px', 'border': '1px solid' }, {}),
                $ul = ej.buildTag("ul", "", { 'width': proxy._gridWidth, 'box-sizing': ' ' }, {});
            (!ej.isNullOrUndefined(model.toolbarSettings.toolbarItems) && model.toolbarSettings.toolbarItems.length) && proxy._renderLi($ul);
            $div.append($ul);
            var $customUl = ej.buildTag("ul");
            $div.append($customUl);
            var helper = {};
            helper.click = proxy._toolBarClick;
            helper.cssClass = "";
            helper.rtl = false;
            helper.itemSeparator = false;
            helper.itemLeave = proxy._toolbarItemLeave;
            helper.width= proxy._gridWidth,
            helper.fields = {
                id: "",
                tooltipText: "",
                imageUrl: "",
                text: "",
                imageAttributes: "",
                spriteCSS: "",
                htmlAttributes: "",
            };
            $div.ejToolbar(helper);
            $div.ejToolbar("disableItem", proxy._disabledToolItems);
            proxy._disabledToolItems = $();
            return $div;
        },
        //Render list to display the tools in toolbar.
        _renderLi: function ($ul) {
            var proxy = this,
                toolBarItems = proxy.model.toolbarSettings.toolbarItems,
                length = toolBarItems.length,
                i = 0,
                $li;
            for (i; i < length; i++) {

                $li = ej.buildTag("li", "", {}, {
                    id: proxy._id + "_" + toolBarItems[i],
                    "tabindex": "0"
                });

                if (toolBarItems[i] !== "search")
                    $li.css({ 'width': '30px', 'height': '24px', });

                proxy._renderLiContent($li, toolBarItems[i]);
                $ul.append($li);
            }
        },

        //RENDER TOOLBAR ICONS
        _renderLiContent: function ($li, item) {
            var $a, $input;
            var selectedRowIndex = this.model.selectedRowIndex;
            var editSetting = this.model.editSettings;
            switch (item) {

                case "add":
                    $a = ej.buildTag("span.e-addnew e-toolbaricons e-icon e-treegrid-add", "", {});                   
                    $li.attr("title", "Add");
                    if (!this.model.editSettings.allowAdding)
                        this._disabledToolItems.push($li.get(0));
                    break;

                case "edit":
                    $a = ej.buildTag("span.e-edit e-toolbaricons e-icon e-treegrid-edit", "", {});
                    $li.attr("title", "Edit");
                    if (!this.model.editSettings.allowEditing || selectedRowIndex == -1) {
                        this._disabledToolItems.push($li.get(0));
                    }

                    break;

                case "delete":
                    $li.attr("title", "Delete");
                    $a = ej.buildTag("span.e-delete e-toolbaricons e-icon e-treegrid-delete", "", {});

                    if (!this.model.editSettings.allowDeleting || selectedRowIndex == -1) {
                        this._disabledToolItems.push($li.get(0));
                    }

                    break;

                case "update":
                    $li.attr("title", "Update");
                    $a = ej.buildTag("span.e-save e-toolbaricons e-icon e-treegrid-save e-disabletool", "", {});
                    this._disabledToolItems.push($li.get(0));
                    break;

                case "cancel":
                    $li.attr("title", "Cancel");
                    $a = ej.buildTag("span.e-cancel e-toolbaricons e-icon e-treegrid-cancel e-disabletool", "", {});
                    this._disabledToolItems.push($li.get(0));
                    break;

                case "expandAll":
                    $li.attr("title", "ExpandAll");
                    $input = ej.buildTag("span.e-expandall e-toolbaricons e-icon e-treegrid-expandall", "", {}, {});
                    $li.append($input);
                    break;

                case "collapseAll":
                    $li.attr("title", "CollapseAll");
                    $input = ej.buildTag("span.e-collapseall e-toolbaricons e-icon e-treegrid-collapseall", "", {}, {});
                    $li.append($input);
                    break;
            }

            $li.append($a);
        },



        //#region TREEGRIDHEADER RENDERIGN

        //TREEGRID HEADER RENDER INITIALIZATION
        _renderAfterColumnInitialize:function(){
            var proxy = this;
            proxy.element.append(proxy._renderGridHeader());
        },

        //TO CHECK FILTER FORM ELEMENTS EDIT TYPE
        filterEditType: function (column, element, j) {

            var proxy = this,
                model = proxy.model;
               
            if (ej.isNullOrUndefined(column["filterEditType"]))
                column["filterEditType"] = "stringedit";

            switch (column["filterEditType"]) {
                case "stringedit":
                    element.html(ej.buildTag('input.e-ejinputtext e-filtertext e-field e-filterwidth', "", {}, { id: column.field + "_filterbarcell", name: column.field }));
                    break;
                case "booleanedit":
                    element.html('<input class="e-field e-checkbox e-filtertext" type ="checkbox" id=' + column.field + "_filterbarcell" + ' name=' + column.field + ' />');
                    break;
                case "numericedit":
                    var $numericText = ej.buildTag('input.e-numerictextbox e-field', "", { "width": column.width - 15 }, { type: "text", id: column.field + "_filterbarcell", name: column.field });
                    element.append($numericText);
                    break;
                case "datepicker":
                case "datetimepicker":
                    var $datePicker = ej.buildTag('input.e-' + column["filterEditType"] + ' e-field', "", {}, { type: "text", id: column.field + "_filterbarcell", name: column.field });
                    element.append($datePicker);
                    break;
                case "dropdownedit":
                    var $dropDownList = ej.buildTag('input.e-field .e-dropdownlist' + ' e-field', "", {}, { type: "text", id: column.field + "_filterbarcell", name: column.field });
                    element.append($dropDownList);
                    break;
            }
        },


        //RENDER FILTER BAR ELEMENTS ACCORDING TO ITS TYPE
        _filteringElements: function (args) {
            var proxy = this,
                model=proxy.model,
                elementFocused = false,
                $formElement,
                i = 0, form, length,
                $element,
                width,
                params = {},
                value,
                column,
                customParams,
                toformat,
                formatVal;
            selectedItem = model.selectedItem;

            if (args.requestType == "filtering") {
                form = document.getElementById(proxy._id + "_filterBar" + args.fieldname);
            }
            
            var column = customParams = ej.TreeGrid.getColumnByField(model.columns,args.fieldname)
            $formElement = $(form).find("input,select");
            length = $formElement.length;
            for (i; i < length; i++) {
                $element = $formElement.eq(i);
                params = {};
                //inputWidth = column.width ? column.width - 2 : proxy.model.commonWidth - 2;
                inputWidth = $element.closest("div").width()-2;
                if ($element.hasClass("e-numerictextbox")) {
                    width = inputWidth;
                    value = $element.val();
                    params.width = width;                    
                    params.showSpinButton = true;
                    params.cssClass = model.cssClass;
                    params.height = 28;
                    //for parent editing 
                    var tempId = $element[0].id;
                    tempId=tempId.replace(proxy._id, '');
                    if (model.filterBarMode=="immediate")
                        params.change = $.proxy(proxy._filterBarHandler, proxy, $element);

                    if (value.length)
                        params.value = parseFloat(value);
                    else
                        params.value = null;
                    customParams = ej.TreeGrid.getColumnByField(proxy.model.columns, $element.prop("name"));
                    if (!ej.isNullOrUndefined(customParams) && !ej.isNullOrUndefined(customParams["editParams"]))
                        $.extend(params, customParams["editParams"]);
                    $element.ejNumericTextbox(params);
                    $element.prop("name", $element.prop("name").replace(proxy._id, ""));
                }
                else if ($element.hasClass("e-datepicker")) {
                    width = inputWidth;
                    params.width = width;                    
                    params.cssClass = model.cssClass;
                    params.dateFormat = model.dateFormat;
                    params.locale = model.locale;
                    params.displayDefaultDate = true;
                    params.height = 28;
                    var tempId = $element[0].id;
                    tempId = tempId.replace(proxy._id, '');
                    //To filter the records once the date seleted.
                    if (model.filterBarMode == "immediate")
                    params.select = $.proxy(proxy._filterBarHandler, proxy, $element);
                    column = ej.TreeGrid.getColumnByField(proxy.model.columns, $element.prop("name"));
                    if (column["format"] !== undefined && column.format.length > 0) {
                        toformat = new RegExp("\\{0(:([^\\}]+))?\\}", "gm");
                        formatVal = toformat.exec(column.format);
                        params.dateFormat = formatVal[2];
                    }
                    if (!ej.isNullOrUndefined(column["editParams"]))
                        $.extend(params, column["editParams"]);

                    if (model.dateFormat.indexOf("hh") != -1)
                        $element.ejDateTimePicker(params);
                    else
                        $element.ejDatePicker(params);
                }
                else if ($element.hasClass("e-datetimepicker")) {
                    width = inputWidth;
                    params = {
                        width: width,
                        rtl: model.rtl,
                        locale:model.locale,
                        cssClass: model.cssClass,
                        showButton: false,

                    };
                    params.height = 28;
                    column = ej.TreeGrid.getColumnByField(proxy.model.columns, $element.prop("name"));
                    if (column["format"] !== undefined && column.format.length > 0) {
                        toformat = new RegExp("\\{0(:([^\\}]+))?\\}", "gm");
                        formatVal = toformat.exec(column.format);
                        params.dateTimeFormat = formatVal[2];
                    }
                    if (!ej.isNullOrUndefined(column["editParams"]))
                        $.extend(params, column["editParams"]);

                    if (model.dateFormat.indexOf("hh") != -1)
                        $element.ejDateTimePicker(params);
                    else
                        $element.ejDatePicker(params);

                }
                else if ($element.hasClass("e-dropdownlist")) {
                    column = ej.TreeGrid.getColumnByField(proxy.model.columns, $element.prop("name"));
                    var dataSource = column.dropdownData;
                    var checkReadonly=false;
                    if (selectedItem !== null && selectedItem.hasChildRecords && args.requestType !== "add")
                    {
                        checkReadonly=true;
                    }

                    $element.ejDropDownList({
                        width:inputWidth,
                        showCheckbox: true,
                        dataSource: dataSource,
                        readOnly: checkReadonly,
                        height : 28,
                        fields: { id: model.resourceIdMapping, text: model.resourceNameMapping, value: model.resourceNameMapping },
                        selectedItems: proxy.getIndexofresourceInfo(dataSource,args.data)
                    });
                    $element.ejDropDownList("setSelectedValue", $element.val());
                } else {
                    switch ($element.prop('tagName')) {
                        case "INPUT":
                            $element.width(inputWidth-4);
                            break;

                        case "SELECT":
                            $element.width(inputWidth).height(15);
                            break;
                    }
                }
                if (!$element.is(":disabled") && !elementFocused && (!$element.is(":hidden") || typeof $element.data("ejDropDownList") == "object")) {
                    if (!proxy._isEnterKeyPressed) {
                        elementFocused = true;
                    }
                }
            }
        },

        // METHOD TO RENDER FILDERING ELEMENTS
        _renderFiltering: function () {
            var proxy = this,
            columns = this.model.columns;
            var $tr = ej.buildTag('tr.e-filterbar', "", {}, {});
            for (var column = 0; column < this.model.columns.length; column++) {

                if (proxy.model.allowFiltering) {
                    var $th = ej.buildTag('th.e-filterbarcell .e-editValue', "", {}, {});
                    $div = ej.buildTag('div.e-filterdiv', "", {}, { id: proxy._id + "_filterBar" + columns[column].field });
                    $tr.append($th.append($div));
                    //Condition to check whether allow filtering enabled for the individual column before rendering filtering elements
                    if (columns[column].allowFiltering==false)
                        continue;
                    else {                        
                       
                        this.filterEditType(columns[column], $div, column);
                        var $span = ej.buildTag('span.e-cancel e-icon e-hide e-spanstyle');
                        this.model.columns[column]["visible"] === false && $th.addClass("e-hide");
                        $div.append($span);
                    }                   
                }          
            }
            return $tr;
        },

        //METHOD FOR RENDERING TREEGRID HEADER
        _renderGridHeader: function () {

            var proxy = this,
                model = proxy.model,
                doc = document,
                $innerDiv = ej.buildTag('div.e-gridheadercontainer', "", { "overflow": "hidden" }, {}),
                $table = ej.buildTag('table.e-table', "", {}, { "cellspacing": "0px", "border-spacing": "0px" }),
                $thead = ej.buildTag('thead'),
                $tbody = ej.buildTag('tbody.e-hide'),
                $columnHeader = ej.buildTag('tr.e-columnheader'),
                $colGroup = $(doc.createElement('colgroup')),
                $rowBody = $(doc.createElement('tr')),
                columnCount = 0,
                columns = model.columns,
                length = columns.length,
                $headerCell,
                bodyCell,
                $headerCellDiv,
                col,
                $div = model.isFromGantt ? ej.buildTag('div.e-gridheader#' + proxy._id + "e-gridheader", "", {}, "") :
                    ej.buildTag('div.e-gridheader#' + proxy._id + "e-gridheader", "",
                {
                    "border-top-style": "solid",
                    "border-left-style": "solid",
                    "border-right-style": "solid",
                    "border-top-width": "1px",
                    "border-left-width": "1px",
                    "border-right-width": "1px",
                    "width": proxy._gridWidth,
                }, "");
            

            proxy.setGridHeaderContent($div);
            proxy._$gridHeaderContainer = $innerDiv;
            proxy._hiddenColumns = [];

            //CHECK SORTING ENABLED OR NOT
            if (model.allowSorting) {
                $columnHeader.css({ 'cursor': 'pointer' });
            }

            for (columnCount; columnCount < length; columnCount++) {
                if (columns[columnCount]) {
                    $headerCell = ej.buildTag('th.e-headercell', "", { "height": "45px" }, {});
                    bodyCell = doc.createElement('td');

                    $headerCellDiv = ej.buildTag(
                        'div.e-headercelldiv',
                        columns[columnCount]["headerText"] == undefined ?
                        columns[columnCount]["headerText"] = columns[columnCount]["field"] :
                        columns[columnCount]["headerText"], {}, { 'unselectable': "on" }
                    );

                    $headerCell.append($headerCellDiv);

                    col = doc.createElement('col');

                    $rowBody.append(bodyCell);
                    $columnHeader.append($headerCell);
                    $colGroup.append(col);


                    //CHECK VISIBLE PROPERTY OF THE COLUMN
                    if (columns[columnCount]["visible"] === false) {
                        $headerCell.addClass("e-hide") && $(col).css("display", "none") &&
                        proxy._hiddenColumns.push(columns[columnCount].headerText);

                    } else {
                        proxy._visibleColumns.push(columns[columnCount].headerText);
                        columns[columnCount]["visible"] = true;
                    }

                    if (columns[columnCount]["allowSorting"] === false) {
                        proxy._disabledSortableColumns.push(columns[columnCount].headerText);
                        $headerCell.css({ 'cursor': 'normal' });
                    }

                    if (!ej.isNullOrUndefined(columns[columnCount]["headerTemplateID"])) {
                        $headerCellDiv.html($(columns[columnCount]["headerTemplateID"]).hide().html()).parent().addClass("headertemplate");
                    }

                    if (columns[columnCount]["width"] == undefined && model.commonWidth !== undefined) {
                        proxy._columnsWidthCollection[columnCount] = model.commonWidth;
                    } else {
                        proxy._columnsWidthCollection.push(columns[columnCount]["width"]);
                    }

                    proxy._fieldColumnNames[columns[columnCount].headerText] = columns[columnCount].field;
                    proxy._headerColumnNames[columns[columnCount].field] = columns[columnCount].headerText;
                }
            }
            // Condition to check whether filtering enabled to render filter elements.
            $filterHeader = ej.buildTag('tr.e-filterbar');
            if (this.model.allowFiltering && !proxy.model.isFromGantt)
            {
                $filterHeader = this._renderFiltering();
            }

            $thead.append($columnHeader).append($filterHeader);
            $table.append($colGroup).append($thead);

            $innerDiv.html($table);
            $div.html($innerDiv);

            proxy.setGridHeaderTable($table);

            return $div;
        },

        //#endregion

        //#region TREEGRIDCONTENT RENDERING
        //TREEGRID CONTENT RENDER INITIALIZATION
        _initGridRender: function () {

            var proxy = this;
            proxy._addInitTemplate();
            proxy._renderGrid();

            //CHECK COLUMN RESIZE IS ENABLED OR NOT AND INITIALIZE THE RESIZER
            if (proxy.model.allowColumnResize) {
                proxy._resizer = new ej.Grid.gridResize(proxy);
            }

        },


        //ADD GRIDCONTENT TO THE TREEGRID
        _renderGrid: function () {
            
            var proxy = this;
            proxy._renderGridContent().insertAfter(proxy.element.children(".e-gridheader"));
            proxy._initialEndRendering();

        },


        //RENDER THE GRIDCONTENT
        _renderGridContent:function(){
            
            var proxy = this,
                doc = document,
                model = proxy.model,
                $tbody = $(doc.createElement('tbody')),
                $div = ej.buildTag("div.e-gridcontent#" + proxy._id + "e-gridcontent", "",
                {                    
                    "height": proxy._viewPortHeight
                },
                {"unselectable":"on"}),
                $innderDiv = ej.buildTag('div.e-gridcontainer#' + proxy._id + "e-gridcontainer", "", {}, {});

            //CHECK VIRTUALIZATION ENABLED OR NOT
            if (model.enableVirtualization) {
                $innderDiv.css({ 'height': proxy._totalHeight });
            }

            var $table = ej.buildTag('table.e-table#' + proxy._id + "e-table", "",
                {top: "0px" }, { 'cellspacing': '0px' });

            $table.append(proxy.getHeaderTable().find('colgroup').clone()).append($tbody);
            $innderDiv.html($table);
            $div.html($innderDiv);
            proxy.setGridContentTable($table);

            //CHECK DATASOURCE IS DEFINED OR NOT
            if (this.dataSource() === null) {
                var $emptyTd = ej.buildTag('td', model.emptyRecordText, {}, { colSpan: model.columns.length });
                $tbody.append($(doc.createElement("tr")).append($emptyTd));
                $innderDiv.css('height', model.rowHeight);
            } else
            {
                proxy.renderRecords();
            }

            if (!model.isFromGantt) {
                $div.css({
                    "border-bottom-style": "solid",
                    "border-bottom-width": "1px",
                    "border-left-style": "solid",
                    "border-left-width": "1px",
                    "border-right-style": "solid",
                    "border-right-width": "1px",
                    "width": "auto",
                    "height":"auto"
                });
            }

            $table.css({ 'position': 'relative' });
            return $div;

        },


        //AFTER INITIALIZATION END RENDERING
        _initialEndRendering: function () {

            var proxy = this,
                index = proxy.selectedRowIndex();

            if (index != -1 && proxy.model.allowSelection) {

                if (!proxy._rowSelectingEventTrigger()) {

                    proxy.selectRows(index);
                    proxy._rowSelectedEventTrigger(index);

                }
            }
        },

        //#endregion
        
        //#region TEMPLATE

        //ADD CELLEDITING TEMPLATE
        _addCellEditTemplate: function () {

            var proxy = this,
                model = proxy.model,
                columns = model.columns,
                columnCount = 0,
                $outerDiv = ej.buildTag('div', "", { display: 'none' }, { id: proxy._id + "_CellEditTemplate" }),
                $innerDiv,
                length =columns&& columns.length;

            for (columnCount = 0; columnCount < length; columnCount++) {
                if (columns[columnCount]) {
                    $innerDiv = ej.buildTag('div', "", {}, { id: columns[columnCount].field + "_CellEdit" });
                    ej.TreeGrid._initCellEditType(proxy, $innerDiv, proxy._id, columnCount);
                    $outerDiv.append($innerDiv);
                }
            }

            if ($outerDiv.children().length) {
                proxy._cellEditTemplate = $outerDiv;
            }

        },


        //ADD TEMPLATE FOR RENDERING GRIDCONTENT
        _addInitTemplate:function(){

            var proxy = this,
                model = proxy.model,
                columns = model.columns,
                columnCount = 0,
                length = columns.length,
                columnName,
                tdCell,
                helpers = {};

            //CHECK THE COLUMNS ARRAY CONTAIN THE COLUMN OBJECT
            if (columns.length === 0) {
                return false;
            }

            helpers["_" + proxy._id + "rowClassName"] = ej.TreeGrid._getrowClassName;
            helpers["_" + proxy._id + "expandStatus"] = $.proxy(proxy._getExpandStatusRecord, proxy);         
            helpers["_" + proxy._id + "cellValue"] = proxy._getCellValue;
            helpers["_" + proxy._id + "getIndentWidth"] = $.proxy(proxy._getIndentWidth, proxy);
            helpers["_" + proxy._id + "checkColumn"] = $.proxy(proxy._getCellColumn, proxy);

            helpers["_treeGridTemplating"] = ej.proxy(proxy._gridTemplate, null, proxy);
            helpers["_" + proxy._id + "itemDetails"] = $.proxy(proxy._convertItemToString, proxy);

            $.views.helpers(helpers);

            
            if (model.rowTemplateID.length > 0) {
                
                var altRowTemplateElement = ej.buildTag("tbody", "", {}, {});
                var rowTemplateElement = ej.buildTag("tbody", "", {}, {});
                var rowTemplateHTML = "";
                var altRowTemplateHTML = "";


                var altRowTemplate = model.altRowTemplateID.length > 0 ? $("#" + model.altRowTemplateID)[0].innerHTML : $("#" + model.rowTemplateID)[0].innerHTML;

                $(altRowTemplateElement[0]).html(altRowTemplate);
                $(rowTemplateElement[0]).html($("#" + model.rowTemplateID)[0].innerHTML);

                if (rowTemplateElement[0].childNodes.length > 0) {
                    for (var i = 0; i < rowTemplateElement[0].childNodes.length; i++) {
                        if (rowTemplateElement[0].childNodes[i].nodeName == 'TR') {

                            rowTemplateElement[0].className = rowTemplateElement[0].childNodes[i].className;
                            rowTemplateElement[0].style.cssText = rowTemplateElement[0].childNodes[i].style.cssText;

                            if (rowTemplateElement[0].childNodes[i].childNodes.length > 0) {
                                var tdCount = 0;
                                for (var j = 0; j < rowTemplateElement[0].childNodes[i].childNodes.length; j++) {

                                    var childNode = rowTemplateElement[0].childNodes[i].childNodes[j];

                                    if (childNode.nodeName == 'TD') {
                                        var innerHtml = childNode.innerHTML;

                                        $("#" + proxy._id + "RowTemplateElement" + tdCount).remove();
                                        var scriptElement = this._createRowTemplateElement(innerHtml, tdCount);
                                        childNode.innerHTML = "{{:~_treeGridTemplating('" + scriptElement.id + "')}}";


                                        childNode.className += " e-rowcell e-templatecell";
                                        if (tdCount == model.treeColumnIndex) {
                                            var indentDiv = "<div  style='height:20px;' unselectable='on'>" +
                                            "<div class='intend' style='height:1px; float:left;width:{{:~_" + proxy._id + "getIndentWidth(#data)}}; display:inline-block;'></div>" +
                                            "<div class='{{if expanded}}e-treegridexpand e-icon{{else hasChildRecords}}e-treegridcollapse e-icon{{/if}}' " +
                                            "style='height:20px;width:30px;margin:auto;float:left;margin-left:10px;style='float: left;display:inline-block; unselectable='on'></div>"+
                                             "<div class='e-cell' style='display:inline-block;width:100%' unselectable='on'>";

                                            rowTemplateHTML += "<td class='" + childNode.className + "{{if isSelected}}e-selectionbackground{{/if}}' style='"
                                                + childNode.style.cssText + "'>" + indentDiv +
                                                childNode.innerHTML + "</div></div></td>";
                                        }
                                        else {
                                            rowTemplateHTML += childNode.outerHTML;
                                        }
                                        tdCount++;
                                    }
                                }
                            }
                        }
                    }
                }

                if (altRowTemplateElement[0].childNodes.length > 0) {
                    for (var i = 0; i < altRowTemplateElement[0].childNodes.length; i++) {
                        if (altRowTemplateElement[0].childNodes[i].nodeName == 'TR') {
                            altRowTemplateElement[0].className = altRowTemplateElement[0].childNodes[i].className;
                            altRowTemplateElement[0].style.cssText = altRowTemplateElement[0].childNodes[i].style.cssText;
                            var tdCount = 0;

                            for (var j = 0; j < altRowTemplateElement[0].childNodes[i].childNodes.length; j++) {

                                var childNode = altRowTemplateElement[0].childNodes[i].childNodes[j];

                                if (childNode.nodeName == 'TD') {

                                    var innerHtml = childNode.innerHTML;
                                    $("#" + proxy._id + "RowTemplateElement" + tdCount).remove();
                                    var scriptElement = this._createRowTemplateElement(innerHtml, tdCount);
                                    childNode.innerHTML = "{{:~_treeGridTemplating('" + scriptElement.id + "')}}";

                                    childNode.className += " e-rowcell e-templatecell";

                                    if (tdCount == model.treeColumnIndex) {
                                        var indentDiv = "<div  style='height:20px;' unselectable='on'>" +
                                        "<div class='intend' style='height:1px; float:left;width:{{:~_" + proxy._id + "getIndentWidth(#data)}}; display:inline-block;'></div>" +
                                        "<div class='{{if expanded}}e-treegridexpand e-icon{{else hasChildRecords}}e-treegridcollapse e-icon{{/if}}' " +
                                        "style='height:20px;width:30px;margin:auto;float:left;margin-left:10px;style='float: left;display:inline-block; unselectable='on'></div>" +
                                        "<div class='e-cell' style='display:inline-block;width:100%' unselectable='on'>";

                                        altRowTemplateHTML += "<td class='" + childNode.className + "{{if isSelected}}e-selectionbackground{{/if}}'" +
                                            " style='" + childNode.style.cssText + "'>" + indentDiv +
                                            childNode.innerHTML + "</div></div></td>";

                                    }
                                    else {
                                        altRowTemplateHTML += childNode.outerHTML;
                                    }
                                    tdCount++;
                                }
                            }
                        }
                    }
                }
               
                var trRow = "{{if isAltRow}}" + "<tr class='{{:~_" + proxy._id + "rowClassName()}} " +
                    "{{if expanded}}e-treegridrowexpand {{else hasChildRecords}} e-treegridrowcollapse {{/if}} e-templaterow"
                    + altRowTemplateElement[0].className + "'  style='" + altRowTemplateElement[0].style.cssText + "'>" + altRowTemplateHTML + "</tr>"

                    + "{{else}}" + "<tr class='{{:~_" + proxy._id + "rowClassName()}} " +
                    "{{if expanded}}e-treegridrowexpand {{else hasChildRecords}} e-treegridrowcollapse {{/if}} e-templaterow"
                    + rowTemplateElement[0].className + "'  style='" + rowTemplateElement[0].style.cssText + "'>" + rowTemplateHTML + "</tr>" +
                    "{{/if}}";

            }

            else {

                var trRow = "<tr class='e-treegridrows {{:~_" + proxy._id + "rowClassName()}} ";

                if (model.enableAltRow) {
                    trRow += "{{if isAltRow}}e-alt-row{{/if}} ";
                }

              
                var tdCellCollections = "";

                for (columnCount = 0; columnCount < length; columnCount++) {
                    if (columns[columnCount]) {
                        columnName = columns[columnCount].field;

                        //CHECK THE template COLUMN OR NOT
                        if (columns[columnCount]["isTemplateColumn"]) {

                            trRow += "e-templaterow "

                            var templateId = columns[columnCount]["templateID"],
                                template = columns[columnCount]["template"],
                                angularTemplate = columns[columnCount]["angularTemplate"];

                            if (angularTemplate) {
                                $("#" + proxy._id + columns[columnCount].headerText + columnCount + "_Template").remove();
                                var scriptElement = this._createTemplateElement(columns[columnCount]);

                                tdCell = "<td style=''" +
                                     "class='{{if isSelected}}e-rowcell e-selectionbackground e-intend {{else}}e-rowcell e-intend {{/if}} e-templatecell'" +
                                     "role='gridcell'" +
                                     "'tabindex='-1'>{{:~_treeGridTemplating('" + scriptElement.id + "')}}</td>";
                            }

                            else if (templateId) {

                                tdCell = "<td style=''" +
                                     "class='{{if isSelected}}e-rowcell e-selectionbackground e-intend {{else}}e-rowcell e-intend {{/if}} e-templatecell'" +
                                     "role='gridcell'" +
                                     "'tabindex='-1'" +
                                     "aria-label={{:~_" + proxy._id + "itemDetails(#data)}}>" +
                                      $("#" + templateId)[0].innerHTML +
                                     "</td>";

                            } else if (template) {

                                tdCell = "<td " +
                                     "class='{{if isSelected}}e-rowcell e-selectionbackground e-intend {{else}}" +
                                     "e-rowcell e-intend {{/if}} e-templatecell'" +
                                     "role='gridcell'" +
                                     "tabindex='-1'" +
                                     "aria-label={{:~_" + proxy._id + "itemDetails(#data)}}>" +
                                     template +
                                     "</td>";
                            }

                            //EXPAND COLLAPSE COLUMN BASED ON THE TREECOLUMNINDEX
                        } else if (columnCount === model.treeColumnIndex) {

                            tdCell = "<td " +
                                 "class='{{if isSelected}}e-rowcell e-selectionbackground e-intend {{else}}e-rowcell e-intend {{/if}}'" +
                                "style='background-color:{{if cellBackgroundColor && ~_" + proxy._id + "checkColumn('" + columnName + "',#data)=='" + columnName + "'}}{{:cellBackgroundColor}}{{else}}none{{/if}};'" +
                                 "role='gridcell'" +
                                 "tabindex='-1'" +
                                 "aria-label={{:~_" + proxy._id + "itemDetails(#data)}}>" +
                                 "<div  style='height:20px;' unselectable='on'>" +
                                 "{{if hasChildRecords}}" +
                                 "<div " +
                                 "class='intend'" +
                                 "style='height:1px; float:left; width:{{:level*20}}" + "px; display:inline-block;'>" +
                                 "</div>" +
                                 "{{else !hasChildRecords}}" +
                                 "<div " +
                                 "class='intend'" +
                                 "style='height:1px; float:left; width:{{:(level+1)*20}}" + "px; display:inline-block;'>" +
                                 "</div>" +
                                 "{{/if}}" +
                                 "<div " +
                                 "class='{{if expanded}}e-treegridexpand e-icon{{else hasChildRecords}}" +
                                 "e-treegridcollapse e-icon{{/if}}'" +
                                 "style='float: left;display:inline-block; font-size:10px; unselectable='on''>" +//unselectable on icon div
                                 "</div>" +
                                 "<div class='e-cell'" +
                                 "style='display:inline-block;width:100%;' unselectable='on'>" +//unselectable on
                                 "{{:#data['" + columnName + "']}}" +
                                 "</div>" +
                                 "</div>" +
                                 "</td>";
                            //CHECK RESOURCE COLUMN FROM GANTT OR NOT
                        } else if (model.isFromGantt && columns[columnCount].mappingName === model.resourceInfoMapping) {
                            helpers = {};
                            helpers["_" + proxy._id + "resourceName"] = proxy._getResourceName;
                            $.views.helpers(helpers);

                            tdCell = "<td  " +
                                 "class='{{if isSelected}}e-rowcell e-selectionbackground{{else}}e-rowcell {{/if}}'" +
                                "style='background-color:{{if cellBackgroundColor && ~_" + proxy._id + "checkColumn('" + columnName + "',#data)=='" + columnName + "'}}{{:cellBackgroundColor}}{{else}}none{{/if}};'" +
                                 "role='gridcell'" +
                                 "tabindex='-1'" +
                                 "aria-label={{:~_" + proxy._id + "itemDetails(#data)}}>" +
                                 "{{:~_" + proxy._id + "resourceName('" + proxy._id + "Object','"
                                 + model.resourceNameMapping + "','" + columnName + "')}}" +
                                 "</td>";
                            //CHECK PREDECESSOR COLUMN FROM GANTT OR NOT
                        } else if (model.isFromGantt && columns[columnCount].mappingName === model.predecessorMapping) {

                            helpers = {};
                            helpers["_" + proxy._id + "predecessor"] = proxy._getPredecessorsValue;
                            $.views.helpers(helpers);

                            tdCell = "<td " +
                                "class='{{if isSelected}}e-rowcell e-selectionbackground{{else}}e-rowcell {{/if}}' " +
                                "style='background-color:{{if cellBackgroundColor && ~_" + proxy._id + "checkColumn('" + columnName + "',#data)=='" + columnName + "'}}{{:cellBackgroundColor}}{{else}}none{{/if}};'" +
                                "role='gridcell'" +
                                "tabindex='-1'" +
                                "aria-label={{:~_" + proxy._id + "itemDetails(#data)}}>" +
                                "{{:~_" + proxy._id + "predecessor('" + proxy._id + "Object','"
                                + model.predecessorMapping + "','" + columnName + "')}}" +
                                "</td>";

                        }
                        else {
                            tdCell = "<td " +
                                "class='{{if isSelected}}e-rowcell e-selectionbackground{{else}}e-rowcell{{/if}}'" +
                                "style='background-color:{{if cellBackgroundColor && ~_" + proxy._id + "checkColumn('" + columnName + "',#data)=='" + columnName + "'}}{{:cellBackgroundColor}}{{else}}none{{/if}};'" +
                                "role='gridcell'" +
                                "tabindex='-1'" +
                                "aria-label={{:~_" + proxy._id + "itemDetails(#data)}} unselectable='on'>" +
                                "{{:~_" + proxy._id + "cellValue('" + columnName + "')}}" +
                                "</td>";//unselectable for 
                        }

                        tdCellCollections += tdCell;
                    }
                }

                trRow += "{{if expanded}}e-treegridrowexpand {{else hasChildRecords}} " +
                      "e-treegridrowcollapse {{/if}} '" +
                      "style='background-color:{{if rowBackgroundColor }}{{:rowBackgroundColor}}{{else}}none{{/if}}; height:" + model.rowHeight + "px;display:{{:~_" + proxy._id + "expandStatus(#data)}}'" +
                      "role='row'>";

                trRow += tdCellCollections;

                if (model.isFromGantt) {
                    trRow += "<td class='e-extendcolumn'></td></tr>";
                }
            }

            var templates = {};
                templates[proxy._id + "_Template"] = trRow;
            $.templates(templates);

            

        },
        
        //#endregion template

        //#region template METHODS

        _gridTemplate: function (self, templateId) {
            return self._renderEjTemplate("#" + templateId, this.data, this.data.index);
        },

        //method for calculating the indent width for expander column
        _getIndentWidth:function(data){
            var level = data.level;
            if (data.hasChildRecords) {
                return (level * 20) + "px";
            }
            else {
                return ((level + 1) * 20) + "px";
            }
        },

        //creating template element for angulartemplate in row template
        _createRowTemplateElement: function (innerHtml, cellCount) {
            var scriptElement = document.createElement("script");
            scriptElement.id = ("treeGridRowTemplateElement" + cellCount).split("").join("");
            scriptElement.type = "text/x-template";
            scriptElement.text = innerHtml;

            $("body").append(scriptElement);
            return scriptElement;
        },

        //creating a template element for angularjs template
        _createTemplateElement: function (column) {
            var scriptElement = document.createElement("script");
            scriptElement.id = ("treeGrid" + column.headerText + $.inArray(column, this.model.columns) + "_Template").split(" ").join("");
            scriptElement.type = "text/x-template";
            scriptElement.text = $(column["angularTemplate"]).html();



            $("body").append(scriptElement);
            return scriptElement;
        },

        //CONVERT RECORD OBJECT TO STRING
        _convertItemToString: function (data) {

            var str = '',
                labelObject = {},
                columns = this.model.columns;

            for (var i = 0; i < columns.length; i++) {
                if (columns[i]) {
                    labelObject[columns[i].field] = data.item[columns[i].field];
                }
            }

            for (var p in labelObject) {
                if (labelObject.hasOwnProperty(p)) {
                    str += p + '' + labelObject[p] + '\n';
                }
            }

            return str;
        },

        _getCellValue: function (columnName) {

            var cellValue = this.data[columnName];

            if (cellValue || cellValue===0) {
                return cellValue;
            } else {
                return this.data.item && this.data.item[columnName];
            }


        },

        _getCellColumn: function (columnName,data) {
            var proxy = this;

            if (data.treeMappingName.indexOf(columnName) !== -1) {
                return columnName;
            }
            else {
                return "none"
            }


        },

        //GET RESOURCE NAME FOR RESOURCE COLUMN IN THE GANTT CONTROL
        _getResourceName: function (gridObject, mappingName, columnName) {

            var proxy = this,
                data = proxy.data[columnName],
                count = 0,
                length = data && data.length,
                resourceName = [];

            if (data && data.length > 0) {
                for (count; count < length; count++) {
                    resourceName.push(data[count][mappingName]);
                }
            }
            return resourceName;
        },


        //GET PREDECESSOR VALUE FOR PREDECESSOR COLUMN IN THE GANTT CONTROL
        _getPredecessorsValue: function (gridObject, mappingName) {

            return this.data.item[mappingName];

        },


        //GET THE EXPAND COLLAPSE STATUS OF TABLE ROW
        _getExpandStatusRecord: function (data) {

            var proxy = this;

            if (proxy.getExpandStatus(data)) {

                return 'table-row';

            }

            return 'none';
        },

        //#endregion TEMPLATE METHODS

        //#region CONVERT HIERARCHICAL RECORDS TO FLAT RECORDS
        //CREATE FLATRECORDS FROM HIERARCHICAL DATASOURCE
        _createRecords: function (dataSource) {

            var proxy = this,
                model = proxy.model,
                flatRecords = model.flatRecords,
                length = dataSource.length,
                count = 0,
                parentRecord,
                parentRecords = model.parentRecords,
                rows = model.records;                

            for (count; count < length; count++) {

                parentRecord = proxy._createRecord(dataSource[count], 0, null);
                proxy._storedIndex++;

                //CHECK ALTROW ENABLED OR NOT
                //if (enableAltRow) {     //  DYNAMICALY CHANGE THE ALTROW 
                parentRecord.isAltRow = proxy._storedIndex % 2 == 0 ? false : true;
                //}

                //CHECK SORTING ENABLED OR NOT
                //if (enableSorting) {//  DYNAMICALY CHANGE THE ALTROW 
                parentRecords.push(parentRecord);
                //}

                parentRecord.index = proxy._storedIndex;
                rows[proxy._storedIndex] = parentRecord;
                flatRecords.push(parentRecord);
                parentRecord.childRecords && proxy._addNestedRecords(parentRecord.childRecords);

            }
        },


        //CREATE RECORD OBJECT
        _createRecord: function (data, level, parentItem, expanded) {

            var proxy = this,
                record,
                childDataSource = data[proxy.model.childMapping],model=this.model;

            //CLONE THE DATA OBJECT
            record = $.extend({}, data);
            var tempData;
            if (model.parentIdMapping && proxy._createdAt==="load") {
                tempData = ej.DataManager(proxy._retrivedData).executeLocal(ej.Query().where(model.idMapping,
                ej.FilterOperators.equal,
                record[model.idMapping]));
                record.item = tempData[0];
            }
            else {

                if (this.dataSource() instanceof ej.DataManager && this.dataSource().dataSource.json && this.dataSource().dataSource.offline && proxy._createdAt === "load") {
                    var tempData = ej.DataManager(proxy._retrivedData).executeLocal(ej.Query().where(model.idMapping,
                    ej.FilterOperators.equal,
                    record[model.idMapping]));
                    if (tempData.length > 0) {
                        record.item = tempData[0];
                    } else {
                        record.item = data;
                    }
                }
                else {
                    record.item = data;
                }
            }
            record.parentItem = parentItem;
            record.childRecords = childDataSource && proxy._createChildRecords(childDataSource, level + 1, record);
            record.hasChildRecords = childDataSource ? true : false;
            record.expanded = expanded !== undefined ? expanded : childDataSource ? childDataSource.length > 0 : false;
            record.isSelected = false;
            record.level = level;
            record.cellBackgroundColor = null;
            record.rowBackgroundColor = null;
            record.treeMappingName = [];

            return record;
        },


        //CREATE CHILD GANTT RECORDS
        _createChildRecords: function (childDataSource, level, parentItem) {

            var proxy = this,
                records = [],
                count = 0,
                length = childDataSource.length,
                record = null,
                childRecord;

            for (count = 0; count < length; count++) {

                record = childDataSource[count];

                if (record) {
                    childRecord = proxy._createRecord(record, level, parentItem);
                    records.push(childRecord);
                }
            }

            return records;

        },


        //ADD NESTED RECORDS TO FLATRECORDS
        _addNestedRecords: function (childDataSource) {

            var proxy = this,
                model = proxy.model,
                flatRecords = model.flatRecords,
                count = 0,
                length = childDataSource.length,
                rows = model.records,
                records = [],
                record;
                

            for (count = 0; count < length; count++) {

                record = childDataSource[count];
                proxy._storedIndex++;

                //CHECK ALTROW ENABLED OR NOT
                //if (enableAltRow) {//DYNAMICALLY CHANGE THE ALT ROW
                record.isAltRow = proxy._storedIndex % 2 == 0 ? false : true;
                //}

                record.index = proxy._storedIndex;
                rows[proxy._storedIndex] = record;
                flatRecords.push(record);
                records = record.childRecords;

                if (records) {

                    var j = 0,
                        recordlength = records.length,
                        childRecord = null;

                    for (j = 0; j < recordlength; j++) {

                        childRecord = records[j];
                        proxy._storedIndex++;
                        childRecord.index=proxy._storedIndex;
                        //CHECK ALTROW ENABLED OR NOT
                        //if (enableAltRow) {  //DYNAMICALLY CHANGE THE ALT ROW
                        childRecord.isAltRow = proxy._storedIndex % 2 == 0 ? false : true;
                        //}

                        rows[proxy._storedIndex] = childRecord;
                        flatRecords.push(childRecord);
                        childRecord.childRecords && proxy._addNestedRecords(childRecord.childRecords);
                    }
                }
            }
        },

        //#endregion CONVERT HIERARCHICAL RECORDS TO FLAT RECORDS

        //#region METHOD FOR EVENTS

        //INITIALIZE THE EVENTS
        _wireEvents: function () {

            var proxy = this,
                model = proxy.model;

            proxy._$gridContent.bind("scroll", $.proxy(proxy._onScroll, proxy));
            proxy._on(proxy.element, "click", proxy._onClick);
            proxy._on(proxy.element, "click", "#" + proxy._id + "e-gridheader", proxy._onHeaderClick);
            proxy._on(proxy.element, "mousedown", "#" + proxy._id + "e-gridheader", proxy._headerMouseDown);
            //Method binding for filtering data.
            if (model.filterBarMode == "immediate") {
                this._on(this.element, "keyup", ".e-filterbarcell input", this._filterBarHandler);
                this._off(this.element, "click", ".e-checkbox")._on(this.element, "click", ".e-checkbox", this._filterBarHandler);
            }
            this._on(this.element, "focus click", ".e-filterbarcell input", this._filterBarClose);
            this._on(this.element, "click", ".e-filterbarcell .e-cancel", this._filterBarClose);
            if (proxy.model.showGridCellTooltip && !proxy.model.showGridExpandCellTooltip) {

                if (ej.browserInfo().name == "msie") {
                    proxy._on(proxy.element, "mouseenter", ".e-rowcell", proxy._mouseHover);
                }
                else {
                    proxy._on(proxy.element, "mousemove", ".e-rowcell", proxy._mouseHover);
                }
            }
            else {
                proxy._on(proxy.element, "mouseenter", ".e-rowcell", proxy._mouseHover);
            }
            proxy._on(proxy.element, "mouseleave", ".e-rowcell", proxy._cellMouseLeave);
            proxy._enableColumnResizeEvents();

            //MOUSE WHEEL EVENT FOR GANTT CONTROL
            if (model.isFromGantt) {
                proxy._on(proxy.element, "mousewheel DOMMouseScroll", proxy._mouseWheel);
            }

            if (model.enableResize && !model.isFromGantt) {
                proxy._on($(window), "resize", proxy._windowResize);
            }
            proxy._enableEditingEvents();
            //Mouse right click event for tree grid
            if (!proxy.model.isFromGantt && model.contextMenuSettings.showContextMenu)
                proxy._on(proxy.element, "contextmenu", proxy._rightClick);
        },
   
        //To renter cancel icon in filtering elements.
        _filterBarClose: function (e) {
            var $target = $(e.target);
            if (e.type == "click" && $target.hasClass("e-cancel")) {
                var $targetText = $target.prev();
                    $targetText.focus().val("");
                $targetText.prop('checked', false);
                $targetText.trigger("keyup");
                e.stopPropagation();
            }
            if (e.type == "focusin") { 
                $target = $(e.target).next();
                this.getHeaderTable().find(".e-cancel").addClass("e-hide");
                $target.removeClass("e-hide");
            }
        },

        //To wireup method while user enter text to the filter textbox.
        _filterBarHandler: function (e) {
            var proxy = this;
            proxy.clearSelection(proxy.selectedRowIndex);
            if (e.target == undefined)
                var $target =$(e);
            else
                var $target = $(e.target);
            
            if (this.model.allowFiltering ) {
                var cols=proxy.model.columns;
                var matchcase;
                matchcase = proxy._cellEditingDetails;
                var key = proxy._queryManagar.queries[0];
                if ($target.hasClass("e-checkbox"))
                    proxy._searchString = $target[0].checked;
                else
                    proxy._searchString = $target.closest("input").val();
                    var splits = $target[0].id.split('_');
                proxy._fieldName = splits[0];
                this._currentFilterColumn = cols[j];                        
                for (var j = 0; j < cols.length; j++) {
                    if (cols[j].field == splits[0]) {                               
                        this._currentFilterColumn = cols[j];
                        break;
                    }                            
                }
                proxy._validateFilterValue(proxy._searchString);
                proxy.filterColumn(proxy._fieldName, this._operator, proxy._searchString, this._predicate);
                if (proxy.model.currentViewData.length > 0)
                    ej.TreeGrid.updateAltRow(proxy, proxy.model.currentViewData[0], 0, 0);                
            }
        },
        //Method to validate search string type and assign operators accordingly.
        _validateFilterValue: function (_value) {
            var proxy = this;
            this._predicate = "and";
            switch (this._currentFilterColumn.filterEditType) {
                case "numericedit":
                    this._operator = ej.FilterOperators.equal;
                    break;
                case "datepicker":
                    this._operator = ej.FilterOperators.equal;
                    
                    var _format;
                    if (this._currentFilterColumn.format == "" || this._currentFilterColumn.format == undefined)
                        _format = Globalize.culture().calendar.patterns.d; //System Date format
                    else
                        _format = this._currentFilterColumn.format.split(':')[1].replace('}', "");
                    if (this._currentFilterbarValue != "")
                        this._currentFilterbarValue = Globalize.format(_value, _format);
                    break;
                case "datetimepicker":
                    this._operator = ej.FilterOperators.equal;
                  
                    var _format;
                    if (this._currentFilterColumn.format == "")
                        _format = Globalize.culture().calendar.patterns.f; //System DateTime format
                    else
                        _format = this._currentFilterColumn.format.split(':')[1].replace('}', "");
                    if (this._searchstring != "")
                        this._searchstring = Globalize.format(_value, _format);
                    break;
                case "stringedit":
                    this._operator = ej.FilterOperators.startsWith;
                    break;
                case "booleanedit":
                    if (proxy._searchString == true || proxy._searchString == "1")
                        proxy._searchString = true;
                    else if (proxy._searchString == "false" || proxy._searchString == "0")
                        proxy._searchString = false;
                    this._operator = ej.FilterOperators.equal;
                    break;
                default:
                    this._operator = ej.FilterOperators.equal;
            }
        },
        
        _mouseHover: function (e) {
            e.preventDefault();
            var $target = $(e.target), proxy = this,
                posx = 0,
                posy = 0,
                $ganttGridRows = proxy.getRows(),
                row = $target.closest('tr'),
                div = $target[0].parentNode,
                progressHandler,
                recordIndexr = $ganttGridRows.index(row),
                item = proxy.model.currentViewData[recordIndexr],
                tooltipElement, tooltiptable, tooltipbody;

            

            proxy._cellMouseLeave();

            if (!e) e = window.event;
            if (e.originalEvent.pageX || e.originalEvent.pageY) {
                posx = e.originalEvent.pageX;
                posy = e.originalEvent.pageY;
            }
            else if (e.originalEvent.clientX || e.originalEvent.clientY) {
                posx = e.originalEvent.clientX + document.body.scrollLeft
                    + document.documentElement.scrollLeft;
                posy = e.originalEvent.clientY + document.body.scrollTop
                    + document.documentElement.scrollTop;
            }

            if ((posx + 200) > proxy._windowWidth) {
                posx -= (posx + 200) - proxy._windowWidth;
            }

            if ((posy + 150) > proxy._windowHeight) {
                posy -= (posy + 150) - proxy._windowHeight;
            }

            if (item) {

                tooltipElement = {
                    ttiptaskname: item.taskName
                };


                tooltiptable = ej.buildTag("table.e-tooltiptable", "", { 'padding': '0' }, { 'cellspacing': '1' });
                if (proxy.model.showGridExpandCellTooltip == false) {
                    if ($target[0].firstChild && $target[0].firstChild.textContent) {
                        tooltipbody = ej.buildTag("tbody", $target[0].firstChild.textContent, {}, {});
                    }
                    else if ((div.childNodes.length > 0 && div.childNodes[1] && div.childNodes[1].textContent)) {
                        tooltipbody = ej.buildTag("tbody", div.childNodes[1].textContent, {}, {});

                    }
                }
                else if (proxy.model.showGridExpandCellTooltip == true) {
                    if (($target[0].firstChild && $target[0].firstChild.childNodes.length > 0)
                        && ($target[0].firstChild && $target[0].firstChild.textContent)) {
                        tooltipbody = ej.buildTag("tbody", $target[0].firstChild.textContent, {}, {});

                    }
                }

                tooltiptable.append(tooltipbody);
                if (tooltipbody) {
                    if (!(proxy.model.showGridExpandCellTooltip) && proxy.model.showGridCellTooltip == true && $target[0].firstChild
                        || (proxy.model.showGridExpandCellTooltip && proxy.model.showGridCellTooltip == true)) {

                        proxy._mouseOverTooltip = ej.buildTag("div.e-tooltipgantt#tooltipgantt" + proxy._id + "", tooltiptable,
                            {
                                "top": (posy + 10) + "px", "left": (posx + 15) + "px",
                                'position': 'absolute',
                                'z-index': '5',
                                'padding': '0',
                                'border-radius': '3px'
                            }, {});

                        $(document.body).append(proxy._mouseOverTooltip);
                    }
                }
            }
        },

        _cellMouseLeave: function () {

            var proxy = this;
            $("#tooltipgantt").remove();
            $(proxy._mouseOverTooltip).remove();
        },

        disableTooltip: function () {
            this._cellMouseLeave();
        },

        _createTooltipTemplate: function () {

            var proxy = this,
                td,
                columnHeaderTexts = proxy.model.columnHeaderTexts,
                helpers = {
                    _getTaskName: proxy._tooltipTaskName
                };

            $.views.helpers(helpers);
            var parentTr = "<tr class='e-tooltip_rowcell'>";

            td = "{{if ~_getTaskName()}}" +
                "<td class='e-tooltiptaskname' style='height:auto;width:auto;font-weight:normal;'>{{:ttiptaskname}}</td>{{/if}}";

            parentTr += td;
            parentTr += "</tr>";

            var templates = {};
            templates[proxy._id + "tooltipTemplate"] = parentTr;
            $.templates(templates);
        },

        _tooltipTaskName: function () {
            return this.data.ttiptaskname;
        },

        //SCROLL EVENT FOR VIRTUALIZATION
        _onScroll: function (args) {

            var proxy = this,
                hScrollDist;
            proxy._popupHide();
                     
            if (proxy.model.showGridCellTooltip) {
                proxy._cellMouseLeave();
            }

            if (!proxy.isVScroll() && !proxy.model.isFromGantt && args.source === "wheel") {
                args.cancel = true;
                return;
            }

            if (args.scrollLeft != undefined) {
                proxy._scrollLeft = args.scrollLeft;
                hScrollDist = Math.abs(proxy._scrollLeft - proxy._prevScrollLeft);
            }

            

            if (hScrollDist) {

                //CHANGE SCROLL LEFT VALUE OF HEADER  BASED ON THE SCROLLING OF CONTENT DIV
                proxy._$gridHeaderContainer.scrollLeft(proxy._scrollLeft);
                proxy._prevScrollLeft = proxy._scrollLeft;
            }
            
            if (args.scrollTop != undefined) {

                

                //CHECK VIRTUALIZATION IS ENABLED OR NOT
                if (proxy.model.enableVirtualization) {

                    proxy._scrollTop = args.scrollTop; //proxy._$gridContent.scrollTop();
                    proxy._vScrollDir = proxy._prevScrollTop <= proxy._scrollTop ? 1 : -1;
                    proxy._vScrollDist = Math.abs(proxy._scrollTop - proxy._prevScrollTop);
                    //console.log("VScrollDist:" + proxy._vScrollDist);
               
                    if (proxy._vScrollDist) {
                        proxy._updateCurrentViewData();
                        proxy._prevScrollTop = proxy._scrollTop;
                    }
                }
            }
        },

        _saveRow:function()
        {
            proxy=this;
            form = $(document.getElementById(proxy._id + "EditForm"));
            formElement = $(form).find("td");
            var index = proxy.selectedRowIndex();
            if (form.closest("tr").hasClass('e-addedrow'))
                index = form.closest("tr").index();
            proxy._currentViewData = proxy.getCurrentViewData();
            for (i = 0; i < this.model.columns.length; i++) {
                column = this.model.columns[i];
                value = proxy.getCurrentEditCellDataForRowEdit(column["field"], column["editType"],i);
                proxy._currentViewData[index][column["field"]] = proxy._currentViewData[index].item[column["field"]] = value;
            }
            var item = proxy._currentViewData[index].item;
            var isEmpty = proxy._checkIsEmptyRow(item);
            if (isEmpty)
                proxy.cancelRowEditCell();

            // Save the edited row           
            proxy.refreshRow(index);
            proxy._isRowEdit = false;            
            if (proxy.model.currentViewData.length > 0)
                ej.TreeGrid.updateAltRow(proxy, proxy._currentViewData[0], 0, 0);           
            proxy._cancelSaveTools();
            if (!isEmpty)
            proxy.selectRows(index);
           proxy.refreshContent();          
            
        },
        //CLICK HANDLER FOR PERFORM ROWSELECTION AND EXPANDCOLLAPSE THE RECORD
        _onClick: function (e) {

            var proxy = this,
                model = proxy.model,
                $target = $(e.target);
                proxy._popupHide();
            if ($target.hasClass('e-icon') && $target.hasClass('e-down-arrow')) {
                //To render back the dropdown list in gantt.
                column = proxy.model.columns,
                object = null;
                for (i = 0; i < column.length; i++) {
                    if (column[i].editType == "dropdownedit") {
                        var dropdownobject = $("#" + proxy._id + column[i].field).data("ejDropDownList");
                        if (dropdownobject)
                            object = dropdownobject.popupList;
                        if (object && object.hide()) {
                            $(object.show());
                            topposition = e.clientY + 15;
                            $(object).css({ 'top': topposition })
                        }
                    }
                }
            }            
            var dateobject = "";
            var col = proxy.model.columns;
            if ($("#" + proxy._id + "EditForm").length == 0) {
            proxy.element[0].focus();
            }
            proxy._clearContextMenu();
            for (i = 0; i < col.length; i++) {
                if (col[i]) {
                    if (col[i].filterEditType == "datepicker" || col[i].filterEditType == "datetimepicker") {
                        dateobj = $("#" + col[i].field + "_filterbarcell").data("ejDatePicker");
                        if (dateobj)
                            dateobj.hide();
                    }
                }
            }
            this.getHeaderTable().find(".e-cancel").addClass("e-hide");
         
            if ($target.hasClass('e-treegridexpand') || $target.hasClass("e-treegridcollapse")) {

                var $tr = $target.closest('tr'),
                    $gridRows = proxy.getRows(),
                    rowIndex = $gridRows.index($tr),
                    record = model.currentViewData && model.currentViewData[rowIndex],
                    recordIndex = proxy._updatedRecords.indexOf(record),
                    args = {},
                    isExpandCollapseEnabeled;

                args.data = record;
                args.recordIndex = recordIndex;
                args.expanded = $tr.hasClass("e-treegridrowexpand") ? false : true;

                if (args.expanded) {

                    isExpandCollapseEnabeled = proxy._trigger("expanding", args);

                } else {

                    isExpandCollapseEnabeled = proxy._trigger("collapsing", args);
                    
                }

                if (!isExpandCollapseEnabeled&&!model.isFromGantt) {
                    ej.TreeGrid.sendExpandCollapseRequest(proxy,args);
                  
                }
                
            } else if ($target.hasClass("e-rowcell") || $target.parent().hasClass("e-rowcell") || ($target.closest("tr").hasClass("e-templaterow"))
                || ($target.closest("td").hasClass("e-rowcell")) && $target.hasClass("e-cell")) {

                if (!model.allowSelection) return;
                
                if (model.selectionType == ej.TreeGrid.SelectionType.Multiple ) {

                    if (e.ctrlKey) proxy._multiSelectCtrlRequest = true;
                    
                    if (e.shiftKey) {

                        proxy._multiSelectShiftRequest = true;
                        if (proxy.getRows()) {
                            proxy.selectRows(proxy._previousIndex, proxy.getRows().index($target.closest('tr')));
                        }
                    }
                }
                
                if (!proxy._multiSelectShiftRequest && $("#" + proxy._id + "EditForm").length == 0) {

                    recordIndex = proxy.getRows()?proxy.getRows().index($target.closest('tr')):-1;

                    if (recordIndex != -1) {
                        
                        record = model.currentViewData[recordIndex];                      
                        var args = { rowElement: $tr, recordIndex: this.selectedRowIndex() };

                        if (!proxy._trigger('rowSelecting', args)) {

                            model.selectedItem = record;
                            this.selectedRowIndex(proxy._updatedRecords.indexOf(record));
                            proxy.selectRows(this.selectedRowIndex());
                            args = {
                                rowElement: $tr,
                                data: proxy.model.selectedItem,
                                target: "ejTreeGrid",
                                recordIndex: this.selectedRowIndex(),
                            };
                           

                                proxy._cancelSaveTools();
                   
                            proxy._trigger("rowSelected", args);
                }
                    }
                }
                
                proxy._multiSelectShiftRequest = false;
                if (proxy._isRowEdit) {
                    $target.focus();
                    if ($target.parents("form").length == 0)
                        proxy._saveRow();
            }
            }
            if (proxy._isRowEdit)
                $target.focus();
        },


        //CLICK HANDLER FOR PERFORM THE SORTING ACTION
        _onHeaderClick: function (e) {

            var proxy = this,
                model = proxy.model;
            proxy._cellMouseLeave();
            proxy._clearContextMenu();
            if ($(e.target).is(".e-ascending, .e-descending")) e.target = e.target.parentNode;

            var $target = $(e.target),
                columnName,
                columnSortDirection;

            proxy.getHeaderTable().find(".e-columnheader").find(".e-headercellactive").removeClass("e-headercellactive");

            if ($target.hasClass("e-headercelldiv")) {

                if (!model.allowSorting) return false;
                proxy._isRowEdit = false;
                columnName = $.trim($target.text());

                if ($target.find('span').hasClass("e-ascending")) {
                    columnSortDirection = ej.sortOrder.Descending;
                } else {
                    columnSortDirection = ej.sortOrder.Ascending;
                }

                if (model.allowMultiSorting && e.ctrlKey) {
                    proxy._multiSortRequest = true;
                }

                proxy.sortColumn(columnName, columnSortDirection);
                var index = proxy.selectedRowIndex();
                proxy.selectRows(index);
                if (proxy.model.isFromGantt && this.selectedRowIndex()>=0) {
                    var args = {};
                    args.data = proxy.model.selectedItem;
                    args.target = "ejTreeGrid";
                    args.recordIndex = this.selectedRowIndex();
                    proxy._trigger("rowSelected", args);
                }
            }
            if ($target.hasClass("e-checkbox"))
                return true
            else
                return false;
        },


        //HEADER MOUSE DOWN EVENT FOR COLUMN RESIZING
        _headerMouseDown: function (e) {

            var proxy = this,
                model = proxy.model;
            proxy._cellMouseLeave();

            if (model.allowColumnResize) proxy._resizer._mouseDown(e);

            if (($(e.target).hasClass("headercelldiv") && $(e.target).hasClass("headercell"))) {

                var $headercell = $(e.target).hasClass("headercelldiv") ? $(e.target).parent() : $(e.target);
                model.headerEffects && $headercell.addClass("headercellactive");

            }
        },


        //EVENT FOR COLUMN RESIZE
        _enableColumnResizeEvents: function () {

            var proxy = this;

            if (proxy.model.allowColumnResize) {
                proxy._on(proxy.element, "mousemove", proxy._mouseMove);
                proxy._on(proxy.element, "mouseup", proxy._mouseUp);
            } else {
                proxy._off(proxy.element, "mousemove", proxy._mouseMove);
                proxy._off(proxy.element, "mouseup", proxy._mouseUp);
            }
        },


        _mouseMove: function (e) {

            var proxy = this;

            if (proxy.model.allowColumnResize) {
                proxy._resizer._mouseMove(e);
                proxy._$gridHeaderContainer.scrollLeft(proxy._$gridContent.ejScroller("option", "scrollLeft"));
            }
        },


        _mouseUp: function (e) {

            var proxy = this;

            if (proxy.model.allowColumnResize) {

                if ($(e.target).hasClass('e-headercelldiv') || $(e.target).hasClass('e-reSizeColbg')) {
                    if (proxy.model.isEdit)
                        proxy.saveCell();
                    else if (proxy._isRowEdit)
                        proxy._saveRow();
                    (proxy.element).focus();
                    
                }
                proxy._resizer._mouseUp(e);
                proxy._$gridContent.ejScroller("refresh");
                proxy._updateScrollCss();
                proxy._$gridHeaderContainer.scrollLeft(proxy._$gridContent.ejScroller("option", "scrollLeft"));
                proxy._resizeFilteringElements();
            }

        },
        // resize the filtering elements after column resized.
        _resizeFilteringElements:function()
        {
            var proxy = this;
            if (proxy.model.allowFiltering) {
                var args = {};
                ej.TreeGrid.Actions.Filter = "filtering";
                args.requestType = ej.TreeGrid.Actions.Filter;
                for (i = 0; i < proxy.model.columns.length; i++) {
                    proxy.model.columns[i].width = proxy._columnsWidthCollection[i];
                    args.fieldname = proxy.model.columns[i].field;
                    this._filteringElements(args);
                }
            }
        },




        //ENABLE THE EDITING EVENTS
        _enableEditingEvents: function () {

            var proxy = this,
                model = proxy.model;

            if (model.editSettings.allowEditing) {

                if (model.editSettings.editMode.toLowerCase() == "cellediting" || model.editSettings.editMode.toLowerCase() == "rowediting") {
                    proxy._on(proxy.element, "mousedown", ".e-gridcontent", proxy._saveCellHandler);
                }

                proxy._on(this.element, "dblclick", ".e-gridcontent", proxy._editdblClickHandler);
            } else {

                if (model.editSettings.editMode.toLowerCase() == "cellediting" || model.editSettings.editMode.toLowerCase() == "rowediting") {
                    proxy._off(proxy.element, "mousedown", ".e-gridcontent", proxy._saveCellHandler);
                }

                proxy._off(this.element, "dblclick", ".e-gridcontent", proxy._editdblClickHandler);
            }
        },


        //ENABLE THE MOUSEDOWNEVENT HANDLER FOR SAVE CELL
        _saveCellHandler: function (e) {

            var $target = $(e.target),
                proxy = this;
            //SKIP THE SCROLL BAR CLICK IN TREE GRID.
            if ($target.hasClass("e-vhandle") || $target.hasClass("e-vscrollbar") || $target.hasClass("e-vup") || $target.hasClass("e-vdown") || $target.hasClass("e-vhandlespace"))
                return;
            if ($target.hasClass("e-hhandle") || $target.hasClass("e-hscrollbar") || $target.hasClass("e-hup") || $target.hasClass("e-hdown") || $target.hasClass("e-hhandlespace"))
                return;
           e.stopPropagation();
           if (proxy._isRowEdit) {
               if ($target.closest("form#" + proxy._id + "EditForm").length == 0)
                   proxy._saveRow();
           }else if ($target.closest(".e-popup").length == 0 &&
                $target.closest(".e-rowcell").find("#" + proxy._id + "EditForm").length == 0) {
                proxy.saveCell();
            }
        },
        //Mouse right click (Context Menu) handler
        _rightClick: function (e) {
            var proxy = this,
               $target = $(e.target),
               div = $target[0].parentNode,
               $ganttGridRows,
               row,
               recordIndexr,
               item, selectIndex,
               args = {};
            proxy._clearContextMenu();
            proxy.disableTooltip();
            if ($target.hasClass("e-cell") || $target.hasClass("e-treegridexpand"))
                div = $target.closest('tr');
            if ($(div).hasClass("e-treegridrows") || $(div).hasClass("e-rowcell"))
                $ganttGridRows = proxy.getRows();
            else
                $ganttGridRows = $(proxy.getRows());
            row = $target.closest('tr');
            recordIndexr = $ganttGridRows.index(row);
            proxy._currentViewData = proxy.getCurrentViewData();
            item = proxy._currentViewData[recordIndexr];
            recordIndexr = proxy._updatedRecords.indexOf(item);
            args.data = item;
            args.recordIndex = recordIndexr;
            //Context menu for edited row or empty records
            if ((proxy.dataSource() == null || proxy.dataSource().length == 0 || $target.closest("form#" + proxy._id + "EditForm").length > 0)) {
                proxy._contextMenuItems = [];
                proxy._contextMenuItems = proxy._getContextMenuItems();
                proxy._subContextMenuItems = [];
                proxy._updateContextmenuOption(recordIndexr, item);
                proxy._clearContextMenu();
                if (proxy._contextMenuItems.length > 0)
                    proxy._renderContextMenu(e, recordIndexr, item);
                //proxy.selectRows(recordIndexr);
            } else if (item) {
                e.preventDefault();
                proxy._contextMenuItems = [];
                proxy._contextMenuItems = proxy._getContextMenuItems();
                proxy._subContextMenuItems = [];
                proxy._subContextMenuItems = proxy._getsubContextMenuItems();
                proxy._updateContextmenuOption(recordIndexr, item);
                proxy._clearContextMenu();
                if (proxy._contextMenuItems.length > 0)
                    proxy._renderContextMenu(e, recordIndexr, item);
                proxy.selectRows(recordIndexr);
            }
        },
        //DOUBLE CLICK EVENT HANDLER FOR DIALOG EDITING
        _editdblClickHandler: function (e) {

            var proxy = this,
                model = proxy.model,
                $form = $("#" + proxy._id + "EditForm"),
                args = {},
                $target = $(e.target);
            if ($target.hasClass("e-vhandle") || $target.hasClass("e-vscrollbar") || $target.hasClass("e-vup") || $target.hasClass("e-vdown") || $target.hasClass("e-vhandlespace"))
                return;
            if ($target.hasClass("e-hhandle") || $target.hasClass("e-hscrollbar") || $target.hasClass("e-hup") || $target.hasClass("e-hdown") || $target.hasClass("e-hhandlespace"))
                return;
                
            if (model.editSettings.editMode === "normal") {
                args.requestType = ej.TreeGrid.Actions.BeginEdit;
                proxy._trigger("actionBegin", args);
            }

            if (proxy._cellEditingDetails.cancelSave) {

                proxy._cellEditingDetails.cancelSave = false;
                return;

            }

            if ($form.length === 0 && proxy.getRows() !== null) {

                if (model.editSettings.editMode.toLowerCase() == "cellediting") {
                proxy.element.focus();
                proxy._cellEditingDetails.columnIndex = proxy.getCellIndex(e);
                proxy._cellEditingDetails.rowIndex = proxy.getRowIndex(e);
                fieldName = proxy._cellEditingDetails.columnIndex >= 0 && model.columns[proxy._cellEditingDetails.columnIndex].field;
                if (fieldName) {
                    model.editSettings.allowEditing &&
                        model.editSettings.editMode.toLowerCase() == ej.TreeGrid.EditMode.CellEditing.toLowerCase() &&
                        proxy.cellEdit(proxy._cellEditingDetails.rowIndex, fieldName);
                }
            }
                else if (model.editSettings.editMode.toLowerCase() == "rowediting") {
                    proxy._currentViewData = proxy.getCurrentViewData();
                    if (proxy.getCellIndex(e) != -1 && proxy.getRowIndex(e)!=-1)
                    proxy._editRow(proxy.getRowIndex(e));
                }
                $form = $("#" + proxy._id + "EditForm");
                if ($form.length > 0)
                    proxy._editAddTools();
            }
            proxy._clearContextMenu();
        },

        //To hide the datepicker and dropdown list.
        _popupHide: function () {
            var proxy = this,
             column = proxy.model.columns,
             object = null;

            for (i = 0; i < column.length; i++) {
                if (column[i]) {
                    if (column[i].editType == "datepicker" || column[i].editType == "datetimepicker")
                        object = $("#" + proxy._id + column[i].field).data("ejDatePicker");
                    else if (column[i].editType == "dropdownedit") {
                        var dropdownobject = $("#" + proxy._id + column[i].field).data("ejDropDownList");
                        if (dropdownobject)
                            object = dropdownobject.popupList;
                    }
                    if (object)
                        object.hide();
                }
            }
        },
        //PERFORM SCROLLING IN TREEGRID
        _mouseWheel: function (e) {

            var proxy = this,
                delta = null,
                ori = e;            
            proxy._popupHide();
            
            e = e.originalEvent;

            try {
                e.preventDefault ? e.preventDefault() : ori.preventDefault();
            }
            catch (err) {
            }
			
			 if (proxy._$gridContent.height() > proxy._$gridContainer.height()) { 
                proxy._$gridContent.ejScroller("scrollY", 0, true);
                return;
            }

            if (e.wheelDelta) {
                delta = -e.wheelDelta / 120;
                if (window.opera) {
                    if (parseFloat(window.opera.version, 10) < 10)
                        delta = -delta;
                }
            } else if (e.detail) {
                delta = e.detail / 3;
            }
	
            if (!delta) return false;

            var scrollTop = proxy._$gridContent.ejScroller("option", "scrollTop"),

                change = scrollTop + (delta * 57);  

            var h = parseInt(proxy._updatedRecords.length * 30) - (proxy._viewPortHeight-18);

            //console.log("TreeGrid ScrollTop:" + scrollTop + "Height :" + h);
            
            if (change> h) {
                change = h;                
            }

            if (change < 0) {
                change = 0;
            }
            
                proxy._updateScrollTop(change);
           
            return true;

        },
        _getCollapsedParentItem:function(record)
        {
            var parentRecord = record.parentItem;
            if (parentRecord) {
                if (parentRecord.expanded === false) {
                    return parentRecord;
                } else {
                    return this._getCollapsedParentItem(parentRecord)
                }
            }
            else {
                return null;
            }
        },
        //KEY PRESSED EVENT FOR KEY BOARD INTERACTION IN TREEGRID CONTROL
        _keyPressed: function (action, target, e) {

                var proxy = this,
                $treegridEle = proxy.element,
                gridObject = $treegridEle.ejTreeGrid("instance"),
                model = gridObject.model;
            //CHECK THE ALLOWKEYBOARDNAVIGATION
            if (!model.allowKeyboardNavigation){
                return false;
            }

            var returnValue = false,
                $target = $(target);
            $form = $("#" + proxy._id + "EditForm");
            switch (action) {

                //save the current edited cellValue on Enter key press
                case "saveRequest":
                    if (proxy._isRowEdit)
                        proxy._saveRow();
                    else if (model.editSettings.editMode.toLowerCase() == "cellediting" && $form.length > 0) {
                        gridObject._moveCurrentCell("down");
                    }
                    if (model.filterBarMode == "onEnter" && model.allowFiltering)
                        proxy._filterBarHandler(target);
                    break;

                    //cancel the cell editing in the current cell Esc key press
                case "cancelRequest":
                    if ($form.length > 0) {
                        if (model.editSettings.editMode.toLowerCase() == "cellediting") {
                            if (proxy._isRowEdit)
                                proxy.cancelRowEditCell();
                            else
                        gridObject.cancelEditCell();
                           
                    }
                    else if (model.editSettings.editMode.toLowerCase() == "rowediting") {
                        proxy.refreshRow(proxy._editedRowIndex);
                        proxy._isRowEdit = false;
                    }
                    }
                    break;

                    //edit the cell in treegrid by F2 key press
                case "editRecord":

                    if (model.editSettings.allowEditing && model.editSettings.editMode.toLowerCase() == "cellediting") {

                        gridObject._cellEditingDetails.rowIndex = this.selectedRowIndex();
                        gridObject._cellEditingDetails.columnIndex = proxy.getCellIndex(e, target);

                        if (gridObject._cellEditingDetails.columnIndex !== -1) {
                            fieldName = gridObject.model.columns[gridObject._cellEditingDetails.columnIndex].field;
                            fieldName && gridObject.cellEdit(gridObject._cellEditingDetails.rowIndex, fieldName);
                        }

                    }

                    break;

                    //select the first row while press the Home key
                case "firstRowSelection":
                    if (proxy._isRowEdit || proxy.model.isEdit) return true;
                    if (!proxy._rowSelectingEventTrigger()) {
                        proxy.selectRows(0);
                        recordIndex = proxy._updatedRecords.indexOf(model.selectedItem);
                        rowTop = recordIndex !== -1 && recordIndex * model.rowHeight;// - (proxy.getCollapsedRecordCount() * model.rowHeight);
                        var currentHeight = proxy._$gridContainer.height();
                        if (currentHeight > proxy._viewPortHeight) {
                            args = {
                                requestType: "scroll",
                                delta: rowTop
                            }
                            proxy._scrollTop = rowTop;
                            proxy._completeAction(args);
                            proxy._$gridContent.children(".e-content").scrollTop(rowTop);
                        }
                        if (model.enableVirtualization) {
                            proxy.selectRows(0);
                            proxy.element[0].focus();
                        }
                        proxy._rowSelectedEventTrigger(0);
                    }
                    break;

                case "lastRowSelection":
                    if (proxy._isRowEdit || proxy.model.isEdit) return true;
                    if (!proxy._rowSelectedEventTrigger()) {
                        lastRowIndex = proxy._updatedRecords.length - 1;
                        var previousItem = proxy._updatedRecords[lastRowIndex],
                               parentItem,
                               rowClassName, length;
                        if (!model.enableVirtualization && previousItem.parentItem) {
                            parentItem = proxy._getCollapsedParentItem(previousItem);
                            if (parentItem) {
                                length = proxy.getChildCount(parentItem, 0);
                                proxy.selectRows(lastRowIndex - length);
                            }
                            else {
                                proxy.selectRows(lastRowIndex);
                            }
                        }
                        else {
                            proxy.selectRows(lastRowIndex);
                        }

                        recordIndex = model.selectedItem && proxy._updatedRecords.indexOf(model.selectedItem);
                        rowTop = lastRowIndex !== -1 && recordIndex * model.rowHeight;

                        if (rowTop + proxy.model.rowHeight >= proxy._viewPortHeight) {
                            scrollTop = rowTop + proxy.model.rowHeight - (proxy._viewPortHeight - proxy._scrollBarHeight) - (proxy.getCollapsedRecordCount() * model.rowHeight);
                            if (scrollTop >= 0) {
                                args = {
                                    requestType: "scroll",
                                    delta: scrollTop
                                };
                            proxy._scrollTop = scrollTop;
                            proxy._completeAction(args); //actionComplete event trigger for perform the scrolling gantt chartcontrol.
                        }
                            if (model.enableVirtualization) {
                                proxy.selectRows(recordIndex);
                                proxy.element[0].focus();
                               
                            }
                        }
                        proxy._rowSelectedEventTrigger(recordIndex);
                    }
                    break;
                    //set the edit mode to previous cell by press shift +tab key
                case "moveCellLeft":
                    //Row edit Element focusing for Shift + tab key press
                    if (proxy._isRowEdit) {
                        previousElement = $target.closest("td").prev("td");
                        if (previousElement.length)
                            proxy._focusElementsForRowEdit(previousElement);
                    } else if (model.editSettings.allowEditing && model.editSettings.editMode.toLowerCase() == "cellediting" && $form.length > 0) {
                        returnValue = proxy._moveCurrentCell("left");
                    }

                    break;

                    //set the edit mode to next cell by tab key
                case "moveCellRight":
                    if (proxy._isRowEdit) {
                        nextElement = $target.closest("td").next("td");
                        if (nextElement.length)
                            proxy._focusElementsForRowEdit(nextElement);
                    } else if (model.editSettings.allowEditing && model.editSettings.editMode.toLowerCase() == "cellediting" && $target && $form.length > 0) {
                        returnValue = proxy._moveCurrentCell("right");
                    }

                    break;

                    //select the next row by press down arrow key
                case "downArrow":
                    if (proxy._isRowEdit || proxy.model.isEdit) return false;
                    else if (!proxy._rowSelectingEventTrigger()) {
                        // debugger;
                        //get the last row index of the ganttchart control
                        var lastRowIndex = proxy._updatedRecords.length - 1;

                        if (proxy.selectedRowIndex() != lastRowIndex) {

                            if (!model.enableVirtualization && !model.selectedItem.expanded) {
                                var child = proxy.getChildCount(model.selectedItem, 0);
                                var index = proxy.selectedRowIndex() + child + 1;
                                if (lastRowIndex >= index)
                                    proxy.selectRows(proxy.selectedRowIndex() + child + 1);

                            }
                            else {
                                proxy.selectRows(proxy.selectedRowIndex() + 1);
                            }
                            model.selectedItem.isSelected = true;
                            var recordIndex = model.selectedItem && proxy._updatedRecords.indexOf(model.selectedItem),
                                rowTop = lastRowIndex !== -1 && recordIndex * model.rowHeight,
                                scrollTop,
                                containerWidth,
                                scrollerExist = proxy._$gridContent.children(".e-content").length;
                            if (scrollerExist)
                                scrollTop = proxy._$gridContent.children(".e-content").scrollTop();
                            else
                                scrollTop = proxy._$gridContent.scrollTop();

                            containerWidth = scrollTop + proxy._viewPortHeight - proxy._scrollBarHeight - model.rowHeight + (proxy.getCollapsedRecordCount() * model.rowHeight);

                            if (containerWidth < rowTop) {
                                args = {
                                    requestType: "scroll",
                                    delta: (scrollTop+model.rowHeight),
                                };
                                proxy._completeAction(args);
                                if (scrollerExist)
                                    proxy._$gridContent.children(".e-content").scrollTop((scrollTop + model.rowHeight));
                                else
                                    proxy._$gridContent.scrollTop((scrollTop + model.rowHeight));

                                if (model.enableVirtualization) {
                                    proxy.element[0].focus();
                                }
                            }
                            proxy._rowSelectedEventTrigger(proxy.selectedRowIndex()); //for diasable completeaction
                        }
                    }
                    break;
                // expand the child task by press right arrow
                case "rightArrow":
                    if (proxy._isRowEdit || proxy.model.isEdit) return true;
                    var rowIndex = proxy.selectedRowIndex(),
                    record = proxy._updatedRecords[rowIndex],
                    args = {},
                    isExpandCollapseEnabeled;
                    args.data = record;
                    args.recordIndex = rowIndex;
                    args.expanded = true;
                    if (!proxy._rowSelectingEventTrigger() && record.hasChildRecords && !record.expanded) {
                        if (proxy.selectedRowIndex() >= 0) {
                            isExpandCollapseEnabeled = proxy._trigger("expanding", args);
                            if (!isExpandCollapseEnabeled && !model.isFromGantt) {
                                ej.TreeGrid.sendExpandCollapseRequest(proxy, args);
                            }
                        }
                    }
                    break;
                //collapse the child task by press left arrow 
                case "leftArrow":
                    if (proxy._isRowEdit || proxy.model.isEdit) return true;
                    var rowIndex = proxy.selectedRowIndex(),
                    record = proxy._updatedRecords[rowIndex],
                    args = {},
                    isExpandCollapseEnabeled;
                    args.data = record;
                    args.recordIndex = rowIndex;
                    args.expanded = false;
                    if (!proxy._rowSelectingEventTrigger()&&record.hasChildRecords && record.expanded) {
                        if (proxy.selectedRowIndex()>=0) {
                                    isExpandCollapseEnabeled = proxy._trigger("collapsing", args); 
                            if (!isExpandCollapseEnabeled&&!model.isFromGantt) {
                                ej.TreeGrid.sendExpandCollapseRequest(proxy,args);
                            }
                         }
                     }
                    break;
                    //select the previous row by press down arrow key
                case "upArrow":
                    if (proxy._isRowEdit || proxy.model.isEdit) return false;
                    if (!proxy._rowSelectingEventTrigger()) {
                        if (proxy.selectedRowIndex() !== 0) {
                            var previousItem = proxy._updatedRecords[proxy.selectedRowIndex() - 1],
                                parentItem,
                                rowClassName, length;
                            if (!model.enableVirtualization && previousItem.parentItem) {
                                parentItem = proxy._getCollapsedParentItem(previousItem);
                                if (parentItem) {
                                    length = proxy.getChildCount(parentItem, 0);
                                    proxy.selectRows(proxy.selectedRowIndex() - length - 1);
                                }
                                else {
                                    proxy.selectRows(proxy.selectedRowIndex() - 1);
                                }
                            }
                            else {
                                proxy.selectRows(proxy.selectedRowIndex() - 1);
                            }

                            model.selectedItem.isSelected = true;
                            recordIndex = proxy._updatedRecords.indexOf(model.selectedItem);
                            rowTop = recordIndex !== -1 && (recordIndex * model.rowHeight) - (proxy.getCollapsedRecordCount() * model.rowHeight);
                            var scrollerExist = proxy._$gridContent.children(".e-content").length, scrollTop;
                            if (scrollerExist)
                                scrollTop = proxy._$gridContent.children(".e-content").scrollTop();
                            else
                                scrollTop = proxy._$gridContent.scrollTop();
                            if (scrollTop) {
                                if (scrollTop > rowTop) {
                                    if (rowTop >= 0) {
                                        args = {
                                            requestType: "scroll",
                                            delta: rowTop
                                        };
                                    }
                                    else
                                    {
                                        args = {
                                            requestType: "scroll",
                                            delta: 0
                                        };
                                    }
                                    if (scrollerExist)
                                        proxy._$gridContent.children(".e-content").scrollTop(args.delta);
                                    else
                                        proxy._$gridContent.scrollTop(args.delta);

                                    proxy._completeAction(args);
                                    if (model.enableVirtualization) {
                                        proxy.selectRows(proxy.selectedRowIndex());
                                        proxy.element[0].focus();
                                    }
                                }
                            }
                            proxy._rowSelectedEventTrigger(proxy.model.selectedRowIndex);
                        }
                    }
                    break;

                default:
                    returnValue = true;
            }

            return returnValue;
        },

        //Method to bind all the filter condition and splice the over writed condition.
        filterColumn: function (fieldName, filterOperator, filterValue, predicate, matchcase, actualFilterValue) {
           
            if (!this.model.allowFiltering)
                return;
            var args = {};
            ej.TreeGrid.Actions.Filter = "filtering";
            args.requestType = ej.TreeGrid.Actions.Filter;
            args.currentFilterObject = [];           
            if (!$.isArray(filterOperator))
                filterOperator = $.makeArray(filterOperator);
            if (!$.isArray(filterValue))
                filterValue = $.makeArray(filterValue);
            var firstLoop = false;
            var filterCol = this._filterCollection;
            if (ej.util.isNullOrUndefined(this._currentFilterColumn))
                this._currentFilterColumn = this.getColumnByField(fieldName);
            for (var index = 0; index < filterOperator.length; index++) {
                var filterObject = {
                    field: fieldName,
                    operator: filterOperator[index],
                    value: filterValue[index],
                    matchcase: matchcase,
                    predicate: predicate,
                    actualFilterValue: actualFilterValue
                };
                this._$colType = "string";
                if (this._filteredColumns.length == 0 && filterObject.value !== "") {
                    if (this._$colType == "date" && (filterOperator == "equal" || filterOperator == "notequal") && typeof (filterObject.value) !== "string")
                        this._setDateFilters(filterObject);
                    else
                        this._filteredColumns.push(filterObject);
                } else {
                    var proxy = this;
                    if (!firstLoop) {
                        var dataManger = ej.DataManager(this._filteredColumns);
                        var query = new ej.Query().where("field", ej.FilterOperators.equal, filterObject.field);
                        var object = dataManger.executeLocal(query);
                        for (var i = 0; i < object.length; i++) {
                            var objectIndex = $.inArray(object[i], this._filteredColumns)
                            if (objectIndex != -1)
                                this._filteredColumns.splice(objectIndex, 1);
                        }
                    }
                    if (filterObject.value !== "") {
                        if (this._$colType == "date" && (filterOperator == "equal" || filterOperator == "notequal") && typeof (filterObject.value) !== "string")
                            this._setDateFilters(filterObject);
                        else
                            this._filteredColumns.push(filterObject);
                    }
                }
                firstLoop = true;
                args.currentFilterObject.push(filterObject);
            }
            args.filterCollection = this._filteredColumns;
            args.currentFilteringColumn = fieldName;
            args.fieldName = fieldName;
            var returnValue = this.processBindings(args);
            if (returnValue) {
                this._filteredColumns.reverse().splice(0, filterOperator.length);
                this._filteredColumns.reverse();
            }
        },
        //ROWSELECTING EVENT METHOD
        _rowSelectingEventTrigger: function () {

            var proxy = this,
                model = proxy.model,
                args = {},
                selectedItem,
                $gridRows;

            if (model.currentViewData.length <= 0) {
                this.selectedRowIndex(-1);
            }
            if (this.selectedRowIndex() !== -1 && model.currentViewData.length > 0) {

                $gridRows = proxy.getRows();
                selectedItem = model.currentViewData[this.selectedRowIndex()];
                model.selectedItem = selectedItem;
                args = {
                    rowElement: $gridRows.eq(this.selectedRowIndex()),
                    data: selectedItem,
                    recordIndex: this.selectedRowIndex(),
                };

            }
            return proxy._trigger('rowSelecting', args);
        },


        //ROWSELECTED EVENT METHOD
        _rowSelectedEventTrigger: function (index) {

            var proxy = this,model=proxy.model,
                args = {},
                $gridRows = proxy.getRows();

            if (model.currentViewData.length > 0) {
                args = {
                    rowElement: $gridRows.eq(index),
                    data: proxy.model.selectedItem,
                    target: "ejTreeGrid",
                    recordIndex: index
                };
                proxy._trigger("rowSelected", args);
            }

        },


        //QUERYCELLINFO,ROWDATABOUND EVENT BINDING FOR TREEGRID
        _eventBindings: function () {

            var proxy = this,
                model = proxy.model,
                count = 0,
                gridRows = proxy._gridRows,
                length = gridRows.length;

            
            if (model.queryCellInfo != null || model.rowDataBound != null) {

                for (count; count < length; count++) {
                    proxy._rowEventTrigger(gridRows[count], model.currentViewData[count]);
                }
            }
        },

        //ROWDATABOUND EVENT TRIGGER
        _rowEventTrigger: function (row, data) {

            var proxy = this;

            proxy._trigger("rowDataBound", {
                rowElement: row,
                data: data
            });

            var tdCells = row.cells,
                $tdRowcells = $(row).find(".e-rowcell"),
                cellIndex = 0,
                length = tdCells.length,
                column=null,
                columns = proxy.model.columns;

            for (cellIndex; cellIndex < length; cellIndex++) {

                if ($(tdCells[cellIndex]).hasClass("e-rowcell")) {

                    column = columns[$tdRowcells.index(tdCells[cellIndex])];

                }

                if (column) {

                    proxy._cellEventTrigger(tdCells[cellIndex], data, column);

                }
            }
        },


        //QUERYCELLINFO EVENT TRIGGER
        _cellEventTrigger: function (cell, data, column) {

            var args = {
                cellElement: cell,
                data: data,
                column: column,

            };

            args.cellValue = args.column && data[args.column.field];
            this._trigger("queryCellInfo", args);
        },


        //ACTION COMPLETE EVENT TRIGGER
        _completeAction: function (args) {

            var proxy = this,
                model = proxy.model,
                sortcolumns = model.sortSettings.sortedColumns;

            model.isEdit = false;

            if ((ej.TreeGrid.Actions.Sorting == args.requestType && model.allowSorting)
                || (ej.TreeGrid.Actions.Refresh == args.requestType)) {

                if (model.allowSorting) {

                    if (!proxy._multiSortRequest) {
                        proxy.getHeaderTable().find(".e-columnheader").
                            find(".e-headercelldiv").find(".e-ascending,.e-descending").remove();

                        proxy.getHeaderTable().find("[aria-sort]").removeAttr("aria-sort");
                    }

                    for (var i = 0; i < sortcolumns.length; i++) {
                        proxy._addSortElementToColumn(sortcolumns[i].field, sortcolumns[i].direction);
                    }

                }

                proxy._multiSortRequest = false;
            } else if (ej.TreeGrid.Actions.BeginEdit == args.requestType || ej.TreeGrid.Actions.Add == args.requestType) {

                var $form = $("#" + proxy._id + "EditForm");

                proxy.model.isEdit = true;
                proxy.setWidthToColumns();

                if (ej.TreeGrid.Actions.Add == args.requestType) {

                    $form.find(".e-field:disabled").not(".e-identity").removeAttr("disabled").removeClass("e-disable");

                }

            }
            else if (args.requestType === "scroll")
            {
                proxy._updateCurrentViewData();

                if (!proxy.model.isFromGantt && args.delta>=0 && proxy.isVScroll() && proxy.model.enableVirtualization)
                {
                    if (!proxy._$gridContent.ejScroller("isHScroll") && args.delta>=18) {
                        args.delta -= proxy._scrollBarHeight;
                        proxy._scrollTop = args.delta;
                    }
                    proxy._$gridContent.ejScroller("scrollY", args.delta, true);
                }
            }
            proxy._trigger("actionComplete", args);
        },


        //#endregion

        //#region METHOD FOR DATA PROCESSING

        //RENDERING THE DATA
        sendDataRenderingRequest: function (args) {

            var proxy = this,
                temp;
            if (proxy.model.currentViewData.length) {

                switch (args.requestType) {

                    case ej.TreeGrid.Actions.Delete:
                    case ej.TreeGrid.Actions.Refresh:
                    case ej.TreeGrid.Actions.Save:
                    case ej.TreeGrid.Actions.Filter:
                    case ej.TreeGrid.Actions.Sorting:
                    case ej.TreeGrid.Actions.Searching:
                    case ej.TreeGrid.Actions.ExpandCollapse:
                    case ej.TreeGrid.Actions.RefreshDataSource:
                        temp = document.createElement('div');
                        proxy.getContentTable().find("colgroup").first().replaceWith(proxy._getMetaColGroup());
                        var $tbody = proxy.getContentTable().children('tbody');
                        $tbody.empty();                        
                        temp.innerHTML = ['<table>', $.render[proxy._id + "_Template"](proxy.model.currentViewData),
                            '</table>'].join("");
                        proxy.getContentTable().get(0).replaceChild(temp.firstChild.firstChild,
                            proxy.getContentTable().get(0).lastChild);
                        proxy._gridRows = proxy.getContentTable().get(0).rows;
                        proxy.setGridRows($(proxy.getContentTable().get(0).rows));
                        proxy._eventBindings();
                        break;
                }

            } else {

                proxy.getContentTable().find('tbody').empty().append(proxy._getEmptyTbody());
                proxy._gridRows = null;
                proxy.setGridRows(null);

            }
            proxy._completeAction(args);

        },


        //SORTING THE DATA BASED ON THE PARTICULAR FIELDS
        /**
      * To sorting the data based on the particular fields
      * @return jQuery
      * @example 
      * &lt;treegrid id="treegrid"&gt;treegrid&lt;/treegrid&gt; <br> 
      * &lt;script&gt;
      * // Create Tree Grid
      * var treegridObj = $("#treegrid").data("ejTreeGrid");
      * treegridObj.ejTreeGrid("sortColumn"); // To sort the data
      * &lt;/script&gt;
      * @example 
      *  &lt;treegrid id="treegrid"&gt;treegrid&lt;/treegrid&gt; <br> 
      * &lt;script&gt;
      * // refresh the content
      * $("#treegrid").ejTreeGrid("sortColumn");	
      * &lt;/script&gt;
      * @memberof ejTreeGrid
      * @instance
       */
        sortColumn: function (columnName, columnSortDirection) {

            var proxy = this,
                model = proxy.model,
                sortColumns = model.sortSettings.sortedColumns,
                args = {},
                count = 0,
                length = sortColumns.length;

            if (!model.allowSorting || $.inArray(columnName, proxy._disabledSortableColumns) != -1
                || columnName.length == 0) {
                return;
            }

            if (!proxy._multiSortRequest) {
                model.sortSettings.sortedColumns = [];
            }

            args.requestType = ej.TreeGrid.Actions.Sorting;
            args.columnName = columnName;

            proxy._cSortedColumn = proxy.getFieldNameByHeaderText(columnName);
            proxy._cSortedDirection = args.columnSortDirection = columnSortDirection === undefined ?
                ej.sortOrder.Ascending : columnSortDirection;

            for (count; count < length; count++) {
                
                if (sortColumns[count].field == proxy._cSortedColumn) {
                    sortColumns.splice(count, 1);
                    break;
                }

            }

            model.sortSettings.sortedColumns.push({
                field: proxy._cSortedColumn,
                direction: proxy._cSortedDirection
            });

            var returnValue = proxy.processBindings(args);

            if (returnValue) {

                proxy._cSortedDirection = proxy._cSortedColumn = null;

            }
        },


        //DELETE THE PARTICULAR RECORD AND MULTIPLE RECORD
        deleteRow: function ($tr) {

            var proxy = this,
                deletedRowIndex,
                deletedRow,
                args = {},
                eveArgs = {};
            length = proxy._selectedRowsIndexes.length;
            proxy._selectedRowsIndexes.sort();
            var deletedrowCount = 0;
            for (var del = 0; del < length; del++) {

                if (ej.isNullOrUndefined($tr))
                    $tr = proxy.getRowByIndex(proxy._selectedRowsIndexes[del]);
                else
                    $tr = proxy.getRowByIndex(proxy._selectedRowsIndexes[del] - deletedrowCount);

            deletedRowIndex = proxy.getRows().index($tr);
            deletedRow = proxy.model.currentViewData[deletedRowIndex];

            args.tr = $tr;
            args.data = deletedRow;
            args.requestType = ej.TreeGrid.Actions.Delete;   

            if (proxy._trigger("actionBegin", args)) {
                return true;
            }

            proxy.processBindings(args);
            deletedrowCount++;
            if (proxy.model.currentViewData.length > 0)
                ej.TreeGrid.updateAltRow(proxy, proxy.model.currentViewData[0], 0, 0);
            }
            proxy._selectedRowsIndexes = [];
            proxy._previousIndex = -1;
        },


        //SEARCH THE TASK FROM TREE GRID CONTROL
        /**
        * To search an item with search string provided at the run time
        * @return jQuery
        * @example 
        * &lt;treegrid id="treegrid"&gt;TreeGrid&lt;/treegrid&gt; <br> 
        * &lt;script&gt;
        * // Create treegrid
        * var treegridObj = $("#treegrid").data("ejTreeGrid");
        * treegridObj.ejTreeGrid("searchItem",$("#text").val()); // To search a task
        * &lt;/script&gt;
        * @example 
        *  &lt;treegrid id="treegrid"&gt;TreeGrid&lt;/treegrid&gt; <br> 
        * &lt;script&gt;
        * // To search a task
        * $("#treegrid").ejTreeGrid("searchItem",$("#text").val());	
        * &lt;/script&gt;
        * @memberof ejTreeGrid
        * @instance
         */
        search: function (searchString) {

            var proxy = this,
                args = {};

            args.requestType = ej.TreeGrid.Actions.Searching;
            args.keyValue = searchString;

            proxy._searchString = searchString;

            proxy.processBindings(args);
        },

        //SEND SAVE REQUEST
        endEdit: function () {

            var proxy = this;

            if (proxy.model.editSettings.editMode.toLowerCase() == "cellediting" && !proxy._isRowEdit)
                return proxy.saveCell();

            return true;

        },

        //#endregion

        //#region PUBLIC METHODS

        //CALCULATE THE VISIBLE RANGE OF RECORDS TO DISPLAYED IN CURRENT VIEWPORT
        getVisibleRange: function () {

            var proxy = this,
                top = proxy._scrollTop / proxy.model.rowHeight,
                coeff = top - Math.floor(top),
                topIndex, bottomIndex,
                model = proxy.model;

            //console.log("TreeGrid ScrollTop:" + proxy._scrollTop);

            proxy._offset = coeff * model.rowHeight;
            topIndex = Math.floor(top);
            bottomIndex = proxy._getRowPosition(proxy._scrollTop + proxy._viewPortHeight);
            topIndex = Math.max(0, topIndex);
            bottomIndex = Math.min(proxy.getRecordsCount(), bottomIndex);

            proxy._visibleRange = {
                top: topIndex,
                bottom: bottomIndex
            };

            return proxy._visibleRange;

        },


        //SET THE COLUMNWIDTH TO EACH COLUMN IN TREEGRID
        setWidthToColumns: function () {

            var proxy = this,
                model = proxy.model,
                $cols1 = proxy.getContentTable().children("colgroup").find("col"),
                $cols2 = proxy.getHeaderTable().children("colgroup").find("col"),
                width = proxy._gridWidth,
                colCount = model.columns.length;

            if ($cols1.length > colCount) $cols1.splice(0, ($cols1.length - colCount));
            if ($cols2.length > colCount) $cols2.splice(0, ($cols2.length - colCount));

            for (var i = 0; i < $cols2.length; i++) {

                if (!ej.isNullOrUndefined(proxy._columnsWidthCollection[i])) {

                    $cols1.eq(i).width(proxy._columnsWidthCollection[i]);
                    $cols2.eq(i).width(proxy._columnsWidthCollection[i]);

                } else {
                    var colWidth = (width / colCount).toFixed(2) + "px";
                    $cols1.eq(i).css("width", colWidth);
                    $cols2.eq(i).css("width", colWidth);
                    proxy._columnsWidthCollection[i] = (width / colCount).toFixed(2);
                }
            }
        },


        //ENTER EDIT MODE INTO THE TREEGRID CELL
        cellEdit: function (index, fieldName) {

            var proxy = this,
                $form,
                model = proxy.model;

            if (proxy.model.showGridCellTooltip) {
                proxy._cellMouseLeave();
            }

            proxy.model.isEdit && proxy.saveCell();

            $form = $("#" + proxy._id + "EditForm");

            if ($form.length > 0) return true;

            if (!proxy.model.selectedItem) return false;

            if (model.isFromGantt && ((fieldName === "status" ||
                fieldName === "startDate" ||
                fieldName === "endDate" ||
                fieldName === "duration" ||
                fieldName === "predecessor") &&
                proxy.model.selectedItem.hasChildRecords) ||
                (fieldName === "baselineStartDate" ||
                    fieldName === "baselineEndDate") || (fieldName==="taskId")) {

                return false;

            }

            if (proxy.getRows()[index]) {
                var $targetTr = $(proxy.getRows()[index]);
                columnIndex = proxy.getColumnIndexByField(fieldName),
                $targetTd = $targetTr.find(".e-rowcell").eq(columnIndex),
                column = proxy.model.columns[columnIndex],
                data = proxy.model.selectedItem,
                beginEditArgs = {},
                args = {
                    validationRules: ej.isNullOrUndefined(column.validationRules) ? {} : $.extend(true, {},
                        column.validationRules),
                    columnName: column.field,
                    value: !ej.isNullOrUndefined(data[fieldName]) ? data[fieldName] : data.item && data.item[fieldName],
                    data: data,
                    columnObject: column,
                    cell: $targetTd
                },
                isEditable = true;

            if (model.isFromGantt && args.columnName === "predecessor") {

                var predecessor = args.data.item[proxy.model.predecessorMapping];
                args.value = predecessor ? predecessor : "";

            }

            beginEditArgs.data = data;
            beginEditArgs.columnIndex = columnIndex;
            beginEditArgs.rowElement = $targetTr;
            beginEditArgs.cellElement = $targetTd;

          

                proxy._cellEventTrigger($targetTr[0].cells[proxy._cellEditingDetails.columnIndex], data, args.columnObject);

                if (proxy._trigger("beginEdit", beginEditArgs)) return false;

                if ($.inArray(fieldName, proxy._primaryKeys) != -1 ||
                    args.columnObject.allowEditing === false) {

                    $.extend(proxy._cellEditingDetails, {
                        cellValue: args.value,
                        rowIndex: index,
                        fieldName: fieldName,
                        data: args.data,
                        columnIndex: columnIndex
                    });

                    isEditable = false;
                }

                if ($targetTr.hasClass("e-insertedrow") && (!args.columnObject.isTemplateColumn)) isEditable = true;

                if (isEditable) {

                    $.extend(proxy._cellEditingDetails, {
                        rowIndex: index,
                        cellValue: args.value,
                        columnIndex: columnIndex,
                        fieldName: fieldName,
                        cellEditType: args.columnObject.editType,
                        data: data
                    });
                }

                proxy._renderCellEditObject(args, $targetTd);
                if (!$targetTr.hasClass("e-templaterow")) {
                    $targetTr.addClass("e-editedrow");
                    args.cell && args.cell.addClass("e-editedcell");
                }

                return true;
            }
        },

        //validate predecessor string

        _validatePredecessorString: function (string) {
            var proxy = this, result;
            if (string.length > 0) {
                string.split(',').forEach(function (el) {
                    values = el.split('+');
                    offsetvalue = '+';
                    if (el.indexOf('-') >= 0) {
                        values = el.split('-');
                        offsetvalue = '-';
                    }
                    match = values[0].match(/(\d+|[A-z]+)/g);
                    if (proxy.model.ids.indexOf(match[0]) != -1) {
                        if (match[1]) {
                            if (match[1].toUpperCase() == 'FS' || match[1].toUpperCase() == 'FF' || match[1].toUpperCase() == 'SF' || match[1].toUpperCase() == 'SS') {
                            }
                            else {
                                result = false;
                            }
                        }
                    } else {
                        result = false;
                    }
                });
            } else {
                return true;
            }
            if (result === undefined || result)
                return true;
            else
                return false;
        },

        //SAVE THE EDITED CELL
        saveCell: function () {

            var proxy = this,
                model = proxy.model;

            if ($("#" + proxy._id + "EditForm").length > 0) {

                if (!proxy.editFormValidate()) return true;

                if (proxy._cellEditingDetails.columnIndex >= 0) {

                    var $form = $("#" + proxy._id + "EditForm"),
                        $targetTr = $form.closest("tr"),
                        $targetTd = $form.closest("td"),
                        formattedValue, args = {},
                        column = model.columns[proxy._cellEditingDetails.columnIndex],
                        $element = $("#" + proxy._id + proxy._cellEditingDetails.fieldName),
                        cellElement;

                    args = {
                        columnName: column.field,
                        value: proxy.getCurrentEditCellData(),
                        data: proxy._cellEditingDetails.data,
                        previousValue: proxy._cellEditingDetails.cellValue,
                        columnObject: column,
                        cellElement: $targetTd,
                        rowElement: $targetTr,
                    };

                    if (proxy._cellEditingDetails.cellEditType == "datetimepicker" ||
                        proxy._cellEditingDetails.cellEditType == "dropdownedit" ||
                        proxy._cellEditingDetails.cellEditType == "datepicker") {

                        $element.data("ejWidgets") && $element[$element.data("ejWidgets")[0]]("destroy");                        

                    }

                    if (proxy._cellEditingDetails.cellEditType === "datepicker")
                        args.value = proxy.getFormatedDate(args.value);

                    if (!ej.isNullOrUndefined(column.format)) {

                        formattedValue = proxy.formatting(column.format, args.value);
                        args.cellElement.empty().html(formattedValue);

                    } else {

                        if (args.columnObject.type == "boolean") {

                            var cellData = {};
                            cellData[args.columnObject.field] = args.value;
                            args.cellElement.empty().html(
                                $($.templates.Grid_JSONTemplate.render(cellData))[0].cells[proxy._cellEditingDetails.columnIndex].innerHTML
                            );

                        } else args.cellElement.empty().html(args.value);
                    }

                    var isValueModified = ((proxy._cellEditingDetails.cellEditType == "datepicker" ||
                            proxy._cellEditingDetails.cellEditType == "datetimepicker") &&
                        args.value instanceof Date && args.previousValue instanceof Date) ?
                        (args.value.getTime() !== args.previousValue.getTime()) :
                        (args.value !== args.previousValue);

                    model.isEdit = false;

                    var fieldName = proxy._cellEditingDetails["fieldName"];

                    if (model.isFromGantt && fieldName === "predecessor") {

                        var eventArg = {},stringResult,logicResult;
                        stringResult = proxy._validatePredecessorString(args.value);
                        if (stringResult) {
                            eventArg.predecessorString = args.value.split(',');
                            eventArg.data = {};
                            eventArg.data[model.taskIdMapping] = args.data.taskId;
                            eventArg.requestType = "validatePredecessor";
                            proxy._trigger("actionComplete", eventArg);
                            logicResult = eventArg.result;
                            if (!logicResult) {
                                args.value = args.previousValue;
                            }
                        }
                        else {
                            args.value = args.previousValue;
                        }
                        args.value = args.value.toUpperCase();
                        var ganttPredecessor = [],
                        prevPredecessors = [],
                        modifiedPredecessors = [],
                        count = 0,
                        length, predecessor;
                        args.previousValue = args.data.predecessor;
                        prevPredecessors = args.previousValue;
                        if (args.value.length > 0) {
                            modifiedPredecessors = args.data._calculatePredecessor(args.value);
                        }
                        length = modifiedPredecessors.length;
                        var index = 0,
                            prevPrdecessorlength = args.previousValue && args.previousValue.length;
                        for (index = 0; index < prevPrdecessorlength; index++) {
                            predecessor = prevPredecessors[index];
                            if (predecessor.from === args.data.taskId.toString()) {
                                ganttPredecessor.push(predecessor);
                            }
                        }
                        for (count = 0; count < length; count++) {
                            ganttPredecessor.push(modifiedPredecessors[count]);
                        }
                        args.data[proxy._cellEditingDetails["fieldName"]] = ganttPredecessor;
                        args.data.item[model.predecessorMapping] = args.value;

                    } else if (isValueModified) {
                        if (model.isFromGantt) {

                            switch (fieldName) {

                                case "taskId":
                                    args.data.item[model.taskIdMapping] = args.value;
                                    break;
                                case "taskName":
                                    args.data.item[model.taskNameMapping] = args.value;
                                    break;
                                case "startDate":
                                    args.data.item[model.startDateMapping] = args.value;
                                    break;
                                case "endDate":
                                    args.data.item[model.endDateMapping] = args.value;
                                    break;
                                case "resourceInfo":
                                    args.data.item[model.resourceInfoMapping] = proxy._getResourceId( args.value);                                    
                                    break;
                                case "duration":
                                    args.data.item[model.durationMapping] = args.value;
                                    break;
                                case "status":
                                    args.data.item[model.progressMapping] = args.value;
                                    break;
                                default:
                                    args.data.item[proxy._cellEditingDetails[fieldName]] = args.value;
                                    break;
                            }

                        } else {
                            args.data.item[proxy._cellEditingDetails.fieldName] = args.value;
                        }
                        
                        args.data[proxy._cellEditingDetails.fieldName] = args.value;
                        
                    }

                    if (model.isFromGantt && (args.columnName === "startDate" ||
                        args.columnName === "endDate" ||
                        args.columnName === "duration" ||
                        args.columnName === "predecessor" ||
                        args.columnName == "status")) {

                        args.isModified = true;

                    }
                    cellElement = $($.render[proxy._id + "_Template"](args.data))[0].cells[proxy._cellEditingDetails.columnIndex];
                    args.cellElement.removeClass("e-editedcell").replaceWith(cellElement);

                    proxy._trigger("refresh");
                    if (!args.data.treeMappingName)
                        args.data.treeMappingName = [];
                    args.data.treeMappingName.push(args.columnName);
                    if (proxy._trigger("endEdit", args)) {
                        args.data[args.columnName] = args.previousValue;
                        args.data.item[args.columnObject.field] = args.previousValue;
                        proxy.selectRows(this.selectedRowIndex());
                        proxy.refreshRow(this.selectedRowIndex());
                    }
                    
                    proxy._cellEventTrigger(args.rowElement[0].cells[proxy._cellEditingDetails.columnIndex], args.data, args.columnObject);
                    $targetTr.removeClass("e-editedrow");                    
                }
            }
            proxy._cancelSaveTools();
            return false;
        },

        //VALIDATE THE MODIFIED CELLVALUE
        editFormValidate: function () {

            if ($.isFunction($.validator))
                return $("#" + this._id + "EditForm").validate({
                    onsubmit: false
                }).form();

            return true;
        },


        //GET THE CURRENT CELL DATA
        getCurrentEditCellData: function () {

            var proxy = this,
                model = proxy.model;

            if ($("#" + proxy._id + "EditForm").length) {

                var $element = $("#" + proxy._id + proxy._cellEditingDetails.fieldName),
                    cellValue;

                switch (proxy._cellEditingDetails.cellEditType) {

                    case ej.TreeGrid.EditingType.String:
                        cellValue = $element.val();
                        break;

                    case ej.TreeGrid.EditingType.Numeric:
                        cellValue = $element.ejNumericTextbox("getValue");
                        $element.ejNumericTextbox("getValue");
                        break;

                    case ej.TreeGrid.EditingType.Dropdown:
                        if (model.isFromGantt) {
                            cellValue = proxy._getSelectedItem($element.ejDropDownList("model.selectedItems"));
                        } else
                            cellValue = $element.ejDropDownList("model.value");
                        break;

                    case ej.TreeGrid.EditingType.Boolean:
                        cellValue = $element.is(':checked');
                        break;

                    case ej.TreeGrid.EditingType.DatePicker:
                        if (model.dateFormat.indexOf("hh") == -1)
                            cellValue = $element.ejDatePicker("model.value");
                        else
                            cellValue = $element.ejDateTimePicker("model.value");

                        break;

                    case ej.TreeGrid.EditingType.DateTimePicker:
                        cellValue = Globalize.format($element.ejDateTimePicker("model.value"), "MM/dd/yyyy hh:mm tt");
                        break;

                }
                if (typeof cellValue == "string" && cellValue.length &&
                    model.columns[proxy._cellEditingDetails.columnIndex].type == "number") {

                    cellValue = parseFloat(cellValue);

                }

                return cellValue;
            }

            return null;
        },
        //Get the value from edited row
        getCurrentEditCellDataForRowEdit: function (field,type,cellIndex) {

            var proxy = this,
                model = proxy.model;

            if ($("#" + proxy._id + "EditForm").length) {

                var $element = $("#" + proxy._id + field),
                    cellValue;

                switch (type) {

                    case ej.TreeGrid.EditingType.String:
                        cellValue = $element.val();
                        break;

                    case ej.TreeGrid.EditingType.Numeric:
                        cellValue = $element.ejNumericTextbox("getValue");
                        $element.ejNumericTextbox("getValue");
                        break;

                    case ej.TreeGrid.EditingType.Dropdown:
                        cellValue = $element.ejDropDownList("model.value");
                        $element.data("ejWidgets") && $element[$element.data("ejWidgets")[0]]("destroy");
                        break;

                    case ej.TreeGrid.EditingType.Boolean:
                        cellValue = $element.is(':checked');
                        break;

                    case ej.TreeGrid.EditingType.DatePicker:
                        cellValue = Globalize.format($element.ejDatePicker("model.value"), this.model.dateFormat)
                        $element.data("ejWidgets") && $element[$element.data("ejWidgets")[0]]("destroy");
                        break;

                    case ej.TreeGrid.EditingType.DateTimePicker:
                        cellValue = Globalize.format($element.ejDateTimePicker("model.value"), "MM/dd/yyyy hh:mm tt");
                        $element.data("ejWidgets") && $element[$element.data("ejWidgets")[0]]("destroy");
                        break;

                }
                if (typeof cellValue == "string" && cellValue.length &&
                    model.columns[cellIndex].type == "number") {
                    cellValue = parseFloat(cellValue);
                }

                return cellValue;
            }

            return null;
        },

        _getResourceId:function(dataSource){

            var resourceIds = [],
                count = 0, length = dataSource.length;

            for (count = 0; count < length; count++) {
                resourceIds.push(dataSource[count][this.model.resourceIdMapping]);
            }
            return resourceIds;
        },

        _getSelectedItem: function (indexArray) {

            var proxy = this,
                count = 0,
                length = indexArray.length,
                dropDownData = proxy.model.columns[proxy._cellEditingDetails.columnIndex].dropdownData,
                selectedItems = [];

            if (dropDownData) {

                for (count = 0; count < length; count++) {

                    $.each(dropDownData, function (index, resourceInfo) {
                        if (indexArray[count] === index) {
                            selectedItems.push(resourceInfo);
                        }
                    });

                }
            }

            return selectedItems;
        },

        //GET THE FORMATED DATE 
        getFormatedDate: function (date) {
            return Globalize.format(date, this.model.dateFormat);
        },


        //GET THE FORMATTED TEXT
        formatting: function (formatstring, str) {

            formatstring = formatstring.replace(/%280/g, "\"").replace(/&lt;/g, "<").replace(/&gt;/g, ">");

            var proxy = this,
                s = formatstring,
                frontHtmlidx, frontHtml, rearHtml, lastidxval;

            frontHtmlidx = formatstring.split("{0:");
            lastidxval = formatstring.split("}");
            frontHtml = frontHtmlidx[0];
            rearHtml = lastidxval[1];

            if (formatstring.indexOf("{0:") != -1) {

                var toformat = new RegExp("\\{0(:([^\\}]+))?\\}", "gm"),
                    formatVal = toformat.exec(formatstring);

                if (formatVal != null && str != null) {

                    if (frontHtml != null && rearHtml != null) str = frontHtml + Globalize.format(str, formatVal[2]) + rearHtml;
                    else str = Globalize.format(str, formatVal[2]);

                } else if (str != null) str = str;
                else str = "";

                return str;
            } else if (proxy.data != null && proxy.data.Value == null) {

                $.each(proxy.data, function (dataIndex, dataValue) {
                    s = s.replace(new RegExp('\\{' + dataIndex + '\\}', 'gm'), dataValue);
                });

                return s;

            } else return proxy.data.Value;

        },


        //GET THE COLUMNINDEX BY USIGN THE FIELD NAME
        getColumnIndexByField: function (field) {

            var proxy = this,
                columns = proxy.model.columns,
                length = columns.length,
                column = 0;

            for (column; column < length; column++) {
                if (columns[column]["field"] == field)
                    break;
            }

            return column;
        },

        //GET THE BROWSER DETAILS
        getBrowserDetails: function () {
            var b = navigator.userAgent.match(/(firefox|chrome|opera|msie|safari)\s?\/?(\d+(.\d+)*)/i);
            if (!!navigator.userAgent.match(/Trident\/7\./))
                return { browser: "msie", version: jQuery.uaMatch(navigator.userAgent).version };
            return { browser: b[1].toLowerCase(), version: b[2] };
        },


        setValidation: function () {

            var proxy = this,
                columns = proxy.model.columns,
                length = columns.length,
                count = 0;

            proxy._initValidator();

            for (count; count < length; count++) {

                if (!ej.isNullOrUndefined(columns[count]["validationRules"])) {

                    proxy.setValidationToField(columns[count].field, columns[count].validationRules);

                }
            }
        },

        //SET THE VALIDATION TO THE PARTICULAR FIELD
        setValidationToField: function (name, rules) {

            var proxy = this,
                ele = $("#" + proxy._id + name).length > 0 ? $("#" + proxy._id + name) : $("#" + name);
            ele.rules("add", rules);

            var validator = $("#" + proxy._id + "EditForm").validate({
                onsubmit: false

            });

            if (!ej.isNullOrUndefined(rules["required"])) {

                validator.settings.messages[name] = {};
                validator.settings.messages[name]["required"] = ej.TreeGrid.getColumnByField(proxy.model.columns, name).headerText + " is required";

            }
        },


        //GET THE FIELDNAME OF COLUMN BY USING THE HEADERTEXT
        getFieldNameByHeaderText: function (headerText) {

            var proxy = this;

            if (ej.isNullOrUndefined(proxy._fieldColumnNames[headerText])) return null;

            return proxy._fieldColumnNames[headerText];
        },


        //CLEAR THE SELECTION

        clearSelection: function (index) {

            var proxy = this,
                model = proxy.model;

            if (this.selectedRowIndex() != -1) {

                var $gridRows = proxy.getRows(),
                    index;

                if (!ej.isNullOrUndefined(index)) {
                    for (i = 0; i < this._selectedRowsIndexes.length; i++)
                        proxy.getRowByIndex(this._selectedRowsIndexes[i]).removeAttr("aria-selected").find(".e-selectionbackground").removeClass("e-selectionbackground").removeClass("e-active");                   
                    var record=model.flatRecords[index];
                    if (record){   // For delete all records
                        record.isSelected = false;
                    }
                    else {

                        if ($gridRows) {
                            $gridRows.removeAttr("aria-selected").find(".e-rowcell").removeClass("e-selectionbackground").removeClass("e-active");
                        }
                        var dataManager = new ej.DataManager(model.flatRecords);

                        var query = new ej.Query();
                        query.search(true, ['isSelected'], ej.FilterOperators.Equals, true);

                        var records = dataManager.executeLocal(query);
                        var length = records && records.length;

                        if (length > 0) {

                            var count = 0;

                            for (count = 0; count < length; count++) {
                                records[count].isSelected = false;
                            }

                        }

                    }
                    if (!proxy._selectedRowsIndexes.length) {
                        proxy.selectedRowIndex(-1);
                        proxy.model.selectedItem = null;//For single selection only
                    }
                }

            }
        },


        //UPDATE EXPAND COLLAPSE RECORDS
        updateExpandCollapseRecords: function (record, expand) {

            var proxy = this;

            record.expanded = expand;
            proxy._removedCount = 0;
            proxy._expandCollapseRecordCount = proxy.getChildRecordsCount(record);
            index = proxy.model.flatRecords.indexOf(record);
            if (expand) {

                proxy._tempRecordIndex = proxy.model.records.indexOf(record);

                if (record.hasChildRecords) {
                    proxy._addNestedExpandCollapseRecords(record.childRecords, record.level, record, index);
                }

            } else {

                proxy.model.flatRecords.splice(index + 1, proxy._expandCollapseRecordCount);

            }
        },

        //COUNT THE CHILDRECORDS COUNT
        getChildRecordsCount: function (record) {

            var proxy = this,
                childRecords = record.childRecords,
                count = 0,
                length = childRecords ? childRecords.length : 0;

            for (count; count < length; count++) {

                if (proxy._filteredRecords.length > 0) {

                    var recordIndex = proxy._filteredRecords.indexOf(childRecords[count]);

                    if (recordIndex != -1) {

                        ++proxy._removedCount;

                        if (childRecords[count].hasChildRecords && childRecords[count].expanded) {
                            proxy.getChildRecordsCount(childRecords[count]);
                        }

                    }
                } else {

                    ++proxy._removedCount;

                    if (childRecords[count].hasChildRecords && childRecords[count].expanded) {
                        proxy.getChildRecordsCount(childRecords[count]);
                    }

                }
            }

            return proxy._removedCount;
        },


        //GET THE EXPAND STATUS OF RECORD
        getExpandStatus: function (record) {

            var parentRecord = record.parentItem;

            if (parentRecord != null) {

                if (parentRecord.expanded === false) {
                    return false;
                } else if (parentRecord.parentItem) {

                    if (parentRecord.parentItem.expanded === false) {
                        return false;
                    } else {
                        return this.getExpandStatus(parentRecord.parentItem);
                    }

                } else return true;
            } else return true;
        },


        //RETURN THE COLUMN FIELD NAMES
        getColumnFieldNames: function () {

            var columnNames = [],
                columns = this.model.columns,
                count = 0,
                length = columns.length;

            for (count; count < length; count++) {

                if (columns[count]["field"] && (columns[count]["field"] != "resourceInfo") && (columns[count]["field"] != "predecessor")) { //&& (columns[count]["field"] != "resourceInfo")
                    columnNames.push(columns[count]["field"]);
                }
                else if (columns[count]["field"] == "resourceInfo") {
                    //columns[count]["field"] = "resourceNames";
                    columnNames.push("resourceNames");
                }
                else if (columns[count]["field"] == "predecessor")
                {
                    //columns[count]["field"] = "predecessorsName";
                    columnNames.push("predecessorsName");
                }

            }

            return columnNames;
        },


        //RENDERED  RECORDS
        renderRecords: function (args) {

            var proxy = this;

            if (!args) {

                args = {};
                args.requestType = ej.TreeGrid.Actions.Refresh;

            }

            this.sendDataRenderingRequest(args);
        },       


        //SELECT THE ROW IN TREEGRID
        selectRows: function (rowIndex, toIndex) {

            var proxy = this,
                model = proxy.model;

            var $gridRows = proxy.getRows(),
            selectedItem;
            
            if ((model.editSettings.allowEditing || model.editSettings.allowAdding) && !proxy._isRowEdit ) {
                if ($("#" + proxy._id + "EditForm").length > 0 && proxy.endEdit()) {
                    $gridRows = proxy.getRows();
                    return;
                }
            }

            if (ej.isNullOrUndefined(toIndex) || ej.isNullOrUndefined(rowIndex)) {

                rowIndex = ej.isNullOrUndefined(rowIndex) ? toIndex : rowIndex;        

                    switch (model.selectionType) {

                        case ej.TreeGrid.SelectionType.Multiple:

                            if (proxy._multiSelectCtrlRequest) {
                                var selectedRowIndex = $.inArray(rowIndex, proxy._selectedRowsIndexes);
                                selectedRowIndex != -1 && proxy.clearSelection(rowIndex) && proxy._selectedRowsIndexes.splice(selectedRowIndex, 0);

                                if (selectedRowIndex == -1) {
                                    proxy._selectedRowsIndexes.push(rowIndex);                                   
                                    proxy.getRowByIndex(rowIndex).attr("aria-selected", "true").find('.e-rowcell').addClass("e-selectionbackground e-active").attr("tabindex", "0");                                    
                                }
                                break;
                            }
                            

                        case ej.TreeGrid.SelectionType.Single:
                            proxy.clearSelection(proxy._previousIndex);
                            model.selectedItem = null;
                            if (rowIndex <= proxy._updatedRecords.length - 1) {
                                proxy._selectedRowsIndexes = [];
                                proxy._selectedRowsIndexes.push(rowIndex);
                                proxy.getRowByIndex(rowIndex).attr("aria-selected", "true").find('.e-rowcell').addClass("e-selectionbackground e-active").attr("tabindex", 0);
                                if (proxy._updatedRecords[rowIndex]) {
                                    proxy._updatedRecords[rowIndex].isSelected = true;  //Selection issue Changes
                                    model.selectedItem = proxy._updatedRecords[rowIndex];
                                }
                                
                                if (proxy._updatedRecords[proxy._previousIndex] && rowIndex != proxy._previousIndex) {
                                    proxy._updatedRecords[proxy._previousIndex].isSelected = false;
                                }

                            }
                            break;
                    }
              
            } else {

                if (model.selectionType == ej.TreeGrid.SelectionType.Multiple)
                {
                proxy.clearSelection();
                proxy._selectedRowsIndexes = [];
                var rows = rowIndex - toIndex < 0 ? $gridRows.slice(rowIndex, toIndex + 1) : $gridRows.slice(toIndex, rowIndex + 1),
                    count = 0,
                    length = rows.length;

                for (count; count < length; count++) {
                    proxy._selectedRowsIndexes.push(rows[count].rowIndex);
                    model.flatRecords[rows[count].rowIndex].isSelected = true;
                }
                    $(rows).attr("aria-selected", "true").find('.e-rowcell').addClass("e-selectionbackground e-active").attr("tabindex", "0");                                       
            }
            }
            proxy._previousIndex = proxy._selectedRowsIndexes.length ? rowIndex : undefined;

            if (this.selectedRowIndex() != rowIndex)
            this.selectedRowIndex(rowIndex);

            proxy._multiSelectCtrlRequest = false;
            return false;
        },


        //GET THE CURRENTCELLINDEX
        getCellIndex: function (e, target) {

            var $target = $(e.target);

            if (target) $target = $(target);

            if ($target.prop("tagName") == "TD") {
                return $target.index();
            } else if ($target.prop('tagName') == "DIV" && $target.hasClass('e-cell')) {

                var $td = $target.closest('td');
                return $td.index();

            } else if ($target.prop('tagName') == "DIV" && $($target.closest('td')[0]).hasClass("e-templatecell")) {

                var $td = $target.closest('td');
                return $td.index();
            }
            else if ($($target.closest('td')[0]).hasClass("e-templatecell") && $($target.closest("tr")[0]).hasClass("e-templaterow")) {

                var $td = $target.closest('td');
                return $td.index();
            }
            return -1;
        },


        //GET THE CURRENT ROW INDEX
        getRowIndex: function (e) {

            var proxy = this,
                $target = $(e.target),
                $gridRows = proxy.getRows(),
                index = $gridRows.index($target.parent());

            if (index == -1) {

                var row = $target.closest('tr');
                index = $gridRows.index(row);

            }

            return index;
        },


        //GET THE ROW ELEMENT BY INDEX
        getRowByIndex: function (from, to) {
            try {
                var proxy = this;

                var $gridRows = proxy.getRows(),
                    gridRows=proxy._gridRows,
                    $row = $();

                if (proxy.model.enableVirtualization) {
                    var recordstart = proxy._updatedRecords[from];
                    from = proxy.model.currentViewData.indexOf(recordstart);            
                }

                if (ej.isNullOrUndefined(to)) {
                    if (proxy.model.enableVirtualization) {
                        var recordend = proxy._updatedRecords[to];
                        to = proxy.model.currentViewData.indexOf(recordend);
                    }
                    return $(gridRows[from]);
                } else {                    
                    return $($gridRows.slice(from, to));
                }
            } catch (e) {
                return $();
            }
        },

        //cancel the editMode of the cell
        cancelEditCell: function (e) {

            var proxy = this,
                tr = proxy._gridRows[proxy.selectedRowIndex()],//proxy._cellEditingDetails.rowIndex
                cellData = {},
                cell;

            cellData[proxy._cellEditingDetails.fieldName] = proxy._cellEditingDetails.cellValue,
            data = proxy.model.selectedItem;

            if ($(tr).hasClass("e-insertedrow")) cell = tr.cells[proxy._cellEditingDetails.columnIndex];
            else cell = tr.cells[proxy._cellEditingDetails.columnIndex];

            $(cell).removeClass("e-editedcell").empty().html(
                $($.render[proxy._id + "_Template"](data))[0].cells[proxy._cellEditingDetails.columnIndex].innerHTML
            );

            proxy.element.focus();          
            proxy.model.isEdit = false;
            proxy._cancelSaveTools();
        },

        //Cancel row edit.
        cancelRowEditCell: function (e) {

            
            var proxy = this;
            
            //  To delete the empty added row when allowDeleting is false.
            var temp = proxy.model.editSettings.allowDeleting;
            form = $(document.getElementById(proxy._id + "EditForm"));
            if (form.closest("tr").hasClass('e-addedrow')) {
                var index = form.closest("tr").index();
                proxy._currentViewData = proxy.getCurrentViewData();
                var item = proxy._currentViewData[index].item;
                var isEmpty = proxy._checkIsEmptyRow(item);                
                if (isEmpty) {
                    if (!proxy.model.editSettings.allowDeleting)
                        proxy.model.editSettings.allowDeleting = true;
                }
            }

            var rowIndex = this.selectedRowIndex();
            if (form.closest("tr").hasClass('e-addedrow'))
                rowIndex = index;
            tr = proxy._gridRows[rowIndex];
            data = proxy.model.selectedItem;
            //Cancel the edited row.
            if ($(tr).hasClass('e-editedrow')) {
                $(tr).removeClass("e-editedrow").empty().html(
                    $($.render[proxy._id + "_Template"](data))[0].innerHTML);
                index = rowIndex;
            }
            else if ($(tr).hasClass('e-rowedit')) {
                $(tr).removeClass("e-rowedit").empty().html(
                    $($.render[proxy._id + "_Template"](data))[0].innerHTML);
                index = rowIndex;
            }               
                //Cancel the newly added row.
            else {
                var length = proxy._$gridRows.length;
                var rowPosition = proxy.model.editSettings.rowPosition;
                if (rowPosition == "bottom")
                    index = length - 1;
                    
                else if (rowPosition == "top")
                    index = 0;
                else
                    index = rowIndex;

                tr = proxy._gridRows[index];
                proxy.deleteRow($(tr));
            }
            proxy.model.isEdit = proxy._isRowEdit = false;
            if (rowPosition == "bottom" || rowPosition == "belowSelectedRow")
                index = index - 1;
            proxy.selectRows(index);
            proxy.model.editSettings.allowDeleting = temp;
            //Change the index of selected row when cancel the first empty row in empty content.
            if (proxy._$gridRows == null) 
                proxy.selectRows(-1);               
        },

        //RERENDERED THE EDITED RECORD
        refreshRow: function (index) {
            var proxy = this,
                data = proxy.model.currentViewData[index],eventArgs={};
            if (data) {
                $(proxy._gridRows[index]).replaceWith($($.render[proxy._id + "_Template"](data)));
                proxy.setGridRows($(proxy.getContentTable().get(0).rows));
                eventArgs.rowElement=proxy._gridRows[index];
                eventArgs.data=data;
                proxy._refreshedCellEventTrigger(eventArgs);
            }
        },
        //Trigger rowDataBound and queryCellInfo event when row is refreshed
        _refreshedCellEventTrigger:function(eventArgs)
        {
            var proxy = this, model = this.model;
            if (model.queryCellInfo != null || model.rowDataBound != null) {
                proxy._trigger("rowDataBound", {
                    rowElement: eventArgs.rowElement,
                    data: eventArgs.data
                });

                var tdCells = eventArgs.rowElement.cells,
                $tdRowcells = $(eventArgs.rowElement).find(".e-rowcell"),
                cellIndex = 0,
                length = tdCells.length,
                column = null,
                columns = proxy.model.columns;

                for (cellIndex; cellIndex < length; cellIndex++) {
                    if ($(tdCells[cellIndex]).hasClass("e-rowcell")) {
                        column = columns[$tdRowcells.index(tdCells[cellIndex])];
                    }
                    if (column) {
                        proxy._cellEventTrigger(tdCells[cellIndex], eventArgs.data, column);
                    }
                }
            }
        },

        //removeRecord: function (args) {
        //    var proxy = this,
        //    deletedRow = args.data, childIndex;
        //    var childRecordsCount = proxy._getFilteredChildRecordsCount(deletedRow);
        //    childRecordsCount += 1;var count=0;
        //    for (var i = 0; i < childRecordsCount; i++) {
        //        proxy.getRows().eq(args.recordIndex).remove();
        //        proxy.setGridRows($(proxy.getContentTable().get(0).rows));
        //    }
        //},

        //RENDERE THE ADDED NEW RECORD
        renderRecord: function (args) {
            var proxy = this,
                addedGridRow = $.render[this._id + "_Template"](args._cAddedRecord),
                model = proxy.model, spliceIndex, spliceIndexRecords;

            if (proxy._gridRows != null && proxy._gridRows.length > 0) {
                var insertIndex = model.currentViewData.indexOf(model.selectedItem);
                if (args.position) {
                    if (args.position == "Above") {
                        proxy.getRows().eq(insertIndex).before(addedGridRow);
                    }
                    else if (args.position == "Below") {
                        proxy.getRows().eq(insertIndex).after(addedGridRow);
                    }
                }
                else {
                    if (insertIndex === -1) {
                        args._cAddedRecord.index = 0;
                        proxy.getRows().eq(0).before(addedGridRow);
                    } else {
                        proxy.getRows().eq(insertIndex).after(addedGridRow);
                    }
                }

                proxy.setGridRows($(proxy.getContentTable().get(0).rows));

                args._cAddedRecord.hasChildRecords = false;
                args._cAddedRecord.expanded = false;

                //For update selfreference datasource
                if (model.parentIdMapping) {
                    if (args._cAddedRecord.parentItem)
                        args._cAddedRecord.item[model.parentIdMapping] = args._cAddedRecord.parentItem.taskId;
                    else
                        delete args._cAddedRecord.item[model.parentIdMapping];

                    if (this.dataSource() instanceof ej.DataManager) {
                        if (this.dataSource().dataSource.offline && this.dataSource().dataSource.json) {
                            this.dataSource().dataSource.json.push(args._cAddedRecord.item);
                        }
                    } else {
                        this.dataSource().push(args._cAddedRecord.item);
                    }
                }
                //update child record in parent item
                if (args._cAddedRecord.parentItem && model.selectedItem) {

                    if (args._cAddedRecord.parentItem.hasChildRecords && (args.position == "Below" || !args.position)) {

                        var tempIndex = model.flatRecords.indexOf(args._cAddedRecord.parentItem);
                        var childIndex = model.flatRecords[tempIndex].childRecords.indexOf(model.selectedItem);
                        if (childIndex === -1) {
                            model.flatRecords[tempIndex].childRecords.splice(0, 0, args._cAddedRecord);
                            if (!model.parentIdMapping)
                                model.flatRecords[tempIndex].item[model.childMapping].splice(0, 0, args._cAddedRecord.item);
                        }
                        else {
                            model.flatRecords[tempIndex].childRecords.splice(childIndex + 1, 0, args._cAddedRecord);
                            if (!model.parentIdMapping)
                                model.flatRecords[tempIndex].item[model.childMapping].splice(childIndex + 1, 0, args._cAddedRecord.item);
                        }
                    }
                    else if (args._cAddedRecord.parentItem.hasChildRecords && args.position == "Above") {

                        var tempIndex = model.flatRecords.indexOf(args._cAddedRecord.parentItem);
                        var childIndex = model.flatRecords[tempIndex].childRecords.indexOf(model.selectedItem);

                        if (childIndex === -1) {
                            model.flatRecords[tempIndex].childRecords.push(args._cAddedRecord);
                            if (!model.parentIdMapping)
                                model.flatRecords[tempIndex].item[model.childMapping].push(args._cAddedRecord.item);
                        }
                        else {
                            model.flatRecords[tempIndex].childRecords.splice(childIndex, 0, args._cAddedRecord);
                            if (!model.parentIdMapping)
                                model.flatRecords[tempIndex].item[model.childMapping].splice(childIndex, 0, args._cAddedRecord.item);
                        }
                    }
                }
                else if (!args._cAddedRecord.parentItem && model.selectedItem) {
                    model.parentRecords.splice(args._cAddedRecord.index, 0, args._cAddedRecord);
                    var tempDataSource;

                    if (this.dataSource() instanceof ej.DataManager) {
                        if (this.dataSource().dataSource.offline && this.dataSource().dataSource.json) {
                            tempDataSource = this.dataSource().dataSource.json;
                        }
                    }
                    else {
                        tempDataSource = this.dataSource();
                    }

                    if (tempDataSource) {
                        var idx = tempDataSource.indexOf(model.selectedItem.item);
                        if (args.position == "Above") {
                            if (!model.parentIdMapping)
                                tempDataSource.splice(idx, 0, args._cAddedRecord.item);
                        }
                        else if (args.position == "Below" || !args.position) {
                            if (!model.parentIdMapping)
                                tempDataSource.splice(idx + 1, 0, args._cAddedRecord.item);
                        }
                    }
                }
                else if (!model.selectedItem && args._cAddedRecord) {
                    if (this.dataSource() instanceof ej.DataManager) {
                        if (this.dataSource().dataSource.offline && this.dataSource().dataSource.json) {
                            if (!model.parentIdMapping)
                                this.dataSource().dataSource.json.splice(0, 0, args._cAddedRecord.item);
                        }
                    }
                    else {
                        if (!model.parentIdMapping)
                            this.dataSource().splice(0, 0, args._cAddedRecord.item);
                    }
                }

                //splice index for records and id
                if (model.selectedItem) {
                    var selectedIndex = model.records.indexOf(model.selectedItem);
                    var flatIndex = model.flatRecords.indexOf(model.selectedItem);
                    if (args.position == "Above") {
                        spliceIndexRecords = selectedIndex;
                        spliceIndex = flatIndex;
                    }
                    else {
                        spliceIndexRecords = selectedIndex + 1;
                        spliceIndex = flatIndex + 1;
                    }
                }
                else {
                    spliceIndexRecords = 0;
                    spliceIndex = 0;
                }

                if (proxy.getExpandStatus(args._cAddedRecord) && model.enableVirtualization) {
                    if (spliceIndex === model.flatRecords.length) {
                        model.flatRecords.push(args._cAddedRecord);
                    }
                    else {
                        proxy._recordIndexCount = 0;
                        model.flatRecords.splice(spliceIndex, 0, args._cAddedRecord);
                    }
                } else if (!model.enableVirtualization) {

                    if (spliceIndex === model.flatRecords.length) {
                        model.flatRecords.push(args._cAddedRecord);
                    }
                    else {
                        proxy._recordIndexCount = 0;
                        model.flatRecords.splice(spliceIndex, 0, args._cAddedRecord);
                    }
                }
                if (spliceIndexRecords === model.records.length) {
                    model.records.push(args._cAddedRecord);
                    if (model.isFromGantt)
                        model.ids.push(args._cAddedRecord.taskId.toString());
                }
                else {
                    model.records.splice(spliceIndexRecords, 0, args._cAddedRecord);
                    if (model.isFromGantt)
                        model.ids.splice(spliceIndexRecords, 0, args._cAddedRecord.taskId.toString());
                }
                proxy.setRecordsCount(model.flatRecords.length);
                proxy.setHeight(model.flatRecords.length * model.rowHeight);
                if (!(model.allowSorting && model.sortSettings.sortedColumns.length > 0)) {
                    proxy._updatedRecords = model.flatRecords;
                    proxy._updateCurrentViewData();
                }
            }
            else if (proxy._gridRows == null || proxy._gridRows.length == 0) {
                //model.ids = [];
                if (this.selectedRowIndex() === -1) {

                    args._cAddedRecord.hasChildRecords = false;
                    args.recordIndex = 0;
                }

                model.flatRecords.push(args._cAddedRecord);
                if (this.dataSource() == null) {
                    this.dataSource([]);
                }

                if (this.dataSource() instanceof ej.DataManager) {
                    if (this.dataSource().dataSource.offline && this.dataSource().dataSource.json) {
                        this.dataSource().dataSource.json.push(args._cAddedRecord.item);
                    }
                } else {
                    this.dataSource().push(args._cAddedRecord.item);
                }
                model.records.push(args._cAddedRecord);
                if (model.isFromGantt)
                    model.ids.push(args._cAddedRecord.taskId.toString());
                proxy._updatedGanttRecords = model.flatRecords;

                proxy._updatedRecords = model.flatRecords;
                proxy.setRecordsCount(model.flatRecords.length);
                proxy.setHeight(model.flatRecords.length * model.rowHeight);

                proxy._updateCurrentViewData();
                model.parentRecords.push(args._cAddedRecord);
                proxy.getContentTable().find('tbody').empty().append(proxy._getEmptyTbody());
                var temp = document.createElement('div');
                proxy.getContentTable().find("colgroup").first().replaceWith(proxy._getMetaColGroup());
                var $tbody = proxy.getContentTable().children('tbody');
                $tbody.empty();
                temp.innerHTML = ['<table>', $.render[proxy._id + "_Template"](proxy.model.currentViewData),
                    '</table>'].join("");
                proxy.getContentTable().get(0).replaceChild(temp.firstChild.firstChild,
                    proxy.getContentTable().get(0).lastChild);

                proxy._gridRows = proxy.getContentTable().get(0).rows;
                proxy.setGridRows($(proxy.getContentTable().get(0).rows));
                proxy._eventBindings();

            }

        },


        
        onScrollHelper: function (scrolltop) {
            var proxy = this;            
            proxy._$gridContent.ejScroller("scrollY", scrolltop, true);
            var isHorizontalScroll = proxy._$gridContent.ejScroller("isHScroll");
            if (!isHorizontalScroll)
                proxy._$gridContent.scrollTop(scrolltop);
        },

        isVScroll: function () {
            if (this._$gridContent.hasClass("e-scroller")) {
                return this._$gridContent.ejScroller("isVScroll");
            }
            else
            {
                return false;
            }
        },

        //REFRESH THE SCROLLER FOR TREEGRIDCONTENT
        refreshScroller:function(panSize){
            
            var proxy = this;                       
            proxy._$gridContent.removeClass("e-borderbox");
            //proxy._$gridContent.css({ 'width': panSize + "px" });
            var scrollTop = proxy._$gridContent.ejScroller("option", "scrollTop");
            var scrollLeft = proxy._$gridContent.ejScroller("option", "scrollLeft");

            proxy._$gridContent.ejScroller("option", { "persist": true });
            proxy._$gridContent.ejScroller("option", { "width": panSize });
            
            var maxScrollWidth = proxy.getMaxScrollWidth();
            if (scrollLeft > maxScrollWidth)
                scrollLeft = maxScrollWidth > 0 ? maxScrollWidth : 0;

            proxy._$gridContent.css("height", proxy._viewPortHeight);
            proxy._$gridContent.ejScroller("refresh");
            var isHorizontalScroll = proxy._$gridContent.ejScroller("isHScroll");

            if (proxy.model.isFromGantt)
                if (!isHorizontalScroll) {
                    proxy._$gridContent.addClass("e-borderbox");
                }
                else {
                    proxy._$gridContent.removeClass("e-borderbox");
                }
            proxy._$gridContent.ejScroller("option", { "scrollTop": scrollTop });
            proxy._$gridContent.ejScroller("option", { "scrollLeft": scrollLeft });
            proxy._$gridHeaderContainer.scrollLeft(scrollLeft);

            if (!isHorizontalScroll)
            proxy._$gridContent.scrollTop(scrollTop);
            //else {
            //    proxy._$gridContent.scrollTop(0)
            //}
        },
        getMaxScrollWidth:function()
        {
            var proxy=this;
            return proxy._$gridContent.children(".e-content").children(".e-gridcontainer").children(".e-table").width() - proxy._$gridContent.children(".e-content").width();
        },
        refreshHeight:function(){

            var proxy = this;
            proxy._$gridContent.ejScroller("refresh");            

        },

        //#endregion

        //#region PRIVATE METHODS

        //CALCULATE THE VIEWPORTHEIGHT
        _getViewPortHeight: function () {

            var proxy = this,
                height = 0,borderTopWidth=0;
                borderTopWidth = proxy.model.isFromGantt ? 0 : 1;
                height = proxy.element.height() -
                proxy._$gridHeaderContent.height() -
                parseFloat(borderTopWidth) -
                parseFloat(proxy._$gridHeaderContent.css("border-bottom-width"));
                if (proxy.model.toolbarSettings.showToolbar) {
                    height -= $("#" + proxy._id + "_toolbarItems").outerHeight();
                }

            if (!proxy.model.isFromGantt)
                height -= 1;//in gantt gridcontent does't contain border-width but have in treeGrid
            return height;

        },

        updateViewPortHeight: function () {
            var proxy = this;
            proxy._viewPortHeight = proxy._getViewPortHeight();
        },

        _updateScrollCss: function () {
            var proxy = this;
            if (!proxy.model.isFromGantt) {
                var isVscroll = proxy.isVScroll();
                if (isVscroll) {
                        proxy._$gridHeaderContent.addClass("e-scrollcss");
                } else {
                    proxy._$gridHeaderContent.removeClass("e-scrollcss");
                }
                proxy._resizeFilteringElements();
            }
        },



        //UPDATE CURRENT VIEWPORT DATA FROM FLATRECORDS/UPDATED RECORDS
        _updateCurrentViewData: function () {

            var proxy = this,
                model = proxy.model,
                args = {},
                tMargin,
                isRangeModified = false;

            //CHECK VIRTUALIZATION IS ENABLED OR NOT 
            if (model.enableVirtualization) {

                proxy.getVisibleRange();
                model.currentViewData = proxy._updatedRecords.slice(proxy._visibleRange.top,
                    proxy._visibleRange.bottom);



                if (proxy._vScrollDist !== 0) {

                    tMargin = proxy._scrollTop - proxy._offset;

                    //console.log("Margin :" + tMargin);

                    if ((proxy._prevRTop - proxy._visibleRange.top !== 0) ||
                        (proxy._prevRBottom - proxy._visibleRange.bottom !== 0)) {

                        args.requestType = ej.TreeGrid.Actions.Refresh;
                        proxy.sendDataRenderingRequest(args);
                        isRangeModified = true;

                    }

                        proxy._$tableContent.css({
                            "top": tMargin
                        });

                    proxy._prevRTop = proxy._visibleRange.top;
                    proxy._prevRBottom = proxy._visibleRange.bottom;

                }

            } else {

                model.currentViewData = proxy._updatedRecords;

            }

            if (proxy._isEnterKeyPressed) {

                proxy._isEnterKeyPressed = false;
                if (model.allowSelection && model.editSettings.allowEditing) {

                    if (!isRangeModified) proxy._cellEditingDetails.rowIndex += 1;

                    if (!proxy._rowSelectingEventTrigger()) {

                        proxy.selectRows(proxy._cellEditingDetails.rowIndex);
                        proxy._rowSelectedEventTrigger(proxy._cellEditingDetails.rowIndex);

                    }

                    proxy.cellEdit(proxy._cellEditingDetails.rowIndex, proxy.model.columns[proxy._cellEditingDetails.columnIndex].field);

                }
            }
        },


        //GET THE TABLE ROW POSITION
        _getRowPosition: function (y) {
            return Math.ceil((y) / this.model.rowHeight);
        },


        //GET THE COLUMNGROUP FOR HEADER TABLE
        _getMetaColGroup: function () {

            var $colgroup = this.getHeaderTable().find('colgroup').clone();
            return $colgroup;

        },


        //CREATE EMPTY ROW WHILE DATASOURCE OBJECT AS NULL
        _getEmptyTbody: function () {

            var proxy = this,
                $emptyTd = ej.buildTag('td', proxy.model.emptyRecordText, {}, { colSpan: proxy.model.columns.length });
            return $(document.createElement("tr")).append($emptyTd);

        },


        //ADD SORTICON TO THE COLUMN HEADER
        _addSortElementToColumn: function (field, direction) {

            var proxy = this,
                column = ej.TreeGrid.getColumnByField(proxy.model.columns, field),
                index = $.inArray(column, proxy.model.columns),
                $headerCellDiv = proxy.getHeaderTable().find("thead").
                find(".e-headercell").eq(index).find(".e-headercelldiv");
            $headerCellDiv.find(".e-ascending,.e-descending").remove();
            $headerCellDiv.append(proxy._createSortElement().addClass("e-" + direction).addClass("e-icon"));
            $headerCellDiv.parent().attr("aria-sort", direction);
        },


        //CREATE SORT ELEMENT        
        _createSortElement: function () {
            return ej.buildTag('span', "&nbsp;");
        },


        //RENDERED EDITED CELL
        _renderCellEditObject: function (cellEditArgs, $td) {

            var proxy = this,
                $form = ej.buildTag("form.#" + proxy._id + "EditForm", "", {}, {}),
                $cellEditTemplate = proxy._cellEditTemplate,
                $element,
                htmlString,
                cellData = {};

            cellData[cellEditArgs.columnObject.field] = cellEditArgs.value,
            columnIndex = proxy.getColumnIndexByField(cellEditArgs.columnObject.field);

            if (columnIndex===proxy.model.treeColumnIndex) {
                $td.find('.e-cell').empty();
            } else $td.empty();

            htmlString = $cellEditTemplate.find("#" + cellEditArgs.columnObject.field + "_CellEdit").html();
            if (cellEditArgs.columnObject.field === "predecessor")
                $element = $($.templates(htmlString).render(cellEditArgs.data));
            else
                 $element = $($.templates(htmlString).render(cellData));

            if ($element.get(0).tagName == "SELECT") {

                $element.val(cellData[cellEditArgs.columnObject.field]);
                $element.val() == null && $element.val($element.find("option").first().val());

            }

            $form.append($element);

           if (columnIndex===proxy.model.treeColumnIndex) {
                $td.find('.e-cell').append($form);
            } else $td.append($form);

            proxy._setoffsetWidth();
            proxy._refreshEditForm();

            if ($.isFunction($.validator) && !$.isEmptyObject(cellEditArgs.validationRules)) {

                proxy._initValidator();
                proxy.setValidationToField(cellEditArgs.columnObject.field, cellEditArgs.validationRules);

            }
            proxy.model.isEdit = true;

        },


        //SET WIDTH FOR EDITING ELEMENTS
        _setoffsetWidth: function () {

            var proxy = this,
                tds, $form = $("#" + proxy._id + "EditForm"),
                i = 0,
                length, child;

            if (proxy.model.editSettings.editMode.toLowerCase() == "cellediting" && !proxy._isRowEdit) {
                tds = $form.closest("td");
            } else {
                tds = $form.find("tr").find(".e-rowcell");
            }

            length = tds.length;

            for (i; i < length; i++) {

                child = $(tds.children()[0]).children();

                if (child.length > 1) {
                    proxy._tdsOffsetWidth[i] = tds.get(i).offsetWidth - child[0].offsetWidth - child[1].offsetWidth;
                } else {
                    proxy._tdsOffsetWidth[i] = tds.get(i).offsetWidth;
                }
            }

        },


        //get Index of resourceInfo
        getIndexofresourceInfo: function (dataSource) {

            var proxy = this,
                data = proxy._cellEditingDetails.data,
                resourceInfo = data.resourceInfo,
                count = 0,
                length = resourceInfo && resourceInfo.length,
                resourceIndex = [];

            for (count; count < length; count++)
                resourceIndex.push(dataSource.indexOf(resourceInfo[count]));

            return resourceIndex;

        },

        //REFRESH THE EDITED FORM
        _refreshEditForm: function () {

            var proxy = this,
                form = document.getElementById(proxy._id + "EditForm"),
                elementFocused = false,
                $formElement = $(form).find("input,select"),
                percent = 86,
                i = 0,
                length = $formElement.length,
                $element, inputWidth,
                model = proxy.model,
                width,
                params = {},
                value,
                column,
                customParams,
                toformat,
                formatVal,
                rowHeight = proxy.model.rowHeight;

            for (i; i < length; i++) {

                $element = $formElement.eq(i);

                if (model.editSettings.editMode.toLowerCase() == "cellediting")
                    percent = 95;
                if (proxy._isRowEdit && $element.attr("type") != "checkbox")
                    inputWidth = "100%";
               else
                inputWidth = proxy._tdsOffsetWidth[i] * (percent / 100);
                if ($element.hasClass("e-numerictextbox")) {

                    width = inputWidth;
                    value = $element.val();
                    params.width = width;
                    params.height = rowHeight - 5;
                    params.showSpinButton = true;
                    params.cssClass = model.cssClass;
                  
                    if (value.length) params.value = parseFloat(value);

                    customParams = ej.TreeGrid.getColumnByField(model.columns, $element.prop("name"));

                    if (model.isFromGantt && (customParams.field === "duration" || customParams.field === "status"))
                    {
                        params.minValue = 0;
                        if (customParams.field == "status")
                            params.maxValue = 100;
                    }

                    if (!ej.isNullOrUndefined(customParams["editParams"])) $.extend(params, customParams["editParams"]);

                    $element.ejNumericTextbox(params);
                    $element.prop("name", $element.prop("name").replace(proxy._id, ""));

                } else if ($element.hasClass("e-datepicker")) {

                    //inputWidth = proxy._tdsOffsetWidth[i] * (90 / 100);
                    width = inputWidth;
                    params.width = width;
                    params.height = rowHeight - 5;
                    params.locale = model.locale;
                    params.cssClass = model.cssClass;
                    params.displayDefaultDate = true;
                    params.dateFormat = model.dateFormat;

                    if ($element.val().length) params.value = new Date($element.val());

                    column = ej.TreeGrid.getColumnByField(model.columns, $element.prop("name"));

                    if (column["format"] !== undefined && column.format.length > 0) {

                        toformat = new RegExp("\\{0(:([^\\}]+))?\\}", "gm");
                        formatVal = toformat.exec(column.format);
                        params.dateFormat = formatVal[2];
                    }

                    if (!ej.isNullOrUndefined(column["editParams"])) $.extend(params, column["editParams"]);

                    if (model.dateFormat.indexOf("hh") == -1)
                        $element.ejDatePicker(params);
                    else {
                        $element.ejDateTimePicker(params);
                    }
                } else if ($element.hasClass("e-datetimepicker")) {

                    width = inputWidth;
                    params = {
                        width: width,
                        height: rowHeight - 5,
                        locale:model.locale,
                        cssClass: model.cssClass,
                        showButton: false
                    };

                    if ($element.val().length) params.value = new Date($element.val());

                    column = ej.TreeGrid.getColumnByField(model.columns, $element.prop("name"));

                    if (column["format"] !== undefined && column.format.length > 0) {

                        toformat = new RegExp("\\{0(:([^\\}]+))?\\}", "gm");
                        formatVal = toformat.exec(column.format);
                        params.dateTimeFormat = formatVal[2];

                    }

                    if (!ej.isNullOrUndefined(column["editParams"])) $.extend(params, column["editParams"]);
                    if (proxy.model.isFromGantt)
                        {
                    if (model.dateFormat.indexOf("hh") == -1)
                        $element.ejDatePicker(params);
                    else
                        $element.ejDateTimePicker(params);
                    }
                    else
                        $element.ejDateTimePicker(params);

                } else if ($element.hasClass("e-dropdownlist")) {
                    if (proxy._isRowEdit)
                        {
                        var dataSource = model.columns[i].dropdownData;
                        var fieldName = model.columns[i].field;
                    }
                    else{
                    var dataSource = model.columns[proxy._cellEditingDetails.columnIndex].dropdownData;
                        var fieldName = model.columns[proxy._cellEditingDetails.columnIndex].field;
                    }

                    if(model.isFromGantt){
                        $element.ejDropDownList({
                            width: inputWidth + "px",
                            height: rowHeight - 5,
                            showCheckbox: true,
                            dataSource: dataSource,
                            popupWidth:"auto",
                            fields: {
                                id: model.resourceIdMapping,
                                text: model.resourceNameMapping,
                                value: model.resourceNameMapping
                            },
                            selectedItems: proxy.getIndexofresourceInfo(dataSource)
                        });
                        
                    } else {
                        $element.css({ 'position': 'absolute', 'margin-top': '-13px' });
                        $element.ejDropDownList({
                            width: inputWidth,
                            height: rowHeight - 5,                            
                            dataSource: dataSource,
                        });                        
                    }
                    $element.ejDropDownList("setSelectedValue", $element.val());
                    $("#" + proxy._id + fieldName + "_list").hide();

                } else {

                    switch ($element.prop('tagName')) {
                        case "INPUT":

                            if ($element.attr("type") != "checkbox") {

                                $element.css("text-align", $element.attr("name") != null &&
                                    ej.TreeGrid.getColumnByField(model.columns, $element.attr("name")) != null ?
                                    ej.TreeGrid.getColumnByField(model.columns, $element.attr("name")).textAlign :
                                    "center");

                                $element.outerWidth(inputWidth).height(model.rowHeight-9);

                            } else $element.width(inputWidth > 0 ? ($element.width() > inputWidth ? inputWidth : $element.width()) : 1);

                            break;

                        case "SELECT":
                            $element.width(inputWidth).height(20);
                            break;
                    }
                }

                if (!$element.is(":disabled") && !elementFocused &&
                    (!$element.is(":hidden") || typeof $element.data("ejDropDownList") == "object")) {

                    if (!proxy._isEnterKeyPressed) {

                        proxy._focusElements($element.closest('td'));
                        elementFocused = true;

                    }
                }
            }
        },


        //INITIALIZE THE VALIDATOR
        _initValidator: function() {

            var proxy = this;

            $("#" + proxy._id + "EditForm").validate({
                onclick: false,
                onfocusout: false,
                errorClass: 'e-field-validation-error',
                errorElement: 'div',
                wrapper: "div",

                errorPlacement: function(error, element) {
                    var $td = element.closest("td"),
                        $container = $(error).addClass("e-error"),
                        $tail = ej.buildTag("div.e-errortail e-toparrow");

                    $td.find(".e-error").remove();
                    element.hasClass("e-numerictextbox") ? $container.insertAfter(element.closest(".e-numeric")) :
                                                          $container.insertAfter(element);
                    $container.prepend($tail);
                    proxy.model.editSettings.editMode != "normal" && $container.offset({
                        left: element.offset().left
                    });

                    $container.fadeIn("slow");
                }
            });
        },


        //SET FOCUS TO EDITED ELEMENT
        _focusElements: function ($currentCell) {
            var proxy = this;

            if ($currentCell.length) {

                $currentCell.focus();
                var $childElem = $currentCell.children();

                if ($childElem[0]) {

                    if ($childElem[0].tagName.toLowerCase() == "select" || 
                        $childElem[0].tagName.toLowerCase() == "input") {

                        $childElem.focus().select();
                        $childElem[0].focus();

                    } else if ($childElem.find(".e-field.e-dropdownlist").length) {

                        $childElem.find(".e-ddl").focus();

                    } else if ($childElem.find(".e-datewidget.e-widget").length) {

                        $childElem.find(".e-datewidget.e-widget").focus();
                    }
                    else {

                        $childElem.find('input,select').select().focus();
                    }
                }
            }
			   proxy._$gridHeaderContainer.scrollLeft(proxy._$gridContent.children('.e-content').scrollLeft());
        },
        //Set the focus for edit row elements
        _focusElementsForRowEdit: function ($currentCell) {
            if ($currentCell.length) {
                var $childElem = $currentCell.children();
                if ($childElem[0].tagName.toLowerCase() == "select" || $childElem[0].tagName.toLowerCase() == "input") {
                    $childElem.focus().select();
                    $childElem[0].focus();
                }
                else if ($childElem.find(".e-field.e-dropdownlist").length)
                    $childElem[0].focus();
                else
                    $childElem.find('input:visible,select').first().select().focus();
            }
        },
        //UPDATE THE GRID CONTAINER HEIGHT
        updateHeight: function (height) {

            var proxy = this;
            if (proxy._$gridContainer && proxy._$gridContent) {
                if (height) {
                    proxy._$gridContainer.css({
                        "height": height + "px",
                        "width": "auto"
                    });
                    proxy._$gridContent.ejScroller("refresh");
                } else {
                    proxy._$gridContainer.css({
                        "height": proxy._totalHeight + "px"
                    });
                }                
                if (proxy._$gridContent.hasClass("e-scroller")) {
                    proxy._$gridContent.ejScroller("refresh");
                    proxy._updateScrollCss();
                }
            }
        },
        //check scroller position in virtualization
        _setScrollTop: function () {

            var proxy = this,
            model = this.model,
            top = proxy._scrollTop;

            if (model.enableVirtualization && top !== 0 && !model.isFromGantt) {
                if ((proxy.model.currentViewData.length * proxy.model.rowHeight) < proxy._viewPortHeight) {
                    var currentPosition = top - (proxy._viewPortHeight - proxy.model.currentViewData.length * proxy.model.rowHeight);
                    if (currentPosition < 0)
                        currentPosition = 0;
                    proxy._$gridContent.ejScroller("scrollY", currentPosition, true);
                }
            }
        },

        //ADD EXPANDED CHILDRECORDS TO FLAT RECORDS
        _addNestedExpandCollapseRecords: function (data, level, parentItem, index) {

            var proxy = this,
                model = proxy.model,
                records = model.flatRecords,
                rows = model.records,
                count = 0,
                length = data.length,
                parentRecord;


            for (count; count < length; count++) {
                
                index++;
                proxy._tempRecordIndex++;
                parentRecord = rows[proxy._tempRecordIndex];

                if ($.inArray(parentRecord, records) === -1) {
                    records.splice(index, 0, parentRecord);
                }

                if (parentRecord && parentRecord.isExpanded === false) {
                    parentRecord.isExpanded = true;
                }

                if (parentRecord.hasChildRecords) {

                    if (parentRecord.expanded) {

                        var len = parentRecord.childRecords.length,
                            k = 0,
                            childRecord;

                        for (k; k < len; k++) {

                            index++;
                            proxy._tempRecordIndex++;
                            childRecord = rows[proxy._tempRecordIndex];
                            records.splice(index, 0, childRecord);

                            if (childRecord.hasChildRecords) {

                                if (childRecord.expanded) {
                                    index = proxy._addNestedExpandCollapseRecords(childRecord.childRecords, level + 1, childRecord, index);
                                } else proxy._tempRecordIndex += proxy.getChildCount(childRecord, 0);//childRecord.childRecords.length;

                            }
                        }
                    } else {

                        proxy._tempRecordIndex += proxy.getChildCount(parentRecord,0);  //parentRecord.childRecords.length;// here inner task are not counted
                    }
                }
            }
            return index;
        },

        getChildCount:function(record,count)
        {
            var currentRecord, proxy = this;
            if (!record.hasChildRecords)
                return 0;
            for (var i = 0; i < record.childRecords.length;i++)
            {
                currentRecord= record.childRecords[i];
                count++;
                if(currentRecord.hasChildRecords)
                {
                    count=proxy.getChildCount(currentRecord, count);
                }
            }
            return count;
        },
        //UPDATE THE FILTERED RECORDS FOR ADDING PARENTRECORDS
        _updateFilteredRecords: function (data) {

            var proxy = this,
                count = 0,
                length = data.length,
                record,virtualization=proxy.model.enableVirtualization;

            proxy._filteredRecords = [];
            proxy._filteredGanttRecords = [];

            for (count; count < length; count++) {

                record = data[count];

                if (record.parentItem != null) {

                    proxy._addParentRecord(record.parentItem);

                    if ($.inArray(record, proxy._filteredRecords) === -1) {
                        if (virtualization)
                        {
                            if (proxy.getExpandStatus(record))
                            {
                                proxy._filteredRecords.push(record);
                            }
                        }
                        else
                        {
                            proxy._filteredRecords.push(record);
                        }
                           
                    }

                } else {

                    if ($.inArray(record, proxy._filteredRecords) === -1) {
                        if (virtualization) {
                            if (proxy.getExpandStatus(record)) {
                                proxy._filteredRecords.push(record);
                            }
                        }
                        else {
                            proxy._filteredRecords.push(record);
                        }
                    }
                }
            }
        },

                
        //ADD PARENTRECORD FOR FILTERED OTH LEVEL ITEMS
        _addParentRecord: function (record) {

            var proxy = this,
            virtualization = proxy.model.enableVirtualization;

            if (record.parentItem) {
                proxy._addParentRecord(record.parentItem);

                if ($.inArray(record, proxy._filteredRecords) === -1) {

                    if (virtualization) {
                        if (proxy.getExpandStatus(record)) {
                            proxy._filteredRecords.push(record);
                        }
                    }
                    else {
                        proxy._filteredRecords.push(record);
                    }
                     

                }
            } else {

                if ($.inArray(record, proxy._filteredRecords) === -1) {

                    if (virtualization) {
                        if (proxy.getExpandStatus(record)) {
                            proxy._filteredRecords.push(record);
                        }
                    }
                    else {
                        proxy._filteredRecords.push(record);
                    }

                }
            }
        },


        //UPDATEEXPANDCOLLAPSE FOR SORTED RECORDS
        _updateExpandCollapseForSortedRecords: function (Record, expanded) {

            var proxy = this,
                count = 0,
                length = proxy._sortedRecords.length,
                record,
                index = proxy._sortedRecords.indexOf(Record);

            if (expanded) {

                proxy._addNestedSortRecords(Record, index);

            } else {

                var removedCount = 0;

                for (count = index + 1; count < length; count++) {

                    record = proxy._sortedRecords[count];

                    if (record.level === Record.level) {
                        break;
                    } else if (!proxy.getExpandStatus(record)) {
                        removedCount++;
                    }

                }

                proxy._sortedRecords.splice(index + 1, removedCount);

            }
        },


        //ADD NESTEDSORTRECORDS
        _addNestedSortRecords: function (record, index) {

            var proxy = this,
                childRecords,
                sortColumns = proxy.model.sortSettings.sortedColumns,
                length;

            if (sortColumns.length) {

                length = sortColumns.length - 1;
                proxy._queryManagar.queries = [];

                for (var i = length; i >= 0; i--) {

                    proxy._queryManagar.sortBy(sortColumns[i].field, sortColumns[i].direction);

                }

            }
            if (record.hasChildRecords) {

                var dataManager = ej.DataManager(record.childRecords),
                    count,
                    childrecord;

                childRecords = dataManager.executeLocal(proxy._queryManagar).result;
                length = childRecords.length;

                for (count = 0; count < length; count++) {

                    childrecord = childRecords[count];

                    if (proxy._filteredRecords.length) {

                        if ($.inArray(childrecord, proxy._filteredRecords) !== -1) {
                            proxy._sortedRecords.splice(++index, 0, childrecord);
                        }

                    } else {
                        proxy._sortedRecords.splice(++index, 0, childrecord);
                    }

                    if (childrecord.hasChildRecords && childrecord.expanded) {
                        proxy._addNestedSortRecords(childrecord, index);
                    }
                }
            }
        },

        //UPDATE Edit Settings
        updateEditSettings: function (edit) {

            var proxy = this;

            if (edit) {
                if (edit.editMode)
                    proxy.model.editSettings.editMode = edit.editMode;
                if (edit.allowAdding)
                    proxy.model.editSettings.allowAdding = edit.allowAdding;
                if (edit.allowEditing)
                    proxy.model.editSettings.allowEditing = edit.allowEditing;
                if (edit.allowDeleting)
                    proxy.model.editSettings.allowDeleting = edit.allowDeleting;
            }
        },

        //UPDATE ALTROW
        _updateAltRow: function () {

            var proxy = this,
                count = 0,
                currentViewData = proxy._updatedRecords,
                length = currentViewData.length,
                record;

            for (count = 0; count < length; count++) {
                record = currentViewData[count];
                record.isAltRow = count % 2 == 0 ? true : false;
            }

        },


        
        //COUNT THE NUMBER OF CHILD RECORDS PRESENT IN THE GANTTRECORD
        _getFilteredChildRecordsCount: function (Record) {

            var proxy = this,
                model=proxy.model,
                length = Record&&Record.childRecords && Record.childRecords.length,
                i = 0,
                record;

            for (i = 0; i < length; i++) {

                record = Record.childRecords[i];
                if (model.enableVirtualization)
                {
                    if(proxy.getExpandStatus(record))
                    {
                        proxy._removedCount++;
                    }
                }
                else
                {
                    proxy._removedCount++;
                }
                   
                if (record.childRecords) {
                    proxy._getFilteredChildRecordsCount(record);
                }
            }

            return proxy._removedCount;
        },


        //SORTING THE RECORDS
        _sortingRecords: function () {

            var proxy = this,
                model = proxy.model,
                sortcolumns = model.sortSettings.sortedColumns;

            proxy._queryManagar.queries = [];

            if (sortcolumns.length) {

                var length = sortcolumns.length - 1;

                for (var i = length; i >= 0; i--) {

                    var column;
                    if(model.isFromGantt)
                        column = ej.TreeGrid.getColumnByMappingName(model.columns, sortcolumns[i].field);
                    if (column) {
                        proxy._queryManagar.sortBy(column.field, sortcolumns[i].direction);
                        sortcolumns[i].field = column.field;
                    }
                    else
                        proxy._queryManagar.sortBy(sortcolumns[i].field, sortcolumns[i].direction);
                }

            }

            var dataManager = new ej.DataManager(model.parentRecords),
                records = dataManager.executeLocal(proxy._queryManagar).result;

            proxy._sortedRecords = [];
            proxy._storedIndex = -1;

            proxy._createSortedRecords(records);
            proxy._tempsortedrecords = proxy._sortedRecords;
           // proxy._updateSortedRecords(proxy._tempsortedrecords);
            proxy.setRecordsCount(proxy._sortedRecords.length);
            if (proxy.model.selectedRowIndex >= 0) {
                var previousIndex = proxy._selectedRowsIndexes.indexOf(proxy.model.selectedRowIndex);
                var selectedRecord = proxy._updatedRecords[proxy.model.selectedRowIndex];
                proxy._previousIndex = proxy.model.selectedRowIndex = proxy._sortedRecords.indexOf(selectedRecord);
                proxy._selectedRowsIndexes[previousIndex] = proxy._previousIndex;
            }
            proxy._updatedRecords = proxy._sortedRecords;

            return true;
        },


        //CREATE SORTED GANTT RECORDS
        _createSortedRecords: function (data) {

            var proxy = this,
                sortedRecords = proxy._sortedRecords,
                dataManager,
                enableAltRow = proxy.model.enableAltRow,model=this.model;

            $.each(data, function (index, record) {

                if (proxy._searchString.length > 0) {

                    if (proxy._filteredRecords.length > 0 && proxy._filteredRecords.indexOf(record) !== -1) {

                        proxy._storedIndex++;

                        if (enableAltRow) {

                            record.isAltRow = proxy._storedIndex % 2 == 0 ? false : true;

                        }

                        sortedRecords[proxy._storedIndex] = record;

                    }
                } else {

                    proxy._storedIndex++;

                    if (enableAltRow) {

                        record.isAltRow = proxy._storedIndex % 2 == 0 ? false : true;

                    }

                    sortedRecords[proxy._storedIndex] = record;

                }

                if (record.hasChildRecords && record.expanded) {

                    dataManager = ej.DataManager(record.childRecords);
                    var childRecords = dataManager.executeLocal(proxy._queryManagar).result;
                    proxy._createSortedRecords(childRecords);

                }
                else if (record.hasChildRecords && !record.expanded && !model.enableVirtualization)
                {
                    proxy._setChildRecords(record, sortedRecords);
                }
            });
        },

        _setChildRecords:function(record,sortedRecords)
        {
            var proxy = this,
            enableAltRow = proxy.model.enableAltRow;
            var length = record.childRecords.length;

            dataManager = ej.DataManager(record.childRecords);
            var childRecords = dataManager.executeLocal(proxy._queryManagar).result;
            for(var count=0;count<length;count++)
            {
                if (proxy._filteredRecords.length > 0) {
                    if (proxy._filteredRecords.length > 0 && proxy._filteredRecords.indexOf(childRecords[count]) !== -1) {
                        proxy._storedIndex++;
                        if (enableAltRow) {
                            childRecords[count].isAltRow = proxy._storedIndex % 2 == 0 ? false : true;
                        }
                        sortedRecords[proxy._storedIndex] = childRecords[count];
                        if (childRecords[count].hasChildRecords) {
                            this._setChildRecords(childRecords[count], sortedRecords);
                        }
                    }
                }else
                {
                    proxy._storedIndex++;
                    if (enableAltRow) {
                        childRecords[count].isAltRow = proxy._storedIndex % 2 == 0 ? false : true;
                    }
                    sortedRecords[proxy._storedIndex] = childRecords[count];
                    if (childRecords[count].hasChildRecords) {
                        this._setChildRecords(childRecords[count], sortedRecords);
                    }
                }
            }
        },    
        //UPDAT THE SORTED RECORDS
        _updateSortedRecords: function (data) {

            var proxy = this,
                count = 0,
                length = data.length,
                record,model=this.model;

            for (count; count < length; count++) {

                record = data[count];

                if (!model.enableVirtualization) {

                    if (proxy._filteredRecords.length > 0) {

                        if ($.inArray(record, proxy._filteredRecords) !== -1 && $.inArray(record, proxy._sortedRecords) === -1) {
                            proxy._sortedRecords.push(record);
                        }

                    } else {

                        if ($.inArray(record, proxy._sortedRecords) === -1) {
                            proxy._sortedRecords.push(record);
                        }

                    }

                    if (record.hasChildRecords && record.childRecords.length > 0) {

                        var dataManager = ej.DataManager(record.childRecords),
                            sortedChildRecords = dataManager.executeLocal(proxy._queryManagar).result;
                        proxy._updateSortedRecords(sortedChildRecords);

                    }
                }
            }
        },


        //REMOVE SORT ICON FORM COLUMN HEADER
        _removeSortElementFromColumn: function (field) {

            var proxy = this,
                column = ej.TreeGrid.getColumnByField(proxy.model.columns, field),
                index = $.inArray(column, proxy.model.columns),
                $headerCellDiv = proxy.getHeaderTable().find("thead").find(".e-headercell").eq(index).find(".e-headercelldiv");

            $headerCellDiv.find(".ascending,.descending").remove();
            $headerCellDiv.parent().removeAttr("aria-sort");
        },


        //ADD EMPTYCOLUMN TO THE TREEGRID
        _addEmptyColumntoGrid: function () {

            $('.e-gridheadercontainer table colgroup').append(ej.buildTag('col', "", {
                "width": "auto"
            },
            {}));

            $('.e-gridheadercontainer table thead tr').append(ej.buildTag('th.e-headercell'));
        },


        //UPDATE THE SCROLLTOP OF THE GRIDCONTAINER
        _updateScrollTop: function (y) {

            var args = {},
                proxy = this;

            args.requestType = "scroll";
            args.delta = y;

            var isHorizontalScroll = proxy._$gridContent.ejScroller("isHScroll");

            if (!isHorizontalScroll) {
                proxy._$gridContent.scrollTop(y);//grid container
            }
            else
            {
                proxy._$gridContent.scrollTop(0)
            }
            proxy._$gridContent.ejScroller("scrollY", y, true);
            proxy._completeAction(args);
            
        },


        //MOVE CURRENT CELL FOR KEYBOARD INTERACTION
        _moveCurrentCell: function (direction) {

            var proxy = this,
                rowIndex = proxy._cellEditingDetails.rowIndex,
                columnIndex = proxy._cellEditingDetails.columnIndex,
                model = proxy.model;

            if (rowIndex == -1 && columnIndex == -1) return false;

            if (proxy.model.isEdit) {

                proxy.saveCell();
                proxy.model.isEdit = false;

            }

            switch (direction) {
                

                case "right":
                    if (!proxy._rowSelectingEventTrigger()) {

                        if (!proxy.selectRows(proxy._cellEditingDetails.rowIndex)) {

                            if (rowIndex == proxy._gridRows.length - 1 && columnIndex == model.columns.length - 1) {
                                return true;
                            }

                            if (columnIndex == model.columns.length - 1) {

                                proxy._cellEditingDetails.columnIndex = 0;
                                proxy._cellEditingDetails.rowIndex = rowIndex + 1;

                            } else proxy._cellEditingDetails.columnIndex = columnIndex + 1;

                            proxy.selectRows(proxy._cellEditingDetails.rowIndex);
                            proxy.cellEdit(proxy._cellEditingDetails.rowIndex,
                                model.columns[proxy._cellEditingDetails.columnIndex].field);
                        }
                    }

                    break;

                case "left":

                    if ((rowIndex == 0 && columnIndex == 0)) return true;

                    if (columnIndex == 0) {

                        proxy._cellEditingDetails.columnIndex = model.columns.length - 1;
                        proxy._cellEditingDetails.rowIndex = rowIndex - 1;

                    } else {
                        proxy._cellEditingDetails.columnIndex = columnIndex - 1;
                    }

                    proxy.selectRows(proxy._cellEditingDetails.rowIndex);
                    proxy.cellEdit(proxy._cellEditingDetails.rowIndex, model.columns[proxy._cellEditingDetails.columnIndex].field);

                    break;

                case "up":

                    if (rowIndex == 0) return true;

                    proxy._cellEditingDetails.rowIndex = rowIndex - 1;
                    proxy.selectRows(proxy._cellEditingDetails.rowIndex);
                    proxy._rowSelectedEventTrigger(proxy._cellEditingDetails.rowIndex);
                    proxy.cellEdit(proxy._cellEditingDetails.rowIndex, model.columns[proxy._cellEditingDetails.columnIndex].field);

                    break;

                case "down":

                    if (rowIndex + 1 == proxy.getRows().length - 1) {

                        if (proxy.model.enableVirtualization) {

                            proxy._isEnterKeyPressed = true;
                            proxy._updateScrollTop(proxy._$gridContent.scrollTop() + model.rowHeight - proxy._offset);
                        }
                    }

                    if (!proxy._isEnterKeyPressed) {

                        if (proxy._updatedRecords.length > (rowIndex + 1))
                        if (!proxy.selectRows(rowIndex + 1)) {

                            proxy._rowSelectedEventTrigger(proxy._cellEditingDetails.rowIndex+1);
                            proxy._cellEditingDetails.rowIndex = rowIndex + 1;
                            proxy.cellEdit(proxy._cellEditingDetails.rowIndex, model.columns[proxy._cellEditingDetails.columnIndex].field);
                            args = {};
                            args.requestType = "scroll";
                            args.delta = proxy._$gridContent.children('.e-content').scrollTop();
                            proxy._trigger("actionComplete", args);
                            //$(".e-ganttviewerbodyContianer").children('.e-content').scrollTop((proxy._$gridContent.children('.e-content').scrollTop()));
                        }

                    }

                    break;
            }

            return false;

        },

        //FIND THE COLUMNWIDTH OF THE TREEGRID COLUMN
        _findColumnsWidth: function (extra) {

            var proxy = this,
                length = proxy.model.columns.length,
                j = proxy.getHeaderTable().find("colgroup").find("col");
            
            for (var i = 0; i < length; i++)
                proxy._columnsWidthCollection[i] = j.eq(i).width();

        },

        //CALCULATE THE TOTAL WIDTH OF THE COLUMNS
        _calculateWidth: function () {

            var j = this.getHeaderTable().find("colgroup").find("col"),
                width = 0;

            for (var i = 0; i < j.length; i++)
                width += j.eq(i).width();

            return width;
        },


        //TEMPLATE FOR DROP DOWNLIST
        _compiledDropDownTemplate: function () {

            var $select = ej.buildTag('select'),
                $option = ej.buildTag("option", "{{:text}}", {},
                {
                    value: "{{:value}}"
               });

            $select.append($option);

            return $.templates($select.html());
        },
        //update element height when viewport height is <0
        _updateElementHeight:function()
        {
            var proxy = this;
            proxy.element.height(450);
            proxy._calculateDimensions();
            proxy.updateViewPortHeight();
        },
        _renderScroller: function () {

            var proxy = this,
            model = proxy.model;
            var containerHeight = model.flatRecords.length * model.rowHeight;
            if (!model.isFromGantt && proxy._viewPortHeight < 0) {
                proxy._updateElementHeight();
            }
            var contentHeight = proxy._viewPortHeight;
            proxy._$gridContent.css({ "height": contentHeight + "px" });
            proxy._$gridContainer.css({ "height": containerHeight + "px" });
            
            if (!proxy._$gridContent.hasClass("e-scroller")) {
                $div = ej.buildTag('div', {}, { "width": "auto", "height": "auto" });
                $div.append(proxy._$gridContainer);
                proxy._$gridContent.append($div);
                var height = proxy._gridHeight ? contentHeight : "auto";
                var width = proxy.element.width();

                proxy._$gridContent.ejScroller({
                    height:proxy.model.isFromGantt ? 0 :height,
                    width: proxy.model.isFromGantt ? width : width - proxy._totalBorderWidth,
                    scroll: $.proxy(proxy._onScroll, proxy)
                });
                proxy._$gridContent.ejScroller("refresh");

            }
            else {
                proxy._$gridContent.ejScroller("refresh");
          }
            proxy._$gridContent.ejScroller("model.keyConfigs", { up: "", down: "" });
            proxy._updateScrollCss();
            var isHorizontalScroll = proxy._$gridContent.ejScroller("isHScroll");
            if (proxy.model.isFromGantt)
                if (!isHorizontalScroll) {
                    proxy._$gridContent.addClass("e-borderbox");
                }
                else {
                    proxy._$gridContent.removeClass("e-borderbox");
                }

        },
        

        
        //ALL EVENTS BOUND USING THIS._ON WILL BE UNBIND AUTOMATICALLY
        _destroy: function () {

            var proxy = this;
            proxy.element.empty().removeClass("e-treegrid-core e-treegrid " + proxy.model.cssClass);
            
        },

        /**
          * To collapse all the parent items in tree grid
          * @return jQuery
          * @example 
          * &lt;treegrid id="treegrid"&gt;Treegrid&lt;/treegrid&gt; <br> 
          * &lt;script&gt;
          * // Create treegrid
          * var treegridObj = $("#treegrid").data("ejTreeGrid");
          * treegridObj.ejTreeGrid("collapseAll"); // To collapse all parent items in tree grid
          * &lt;/script&gt;
          * @example 
          *  &lt;treegrid id="treegrid"&gt;Treegrid&lt;/treegrid&gt; <br> 
          * &lt;script&gt;
          * // To expand all items
          * $("#treegrid").ejTreeGrid("collapseAll");	
          * &lt;/script&gt;
          * @memberof ejTreeGrid
          * @instance
           */

        collapseAll: function () {
            var proxy = this,
                model = proxy.model,
                count = 0,
                ganttRecord,
                args = {},
                enableVirtualization = model.enableVirtualization,
                $gridRows = proxy.getRows(),
                $rowElement = null;

            proxy._gridRows = $gridRows;
            //To cancel the cell edit or row edit mode when collapse the all record.
            if (proxy._isRowEdit || proxy.model.isEdit) {                
                proxy.cancelRowEditCell();
                proxy.selectRows(-1);
                proxy._cancelSaveTools();                              
            }
            
            //loop excecute for iterate the GanttRecords preseent in the Gantt Control

            for (count = 0; count < proxy.model.parentRecords.length; count++) {
                ganttRecord = proxy.model.parentRecords[count];
                args.data = ganttRecord;
                args.recordIndex = count;
                args.expanded = false;

                if (enableVirtualization) {
                    if (ganttRecord.hasChildRecords && ganttRecord.expanded) {
                        ej.TreeGrid.sendExpandCollapseRequest(proxy, args);
                    }
                } else {
                    if (ganttRecord.hasChildRecords && ganttRecord.expanded) {
                        ej.TreeGrid.sendExpandCollapseRequest(proxy, args);
                    }
                }
            }
        },
        //populate the context menu with items
        _getContextMenuItems: function () {
            var contextMenuItems = [];

            contextMenuItems = [ {
                headerText: "Add Row",
                eventHandler: null,
                isDefault: true,
                disable:false,
            },
             {
                 iconClass: "e-edit",
                 headerText: "Edit",
                 eventHandler: null,
                 isDefault: true,
                 isEdit: true,
                 disable: false,
             },
            {
                headerText: "Delete",
                eventHandler: null,
                isDefault: true,
                disable: false,
            },
            {
                iconClass: "e-save",
                headerText: "Save",
                eventHandler: null,
                isDefault: true,
                isEdit: true,
                disable: false,
            },
             {
                 iconClass: "e-cancel",
                 headerText: "Cancel",
                 eventHandler: null,
                 isDefault: true,
                 isEdit: true,
                 disable: false,
             },
            ];
            return contextMenuItems;
        },

        //populate sub context menu items
        _getsubContextMenuItems: function () {
            var contextMenuItems = [];

            contextMenuItems = [{
                iconPath: null,
                headerText: "Above",
                eventHandler: null
            }, {
                iconPath: null,
                headerText: "Below",
                eventHandler: null
            }
            ];
            return contextMenuItems;
        },
        _clearContextMenu: function () {
            //remove context menu items
            $('.e-contextmenu').remove();
            $('.e-innerContextmenu').remove();
        },
        // create and append a context menu and also bind the events for context menu option
        _renderContextMenu: function (e, index, item) {

            var proxy = this,
            model = proxy.model,
                eventArgs = {},
                args = {},
                posx,
				subposx,
                posy,
                subposx,
                contextMenu,
                contextMenuUList,
                subContextMenu,
                subContextMenuUList;
            if (!e) e = window.event;
            if (e.pageX || e.pageY) {
               subposx = posx = e.pageX;
                posy = e.pageY;
            } else if (e.clientX || e.clientY) {
                subposx = posx = e.clientX + document.body.scrollLeft
                    + document.documentElement.scrollLeft;
                posy = e.clientY + document.body.scrollTop
                    + document.documentElement.scrollTop;
            }
            if ($(window).width() < posx + 130) {
                posx = posx - 130;
                subposx = posx - 102;
            }
            else
                subposx = subposx + 132;
            if ($(window).height() < posy + (25*proxy._contextMenuItems.length))
                posy = posy - (25 * proxy._contextMenuItems.length);
            args.targetElement = e;
            args.item = item;
            args.index = index;
            args.requestType = "ContextMenuOpen";
            args.contextMenuItems = proxy._contextMenuItems;
            args.innerContextMenuItems = proxy._subContextMenuItems;
            proxy._trigger("contextMenuOpen", args);
            contextMenu = ej.buildTag("div.e-contextmenu", "", {
                'height': 'auto',
                'width': '130px',
                'position': 'absolute',
                'left': posx + 'px',
                'top': posy + 'px',
                'background-color': '#F0F0F0',
                'border': '1px solid #99bce8',
                'z-index': '10033',
            }, {});

            contextMenuUList = ej.buildTag("ul", $.render[proxy._id + "contextMenuTemplate"](args.contextMenuItems), {
                'height': 'auto',
                'width': 'auto',
                'top': '0px',
                'display': 'inline'
            }, {
                'data-icon': false,
                'type': 'none',
                'data-role': 'list-divider'
            });
            //var addIndex = proxy._contextMenuItems.indexOf("add");
            subContextMenu = ej.buildTag("div.e-innerContextmenu", "", {
                'height': 'auto',
                'width': '100px',
                'position': 'absolute',
                'left': subposx + 'px',
                'top': posy + (proxy._contextAddMenuIndex * 30) + 'px',
                'background-color': '#F0F0F0',
                'border': '1px solid #99bce8',
                'z-index': '10',
                'visibility': 'hidden',
            }, {});

            subContextMenuUList = ej.buildTag("ul", $.render[proxy._id + "subContextMenuTemplate"](args.innerContextMenuItems), {
                'height': 'auto',
                'width': 'auto',
                'top': '0px',
                'display': 'inline'
            }, {
                'data-icon': false,
                'type': 'none',
                'data-role': 'list-divider'
            });
            contextMenu.append(contextMenuUList);
            $(document.body).append(contextMenu);

            if (args.innerContextMenuItems.length > 0) {
                subContextMenu.append(subContextMenuUList);
                $(document.body).append(subContextMenu);
            }



            $(contextMenu).css({ 'height': 'auto' });
            proxy._on(contextMenu, "contextmenu", function (argsE) {
                argsE.preventDefault();
            });
            //click event handlers for contextmenu items and subcontextmenu items
            $('.e-menuitem').click(function () {
                var choice = $(this).attr('id');
                if(!$(this).hasClass("e-disable")){
                switch (choice) {
                    case "Delete": eventArgs.requestType = "contextMenuDelete";
                        proxy.deleteRow();
                        proxy._clearContextMenu();
                        break;
                    case "Above":
                        proxy._subContextMenuAction(item, index, "Above");
                        $(proxy.element).focus();
                        break;
                    case "Below":
                        proxy._subContextMenuAction(item, index, "Below");
                        $(proxy.element).focus();
                        break;
                    case "Add":
                        proxy._setInitialData();
                        proxy._clearContextMenu();
                        
                        break;
                    case "Edit":
                        if (model.editSettings.editMode.toLowerCase() == "cellediting") {

                            proxy.element.focus();
                            proxy._cellEditingDetails.columnIndex = proxy.getCellIndex(e);
                            proxy._editedRowIndex=proxy._cellEditingDetails.rowIndex = proxy.getRowIndex(e);
                            fieldName = proxy._cellEditingDetails.columnIndex >= 0 && model.columns[proxy._cellEditingDetails.columnIndex].field;
                            if (fieldName) {
                                model.editSettings.allowEditing &&
                                    model.editSettings.editMode == ej.TreeGrid.EditMode.CellEditing &&
                                    proxy.cellEdit(proxy._cellEditingDetails.rowIndex, fieldName);
                                    proxy._editAddTools();
                            }
                        }
                        else if (model.editSettings.editMode.toLowerCase() == "rowediting") 
                            proxy._editRow(index);
                        proxy._clearContextMenu();
                        break;
                    case "Save":
                        if (model.editSettings.editMode.toLowerCase() == "cellediting") {
                             if (proxy._isRowEdit)
                                   proxy._endEdit();
                                   else proxy.saveCell();
                            }
                        else if (model.editSettings.editMode.toLowerCase() == "rowediting")
                            proxy._saveRow();
                        proxy._cancelSaveTools();
                        proxy._clearContextMenu();
                        $(proxy.element).focus();
                        break;
                    case "Cancel":
                        proxy.cancelRowEditCell();
                        proxy._cancelSaveTools();
                        proxy._clearContextMenu();
                        $(proxy.element).focus();
                        break;
                    default:
                        $.each(proxy._contextMenuItems, function (idx, val) {
                            if (val.headerText === choice) {
                                proxy.model["customEvent"] = val.eventHandler;
                                proxy._trigger("customEvent", args);
                            }
                        });
                        proxy._clearContextMenu();
                        break;
                }
                if (proxy.model.enableAltRow && proxy._currentViewData[0])
                    ej.TreeGrid.updateAltRow(proxy, proxy._currentViewData[0], 0, 0);
                proxy.updateHeight();
                    
                }
            });
            //Mouseenter and mouse leave handler for contextmenu items and Subcontextmenuitems
            $(".e-menuitem").mouseenter(function () {
                if (!$(this).hasClass("e-disable")) {
                    $(".e-contextmenu-mouseover").removeClass("e-contextmenu-mouseover");
                $(this).addClass("e-contextmenu-mouseover");
                if ($(this).attr('id') == "Add" || $(this).attr('id') == "Above" || $(this).attr('id') == "Below") {
                    $('.e-innerContextmenu').css({ 'visibility': 'visible' });
                    $('#Add').addClass("e-contextmenu-mouseover");
                }
                else {
                    $('.e-innerContextmenu').css({ 'visibility': 'hidden' });
                }
                }
            });
            $(".e-menuitem").mouseleave(function () {
                $(this).removeClass("e-contextmenu-mouseover");
            });
            e.preventDefault();
        },
        _createContextMenuTemplate: function () {
            var proxy = this;
            helpers = {
                getHeaderName: $.proxy(proxy._getHeaderName, proxy),
            };
            $.views.helpers(helpers);
            var menuItemList = "<li style='list-style-type:none;width:92px;height:25px;display:inline-block;'>";
            var listChild = "<div class='e-menuitem {{if disable}}e-disable{{/if}}' id={{:headerText}}  style='left:0px;padding-top:3px;height:25px;width:130px;cursor:{{if disable}}default{{else}}pointer{{/if}};display:block;position:absolute;'  {{if !isDefault}}onClick='{{:eventHandler}}'{{/if}}>" +
                            "{{if !isEdit}}" +
                            "<div class='e-icon' style='left:10px;top:4px;height:20px;position:absolute;" +
                            "background-image:{{:iconPath}};background-repeat:no-repeat;'/> " + 
                            "{{else}}" +
                            "<span class='e-icon {{:iconClass}}' style='left:10px;top:7px;height:20px;position:absolute;opacity:0.5'/>" +
                            "{{/if}}" +
                            "<div style='left:35px;position:absolute;'>" +
                            "<span style='font-family:Segoe UI;font-size:12px;padding-left:5px;'>{{:headerText}}</span></div>" +
                            "{{if ~getHeaderName(#data)}}<span class='e-icon e-expander' style='height:16px;width:16px;right:5px;top:7px;position:absolute;'></span>{{/if}}";

            menuItemList += listChild;
            menuItemList += "</div></li>";
            var templates = {};
            templates[proxy._id + "contextMenuTemplate"] = menuItemList;
            $.templates(templates);
        },
        _createSubContextMenuTemplate: function () {
            var proxy = this,
                helpers = {
                    getHeaderName: proxy._getHeaderName
                };
            $.views.helpers(helpers);

            var menuItemList = "<li style='list-style-type:none;width:100px;height:25px;display:inline-block;'>";
            var listChild = "<div class='e-menuitem' id={{:headerText}} style='left:0px;padding-top:3px;" +
                "height:25px;width:100px;cursor: pointer;display:block;position:absolute;'>" +
                "<div style='left:10px;height:20px;width:16px;position:absolute;padding-top:5px;" +
                "background-image:{{:iconPath}};background-repeat:no-repeat;'/>" +
               "<div style='left:10px;position:absolute;'>" +
                "<span style='font-family:Segoe UI;font-size:12px;padding-left:5px;'>{{:headerText}}" +
                "</span></div></div>";


            menuItemList += listChild;
            menuItemList += "</li>";

            var templates = {};
            templates[proxy._id + "subContextMenuTemplate"] = menuItemList;
            $.templates(templates);
        },
        _getHeaderName: function (data) {
            if (data.headerText == "Add Row" && this._subContextMenuItems.length > 0) {
                return true;
            }
            return false;
        },
        //Change the context menu based on context menu item list.
        _updateContextmenuOption: function (recordIndex) {
            //removing empty string and undefined from contextmenu items.
            Array.prototype.clean = function (deleteValue) {
                for (var i = 0; i < this.length; i++) {
                    if (this[i] == deleteValue) {
                        this.splice(i, 1);
                        i--;
                    }
                }
                return this;
            };
            var proxy = this;
            
            if(proxy._isRowEdit || proxy.model.isEdit)
            {
                //Remove add, delete and edit context menu when row in edit mode.
                proxy._contextMenuItems.splice(0, 3);
            }
            else
            {
                proxy._contextMenuItems.splice(3, 2); //Remove save and cancel when row not in edit mode
                var editSetting = proxy.model.editSettings
                var contextMenuItems = $.extend(true, [], proxy._contextMenuItems);
                var contextMenuList = proxy.model.contextMenuSettings.contextMenuItems.clean("").clean(undefined);
                var contextMenuItemList = [];
                //removing duplicate conetxt menu items
                $.each(contextMenuList, function (i, el) {
                    if ($.inArray(el.toLowerCase(), contextMenuItemList) === -1) contextMenuItemList.push(el.toLowerCase());
                });
                proxy._contextMenuItems = [];
                if (recordIndex == -1) {
                    if (contextMenuItemList.indexOf("add") != -1 || contextMenuItemList.length==0)
                        proxy._contextMenuItems[0] = contextMenuItems[0];
                    if (!editSetting.allowAdding)
                        proxy._contextMenuItems[0].disable = true;
                    proxy._contextAddMenuIndex = 0;
                }
                //Adding default context menu when user not specify the context menu items.
                else if (contextMenuItemList.length == 0)
                {
                    proxy._contextMenuItems[0] = contextMenuItems[0];
                    if (!editSetting.allowAdding)
                        proxy._contextMenuItems[0].disable = true;
                    proxy._contextAddMenuIndex = 0;
                    proxy._contextMenuItems[1] = contextMenuItems[2];
                    if (!editSetting.allowDeleting)
                        proxy._contextMenuItems[1].disable = true;
                }
                //Change the context menu order based on context menu items order
                else {
                for(i=0;i<contextMenuItemList.length;i++)
                {
                    var item=contextMenuItemList[i];
                    switch(item.toLowerCase())
                    {
                        case "add":
                            proxy._contextMenuItems[i] = contextMenuItems[0];
                            proxy._contextAddMenuIndex = i;
                            if (!editSetting.allowAdding)
                                proxy._contextMenuItems[i].disable = true;
                            break;
                        case "delete":
                            proxy._contextMenuItems[i] = contextMenuItems[2];
                            if (!editSetting.allowDeleting)
                                proxy._contextMenuItems[i].disable = true;
                            break;
                        case "edit":
                            proxy._contextMenuItems[i] = contextMenuItems[1];
                            if (!editSetting.allowEditing)
                                proxy._contextMenuItems[i].disable = true;
                            break;
                    }
                }
                }
            }
        },
        //Assign default value to columns based on column edit type
        _setInitialData:function()
        {
            var eventArgs = {}, proxy = this,
               model = proxy.model, data = [], item, initialData = {};
            for (i = 0; i < model.columns.length; i++)
            {
                var column = model.columns[i];
                switch(column.editType)
                {
                    case "booleanedit":
                        initialData[column.field] = false;
                        break;
                    case "stringedit":
                        initialData[column.field] = null;
                        break;
                    case "datepicker":
                        initialData[column.field] = Globalize.format(new Date(), this.model.dateFormat);
                        break;
                    case "datetimepicker":
                        today = new Date();
                        initialData[column.field] = Globalize.format(new Date(), "MM/dd/yyyy hh:mm tt");
                        break;
                    case "numericedit":
                        initialData[column.field] = 0;
                        break;
                    default:
                        initialData[column.field] = null;

            }
            }
            data.push(initialData);
            if (proxy.dataSource() == null || proxy.dataSource().length == 0) {
                //proxy._createGanttRecords(data);
                item = proxy._createRecord(data[0], 0, null);
                item.index = 0;
                eventArgs._cAddedRecord = jQuery.extend(true, {}, item);
                eventArgs.data = eventArgs._cAddedRecord.item;
                eventArgs.requestType = "save";
                eventArgs.actionRequestType = "contextMenuAdd";
                proxy.renderRecord(eventArgs);
                proxy._clearContextMenu();
            }
        },
        _subContextMenuAction:function(item,index,position)
        {
            proxy = this;
            eventArgs = {};
            eventArgs.requestType = "save";
            newItem = jQuery.extend(true, {}, item.item);
            newItem[proxy.model.childMapping] = null;
            eventArgs._cAddedRecord = jQuery.extend({}, item);
            eventArgs._cAddedRecord.isSelected = false;
            if (eventArgs._cAddedRecord.hasChildRecords && position == "Below") {
                eventArgs._cAddedRecord.parentItem = item;
                eventArgs._cAddedRecord.level += 1;
            }
            eventArgs._cAddedRecord.hasChildRecords = false;
            eventArgs._cAddedRecord.expanded = false;
            eventArgs._cAddedRecord.childRecords = null;
            eventArgs._cAddedRecord.item = newItem;
            eventArgs.recordIndex = index == 0 ? 0 : index;
            eventArgs.position = position;
            eventArgs.data = eventArgs._cAddedRecord.item;
            eventArgs.actionRequestType = "contextMenuAdd";
            eventArgs.selectedItem = proxy.model.selectedItem;
            proxy.renderRecord(eventArgs);
            proxy._clearContextMenu();
            selectionIndex = proxy._currentViewData.indexOf(proxy.model.selectedItem);
            proxy.selectRows(selectionIndex);
            if(proxy.model.enableAltRow)
                ej.TreeGrid.updateAltRow(proxy, proxy._currentViewData[0], 0, 0);
            proxy.refreshRow(proxy._currentViewData.indexOf(eventArgs._cAddedRecord));
        },
        //Create editable row with specific edit type.
        _editRow: function (index, addrow) {
            proxy = this;
            proxy._editedRowIndex = index;
            var rowHeight=proxy.model.rowHeight;
            $form = ej.buildTag("form.#" + proxy._id + "EditForm", "", {"margin":"-1px"}, {})
            $table = ej.buildTag('table.e-table', "", {}, { "cellspacing": "0px","cellpadding":"0"});
            $table.append(proxy.getHeaderTable().find('colgroup').clone());
            var $targetTr = $(proxy.getRows()[index])
            $targetTr.empty();
            if (addrow)
                $targetTr.addClass('e-addedrow');
            else
                $targetTr.addClass('e-rowedit');
            $mainTd = ej.buildTag("td", "", {}, { "colspan": proxy.model.columns.length });
            var $headerTable = proxy.getHeaderTable();
            var $tr = ej.buildTag('tr.e-treegridrows e-selectionbackground e-active', { "height": rowHeight }, {}), $trClone;
            $tbody = ej.buildTag('tbody');
            $cellEditTemplate = proxy._cellEditTemplate
            for (var column = 0; column < proxy.model.columns.length; column++) {
                var data = {};
                //Create a html string for column field with specific edit type using cellEditTemplate
                htmlString = $cellEditTemplate.find("#" + proxy.model.columns[column].field + "_CellEdit").html();
                data[proxy.model.columns[column]["field"]] = proxy._updatedRecords[index][proxy.model.columns[column]["field"]];
                $element = $($.templates(htmlString).render(data));
                var $td = ej.buildTag('td.e-rowcell', "", { "height": rowHeight, "vertical-align": "middle;", "overflow": "hidden" }, {});
                if ($element.get(0).tagName == "SELECT") {

                    $element.val(data[proxy.model.columns[column]["field"]]);
                    $element.val() == null && $element.val($element.find("option").first().val());
                }
                $tr.append($td.append($element));
                $tbody.append($tr);
            }
            $table.append($tbody);
            $form.append($table)
            $mainTd.append($form);
            $targetTr.append($mainTd);
            proxy._isRowEdit = true;
            proxy._setoffsetWidth();
            proxy._editAddTools();
            proxy._refreshEditForm();
        },
        //#endregion       

    });

    //ENUM FOR EACH ACTION IN TREEGRID
    ej.TreeGrid.Actions = {
        Sorting: "sorting",
        BeginEdit: "beginedit",
        Save: "save",
        Add: "add",
        Delete: "delete",
        Cancel: "cancel",
        Refresh: "refresh",
        Searching: "searching",
        ExpandCollapse: "expandcollapse",
        Selection: "selection",
        rowHover: "rowHover",
        Scroll: "scroll",
        ContextMenuAdd: "contextMenuAdd",
        RefreshDataSource:"refreshDataSource"
    };

    //ENUM FOR SELECTION MODE IN TREEGRID
    ej.TreeGrid.SelectionType = {
        Single: "single",
        Multiple: "multiple"
    };

    //ENUM FOR DIFFERENT EDIT MODE IN TREEGRID
    ej.TreeGrid.EditMode = {
        Normal: "normal",
        CellEditing: "cellEditing",
        RowEditing:"rowEditing",
    };

    //Enum for position of new added row.
    ej.TreeGrid.RowPosition = {
        Top: "top",
        Bottom: "bottom",
        Above: "aboveSelectedRow",
        Below: "belowSelectedRow"
    }
    /* enum for six different columnEditType for treegrid */
    ej.TreeGrid.EditingType = {
        String: "stringedit",
        Boolean: "booleanedit",
        Numeric: "numericedit",
        Dropdown: "dropdownedit",
        DatePicker: "datepicker",
        DateTimePicker: "datetimepicker",
        
    };
    /* enum for different context menu in treegrid */
    ej.TreeGrid.ContextMenuItems = {
        Add: "add",
        Edit: "edit",
        Delete: "delete",
    };
    
    ej.TreeGrid = ej.TreeGrid || {};


    //INITIALIZE THE CELLEDIT ELEMENT FOR DIFFERENT TYPES OF EDITORS
    ej.TreeGrid._initCellEditType = function (instance, $element, id, columnCount) {

        var proxy=instance,
            model=proxy.model,
            columns=model.columns,
            column=columns[columnCount];

        if (ej.isNullOrUndefined(columns[columnCount]["editType"])) {
            column["editType"] = "stringedit";
        }

        switch (column["editType"]) {
            
            case "stringedit":

                if(model.isFromGantt){
                    
                    var helpers={};
                    
                    helpers["_" + id + "cellValue"] = ej.TreeGrid._getCellValue;
                    
                    if(column.field==="predecessor"){
                        helpers["_" + id + "predecessorCell"] = ej.Gantt._getPredecessorsValue;
                    }
                    
                    $.views.helpers(helpers);


                    if(column.field==="predecessor"){ //get the predecessor value from item of GanttRecord
                     
                        var $input=ej.buildTag('input.e-field e-ejinputtext',
                                       "",{},
                                       {
                                           value:"{{:~_" + id + "predecessorCell('"+model.predecessorMapping+"')}}",
                                           id: id + column.field, 
                                           name: column.field
                                       }
                                       );
                    }else { /*get the cellValue if the column does not exist in the GanttRecord object and
                           present in the item of GanttRecord*/
                        $input= ej.buildTag('input.e-field e-ejinputtext', 
                                            "",
                                            {},
                                            {
                                                value: "{{:~_" + proxy._id + "cellValue('" + columns[columnCount].field + "')}}",
                                                id: proxy._id + model.columns[columnCount].field,
                                                name: model.columns[columnCount].field
                                            });
                       
                    }

                }else { /*Get the cellvalue of the normal gridcell*/
                    $input=ej.buildTag('input.e-field e-ejinputtext',
                                          "",
                                          {}, 
                                          {
                                              value: "{{:#data['" + column.field + "']}}", 
                                              id: id + column.field, 
                                              name: column.field
                                          });
                }    
                $element.html($input);
            
                break;

            case "booleanedit":
                
                $element.html('{{if ' + columns[columnCount].field + '}} ' +
                        '<input class="e-field e-checkbox" type ="checkbox" ' +
                        'id=' + proxy._id + columns[columnCount].field +
                        ' name=' + columns[columnCount].field +
                        ' checked="checked"></input>' +
                        ' {{else}} ' +
                        ' <input class="e-field e-checkbox"' +
                        ' type ="checkbox" ' +
                        ' id=' + proxy._id + columns[columnCount].field +
                        ' name=' + columns[columnCount].field + ' > ' +
                        ' {{/if}}');

                break;
            
            case "numericedit":

                var $numericText = ej.buildTag('input.e-numerictextbox e-field', "", {}, {
                    type: "text",
                    value: "{{:#data['" + columns[columnCount].field + "']}}",
                    id: proxy._id + columns[columnCount].field,
                    name: columns[columnCount].field
                });
                $element.append($numericText);

                break;

            case "datepicker":
            case "datetimepicker":
                
                var $datePicker = ej.buildTag('input.e-' + columns[columnCount]["editType"] + ' e-field', "",
                                             {}, 
                                             {
                                                 type: "text",
                                                 value: "{{:#data['" + columns[columnCount].field + "']}}",
                                                 id: id + columns[columnCount].field,
                                                 name: columns[columnCount].field
                                             });
                $element.append($datePicker);

                break;

            case "dropdownedit":

                if(model.isFromGantt){
                    var $dropDownList = ej.buildTag('input.e-field e-dropdownlist' + ' e-field',
                        "", 
                        {}, 
                        {
                            type: "text",
                            value: "{{:#data['" + columns[columnCount].field + "']}}",
                            id: id + columns[columnCount].field,
                            name: columns[columnCount].field
                        });
                    $element.append($dropDownList);
                }else {
                    if (!ej.isNullOrUndefined(column.dropdownData)) {
                        var selectedItems = column.dropdownData;
                        var dropDownTemplate = proxy._compiledDropDownTemplate();
                        $element.get(0).innerHTML = ["<select>", dropDownTemplate.render(selectedItems), "</select>"].join("");
                        $element.find("select").prop({ id: proxy._id + column.field, name: column.field }).addClass("e-field e-dropdownlist");
                    }
                }

                break;
        }
    };
    
    ej.TreeGrid._getCellValue= function (columnName) {

        var cellValue = this.data[columnName];

        if (cellValue) {
            return cellValue;
        } else {
            return this.data.item && this.data.item[columnName];
        }


    };
    //Initialize tree grid toolbar item.
    ej.TreeGrid.ToolbarItems = {
        Add: "add",
        Edit: "edit",
        Delete: "delete",
        Update: "update",
        Cancel: "cancel",
        ExpandAll: "expandAll",
        CollapseAll: "collapseAll"
    };
    //GET ROW CLASS NAME FOR EXPAND COLLAPSE ACTION
    ej.TreeGrid._getrowClassName = function () {

        var rowClass = "gridrowIndex",
            proxy = this;

        if (proxy.data.parentItem) {// && proxy.data.parentItem.index

            rowClass += proxy.data.parentItem.index.toString();

        }

        rowClass += "level";
        rowClass += proxy.data.level.toString();

        return rowClass;
    };

    //GET COLUMN BY FIELD NAME
    ej.TreeGrid.getColumnByField = function (columns, field) {

        var column = 0;

        for (column; column < columns.length; column++) {

            if (columns[column]["field"] == field) break;

        }

        return column == columns.length ? null : columns[column];
    };


    ej.TreeGrid.getColumnByMappingName = function (columns, field) {
        var column = 0;
        for (column; column < columns.length; column++) {
            if (columns[column]["mappingName"] == field) break;
        }
        return column == columns.length ? null : columns[column];
    };

    //EXPAND COLLAPSE THE PARTICULAR RECORD OBJECT
    ej.TreeGrid.sendExpandCollapseRequest = function (element, args) {

        var proxy = element,
            model = proxy.model;

        args.requestType = ej.TreeGrid.Actions.ExpandCollapse;
        //To cancel the cell edit or row edit mode when expand the all record.
        if (proxy._isRowEdit || proxy.model.isEdit) {
            proxy.cancelRowEditCell();
            proxy._cancelSaveTools();
        }
        if (model.enableVirtualization) {

            if (proxy._isFromGantt) {
                proxy._$treegridHelper.ejTreeGrid("processBindings", args);
            } else {
                proxy.processBindings(args);
            }

            if (args.expanded) {

                proxy._trigger("expanded", args);

            } else {

                proxy._trigger("collapsed", args);

            }

            if (proxy._isFromGantt) {
                proxy._$treegridHelper.ejTreeGrid("sendDataRenderingRequest", args);
                proxy._updatedGanttRecords = proxy.getUpdatedRecords();
                proxy._currentViewData = proxy.getCurrentViewData();
                if (proxy.model.enableVirtualization) {
                    if (proxy.model.predecessorMapping) {
                        proxy._isValidationEnabled = false;
                        proxy._connectorlineIds = [];
                        proxy._connectorLinesCollection = [];
                        proxy._$ganttchartHelper.ejGanttChart("clearConnectorLines");
                        proxy._createConnectorLinesCollection();
                    }
                   proxy._$ganttchartHelper.ejGanttChart("refreshHelper", proxy._currentViewData, proxy._updatedGanttRecords);
                   proxy._$treegridHelper.ejTreeGrid("refreshHeight");                    
                }
                
            } else {
                proxy.sendDataRenderingRequest(args);
                proxy._setScrollTop();
                proxy._$gridContent.ejScroller("refresh");
                proxy._updateScrollCss();
            }
            

        } else {

            var record = args.data,
                index,
                $row,
                height = 0,
                isModified = record.expanded !== args.expanded;

            if (proxy._isFromGantt) {
                index = proxy._currentViewData.indexOf(record)
            } else {
                index = proxy.model.currentViewData.indexOf(record);
            }

            $row = $(proxy.getRows()[index]);

            if (args.expanded) {//expand event 
                record.expanded = args.expanded;
                proxy._expandedRecordsCount = 0;
                ej.TreeGrid.expandRecord(proxy, record, args.expanded, args);

                if (isModified) {
                    proxy._totalCollapseRecordCount -= proxy._expandedRecordsCount;
                }

                $row.find(".e-treegridcollapse").removeClass('e-treegridcollapse').addClass('e-treegridexpand');
                $row.removeClass('e-treegridrowcollapse').addClass('e-treegridrowexpand');                

                if (model.enableAltRow) {
                    ej.TreeGrid.updateAltRow(proxy, record, index, 1);
                }
            } else {

                proxy._collapsedRecordCount = 0;
                ej.TreeGrid.collapseRecord(proxy, record, args.expanded);
                
                if (isModified)
                    proxy._totalCollapseRecordCount += proxy._collapsedRecordCount;

                record.expanded = args.expanded;
                $row.find(".e-treegridexpand").removeClass('e-treegridexpand').addClass('e-treegridcollapse');
                $row.removeClass('e-treegridrowexpand').addClass('e-treegridrowcollapse');               
                    
                if (model.enableAltRow)
                    ej.TreeGrid.updateAltRow(proxy, record, index, proxy._collapsedRecordCount + 1);
            }


            var filteredCollapseCount = 0;
            if (proxy._searchString) {
                filteredCollapseCount = proxy.getUpdatedRecords().filter(function (record) {
                    return (proxy.getExpandStatus(record) === false);
                });
                height = (proxy.getUpdatedRecords().length - filteredCollapseCount.length) * model.rowHeight;
            } else
                height = (proxy.getUpdatedRecords().length - proxy._totalCollapseRecordCount) * model.rowHeight;
            if (proxy._isFromGantt) {
                proxy._$treegridHelper.ejTreeGrid("updateHeight", height);
                proxy._$ganttchart.ejGanttChart("updateHeight", height);
                proxy._$ganttchart.ejGanttChart("setCollapsedRecordCount", proxy._totalCollapseRecordCount);
                proxy._$treegridHelper.ejTreeGrid("setCollapsedRecordCount", proxy._totalCollapseRecordCount);
                
            } else {
                proxy.updateHeight(height);
            }

            

            if (args.expanded)
                proxy._trigger("expanded", args);
            else
                proxy._trigger("collapsed", args);
        }
        if (proxy._isFromGantt) {
            var treeGrid = proxy._$treegridHelper.ejTreeGrid("instance");
            var chart = proxy._$ganttchart.ejGanttChart("instance");
            var top = treeGrid._$gridContent.ejScroller("option", "scrollTop");
            chart._$bodyContainer.ejScroller("option", "scrollTop", top);
        }
        var selectItem = proxy.selectedItem();
        if (!proxy._isFromGantt && !args.expanded && selectItem) {            
            var expanded = proxy.getExpandStatus(selectItem);
            if (!expanded) {
                proxy.selectRows(-1);
                proxy.selectedRowIndex(-1);
                selectItem.isSelected = false;
                model.selectedItem = null;
                var editSettings = proxy.model.editSettings;
                var disableToolItems = [];
                if (editSettings.allowEditing && !$($('.e-edit')[0]).parent("li").hasClass("e-disable"))
                    disableToolItems.push($($('.e-edit')[0]).parent()[0]);
                if (editSettings.allowDeleting && !$($('.e-delete')[0]).parent("li").hasClass("e-disable"))
                    disableToolItems.push($($('.e-delete')[0]).parent()[0]);
                if (editSettings.allowDeleting && !$($('.e-cancel')[0]).parent("li").hasClass("e-disable"))
                    disableToolItems.push($($('.e-cancel')[0]).parent()[0]);
                if (editSettings.allowDeleting && !$($('.e-save')[0]).parent("li").hasClass("e-disable"))
                    disableToolItems.push($($('.e-save')[0]).parent()[0]);
                $('.e-treegridtoolbar').ejToolbar('disableItem', disableToolItems);
            }
        }
    };

    //EXPAND THE RECORD
    ej.TreeGrid.expandRecord = function (controlObject, Record, expanded, args) {
  
        var proxy = controlObject,
            rowClassName = ".gridrowIndex" + Record.index.toString() + "level" + (Record.level + 1).toString(),
            $rows = $(rowClassName),
            count = 0,
            length = $rows.length,
            row,
            index,
            record,
            model = proxy.model,
            $expandedRows = $(rowClassName),
            index,
            $gridRows = proxy.getRows(),
            $row = $($gridRows[index]);

        if (proxy._isFromGantt) {
            index = proxy._currentViewData.indexOf(Record);


        } else {
            index = model.currentViewData.indexOf(Record);
        }

        if (Record.hasChildRecords && Record.childRecords.length > 0) {
            $row.find(".e-treegridcollapse").removeClass('e-treegridcollapse').addClass('e-treegridexpand');
            $row.removeClass('e-treegridrowcollapse').addClass('e-treegridrowexpand');
        }

        proxy._expandedRecordsCount += proxy._isFromGantt ? $expandedRows.length / 2 : $expandedRows.length;

        if ($expandedRows.length === 0) {
            if (proxy.model.allowSearching && proxy._searchString && proxy._searchString.length > 0) {
                args && ej.TreeGrid.sendExpandCollapseRequest(proxy, args);
            }
        }

        $expandedRows.css({ 'display': 'table-row' });

        if (proxy._isFromGantt) {
         
            length = length / 2;
        }

        for (count; count < length; count++) {
            row = $rows[count];
            index = $gridRows.index(row);
            if (index !== -1) {
                record = proxy._isFromGantt ? proxy._updatedGanttRecords[index] : proxy._updatedRecords[index];
                record.isExpanded = true;
                if (record.expanded)
                    ej.TreeGrid.expandRecord(proxy,record, expanded);
            }
        }

        if (proxy._isFromGantt)
        proxy.updateConnectorLines($expandedRows, expanded);
    },
    
    //COLLAPSE THE RECORD
    ej.TreeGrid.collapseRecord = function (controlObject, Record, expanded) {

        var proxy = controlObject,
            model = proxy.model,
            rowClassName = ".gridrowIndex" + Record.index.toString() + "level" + (Record.level + 1).toString(),
            $rows = $(rowClassName),
            count = 0,
            length = $rows.length,
            row,
            index,
            record,
            $collapsedRows = $(rowClassName),
        $gridRows = proxy.getRows();

        proxy._collapsedRecordCount += proxy._isFromGantt ? $collapsedRows.length / 2 : $collapsedRows.length;
        $collapsedRows.css({ 'display': 'none' });

        if (proxy._isFromGantt) {

            proxy.updateConnectorLines($collapsedRows, expanded);
            length = length / 2;

        }

        for (count; count < length; count++) {

            row = $rows[count];
            var nn = proxy.getRows();
            index = proxy.getRows().index(row);


            if (index !== -1) {
                record = proxy.getUpdatedRecords()[index];

                if (record.expanded)
                    ej.TreeGrid.collapseRecord(proxy,record, expanded);
            }
        }
    },

    //UPDATE THE ALT ROW FUNCTION
    ej.TreeGrid.updateAltRow = function (controlObject, Record, recordIndex, offset) {

        var proxy = controlObject,
            count = 0,
            model = proxy.model,
            currentViewData = proxy._isFromGantt ? proxy._currentViewData : model.currentViewData,
            length = currentViewData.length,
            isAltRow = Record.isAltRow,
            record,
            $gridRows = proxy.getRows();

        for (count = recordIndex + offset; count < length; count++) {

            if ($($gridRows[count]).css('display') === "none")
                continue;

            record = currentViewData[count];
            if(count!=0)
            record.isAltRow = !isAltRow;
            isAltRow = record.isAltRow;

            if (isAltRow)
                $($gridRows[count]).addClass('e-alt-row');
            else
                $($gridRows[count]).removeClass('e-alt-row');

        }
    };     

    jQuery.uaMatch = function (ua) {
        ua = ua.toLowerCase();

        var match = /(chrome)[ \/]([\w.]+)/.exec(ua) ||
            /(webkit)[ \/]([\w.]+)/.exec(ua) ||
            /(opera)(?:.*version|)[ \/]([\w.]+)/.exec(ua) ||
            /(msie) ([\w.]+)/.exec(ua) ||
            ua.indexOf("compatible") < 0 && /(mozilla)(?:.*? rv:([\w.]+)|)/.exec(ua) ||
            [];

        return {
            browser: match[1] || "",
            version: match[2] || "0"
        };
    };

})(jQuery, Syncfusion);;;;
(function ($, ej, undefined) {
    // ejGanttChart is the plugin name 
    // "ej.GanttChart" is "namespace.className" will hold functions and properties

    ej.widget("ejGanttChart", "ej.GanttChart", {
        // widget element will be automatically set in this
        element: null,

        // user defined model will be automatically set in this
        model: null,
        _rootCSS: "e-ganttchart",

        /* keyConfigurations for keyboard interaction in treegrid */
        keyConfigs: {
            focus: "e",

            //Insert
            insertRecord: "45",

            // delete
            deleteRecord: "46",

            //F2
            editRecord: "113",

            // Enter
            saveRequest: "13",

            //Esc   
            cancelRequest: "27",

            //Home,
            firstRowSelection: "36",

            //End,
            lastRowSelection: "35",

            //Up arrow
            upArrow: "38",

            //Down arrow
            downArrow: "40",

            //tab
            moveCellRight: "9",

            //shifttab
            moveCellLeft: "shift+9",

            //AltPlusDownArrow
            selectedRowExpand: "alt+40",

            //CtrlPlusDownArrow
            totalRowExpand: "ctrl+40",

            //AltPlusUpArrow
            selectedRowCollapse: "alt+38",

            //CtrlPlusUpArrow
            totalRowCollapse: "ctrl+38"
        },

        //default model
        defaults: {
            childPropertyName: "",
            taskIdMapping: "",
            taskNameMapping: "",
            startDateMapping: "",
            endDateMapping: "",
            childMapping: "",
            finishDateMapping: "",
            durationMapping: "",
            milestoneMapping: "",
            progressMapping: "",
            predecessorMapping: "",
            resourceInfoMapping: "",
            resourceNameMapping: "",
            resourceCollection: [], /*--------------Array containing the resource names */

            holidays: [
                {
                    day: null,
                    label: null,
                    background: null
                }
            ],

            stripLines: [
                {
                    day: null,
                    label: null,
                    lineStyle: "dotted",
                    lineColor: "#169dd7",
                    lineWidth: 2
                }
            ],

            enableTaskbarTooltip: true, /*------------showing tooltip on taskbar mouse over */
            enableTaskbarDragTooltip: true, /*--------showing taskbar while dragging taskbar */

            highlightWeekends: true, /*-------------Boolean value for highlighting weekends */

            scheduleStartDate: null, /*-------------start date of entire project */
            scheduleEndDate: null, /*---------------end date of entire project */

            enableProgressBarResizing: true, /*----------Boolean value for resizing progress bar */

            rowHeight: 30,
            progressbarHeight: 100,
            connectorlineWidth: 1,
            dateFormat: "MM/dd/yyyy",
            locale: "en-US",

            //background style
            taskbarBackground: "#DE8080", //"#5AC1E0",
            progressbarBackground: "#C44647", //"#169DD7",
            weekendBackground: '#F2F2F2',
            connectorLineBackground: "#383838",
            parentTaskbarBackground: "#383838",
            parentProgressbarBackground: "#1C1C1C",

            selectedItem: null,
            selectedRowIndex: -1,
            perDayWidth: null,

            perMonthWidth: null,//year-month schedule mode
            perWeekWidth: null,//month-week schedule mode
            perHourWidth:null,
            queryTaskbarInfo: null,

            taskbarTemplate: null,
            progressbarTemplate: null,
            parenttaskbarTemplate: null,
            parentprogressbarTemplate: null,

            //internal collections
            rows: [],
            ganttRecords: [],
            scheduleWeeks: [],

            scheduleYears: [],
            scheduleMonths: [], //new property for month schedule
            scheduleDays:[],
            projectStartDate: null, //new property instead of scheduleWeeks[0] and scheduleYears[0]
            projectEndDate: null,

            updatedGanttRecords: [],

            //tooltip templates
            tooltipTemplate: null,
            tooltipTemplateId:null,
            progressbarTooltipTemplateId: null,
            taskbarEditingTooltipTemplateId: null,

            taskbarEditingTooltipTemplate: null,
            progressbarTooltipTemplate: null,

            //boolean values
            showTaskNames: true,
            showProgressStatus: true,
            showResourceNames: true,
            enableRowHover: false,
            includeWeekend: false,
            allowZooming: false,
            allowGanttChartEditing: true,
            allowKeyboardNavigation: true,

            //baselines
            renderBaseline: false,
            baselineColor: '#fba41c ',

            /* editing API's */
            editSettings: {
                allowEditing: false,
                allowAdding: false,
                allowDeleting: false,
                editMode: "normal",
                dialogEditorTemplateId: null
            },

            scheduleHeaderSettings:
            {
                weekHeaderFormat: "MMM dd , yyyy",//for week - Day schedule mode
                dayHeaderFormat: "ddd",
                weekendBackground: '#F2F2F2',

                yearHeaderFormat: "yyyy",
                monthHeaderFormat: "MMM",

                hourHeaderFormat: "HH",

                scheduleHeaderType: "week"
            },
            workingTimeScale: "TimeScale8Hours",
            roundOffDayworkingTime: true,
            durationUnit: "day",

            localizedDays: null,
            localizedMonths: null,
            //localized string to be displayed in toolTip
            columnHeaderTexts: null,
            enablePredecessorEditing:true,
        },

        updateHighlightWeekends: function (boolValue) {
            var proxy = this;
            proxy.model.highlightWeekends = boolValue;

            if (proxy.model.highlightWeekends == true)
                proxy._renderWeekends();
            else
                proxy._$weekendContainer.remove();
        },

        updateWeekendBackground: function (bgcolor) {
            var proxy = this;
            proxy.model.weekendBackground = bgcolor;
            proxy._$weekendContainer.remove();
            proxy._renderWeekends();
        },

        showTooltip: function (boolValue) {
            var proxy = this;
            proxy.model.enableTaskbarTooltip = boolValue;
            proxy._createTaskbarTemplate();
            proxy._refresh();
        },

        showEditingTooltip: function (boolValue) {
            var proxy = this;
            proxy.model.enableTaskbarDragTooltip = boolValue;
            proxy._createTaskbarTemplate();
            proxy._refresh();
        },

        updateConnectorLineBackground: function (bgcolor) {
            var proxy = this;
            proxy.model.connectorLineBackground = bgcolor;
            proxy._createConnectorLineTemplate();
        },

        updateConnectorlineWidth: function (lineWidth) {
            var proxy = this;
            proxy.model.connectorlineWidth = parseInt(lineWidth);
            proxy._createConnectorLineTemplate();
        },


        updateTaskbarBackground: function (bgcolor) {
            var proxy = this;
            proxy.model.taskbarBackground = bgcolor;
            this._createTaskbarTemplate();
            this._refresh();
        },

        updateProgressbarBackground: function (bgcolor) {
            this.model.progressbarBackground = bgcolor;
            this._createTaskbarTemplate();
            this._refresh();
        },

        updateParentTaskbarBackground: function (bgcolor) {
            this.model.parentTaskbarBackground = bgcolor;
            this._createTaskbarTemplate();
            this._refresh();
        },

        updateParentProgressbarBackground: function (bgcolor) {
            this.model.parentProgressbarBackground = bgcolor;
            this._createTaskbarTemplate();
            this._refresh();
        },

        updateRenderTaskNames: function (bool) {
            var proxy = this;
            proxy.model.showTaskNames = bool;
            proxy._createTaskbarTemplate();
            proxy._refresh();
        },

        updateRendeProgressStatus: function (bool) {
            var proxy = this;
            proxy.model.showProgressStatus = bool;
            proxy._createTaskbarTemplate();
            proxy._refresh();
        },

        updateRenderResourceNames: function (bool) {
            var proxy = this;
            proxy.model.showResourceNames = bool;
            proxy._createTaskbarTemplate();
            proxy._refresh();
        },

        ganttChartEditing: function (boolValue) {
            var proxy = this;
            proxy.model.allowGanttChartEditing = boolValue;
        },

        resizeProgressbar: function (boolValue) {
            var proxy = this;
            proxy.model.enableProgressBarResizing = boolValue;

        },

        updateAllowKeyboardNavigation: function (bool) {
            this.model.allowKeyboardNavigation = bool;
        },

        updateProgressbarHeight: function (height) {
            var proxy = this;
            this.model.progressbarHeight = height;
            proxy._createTaskbarTemplate();
            proxy._refresh();
        },

        updateBaselineColor: function (color) {
            var proxy = this;
            this.model.baselineColor = color;
            proxy._createTaskbarTemplate();
            proxy._refresh();
        },

        updateRenderBaseline: function (bool) {
            var proxy = this;
            this.model.renderBaseline = bool;
            proxy._createTaskbarTemplate();
            proxy._refresh();
            proxy._createConnectorLineTemplate();
        },


        //returns the schedule year width
        _getYearWidth: function () {
            var proxy = this,count=0,width=0;
            for (count = 0; count < this.model.scheduleYears.length; count++) {
                width += this._getTemplateYearWidth(this.model.scheduleYears[count]);
            }
            return (width);
        },

        //returns the schedule month width
        _getMonthWidth: function () {
            var proxy = this,
                model = proxy.model,
                date, scheduleMonths = model.scheduleMonths,
                    monthWidth = 0;

            for (var i = 0; i < scheduleMonths.length; i++) {
                var startDate = scheduleMonths[i];

                if (typeof startDate === "object") {
                    date = new Date(startDate);
                }
                else {
                    date = Globalize.parseDate(startDate, "MM/dd/yyyy");
                }
                var monthLastDay = new Date(date.getFullYear(), date.getMonth() + 1, 0);

                var lastDate = monthLastDay.getDate();
                if (lastDate == 31)
                    monthWidth += (this.model.perDayWidth * 31);
                else if (lastDate == 30)
                    monthWidth += (this.model.perDayWidth * 30);
                else if (lastDate == 28)
                    monthWidth += (this.model.perDayWidth * 28);
            }
            return monthWidth;
        },



        //returns the schedule week width
        _getWeekWidth: function () {
            return (this.model.perDayWidth * 7);
        },

        _getNumberOftWeeks: function (startdate, enddate) {


            //var date1 = new Date(startdate), date2 = new Date(enddate);
            //// The number of milliseconds in one week
            //var ONE_WEEK = 1000 * 60 * 60 * 24 * 7;
            //// Convert both dates to milliseconds
            //var date1_ms = date1.getTime();
            //var date2_ms = date2.getTime();
            //// Calculate the difference in milliseconds
            //var difference_ms = Math.abs(date1_ms - date2_ms);
            //// Convert back to weeks and return hole weeks
            //return Math.floor(difference_ms / ONE_WEEK);
            var startDate = new Date(startdate),
                endDate = new Date(enddate);

            var totalWeeksCollection = [];
            do {
                totalWeeksCollection.push(new Date(startDate));
                startDate.setDate(startDate.getDate() + 7);
            } while (!(startDate > endDate));

            return totalWeeksCollection;
        },

        //returns the ganttchart container height
        _getHeight: function () {
            return this._containerHeight;
        },

        //sets the height of the ganttchart container
        _setHeight: function (value) {
            this._containerHeight = value;
        },

        //returns the rows in the ganttchart
        getGanttChartRows: function () {
            return this._ganttChartRows;
        },

        //returns the gantt record collection
        getUpdatedRecords: function () {
            return this.model.ganttRecords;
        },

        //sets value for currentviewdata , ganttrecords and row collections
        setUpdatedRecords: function (currentViewData, updatedGanttRecords, rows,ids) {
            var proxy = this;
            proxy._currentViewData = currentViewData;
            proxy.model.updatedGanttRecords = updatedGanttRecords;
            proxy.model.ganttRecords = rows;
            proxy.model.rows = rows;
            proxy.model._ids = ids;
        },

        //returns the string date type 
        _getFormatedDate: function (date, format) {
            return Globalize.format(date, format);
        },

        //returns the viewport height
        _getViewportHeight: function () {
            var proxy = this,
                headerdiv = proxy._$headerContainer,
                height;

            height = proxy.element.height() - headerdiv.height() -
                    parseFloat(headerdiv.css("border-bottom-width"));
            return height;
        },

        updateViewPortHeight:function(){
            var proxy = this;
            proxy._viewportHeight=proxy._getViewportHeight();
        },

        //constructor function
        _init: function () {

            var proxy = this, model = proxy.model,
            scheduleMode = model.scheduleHeaderSettings.scheduleHeaderType;

            proxy.element.addClass("e-ganttchart-core");
            proxy.element.attr("tabindex", "0");
            proxy._initPrivateProperties();
            proxy._initialize();
            proxy._renderGanttChart();
            proxy._$bodyContainer.append(proxy._$bodyContent);
            proxy._$ganttChartContainer.append(proxy._$bodyContainer);

            $(proxy._$bodyContainer).css({ "height": proxy._viewportHeight + "px" });
            if (proxy.model.enableVirtualization)
                $(proxy._$bodyContent).css({ "height": (model.rowHeight * model.updatedGanttRecords.length) + "px" });

            if (scheduleMode == "week") {
                $(proxy._$bodyContent).css({ "width": (model.scheduleWeeks.length * proxy._scheduleWeekWidth) + "px" });
            }
            else if (scheduleMode == "year") {
                $(proxy._$bodyContent).css({ "width": (proxy._scheduleYearWidth) + "px" });

            }
            else if (scheduleMode == "month") {
                $(proxy._$bodyContent).css({ "width": (proxy._scheduleMonthWidth) + "px" });
            }
            else if (scheduleMode == "day") {
                $(proxy._$bodyContent).css({ "width": (model.scheduleDays.length * (proxy.model.perHourWidth * 24)) + "px" });
            }

            proxy.createGridLinesTable();
            proxy.renderGanttRecords();
          //  Inner div for scroller
            var scrollerDiv = ej.buildTag('div');
            scrollerDiv.append(proxy._$bodyContent);
            proxy._$bodyContainer.append(scrollerDiv);
            proxy._$bodyContainer.ejScroller({
                width: proxy.element.width(),
                enableTouchScroll:false,
                height: proxy._getViewportHeight(), scroll: function (args) {

                    var arg = {},
                        scrollTop = args.scrollTop;

                    args.requestType = "scroll";
                    args.delta = scrollTop;
//                    proxy._completeAction(args);
                    if (scrollTop != undefined) {// && this.isVScroll()
                        if (proxy.onScrollHelper(scrollTop) === false) {
                           args.cancel = true;
                        }
                    } else {
                        proxy._handleScroll(args);
                    }
                    
                }
            });
            proxy._$bodyContainer.ejScroller("model.keyConfigs", { up: "", down: "" });
            proxy._$bodyContainer.ejScroller("refresh");
            //check if Hscroller is render or not
            var isHorizontalScroll = proxy._$bodyContainer.ejScroller("isHScroll");
                if (!isHorizontalScroll) {
                    proxy._$bodyContainer.addClass("e-borderbox");
                }
                else {
                    proxy._$bodyContainer.removeClass("e-borderbox");
                }
            proxy._wireEvents();


        },

        //rendering gantt chart again after zoomingvalue changed
        reRenderGanttChart: function (daywidth, ganttRecords) {

            var proxy = this,
                   scheduleMode = model.scheduleHeaderSettings.scheduleHeaderType;

            proxy._wireEvents();
            proxy.model.perDayWidth = daywidth;

            // proxy.model.perMonthWidth = monthwidth;

            proxy.model.ganttRecords = ganttRecords;
            proxy._scheduleWeekWidth = proxy._getWeekWidth();
            proxy._scheduleYearWidth = proxy._getYearWidth();
            proxy._scheduleMonthWidth = proxy._getMonthWidth();

            $(proxy._$secondaryCanvas).empty();
            $(proxy._$headerContainer).empty();
            $(proxy._$scheduleDiv).empty();
            proxy._renderGanttChart();
            proxy._$bodyContainer.append(proxy._$bodyContent);
            proxy._$ganttChartContainer.append(proxy._$bodyContainer);

            if (scheduleMode == "week") {
                $(proxy._$bodyContent).css({ "width": (proxy.model.scheduleWeeks.length * proxy._scheduleWeekWidth) + "px" });
            }
            else if (scheduleMode == "year") {
                $(proxy._$bodyContent).css({ "width": (proxy._scheduleYearWidth) + "px" });
            }
            else if (scheduleMode == "month") {
                $(proxy._$bodyContent).css({ "width": (proxy._scheduleMonthWidth) + "px" });
            } 
            else if (scheduleMode == "day") {
                $(proxy._$bodyContent).css({ "width": (proxy.model.scheduleDays.length * (proxy.model.perHourWidth * 24)) + "px" });
            }
        },

        //declaring private properties
        _initPrivateProperties: function () {
            var proxy = this;
            proxy._viewportHeight = 0,
                proxy._prevScrollTop = 0,
                proxy._scrollTop = 0,
                proxy._vScrollDir = 1,
                proxy._$ganttChartContainer = null,
                proxy._$headerContainer = null,
                proxy._$bodyContainer = null,
                proxy._$bodyContent = null,
                proxy._$dependencyViewContainer = null,
                proxy._$secondaryCanvas = null,
                proxy._$ganttViewTable = null,
                proxy._$ganttViewTablebody = null,
                proxy._weekdays = [],
                proxy._rowMargin = 0,
                proxy._renderedRange = null,
                proxy._visibleRange = null,
                proxy._vTop = null,
                proxy._vBottom = null,
                proxy._rTop = null,
                proxy._rBottom = null,
                proxy._vscrollDist = 0,
                proxy._containerHeight = 0,
                proxy._currentViewData = [],
                proxy._id = this.element.attr("id"),
                proxy._ganttChartRows = null,
                proxy._filteredRecords = [],
                proxy._sortedRecords = [],
                proxy._tempSortedRecords = [],
                proxy._scheduleHours = [],

              proxy._updateScheduleWidth(),
            proxy._totalMonthWidth = 0;

            proxy._tempFilteredRecords = [],
            proxy._prevLeft = 0,
            proxy._allowDragging = false,
            proxy._leftResizing = false,
            proxy._rightResizing = false,
            proxy._progressResizing = false,
            proxy._editingContainer = null,
            proxy._allowExpandCollapse = true,
            proxy._leftResizer = null,
            proxy._taskbarItem = null,
            proxy._progressbarItem = null,
            proxy._progressResizer = null,
            proxy._rightResizer = null,
            proxy._tasknameContainer = null,
            proxy._mousePosX = 0,
            proxy._currMousePosX = 0,
            proxy._currMousePosY = 0,
            proxy._prevItem = {},
            proxy._mouseTarget = null,
            proxy._mouseDown = false,
            proxy._$scheduleDiv = null,
            proxy._leftResizerGripper = null,
            proxy._rightResizerGripper = null,
            proxy._progressHandle = null,
            proxy._progressHandleChild = null,
            proxy._mouseOverTooltip = document.getElementById(this.model.tooltipTemplate),
            proxy._progressBarTooltipID = document.getElementById(this.model.progressbarTooltipTemplateId),
            proxy._taskbarEditingTooltipID = document.getElementById(this.model.taskbarEditingTooltipTemplateId),
            proxy._ids = null,
            proxy._scrollBarHeight = 18,
            proxy._windowWidth = $(window).width(),
            proxy._windowHeight = $(window).height(),
            proxy._editingItem = null,
            proxy._editingTarget = null,
            proxy.tooltipState = null,
            proxy._visibleRecordsCount = 0;
            proxy._$gridLinesTablebody = null;

            //Properties for connector line mouse
            proxy._leftConnectorPoint = null;
            proxy._rightConnectorPoint = null;
            proxy._childLeftConnectorPoint = null;
            proxy._childRightConnectorPoint = null;
            proxy._editPredecessor = false;
            proxy._connectorPointX = null;
            proxy._connectorPointY = null;
            proxy._predecessorTooltip = null;
            proxy._totalCollapsedRecord = 0;
        },
        //Calculate schedulw width for all modes
        _updateScheduleWidth:function(){
            var proxy = this;
            proxy._scheduleWeekWidth = proxy._getWeekWidth();
            proxy._numOfWeeks = proxy._getNumberOftWeeks(this.model.projectStartDate, this.model.projectEndDate);
            proxy._scheduleYearWidth = proxy._getYearWidth();
            proxy._scheduleMonthWidth = proxy._getMonthWidth();
            proxy._totalWeekWidth = proxy._scheduleWeekWidth * proxy._numOfWeeks.length;
            proxy._balanceWidth = proxy._totalWeekWidth - proxy._scheduleMonthWidth;
            proxy._scheduleMonthWidth += proxy._balanceWidth;
        },
        //Initialize ganttchart
        _initialize: function () {
            var proxy = this;
            proxy._$ganttChartContainer = ej.buildTag("div.e-ganttviewercontainer#ganttviewercontainer" + proxy._id, "", { width: "100%" }, {});
            proxy._$headerContainer = ej.buildTag("div.e-ganttviewerheaderContainer#ganttviewerheaderContainer" + proxy._id, "", {}, {});
            proxy._$bodyContainer = ej.buildTag("div.e-ganttviewerbodyContianer#ganttviewerbodyContianer" + proxy._id, "", {
                '-ms-touch-action': 'none',
                'touch-action': 'none',
            }, {});
            proxy._$bodyContent = ej.buildTag("div.e-ganttviewerbodyContent#ganttviewerbodyContent" + proxy._id, "", {
            }, {});

            proxy._$dependencyViewContainer = ej.buildTag("div.e-ganttviewerbodyContianer-dependencyViewContainer#dependencyViewContainer" + proxy._id,
                "", {
                    'z-index': '4',
                    'position': 'absolute'
                }, {});
            proxy._$secondaryCanvas = ej.buildTag("div.e-ganttviewerbodyContianer-secondaryCanvas", "", {
                'z-index': '3',
                'position': 'absolute'
            }, {});
            proxy._$weekendsContainer = ej.buildTag("div.e-ganttviewerbodyContianer-weekendsContainer", "", {
                'z-index': '1',
                'position': 'absolute'
            }, {});

            proxy._$ganttViewTable = ej.buildTag("table.e-ganttviewerbodyContianer-ganttViewTable#ganttViewTable" + proxy._id, "", {
                'z-index': '5',
                'position': 'absolute'
            }, { 'cellspacing': '0px' });
            proxy._$scheduleDiv = ej.buildTag("div.e-gantt-schedule-container#gantt-schedule" + proxy._id + "", "", {}, {});
        },

        _getScheduleLength: function (scheduleMode) {
            var proxy = this,
                model = proxy.model;

            switch (scheduleMode) {
                case "week":                    
                    return (model.scheduleWeeks.length * proxy._scheduleWeekWidth);
                    break;
                case "year":                    
                    return (proxy._scheduleYearWidth);
                    break;
                case "month":
                    return (proxy._scheduleMonthWidth);
                    break;
                case "day":
                    return (model.scheduleDays.length * (proxy.model.perHourWidth * 24));
                    break;
                default:
                    return (model.scheduleWeeks.length * proxy._scheduleWeekWidth);

            }
        },

        //Rendering GanttChart
        _renderGanttChart: function () {
            var proxy = this, model = proxy.model,
                scheduleLength, $colsgroup, $column,
            scheduleMode = model.scheduleHeaderSettings.scheduleHeaderType;
            
        proxy._createSchedule(proxy._getDateType(model.scheduleStartDate),
            proxy._getDateType(model.scheduleEndDate));

            proxy._viewportHeight = proxy._getViewportHeight();
                       
            proxy._$ganttViewTable.css("width", proxy._getScheduleLength(scheduleMode) + 'px');
            
            $colsgroup = ej.buildTag("colgroup", "", {}, {});
            $column = $(document.createElement("col"));
            $column.css("width", proxy._getScheduleLength(scheduleMode) + 'px');
            
            $colsgroup.append($column);
            proxy._$ganttViewTable.append($colsgroup);

            proxy._createTooltipTemplate();
            proxy._createEditingTooltipTemplate();
            proxy._createProgressbarTooltipTemplate();

            proxy._createTaskbarTemplate();
            proxy._createConnectorLineTemplate();

            proxy._updateCurrentViewData();

            //Display weekends
            if (proxy.model.highlightWeekends == true
                && model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Week)
                proxy._renderWeekends();

            //Display striplines
            if (proxy.model.stripLines != null) {
                this._renderStripLines(proxy.model.stripLines);
            }

            //Display Holidays
            if (proxy.model.holidays != null) {
                var holidayCount = proxy.model.holidays.length;
                for (var i = 0; i < holidayCount; i++) {
                    proxy._renderHoliday(proxy.model.holidays[i]);
                }
            }
        },

        //Rendering connectorlines from Gantt
        renderConnectorLines: function (connectorLinesCollection) {
            var proxy = this,
                connectorLineContainer = $.render[proxy._id + "ConnectorLineTemplate"](connectorLinesCollection);

            $(proxy._$dependencyViewContainer).empty();
            proxy._$dependencyViewContainer.append(connectorLineContainer);
            proxy._$bodyContent.append(proxy._$dependencyViewContainer);
        },

        //Empty the entire connectorline collection
        clearConnectorLines: function () {
            $(this._$dependencyViewContainer).empty();
        },

        //append single connectorline
        appendConnectorLine: function (connectorLineCollection) {
            var proxy = this,
            connectorLineContainer = $.render[proxy._id + "ConnectorLineTemplate"](connectorLineCollection);
            proxy._$dependencyViewContainer.append(connectorLineContainer);
        },
        //set Collapsed record Count

        setCollapsedRecordCount:function(count)
        {
            this._totalCollapsedRecord = count;
        },
        //get collapsed record count
        getCollapsedRecordCount:function()
        {
            return this._totalCollapsedRecord;
        },
        //remove a particular connector line
        removeConnectorline: function (lineId) {
            $("#ConnectorLine" + lineId).remove();
        },

        //Events
        _wireEvents: function () {
            var proxy = this,
                matched = jQuery.uaMatch(navigator.userAgent);

            //$(proxy._$bodyContainer).bind("scroll", $.proxy(proxy._handleScroll, proxy));

            proxy._on(proxy.element, "mouseenter", ".e-gantt-milestone-container,.e-gantt-childtaskbar,.e-gantt-childtaskbar-progress,.e-gantt-parenttaskbar-innerdiv,.e-gantt-parenttaskbar-progress", this._mouseHover);//.gantt-viewer-bodyContianer tr td
            proxy._on(proxy.element, "mouseleave", ".e-gantt-milestone-container,.e-gantt-childtaskbar,.e-gantt-childtaskbar-progress,.e-gantt-parenttaskbar-innerdiv,.e-gantt-parenttaskbar-progress", this._mouseLeave);//.gantt-viewer-bodyContianer tr td
            proxy._on(proxy.element, "click", proxy._cellClickHandler);

            proxy._on(proxy.element, "mouseenter", ".taskbarresizer-left", proxy._resizerleftOver);
            proxy._on(proxy.element, "mouseleave", ".taskbarresizer-left", proxy._resizerleftLeave);

            proxy._on(proxy.element, "mouseenter", ".taskbarresizer-right", proxy._resizerrightOver);
            proxy._on(proxy.element, "mouseleave", ".taskbarresizer-right", proxy._resizerrightLeave);

            proxy._on(proxy.element, "mouseenter", ".progressbarresizer-right", proxy._progressresizerOver);
            proxy._on(proxy.element, "mouseleave", ".progressbarresizer-right", proxy._progressresizerLeave);

            proxy._on(proxy.element, "mouseenter", ".e-connectorpoint-left", proxy._dragLeftOver);
            proxy._on(proxy.element, "mouseleave", ".e-connectorpoint-left", proxy._dragLeftLeave);

            proxy._on(proxy.element, "mouseenter", ".e-connectorpoint-right", proxy._dragRightOver);
            proxy._on(proxy.element, "mouseleave", ".e-connectorpoint-right", proxy._dragRightLeave);
          

            if (matched.browser.toLowerCase() != "msie") {
                proxy._on(proxy.element, "mousedown", ".e-tasklabel,.e-parentContainer,.e-childContainer,.e-gantt-milestone-container", proxy._mousedown);
            }
            else {
                proxy._on(proxy.element, "mousedown", ".e-tasklabel,.e-parentContainer,.e-childContainer,.e-gantt-milestone-container", proxy._mousedown);
            }

            $(proxy._$bodyContainer).bind("mouseup", $.proxy(proxy._handleMouseUp, proxy));
            $(document).bind("mouseup", $.proxy(proxy._tooltipMouseup, proxy));

            //if (matched.browser.toLowerCase() == "msie") {
            //    proxy._on(proxy.element, "MSPointerDown", ".e-tasklabel,.e-parentContainer,.e-childContainer,.e-gantt-milestone-container", proxy._mousedown);
            //    $(document.body).bind("MSPointerMove", function (event) {
            //        event.preventDefault();
            //    });
            //    $(document.body).bind("MSPointerMove", $.proxy(proxy.handleMouseMove, proxy));
            //    $(proxy._$bodyContainer).bind("MSPointerUp", $.proxy(proxy._handleMouseUp, proxy));
            //}


            if (matched.browser.toLowerCase() == "chrome") {
                proxy._on(proxy.element, "touchstart", ".e-tasklabel,.e-parentContainer,.e-childContainer,.e-gantt-milestone-container", proxy._mousedown);
                $(document.body).bind("touchmove", function (event) {
                    event.preventDefault();
                });
                $(document.body).bind("touchmove", $.proxy(proxy.handleMouseMove, proxy));

                proxy._on(proxy.element, "touchend", ".e-tasklabel,.e-parentContainer,.e-childContainer,.e-gantt-milestone-container", proxy._handleMouseUp);
                proxy._on(proxy.element, "touchleave", ".e-tasklabel,.e-parentContainer,.e-childContainer,.e-gantt-milestone-container", proxy._handleMouseUp);
                $(proxy._$bodyContainer).bind("touchend", $.proxy(proxy._handleMouseUp, proxy));
                $(proxy._$bodyContainer).bind("touchleave", $.proxy(proxy._handleMouseUp, proxy));
            }

            proxy._on(proxy.element, "mouseenter", ".e-stripline", proxy._stripLineMouseOver);
            proxy._on(proxy.element, "mouseleave", ".e-stripline", proxy._stripLineMouseLeave);
            proxy._enableEditingEvents();
        },

        //Event append for editDialogOpen while perform double click action
        _enableEditingEvents: function () {

            var proxy = this,
                model = proxy.model;

            if (model.editSettings.allowEditing) {
                if (model.editSettings.editMode === "normal") {
                    proxy._on(this.element, "dblclick", ".e-ganttviewerbodyContent", proxy._editdblClickHandler);
                }
            }
        },

        //Double click event handler for editing with editMode as normal
        _editdblClickHandler: function () {

            var proxy = this,
                args = {};

            if (proxy.model.editSettings.editMode === "normal") {
                args.requestType = ej.TreeGrid.Actions.BeginEdit;
                proxy._trigger("actionBegin", args);
            }

        },


        //Event to append RowHover effect
        _enableRowHover: function () {
            var proxy = this;
            if (proxy.model.enableRowHover)
                proxy._on(proxy.element, "mouseleave mouseenter",
                    "#ganttviewerbodyContent,.e-ganttviewerbodyContent tr,.e-ganttviewerbodyContent" + proxy._id,
                    proxy._rowHover);
            else
                proxy._on(proxy.element, "mouseleave mouseenter",
                    "#ganttviewerbodyContent,.e-ganttviewerbodyContent tr,.e-ganttviewerbodyContent" + proxy._id);
        },

        //MouseLeave event for striplines to remove tooltip
        _stripLineMouseLeave: function () {
            $(this._mouseOverTooltip).remove();
        },

        //mouseHover event for stripline to render tooltip
        _stripLineMouseOver: function (e) {

            e.target.style.cursor = "pointer";
            var proxy = this, model = proxy.model,
                $target = $(e.target),
                parentNode, match,
                tooltiptable,
                tooltipbody,
                posx = 0, posy = 0;

            if ($target.hasClass("e-striplinespan")) {
                parentNode = $target[0].parentNode;
            } else
                parentNode = $target[0];

            match = parentNode.id.match(/(\d+|[A-z]+)/g);

            if (e.type == "mouseenter" || e.type == "mousemove") {
                if (!e) e = window.event;
                if (e.originalEvent.pageX || e.originalEvent.pageY) {
                    posx = e.originalEvent.pageX;
                    posy = e.originalEvent.pageY;
                }
                else if (e.originalEvent.clientX || e.originalEvent.clientY) {
                    posx = e.originalEvent.clientX + document.body.scrollLeft
                        + document.documentElement.scrollLeft;
                    posy = e.originalEvent.clientY + document.body.scrollTop
                        + document.documentElement.scrollTop;
                }

                tooltiptable = ej.buildTag("table.e-tooltiptable", "", { "width": "auto" },
                    { 'cellspacing': '2px', 'cellpadding': '2px' });
                tooltipbody = ej.buildTag("tbody",
                    "<tr><td>" + model.stripLines[match[1]].day + "</td></tr><tr><td>" +
                        model.stripLines[match[1]].label + "</td></tr>", {}, {});

                tooltiptable.append(tooltipbody);
                if (model.tooltipTemplate == null) {
                    proxy._mouseOverTooltip = ej.buildTag("div.e-tooltipgantt#tooltipgantt" + proxy._id + "", tooltiptable,
                        { "top": (posy) + "px", "left": (posx + 15) + "px", 'position': 'absolute', 'z-index': '6' }, {});
                } else {
                    if (typeof (model.tooltipTemplate) != "object") {
                        var parser = $.parseHTML(model.tooltipTemplate);
                        proxy._mouseOverTooltip = parser[0];
                    }
                    else {
                        var markup = $(model.tooltipTemplate)[0].innerHTML;
                        parser = $.parseHTML(markup);
                        proxy._mouseOverTooltip = parser[1];
                    }

                    $(proxy._mouseOverTooltip).css({
                        "left": (posx + 15) + "px", "top": (posy) + "px",
                        "position": "absolute"
                    });
                    $(proxy._mouseOverTooltip).addClass("customTooltip");
                    proxy._mouseOverTooltip.innerHTML = "<table>" + tooltiptable[0].innerHTML + "</table>";
                }
                $(document.body).append(proxy._mouseOverTooltip);
            }
        },

        //Mouseup over tooltip 
        _tooltipMouseup: function () {
            var proxy = this;
            if (proxy._mouseTarget != null) {
                proxy._handleMouseUp(proxy._mouseTarget);
            }
        },

        //removes all the tooltip in ganttchart
        _clearTooltip: function () {
            var proxy = this;
            $(proxy._mouseOverTooltip).remove();
            $(proxy._taskbarEditingTooltipID).remove();
            $(proxy._progressBarTooltipID).remove();
            $('.e-editingtooltip').remove();
            $(".e-progressbartooltip").remove();
        },

        //mousewheel action for zooming ganttchart
        _mouseWheel: function (e) {
            if (this.model.allowZooming) {
                var proxy = this, args = {},
                    delta = null;

                e = e.originalEvent;
                e.preventDefault();

                if (e.wheelDelta)
                    delta = -e.wheelDelta / 120;
                else if (e.detail)
                    delta = e.detail / 3;

                if (!delta)
                    return;
                args.requestType = "scroll";
                args.delta = delta;
                proxy._enbleZooming(args);
            }
        },


        //mouseHover event on taskbar right helper element
        _resizerrightOver: function (e) {

            var proxy = this,
                $target = e.target,
                div = $target.parentNode;

            if (proxy.model.allowGanttChartEditing == true) {
                if (this._mouseDown == false)
                    e.target.style.cursor = "w-resize";
                proxy._setEditingElements(div);
            }
        },


        //mouseLeave event for taskbar right helper element
        _resizerrightLeave: function () {

            var proxy = this;
            if (proxy.model.allowGanttChartEditing == true) {
                proxy._removeEditingElements();
            }
        },


        //mouseHover event on taskbar left helper element
        _resizerleftOver: function (e) {

            var proxy = this,
                $target = e.target,
                div = $target.parentNode;
            if (proxy.model.allowGanttChartEditing == true) {
                if (this._mouseDown == false)
                    e.target.style.cursor = "e-resize";
                proxy._setEditingElements(div);
            }
        },


        //mouseLeave event for taskbar left helper element
        _resizerleftLeave: function () {
            var proxy = this;
            if (proxy.model.allowGanttChartEditing == true) {
                proxy._removeEditingElements();
            }
        },


        //mouseHover event on taskbar progressbar helper element
        _progressresizerOver: function (e) {
            var proxy = this,
                $target = e.target,
                div = $target.parentNode;
            if (proxy.model.allowGanttChartEditing == true) {
                if (proxy._mouseDown == false)
                    $target.style.cursor = "col-resize";
                proxy._setEditingElements(div);
            }
        },


        //mouseLeave event for progressbar helper element
        _progressresizerLeave: function () {
            var proxy = this;
            if (proxy.model.allowGanttChartEditing == true) {
                proxy._removeEditingElements();
            }
        },


        _secondMouseOverConnectorPoint: function (e, mouseUp)
        {
            var proxy = this, row, recordIndexr, item;

            if ((proxy._mouseDown && proxy._falseLine) || (mouseUp && proxy._falseLine)) {

                var $target = $(e.target),
                  $ganttGridRows = proxy.getGanttChartRows(),
                  row = $target.closest('tr'),
                  recordIndexr = $ganttGridRows.index(row),
                  item = proxy._currentViewData[recordIndexr];

                var fromItem = proxy._editingItem;
                var toItem = item, predecessor, fullPredecessor, currentTarget;

                if (proxy._prevItem.predecessorTarget === 'Start') {
                    predecessor = fromItem.taskId + 'S';
                } else if (proxy._prevItem.predecessorTarget === 'Finish') {
                    predecessor = fromItem.taskId + 'F';
                }

                if ($target.hasClass('e-connectorpoint-left')) {
                    predecessor += 'S';
                    currentTarget = "Start"
                }
                else if ($target.hasClass('e-connectorpoint-right')) {
                    predecessor += 'F';
                    currentTarget = "Finish"
                }

                //Append second item in predecessor tooltip

                $table = proxy._predecessorTooltip.find("table");
                $td = $table.find("tbody").find("tr:eq(1)").find("td:eq(2)").text(toItem.taskName);
                $td = $table.find("tbody").find("tr:eq(1)").find("td:eq(3)").text(currentTarget);
                var args = {};
                args.requestType = "validatePredecessor";
                args.fromItem = fromItem;
                args.toItem = toItem;

                if (args.toItem.item[proxy.model.predecessorMapping]) {
                    fullPredecessor = args.toItem.item[proxy.model.predecessorMapping] + "," + predecessor;
                }
                else {
                    fullPredecessor = predecessor;
                }
                args.predecessor = predecessor;
                args.data = {};
                args.data.taskID = toItem.taskId;
                args.predecessorString = [];
                args.predecessorString.push(fullPredecessor);
                var validation = proxy._completeAction(args);
                $td = $table.find("tbody").find("tr:eq(0)").find("td:eq(0)");
                if (validation) {
                   // $td.text("True");
                    $td.removeClass();
                    $td.addClass("e-predecessor-true");
                } else {
                  //  $td.text("False");
                    $td.removeClass();
                    $td.addClass("e-predecessor-false");
                }

                //Here also update on moueup//same code is required
                if (mouseUp) {
                    return args;
                }
                
            }
        },
        //mouse enter event for left-connectorpoint-point

        _dragLeftOver:function(e)
        {
            var proxy = this,
              $target = e.target,
              div = $target.parentNode;
            if (proxy.model.predecessorMapping && proxy.model.allowGanttChartEditing && proxy.model.enablePredecessorEditing) {
                if (this._mouseDown == false ) {
                    $target.style.cursor = "pointer";
                }
                proxy._setEditingElements(div);
            }
            if(!$(div).hasClass('e-parentContainer'))
                proxy._secondMouseOverConnectorPoint(e);

        },
        //mouse leave event for left-connectorpoint-point
        _dragLeftLeave: function (e) {

            var proxy = this;
            if (proxy.model.allowGanttChartEditing == true && proxy.model.enablePredecessorEditing) {
                proxy._removeEditingElements();
            }
        },

        //mouse enter event for right-connectorpoint-point

        _dragRightOver: function (e) {
            var proxy = this,
             $target = e.target,
             div = $target.parentNode;
            if (proxy.model.predecessorMapping && proxy.model.allowGanttChartEditing && proxy.model.enablePredecessorEditing) {
                if (this._mouseDown == false) {
                    $target.style.cursor = "pointer";
                }
                proxy._setEditingElements(div);
            }
            if (!$(div).hasClass('e-parentContainer'))
                proxy._secondMouseOverConnectorPoint(e);
        },
        //mouse leave event for right-connectorpoint-point
        _dragRightLeave: function (e) {
            var proxy = this;
            if (proxy.model.allowGanttChartEditing == true && proxy.model.enablePredecessorEditing) {
                proxy._removeEditingElements();
            }
        },




        //adding styles for taskbar helper elements
        _setEditingElements: function (div) {
            var proxy = this, progressHandler;

            if ($(div).hasClass("e-childContainer")) {
                proxy._leftResizerGripper = div.childNodes[1],//[0]
                proxy._rightResizerGripper = div.childNodes[5];//[4]
                progressHandler = div.childNodes[4];//[3]
                proxy._progressHandle = progressHandler.firstChild;
                proxy._progressHandleChild = progressHandler.childNodes[1];

                $(proxy._leftResizerGripper).addClass("gripper");
                $(proxy._rightResizerGripper).addClass("gripper");

                if (proxy.model.progressMapping) {
                    $(proxy._progressHandle).addClass("e-progresshandle");
                    $(proxy._progressHandleChild).addClass("e-progresshandleafter");
                }
            }


            if (proxy.model.enablePredecessorEditing) {
                if ($(div).hasClass("e-childContainer") && proxy.model.predecessorMapping && !proxy._falseLine) {

                    proxy._leftConnectorPoint = div.childNodes[0];
                    proxy._rightConnectorPoint = div.childNodes[6];
                    $(proxy._leftConnectorPoint).addClass("e-connectorpoint-hover");
                    $(proxy._rightConnectorPoint).addClass("e-connectorpoint-hover");
                }
                else if ($(div).hasClass("e-gantt-milestone-container") && proxy.model.predecessorMapping && !proxy._falseLine) {

                    proxy._leftConnectorPoint = div.childNodes[0];
                    proxy._rightConnectorPoint = div.childNodes[2];
                    $(proxy._leftConnectorPoint).addClass("e-connectorpoint-hover");
                    $(proxy._rightConnectorPoint).addClass("e-connectorpoint-hover");
                }
                else if ($(div).hasClass("e-childContainer") && proxy.model.predecessorMapping && proxy._falseLine) {
                    proxy._childLeftConnectorPoint = div.childNodes[0];
                    proxy._childRightConnectorPoint = div.childNodes[6];
                    $(proxy._childLeftConnectorPoint).addClass("e-connectorpoint-hover");
                    $(proxy._childRightConnectorPoint).addClass("e-connectorpoint-hover");
                }
                else if ($(div).hasClass("e-gantt-milestone-container") && proxy.model.predecessorMapping && proxy._falseLine) {
                    proxy._childLeftConnectorPoint = div.childNodes[0];
                    proxy._childRightConnectorPoint = div.childNodes[2];
                    $(proxy._childLeftConnectorPoint).addClass("e-connectorpoint-hover");
                    $(proxy._childRightConnectorPoint).addClass("e-connectorpoint-hover");
                }
                else if ($(div).hasClass("e-parentContainer") && proxy.model.predecessorMapping && !proxy._falseLine) {

                    proxy._leftConnectorPoint = div.childNodes[0];
                    proxy._rightConnectorPoint = div.childNodes[3];
                    $(proxy._leftConnectorPoint).addClass("e-connectorpoint-hover");
                    $(proxy._rightConnectorPoint).addClass("e-connectorpoint-hover");

                }
            }
        },


        //removing styles for taskbar helper elements
        _removeEditingElements: function () {
            var proxy = this;
            $(proxy._leftResizerGripper).removeClass("gripper");
            $(proxy._rightResizerGripper).removeClass("gripper");

            if (proxy.model.progressMapping) {
                $(proxy._progressHandle).removeClass("e-progresshandle");
                $(proxy._progressHandleChild).removeClass("e-progresshandleafter");
            }


            //Remove Connector points in chart
            if (proxy.model.enablePredecessorEditing) {
                if (proxy.model.predecessorMapping && proxy._mouseDown == false) {

                    $(proxy._leftConnectorPoint).removeClass('e-connectorpoint-hover');
                    $(proxy._rightConnectorPoint).removeClass('e-connectorpoint-hover');
                    proxy._leftConnectorPoint = null;
                    proxy._rightConnectorPoint = null;
                }

                if (proxy.model.predecessorMapping && proxy._leftConnectorPoint !== null && proxy._mouseDown == true || proxy._childLeftConnectorPoint) {
                    $(proxy._childLeftConnectorPoint).removeClass("e-connectorpoint-hover");
                    $(proxy._childRightConnectorPoint).removeClass("e-connectorpoint-hover");
                    //remove curret target predecessor in tooltip    
                    if (proxy._predecessorTooltip) {
                        $table = proxy._predecessorTooltip.find("table");
                        $table.find("tbody").find("tr:eq(1)").find("td:eq(2)").text("");
                        $table.find("tbody").find("tr:eq(1)").find("td:eq(3)").text("");
                        $td = $table.find("tbody").find("tr:eq(0)").find("td:eq(0)").removeClass();
                        //$td.text("False");
                        $td.addClass('e-predecessor-false');
                    }
                }
            }
        },


        refreshHeight:function(){

            var proxy = this;
            proxy._$bodyContainer.ejScroller("refresh");
        },

        //mousedown event for ganttchart
        _mousedown: function (e) {

            var proxy = this;
            proxy._clearTooltip();
            proxy._mouseDown = true;
            args = {};
            //proxy._clearContextMenu();
            var $target = $(e.target),
            $ganttGridRows = proxy.getGanttChartRows(),
            row = $target.closest('tr'),
            recordIndexr = $ganttGridRows.index(row),
            item = proxy._currentViewData[recordIndexr],
            div = $target[0].parentNode,
            matched = jQuery.uaMatch(navigator.userAgent);

            if (ej.isNullOrUndefined(item)) {
                return;
            }
            proxy._editingItem = item;
            proxy._editingTarget = $target;

            if ($(div).hasClass("e-gantt-childtaskbar-progress") ||
                $(div).hasClass("progressbarresizer-right")) {
                div = div.parentNode;
            }

            if ($(div).hasClass("e-childContainer") ||
                ($(div).hasClass("e-gantt-milestone")) || $(div).hasClass('e-parentContainer') || $(div).hasClass("e-gantt-milestone-container")) {

                $(row).addClass("e-editmode");
                proxy._mouseTarget = e;
            }

            if (proxy.model.allowGanttChartEditing && ($(div).hasClass("e-childContainer")
                || ($(div).hasClass("e-gantt-milestone")) || $(div).hasClass("e-gantt-milestone-container") || $(div).hasClass('e-parentContainer'))) { //mouse down on drag points in child and milestone container and parent container also included 

                if (e.target.style.cursor == "e-resize" && ($(div).hasClass("e-childContainer")
                    || ($(div).hasClass("e-gantt-milestone")))
                    || (e.type == "touchstart" && e.target.className == "taskbarresizer-left" && matched.browser.toLowerCase() == "chrome")) {
                    proxy._updateEditingType();
                    proxy._leftResizing = true;
                }

                if (e.target.style.cursor == "w-resize" && ($(div).hasClass("e-childContainer")
                    || ($(div).hasClass("e-gantt-milestone")))
                    || (e.type == "touchstart" && e.target.className == "taskbarresizer-right" && matched.browser.toLowerCase() == "chrome")) {
                    proxy._updateEditingType();
                    proxy._rightResizing = true;

                }
                if (e.target.style.cursor == "col-resize" && ($(div).hasClass("e-childContainer")
                    || ($(div).hasClass("e-gantt-milestone")))
                    || (e.type == "touchstart" && e.target.className == "progressbarresizer-right" && matched.browser.toLowerCase() == "chrome")) {
                    proxy._updateEditingType();
                    proxy._progressResizing = true;
                }
                if (e.target.style.cursor == "move" && ($(div).hasClass("e-childContainer")
                    || ($(div).hasClass("e-gantt-milestone")))) {
                    proxy._updateEditingType();
                    proxy._allowDragging = true;
                }
                if (e.target.style.cursor == "" && ($(div).hasClass("e-childContainer")
                  || ($(div).hasClass("e-gantt-milestone")))) {
                    proxy._updateEditingType();
                    proxy._allowDragging = true;
                }

                // ON drag points initiate the false line and edit type for predecessor

                if (proxy.model.enablePredecessorEditing) {
                    if (e.target.style.cursor == "pointer" && ($(div).hasClass("e-childContainer")
                     || ($(div).hasClass("e-gantt-milestone")) || $(div).hasClass("e-gantt-milestone-container") || $(div).hasClass('e-parentContainer'))) {
                        proxy._updateEditingType();
                        proxy._editPredecessor = true;
                        if ($target.hasClass('e-connectorpoint-left')) {
                            proxy._prevItem.predecessorTarget = 'Start';
                        }
                        else if ($target.hasClass('e-connectorpoint-right')) {
                            proxy._prevItem.predecessorTarget = 'Finish';
                        }
                    }
                }




                if (!e) e = window.event;
                if (ej.browserInfo().name == "msie" && ej.browserInfo().version < 9) {
                    e.originalEvent.pageX = e.originalEvent.screenX;
                    e.originalEvent.pageY = e.originalEvent.screenY;
                }

                if (e.originalEvent.pageX || e.originalEvent.pageY) {
                    proxy._currMousePosX = e.originalEvent.pageX;
                    proxy._currMousePosY = e.originalEvent.pageY;
                    proxy.dragPosX = e.originalEvent.pageX;
                }
                else if (e.originalEvent.clientX || e.originalEvent.clientY) {
                    proxy.dragPosX = e.originalEvent.clientX + document.body.scrollLeft
                        + document.documentElement.scrollLeft;
                }
                else if (e.originalEvent && e.originalEvent.changedTouches
                    && e.originalEvent.changedTouches.length > 0) {
                    proxy._currMousePosX = e.originalEvent.changedTouches[0].pageX;
                    proxy._currMousePosY = e.originalEvent.changedTouches[0].pageY;
                    proxy.dragPosX = e.originalEvent.changedTouches[0].pageX;
                }

                proxy._prevItem.left = item.left;
                proxy._prevItem.status = item.status;
                proxy._prevItem.duration = item.duration;
                proxy._prevItem.startDate = item.startDate;
                proxy._prevItem.endDate = item.endDate;
                proxy._prevItem.width = item.width;

                //For false line starting point
                if (proxy.model.enablePredecessorEditing) {
                    proxy._connectorPointX = proxy._currMousePosX - proxy._$bodyContent.offset().left;
                    proxy._connectorPointY = proxy._currMousePosY - proxy._$bodyContent.offset().top;
                }


                $(proxy._$bodyContainer).bind("mousemove", $.proxy(proxy.handleMouseMove, proxy));

                if (matched.browser.toLowerCase() == "chrome") {

                    proxy._on(proxy.element, "touchend", ".e-tasklabel,.e-parentContainer,.e-childContainer,.e-gantt-milestone-container", proxy._handleMouseUp);
                    proxy._on(proxy.element, "touchleave", ".e-tasklabel,.e-parentContainer,.e-childContainer,.e-gantt-milestone-container", proxy._handleMouseUp);
                    $(proxy._$bodyContainer).bind("touchend", $.proxy(proxy._handleMouseUp, proxy));
                    $(proxy._$bodyContainer).bind("touchleave", $.proxy(proxy._handleMouseUp, proxy));
                    $(document.body).bind("touchend", $.proxy(proxy._handleMouseUp, proxy));
                    $(document.body).bind("touchleave", $.proxy(proxy._handleMouseUp, proxy));
                }
            }

            if (($(div).hasClass("e-parentContainer")) && !$target.hasClass("e-connectorpoint-left") && !$target.hasClass("e-connectorpoint-right")) { // here check drag point class
                if (proxy._allowExpandCollapse && item && item.hasChildRecords) {
                        if (proxy.model.selectedRowIndex !== args.recordIndex && model.allowSelection) {
                            args.target = "ejGanttChart";
                            args.data = item;
                            proxy.model.selectedRowIndex = proxy.model.updatedGanttRecords.indexOf(args.data);
                            proxy.selectRows(proxy.model.selectedRowIndex);
                            args.recordIndex = proxy.model.selectedRowIndex;
                            proxy._trigger("rowSelected", args);
                            if (proxy.prevSelectedItem != null) {
                                proxy.prevSelectedItem.isSelected = false;
                                proxy.model.updatedGanttRecords[proxy.model.selectedRowIndex].isSelected = true;
                            }
                            proxy.prevSelectedItem = args.data;
                        }
                    proxy._expandCollapse(recordIndexr);
                }
            } else {
                proxy._appendTooltip($target, recordIndexr);
            }
        },


        handleMouseMove: function (e) {
            this._updateOnmouseMove(e);

        },


        //Handler for MouseUp event in ganttchart
        _handleMouseUp: function (e) {

            var proxy = this,
                args = {},
                $ganttGridRows = proxy.getGanttChartRows(),
                $target, row, recordIndexr = 0, item;

            
            //Calculate and validate predecessor and draw connectorline after second connector point connects
            if (($(e.target).hasClass('e-connectorpoint-left') || $(e.target).hasClass('e-connectorpoint-right')) && proxy._falseLine && !$(e.target).parent().hasClass('e-parentContainer')) {
                var newArgs = proxy._secondMouseOverConnectorPoint(e, true);
                if (newArgs.predecessorValidation) {
                    newArgs.requestType = "drawConnectorLine";
                    proxy._completeAction(newArgs);
                }
            }

            if (proxy._editingTarget != null && proxy._editingItem != null) {
                $target = proxy._editingTarget,
                row = $target.closest('tr'),
                recordIndexr = $ganttGridRows.index(row),
                item = proxy._editingItem;
                if ($(row).hasClass("e-editmode")) {
                    $(row).removeClass("e-editmode");
                    proxy._mouseTarget = null;
                }
            }


            proxy._editingTarget = null;
            proxy._editingItem = null;

            proxy._clearTooltip();
            proxy._$ganttChartContainer[0].style.cursor = "auto";

            proxy._allowExpandCollapse = true;

            if (item != null) {
                proxy.updateConnectorLineOffset(item);
            }

            if (item != null && (proxy._allowDragging || proxy._leftResizing || proxy._rightResizing || proxy._progressResizing)) {
                args.editingFields = { startdate: item.startDate, enddate: item.endDate, progress: item.status, duration: item.duration };
                args.data = item;
                args.previousData = proxy._prevItem;
                args.dragging = proxy._allowDragging;
                args.leftResizing = proxy._leftResizing;
                args.rightResizing = proxy._rightResizing;
                args.progressResizing = proxy._progressResizing;
                proxy._taskbarEdited(args);
            }

            if (args.cancel) {
                proxy._getPrevItem(item, recordIndexr);
                if (proxy.model.predecessorMapping) {
                    args.requestType = "updateConnectors";
                    proxy._trigger("actionComplete", args);
                }
            }

            $("#ganttviewerbodyContianer" + proxy._id).unbind("mousemove");
            proxy._updateEditingType();
            proxy._mouseDown = false;

            //Remove drag point and false lines on mouse up
            proxy._falseLine && proxy._falseLine.remove();
            proxy._falseLine = null;
            proxy._predecessorTooltip && proxy._predecessorTooltip.remove();
            proxy._predecessorTooltip = null;
            $(proxy._leftConnectorPoint).removeClass("e-connectorpoint-hover");
            $(proxy._rightConnectorPoint).removeClass("e-connectorpoint-hover");
            $(proxy._childRightConnectorPoint).removeClass("e-connectorpoint-hover");
            $(proxy._childLeftConnectorPoint).removeClass("e-connectorpoint-hover");
            proxy._leftConnectorPoint = null;
            proxy._rightConnectorPoint = null;
            proxy._childRightConnectorPoint = null;
            proxy._childLeftConnectorPoint = null;
        },

        getChildCount: function (record, count) {
            var currentRecord, proxy = this;
            if (!record.hasChildRecords)
                return 0;
            for (var i = 0; i < record.childRecords.length; i++) {
                currentRecord = record.childRecords[i];
                count++;
                if (currentRecord.hasChildRecords) {
                    count = proxy.getChildCount(currentRecord, count);
                }
            }
            return count;
        },

        //get the Expand status of GridRecord
        _getCollapsedParentItem: function (record) {
            var parentRecord = record.parentItem;
            if (parentRecord) {
                if (parentRecord.expanded === false) {
                    return parentRecord;
                } else {
                    return this._getCollapsedParentItem(parentRecord)
                }
            }
            else
            {
                return null;
            }
        },
        //keyPressed event for perform the keynavigate selection in gantt
        _keyPressed: function (action, target, arg, e) {

            var proxy = this,
                $ganttChartEle = proxy.element,
                ganttChartObject = $ganttChartEle.ejGanttChart("instance"),
                model = ganttChartObject.model;

            e.stopImmediatePropagation();
            e.preventDefault();

            if (!model.allowKeyboardNavigation)
                return true;

            switch (action) {

                case "downArrow":
                    if (!proxy._rowSelectingEventTrigger()) {
                        //get the last row index of the ganttchart control
                        var lastRowIndex = proxy.model.updatedGanttRecords.length - 1;

                        if (proxy.model.selectedRowIndex != lastRowIndex) {

                            if(!model.enableVirtualization && !model.selectedItem.expanded)
                            {
                                var child = proxy.getChildCount(model.selectedItem, 0);
                                var index=proxy.model.selectedRowIndex + child+1;
                                if (lastRowIndex >= index)
                                    proxy.selectRows(proxy.model.selectedRowIndex + child + 1);
                            }
                            else
                            {
                                proxy.selectRows(proxy.model.selectedRowIndex + 1);
                            }
                            model.selectedItem.isSelected = true;
                            var recordIndex = model.selectedItem &&
                                proxy.model.updatedGanttRecords.indexOf(model.selectedItem),
                                rowTop = lastRowIndex !== -1 && recordIndex * model.rowHeight,
                                scrollTop,
                                containerWidth,
                                scrollerExsist = proxy._$bodyContainer.children(".e-content").length;
                                if (scrollerExsist)
                                    scrollTop = proxy._$bodyContainer.children(".e-content").scrollTop();
                                else
                                    scrollTop = proxy._$bodyContainer.scrollTop();

                                containerWidth = scrollTop + proxy._viewportHeight - model.rowHeight-proxy._scrollBarHeight + (proxy.getCollapsedRecordCount() * model.rowHeight);
                            if (containerWidth < rowTop) {
                                proxy._$bodyContainer.ejScroller("scrollY", scrollTop + model.rowHeight, true);
                            }

                            if (model.enableVirtualization) {
                                proxy.element[0].focus();
                                proxy.selectRows(proxy.model.selectedRowIndex);
                            }
                            proxy._rowSelectedEventTrigger(proxy.model.selectedRowIndex); //for diasable completeaction
                        }
                    }
                    break;

                    //select the previous row by press down arrow key
                case "upArrow":
                    if (!proxy._rowSelectingEventTrigger()) {
                        if (proxy.model.selectedRowIndex !== 0) {
                            var previousItem = proxy.model.updatedGanttRecords[proxy.model.selectedRowIndex - 1],
                                parentItem,
                                rowClassName,length,
                                scrollTop,
                                containerWidth,
                                scrollerExsist = proxy._$bodyContainer.children(".e-content").length;
                            if (!model.enableVirtualization && previousItem.parentItem)
                            {
                                parentItem = proxy._getCollapsedParentItem(previousItem);
                                if (parentItem)
                                {
                                    length = proxy.getChildCount(parentItem, 0);
                                    proxy.selectRows(proxy.model.selectedRowIndex - length - 1);
                                }
                                else
                                {
                                    proxy.selectRows(proxy.model.selectedRowIndex - 1);
                                }
                            }
                            else
                            {
                                proxy.selectRows(proxy.model.selectedRowIndex - 1);
                            }
                            recordIndex = proxy.model.updatedGanttRecords.indexOf(model.selectedItem);
                            rowTop = recordIndex !== -1 && (recordIndex * model.rowHeight) - (proxy.getCollapsedRecordCount() * model.rowHeight);
                            if (scrollerExsist)
                                scrollTop = proxy._$bodyContainer.children(".e-content").scrollTop();
                            else
                                scrollTop = proxy._$bodyContainer.scrollTop();
                            if (scrollTop) {
                                if (scrollTop > rowTop) {
                                    if (rowTop >= 0)
                                        proxy._$bodyContainer.ejScroller("scrollY", rowTop, true);
                                    else
                                        proxy._$bodyContainer.ejScroller("scrollY", 0, true);
                                    if (model.enableVirtualization) {
                                        proxy.selectRows(recordIndex);
                                        proxy.element[0].focus();
                                    }
                                }
                            }
                            proxy._rowSelectedEventTrigger(proxy.model.selectedRowIndex);
                        }
                    }

                    break;

                    //select the first row while press the Home key
                case "firstRowSelection":
                    if (!proxy._rowSelectingEventTrigger()) {
                        proxy.selectRows(0);
                        recordIndex = model.updatedGanttRecords.indexOf(model.selectedItem);
                        rowTop = recordIndex !== -1 && recordIndex * model.rowHeight;
                        var currentPos = proxy._$ganttViewTable.height();
                        if (currentPos > (proxy._viewportHeight - proxy._scrollBarHeight)) {
                            args = {
                                requestType: "scroll",
                                delta: rowTop
                            };
                            proxy._$bodyContainer.ejScroller("scrollY", rowTop, true);
                        }
                            if (model.enableVirtualization) {
                                proxy.element[0].focus();
                                proxy.selectRows(0);
                            }
                        proxy._rowSelectedEventTrigger(0);
                    }
                    break;

                case "lastRowSelection":

                    if (!proxy._rowSelectedEventTrigger()) {
                        lastRowIndex = model.updatedGanttRecords.length - 1;
                        var previousItem = model.updatedGanttRecords[lastRowIndex];
                        if (!model.enableVirtualization && previousItem.parentItem) {
                            parentItem = proxy._getCollapsedParentItem(previousItem);
                            if (parentItem) {
                                length = proxy.getChildCount(parentItem, 0);
                                proxy.selectRows(lastRowIndex - length);
                            }
                            else {
                                proxy.selectRows(lastRowIndex);
                            }
                        }
                        else {
                            proxy.selectRows(lastRowIndex);
                        }
                        recordIndex = model.selectedItem && model.updatedGanttRecords.indexOf(model.selectedItem);
                        rowTop = lastRowIndex !== -1 && recordIndex * model.rowHeight;

                        if (rowTop + proxy.model.rowHeight >= proxy._viewportHeight) {

                            scrollTop = rowTop + proxy.model.rowHeight - (proxy._viewportHeight - proxy._scrollBarHeight) - (proxy.getCollapsedRecordCount() * model.rowHeight);
                            if (scrollTop >= 0) {
                                args = {
                                    requestType: "scroll",
                                    delta: scrollTop
                                };
                                proxy._$bodyContainer.ejScroller("scrollY", scrollTop, true);
                            }
                            if (model.enableVirtualization) {
                                proxy.element[0].focus();
                                proxy.selectRows(recordIndex);
                            }
                        }
                        proxy._rowSelectedEventTrigger(recordIndex);
                    }

                    break;
            }

            return true;
        },

        _rowSelectingEventTrigger: function () {
            var proxy = this,
                model = proxy.model,
                args = {},
                selectedItem,
                $gridRows;

            if (model.selectedRowIndex !== -1) {

                $gridRows = proxy.getGanttChartRows();
                selectedItem = proxy.model.updatedGanttRecords[model.selectedRowIndex];
                model.selectedItem = selectedItem;
                args = {
                    rowElement: $gridRows.eq(model.selectedRowIndex),
                    data: selectedItem,
                    recordIndex: model.selectedRowIndex
                };

            }

            return proxy._trigger('rowSelecting', args);
        },

        _rowSelectedEventTrigger: function (index) {
            var proxy = this,
                args,
                $gridRows = proxy.getGanttChartRows();
            args = {
                rowElement: $gridRows.eq(index),
                data: proxy.model.selectedItem,
                target: "ejGanttChart",
                recordIndex: index
            };
            proxy._trigger("rowSelected", args);
        },

        _updateEditingType: function () {
            var proxy = this;
            proxy._leftResizing = false;
            proxy._allowDragging = false;
            proxy._rightResizing = false;
            proxy._progressResizing = false;
            proxy._editPredecessor = false;
        },


        //update offset values for predecessor
        updateConnectorLineOffset: function (item) {

            var parentGanttRecord,
                model = this.model,
                predecessor = item.predecessor,
                predecessorValue = [],
                parentStartDate,
                parentEndDate,
                weekendOffset, childGanttRecord, dayOffset;

            if (predecessor) {
                for (var i = 0; i < predecessor.length; i++) {
                    if ((predecessor[i].to === item['taskId'].toString())) {

                        parentGanttRecord = model.rows[model._ids.indexOf(predecessor[i].from)];
                        childGanttRecord = model.rows[model._ids.indexOf(predecessor[i].to)];
                        parentStartDate = new Date(parentGanttRecord.startDate);
                        parentEndDate = new Date(parentGanttRecord.endDate);

                        if (predecessor[i].predecessorsType == "FS") {

                            if (childGanttRecord.left < (parentGanttRecord.left + parentGanttRecord.width)) {

                                dayOffset = ((parentGanttRecord.left + parentGanttRecord.width)
                                    - childGanttRecord.left) / this.model.perDayWidth;

                                dayOffset = childGanttRecord.isMilestone == true ? (dayOffset - 1) : dayOffset;
                                predecessor[i].offset = Math.round(-dayOffset);
                            }
                            else {
                                dayOffset = (childGanttRecord.left - (parentGanttRecord.left + parentGanttRecord.width))
                                    / this.model.perDayWidth;

                                if (dayOffset >= 0)
                                    predecessor[i].offset = Math.round(dayOffset);
                            }

                            if (model.includeWeekend === false) {
                                if (predecessor[i].offset > 0) {
                                    var weekEndDays = this._calculateWeekendDays(parentEndDate, new Date(childGanttRecord.startDate))
                                    predecessor[i].offset -= weekEndDays;
                                } else if (predecessor[i].offset < 0) {
                                    var weekEndDays = this._calculateWeekendDays(new Date(childGanttRecord.startDate), parentEndDate)
                                    predecessor[i].offset += weekEndDays;

                                }
                            }

                        }
                        if (predecessor[i].predecessorsType == "SS") {
                            if (childGanttRecord.left < parentGanttRecord.left) {
                                dayOffset = ((parentGanttRecord.left) - childGanttRecord.left) / this.model.perDayWidth;
                                predecessor[i].offset = Math.round(-dayOffset);
                            }
                            else if (childGanttRecord.left > parentGanttRecord.left) {
                                dayOffset = (childGanttRecord.left - (parentGanttRecord.left)) / this.model.perDayWidth;
                                predecessor[i].offset = Math.round(dayOffset);
                            }

                            if (model.includeWeekend === false) {
                                if (predecessor[i].offset > 0) {
                                    var weekEndDays = this._calculateWeekendDays(parentStartDate, new Date(childGanttRecord.startDate))
                                    predecessor[i].offset -= weekEndDays;
                                } else if (predecessor[i].offset < 0) {
                                    var weekEndDays = this._calculateWeekendDays(new Date(childGanttRecord.startDate), parentStartDate)
                                    predecessor[i].offset += weekEndDays;
                                }
                            }

                        }
                        if (predecessor[i].predecessorsType == "SF") {

                            if (parentStartDate.getDay() == 5) {
                                weekendOffset = 2 * this.model.perDayWidth;
                            }
                            if ((childGanttRecord.left + childGanttRecord.width) < parentGanttRecord.left) {

                                dayOffset = ((parentGanttRecord.left) - (childGanttRecord.left + childGanttRecord.width))
                                    / this.model.perDayWidth;
                                if (weekendOffset && this.model.includeWeekend == false)
                                    dayOffset = dayOffset - weekendOffset;
                                if (dayOffset > 0)
                                    predecessor[i].offset = Math.round(-dayOffset);
                            } else if ((childGanttRecord.left + childGanttRecord.width) > parentGanttRecord.left) {

                                dayOffset = ((childGanttRecord.left + childGanttRecord.width) -
                                    (parentGanttRecord.left)) / this.model.perDayWidth;
                                if (weekendOffset && this.model.includeWeekend == false)
                                    dayOffset = dayOffset - weekendOffset;
                                if (dayOffset > 0)
                                    predecessor[i].offset = Math.round(dayOffset);
                            }
                            if (model.includeWeekend === false) {
                                if (predecessor[i].offset > 0) {
                                    var weekEndDays = this._calculateWeekendDays(parentStartDate, new Date(childGanttRecord.startDate))
                                    predecessor[i].offset -= weekEndDays;
                                } else if (predecessor[i].offset < 0) {
                                    var weekEndDays = this._calculateWeekendDays(new Date(childGanttRecord.startDate), parentStartDate)
                                    predecessor[i].offset += weekEndDays;
                                }
                            }
                        }

                        if (predecessor[i].predecessorsType == "FF") {

                            if ((childGanttRecord.left + childGanttRecord.width) < (parentGanttRecord.left + parentGanttRecord.width)) {
                                dayOffset = ((parentGanttRecord.left + parentGanttRecord.width) -
                                    (childGanttRecord.left + childGanttRecord.width)) / this.model.perDayWidth;
                                predecessor[i].offset = Math.round(-dayOffset);
                            }
                            else if ((childGanttRecord.left + childGanttRecord.width) > (parentGanttRecord.left + parentGanttRecord.width)) {
                                dayOffset = ((childGanttRecord.left + childGanttRecord.width) -
                                    (parentGanttRecord.left + parentGanttRecord.width)) / this.model.perDayWidth;
                                predecessor[i].offset = Math.round(dayOffset);
                            }
                            if (model.includeWeekend === false) {
                                if (predecessor[i].offset > 0) {
                                    var weekEndDays = this._calculateWeekendDays(parentEndDate,new Date(childGanttRecord.endDate))
                                    predecessor[i].offset -= weekEndDays;
                                } else if (predecessor[i].offset < 0) {
                                    var weekEndDays = this._calculateWeekendDays(new Date(childGanttRecord.endDate), parentEndDate)
                                    predecessor[i].offset += weekEndDays;
                                }
                            }
                        } 
                        

                        if (predecessor[i].offset < 0) {
                            predecessorValue.push(predecessor[i].from + "" + predecessor[i].predecessorsType + ""
                                + predecessor[i].offset + "d");
                        }
                        else if (predecessor[i].offset >= 1) {
                            predecessorValue.push(predecessor[i].from + "" + predecessor[i].predecessorsType + "+"
                                + predecessor[i].offset + "d");
                        }
                        else {
                            predecessorValue.push(predecessor[i].from + "" + predecessor[i].predecessorsType);
                        }
                    }
                }
                if (predecessorValue.length > 0) {
                    item.item[model.predecessorMapping] = predecessorValue.join(',');
                    //this.refreshRow(itemIndex, false);
                }
            }
        },
        _calculateWeekendDays: function (fromDate, toDate)
        {
                var weekendDayCount = 0;

                while(fromDate < toDate){
                    fromDate.setDate(fromDate.getDate() + 1);
                    if(fromDate.getDay() === 0 || fromDate.getDay() == 6){
                        ++weekendDayCount ;
                    }
                }
                return weekendDayCount ;
        },

        //Returns the previous item properties
        _getPrevItem: function (item, index) {
            var proxy = this;
            item.left = proxy._prevItem.left;
            item.width = proxy._prevItem.width;
            item.startDate = proxy._prevItem.startDate;
            item.endDate = proxy._prevItem.endDate;
            item.duration = proxy._prevItem.duration;
            item.status = proxy._prevItem.status;
            item.progressWidth = this._getProgressWidth(item.width, item.status);
            this.refreshRow(index);
        },

        //handler for left resizing taskbar item
        _enableLeftResizing: function (e, item) {

            var proxy = this;
            e.target.style.cursor = "e-resize";
            $(proxy._leftResizer).addClass("gripper");
            $(proxy._rightResizer).addClass("gripper");

            if (proxy.dragPosX > proxy._mousePosX) {
                proxy._mousePosX = proxy.dragPosX - proxy._mousePosX;
                if (item.left > 0) {
                    if ((item.left + 30) < (item.left + item.width)) {
                        item.left -= proxy._mousePosX;
                    }
                    item.width += proxy._mousePosX;
                }
            }
            else {
                proxy._mousePosX -= proxy.dragPosX;
                if ((item.left + 30) < (item.left + item.width)) {
                    item.left += proxy._mousePosX;
                }
                item.width -= proxy._mousePosX;
            }
            if (e.originalEvent.pageX == 0) {
                this.dragPosX = e.originalEvent.targetTouches[0].pageX;
            }
            else {
                this.dragPosX = e.originalEvent.pageX;
            }
            if (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Day)
                item.width = item.width < proxy.model.perHourWidth ? proxy.model.perHourWidth : item.width;
            else
                item.width = item.width < proxy.model.perDayWidth ? proxy.model.perDayWidth : item.width;
            item.progressWidth = proxy._getProgressWidth(item.width, item.status);

            proxy._setItemPosition(item);

            if (proxy._taskbarItem && proxy._taskbarItem.childNodes.length > 0) {
                proxy._taskbarItem.removeChild(proxy._taskbarItem.lastChild);
            }
        },

        //handler for progressbar resizing
        _enableProgressResizing: function (e, item) {
            var proxy = this,
                diff,
                radius;
            e.target.style.cursor = "col-resize";
            $(proxy._leftResizer).addClass("gripper");
            $(proxy._rightResizer).addClass("gripper");

            if (proxy._progressResizer) {
                proxy._progressHandle = proxy._progressResizer.firstChild;
                proxy._progressHandleChild = proxy._progressResizer.childNodes[1];
            }

            if (proxy.dragPosX > proxy._mousePosX) {
                proxy._mousePosX = proxy.dragPosX - proxy._mousePosX;
                if (item.left > 0) {
                    item.progressWidth -= proxy._mousePosX;
                }
            }
            else {
                proxy._mousePosX -= proxy.dragPosX;
                item.progressWidth += proxy._mousePosX;
            }
            if (e.originalEvent.pageX == 0) {
                this.dragPosX = e.originalEvent.targetTouches[0].pageX;
            }
            else {
                this.dragPosX = e.originalEvent.pageX;
            }
            item.progressWidth = item.progressWidth > item.width ? item.width : item.progressWidth;
            item.progressWidth = item.progressWidth < 0 ? 0 : item.progressWidth;

            diff = item.width - item.progressWidth;

            if (diff <= 4) {
                radius = 4 - diff;
            }
            else
                radius = 0;

            $(proxy._progressbarItem).css({
                "width": (item.progressWidth) + "px",
                "left": (item.left) + "px",
                "border-top-right-radius": radius + "px",
                "border-bottom-right-radius": radius + "px"
            });
            $(proxy._progressResizer).css({ "left": (item.left + item.progressWidth - 10) + "px" });

            $(proxy._progressHandle).addClass("e-progresshandle");
            $(proxy._progressHandleChild).addClass("e-progresshandleafter");
        },


        //handler for right resizing taskbar
        _enableRightResizing: function (e, item) {

            var proxy = this;
            e.target.style.cursor = "w-resize";

            $(proxy._leftResizer).addClass("gripper");
            $(proxy._rightResizer).addClass("gripper");

            if (proxy.dragPosX > proxy._mousePosX) {
                proxy._mousePosX = proxy.dragPosX - proxy._mousePosX;
                if (item.left > 0) {
                    item.width -= proxy._mousePosX;
                }
            } else {
                proxy._mousePosX -= proxy.dragPosX;
                item.width += proxy._mousePosX;
            }
            if (e.originalEvent.pageX == 0) {
                this.dragPosX = e.originalEvent.targetTouches[0].pageX;
            }
            else {
                this.dragPosX = e.originalEvent.pageX;
            }

            if (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Day)
                item.width = item.width < proxy.model.perHourWidth ? proxy.model.perHourWidth : item.width;
            else
                item.width = item.width < proxy.model.perDayWidth ? proxy.model.perDayWidth : item.width;

            item.progressWidth = proxy._getProgressWidth(item.width, item.status);

            $(proxy._taskbarItem).css({ "left": (item.left) + "px", "width": (item.width) + "px" });
            $(proxy._progressbarItem).css({ "width": (item.progressWidth) + "px", "left": (item.left) + "px" });
            $(proxy._rightResizer).css({ "left": (item.left + item.width - 12) + "px" });
            $(proxy._progressResizer).css({ "left": (item.left + item.progressWidth - 10) + "px" });
            $(proxy._tasknameContainer).css({ "left": (item.left) + "px", "width": (item.width) + "px" });

            $(proxy._leftConnectorPoint).css({ "left": (item.left - 10) + "px" });
            $(proxy._rightConnectorPoint).css({ "left": (item.left + item.width) + "px" });

            if (proxy._taskbarItem && proxy._taskbarItem.childNodes.length > 0) {
                proxy._taskbarItem.removeChild(proxy._taskbarItem.lastChild);
            }
        },


        //Handler for dragging taskbar
        _enableDragging: function (e, item) {
            var proxy = this;
            e.target.style.cursor = "move";

            if ($(e.target.parentNode).hasClass("e-parentContainer")) {
                proxy._allowExpandCollapse = false;
            }

            if (this.dragPosX > proxy._mousePosX) {
                proxy._mousePosX = proxy.dragPosX - proxy._mousePosX;
                if (item.left > 0) {
                    item.left -= proxy._mousePosX;
                }
            } else {
                proxy._mousePosX -= proxy.dragPosX;
                item.left += proxy._mousePosX;
            }

            if (e.originalEvent.pageX == 0) {
                this.dragPosX = e.originalEvent.targetTouches[0].pageX;
            }
            else {
                this.dragPosX = e.originalEvent.pageX;
            }
            item.left = item.left < 0 ? 0 : item.left;

            $(proxy._progressbarItem).css({ "left": (item.left) + "px" });
            $(proxy._taskbarItem).css({ "left": (item.left) + "px" });
            $(proxy._rightResizer).css({ "left": (item.left + item.width - 12) + "px" });
            $(proxy._leftResizer).css({ "left": (item.left + 2) + "px" });
            $(proxy._progressResizer).css({ "left": (item.left + item.progressWidth - 10) + "px" });
            $(proxy._tasknameContainer).css({
                "left": (item.left) + "px",
                "width": (item.width) + "px"
            });

            $(proxy._leftConnectorPoint).css({ "left": (item.left-10) + "px" });
            $(proxy._rightConnectorPoint).css({ "left": (item.left + item.width) + "px" });

            if (proxy._taskbarItem && proxy._taskbarItem.childNodes.length > 0) {
                proxy._taskbarItem.removeChild(proxy._taskbarItem.lastChild);
            }
        },


        //Append tooltip while editing taskbar
        _appendTooltip: function (target, index) {

            var proxy = this, tooltipElement, tooltiptable, tooltipbody,
                $target = $(target),
                item = proxy._currentViewData[index],
                columnHeaderTexts = proxy.model.columnHeaderTexts;

            if (item != null) {
                if ((proxy._currMousePosX + 150) > proxy._windowWidth) {
                    proxy._currMousePosX -= (proxy._currMousePosX + 150) - proxy._windowWidth;
                }

                var div = $target[0];

                if ($(div).hasClass("e-parentContainer") || $(div).hasClass("e-childContainer")) {
                    proxy._editingContainer = div;
                    proxy._leftResizer = proxy._editingContainer.childNodes[0];
                    proxy._taskbarItem = proxy._editingContainer.childNodes[1];
                    proxy._progressbarItem = proxy._editingContainer.childNodes[2];
                    proxy._progressResizer = proxy._editingContainer.childNodes[3];
                    proxy._rightResizer = proxy._editingContainer.childNodes[4];
                }

                //Don't need to display the drag tooltip in Parent Taskbar
                if (this.model.enableTaskbarDragTooltip && (!$target.hasClass('e-parentContainer'))) {

                    if (this._progressResizing == true) {

                        proxy._$ganttChartContainer[0].style.cursor = "col-resize";

                        tooltiptable = ej.buildTag("table.e-tooltiptable", "", {}, { 'cellspacing': '2px', 'cellpadding': '2px' });
                        tooltipbody = ej.buildTag("tbody", "", {}, {});
                        tooltipbody[0].innerHTML = "<tr><td>" + columnHeaderTexts["status"] + " : " + item.status + "%</td></tr>";
                        tooltiptable.append(tooltipbody);
                        if (proxy.model.progressbarTooltipTemplate) {
                            proxy._progressBarTooltipID = ej.buildTag("div.e-progressbartooltip#progressbartooltip" + proxy._id + "", "",
                              {
                                  "top": (proxy._currMousePosY - 95) + "px",
                                  "left": (proxy._currMousePosX) + "px",
                                  'position': 'absolute',
                                  'z-index': '6'
                              }, {});
                            //proxy.tooltipState = "editingTemplateID";
                            var tooltipbody = ej.buildTag("tbody", $.render[proxy._id + "progressbarTooltipTemplate"](item), {}, {});
                            proxy._progressBarTooltipID[0].innerHTML = "<table>" + tooltipbody[0].innerHTML + "</table>";
                        }
                        else if (proxy.model.progressbarTooltipTemplateId) {
                            proxy._progressBarTooltipID = ej.buildTag("div.e-progressbartooltip#progressbartooltip" + proxy._id + "", "",
                                    {
                                        "top": (proxy._currMousePosY - 95) + "px",
                                        "left": (proxy._currMousePosX) + "px",
                                        'position': 'absolute',
                                        'z-index': '6'
                                    }, {});

                            //proxy.tooltipState = "editingTemplate";
                            var tooltipbody = ej.buildTag("tbody", $.render[proxy._id + "progressbarTooltipTemplate"](item), {}, {});
                            proxy._progressBarTooltipID[0].innerHTML = "<table>" + tooltipbody[0].innerHTML + "</table>";
                        }
                        else {
                            proxy._progressBarTooltipID = ej.buildTag("div.e-progressbartooltip#progressbartooltip" + proxy._id + "",
                                tooltiptable,
                                {
                                    "top": (proxy._currMousePosY - 65) + "px",
                                    "left": proxy._currMousePosX + "px",
                                    'position': 'absolute',
                                    'z-index': '6'
                                }, { 'onselectstart': 'return false' });
                        }
                        if (proxy._progressBarTooltipID) {
                            $(document.body).append(proxy._progressBarTooltipID);
                        }
                    }
                    // for apend tooltip for connector line
                    else if (this._editPredecessor === true && proxy.model.enablePredecessorEditing) {
                        if (proxy._predecessorTooltip === null) {
                            proxy._predecessorTooltip = ej.buildTag("div.e-tooltipganttpredecessor#predecessortooltip" + proxy._id + "",
                                      "",
                                      {
                                          "top": (proxy._currMousePosY + 10) + "px",
                                          "left": (proxy._currMousePosX + 10) + "px",
                                          'position': 'absolute',
                                          'z-index': '6'
                                      }, { 'onselectstart': 'return false' });
                            tooltiptable = ej.buildTag("table.e-tooltiptable", "", {}, { 'cellspacing': '2px', 'cellpadding': '2px' });
                            tooltipbody = ej.buildTag("tbody", "", {}, {});
                            tooltipbody[0].innerHTML = "<tr><td class='e-predecessor-false'></td><td >From:</td><td class='e-tooltiptaskname'>" + item.taskName + "</td><td>" + proxy._prevItem.predecessorTarget + "</td> </tr>" +
                                "<tr><td></td><td>To:</td><td class='e-tooltiptaskname'></td><td></td></tr>";
                            tooltiptable.append(tooltipbody);
                            proxy._predecessorTooltip.append(tooltiptable);
                            $(document.body).append(proxy._predecessorTooltip);

                            //   proxy._$bodyContent.append(proxy._predecessorTooltip);
                        }
                    }
                    else if (proxy._leftResizing == true || proxy._rightResizing == true || proxy._allowDragging == true)
                    {
                    if (proxy._leftResizing == true) {
                        proxy._$ganttChartContainer[0].style.cursor = "e-resize";

                        tooltipElement = {
                            ttipstartDate: item.startDate,
                            ttipduration: item.duration,
                        };
                    } else if (proxy._rightResizing == true) {

                        proxy._$ganttChartContainer[0].style.cursor = "w-resize";

                        tooltipElement = {
                            ttipendDate: item.endDate,
                            ttipduration: item.duration,
                        };
                    } else if (proxy._allowDragging == true) {
                        proxy._$ganttChartContainer[0].style.cursor = "move";

                        tooltipElement = {
                            ttipstartDate: item.startDate,
                            ttipendDate: item.endDate,
                        };
                    }


                    tooltiptable = ej.buildTag("table.e-tooltiptable", "", {}, { 'cellspacing': '2px', 'cellpadding': '2px' });

                    if (proxy.model.taskbarEditingTooltipTemplate) {
                        proxy._taskbarEditingTooltipID = ej.buildTag("div.e-editingtooltip#editingtooltip" + proxy._id + "", "",
                           {
                               "top": (proxy._currMousePosY - 95) + "px",
                               "left": (proxy._currMousePosX) + "px",
                               'position': 'absolute',
                               'z-index': '6'
                           }, {});
                        proxy.tooltipState = "editingTemplateID";
                        var tooltipbody = ej.buildTag("tbody", $.render[proxy._id + "editingTooltipTemplate"](item), {}, {});
                        proxy._taskbarEditingTooltipID[0].innerHTML = "<table>" + tooltipbody[0].innerHTML + "</table>";
                    }
                    else if (proxy.model.taskbarEditingTooltipTemplateId) {
                        proxy._taskbarEditingTooltipID = ej.buildTag("div.e-editingtooltip#editingtooltip" + proxy._id + "", "",
                                {
                                    "top": (proxy._currMousePosY - 95) + "px",
                                    "left": (proxy._currMousePosX) + "px",
                                    'position': 'absolute',
                                    'z-index': '6'
                                }, {});

                        proxy.tooltipState = "editingTemplate";
                        var tooltipbody = ej.buildTag("tbody", $.render[proxy._id + "editingTooltipTemplate"](item), {}, {});
                        proxy._taskbarEditingTooltipID[0].innerHTML = "<table>" + tooltipbody[0].innerHTML + "</table>";
                    }

                    else {
                        proxy.tooltipState = "";
                        if (tooltipElement) {
                            tooltipbody = ej.buildTag("tbody", $.render[proxy._id + "editingTooltipTemplate"](tooltipElement), {}, {});
                            tooltiptable.append(tooltipbody);
                        }

                        proxy._taskbarEditingTooltipID = ej.buildTag("div.e-editingtooltip#editingtooltip" + proxy._id + "", tooltiptable,
                            {
                                "top": (proxy._currMousePosY - 95) + "px",
                                "left": (proxy._currMousePosX) + "px",
                                'position': 'absolute',
                                'z-index': '6'
                            }, {});
                    }
                    if (proxy._taskbarEditingTooltipID) {
                        $(document.body).append(proxy._taskbarEditingTooltipID);
                    }
                }
                }
            }
        },

        _setItemPosition: function (item) {
            var proxy = this;
            $(proxy._leftResizer).css({ "left": (item.left + 2) + "px" });
            $(proxy._rightResizer).css({ "left": (item.left + item.width - 12) + "px" });
            $(proxy._taskbarItem).css({
                "left": (item.left) + "px",
                "width": (item.width) + "px"
            });
            $(proxy._progressbarItem).css({
                "left": (item.left) + "px",
                "width": (item.progressWidth) + "px"
            });
            $(proxy._progressResizer).css({ "left": (item.left + item.progressWidth - 10) + "px" });
            $(proxy._tasknameContainer).css({
                "left": (item.left) + "px",
                "width": (item.width) + "px"
            });

            $(proxy._leftConnectorPoint).css({ "left": (item.left - 10) + "px" });
            $(proxy._rightConnectorPoint).css({ "left": (item.left + item.width) + "px" });


        },

        //returns the custom template for tooltip
        _getTemplate: function (template) {
            if (typeof (template) != "object") {
                var parser = $.parseHTML(this.model.tooltipTemplate);
                return parser[0];
            } else {
                var markup = $(template)[0].innerHTML;
                parser = $.parseHTML(markup);
                return parser[1];
            }
        },


        //Handles the mousemove after mousedown event
        _updateOnmouseMove: function (e) {

            var proxy = this, args = {}, posy,
                $target = (proxy._editingTarget) ? proxy._editingTarget : null,
                $ganttGridRows = proxy.getGanttChartRows(),
                row = ($target) ? $target.closest('tr') : null,
                recordIndexr = $ganttGridRows.index(row),
                item = proxy._editingItem,
                div = ($target) ? $target[0].parentNode : null;

            if ($(div).hasClass("progressbarresizer-right") || $(div).hasClass("e-gantt-childtaskbar-progress")) {
                div = div.parentNode;
            }

            if (item != null) {

                args.editingFields = {
                    startdate: item.startDate,
                    enddate: item.endDate,
                    progress: item.status,
                    duration: item.duration
                };
                args.rowData = { rowData: item };

                proxy._taskbarEditing(args);

                if (!args.cancel) {

                    if (!e) e = window.event;

                    if (ej.browserInfo().name == "msie" && ej.browserInfo().version < 9) {
                        e.originalEvent.pageX = e.originalEvent.screenX;
                        e.originalEvent.pageY = e.originalEvent.screenY;
                    }

                    if (e.originalEvent.pageX || e.originalEvent.pageY) {
                        proxy._mousePosX = e.originalEvent.pageX;
                        posy = e.originalEvent.pageY;
                    } else if (e.originalEvent.clientX || e.originalEvent.clientY) {
                        proxy._mousePosX = e.originalEvent.clientX + document.body.scrollLeft
                            + document.documentElement.scrollLeft;
                        posy = e.originalEvent.clientY + document.body.scrollTop
                            + document.documentElement.scrollTop;
                    }
                    else if (e.originalEvent.touches[0].pageX || e.originalEvent.touches[0].pageY) {
                        proxy._mousePosX = e.originalEvent.targetTouches[0].pageX;
                        posy = e.originalEvent.targetTouches[0].pageY;
                    }

                    if ($target.hasClass("e-gantt-milestone")) {
                        if ($(row).hasClass("e-editmode")) {
                            this._editMilestone(e);
                        }
                    } else {

                        if ($(div).hasClass("e-childContainer")) {
                            proxy._editingContainer = div;
                            proxy._leftResizer = proxy._editingContainer.childNodes[1]; //[0]
                            proxy._taskbarItem = proxy._editingContainer.childNodes[2];//[1]
                            proxy._progressbarItem = proxy._editingContainer.childNodes[3];//[2]
                            proxy._progressResizer = proxy._editingContainer.childNodes[4];//[3]
                            proxy._rightResizer = proxy._editingContainer.childNodes[5];//[4]
                            proxy._tasknameContainer = proxy._editingContainer.childNodes[5];//task name contaner wrong
                            if (proxy.model.predecessorMapping && proxy.model.enablePredecessorEditing) {
                                proxy._leftConnectorPoint = div.childNodes[0];
                                proxy._rightConnectorPoint = div.childNodes[6];
                                $(proxy._leftConnectorPoint).addClass("e-connectorpoint-hover");
                                $(proxy._rightConnectorPoint).addClass("e-connectorpoint-hover");
                            }

                        }

                        if ($(row).hasClass("e-editmode") &&
                            (($(div).hasClass("e-parentContainer")) || $(div).hasClass("e-gantt-milestone-container") || $(div).hasClass("e-childContainer"))) {

                            if (proxy._leftResizing == true) {
                                proxy._enableLeftResizing(e, item);
                                proxy._updateEditedItem(item, "leftResizing");

                            } else if (proxy._progressResizing == true
                                && proxy.model.enableProgressBarResizing
                                && proxy.model.progressMapping) {
                                proxy._enableProgressResizing(e, item);
                                proxy._updateEditedItem(item, "progressResizing");

                            } else if (proxy._rightResizing == true) {
                                proxy._enableRightResizing(e, item);
                                proxy._updateEditedItem(item, "rightResizing");

                            } else if (proxy._allowDragging == true) {
                                proxy._enableDragging(e, item);
                                proxy._updateEditedItem(item, "dragging");
                            }

                            //for predecessor , draw false line move the tooltip
                            else if (proxy._editPredecessor == true) {
                                proxy._drawFalseLine(e, item);
                            }
                        }
                    }
                    proxy._clearTooltip();
                    proxy._appendTooltip($target, recordIndexr);
                }
            }
        },


        //Handler for milestone editing
        _editMilestone: function (e) {

            var proxy = this,
                $target = proxy._editingTarget,
                div = $target[0].parentNode,
                $ganttGridRows = proxy.getGanttChartRows(),
                row = $target.closest('tr'),
                recordIndexr = $ganttGridRows.index(row),
                item = proxy._editingItem;

            if (item != null) {

                if (!e) e = window.event;
                if (e.originalEvent.pageX || e.originalEvent.pageY) {
                    proxy._mousePosX = e.originalEvent.pageX;
                } else if (e.originalEvent.clientX || e.originalEvent.clientY) {
                    proxy._mousePosX = e.originalEvent.clientX + document.body.scrollLeft
                        + document.documentElement.scrollLeft;
                }
                else if (e.originalEvent.touches[0].pageX || e.originalEvent.touches[0].pageY) {
                    proxy._mousePosX = e.originalEvent.targetTouches[0].pageX;
                    posy = e.originalEvent.targetTouches[0].pageY;
                }

                e.target.style.cursor = "move";
                if (proxy.dragPosX > proxy._mousePosX) {
                    proxy._mousePosX = proxy.dragPosX - proxy._mousePosX;
                    if (item.left > 0) {
                        item.left -= proxy._mousePosX;
                    }
                } else {
                    proxy._mousePosX -= proxy.dragPosX;
                    item.left += proxy._mousePosX;
                }
                if (e.originalEvent.pageX == 0) {
                    this.dragPosX = e.originalEvent.targetTouches[0].pageX;
                }
                else {
                    this.dragPosX = e.originalEvent.pageX;
                }
                item.left = item.left < 0 ? 0 : item.left;

                $(div).css({ "left": (item.left) + "px" });

                $(proxy._leftConnectorPoint).css({ "left": (item.left - 10) + "px" });
                $(proxy._rightConnectorPoint).css({ "left": (item.left + 24) + "px" });

                proxy._updateEditedItem(item, "dragging");
                proxy._appendTooltip($target, recordIndexr);
            }
        },


        //Updates the edited item's values
        _updateEditedItem: function (ganttRecord, reason) {

            var proxy = this,
                model = proxy.model,
                projectStartDate = ganttRecord._getFormatedDate(model.projectStartDate, model.dateFormat),
                projectStartDate = ganttRecord._getDateFromFormat(projectStartDate, model.dateFormat),
                projectStartDateHours = ganttRecord._getDateFromFormat(ganttRecord.startDate, model.dateFormat).getHours(),
                projectStartDateMinutes = ganttRecord._getDateFromFormat(ganttRecord.startDate, model.dateFormat).getMinutes(),

                remainDays, day, offset, rem, startDate, endDate;

            switch (reason) {

                case 'dragging':
                    remainDays = ganttRecord.left % model.perDayWidth,
                    day = (ganttRecord.left - remainDays) / model.perDayWidth,
                    offset = 0;
                    if (remainDays > 0 && (model.workingTimeScale != ej.Gantt.workingTimeScale.TimeScale24Hours
                        && model.workingTimeScale != ej.Gantt.workingTimeScale.TimeScale24Hours)) {
                        offset = remainDays >= model.perDayWidth / 2 ? 1 : 0;
                    }
                    if (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Day ||
                        (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Week && model.dateFormat.indexOf("hh") != -1)) {
                        var remainingHours = Math.round(remainDays / (model.perDayWidth / 24));//hour calculation
                        projectStartDate.setDate(projectStartDate.getDate() + day + offset);
                        if (model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale24Hours)
                            projectStartDate.setHours(remainingHours);
                        else
                            projectStartDate.setHours(8);
                    }
                    else if (model.dateFormat.indexOf("hh:") &&
                       model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale8Hours) {
                        var remainingHours = Math.round(remainDays / (model.perDayWidth / 9));
                        projectStartDate.setHours(8 + remainingHours);
                        projectStartDate.setDate(projectStartDate.getDate() + day + offset);
                    }

                    ganttRecord.startDate = ganttRecord._calculateFormatedDate(projectStartDate, model.dateFormat);
                    ganttRecord._calculateEndDate(model.includeWeekend, model.holidays, model, model.perDayWidth);
                   
                    //update on dataSource
                    if (model.startDateMapping)
                        ganttRecord.item[model.startDateMapping] = ganttRecord.startDate;
                    if (model.endDateMapping)
                        ganttRecord.item[model.endDateMapping] = ganttRecord.endDate;

                    break;

                case 'leftResizing':
                    remainDays = ganttRecord.left % model.perDayWidth,
                    day = (ganttRecord.left - remainDays) / model.perDayWidth,
                    offset = 0;
                    if (remainDays > 0 && (model.workingTimeScale != ej.Gantt.workingTimeScale.TimeScale24Hours
                        && model.workingTimeScale != ej.Gantt.workingTimeScale.TimeScale24Hours)) {// 
                        offset = remainDays >= model.perDayWidth / 2 ? 1 : 0;
                    }

                    var remainingHours = Math.round(remainDays / (model.perDayWidth / 24));//hour calculation

                    projectStartDate.setDate(projectStartDate.getDate() + day + offset);

                    if (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Day ||
                        (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Week && model.dateFormat.indexOf("hh") != -1)) {
                        if (model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale24Hours)
                            projectStartDate.setHours(remainingHours);
                        else
                            projectStartDate.setHours(8);
                    }
                    else if (model.dateFormat.indexOf("hh:") &&
                        model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale8Hours) {
                        var remainingHours = Math.round(remainDays / (model.perDayWidth / 9));
                        projectStartDate.setHours(8 + remainingHours);
                    }


                    //if (projectStartDate < new Date(ganttRecord.endDate)) {
                    ganttRecord.startDate = ganttRecord._calculateFormatedDate(projectStartDate, model.dateFormat);
                 

                    ganttRecord._calculateDuration(projectStartDate, new Date(ganttRecord.endDate),
                        model.includeWeekend, model.holidays, false,model);
                    //}
                    if (Globalize.parseDate(ganttRecord.startDate, this.model.dateFormat).getTime() == Globalize.parseDate(ganttRecord.endDate, this.model.dateFormat).getTime()
                        && ej.isNullOrUndefined(ganttRecord.isMilestone) && ganttRecord.isMilestone == false && ganttRecord.duration == 0) {
                        ganttRecord.duration = 1;
                    }

                    //update on dataSource
                    if (model.startDateMapping)
                        ganttRecord.item[model.startDateMapping] = ganttRecord.startDate;
                    if(model.durationMapping)
                        ganttRecord.item[model.durationMapping] = ganttRecord.duration;

                    break;

                case 'rightResizing':
                    day = ganttRecord.width / model.perDayWidth,
                    rem = ganttRecord.width % model.perDayWidth,
                    startDate = new Date(ganttRecord.startDate);
                    offset = 0;

                    if (rem > 0 && (model.workingTimeScale != "TimeScale24Hours"
                      && model.workingTimeScale != "TimeScale24Hours")) {
                        offset = rem >= (model.perDayWidth / 2) ? 1 : 0;
                    }

                    var totalLength = ganttRecord.left + ganttRecord.width;
                    var remainingLength = totalLength % model.perDayWidth;

                    var remainingHours = Math.round(remainingLength / (model.perDayWidth / 24));//hour calculation


                    if ((model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Day
                        && model.dateFormat.indexOf("hh") == -1)) {

                        var startDateHour = (ganttRecord.left % model.perDayWidth) / model.perHourWidth;
                        var remainingHourDiff = Math.round(remainingLength % (model.perHourWidth));

                        endDate = day < 1 ? ganttRecord._dateUpdate(startDate, 0, (remainingHourDiff)) :
                            ganttRecord._dateUpdate(startDate, Math.ceil(day - 1 + offset), remainingHourDiff);

                        startDate.setHours(startDateHour);
                    }

                    else if ((model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Week
                    && model.dateFormat.indexOf("hh") != -1)) {
                        if (model.durationUnit == ej.Gantt.DurationUnit.Hour) {
                            var startDateHour = Math.round((ganttRecord.left % model.perDayWidth) / (model.perDayWidth / 24));
                            var remainingHourDiff = Math.round(totalLength / (model.perDayWidth / 24));
                            remainingHourDiff -= startDateHour;
                            endDate = ganttRecord._dateUpdate(startDate, 0, remainingHourDiff);
                        }
                        else {
                            var dayCount = (day - 1) + offset;
                            dayCount = Math.round(dayCount);
                            endDate = ganttRecord._dateUpdate(startDate, dayCount, 0);
                        }

                    }


                    else if ((model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Day
                        && model.dateFormat.indexOf("hh") != -1)) {

                        var startDateHour = (ganttRecord.left % model.perDayWidth) / model.perHourWidth;
                        var remainingHourDiff = Math.round(totalLength / (model.perHourWidth));
                        remainingHourDiff -= startDateHour;

                        endDate = ganttRecord._dateUpdate(startDate, 0, (remainingHourDiff));

                        startDate.setHours(startDateHour);
                    }

                    else
                        endDate = ganttRecord._dateUpdate(startDate, day - 1 + offset, 0);
                    
                    if (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Day ||
                        (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Week && model.dateFormat.indexOf("hh") != -1)) {
                        if (model.workingTimeScale != ej.Gantt.workingTimeScale.TimeScale24Hours) {
                            if (model.durationUnit == ej.Gantt.DurationUnit.Hour) {
                                endDate.setHours(Math.round(remainingHours));
                            }
                            else
                                endDate.setHours(17);
                        }
                    }
                    else if (model.dateFormat.indexOf("hh:") &&
                       model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale8Hours) {
                        var remainingHours = Math.round(remainingLength / (model.perDayWidth / 9));
                        endDate.setHours(Math.round(8 + remainingHours));
                    }
                    ganttRecord.endDate = ganttRecord._calculateFormatedDate(endDate, model.dateFormat);

                    if (model.holidays && model.holidays.length) {
                        var holidayIndex = 0,
                            holidayslength = model.holidays.length,
                            holiday;
                        for (holidayIndex = 0; holidayIndex < holidayslength; holidayIndex++) {
                            holiday = new Date(model.holidays[holidayIndex]);
                            if (endDate === holiday) {
                                endDate.setDate(endDate.getDate() - 1);
                            }
                        }
                    }
                    if (this.model.includeWeekend == false) {
                        if (endDate.getDay() == 0)
                            endDate.setDate(endDate.getDate() - 2);
                        else if (endDate.getDay() == 6)
                            endDate.setDate(endDate.getDate() - 1);
                    }
                    ganttRecord._calculateDuration(startDate, endDate, model.includeWeekend, model.holidays, false, model);

                    //update on datasource
                    if(model.endDateMapping)
                        ganttRecord.item[model.endDateMapping] = ganttRecord.endDate;
                    if (model.durationMapping)
                        ganttRecord.item[model.durationMapping] = ganttRecord.duration;


                    break;

                case 'progressResizing':
                    ganttRecord.status = proxy._getProgressPercent(ganttRecord.width, ganttRecord.progressWidth);
                    if (model.progressMapping)
                        ganttRecord.item[model.progressMapping] = ganttRecord.status;
                    break;
            }
        },


        //false line implementation 
        _drawFalseLine: function (e, item) {

            var proxy = this,

              x1 = proxy._connectorPointX;
              y1 = proxy._connectorPointY;

              x2 = e.pageX - proxy._$bodyContent.offset().left,
              y2 = e.pageY - proxy._$bodyContent.offset().top;

            //var sy=proxy._$bodyContainer.ejScroller("option", "scrollTop");
            //var sx = proxy._$bodyContainer.ejScroller("option", "scrollLeft");

            var length = Math.sqrt((x1 - x2) * (x1 - x2) + (y1 - y2) * (y1 - y2));
            var angle = Math.atan2(y2 - y1, x2 - x1) * 180 / Math.PI;
            var transform = 'rotate(' + angle + 'deg)';

            proxy._falseLine && proxy._falseLine.remove();

                proxy._falseLine = ej.buildTag("div.e-gantt-falseLine#ganttfalseline" + proxy._id, "", {}, {});
                proxy._falseLine.css({
                    'transform-origin': '0% 100%',
                    'right':'auto',
                    'position': 'absolute',
                    'transform': transform,
                    '-ms-transform':transform, /* IE 9 */
                    '-moz-transform':transform, /* Firefox */
                    '-webkit-transform':transform, /* Safari and Chrome */
                    '-o-transform':transform, /* Opera */
                    'border-top-width': '2px',
                    'border-top-style': 'dashed',
                    'z-index': '5'
                }).width(length - 3).offset({ left: x1, top: y1 });

                if (!(ej.browserInfo().name == "msie" && ej.browserInfo().version < 9)) {
                    proxy._$bodyContent.append(proxy._falseLine);
                }

            //Change the position of predecesspr tooltip
                if (((e.pageX + proxy._predecessorTooltip.width() + 30) > proxy._windowWidth)) {
                    var pos =e.pageX - proxy._predecessorTooltip.width() - 10;
                    proxy._predecessorTooltip.css('left', ((pos) + 'px'));
                }
                else {
                    proxy._predecessorTooltip.css('left', (e.pageX+10) + 'px');
                }
                if (((e.pageY + proxy._predecessorTooltip.height() + 30) > proxy._windowHeight)) {
                    var pos = e.pageY - (proxy._predecessorTooltip.height()*2);
                    proxy._predecessorTooltip.css('top', ((pos) + 'px'));
                } else {
                    proxy._predecessorTooltip.css('top', (e.pageY + 10) + 'px');
                }
               
               
        },

        _mouseOverTooltip: function () {

            $(proxy._mouseOverTooltip).remove();

            if (this._mouseDown == false) {
                $(proxy._leftResizerGripper).removeClass("gripper");
                $(proxy._rightResizerGripper).removeClass("gripper");

                if (proxy.model.progressMapping) {
                    $(proxy._progressHandle).removeClass("e-progresshandle");
                    $(proxy._progressHandleChild).removeClass("e-progresshandleafter");
                }
            }
        },

        _mouseLeave: function () {

            var proxy = this;
            $(".e-tooltipgantt").remove();
            $(".progressbarresizer-right").css({ "background-image": "none" });
            $(proxy._mouseOverTooltip).remove();

            if (this._mouseDown == false) {
                $(proxy._leftResizerGripper).removeClass("gripper");
                $(proxy._rightResizerGripper).removeClass("gripper");

                if (proxy.model.progressMapping) {
                    $(proxy._progressHandle).removeClass("e-progresshandle");
                    $(proxy._progressHandleChild).removeClass("e-progresshandleafter");
                }

                if (proxy.model.predecessorMapping && proxy.model.enablePredecessorEditing) {

                    $(proxy._leftConnectorPoint).removeClass('e-connectorpoint-hover');
                    $(proxy._rightConnectorPoint).removeClass('e-connectorpoint-hover');
                    proxy._leftConnectorPoint = null;
                    proxy._rightConnectorPoint = null;
                }
            }
        },

        _mouseHover: function (e) {

            var $target = $(e.target), proxy = this,
                posx = 0,
                posy = 0,
                $ganttChartRows = proxy.getGanttChartRows(),
                row = $target.closest('tr'),
                div = $target[0].parentNode,
                progressHandler,
                recordIndexr = $ganttChartRows.index(row),
                item = proxy._currentViewData[recordIndexr],
                tooltipElement, tooltiptable, tooltipbody;

            if (proxy._rightResizing == false && proxy._leftResizing == false &&
                proxy._progressResizing == false && proxy._mouseDown == false) {

                if ($target.hasClass('e-gantt-parenttaskbar-innerdiv')
                    || $target.hasClass('e-gantt-parenttaskbar-progress')) {
                }
                else if (proxy.model.allowGanttChartEditing) {
                    e.target.style.cursor = "move";
                }


                if (e.type == "mouseenter" || e.type == "mousemove") {

                    if (!e) e = window.event;
                    if (e.originalEvent.pageX || e.originalEvent.pageY) {
                        posx = e.originalEvent.pageX;
                        posy = e.originalEvent.pageY;
                    }
                    else if (e.originalEvent.clientX || e.originalEvent.clientY) {
                        posx = e.originalEvent.clientX + document.body.scrollLeft
                            + document.documentElement.scrollLeft;
                        posy = e.originalEvent.clientY + document.body.scrollTop
                            + document.documentElement.scrollTop;
                    }
                    if ($(div).hasClass("e-childContainer") && proxy.model.allowGanttChartEditing) {
                        proxy._leftResizerGripper = div.childNodes[1],//[0]  // New div is added for drag points so other elemnts are changed
                        proxy._rightResizerGripper = div.childNodes[5];//[4]
                        progressHandler = div.childNodes[4];//[3]
                        proxy._progressHandle = progressHandler.firstChild;
                        proxy._progressHandleChild = progressHandler.childNodes[1];//[1]

                        $(proxy._leftResizerGripper).addClass("gripper");
                        $(proxy._rightResizerGripper).addClass("gripper");

                        if (proxy.model.progressMapping) {
                            $(proxy._progressHandle).addClass("e-progresshandle");
                            $(proxy._progressHandleChild).addClass("e-progresshandleafter");
                        }
                    }

                    //Before Mouse Down  , Apply style for drag points in child cotainer and miles stone container
                    if ($(div).hasClass("e-childContainer") && proxy.model.predecessorMapping  && proxy.model.allowGanttChartEditing && proxy.model.enablePredecessorEditing) {

                        proxy._leftConnectorPoint = div.childNodes[0];
                        proxy._rightConnectorPoint = div.childNodes[6];
                        $(proxy._leftConnectorPoint).addClass("e-connectorpoint-hover");
                        $(proxy._rightConnectorPoint).addClass("e-connectorpoint-hover");
                    }
                    else if ($(div).hasClass("e-gantt-milestone") && proxy.model.predecessorMapping && proxy.model.allowGanttChartEditing && proxy.model.enablePredecessorEditing) {
                        var milesStoneContainer = div.parentNode;
                        proxy._leftConnectorPoint = milesStoneContainer.childNodes[0];
                        proxy._rightConnectorPoint = milesStoneContainer.childNodes[2];
                        $(proxy._leftConnectorPoint).addClass("e-connectorpoint-hover");
                        $(proxy._rightConnectorPoint).addClass("e-connectorpoint-hover");
                    }


                    if (item && proxy.model.enableTaskbarTooltip) {
                        tooltipElement = {
                            ttipstartDate: item.startDate,
                            ttipendDate: item.endDate,
                            ttipduration: item.duration,
                            ttipprogress: item.status,
                            ttiptaskname: item.taskName,
                        };

                        tooltiptable = ej.buildTag("table.e-tooltiptable", "", {}, { 'cellspacing': '5' });
                      

                        if (proxy.model.tooltipTemplate == null && proxy.model.tooltipTemplateId == null) {
                            proxy.tooltipState = "";
                            tooltipbody = ej.buildTag("tbody", $.render[proxy._id + "tooltipTemplate"](tooltipElement), {}, {});
                            tooltiptable.append(tooltipbody);
                            proxy._mouseOverTooltip = ej.buildTag("div.e-tooltipgantt#tooltipgantt" + proxy._id + "", tooltiptable,
                                { "top": (posy + 10) + "px", "left": (posx + 15) + "px", 'position': 'absolute', 'z-index': '6', 'border-radius': '5px' }, {});

                            proxy._mouseOverTooltip.innerHTML = "<table>" + tooltiptable[0].innerHTML + "</table>";
                            $(document.body).append(proxy._mouseOverTooltip);
                        }
                        else if (proxy.model.tooltipTemplate) {
                            proxy._mouseOverTooltip = ej.buildTag("div.e-tooltipgantt#tooltipgantt" + proxy._id + "","",
                                { "top": (posy + 10) + "px", "left": (posx + 15) + "px", 'position': 'absolute', 'z-index': '6', 'border-radius': '5px' }, {});
                            $(document.body).append(proxy._mouseOverTooltip);

                            proxy.tooltipState = "Template";
                            var tooltipbody = ej.buildTag("tbody", $.render[proxy._id + "tooltipTemplate"](item), {}, {});
                            proxy._mouseOverTooltip[0].innerHTML = "<table>" + tooltipbody[0].innerHTML + "</table>";
                        }
                        else if (proxy.model.tooltipTemplateId) {
                            proxy._mouseOverTooltip = ej.buildTag("div.e-tooltipgantt#tooltipgantt" + proxy._id + "", "",
                                { "top": (posy + 10) + "px", "left": (posx + 15) + "px", 'position': 'absolute', 'z-index': '6', 'border-radius': '5px' }, {});
                            $(document.body).append(proxy._mouseOverTooltip);

                            proxy.tooltipState = "TemplateID";
                            var tooltipbody = ej.buildTag("tbody", $.render[proxy._id + "tooltipTemplate"](item), {}, {});
                            proxy._mouseOverTooltip[0].innerHTML = "<table>" + tooltipbody[0].innerHTML + "</table>";
                        }
                        var bodyScrollPosY = $(document).scrollTop();
                        var width = $(proxy._mouseOverTooltip).width();
                        var height = $(proxy._mouseOverTooltip).height();
                        var windowHeight = $(window).height() + bodyScrollPosY;
                        //Reset the tool tip position
                        if ((posx + width + 40) > $(window).width())
                            posx = posx - (width+40)
                        if ((posy + height + 20) > windowHeight)
                            posy = posy - height;
                        $(proxy._mouseOverTooltip).css({
                            "left": (posx + 15) + "px",
                            "top": (posy) + "px",
                            "position": "absolute"
                        });
                        $(proxy._mouseOverTooltip).addClass("customTooltip");
                    }
                }
            }
        },



        _createEditingTooltipTemplate: function () {

            var proxy = this,
                td,
                columnHeaderTexts = proxy.model.columnHeaderTexts,
                helpers = {
                    _getStartDate: proxy._tooltipStartDate,
                    _getEndDate: proxy._tooltipEndDate,
                    _getDuration: proxy._tooltipDuration,
                    _getTaskName: proxy._tooltipTaskName,
                    _getDurationUnit: $.proxy(proxy._getEditDurationUnits, proxy),
                    _getProgress: proxy._tooltipProgress
                },
            editingTemplateId = proxy.model.taskbarEditingTooltipTemplateId,
            editingTemplate = proxy.model.taskbarEditingTooltipTemplate;

            $.views.helpers(helpers);

            
            if (editingTemplateId) {
                var parentTr = $("#" + editingTemplateId)[0].innerHTML;
            }
            else if (editingTemplate) {
                var parentTr = editingTemplate;
            }
            else {
                var parentTr = "<tr class='e-tooltip_rowcell'>";

                td = "{{if ~_getTaskName()}}" +
                    "<td class='e-tooltiptaskname' style='width:40px;text-align:left;' colspan='3';>{{:ttiptaskname}}</td>{{/if}}" +
                    "</tr><tr>" +
                    "{{if ~_getStartDate()}}" +
                    "<td class='e-tooltiptd-alignleft' style='width:30px;white-space:nowrap;'>" + columnHeaderTexts["startDate"] + "</td>" +
                    "<td class='e-tooltiptd-aligncenter' style='width:10px;font-weight:bold;'>:</td>" +
                    "<td class='e-tooltiptd-alignright' style='width:30px;white-space:nowrap;'>{{:ttipstartDate}}</td> {{/if}}" +
                    "</tr><tr>" +
                    "{{if ~_getEndDate()}}" +
                    "<td class='e-tooltiptd-alignleft' style='width:30px;white-space:nowrap;'>" + columnHeaderTexts["endDate"] + "</td>" +
                    "<td class='e-tooltiptd-aligncenter' style='width:10px;font-weight:bold;'>:</td>" +
                    "<td class='e-tooltiptd-alignright' style='width:30px;white-space:nowrap;'>{{:ttipendDate}}</td>{{/if}}" +
                    "</tr><tr>" +
                    "{{if ~_getDuration()}}" +
                    "<td class='e-tooltiptd-alignleft' style='width:30px;white-space:nowrap;'>" + columnHeaderTexts["duration"] + "</td>" +
                    "<td class='e-tooltiptd-aligncenter' style='width:10px;font-weight:bold;'>:</td>" +
                    "<td class='e-tooltiptd-alignright' style='width:30px;white-space:nowrap;'>{{:ttipduration}}  {{: ~_getDurationUnit(#data)}}</td>{{/if}}" +
                    "</tr><tr>" +
                    "{{if ~_getProgress()}}" +
                    "<td class='e-tooltiptd-alignleft' style='width:30px;white-space:nowrap;'>" + columnHeaderTexts["status"] + "</td>" +
                    "<td class='e-tooltiptd-aligncenter' style='width:10px;font-weight:bold;'>:</td>" +
                    "<td class='e-tooltiptd-alignright' style='width:30px;white-space:nowrap;'>{{:ttipprogress}}%</td>{{/if}}";

                parentTr += td;
                parentTr += "</tr>";
            }

            var templates = {};
            templates[proxy._id + "editingTooltipTemplate"] = parentTr;
            $.templates(templates);
        },

        _getEditDurationUnits: function (data) {
            var proxy = this;
            if (proxy.model.durationUnit == ej.Gantt.DurationUnit.Hour)
                return "hours";
            else
                return "days";

        },

        _createProgressbarTooltipTemplate: function () {
            var proxy = this,
                  templateId = proxy.model.progressbarTooltipTemplateId,
            template = proxy.model.progressbarTooltipTemplate;

            if (templateId) {
                var parentTr = $("#" + proxy.model.progressbarTooltipTemplateId)[0].innerHTML;
            }
            else if (proxy.model.progressbarTooltipTemplate) {
                var parentTr = proxy.model.progressbarTooltipTemplate;
            }
            var templates = {};
            templates[proxy._id + "progressbarTooltipTemplate"] = parentTr;
            $.templates(templates);
        },


        //Template to create tooltip
        _createTooltipTemplate: function () {

            var proxy = this,
                td,
                columnHeaderTexts = proxy.model.columnHeaderTexts,
                helpers = {
                    _getStartDate: proxy._tooltipStartDate,
                    _getEndDate: proxy._tooltipEndDate,
                    _getDuration: proxy._tooltipDuration,
                    _getTaskName: proxy._tooltipTaskName,
                    _getProgress: proxy._tooltipProgress,
                    _getDurationUnit: $.proxy(proxy._getDurationUnits, proxy),
                },
                templateId = proxy.model.tooltipTemplateId,
            template = proxy.model.tooltipTemplate;

            $.views.helpers(helpers);

            if (templateId ) {
                var parentTr = $("#" + proxy.model.tooltipTemplateId)[0].innerHTML;
            }
            else if (proxy.model.tooltipTemplate ) {
                var parentTr = proxy.model.tooltipTemplate;
            }
           
            else {
                var parentTr = "<tr class='e-tooltip_rowcell'>";

                td = "{{if ~_getTaskName()}}" +
                    "<td class='e-tooltiptaskname' style='width:40px;text-align:left;' colspan='3';>{{:ttiptaskname}}</td>{{/if}}" +
                    "</tr><tr>" +
                    "{{if ~_getStartDate()}}" +
                    "<td class='e-tooltiptd-alignleft' style='width:30px;white-space:nowrap;'>" + columnHeaderTexts["startDate"] + "</td>" +
                    "<td class='e-tooltiptd-aligncenter' style='width:10px;font-weight:bold;'>:</td>" +
                    "<td class='e-tooltiptd-alignright' style='width:30px;white-space:nowrap;'>{{:ttipstartDate}}</td> {{/if}}" +
                    "</tr><tr>" +
                    "{{if ~_getEndDate()}}" +
                    "<td class='e-tooltiptd-alignleft' style='width:30px;white-space:nowrap;'>" + columnHeaderTexts["endDate"] + "</td>" +
                    "<td class='e-tooltiptd-aligncenter' style='width:10px;font-weight:bold;'>:</td>" +
                    "<td class='e-tooltiptd-alignright' style='width:30px;white-space:nowrap;'>{{:ttipendDate}}</td>{{/if}}" +
                    "</tr><tr>" +
                    "{{if ~_getDuration()}}" +
                    "<td class='e-tooltiptd-alignleft' style='width:30px;white-space:nowrap;'>" + columnHeaderTexts["duration"] + "</td>" +
                    "<td class='e-tooltiptd-aligncenter' style='width:10px;font-weight:bold;'>:</td>" +
                    "<td class='e-tooltiptd-alignright' style='width:30px;white-space:nowrap;'>{{:ttipduration}} {{: ~_getDurationUnit(#data)}}</td>{{/if}}" +
                    "</tr><tr>" +
                    "{{if ~_getProgress()}}" +
                    "<td class='e-tooltiptd-alignleft' style='width:30px;white-space:nowrap;'>" + columnHeaderTexts["status"] + "</td>" +
                    "<td class='e-tooltiptd-aligncenter' style='width:10px;font-weight:bold;'>:</td>" +
                    "<td class='e-tooltiptd-alignright' style='width:30px;white-space:nowrap;'>{{:ttipprogress}}%</td>{{/if}}";

                parentTr += td;
                parentTr += "</tr>";
            }

            var templates = {};
            templates[proxy._id + "tooltipTemplate"] = parentTr;
            $.templates(templates);
        },

        _tooltipTaskName: function () {
            return this.data.ttiptaskname;
        },

        _tooltipProgress: function () {
            return this.data.ttipprogress;
        },

        _tooltipStartDate: function () {
            return this.data.ttipstartDate;
        },

        _tooltipEndDate: function () {
            return this.data.ttipendDate;
        },

        _tooltipDuration: function () {
            return this.data.ttipduration;
        },

        _getDurationUnits: function (data) {
            var proxy = this;
            if (proxy.model.durationUnit == ej.Gantt.DurationUnit.Hour)
                return "hours";
            else
                return "days";

        },

        _cellClickHandler: function (e) {
            var $target = $(e.target),
                $row = $target.closest('tr'),
                proxy = this,
                args = {},
                selectedItem,
                index,
                $ganttGridRows = proxy.getGanttChartRows();

            //proxy._clearContextMenu();
            if (proxy.model.selectedRowIndex !== -1) {

                selectedItem = proxy.model.updatedGanttRecords && proxy.model.updatedGanttRecords[proxy.model.selectedRowIndex];
                args = {
                    rowElement: $row,
                    recordIndex: proxy.model.selectedRowIndex
                };
            }

            if (proxy._trigger('rowSelecting', args))  //check the cancel arguements in rowSelecting event
                return;

            index = $ganttGridRows.index($target.parent());

            if (index == -1) {
                index = $ganttGridRows.index($row);
            }

          
            if (index != -1 && proxy.model.allowSelection) {
                
                selectedItem = proxy._currentViewData[index];
                proxy.model.selectedRowIndex = proxy.model.updatedGanttRecords.indexOf(selectedItem);
                proxy.selectRows(proxy.model.selectedRowIndex);
                args.target = "ejGanttChart";
                
                args.data = selectedItem;
                args.recordIndex = proxy.model.selectedRowIndex;
                proxy._trigger("rowSelected", args);

                if (proxy.prevSelectedItem != null) {
                    proxy.prevSelectedItem.isSelected = false;
                    proxy.model.updatedGanttRecords[proxy.model.selectedRowIndex].isSelected = true;
                }

                proxy.prevSelectedItem = selectedItem;

                proxy.element[0].focus();
            }

        },

        getRowByIndex: function (from, to) {
            try {
                var proxy = this;

                var gridRows = proxy.getGanttChartRows(),
                    $gridRows = $(gridRows),
                    $row = $();

                if (proxy.model.enableVirtualization) {
                    var recordstart = proxy.model.updatedGanttRecords[from];
                    from = proxy._currentViewData.indexOf(recordstart);
                }

                if (ej.isNullOrUndefined(to)) {
                    if (proxy.model.enableVirtualization) {
                        var recordend = proxy.model.updatedGanttRecords[to];
                        to = proxy._currentViewData.indexOf(recordend);
                    }
                    return $(gridRows[from]);
                } else {
                    return $($gridRows.slice(from, to));
                }
            } catch (e) {
                return $();
            }
        },

        selectRows: function (index) {
            var proxy = this,
                $ganttGridRows = proxy.getGanttChartRows(),
                selectedItem;
            if (proxy.model.selectedItem)
            {
                proxy.model.selectedItem.isSelected = false;
            }
            $ganttGridRows.removeClass("e-gantt-mouseclick");
            var $row = proxy.getRowByIndex(index);
            $row.addClass("e-gantt-mouseclick");
            proxy.model.selectedRowIndex = index;
            selectedItem = proxy.model.updatedGanttRecords[index];
            if(selectedItem)
                selectedItem.isSelected = true;

            proxy.model.selectedItem = selectedItem;
        },

        updateSelectedItem: function (recordIndex) {
            var proxy = this,
                $ganttGridRows = $(proxy.getGanttChartRows());

            $ganttGridRows.removeClass("e-gantt-mouseclick");
            proxy.model.updatedGanttRecords[recordIndex].isSelected = true;
            proxy.model.selectedItem = proxy.model.updatedGanttRecords[recordIndex];
            this._refresh();
            proxy._rowSelectedEventTrigger(recordIndex);

        },


        ganttrowHover: function (index) {
            var proxy = this;
            if (!proxy.model.enableRowHover)
                return;
            var $gridRows =proxy.getGanttChartRows();
            $gridRows.removeClass("e-gantt_mousehover").addClass("e-gantt_mouseleave");;
            $($gridRows[index]).addClass("e-gantt_mousehover").removeClass("e-gantt_mouseleave");
        },

        _rowHover: function (e) {
            var proxy = this,
                $target = $(e.target),
                $gridRows,
                args = {},
                index,
                row;
            if (!proxy.model.enableRowHover)
                return false;
            $gridRows = $(proxy.getGanttChartRows());
            index = $gridRows.index($target.parent());
            if (index == -1) {
                row = $target.closest('tr');
                index = $gridRows.index(row);
            }
            args.index = index;

            if (e.type == "mouseenter") {
                args.reason = "mouseenter";
                proxy.addRowHover(index);
            } else {
                args.reason = "mouseleave";
                proxy.removeRowHover();
            }
            proxy._trigger("rowHover", args);
            return false;
        },

        addRowHover: function (index) {
            var $gridRows = this.getGanttChartRows();
            if (index != null)
                index != -1 && $($gridRows[index]).addClass("e-enablerowhover");
        },

        removeRowHover: function () {
            var $gridRows = this.getGanttChartRows();
            $gridRows.removeClass("e-enablerowhover");
        },

        updateHeight: function (height) {
            var proxy = this,
                model = proxy.model;
            proxy._setScrollTop();
            if (model.stripLines) {
                $(".e-stripline,.e-stripLines").css({ height: height + "px" });
            }

            if (model.holidays) {
                $(".e-holidays,.e-holiday").css({ height: height + "px" });
            }
            $(".e-secondary_canvas").css({ height: height + "px" });
            $(".e-weekends").css({ height: height + "px" });

            if (height < proxy._viewportHeight) {
                if (height <= model.rowHeight) {
                    $(".e-holiday-label").css({ top:-height-30});
                }
                else
                    $(".e-holiday-label").css({ top: height / 2 });
            }
            else
                $(".e-holiday-label").css({ top: proxy._viewportHeight / 2 });
            proxy._$bodyContainer.ejScroller("refresh");
        },


        //method to trigger actioncomplete event
        _completeAction: function (args) {
            var proxy = this;
            args.vscrollExsist = proxy._$bodyContainer.ejScroller("isVScroll");
            proxy._trigger("actionComplete", args);
            if (args.requestType === "validatePredecessor") {
                return args.predecessorValidation;
            }
        },


        //method to trigger taskbarediting event
        //to apply changes during taskbar editing
        _taskbarEditing: function (args) {
            var proxy = this;
            proxy._trigger("taskbarEditing", args);
        },


        //method to trigger taskbaredited event
        //to apply changes after taskbar edited
        _taskbarEdited: function (args) {
            var proxy = this;
            proxy._trigger("taskbarEdited", args);
        },


        //method to trigger querytaskbarinfo 
        //to apply changes at load time
        _queryTaskbarinfo: function (args) {
            this._trigger("queryTaskbarInfo", args);
            this._updateTaskbarItems(args);
        },


        //method to trigger refresh row
        _refreshRow: function (args) {
            var proxy = this;
            proxy._trigger("refreshRow", args);
        },

        _enbleZooming: function (args) {
            var proxy = this;
            proxy._trigger("zooming", args);
        },


        //Updates taskbar items styles when chart loads
        _updateTaskbarItems: function (args) {

            var $ganttChartRows = this.getGanttChartRows(),
                index = this._currentViewData.indexOf(args.data),
                taskbarContainer = $ganttChartRows[index], taskElement;

            if (taskbarContainer) {
                if (taskbarContainer.childNodes.length > 1)
                    taskElement = taskbarContainer.childNodes[1].firstChild;
                else
                    taskElement = taskbarContainer.childNodes[0].firstChild;

                if ($(taskElement).hasClass("e-parentContainer")) {

                    var parentTaskbar = taskElement.firstChild,
                        parentProgressbar = taskElement.childNodes[1],
                        parentTaskbarStyle = parentTaskbar.style,
                        parentProgressbarStyle = parentProgressbar.style;

                    if (parentTaskbarStyle.backgroundColor != args.parentTaskbarBackground) {
                        parentTaskbarStyle.backgroundColor = args.parentTaskbarBackground;
                    }
                    if (parentProgressbarStyle.backgroundColor != args.parentProgressbarBackground) {
                        parentProgressbarStyle.backgroundColor = args.parentProgressbarBackground;
                    }

                } else if ($(taskElement).hasClass("e-childContainer")) {

                    var taskbar = taskElement.childNodes[2],
                        progressbar = taskElement.childNodes[3],
                        taskbarStyle = taskbar.style,
                        progressbarStyle = progressbar.style;

                    if (taskbarStyle.backgroundColor != args.taskbarBackground) {
                        taskbarStyle.backgroundColor = args.taskbarBackground;
                    }
                    if (progressbarStyle.backgroundColor != args.progressbarBackground) {
                        progressbarStyle.backgroundColor = args.progressbarBackground;
                    }
                }
            }
        },

        //to perform expand collapse operation from ganttchart
        _expandCollapse: function (recordIndex) {

            var proxy = this,
                args = {},
                data = proxy._currentViewData[recordIndex];

            args.data = data;
            args.recordIndex = proxy.model.updatedGanttRecords && proxy.model.updatedGanttRecords.indexOf(data);
            args.source = "ganttChart";
            args.expanded = !data.expanded;
            if (data) {
                if (!args.expanded) {
                    proxy._trigger("collapsing", args);
                }
                else {
                    proxy._trigger("expanding", args);
                }
            }
        },


        //get the Expand status of GridRecord
        _getExpandStatus: function (record) {
            var parentRecord = record.parentItem;
            if (parentRecord != null) {
                if (parentRecord.expanded === false)
                    return false;
                else if (parentRecord.parentItem) {
                    if (parentRecord.parentItem.expanded === false)
                        return false;
                    else
                        return this._getExpandStatus(parentRecord.parentItem);
                }
                else
                    return true;
            } else
                return true;
        },



        //method to scroll ganttchart from gridtree scroll event       

        onScrollHelper: function (scrollTop) {

            var proxy = this;
			if (!proxy._$bodyContainer.ejScroller("isVScroll"))
			{
                return false;
            }
            proxy._mouseLeave();

            var div = $("#ganttviewerbodyContianer" + this._id);
            
            $(".e-ganttviewerbodyContent").scrollTop(scrollTop);

            //Afetr addd new div in body container ,tregrid wheel event is not updated in chart part.
            $(".e-ganttviewerbodyContent").parent(".e-content").scrollTop(scrollTop);

            var h = parseInt(proxy.model.updatedGanttRecords.length * 30) - (proxy._viewportHeight - 18);
            

            if (scrollTop > h) {
                scrollTop = h;
            }

            if (scrollTop < 0) {
                scrollTop = 0;
            }

            var args = { scrollTop: scrollTop };

            proxy._handleScroll(args);
            
            //var div = $("#ganttviewerbodyContianer" + this._id);
            //div.scrollTop(scrollTop);
            
        },



        //Handler for scroll event from ganttchart
        _handleScroll: function (args) {

            var proxy = this,
                args =args|| {},
                headerdiv = proxy._$headerContainer,
                contentdiv = proxy._$bodyContainer,
                left = proxy._prevLeft;

            
            if (args.scrollTop !== undefined) {
                proxy._scrollTop = args.scrollTop;
            }

            if (args.scrollLeft !== undefined) {
                left = args.scrollLeft;
            }

            var diff = (left - proxy._prevLeft),
                vDiff = proxy._scrollTop - proxy._prevScrollTop;

            if (diff) {
                headerdiv.scrollLeft(left);
            }
            else {
                headerdiv.scrollLeft(proxy._prevLeft);
            }

            if (proxy.model.enableVirtualization) {
                proxy._vscrollDist = Math.abs(proxy._scrollTop - proxy._prevScrollTop);
                if (proxy._vscrollDist) {
                    proxy._vScrollDir = proxy._prevScrollTop <= proxy._scrollTop ? 1 : -1;
                        proxy._updateCurrentViewData();

                    proxy.renderGanttRecords();
                    proxy._prevScrollTop = proxy._scrollTop;
                }
            }
            args.requestType = "scroll";
            args.delta = proxy._scrollTop;
            proxy._prevLeft = left;
            proxy._prevScrollTop = proxy._scrollTop;
            if (diff === 0 && vDiff !== 0) {
                proxy._completeAction(args);
            }
        },


        //helper method to refresh the ganttchart content from gantt
        refreshHelper: function (currentviewdata, records,collapseRecordsCount) {

            var proxy = this;
            proxy._currentViewData = currentviewdata;
            proxy.model.updatedGanttRecords = records;
            if (records) {
                proxy._refresh();
                proxy._setHeight(records.length * proxy.model.rowHeight);
                if (proxy.model.enableVirtualization) {
                    $("#ganttviewerbodyContent" + proxy._id + "").css({
                        "height": proxy._containerHeight + "px"
                    });
                    proxy.updateHeight(proxy._containerHeight);
                }
                else
                {
                    var tempHeight =0;
                    if (collapseRecordsCount)
                        tempHeight = (records.length - collapseRecordsCount) * proxy.model.rowHeight;
                    else
                        tempHeight = records.length * proxy.model.rowHeight;

                    proxy.updateHeight(tempHeight);
                }
           
                var isVScroll = proxy._$bodyContainer.ejScroller("isVScroll");
                var isHScroll = proxy._$bodyContainer.ejScroller("isHScroll");
                if (isVScroll || isHScroll) 
                    proxy._$bodyContainer.ejScroller("refresh");
            }
        },
        _setScrollTop: function () {

            var proxy = this,
            model = this.model,
            top = proxy._scrollTop;

            if (model.enableVirtualization && top!==0) {
                if ((proxy._currentViewData.length * proxy.model.rowHeight) < proxy._viewportHeight) {
                    var currentPosition = top - (proxy._viewportHeight - proxy._currentViewData.length * proxy.model.rowHeight);
                    if (currentPosition < 0)
                        currentPosition = 0;
                    proxy._$bodyContainer.ejScroller("scrollY", currentPosition, true);
                }
            }
        },
        getVisibleRecordsCount:function()
        {
            return this._visibleRecordsCount;
        },

        reRenderGanttGridLinesTable: function (length) {
            var proxy = this;
            //   var $gridLinesTablebody = $("#gridLinesTablebody" + proxy._id + "");
            //if (proxy.model.enableVirtualization) {
            //    proxy._$gridLinesTablebody.append(proxy._createGridLinesTableRow(length));
            //} else {
            proxy._visibleRecordsCount = (proxy._visibleRecordsCount + length < 0) ?
                proxy._visibleRecordsCount : proxy._visibleRecordsCount + length;

            if (proxy._visibleRecordsCount > 0) {
                proxy._$gridLinesTablebody.empty().append(proxy._createGridLinesTableRow(proxy._visibleRecordsCount));
                //this is called after update height method so scroller is refreshed
                proxy._$bodyContainer.ejScroller("refresh");
            }
            //}
        },

        refrehGridLinesTable:function(length)
        {
            var proxy = this;
            if (proxy._visibleRecordsCount > 0) {
                proxy._$gridLinesTablebody.empty().append(proxy._createGridLinesTableRow(length));
                proxy._$bodyContainer.ejScroller("refresh");
                proxy._visibleRecordsCount = length;
            }
        },
        //to refresh the content of the ganttchart
        _refresh: function () {

            var proxy = this, model = proxy.model,
                data = $.render[proxy._id + "_CustomTemplate2"](proxy._currentViewData);

            proxy._$ganttViewTablebody = $("#ganttViewTablebody" + proxy._id + "");

            proxy._$ganttViewTablebody.empty().append(data);

            //var $gridLinesTablebody = $("#gridLinesTablebody" + proxy._id + "");
            
            if (model.enableVirtualization) {
                proxy._visibleRecordsCount = proxy._currentViewData.length;
                proxy._$gridLinesTablebody.empty().append(proxy._createGridLinesTableRow(proxy._currentViewData.length));
            }
            else {
                if (proxy._visibleRecordsCount == 0 || proxy._visibleRecordsCount > proxy._currentViewData.length)
                    proxy._visibleRecordsCount = proxy._currentViewData.length;
                proxy._$gridLinesTablebody.empty().append(proxy._createGridLinesTableRow(proxy._visibleRecordsCount));
            }


            if (proxy._$ganttViewTablebody[0] != null) {
                this._ganttChartRows = $(proxy._$ganttViewTablebody[0].childNodes);
            }
            else {
                proxy._$ganttViewTablebody = ej.buildTag("tbody.e-gantt-viewer-ganttViewTablebody#ganttViewTablebody" + proxy._id + "",
                    data, {}, {});
                proxy._ganttChartRows = $(proxy._$ganttViewTablebody[0].childNodes);
            }
            if(model.queryTaskbarInfo)
                proxy._eventBindings();

        },


        //to rerender a particular ganttchart row
        refreshRow: function (index) {

            var proxy = this,
                $tr = $(proxy.getGanttChartRows()[index]),
                selectedItem = proxy._currentViewData[index];

            if (index != -1 && selectedItem) {
                $tr.replaceWith($.render[proxy._id + "_CustomTemplate2"](selectedItem));
                proxy._setGanttChartRows($(proxy._$ganttViewTablebody[0].childNodes));
            }
            if (model.queryTaskbarInfo)
                proxy._refreshedRowEventBinding(index);

        },


        //Trigger queryTaskbarInfo while refresh the row
        _refreshedRowEventBinding: function (index)
        {
            var $ganttChartRows = $(this.getGanttChartRows()),
                            taskbarContainer,
                            args = {}, progressbar, taskbar,
                            parentProgressbar, parentTaskbar, taskElement;

                    taskbarContainer = $ganttChartRows[index];

                    if ($(taskbarContainer).hasClass("e-ganttrowcell")) {

                        if (taskbarContainer.childNodes.length > 1)
                            taskElement = taskbarContainer.childNodes[1].firstChild;
                        else
                            taskElement = taskbarContainer.childNodes[0].firstChild;

                        if ($(taskElement).hasClass("e-parentContainer")) {

                            parentTaskbar = taskElement.firstChild;
                            parentProgressbar = taskElement.childNodes[1];
                        } else if ($(taskElement).hasClass("e-childContainer")) {

                            taskbar = taskElement.childNodes[1];
                            progressbar = taskElement.childNodes[2];
                        }

                        args.data = this._currentViewData[index];
                        args.taskbar = taskbarContainer;

                        args.taskbarBackground = taskbar != null ?
                            taskbar.style.backgroundColor : null;

                        args.progressbarBackground = progressbar != null ?
                            progressbar.style.backgroundColor : null;

                        args.parentTaskbarBackground = parentTaskbar != null ?
                            parentTaskbar.style.backgroundColor : null;

                        args.parentProgressbarBackground = parentProgressbar != null ?
                            parentProgressbar.style.backgroundColor : null;
                        this._queryTaskbarinfo(args);
                    }

        },
        //REFRESH THE SCROLLER FOR TREEGRIDCONTENT
        refreshScroller: function (panSize) {

            var proxy = this,maxScrollWidth;
            //proxy._$gridContent.css({'width':panSize+"px"});
            proxy._$bodyContainer.removeClass("e-borderbox");
            var scrollTop = proxy._$bodyContainer.ejScroller("option", "scrollTop");
            var scrollLeft = proxy._$bodyContainer.ejScroller("option", "scrollLeft");
            proxy._$bodyContainer.ejScroller("option", { "width": panSize });
            proxy._$bodyContainer.ejScroller("refresh");
            maxScrollWidth=proxy.getMaxScrollWidth();
            
            if (scrollLeft > maxScrollWidth)
                scrollLeft = maxScrollWidth > 0 ? maxScrollWidth : 0;

            var isHorizontalScroll = proxy._$bodyContainer.ejScroller("isHScroll");
            if (!isHorizontalScroll) {
                proxy._$bodyContainer.addClass("e-borderbox");
            }
            else {
                proxy._$bodyContainer.removeClass("e-borderbox");
            }
            var isVerticalScroll = proxy._$bodyContainer.ejScroller("isVScroll");
            if (isVerticalScroll)
            {
                proxy._$bodyContainer.ejScroller("scrollY", scrollTop, true);
            }
            proxy._$bodyContainer.ejScroller("option", "scrollLeft", scrollLeft);
            proxy._$headerContainer.scrollLeft(scrollLeft);

        },
        getMaxScrollWidth:function()
        {
            var proxy = this;
            return proxy._$bodyContainer.children(".e-content").children().width() - proxy._$bodyContainer.children(".e-content").width();
        },
        refreshStripLines:function ()
        {
            this._renderStripLines(this.model.stripLines);
        },
        refreshHolidays: function () {
            //Display Holidays
            var proxy = this;
            if (proxy.model.holidays != null) {
                var holidayCount = proxy.model.holidays.length;
                for (var i = 0; i < holidayCount; i++) {
                    proxy._renderHoliday(proxy.model.holidays[i]);
                }
            }
        },
        renderRecord: function (args,collapseCount) {
            var proxy = this, model = proxy.model;
            addedchartRow = $.render[this._id + "_CustomTemplate2"](args._cAddedRecord);
            if (proxy._ganttChartRows.length != 0) {
                var insertIndex = proxy._currentViewData.indexOf(model.selectedItem);
                if (args.position) {
                    if (args.position == "Above") {
                        proxy.getGanttChartRows().eq(insertIndex-1).before(addedchartRow);//cuurent view data is updated before it is renderd
                    } else if (args.position == "Below") {
                        proxy.getGanttChartRows().eq(insertIndex).after(addedchartRow);
                    }
                }
                else {
                    if( insertIndex== -1) {
                        proxy.getGanttChartRows().eq(0).before(addedchartRow);
                    } else {
                        proxy.getGanttChartRows().eq(insertIndex).after(addedchartRow);
                    }
                }
                proxy._setGanttChartRows($(proxy._$ganttViewTablebody[0].childNodes));
            }

            if (proxy._ganttChartRows.length == 0) {
                proxy._updateCurrentViewData();
                proxy._refresh();
                proxy._setGanttChartRows($(proxy._$ganttViewTablebody[0].childNodes));
            }
            if (model.enableVirtualization === false)
            {
                proxy._setHeight((proxy.model.updatedGanttRecords.length - collapseCount) * proxy.model.rowHeight);

            } else
            {
                proxy._setHeight(proxy.model.updatedGanttRecords.length * proxy.model.rowHeight);
            }
            proxy.updateHeight(proxy._containerHeight);
            proxy._$bodyContainer.ejScroller("refresh");
        },

        _setGanttChartRows: function (value) {
            this._ganttChartRows = value;
        },

        refreshChartHeader:function(startdate,enddate)
        {
            var proxy = this,
            model = proxy.model,
            scheduleMode = model.scheduleHeaderSettings.scheduleHeaderType,
            $colsgroup, $column, $thead,
            $tr, $td, $div, $table;
            proxy._updateScheduleWidth();
            if (scheduleMode == "month") {
                proxy._createScheduleTopMonthTemplate();
            }
            
            startdate = startdate == null ? new Date() : startdate;
            enddate = enddate == null ? new Date(null) : enddate;
            proxy._$scheduleDiv.empty();
            $table = ej.buildTag("table.e-schedule-headerrow-week", "",
                { 'display': 'block' },
                { 'cell-spacing': '0' }
            );

            $colsgroup = ej.buildTag("colgroup", "", {}, {});
            $column = $(document.createElement("col"));
            $column.css("width", proxy._getScheduleLength(scheduleMode) + 'px');

            $colsgroup.append($column);

            $thead = ej.buildTag("thead.e-ejganttschedule", "",
                { 'display': 'block', 'border-collapse': 'collapse' }, {});

            if (scheduleMode == "week")
                $tr = ej.buildTag("tr", $.render[this._id + "ScheduleWeekTemplate"](proxy.model.scheduleWeeks), {}, {});
            else if (scheduleMode == "year")
                $tr = ej.buildTag("tr", $.render[this._id + "ScheduleYearTemplate"](proxy.model.scheduleYears), {}, {});
            else if (scheduleMode == "month")
                $tr = ej.buildTag("tr", $.render[this._id + "ScheduleTopMonthTemplate"](proxy.model.scheduleMonths), {}, {});
            else if (scheduleMode == "day")
                $tr = ej.buildTag("tr", $.render[this._id + "ScheduleTopDayTemplate"](proxy.model.scheduleDays), {}, {});

            $td = ej.buildTag("th.schedule", "", {}, {});
            $div = ej.buildTag("div.schedule", "", { 'width': 20 + 'px' }, {});
            $td.append($div);
            $tr.append($td);

            $thead.append($tr);
            $table.append($colsgroup);
            $table.append($thead);
            proxy._$scheduleDiv.append($table);

            $tr = null;

            $table = ej.buildTag("table.e-schedule-headerrow-day", "",
                {
                    'display': 'block',
                    'border-collapse': 'collapse'
                }, { 'cell-spacing': '0' });
            $thead = ej.buildTag("thead.e-ejganttschedule", "",
                { 'display': 'block', 'border-collapse': 'collapse' }, {});

            if (scheduleMode == "week")
                $tr = ej.buildTag("tr", $.render[this._id + "_CustomTemplate1"](proxy.model.scheduleWeeks), {}, {});
            if (scheduleMode == "year")
                $tr = ej.buildTag("tr", $.render[this._id + "ScheduleMonthTemplate"](proxy.model.scheduleYears), {}, {});
            if (scheduleMode == "month") {
                proxy._numOfWeeks = proxy._getNumberOftWeeks(this.model.projectStartDate, this.model.projectEndDate);
                $tr = ej.buildTag("tr", $.render[this._id + "ScheduleBottomWeekTemplate"](proxy._numOfWeeks), {}, {});
            }
            if (scheduleMode == "day")
                $tr = ej.buildTag("tr", $.render[this._id + "scheduleHourTemplate"](proxy._getScheduleHours()), {}, {});

            $td = ej.buildTag("th.schedule", "", {}, {});
            $div = ej.buildTag("div.schedule", "", { 'width': 20 + 'px' }, {});
            $td.append($div);
            $tr.append($td);

            $thead.append($tr);
            $table.append($colsgroup);
            $table.append($thead);
            proxy._$scheduleDiv.append($table);
        },


        //update all containers width
        refreshContainersWidth:function()
        {
            var proxy = this,
                width,
                scheduleMode = model.scheduleHeaderSettings.scheduleHeaderType;
            width = proxy._getScheduleLength(scheduleMode),
            $gridLineContainerTable=$("#ganttgridLinesTable" + proxy._id);

            proxy._$bodyContent.width(width);//main body container
            if (scheduleMode === "week")
                proxy.refreshWeekEndContainer();//weekENd Container
            $gridLineContainerTable.width(width);
            $gridLineContainerTable.children("col").width(width);
            proxy._$ganttViewTable.width(width);
            proxy._$ganttViewTable.children("col").width(width);
            proxy._createTaskbarTemplate();
            proxy._$secondaryCanvas.empty();
            if (proxy.model.stripLines != null) {
                this._renderStripLines(proxy.model.stripLines);
            }
            if (proxy.model.holidays != null) {
                var holidayCount = proxy.model.holidays.length;
                for (var i = 0; i < holidayCount; i++) {
                    proxy._renderHoliday(proxy.model.holidays[i]);
                }
            }
        },
        //refresh week ends when schedule dates changes
        refreshWeekEndContainer:function()
        {
            var proxy = this,
                left = 0,
                width = (proxy.model.perDayWidth) + 1,
                height = ((proxy.model.updatedGanttRecords.length) * this.model.rowHeight),
                count = proxy.model.scheduleWeeks.length,
                $sunday, $saturday,
                $weekendContainer = proxy._$weekendsContainer.children('.e-secondary_canvas');
                $weekendContainer.empty();


                for (var i = 0; i < count; i++) {
                    $sunday = ej.buildTag("div.e-weekends", "", {
                        'left': left + 'px',
                        'width': width + 'px',
                        'height': height + 'px',
                        'background-color': this.model.weekendBackground
                    }, {});
                    $saturday = ej.buildTag("div.e-weekends", "", {
                        'left': (left + (proxy.model.perDayWidth * 6)) + 'px',
                        'width': width + 'px',
                        'height': height + 'px',
                        'background-color': this.model.weekendBackground
                    }, {});
                    $weekendContainer.append($sunday);
                    $weekendContainer.append($saturday);
                    left = left + this._scheduleWeekWidth;
                }
                proxy._$weekendsContainer.append($weekendContainer);
        },
        //delete gantt chart rows without rerendering of whole page
        deleteChartRows: function (startIndex, count) {
            var proxy = this;
            var $chartRows = proxy.getGanttChartRows();
            for (var i = startIndex; i < startIndex + count; i++) {
                $chartRows.splice(i, 1);
            }
        },


        //helper method to bind querytaskbarinfo events to ganttchart rows
        _eventBindings: function () {

            var $ganttChartRows = $(this.getGanttChartRows()),
                rowsLength = $ganttChartRows.length,
                taskbarContainer,
                args = {}, progressbar, taskbar,
                parentProgressbar, parentTaskbar, taskElement;

            if (rowsLength != 0) {

                for (var row = 0; row < rowsLength; row++) {

                    taskbarContainer = $ganttChartRows[row];

                    if ($(taskbarContainer).hasClass("e-ganttrowcell")) {

                        if (taskbarContainer.childNodes.length > 1)
                            taskElement = taskbarContainer.childNodes[1].firstChild;
                        else
                            taskElement = taskbarContainer.childNodes[0].firstChild;

                        if ($(taskElement).hasClass("e-parentContainer")) {

                            parentTaskbar = taskElement.firstChild;
                            parentProgressbar = taskElement.childNodes[1];
                        } else if ($(taskElement).hasClass("e-childContainer")) {

                            taskbar = taskElement.childNodes[1];
                            progressbar = taskElement.childNodes[2];
                        }

                        args.data = this._currentViewData[row];
                        args.taskbar = taskbarContainer;

                        args.taskbarBackground = taskbar != null ?
                            taskbar.style.backgroundColor : null;

                        args.progressbarBackground = progressbar != null ?
                            progressbar.style.backgroundColor : null;

                        args.parentTaskbarBackground = parentTaskbar != null ?
                            parentTaskbar.style.backgroundColor : null;

                        args.parentProgressbarBackground = parentProgressbar != null ?
                            parentProgressbar.style.backgroundColor : null;
                        this._queryTaskbarinfo(args);
                    }
                }
            }
        },


        //to update the currentviewdata of ganttchart
        _updateCurrentViewData: function () {
            var proxy = this, margin = 0;
            if (!this.model.enableVirtualization) {
                this._currentViewData = this.model.updatedGanttRecords;
            }
            else {
                this._getRenderedRowRange();

                //console.log("Gantt Chart Rendered Range Top: " + proxy._renderedRange.top + "Bottom :" + proxy._renderedRange.bottom);

                this._currentViewData = this.model.updatedGanttRecords.slice(proxy._renderedRange.top,
                    proxy._renderedRange.bottom);
                if (proxy._vscrollDist !== 0) {
                    margin = proxy._scrollTop;
                    margin -= proxy._rowMargin;
                }
                $("#ganttViewTable" + proxy._id + "").css({ "top": margin + "px" });

                $("#ganttgridLinesTable" + proxy._id + "").css({ "top": margin + "px" });

                proxy._vTop = proxy._visibleRange.top;
                proxy._vBottom = proxy._visibleRange.bottom;
                proxy._rTop = proxy._renderedRange.top;
                proxy._rBottom = proxy._renderedRange.bottom;
            }

        },

       
        //to render ganttchart content
        renderGanttRecords: function () {

            var proxy = this;
            proxy._refresh();
            proxy._$ganttViewTable.append(proxy._$ganttViewTablebody);
            proxy._$bodyContent.append(proxy._$ganttViewTable);
        },

        _getRenderedRowRange: function () {

            var proxy = this;
            proxy._getVisibleRowRange();
            var topIndex = proxy._visibleRange.top;
            var bottomIndex = proxy._visibleRange.bottom;
            proxy._renderedRange = { top: topIndex, bottom: bottomIndex };
            return proxy._renderedRange;
        },

        _getVisibleRowRange: function () {

            var proxy = this,
                top = proxy._scrollTop / proxy.model.rowHeight,
                coeff = top - Math.floor(top),
                topIndex,
                bottomIndex, length;

            //console.log("GanttChart ScrollTop :" + proxy._scrollTop);

            proxy._rowMargin = coeff * proxy.model.rowHeight;
            topIndex = Math.floor(top);
            length = proxy.model.updatedGanttRecords.length;
            bottomIndex = proxy._getrowposition(proxy._scrollTop + proxy._viewportHeight);
            topIndex = Math.max(0, topIndex);
            bottomIndex = Math.min(length, bottomIndex);
            proxy._visibleRange = { top: topIndex, bottom: bottomIndex };
        },

        _getrowposition: function (y) {
            return Math.ceil((y) / this.model.rowHeight);
        },


        //returns the date object
        _getDateType: function (date) {

            if (date != null) {
                if (typeof (date) == "object") {
                    return date;
                } else {
                    var re = new RegExp("\\-", "g");
                    var re1 = new RegExp("\\.", "g");
                    date = date.replace(re, "/");
                    date = date.replace(re1, "/");

                    return new Date(date);
                }
            }
            return null;
        },

        _createScheduleTopDayTemplate: function () {
            var proxy = this,
                model = proxy.model,
                dayFormat = model.scheduleHeaderSettings.dayHeaderFormat,
                helpers = {
                    renderDayTop: $.proxy(proxy._getDaySplit, proxy),
                };
            $.views.helpers(helpers);

            var parentTr = "<th class='e-schedule-week-headercell' style='box-sizing:border-box;-moz-box-sizing:border-box;'>";

            td = "<div class='e-schedule-week-headercell-content'  style='width:"
                + ((proxy.model.perHourWidth*24)-1) + "px;margin:auto;white-space:nowrap;'>"
                + "{{:~renderDayTop('" + dayFormat + "',#data)}}" + "</div>" +
            "</div>"

            parentTr += td;
            parentTr += "</th>";

            var templates = {};
            templates[proxy._id + "ScheduleTopDayTemplate"] = parentTr;
            $.templates(templates);
        },

        //helper methood for day schedule mode

        _getDaySplit: function (dateformat,data) {
            var date = new Date(data),
               proxy = this,
               model = proxy.model,
               formatedDate;

            formatedDate = Globalize.format(date, dateformat, model.locale);
            return formatedDate;
        },


        // Month Week Schedule Mode

        _createScheduleTopMonthTemplate: function () {

            var proxy = this, td, i = 0,
                model = proxy.model,
                monthFormat = model.scheduleHeaderSettings.monthHeaderFormat,
                helpers = {
                    renderMonthTop: $.proxy(proxy._getMonthsplit, proxy),
                    setMonthWidth: $.proxy(proxy._setMonthWidth, proxy),
                    isLastMonth: $.proxy(proxy._checkLastMonthWidth, proxy),
                };

            $.views.helpers(helpers);
            var parentTr = "<th class='e-schedule-week-headercell' style='box-sizing:border-box;-moz-box-sizing:border-box;'>";

            td = "<div class='e-schedule-week-headercell-content'  style='margin:auto;white-space:nowrap;width:{{:~setMonthWidth(#data)-1}}" + "px;'>"
                + "{{:~renderMonthTop('" + monthFormat + "',#data)}}" + "</div>"
                 +"{{if ~isLastMonth(#data)}}"
                 + "<th class='e-schedule-week-headercell' style='box-sizing:border-box;-moz-box-sizing:border-box;'>"
                    + "<div class='e-schedule-week-headercell-content' style='margin:auto;white-space:nowrap;width:" + (proxy._balanceWidth-1) + "px;'>"
                +"</div></th>{{/if}}"
            
                parentTr += td;
                parentTr += "</th>";
                //if (proxy._balanceWidth) {
                //    parentTr += tdx;
                //    parentTr += "</th>";
                //}

            var templates = {};
            templates[proxy._id + "ScheduleTopMonthTemplate"] = parentTr;
            $.templates(templates);
        },

        //helper method for calculating unique month width
        _setMonthWidth: function (data) {
            var proxy = this;
            var date;
            if (typeof data === "object") {
                date = new Date(data);
            }
            else {
                date = Globalize.parseDate(data, "MM/dd/yyyy");
            }

            var monthLastDay = new Date(date.getFullYear(), date.getMonth() + 1, 0);

            var lastDate = monthLastDay.getDate();
            if (lastDate == 31)
                return (this.model.perDayWidth * 31);
            else if (lastDate == 30)
                return (this.model.perDayWidth * 30);
            else if (lastDate == 28)
                return (this.model.perDayWidth * 28);
            else if (lastDate == 29)
                return (this.model.perDayWidth * 29);
        },

        _checkLastMonthWidth: function (data) {
            var proxy = this;
            if (data == proxy.model.scheduleMonths[proxy.model.scheduleMonths.length - 1] && proxy._balanceWidth>0) {
                return true;
            }
            else
            {
                return false;
            }
        },


        //helper method for _createScheduleMonthTemplate
        _getMonthsplit: function (monthFormat, data) {

            var date = new Date(data),
                proxy = this,
                model = proxy.model,
                formatedDate;

            formatedDate = Globalize.format(date, monthFormat, model.locale);
            return formatedDate;

        },


        _createScheduleYearTemplate: function () {

            var proxy = this, td,
                model = proxy.model,
                yearFormat = model.scheduleHeaderSettings.yearHeaderFormat,
                helpers = {
                    renderYear: $.proxy(proxy._getYearsplit, proxy),
                    getYearWidth: $.proxy(proxy._getTemplateYearWidth, proxy),
                };

            $.views.helpers(helpers);
            var parentTr = "<th class='e-schedule-week-headercell' style='box-sizing:border-box;-moz-box-sizing:border-box;'>";
            
            td = "<div class='e-schedule-week-headercell-content'  style='margin:auto;white-space:nowrap;width:{{:~getYearWidth(#data)-1}}px'>"
                + "{{:~renderYear('" + yearFormat + "',#data)}}" + "</div>";

            parentTr += td;
            parentTr += "</th>";

            var templates = {};
            templates[proxy._id + "ScheduleYearTemplate"] = parentTr;
            $.templates(templates);
        },

        //helper method for _createScheduleYearTemplate
        _getYearsplit: function (yearFormat, data) {

            var date = new Date(data),
                proxy = this,
                model = proxy.model,
                formatedDate;

            formatedDate = Globalize.format(date, yearFormat, model.locale);
            return formatedDate;

        },
        _getTemplateYearWidth: function (date) {

            var year = date.getFullYear();
            if (new Date(year, 1, 29).getMonth() === 1) {
                return 366 * this.model.perDayWidth;
            }
            else
                return 365 * this.model.perDayWidth;
        },
        //Template to render schedule week view
        _createScheduleWeekTemplate: function () {

            var proxy = this, td,
                model = proxy.model,
                dateFormat = model.scheduleHeaderSettings.weekHeaderFormat,
                helpers = {
                    renderWeek: $.proxy(proxy._getWeeksplit, proxy)
                };

            $.views.helpers(helpers);
            var parentTr = "<th class='e-schedule-week-headercell' style='box-sizing:border-box;-moz-box-sizing:border-box;'>";

            td = "<div class='e-schedule-week-headercell-content'  style='width:"
                + (proxy._scheduleWeekWidth - 1) + "px;margin:auto;white-space:nowrap;'>"
                + "{{:~renderWeek('" + dateFormat + "',#data)}}" + "</div>";

            parentTr += td;
            parentTr += "</th>";

            var templates = {};
            templates[proxy._id + "ScheduleWeekTemplate"] = parentTr;
            $.templates(templates);
        },

        //helper method for _createScheduleWeekTemplate
        _getWeeksplit: function (dateFormat, data) {

            var date = new Date(data),
                proxy = this,
                model = proxy.model,
                formatedDate;
            //var values = dateFormat.split(' '),
            //    scheduleUnits = values[0].match(/(\d+|[A-z]+)/g),
            //    month = date.getMonth(),
            //    day = date.getDay() == 1 ? proxy._days("mon") : "",
            //    weekTemplate = [];

            //switch (month) {
            //    case 0:
            //        month = proxy._getLocalizedLabels("jan");
            //        break;
            //    case 1:
            //        month = proxy._getLocalizedLabels("feb");
            //        break;
            //    case 2:
            //        month = proxy._getLocalizedLabels("mar");
            //        break;
            //    case 3:
            //        month = proxy._getLocalizedLabels("apr");
            //        break;
            //    case 4:
            //        month = proxy._getLocalizedLabels("may");
            //        break;
            //    case 5:
            //        month = proxy._getLocalizedLabels("jun");
            //        break;
            //    case 6:
            //        month = proxy._getLocalizedLabels("jul");
            //        break;
            //    case 7:
            //        month = proxy._getLocalizedLabels("aug");
            //        break;
            //    case 8:
            //        month = proxy._getLocalizedLabels("sep");
            //        break;
            //    case 9:
            //        month = proxy._getLocalizedLabels("oct");
            //        break;
            //    case 10:
            //        month = proxy._getLocalizedLabels("nov");
            //        break;
            //    case 11:
            //        month = proxy._getLocalizedLabels("dec");
            //        break;
            //}

            //for (var i = 0; i < scheduleUnits.length; i++) {
            //    switch (scheduleUnits[i]) {//('0' + currentDate.getHours()).slice(-2)
            //        case "d":
            //        case "D":
            //            weekTemplate.push(('0' + date.getDate()).slice(-2));
            //            break;
            //        case "dd":
            //        case "DD":
            //            weekTemplate.push(date.getDate());
            //            break;
            //        case "ddd":
            //        case "DDD":
            //            weekTemplate.push(day.substring(0, 3));
            //            break;
            //        case "dddd":
            //        case "DDDD":
            //            weekTemplate.push(day);
            //            break;
            //        case "M":
            //        case "m":
            //            weekTemplate.push(('0' + date.getMonth() + 1).slice(-2));
            //            break;
            //        case "MM":
            //        case "mm":
            //            weekTemplate.push(date.getMonth() + 1);
            //            break;
            //        case "MMM":
            //        case "mmm":
            //            weekTemplate.push(month.substring(0, 3));
            //            break;
            //        case "MMMM":
            //        case "mmmm":
            //            weekTemplate.push(month);
            //            break;
            //        case "YY":
            //        case "yy":
            //            weekTemplate.push(('0' + date.getFullYear()).slice(-2));
            //            break;
            //        case "YYYY":
            //        case "yyyy":
            //            weekTemplate.push(date.getFullYear());
            //            break;
            //    }
            //}
            formatedDate = Globalize.format(date, dateFormat, model.locale);

            return formatedDate.toLowerCase().replace(/(-(\w)|(^| )(\w)|:(\w)|,(\w)|\/(\w)|\.(\w))/g, function (x) {
                return x.toUpperCase();
            });
        },

        _createScheduleHourTemplate: function () {
            var proxy = this, model = proxy.model,td,
                hourHeaderFormat = model.scheduleHeaderSettings.hourHeaderFormat,
                helpers = {
                    renderHour:$.proxy(proxy._getHourTemplate,proxy),
                };
            $.views.helpers(helpers);
            var parentTr = "<th  class='e-schedule-day-headercell' " +
                "style='-moz-box-sizing:border-box;box-sizing:border-box;'>";
            td = "<div class='e-schedule-day-headercell-content' style='width:"
                + (proxy.model.perHourWidth - 1) + "px;position:static;box-sizing:border-box;overflow:hidden;text-overflow:clip'>" +
                "{{:~renderHour('" + hourHeaderFormat + "',#data)}}</div>";

            parentTr += td;

            parentTr += "</th>";
            var templates = {};
            templates[proxy._id + "scheduleHourTemplate"] = parentTr;
            $.templates(templates);
        },

        _getHourTemplate: function (format,data) {
            var date = new Date(data),
              proxy = this,
              model = proxy.model,
              formatedDate;

            formatedDate = Globalize.format(date, format, model.locale);
            return formatedDate;
        },


        //Template to render schedule week view in month-week schedule mode
        _createScheduleBottomWeekTemplate: function () {

            var proxy = this, td, model = proxy.model,
                weekFormat = model.scheduleHeaderSettings.weekHeaderFormat,
                helpers = {
                    renderWeek: $.proxy(proxy._getMonthWeekTemplate, proxy)
                };

            $.views.helpers(helpers);

            var parentTr = "<th  class='e-schedule-day-headercell' " +
                "style='-moz-box-sizing:border-box;box-sizing:border-box;'>";
            td = "<div class='e-schedule-day-headercell-content' style='position:static;box-sizing:border-box;overflow:hidden;text-overflow:clip;padding-left:2px;width:" + (proxy.model.perWeekWidth-1) + "px;'>" +
                "{{:~renderWeek('" + weekFormat + "',#data)}}</div>";

            parentTr += td;

            parentTr += "</th>";
            var templates = {};
            templates[proxy._id + "ScheduleBottomWeekTemplate"] = parentTr;
            $.templates(templates);
        },

        _getMonthWeekTemplate: function (weekFormat, data) {

            var date = new Date(data),
                proxy = this, model = proxy.model;

            //date.setDate(date.getDate() + (weekLength * 7));

            switch (weekFormat) {
                case "d":
                case "dd":
                    //return (('0' + date.getDate()).slice(-2));
                case "ddd":

                default: return Globalize.format(date, weekFormat, model.locale);
            }
        },




        //Template to render schedule day view
        _createScheduleMonthTemplate: function () {

            var proxy = this, td, model = proxy.model,
                monthFormat = model.scheduleHeaderSettings.monthHeaderFormat,
                helpers = {
                    renderMonth: $.proxy(proxy._getMonthTemplate, proxy),
                    getMonthWidth: $.proxy(proxy._setMonthWidthYearMode, proxy)
                };

            $.views.helpers(helpers);

            var parentTr = "<th  class='e-schedule-day-headercell' " +
                "style='-moz-box-sizing:border-box;box-sizing:border-box;'>";
            td = "<div class='e-schedule-day-headercell-content' style='"
                + "position:static;box-sizing:border-box;overflow:hidden;text-overflow:clip;width:{{:~getMonthWidth(0,#data)-1}}px;'>" +
                "{{:~renderMonth('" + monthFormat + "',0,#data)}}</div>" +

                "<th  class='e-schedule-day-headercell' " +
                "style='-moz-box-sizing:border-box;box-sizing:border-box;'>" +
                "<div class='e-schedule-day-headercell-content' style='position:static;box-sizing:border-box;overflow:hidden;text-overflow:clip;width:{{:~getMonthWidth(1,#data)-1}}px;'>" +
                "{{:~renderMonth('" + monthFormat + "',1,#data)}}</div>" +

                "<th  class='e-schedule-day-headercell' " +
                "style='-moz-box-sizing:border-box;box-sizing:border-box;'>" +
                "<div class='e-schedule-day-headercell-content' style='position:static;box-sizing:border-box;overflow:hidden;text-overflow:clip;width:{{:~getMonthWidth(2,#data)-1}}px;'>" +
                "{{:~renderMonth('" + monthFormat + "',2,#data)}}</div>" +

                "<th  class='e-schedule-day-headercell' " +
                "style='-moz-box-sizing:border-box;box-sizing:border-box;'>" +
                "<div class='e-schedule-day-headercell-content' style='position:static;box-sizing:border-box;overflow:hidden;text-overflow:clip;width:{{:~getMonthWidth(3,#data)-1}}px;'>" +
                "{{:~renderMonth('" + monthFormat + "',3,#data)}}</div>" +

                "<th  class='e-schedule-day-headercell' " +
                "style='-moz-box-sizing:border-box;box-sizing:border-box;'>" +
                "<div class='e-schedule-day-headercell-content' style='position:static;box-sizing:border-box;overflow:hidden;text-overflow:clip;width:{{:~getMonthWidth(4,#data)-1}}px;'>" +
                "{{:~renderMonth('" + monthFormat + "',4,#data)}}</div>" +

                "<th  class='e-schedule-day-headercell' " +
                "style='-moz-box-sizing:border-box;box-sizing:border-box;'>" +
                "<div class='e-schedule-day-headercell-content' style='position:static;box-sizing:border-box;overflow:hidden;text-overflow:clip;width:{{:~getMonthWidth(5,#data)-1}}px;'>" +
                "{{:~renderMonth('" + monthFormat + "',5,#data)}}</div>" +

                "<th  class='e-schedule-day-headercell' " +
                "style='-moz-box-sizing:border-box;box-sizing:border-box;'>" +
                "<div class='e-schedule-day-headercell-content' style='position:static;box-sizing:border-box;overflow:hidden;text-overflow:clip;width:{{:~getMonthWidth(6,#data)-1}}px;'>" +
                "{{:~renderMonth('" + monthFormat + "',6,#data)}}</div>" +

                "<th  class='e-schedule-day-headercell' " +
                "style='-moz-box-sizing:border-box;box-sizing:border-box;'>" +
                "<div class='e-schedule-day-headercell-content' style='position:static;box-sizing:border-box;overflow:hidden;text-overflow:clip;width:{{:~getMonthWidth(7,#data)-1}}px;'>" +
                "{{:~renderMonth('" + monthFormat + "',7,#data)}}</div>" +

                "<th  class='e-schedule-day-headercell' " +
                "style='-moz-box-sizing:border-box;box-sizing:border-box;'>" +
                "<div class='e-schedule-day-headercell-content' style='position:static;box-sizing:border-box;overflow:hidden;text-overflow:clip;width:{{:~getMonthWidth(8,#data)-1}}px;'>" +
                "{{:~renderMonth('" + monthFormat + "',8,#data)}}</div>" +

                "<th  class='e-schedule-day-headercell' " +
                "style='-moz-box-sizing:border-box;box-sizing:border-box;'>" +
                "<div class='e-schedule-day-headercell-content' style='position:static;box-sizing:border-box;overflow:hidden;text-overflow:clip;width:{{:~getMonthWidth(9,#data)-1}}px;'>" +
                "{{:~renderMonth('" + monthFormat + "',9,#data)}}</div>" +

                "<th  class='e-schedule-day-headercell' " +
                "style='-moz-box-sizing:border-box;box-sizing:border-box;'>" +
                "<div class='e-schedule-day-headercell-content' style='position:static;box-sizing:border-box;overflow:hidden;text-overflow:clip;width:{{:~getMonthWidth(10,#data)-1}}px;'>" +
                "{{:~renderMonth('" + monthFormat + "',10,#data)}}</div>" +

                "<th  class='e-schedule-day-headercell' " +
                "style='-moz-box-sizing:border-box;box-sizing:border-box;'>" +
                "<div class='e-schedule-day-headercell-content' style='position:static;box-sizing:border-box;overflow:hidden;text-overflow:clip;width:{{:~getMonthWidth(11,#data)-1}}px;'>" +
                "{{:~renderMonth('" + monthFormat + "',11,#data)}}</div>";

            
            parentTr += td;
            parentTr += "</th>";
            var templates = {};
            templates[proxy._id + "ScheduleMonthTemplate"] = parentTr;
            $.templates(templates);
        },

        _getMonthTemplate: function (monthFormat, monthLength, data) {

            var date = new Date(data),
                proxy = this, model = proxy.model;
            date.setMonth(date.getMonth() + monthLength);

            switch (monthFormat) {
                case "M":
                case "m":
                    return (('0' + date.getDate()).slice(-2));
                case "MM":
                case "mm":
                    return date.getDate();
                case "MMM":
                case "mmm":
                case "MMMM":
                case "mmmm":
                    return Globalize.format(date, monthFormat, model.locale);
                default: return Globalize.format(date, monthFormat, model.locale);
            }
        },

        //For year template set month width accordance with num of days
        _setMonthWidthYearMode: function (monthLength, data) {

            var proxy = this;
            var date=new Date(data);
            date.setMonth(date.getMonth() + monthLength);

            var monthLastDay = new Date(date.getFullYear(), date.getMonth() + 1, 0);

            var lastDate = monthLastDay.getDate();
            if (lastDate == 31)
                return (this.model.perDayWidth * 31);
            else if (lastDate == 30)
                return (this.model.perDayWidth * 30);
            else if (lastDate == 28)
                return (this.model.perDayWidth * 28);
            else if (lastDate == 29)
                return (this.model.perDayWidth * 29);

        },


        //Template to render schedule day view
        _createScheduleDayTemplate: function () {

            var proxy = this, td, model = proxy.model,
                dayFormat = model.scheduleHeaderSettings.dayHeaderFormat,
                helpers = {
                    renderDay: $.proxy(proxy._getDayTemplate, proxy)
                };

            $.views.helpers(helpers);

            var parentTr = "<th  class='e-schedule-day-headercell  e-headercell-weekend' " +
                "style='-moz-box-sizing:border-box;box-sizing:border-box;" +
                "background-color:" + this.model.scheduleHeaderSettings.weekendBackground + "'>";
            td = "<div class='e-schedule-day-headercell-content' style='width:"
                + (proxy.model.perDayWidth - 1) + "px;position:static;box-sizing:border-box;overflow:hidden;text-overflow:clip'>" +
                "{{:~renderDay('" + dayFormat + "',0,#data)}}</div>" +

                "<th  class='e-schedule-day-headercell' " +
                "style='-moz-box-sizing:border-box;box-sizing:border-box;'>" +
                "<div class='e-schedule-day-headercell-content' style='width:"
                + (proxy.model.perDayWidth - 1) + "px;position:static;box-sizing:border-box;overflow:hidden;text-overflow:clip'>" +
                "{{:~renderDay('" + dayFormat + "',1,#data)}}</div>" +

                "<th  class='e-schedule-day-headercell' " +
                "style='-moz-box-sizing:border-box;box-sizing:border-box;'>" +
                "<div class='e-schedule-day-headercell-content' style='width:"
                + (proxy.model.perDayWidth - 1) + "px;position:static;box-sizing:border-box;overflow:hidden;text-overflow:clip'>" +
                "{{:~renderDay('" + dayFormat + "',2,#data)}}</div>" +

                "<th  class='e-schedule-day-headercell' " +
                "style='-moz-box-sizing:border-box;box-sizing:border-box;'>" +
                "<div class='e-schedule-day-headercell-content' style='width:"
                + (proxy.model.perDayWidth - 1) + "px;position:static;box-sizing:border-box;overflow:hidden;text-overflow:clip'>" +
                "{{:~renderDay('" + dayFormat + "',3,#data)}}</div>" +

                "<th  class='e-schedule-day-headercell'" +
                " style='-moz-box-sizing:border-box;box-sizing:border-box;'>" +
                "<div class='e-schedule-day-headercell-content' style='width:"
                + (proxy.model.perDayWidth - 1) + "px;position:static;box-sizing:border-box;overflow:hidden;text-overflow:clip'>" +
                "{{:~renderDay('" + dayFormat + "',4,#data)}}</div>" +

                "<th  class='e-schedule-day-headercell'" +
                " style='-moz-box-sizing:border-box;box-sizing:border-box;'>" +
                "<div class='e-schedule-day-headercell-content' style='width:"
                + (proxy.model.perDayWidth - 1) + "px;position:static;box-sizing:border-box;overflow:hidden;text-overflow:clip'>" +
                "{{:~renderDay('" + dayFormat + "',5,#data)}}</div>" +

                "<th  class='e-schedule-day-headercell  e-headercell-weekend' " +
                "style='-moz-box-sizing:border-box;box-sizing:border-box;" +
                "background-color:" + this.model.scheduleHeaderSettings.weekendBackground + "'>" +
                "<div class='e-schedule-day-headercell-content' style='width:"
                + (proxy.model.perDayWidth - 1) + "px;position:static;box-sizing:border-box;overflow:hidden;text-overflow:clip'>" +
                "{{:~renderDay('" + dayFormat + "',6,#data)}}</div>";

            parentTr += td;
            parentTr += "</th>";
            var templates = {};
            templates[proxy._id + "_CustomTemplate1"] = parentTr;
            $.templates(templates);
        },

        _getDayTemplate: function (dayFormat, dayLength, data) {

            var date = new Date(data),
                proxy = this, model = proxy.model;
            date.setDate(date.getDate() + dayLength);

            switch (dayFormat) {
                case "D":
                case "d":
                    return (('0' + date.getDate()).slice(-2));
                case "DD":
                case "dd":
                    return date.getDate();
                case "DDD":
                case "ddd":
                case "DDDD":
                case "dddd":
                    return Globalize.format(date, dayFormat, model.locale)[0].toUpperCase();
                default: return Globalize.format(date, dayFormat, model.locale)[0].toUpperCase();
            }
        },


        //Method to render schedule header
        _createSchedule: function (startdate, enddate) {

            var proxy = this,
                model=proxy.model,
                scheduleMode = model.scheduleHeaderSettings.scheduleHeaderType,
                $colsgroup, $column, $thead,
                $tr, $td, $div, $table;

            startdate = startdate == null ? new Date() : startdate;
            enddate = enddate == null ? new Date(null) : enddate;

            proxy._createScheduleWeekTemplate();
            proxy._createScheduleYearTemplate();
            proxy._createScheduleTopMonthTemplate();//template for MONTH week schedule mode
            proxy._createScheduleTopDayTemplate();

            $table = ej.buildTag("table.e-schedule-headerrow-week", "",
                { 'display': 'block' },
                { 'cell-spacing': '0' }
            );

            $colsgroup = ej.buildTag("colgroup", "", {}, {});
            $column = $(document.createElement("col"));
            $column.css("width", proxy._getScheduleLength(scheduleMode) + 'px');
            
            $colsgroup.append($column);

            $thead = ej.buildTag("thead.e-ejganttschedule", "",
                { 'display': 'block', 'border-collapse': 'collapse' }, {});

            if (scheduleMode == "week")
                $tr = ej.buildTag("tr", $.render[this._id + "ScheduleWeekTemplate"](proxy.model.scheduleWeeks), {}, {});
            else if (scheduleMode == "year")
                $tr = ej.buildTag("tr", $.render[this._id + "ScheduleYearTemplate"](proxy.model.scheduleYears), {}, {});
            else if (scheduleMode == "month")
                $tr = ej.buildTag("tr", $.render[this._id + "ScheduleTopMonthTemplate"](proxy.model.scheduleMonths), {}, {});
            else if (scheduleMode == "day")
                $tr = ej.buildTag("tr", $.render[this._id + "ScheduleTopDayTemplate"](proxy.model.scheduleDays), {}, {});

            $td = ej.buildTag("th.schedule", "", {}, {});
            $div = ej.buildTag("div.schedule", "", { 'width': 20 + 'px' }, {});
            $td.append($div);
            $tr.append($td);

            $thead.append($tr);
            $table.append($colsgroup);
            $table.append($thead);
            proxy._$scheduleDiv.append($table);

            $tr = null;

            proxy._createScheduleDayTemplate();
            proxy._createScheduleMonthTemplate();//for year - month schedule mode
            proxy._createScheduleBottomWeekTemplate(); //for month - week schedule mode

            proxy._createScheduleHourTemplate();

            $table = ej.buildTag("table.e-schedule-headerrow-day", "",
                {
                    'display': 'block',
                    'border-collapse': 'collapse'
                }, { 'cell-spacing': '0' });
            $thead = ej.buildTag("thead.e-ejganttschedule", "",
                { 'display': 'block', 'border-collapse': 'collapse' }, {});
            
            if (scheduleMode == "week")
                $tr = ej.buildTag("tr", $.render[this._id + "_CustomTemplate1"](proxy.model.scheduleWeeks), {}, {});
            if (scheduleMode == "year")
                $tr = ej.buildTag("tr", $.render[this._id + "ScheduleMonthTemplate"](proxy.model.scheduleYears), {}, {});
            if (scheduleMode == "month")
                $tr = ej.buildTag("tr", $.render[this._id + "ScheduleBottomWeekTemplate"](proxy._numOfWeeks), {}, {});
            if (scheduleMode == "day")
                $tr = ej.buildTag("tr", $.render[this._id + "scheduleHourTemplate"](proxy._getScheduleHours()), {}, {});

            $td = ej.buildTag("th.schedule", "", {}, {});
            $div = ej.buildTag("div.schedule", "", { 'width': 20 + 'px' }, {});
            $td.append($div);
            $tr.append($td);

            $thead.append($tr);
            $table.append($colsgroup);
            $table.append($thead);
            proxy._$scheduleDiv.append($table);

            proxy._$headerContainer.append(proxy._$scheduleDiv);
            proxy._$ganttChartContainer.append(proxy._$headerContainer);
            $("#" + proxy._id).append(proxy._$ganttChartContainer);
        },

        _getScheduleHours: function () {
            var proxy = this, model = proxy.model,
                startHour = new Date(proxy.model.projectStartDate),
                endHour = new Date(model.projectEndDate);
                proxy._scheduleHours = [];
                endHour.setHours(24);
            do {
                proxy._scheduleHours.push(new Date(startHour));
                startHour.setHours(startHour.getHours() + 1);
            } while (!(startHour.getTime()>= endHour.getTime()));

            return proxy._scheduleHours;
        },

        createGridLinesTable: function () {
            var proxy=this,
                model = proxy.model,
                $gridLinesTable,
                gridLineTable,
                scheduleMode = model.scheduleHeaderSettings.scheduleHeaderType,
                scheduleLength,
                tableRows;

            $gridLinesTable = ej.buildTag("table.e-ganttgridLinesTable#ganttgridLinesTable" + proxy._id, "", {
                'z-index': '2',
                'position': 'absolute',
            }, { 'cellspacing': '0px' });
            var $colsgroup = ej.buildTag("colgroup", "", {}, {});
            var $column = $(document.createElement("col"));

            switch (scheduleMode) {
                case "week":
                    scheduleLength = model.scheduleWeeks.length,
                    $gridLinesTable.css("width",(scheduleLength * proxy._scheduleWeekWidth) + 'px');
                    $column.css("width", (scheduleLength * this._scheduleWeekWidth) + 'px');
                    break;

                case "year":
                    scheduleLength = model.scheduleYears.length,                    
                    $gridLinesTable.css("width", (proxy._scheduleYearWidth) + 'px');
                    $column.css("width", (this._scheduleYearWidth) + 'px');

                    break;
                case "month":
                    scheduleLength = model.scheduleMonths.length,
                    $gridLinesTable.css("width", (proxy._scheduleMonthWidth) + 'px');
                    $column.css("width", (this._scheduleMonthWidth) + 'px');
                    break;
                case "day":
                    scheduleLength = model.scheduleDays.length,
                    $gridLinesTable.css("width", (scheduleLength * (proxy.model.perHourWidth*24)) + 'px');
                    $column.css("width", (scheduleLength * (proxy.model.perHourWidth * 24)) + 'px');
                    break;
                default:
                    break;

            }

            $colsgroup.append($column);
            $gridLinesTable.append($colsgroup);

            tableRows = proxy._createGridLinesTableRow(model.updatedGanttRecords.length);
            
            var $gridLinesTablebody = ej.buildTag("tbody.e-gantt-viewer-gridLinesTablebody#gridLinesTablebody" + proxy._id + "",
                tableRows, {}, {});
            proxy._$gridLinesTablebody = $gridLinesTablebody;
            $gridLinesTable.append(proxy._$gridLinesTablebody);
            proxy._$bodyContent.append($gridLinesTable);
        },


        _createGridLinesTableRow: function (length) {
            var proxy = this,
                tableRows="";

            for (var i = 0; i < length; i++) {
                tableRows += "<tr style='display:table-row;height:" + this.model.rowHeight + "px'><td class='e-ganttgridlines'></td></tr>"
            }
            return tableRows;
        },


        //Template to render taskbar and milestone items
        _createTaskbarTemplate: function () {

            var proxy = this,
                model = proxy.model,
                tdWidth,
                scheduleMode = model.scheduleHeaderSettings.scheduleHeaderType,
                tr, baselineHeight = 4, taskbarHeight,
                shrinkedTaskbarHeight = 0,
                baselineColor = model.baselineColor,
                helpers = {
                    _getType: proxy._getTypedata,
                    _expander: proxy._addRecordExpandCollapse,
                    _milestoneMapping: proxy._isMilestone,
                    _resources: $.proxy(proxy._getResourceInfo, proxy),
                    _rowClassName: ej.TreeGrid._getrowClassName,//proxy._getrowClassName,
                    _expandStatus: $.proxy(proxy._getExpandStatusRecord, proxy),
                    _borderRadius: proxy._getBorderRadius,
                };

            if (scheduleMode == "week") {
                tdWidth = proxy.model.scheduleWeeks.length * proxy._scheduleWeekWidth;
            }
            else if (scheduleMode == "year") {
                tdWidth = proxy._scheduleYearWidth;
            }
            else if (scheduleMode == "month") {
                tdWidth = proxy._scheduleMonthWidth;
            }
            else if (scheduleMode == "day") {
                tdWidth = proxy.model.scheduleDays.length * (proxy.model.perHourWidth*24);
            }

            if (model.renderBaseline) {
                //taskbarHeight = model.rowHeight - 10;
                taskbarHeight = model.rowHeight - baselineHeight - 5;
                shrinkedTaskbarHeight = 0;
            } else {
                taskbarHeight = model.rowHeight - 10;
            }

            $.views.helpers(helpers);

            if (!model.progressMapping) {


                this.model.showProgressStatus = false;
            }

            if (!model.resourceInfoMapping) {
                model.showResourceNames = false;
            }

            var parentTr = "<tr class='{{:~_rowClassName()}}  {{if isSelected}}e-ganttrowcell {{:~_expander()}} e-gantt-mouseclick{{else}}e-ganttrowcell {{:~_expander()}}{{/if}}' id='chartrowcell"
                + proxy._id + "' style='display:{{:~_expandStatus(#data)}};background-color:{{if rowBGColor }}{{:rowBGColor}}{{else}} none{{/if}};'>";
            var radius = "{{:~_borderRadius()}}";

            tr = "{{if ~_getType()}}" +

                //Parent taskbar Item

                "{{if " + this.model.showTaskNames + "}}<td class='e-chartcell'>" +
                "<div class='e-tasknameContainer'  unselectable='on' style='left:-{{:width}}px;width:{{:left+width}}px;'>" +
                "<span class='e-taskbarname'  style='margin-top:" + ((this.model.rowHeight) / 2) + "px;margin-right:30px;" +
                "font-weight:bold'>{{:taskName}}</span></div></td>{{/if}}" +

                "<td  class='e-chartcell' vertical-align='middle' style='width:" + tdWidth + "px;'>" +

               "<div class='e-parentContainer' unselectable='on' style='height:" + (this.model.rowHeight-1) + "px;z-index:3;'>" +

                "<div class='e-connectorpoint-left' style='left:{{:left-10}}px;width:10px;margin-top:10px;height:" + (taskbarHeight / 2) + "px;'></div>" +

                "<div class='e-gantt-parenttaskbar-innerdiv {{:~_expander()}}' style='left:{{:left}}px;margin-top:5px;width:{{:width}}px;height:"
                + (taskbarHeight) + "px;background-color:{{if parentTaskbarBackground }}{{:parentTaskbarBackground}}{{else}} " + this.model.parentTaskbarBackground + "{{/if}} ;'></div>" +
                "<div  class='e-gantt-parenttaskbar-progress {{:~_expander()}}  progressbar' id='progressbar' " +
                "style='margin-top:5px;border-style:{{if progressWidth}}solid{{else}}none{{/if}}; left:{{:left}}px;width:{{:progressWidth}}px;height:" + (taskbarHeight)
                + "px;position:absolute;background-color:{{if parentProgressbarBackground }}{{:parentProgressbarBackground}}{{else}} " + this.model.parentProgressbarBackground + "{{/if}};z-index:3;" +
                "border-top-right-radius:" + radius + "px;border-bottom-right-radius:" + radius + "px;'></div>" +

                  "<div class='e-connectorpoint-right' style='left:{{:left+width}}px;width:10px;margin-top:10px;height:" + (taskbarHeight / 2) + "px;'></div>" +

             "</div>" +

                "{{if " + this.model.renderBaseline + " }}" +
                "<div  class='e-baselinebar' style='margin-top:-4px;left:{{:baselineLeft}}px;" +
                "width:{{:baselineWidth}}px;height:" + baselineHeight + "px;background-color: " + baselineColor + ";" +
                "position:absolute;z-index:3;box-sizing:border-box;-moz-box-sizing:border-box;'></div>{{/if}}" +

                "</td>" +

               "{{if " + this.model.showResourceNames + "}}<td class='e-chartcell' >" +
                "<div class='e-resourceinfo'  unselectable='on' style='margin-top:5px;left:{{:left+width+30}}px;" +
                "margin:0;margin-left:5px;margin-top:-9px;position:absolute;background-color:transparent;font-weight:bold'>" +
                "<span class='e-resourcename'  style='margin-top:" + ((this.model.rowHeight) / 2) + "px;margin-right:30px;outline:none;'>"
                + "{{:~_resources(#data)}}" + "</span></div></td>{{/if}}" +


               //Milestone Item

                "{{else ~_milestoneMapping()}}" +
                    
                "{{if " + this.model.showTaskNames + "}}<td class='e-chartcell'>" +
                "<div class='e-tasknameContainer'  unselectable='on' style='left:-{{:width}}px;width:{{:left+width}}px;'>" +
                "<span class='e-taskbarname'  style='margin-top:" + ((this.model.rowHeight) / 2) + "px;margin-right:30px;'>" +
                "{{:taskName}}</span></div></td>{{/if}}" +

               "<td class='e-chartcell' style='width:" + tdWidth + "px;'>" +
                "<div class='e-gantt-milestone-container' style=height:" + (this.model.rowHeight - 1) + "px;>" +
                "<div class='e-connectorpoint-left' style='left:{{:left-10}}px;width:10px;margin-top:10px;height:" + (taskbarHeight / 2) + "px;'></div>" +
                "<div class='e-gantt-milestone' style='position:absolute;left:{{:left}}px;'>" +
                "<div class='e-gantt-milestone milestone-top'  style='top:" + (3) + "px;'></div>" +
                "<div class='e-gantt-milestone milestone-bottom'  style='top:" + (15) + "px;'></div>" +
                "</div>"+
                 "<div class='e-connectorpoint-right' style='left:{{:left+24}}px;width:10px;margin-top:10px;height:" + (taskbarHeight / 2) + "px;'></div>" +
                "</div>" +

                "{{if " + this.model.renderBaseline + " }}" +
                "<div class='e-baseline-gantt-milestone-container' >" +
                "<div class='e-baseline-gantt-milestone' style='position:absolute;left:{{:baselineLeft}}px;z-index:2;'>" +
                "<div class='e-baseline-gantt-milestone baseline-milestone-top'  " +
                "style=' border-bottom-color: " + baselineColor + ";z-index:2;top:" + (-26) + "px;'></div>" +
                "<div class='e-baseline-gantt-milestone baseline-milestone-bottom'  " +
                "style=' border-top-color: " + baselineColor + ";z-index:2;top:" + (-14) + "px;'></div>" +
                "</div></div>{{/if}}" +

                "</td>" +

               "{{if " + this.model.showResourceNames + "}}<td class='e-chartcell' >" +
                "<div class='e-resourceinfo'  unselectable='on' style='margin-top:5px;left:{{:left+56}}px;margin:0;margin-left:5px;margin-top:-9px;" +
                "position:absolute;background-color:transparent;'><span class='e-resourcename'  style='margin-top:"
                + ((this.model.rowHeight) / 2) + "px;margin-right:30px;'>" + "{{:~_resources(#data)}}" + "</span></div></td>{{/if}}" +

                //Child Taskbar Item

                "{{else}}" +

                //left label
               "{{if " + this.model.showTaskNames + "}}<td class='e-chartcell'>" +
                "<div class='e-tasknameContainer'  unselectable='on' style='left:-{{:width}}px;width:{{:left+width}}px;'>" +
                "<span class='e-taskbarname'  style='margin-top:" + ((this.model.rowHeight) / 2) + "px;margin-right:30px;'>" +
                "{{:taskName}}</span></div></td>{{/if}}" +

                //taskbar
               "<td class='e-chartcell' style='width:" + tdWidth + "px;'>" +

               

               "<div  class='e-childContainer'  unselectable='on' style='height:" + (this.model.rowHeight - 1) + "px;'>" +

               "<div class='e-connectorpoint-left' style='left:{{:left-10}}px;width:10px;margin-top:10px;height:" + (taskbarHeight/2) + "px;'></div>"+

              "<div class='taskbarresizer-left e-icon' style='left:{{:left+2}}px;width:10px;margin-top:5px;height:" + (taskbarHeight) + "px;'></div>" +
            
               "<div  class='e-gantt-childtaskbar' style='left:{{:left}}px;width:{{:width}}px;height:"
                + (taskbarHeight) + "px;background-color:{{if taskbarBackground }}{{:taskbarBackground}}{{else}} " + this.model.taskbarBackground + "{{/if}};" + "margin-top:5px;'></div>" +

               "<div  class='e-gantt-childtaskbar-progress  progressbar' id='progressbar' style='border-style:{{if progressWidth}}solid{{else}}none{{/if}}; left:{{:left}}px;" +
                "width:{{:progressWidth}}px;text-align:right;line-height:" + (taskbarHeight) + "px;margin-top:5px;" +
                //"margin-top:" + (((taskbarHeight) - (this.model.progressbarHeight * ((taskbarHeight) / 100))) / 2) + "px;" +
                "height:" + (this.model.progressbarHeight * ((taskbarHeight) / 100)) + "px;" +
                "position:absolute;background-color:{{if progressbarBackground }}{{:progressbarBackground}}{{else}} " + this.model.progressbarBackground + "{{/if}};" +
                "border-top-right-radius:" + radius + "px;border-bottom-right-radius:" + radius + "px;'>" +
                "{{if " + this.model.showProgressStatus + "}}<span class='e-tasklabel' style=''>{{:status}}%</span>{{/if}}</div>" +

               "<div class='progressbarresizer-right' style='left:{{:left+progressWidth-10}}px;width:20px;margin-top:5px;" +
                "height:" + (taskbarHeight) + "px;position:absolute;z-index:4;'>" +
               "<div class='progressbarresizer-right' style='top:" + (22 - (shrinkedTaskbarHeight / 2)) + "px;margin-top:5px;position:absolute;'><div class='e-progresshandler-element'></div></div>" +//-" + (shrinkedTaskbarHeight/2) + "
               "<div class='progressbarresizer-right' style='top:" + (17 - (shrinkedTaskbarHeight / 2)) + "px;margin-top:5px;position:absolute;'><div class='e-progresshandlerafter-element'></div></div></div>" +

               "<div class='taskbarresizer-right e-icon' style='left:{{:left+width-12}}px;width:10px;" +
                "height:" + (taskbarHeight) + "px;position:absolute;z-index:2;margin-top:5px;'></div>" +
               
                "<div class='e-connectorpoint-right' style='left:{{:left+width}}px;width:10px;margin-top:10px;height:" + (taskbarHeight / 2) + "px;'></div>" +
                //"<div class='e-connectorpoint-right' style='left:{{:left-20}}px;width:20px;margin-top:10px;background-color:black;height:" + (taskbarHeight) + "px;'></div>"+
                 "</div>" +

                "{{if " + this.model.renderBaseline + " }}" +
                "<div  class='e-baselinebar' style='margin-top:-4px;left:{{:baselineLeft}}px;" +
                "width:{{:baselineWidth}}px;height:" + baselineHeight + "px;background-color: " + baselineColor + ";" +
                "position:absolute;z-index:3;box-sizing:border-box;-moz-box-sizing:border-box;'></div>{{/if}}" +

                "</td>" +

                //right label
               "{{if " + this.model.showResourceNames + "}}<td class='e-chartcell' >" +
                "<div class='e-resourceinfo'  unselectable='on' style='left:{{:left+width+30}}px;margin:0;margin-left:5px;margin-top:-9px;" +
                "position:absolute;text-align:left;background-color:transparent;'><span class='e-resourcename'  style='margin-top:" + ((this.model.rowHeight) / 2) + "px;margin-right:30px;'>" +
                "{{:~_resources(#data)}}" + "</span></div></td>{{/if}}{{/if}}";

            parentTr += tr;
            parentTr += "</tr>";

            var templates = {};
            templates[this._id + "_CustomTemplate2"] = parentTr;
            $.templates(templates);

        },

        _getResourceInfo: function (data) {
            var resource = null;
            if (data.resourceInfo != null) {
                var resourcelength = data.resourceInfo.length;
                if (resourcelength > 0) {
                    for (var i = 0; i < resourcelength; i++) {
                        if (resource == null)
                            resource = data.resourceInfo[i][this.model.resourceNameMapping];
                        else
                            resource += " , " + data.resourceInfo[i][this.model.resourceNameMapping];
                    }
                    return resource;
                } else
                    return data.resourceInfo[0][this.model.resourceNameMapping];
            }
            return String.empty;
        },

        _getrowClassName: function () {
            var rowClass = "gridrowtaskId",
                proxy = this;
            if (proxy.data.parentItem)
                rowClass += proxy.data.parentItem.taskId.toString();
            rowClass += "level";
            rowClass += proxy.data.level.toString();
            return rowClass;
        },

        _getExpandStatusRecord: function (data) {
            var proxy = this;
            if (proxy._getExpandStatus(data)) {
                return 'table-row';
            }
            return 'none';
        },


        _isMilestone: function () {
            if (this.data.isMilestone)
                return true;
            else
                return false;
        },

        _addRecordExpandCollapse: function () {
            if (this.data.expanded)
                return 'e-chartexpand';
            else if (!this.data.expanded && this.data.hasChildRecords) {
                return 'e-chartcollapse';
            }
            return false;
        },

        _getTypedata: function () {
            return this.data.hasChildRecords;
        },


        _getBorderRadius: function () {

            var proxy = this,
                diff = proxy.data.width - proxy.data.progressWidth;

            if (diff <= 4) {
                return 4 - diff;
            }
            else
                return 0;

        },


        _createConnectorLineTemplate: function () {
            var proxy = this,
                lineStroke = this.model.connectorlineWidth,
                shrinkedTaskbarHeight = 0,
                deltaTop, taskbarMidpoint,
                lineColor = this.model.connectorLineBackground,
                helpers = {
                    _getWidthVal: proxy._getWidth,
                    _getTop: proxy._getPredecessorTop,
                    _getPosition: proxy._getParentPosition,
                    _setContainerWidthSSType2: proxy._getContainerWidthSSType2,
                    _setInnerChildWidthSSType2: proxy._getInnerChildWidthSSType2,
                    _setInnerElementLeftSSType2: proxy._getInnerElementLeftSSType2,
                    _setInnerElementWidthSSType2: proxy._getInnerElementWidthSSType2,
                    _isMilestone: proxy._isTaskMilestone,
                    _isMilestoneParent: proxy._isMilestoneParent,
                };

            if (proxy.model.renderBaseline) {
                deltaTop = shrinkedTaskbarHeight / 2;
                taskbarMidpoint = ((this.model.rowHeight) / 2) - deltaTop;
            } else {
                taskbarMidpoint = ((this.model.rowHeight) / 2);
            }

            $.views.helpers(helpers);
            var connectorContainer = "<div  id='ConnectorLine{{:ConnectorLineId}}' style='background-color=black'>";

            var div = "{{if ~_getPosition()=='FSType1'}}"//FS
            + "<div style='left:{{:ParentLeft+ParentWidth}}px;top:{{:ParentTop+" + taskbarMidpoint + "}}px;" +
                "width:{{:(ChildLeft - (ParentLeft + ParentWidth + 20))}}px;height:{{:Height}}px;position:absolute'>"
            + "<div class='e-line' style='left:{{if milestoneParent}}-7px{{else}}0px{{/if}};width:{{if milestoneParent}}{{:(ChildLeft-(ParentLeft + ParentWidth + 10))+" + lineStroke + "-2}}px{{else}}{{:(ChildLeft-(ParentLeft + ParentWidth + 10))+" + lineStroke + "-10}}px{{/if}};" +
                "height:" + lineStroke + "px;background-color:" + lineColor + ";position:relative'></div>"
            + "<div class='e-line' style='left:{{:(ChildLeft-(ParentLeft + ParentWidth + 10))+" + lineStroke + "-10}}px;" +
                "width:" + lineStroke + "px;height:{{:Height-" + lineStroke + "}}px;background-color:" + lineColor + ";position:relative'></div>"
            + "<div class='e-line' style='left:{{:(ChildLeft-(ParentLeft + ParentWidth + 10))+" + lineStroke + "-10}}px;width:10px;" +
                "height:" + lineStroke + "px;background-color:" + lineColor + ";position:relative'></div>"
            + "<div class='connectorline-rightarrow' style='left:{{:(ChildLeft - (ParentLeft + ParentWidth + 10))}}px;" +
                "border-left: 10px solid " + lineColor + ";top:{{:-6-" + lineStroke + "}}px;" +
                "border-bottom-width:{{:5+" + lineStroke + "}}px;border-top-width:{{:5+" + lineStroke + "}}px;width:0;height:0;position:relative'></div>"
            + "</div>"

            + "{{else  ~_getPosition()=='FSType2'}}"//FS
            + "<div style='left:{{:ParentLeft}}px;top:{{:ParentTop+" + taskbarMidpoint + "}}px;" +
                "width:{{:~_getWidthVal()}}px;height:{{:Height}}px;position:absolute'>"
            + "<div class='e-line' style='left:{{if milestoneParent}}{{:ParentWidth-7}}px{{else}}{{:ParentWidth}}px{{/if}};width:{{if milestoneParent}}17px{{else}}10px{{/if}};height:" + lineStroke + "px;background-color:" + lineColor + ";position:relative'></div>"
            + "<div class='e-line' style='left:{{:ParentWidth+10-" + lineStroke + "}}px;width:" + lineStroke + "px;" +
                "height:{{:Height-14-" + lineStroke + "}}px;background-color:" + lineColor + ";" +
                "position:relative'></div><div class='e-line' style='left:{{:(ParentWidth - (((ParentLeft + ParentWidth) - ChildLeft) + 20))}}px;" +
                "width:{{:(((ParentLeft + ParentWidth) - ChildLeft) + 30 )}}px;height:" + lineStroke + "px;" +
                "background-color:" + lineColor + ";position:relative'></div>"
            + "<div class='e-line' style='left:{{:(ParentWidth - (((ParentLeft + ParentWidth) - ChildLeft) + 20))}}px;width:" + lineStroke + "px;" +
                "height:{{:14-" + lineStroke + "}}px;background-color:" + lineColor + ";position:relative'></div>"
            + "<div class='e-line' style='left:{{:(ParentWidth - (((ParentLeft + ParentWidth) - ChildLeft) + 20))}}px;width:10px;" +
                "height:" + lineStroke + "px;background-color:" + lineColor + ";position:relative'></div>"
            + "<div class='connectorline-rightarrow' style='left:{{:(ParentWidth - (((ParentLeft + ParentWidth) - ChildLeft) + 10))}}px;" +
                "border-left: 10px solid " + lineColor + ";border-bottom-width:{{:5+" + lineStroke + "}}px;" +
                "border-top-width:{{:5+" + lineStroke + "}}px;top:{{:-6-" + lineStroke + "}}px;width:0;height:0;position:relative'></div>"
            + "</div>"

            + "{{else ~_getPosition()=='FSType3'}}"
            + "<div style='left:{{:ChildLeft-20}}px;top:{{:ChildTop+" + taskbarMidpoint + "}}px;" +
                "width:{{:ParentWidth+ChildWidth}}px;height:{{:Height}}px;position:absolute'>"
            + "<div class='connectorline-rightarrow' style='left:10px;border-left: 10px solid " + lineColor + ";" +
                "border-bottom-width:{{:5+" + lineStroke + "}}px;border-top-width:{{:5+" + lineStroke + "}}px;" +
                "top:{{:-6-" + lineStroke + "}}px;width:0;height:0;position:relative'></div>"
            + "<div class='e-line' style='width:10px;height:" + lineStroke + "px;background-color:" + lineColor + ";" +
                "position:relative;top:-13px;'></div>"
            + "<div class='e-line' style='width:" + lineStroke + "px;height:{{:Height-14-" + lineStroke + "}}px;" +
                "background-color:" + lineColor + ";position:relative;top:-13px;'></div>"
            + "<div class='e-line' style='width:{{:(((ParentLeft + ParentWidth) - ChildLeft) + 30)}}px;height:" + lineStroke + "px;" +
                "background-color:" + lineColor + ";position:relative;top:-13px;'></div>"
            + "<div class='e-line' style='left:{{:(((ParentLeft + ParentWidth) - ChildLeft) + 30)}}px;width:" + lineStroke + "px;" +
                "height:{{:12-" + lineStroke + "}}px;background-color:" + lineColor + ";position:relative;" +
                "top:-13px;'></div>"
            + "<div class='e-line' style='left:{{:(((ParentLeft + ParentWidth) - ChildLeft) + 20)}}px;width:10px;height:" + lineStroke + "px;" +
                "background-color:" + lineColor + ";position:relative;top:-13px;'></div>"
            + "</div>"

            + "{{else ~_getPosition()=='FSType4'}}"
            + "<div style='left:{{:ParentLeft+ParentWidth}}px;top:{{:ChildTop+" + taskbarMidpoint + "}}px;" +
                "width:{{:(ChildLeft - (ParentLeft + ParentWidth + 20))}}px;height:{{:Height}}px;position:absolute'>"
            + "<div class='connectorline-rightarrow' style='left:{{:(ChildLeft - (ParentLeft + ParentWidth + 10))}}px;" +
                "border-left: 10px solid " + lineColor + ";top:{{:-6-" + lineStroke + "}}px;" +
                "border-bottom-width:{{:5+" + lineStroke + "}}px;border-top-width:{{:5+" + lineStroke + "}}px;width:0;height:0;position:relative'></div>"
            + "<div class='e-line' style='left:{{:(ChildLeft - (ParentLeft + ParentWidth) - 20)}}px;top:-13px;width:10px;" +
                "height:" + lineStroke + "px;background-color:" + lineColor + ";position:relative'></div>"
            + "<div class='e-line' style='top:-13px;left:{{:(ChildLeft - (ParentLeft + ParentWidth) - 20)}}px;width:" + lineStroke + "px;" +
                "height:{{:Height-" + lineStroke + "}}px;background-color:" + lineColor + ";position:relative'></div>"
            + "<div class='e-line' style='{{if ~_isMilestoneParent()}}left:-6px;{{/if}}top:-13px;width:{{if ~_isMilestoneParent()}}{{:(ChildLeft-(ParentLeft + ParentWidth+20 )+ 6)+" + lineStroke + "}}px;{{else}}{{:(ChildLeft-(ParentLeft + ParentWidth + 20))+" + lineStroke + "}}px;{{/if}}" +
                "height:" + lineStroke + "px;background-color:" + lineColor + ";position:relative'></div>"
            + "</div>"

            + "{{else ~_getPosition()=='SSType4'}}"
            + "<div  style='left:{{:ParentLeft-10}}px;top:{{:ChildTop+" + taskbarMidpoint + "}}px;" +
                "width:{{:ChildLeft-ParentLeft}}px;height:{{:Height}}px;position:absolute'>"
            + "<div class='connectorline-rightarrow' style='left:{{:ChildLeft-ParentLeft}}px;border-left: 10px solid " + lineColor + ";" +
                "top:{{:-6-" + lineStroke + "}}px;border-bottom-width:{{:5+" + lineStroke + "}}px;" +
                "border-top-width:{{:5+" + lineStroke + "}}px;width:0;height:0;position:relative'></div>"
            + "<div class='e-line' style='top:-13px;width:{{:ChildLeft-ParentLeft}}px;height:" + lineStroke + "px;" +
                "background-color:" + lineColor + ";position:relative'></div>"
            + "<div class='e-line' style='top:-13px;width:" + lineStroke + "px;height:{{:Height-" + lineStroke + "}}px;" +
                "background-color:" + lineColor + ";position:relative'></div>"
            + "<div class='e-line' style='top:-13px;width:10px;height:" + lineStroke + "px;background-color:" + lineColor + ";position:relative'></div>"
            + "</div>"

            + "{{else ~_getPosition()=='SSType3'}}"
            + "<div  style='left:{{:ChildLeft-20}}px;top:{{:ChildTop+" + taskbarMidpoint + "}}px;" +
                "width:{{:ParentLeft-ChildLeft}}px;height:{{:Height}}px;position:absolute'>"
            + "<div class='connectorline-rightarrow' style='left:10px;border-left: 10px solid " + lineColor + ";" +
                "top:{{:-6-" + lineStroke + "}}px;border-bottom-width:{{:5+" + lineStroke + "}}px;" +
                "border-top-width:{{:5+" + lineStroke + "}}px;width:0;height:0;position:relative'></div>"
            + "<div class='e-line' style='top:-13px;width:10px;height:" + lineStroke + "px;background-color:" + lineColor + ";position:relative'></div>"
            + "<div class='e-line' style='top:-13px;width:" + lineStroke + "px;height:{{:Height-" + lineStroke + "}}px;" +
                "background-color:" + lineColor + ";position:relative'></div>"
            + "<div class='e-line' style='top:-13px;width:{{:ParentLeft-ChildLeft+20}}px;height:" + lineStroke + "px;" +
                "background-color:" + lineColor + ";position:relative'></div>"
            + "</div>"

            + "{{else ~_getPosition()=='SSType2'}}"
            + "<div  style='left:{{:~_setInnerElementLeftSSType2()}}px;top:{{:ParentTop+" + taskbarMidpoint + "}}px;" +
                "width:{{:~_setContainerWidthSSType2()}}px;height:{{:Height}}px;position:absolute'>"
            + "<div class='e-line' style='width:{{:~_setInnerChildWidthSSType2()}}px;height:" + lineStroke + "px;" +
                "background-color:" + lineColor + ";position:relative'></div>"
            + "<div class='e-line' style='width:" + lineStroke + "px;height:{{:Height-" + lineStroke + "}}px;" +
                "background-color:" + lineColor + ";position:relative'></div>"
            + "<div class='e-line' style='width:{{:~_setInnerElementWidthSSType2()}}px;height:" + lineStroke + "px;" +
                "background-color:" + lineColor + ";position:relative'></div>"
            + "<div class='connectorline-rightarrow' style='left:{{:~_setInnerElementWidthSSType2()}}px;" +
                "border-left: 10px solid " + lineColor + ";top:{{:-6-" + lineStroke + "}}px;" +
                "border-bottom-width:{{:5+" + lineStroke + "}}px;border-top-width:{{:5+" + lineStroke + "}}px;width:0;" +
                "height:0;position:relative'></div>"
            + "</div>"

            + "{{else ~_getPosition()=='SSType1'}}"
            + "<div  style='left:{{:ChildLeft-20}}px;top:{{:ParentTop+" + taskbarMidpoint + "}}px;" +
                "width:{{:ParentLeft-ChildLeft}}px;height:{{:Height}}px;position:absolute'>"
            + "<div class='e-line' style='width:{{:ParentLeft-ChildLeft+20}}px;height:" + lineStroke + "px;" +
                "background-color:" + lineColor + ";position:relative'></div>"
            + "<div class='e-line' style='width:" + lineStroke + "px;height:{{:Height-" + lineStroke + "}}px;" +
                "background-color:" + lineColor + ";position:relative'></div>"
            + "<div class='e-line' style='width:10px;height:" + lineStroke + "px;background-color:" + lineColor + ";" +
                "position:relative'></div>"
            + "<div class='connectorline-rightarrow' style='left:10px;border-left: 10px solid " + lineColor + ";" +
                "top:{{:-6-" + lineStroke + "}}px;border-bottom-width:{{:5+" + lineStroke + "}}px;" +
                "border-top-width:{{:5+" + lineStroke + "}}px;width:0;height:0;position:relative'></div>"
            + "</div>"

            + "{{else ~_getPosition()=='FFType1'}}"
            + "<div class='FFtype1' style='left:{{:ChildLeft+ChildWidth}}px;top:{{:ParentTop+" + taskbarMidpoint + "}}px;" +
                "width:{{:((ChildLeft + ChildWidth)-(ParentLeft + ParentWidth))+30}}px;height:{{:Height}}px;position:absolute'>"
            + "<div class='e-line' style='left:{{if ~_isMilestoneParent()}}{{:((ParentLeft + ParentWidth) - (ChildLeft + ChildWidth))-10}}px;{{else}}{{:((ParentLeft + ParentWidth) - (ChildLeft + ChildWidth))}}px;{{/if}}" +
                "width:{{if ~_isMilestoneParent()}}30px;{{else}}20px;{{/if}}" +
                "height:" + lineStroke + "px;background-color:" + lineColor + ";position:relative'></div>"
            + "<div class='e-line' style='left:{{if ~_isMilestoneParent()}}{{:((ParentLeft + ParentWidth) - (ChildLeft + ChildWidth))+20}}px;{{else}}{{:((ParentLeft + ParentWidth) - (ChildLeft + ChildWidth))+20}}px;{{/if}}width:" + lineStroke + "px;" +
                "height:{{:Height-" + lineStroke + "}}px;background-color:" + lineColor + ";" +
                "position:relative'></div>"
            + "<div class='e-line' style='left:{{if ~_isMilestone()}}4px;{{else}}10px;{{/if}}width:{{if ~_isMilestone()}}{{:((ParentLeft + ParentWidth) - (ChildLeft + ChildWidth))+16}}px;{{else}}{{:((ParentLeft + ParentWidth) - (ChildLeft + ChildWidth))+10}}px;{{/if}}" +
                "height:" + lineStroke + "px;background-color:" + lineColor + ";position:relative'></div>"
            + "<div class='connectorline-leftarrow' style='{{if ~_isMilestone()}}left:-6px;{{/if}}border-right: 10px solid " + lineColor + ";" +
                "top:{{:-6-" + lineStroke + "}}px;border-bottom-width:{{:5+" + lineStroke + "}}px;" +
                "border-top-width:{{:5+" + lineStroke + "}}px;width:0;height:0;position:relative'></div>"
            + "</div>"

            + "{{else ~_getPosition()=='FFType2'}}"
            + "<div style='left:{{:ParentLeft+ParentWidth}}px;top:{{:ParentTop+" + taskbarMidpoint + "}}px;" +
                "width:{{:((ChildLeft +ChildWidth)-(ParentLeft + ParentWidth))+20}}px;height:{{:Height}}px;position:absolute'>"
            + "<div class='e-line' style='{{if ~_isMilestoneParent()}}left:-6px;{{/if}}width:{{if ~_isMilestoneParent()}}{{:((ChildLeft +ChildWidth)-(ParentLeft + ParentWidth))+26}}px;{{else}}{{:((ChildLeft +ChildWidth)-(ParentLeft + ParentWidth))+20}}px;{{/if}}height:" + lineStroke + "px;" +
                "background-color:" + lineColor + ";position:relative'></div>"
            + "<div class='e-line' style='left:{{:((ChildLeft +ChildWidth)-(ParentLeft + ParentWidth))+20}}px;width:" + lineStroke + "px;" +
                "height:{{:Height-" + lineStroke + "}}px;background-color:" + lineColor + ";" +
                "position:relative'></div>"
            + "<div class='e-line' style='left:{{if ~_isMilestone()}}{{:((ChildLeft +ChildWidth)-(ParentLeft + ParentWidth))+4}}px;{{else}}{{:((ChildLeft +ChildWidth)-(ParentLeft + ParentWidth))+10}}px;{{/if}}" +
                "width:{{if ~_isMilestone()}}16px;{{else}}10px;{{/if}}" +
                "height:" + lineStroke + "px;background-color:" + lineColor + ";position:relative'></div>"
            + "<div class='connectorline-leftarrow' style='left:{{if ~_isMilestone()}}{{:((ChildLeft +ChildWidth)-(ParentLeft + ParentWidth))-6}}px;{{else}}{{:((ChildLeft +ChildWidth)-(ParentLeft + ParentWidth))}}px;{{/if}}" +
                "border-right: 10px solid " + lineColor + ";top:{{:-6-" + lineStroke + "}}px;" +
                "border-bottom-width:{{:5+" + lineStroke + "}}px;border-top-width:{{:5+" + lineStroke + "}}px;width:0;height:0;position:relative'></div>"
            + "</div>"

            + "{{else ~_getPosition()=='FFType3'}}"
            + "<div  style='left:{{:ChildLeft+ChildWidth}}px;top:{{:ChildTop+" + taskbarMidpoint + "}}px;" +
                "width:{{:((ParentLeft + ParentWidth) - (ChildLeft + ChildWidth))+20}}px;height:{{:Height}}px;position:absolute'>"
            + "<div class='connectorline-leftarrow' style='top:-12.5px;border-right: 10px solid " + lineColor + ";" +
                "top:{{:-6-" + lineStroke + "}}px;border-bottom-width:{{:5+" + lineStroke + "}}px;" +
                "border-top-width:{{:5+" + lineStroke + "}}px;width:0;height:0;position:relative'></div>"
            + "<div class='e-line' style='width:{{:((ParentLeft + ParentWidth) - (ChildLeft + ChildWidth))+20}}px;top:-12.5px;" +
                "height:" + lineStroke + "px;background-color:" + lineColor + ";position:relative'></div>"
            + "<div class='e-line' style='left:{{:((ParentLeft + ParentWidth) - (ChildLeft + ChildWidth))+20}}px;top:-12.5px;" +
                "width:" + lineStroke + "px;height:{{:Height-" + lineStroke + "}}px;background-color:" + lineColor + ";position:relative'></div>"
            + "<div class='e-line' style='left:{{:((ParentLeft + ParentWidth) - (ChildLeft + ChildWidth))}}px;top:-12.5px;width:20px;" +
                "height:" + lineStroke + "px;background-color:" + lineColor + ";position:relative'></div>"
            + "</div>"

            + "{{else ~_getPosition()=='FFType4'}}"
            + "<div  style='left:{{:ParentLeft+ParentWidth}}px;top:{{:ChildTop+" + taskbarMidpoint + "}}px;" +
                "width:{{:((ChildLeft +ChildWidth)-(ParentLeft + ParentWidth))+20}}px;height:{{:Height}}px;position:absolute'>"
            + "<div  class='connectorline-leftarrow' style='left:{{:((ChildLeft +ChildWidth)-(ParentLeft + ParentWidth))}}px;" +
                "border-right: 10px solid " + lineColor + ";top:{{:-6-" + lineStroke + "}}px;" +
                "border-bottom-width:{{:5+" + lineStroke + "}}px;border-top-width:{{:5+" + lineStroke + "}}px;width:0;height:0;" +
                "position:relative'></div>"
            + "<div class='e-line' style='left:{{:((ChildLeft +ChildWidth)-(ParentLeft + ParentWidth))+10}}px;top:-13px;width:10px;" +
                "height:" + lineStroke + "px;background-color:" + lineColor + ";position:relative'></div>"
            + "<div class='e-line' style='left:{{:((ChildLeft +ChildWidth)-(ParentLeft + ParentWidth))+20}}px;top:-13px;width:" + lineStroke + "px;" +
                "height:{{:Height-" + lineStroke + "}}px;background-color:" + lineColor + ";position:relative'></div>"
            + "<div class='e-line' style='width:{{:((ChildLeft +ChildWidth)-(ParentLeft + ParentWidth))+20}}px;top:-13px;height:" + lineStroke + "px;" +
                "background-color:" + lineColor + ";position:relative'></div>"
            + "</div>"

            + "{{else  ~_getPosition()=='SFType4'}}"//SF
            + "<div style='left:{{:ParentLeft-10}}px;top:{{:ChildTop+" + taskbarMidpoint + "}}px;width:{{:((ChildLeft + ChildWidth) - (ParentLeft ))+20}}px;" +
                "height:{{:Height}}px;position:absolute'>"
            + "<div class='connectorline-leftarrow' style='left:{{:((ChildLeft + ChildWidth) - (ParentLeft ))+10}}px;" +
                "top:-13px;border-right: 10px solid " + lineColor + ";top:{{:-6-" + lineStroke + "}}px;" +
                "border-bottom-width:{{:5+" + lineStroke + "}}px;border-top-width:{{:5+" + lineStroke + "}}px;width:0;height:0;" +
                "position:relative'></div>"
            + "<div class='e-line' style='left:{{:((ChildLeft + ChildWidth) - (ParentLeft ))+20}}px;top:-13px;width:10px;" +
                "height:" + lineStroke + "px;background-color:" + lineColor + ";position:relative'></div>"
            + "<div class='e-line' style='left:{{:((ChildLeft + ChildWidth) - (ParentLeft ))+30}}px;top:-13px;width:" + lineStroke + "px;" +
                "height:{{:Height-15-" + lineStroke + "}}px;background-color:" + lineColor + ";" +
                "position:relative'></div>"
            + "<div class='e-line' style='top:-13px;width:{{:((ChildLeft + ChildWidth) - (ParentLeft ))+30}}px;height:" + lineStroke + "px;" +
                "background-color:" + lineColor + ";position:relative'></div>"
            + "<div class='e-line' style='top:-13px;width:" + lineStroke + "px;height:{{:12-" + lineStroke + "}}px;background-color:" + lineColor + ";position:relative'></div>"
            + "<div class='e-line' style='top:-13px;width:10px;height:" + lineStroke + "px;background-color:" + lineColor + ";position:relative'></div>"
            + "</div>"

            + "{{else ~_getPosition()=='SFType3'}}"//SF
            + "<div style='left:{{:ChildLeft+ChildWidth}}px;top:{{:ChildTop+" + taskbarMidpoint + "}}px;" +
                "width:{{:((ParentLeft)-(ChildLeft + ChildWidth))}}px;height:{{:Height}}px;position:absolute'>"
            + "<div class='connectorline-leftarrow' style='top:-13px;border-right: 10px solid " + lineColor + ";" +
                "top:{{:-6-" + lineStroke + "}}px;border-bottom-width:{{:5+" + lineStroke + "}}px;" +
                "border-top-width:{{:5+" + lineStroke + "}}px;width:0;height:0;position:relative'></div>"
            + "<div class='e-line' style='left:10px;top:-13px;width:10px;height:" + lineStroke + "px;" +
                "background-color:" + lineColor + ";position:relative'></div>"
            + "<div class='e-line' style='left:20px;top:-13px;width:" + lineStroke + "px;height:{{:Height-" + lineStroke + "}}px;" +
                "background-color:" + lineColor + ";position:relative'></div>"
            + "<div class='e-line' style='left:20px;top:-13px;width:{{:(ChildLeft-(ParentLeft + ParentWidth + 20))+" + lineStroke + "}}px;" +
                "height:" + lineStroke + "px;background-color:" + lineColor + ";position:relative'></div>"
            + "</div>"

            + "{{else  ~_getPosition()=='SFType1'}}"//SF
            + "<div style='left:{{:ParentLeft-10}}px;top:{{:ParentTop+" + taskbarMidpoint + "}}px;" +
                "width:{{:ChildLeft+ChildWidth+20}}px;height:{{:Height}}px;position:absolute'>"
            + "<div class='e-line' style='width:10px;height:" + lineStroke + "px;background-color:" + lineColor + ";" +
                "position:relative'></div>"
            + "<div class='e-line' style='width:" + lineStroke + "px;height:{{:Height-15-" + lineStroke + "}}px;" +
                "background-color:" + lineColor + ";position:relative'></div>"
            + "<div class='e-line' style='width:{{:((ChildLeft + ChildWidth) - (ParentLeft ))+30}}px;height:" + lineStroke + "px;" +
                "background-color:" + lineColor + ";position:relative'></div>"
            + "<div class='e-line' style='left:{{:((ChildLeft + ChildWidth) - (ParentLeft ))+30}}px;width:" + lineStroke + "px;" +
                "height:{{:12-" + lineStroke + "}}px;background-color:" + lineColor + ";position:relative'></div>"
            + "<div class='e-line' style='left:{{:((ChildLeft + ChildWidth) - (ParentLeft ))+20}}px;width:10px;height:" + lineStroke + "px;" +
                "background-color:" + lineColor + ";position:relative'></div>"
            + "<div class='connectorline-leftarrow' style='left:{{:((ChildLeft + ChildWidth) - (ParentLeft ))+10}}px;" +
                "border-right: 10px solid " + lineColor + ";top:{{:-6-" + lineStroke + "}}px;" +
                "border-bottom-width:{{:5+" + lineStroke + "}}px;border-top-width:{{:5+" + lineStroke + "}}px;" +
                "width:0;height:0;position:relative'></div>"
            + "</div>"

            + "{{else ~_getPosition()=='SFType2'}}"//SF
            + "<div  style='left:{{:ChildLeft+ChildWidth}}px;top:{{:ParentTop+" + taskbarMidpoint + "}}px;" +
                "width:{{:((ParentLeft) - (ChildLeft + ChildWidth))}}px;height:{{:Height}}px;position:absolute'>"
            + "<div class='e-line' style='left:{{:((ParentLeft) - (ChildLeft + ChildWidth))-10}}px;width:10px;height:" + lineStroke + "px;" +
                "background-color:" + lineColor + ";position:relative'></div>"
            + "<div class='e-line' style='left:{{:((ParentLeft) - (ChildLeft + ChildWidth))-10}}px;width:" + lineStroke + "px;" +
                "height:{{:Height-" + lineStroke + "}}px;background-color:" + lineColor + ";" +
                "position:relative'></div>"
            + "<div class='e-line' style='left:10px;width:{{:((ParentLeft) - (ChildLeft + ChildWidth))-20}}px;height:" + lineStroke + "px;" +
                "background-color:" + lineColor + ";position:relative'></div>"
            + "<div class='connectorline-leftarrow' style='border-right: 10px solid " + lineColor + ";" +
                "top:{{:-6-" + lineStroke + "}}px;border-bottom-width:{{:5+" + lineStroke + "}}px;border-top-width:{{:5+" + lineStroke + "}}px;width:0;height:0;position:relative'></div>"
            + "</div>"

            + "{{/if}}";

            connectorContainer += div;
            connectorContainer += "</div>";

            var templates = {};
            templates[this._id + "ConnectorLineTemplate"] = connectorContainer;
            $.templates(templates);
        },

        _isTaskMilestone: function () {
            if (this.data.milestoneChild)
                return true;
            else
                return false;
            
        },

        _isMilestoneParent: function () {
            if (this.data.milestoneParent)
                return true;
            else
                return false;
        },

        _getInnerChildWidthSSType2: function () {
            if ((this.data.ParentLeft + this.data.ParentWidth) < this.data.ChildLeft) {
                return 10;
            }
            if (this.data.ParentLeft == this.data.ChildLeft) {
                return 20;
            }
            return (this.data.ChildLeft - this.data.ParentLeft);
        },

        _getInnerElementLeftSSType2: function () {
            if (this.data.ParentLeft == this.data.ChildLeft) {
                return (this.data.ParentLeft - 20);
            }
            return (this.data.ParentLeft - 10);
        },

        _getInnerElementWidthSSType2: function () {
            if (this.data.ParentLeft == this.data.ChildLeft) {
                return 10;
            }
            return (this.data.ChildLeft - this.data.ParentLeft);
        },


        _getContainerWidthSSType2: function () {
            if (this.data.ParentLeft == this.data.ChildLeft) {
                return 20;
            }
            return (this.data.ChildLeft - this.data.ParentLeft);
        },

        _getPredecessorTop: function () {
            if (this.data.ParentTop > this.data.ChildTop)
                return true;
            else
                return false;
        },

        _getParentPosition: function () {
            if (this.data.ParentTop < this.data.ChildTop) {

                if (this.data.Type == "FF") {
                    if (this.data.ChildLeft >= this.data.ParentLeft ||
                        ((this.data.ChildLeft + this.data.ChildWidth) >= this.data.ParentLeft) && this.data.milestoneParent) {
                        return "FFType2";
                    }
                    else {
                        return "FFType1";
                    }
                }

                else if ((this.data.ParentLeft < this.data.ChildLeft) && (this.data.ChildLeft > (this.data.ParentLeft + this.data.ParentWidth + 25))) {
                    if (this.data.Type == "FS") return "FSType1";
                    if (this.data.Type == "SF") return "SFType1";
                    else if (this.data.Type == "SS") return "SSType2";
                    else if (this.data.Type == "FF") return "FFType2";
                }
                else if ((this.data.ParentLeft < this.data.ChildLeft && (this.data.ChildLeft < (this.data.ParentLeft + this.data.ParentWidth)))
                    || (this.data.ParentLeft == this.data.ChildLeft || this.data.ParentLeft > this.data.ChildLeft)) {

                    if (this.data.ParentLeft > (this.data.ChildLeft + this.data.ChildWidth + 25)) {
                        if (this.data.Type == "SF") return "SFType2";
                    }

                    if (this.data.ParentLeft > this.data.ChildLeft) {
                        if (this.data.Type == "SS") return "SSType1";
                        if (this.data.Type == "SF") return "SFType1";
                        if (this.data.Type == "FF") return "FFType1";
                    }
                    else if ((this.data.ChildLeft + this.data.ChildWidth) > (this.data.ParentLeft + this.data.ParentWidth)) {
                        if (this.data.Type == "FF") return "FFType2";
                    }
                    if (this.data.Type == "FS") return "FSType2";
                    else if (this.data.Type == "SS") return "SSType2";
                    else if (this.data.Type == "FF") return "FFType1";
                    else if (this.data.Type == "SF") return "SFType1";
                }
                else if ((this.data.ParentLeft + 25) < this.data.ChildLeft) {

                    if (this.data.Type == "FS") return "FSType2";
                    else if (this.data.Type == "FF") return "FFType2";
                    else if (this.data.Type == "SS") return "SSType2";

                }

            }
            else if (this.data.ParentTop > this.data.ChildTop) {
                if ((this.data.ParentLeft < this.data.ChildLeft) && (this.data.ChildLeft > (this.data.ParentLeft + this.data.ParentWidth))) {
                    if (this.data.Type == "FS") return "FSType4";
                    if (this.data.ParentLeft < this.data.ChildLeft || ((this.data.ChildLeft + this.data.ChildWidth) > (this.data.ParentLeft + this.data.ParentWidth))) {
                        if (this.data.Type == "SS") return "SSType4";
                        if (this.data.Type == "FF") return "FFType4";
                    }
                    else if ((this.data.ChildLeft + this.data.ChildWidth) > (this.data.ParentLeft + this.data.ParentWidth)) {
                        if (this.data.Type == "FF") return "FFType4";
                    }
                }
                else if ((this.data.ParentLeft < this.data.ChildLeft && (this.data.ChildLeft < (this.data.ParentLeft + this.data.ParentWidth)))
                    || (this.data.ParentLeft == this.data.ChildLeft || this.data.ParentLeft > this.data.ChildLeft)) {
                    if ((this.data.ChildLeft + this.data.ChildWidth) <= (this.data.ParentLeft + this.data.ParentWidth)) {
                        if (this.data.Type == "FF") return "FFType3";
                        if (this.data.Type == "SF") return "SFType3";
                    }
                    else if ((this.data.ChildLeft + this.data.ChildWidth) > (this.data.ParentLeft + this.data.ParentWidth)) {
                        if (this.data.Type == "FF") return "FFType4";
                        if (this.data.Type == "SF") return "SFType4";
                    }
                    if (this.data.Type == "FS") return "FSType3";
                    else if (this.data.Type == "SS") return "SSType3";
                }
                else if (this.data.ParentLeft < this.data.ChildLeft) {

                    if (this.data.Type == "FS") return "FSType3";
                    if (this.data.Type == "SS") return "SSType4";

                }
            }
            return false;
        },

        _getWidth: function () {
            return ((this.data.ChildLeft + this.data.ChildWidth) < (this.data.ParentLeft + this.data.ParentWidth)) ?
                this.data.ParentWidth : (this.data.ChildWidth + this.data.ParentWidth);
        },


        //renders Weekends in chart
        _renderWeekends: function () {
            var proxy = this,
                left = 0,
                width = (proxy.model.perDayWidth) + 1,
                height = ((proxy.model.updatedGanttRecords.length) * this.model.rowHeight),
                count = proxy.model.scheduleWeeks.length,
                $sunday, $saturday,
                $weekendContainer = ej.buildTag("div.e-secondary_canvas", "", { 'height': height + 'px' }, {});

            for (var i = 0; i < count; i++) {
                $sunday = ej.buildTag("div.e-weekends", "", {
                    'left': left + 'px',
                    'width': width + 'px',
                    'height': height + 'px',
                    'background-color': this.model.weekendBackground
                }, {});
                $saturday = ej.buildTag("div.e-weekends", "", {
                    'left': (left + (proxy.model.perDayWidth * 6)) + 'px',
                    'width': width + 'px',
                    'height': height + 'px',
                    'background-color': this.model.weekendBackground
                }, {});
                $weekendContainer.append($sunday);
                $weekendContainer.append($saturday);
                left = left + this._scheduleWeekWidth;
            }

            proxy._$weekendsContainer.append($weekendContainer);
            proxy._$bodyContent.append(proxy._$weekendsContainer);
        },



        //Renders StripLines for given striplines collection object
        _renderStripLines: function (stripLines) {

            var proxy = this,
                height = ((proxy.model.updatedGanttRecords.length) * this.model.rowHeight),
                stripLineCount = stripLines.length, day, left,
                projectStartDate = proxy.model.projectStartDate,
                dayWidth = this.model.perDayWidth,
                stripLineContainer = ej.buildTag("div.e-stripLines", "", { 'height': height + 'px' }, {});

            for (var i = 0; i < stripLineCount; i++) {

                day = this._getDateType(stripLines[i].day);
                left = ((day - this._getDateType(projectStartDate)) / 86400000) * dayWidth;
                stripLines[i].lineWidth = stripLines[i].lineWidth > 30 ? 30 : stripLines[i].lineWidth;

                var stripline = ej.buildTag("div.e-stripline#stripline" + [i] + "", "", {
                    'left': left + 'px',
                    'width': '1px',
                    'height': height + 'px',
                    'border-left-width': stripLines[i].lineWidth + 'px',
                    'border-left-color': stripLines[i].lineColor,
                    'border-left-style': stripLines[i].lineStyle
                }, {});

                var innerspan = ej.buildTag("span.e-striplinespan", stripLines[i].label, {
                    'background-color': stripLines[i].lineColor,
                }, {});

                if (stripLines[i].day && stripLines[i].day.length > 0) {
                    if (stripLines[i].label && stripLines[i].label.length > 0) {
                        stripline.append(innerspan);
                    }
                    stripLineContainer.append(stripline);
                }
            }

            proxy._$secondaryCanvas.append(stripLineContainer);
            proxy._$bodyContent.append(proxy._$secondaryCanvas);
        },


        //returns progress width for the taskbar
        _getProgressWidth: function (parentwidth, percent) {
            return (parentwidth * percent) / 100;
        },


        //returns progress percentage of the taskbar
        _getProgressPercent: function (parentwidth, progresswidth) {
            return Math.ceil(((progresswidth / parentwidth) * 100).toFixed(2));
        },


        //renders holidays for holiday collection object
        _renderHoliday: function (holiday) {

            var proxy = this, scheduleHeaderType = proxy.model.scheduleHeaderSettings.scheduleHeaderType,
                date = this._getDateType(holiday.day),
                weekCount = proxy.model.scheduleWeeks.length,
                monthcount = proxy.model.scheduleMonths.length,
                yearcount = proxy.model.scheduleYears.length,
                daycount=proxy.model.scheduleDays.length,
                prevDate = 0,
                left = 0, textLength, text, $holidayContainer, $holidaySpan,
                ganttRecords = proxy.model.updatedGanttRecords.length, height;

            left = ((date - this._getDateType(proxy.model.projectStartDate)) / 86400000) * this.model.perDayWidth;

            height = (ganttRecords * this.model.rowHeight);
            textLength = holiday.label != null ? holiday.label.length : 0;
            if (holiday.background == null)
                holiday.background = "white";
            if (proxy.model.scheduleHeaderSettings.scheduleHeaderType != "day") {
                text = ej.buildTag("div.e-holiday-label", holiday.label, {
                    'top': (proxy._getHolidayLabelHeight(textLength)) + 'px',
                }, {});
            }
            else
            {
                text = ej.buildTag("div.e-holiday-label", holiday.label, {
                    'bottom': (proxy._getHolidayLabelHeight(textLength)) + 'px',
                }, {});
            }
            $holidayContainer = ej.buildTag("div.e-secondary-canvas-holiday");
            $holidaySpan = ej.buildTag("div.e-holidays", "", {
                'left': left + 'px',
                'width': proxy.model.perDayWidth + 'px',
                'height': height + 'px',
                'background-color': holiday.background
            }, {});

            if (holiday.label != null)
                $holidaySpan.append(text);
            $holidayContainer.append($holidaySpan);

            proxy._$secondaryCanvas.append($holidayContainer);
            proxy._$bodyContent.append(proxy._$secondaryCanvas);
        },

        _getHolidayLabelHeight: function (textlength) {
            var proxy = this, model = proxy.model,
                containerHeight = proxy._getHeight(),
                totalHeight = model.updatedGanttRecords.length * proxy.model.rowHeight;
            if (containerHeight > 0)
                return (containerHeight / 2);
            else if (proxy._viewportHeight < totalHeight)
                return (proxy._viewportHeight / 2);
            else
                return totalHeight / 2;

        },

        // all events bound using this._on will be unbind automatically
        _destroy: function () {

            var proxy = this;
            proxy.element.empty().removeClass("e-ganttchart-core e-ganttchart" + proxy.model.cssClass);

        },
    });

    ej.GanttChart.contextMenuItem = {
        taskDetails: "Task Details....",
        add: "Add new task",
        indent: "Indent",
        outdent: "Outdent",
        Delete: "Delete",
    };

    jQuery.uaMatch = function (ua) {
        ua = ua.toLowerCase();

        var match = /(chrome)[ \/]([\w.]+)/.exec(ua) ||
            /(webkit)[ \/]([\w.]+)/.exec(ua) ||
            /(opera)(?:.*version|)[ \/]([\w.]+)/.exec(ua) ||
            /(msie) ([\w.]+)/.exec(ua) ||
            ua.indexOf("compatible") < 0 && /(mozilla)(?:.*? rv:([\w.]+)|)/.exec(ua) ||
            [];

        return {
            browser: match[1] || "",
            version: match[2] || "0"
        };
    };

})(jQuery, Syncfusion);;
(function ($, ej, undefined) {
    ej.Grid = ej.Grid || {};
    ej.Grid.gridResize = function (instance) {
        this.$headerTable = instance.getHeaderTable();
        this.gridInstance = instance;
        this._colMinWidth = 15;
        this._$visualElement = $();
        this._currentCell = -1;
        this._allowStart = false;
        this._oldWidth = null;
        this._orgX = null;
        this._orgY = null;
        this._extra = null;
        this._expand = false;
        this._target = null;
    }

    ej.Grid.gridResize.prototype = {
        _mouseHover: function (e) {
            if (this._$visualElement.is(":visible"))
                return;
            if ($(e.target).is(".e-headercelldiv"))
                e.target = e.target.parentNode;
            var $target = $(e.target);
            if ($target.hasClass("e-headercell")) {
                var _resizableCell = e.target;
                var location = _resizableCell.getBoundingClientRect(), _x = 0, _y = 0;
                if (e.type = "mousemove") {
                    _x = e.clientX;
                    _y = e.clientY;
                }
                else if (e.type = "touchmove") {
                    _x = evt.originalEvent.changedTouches[0].clientX;
                    _y = evt.originalEvent.changedTouches[0].clientY;
                }
                else if (e.type = "MSPointerMove") {
                    _x = e.originalEvent.clientX;
                    _y = e.originalEvent.clientY;
                }
                if (this.gridInstance.model.scrollSettings && this.gridInstance.model.scrollSettings.frozenColumns)
                    var _nlx = this.gridInstance.getHeaderContent().width() + this.gridInstance.element.children(".e-gridheader").find(".e-columnheader").offset().left;
                else
                    var _nlx = this.gridInstance.getHeaderTable().width() + this.gridInstance.element.children(".e-gridheader").find(".e-columnheader").offset().left;
                if (((_x >= (location.left + document.documentElement.scrollLeft + _resizableCell.offsetWidth - 5)) || ((_x <= (location.left + 3)))) && (_x < _nlx) && (_x >= location.left) && (_y <= location.top + document.documentElement.scrollTop + e.target.offsetHeight)) {
                    this.gridInstance.model.showStackedHeader && $($target.parents('thead')).find('tr').css("cursor", "col-resize");
                    !this.gridInstance.model.showStackedHeader && $target.parent().css("cursor", "col-resize");
                    if ($(e.target).hasClass('e-stackedHeaderCell'))
                        this._currentCell = this.gridInstance.getHeaderContent().find(".e-headercell:visible").index(_resizableCell);
                    else
                        this._currentCell = this.gridInstance.getHeaderContent().find(".e-headercell:visible").not(".e-stackedHeaderCell").index(_resizableCell);
                    this._allowStart = true;
                }
                else {
                    $target.parent().css("cursor", "pointer");
                    this._allowStart = false;
                    this._currentCell = -1;
                }
            }
        },
        _start: function (_x, _y) {
            var _myrow = this.gridInstance.getHeaderTable().find(".e-columnheader");
            var _cells, _mycel;
            if ($(this._target).hasClass('e-stackedHeaderCell'))
                _cells = _myrow.find(".e-headercell")
            else
                _cells = _myrow.find(".e-headercell").not(".e-stackedHeaderCell");
            if (this._currentCell != -1 && this._currentCell < _cells.length)
                _mycel = _cells[this._currentCell];
            if (typeof (_mycel) == 'undefined')
                return;
            var _j = _mycel.getBoundingClientRect();
            this._tableY = _j.top + parseInt(navigator.userAgent.indexOf("WebKit") != -1 ? document.body.scrollTop : document.documentElement.scrollTop);
            if (this._allowStart) {
                this._$visualElement = $(document.createElement('div'));
                _height = this.gridInstance.element.find(".e-gridcontent").first().height() + this.gridInstance.element.find(".e-gridheader").height();
                if (this.gridInstance.model.showStackedHeader && this.gridInstance.model.stackedHeaderRows.length > 0) {
                    var headerRow = this.gridInstance.getHeaderTable().find('tr.e-columnheader')
                    var lenght = headerRow.length;
                    var currentIndex = $(this._target).parent('tr')[0].rowIndex;
                    for (var i = 0; i < currentIndex; i++) {
                        _height = _height - $(headerRow[i]).height();
                    }
                    // _height = _height - $(".e-stackedHeaderRow").height();
                }
                this._$visualElement.addClass("e-reSizeColbg").appendTo(this.gridInstance.element).css({ height: _height + 'px', cursor: 'col-resize' });
                this._$visualElement.css({ left: _x, top: this._tableY });
                this._oldWidth = _mycel.offsetWidth;
                this._orgX = _x;
                this._orgY = _y;
                this._extra = _x - this._orgX;
                this._expand = true;
            }
            else {
                this._currentCell = -1;
            }
        },
        _mouseMove: function (e) {
            if (this._expand) {
                var _x = 0, _y = 0;
                if (e.type = "mousemove") {
                    _x = e.clientX;
                    _y = e.clientY;
                }
                else if (e.type = "touchmove") {
                    _x = evt.originalEvent.changedTouches[0].clientX;
                    _y = evt.originalEvent.changedTouches[0].clientY;
                }
                else if (e.type = "MSPointerMove") {
                    _x = e.originalEvent.clientX;
                    _y = e.originalEvent.clientY;
                }
                if (navigator.userAgent.indexOf("WebKit") != -1) {
                    _x = e.pageX;
                    _y = e.pageY;
                }
                _x += document.documentElement.scrollLeft;
                e.preventDefault();
                this._moveVisual(_x);
            }
            else
                this._mouseHover(e);
        },
        _getCellIndex: function (e) {
            var $target = $(e._target);
            var targetCell = e._target;
            var hCellIndex = targetCell.cellIndex;
            var cellIndex = hCellIndex;
            if (e.gridInstance.model.groupSettings.groupedColumns.length) {
                cellIndex = hCellIndex - e.gridInstance.model.groupSettings.groupedColumns.length;
            }
            return cellIndex;
        },
        _reSize: function (_x, _y) {
            // Function used for Resizing the column
            var proxy = this;
            var resized = false, $content;
            if (this.gridInstance.model.scrollSettings && this.gridInstance.model.scrollSettings.frozenColumns)
                this._initialTableWidth = this.gridInstance.getHeaderTable().first().parent().width() + this.gridInstance.getHeaderTable().last().parent().width();
            else
                this._initialTableWidth = this.gridInstance.getHeaderTable().parent().width();
            !this.gridInstance.model.enableRTL && this._getResizableCell();
            var _rowobj = $(this._target).parents('thead');
            if (this._currentCell != -1 && this._expand) {
                this._expand = false;
                var _childTH = _rowobj.find(".e-headercell").filter(":visible");
                var _outerCell = _childTH[this._currentCell];
                var _oldWidth = _outerCell.offsetWidth;
                var _extra = _x - this._orgX;
                //Check whether the column minimum width reached
                if (parseInt(_extra) + parseInt(_oldWidth) > this._colMinWidth) {
                    if (_extra != 0)
                        _rowobj.css("cursor", 'default');
                    this._resizeColumnUsingDiff(_oldWidth, _extra);
                    $content = this.gridInstance.element.find(".e-gridcontent").first();
                    this.gridInstance.model.allowScrolling && $content.ejScroller("refresh");
                    var browser = this.gridInstance.getBrowserDetails();
                    if (browser.browser == "msie" && this.gridInstance.model.allowScrolling) {
                        var oldWidth = this.gridInstance.getContentTable().width(), newwidth = this.gridInstance._calculateWidth();
                        if (this.gridInstance.model.scrollSettings && this.gridInstance.model.scrollSettings.frozenColumns > 0) {
                            this.gridInstance.getHeaderTable().last().width(newwidth - this.gridInstance.getHeaderContent().find(".e-frozenheaderdiv").width());
                            this.gridInstance.getContentTable().last().width(newwidth - this.gridInstance.getContent().find(".e-frozencontentdiv").width());
                            this.gridInstance.model.showSummary && this.gridInstance.getFooterTable().last().width(newwidth - this.gridInstance.getFooterContent().find(".e-frozenfootertdiv").width());
                        }
                        else {
							if (newwidth > oldWidth) {
								this.gridInstance.getHeaderTable().width(newwidth);
								this.gridInstance.getContentTable().width(newwidth);
								this.gridInstance.model.showSummary && this.gridInstance.getFooterTable().width(newwidth);
							}
                        }
                        if (parseInt(browser.version, 10) > 8 && this.gridInstance.model.groupSettings && this.gridInstance.model.groupSettings.groupedColumns.length) {
                            if (newwidth > oldWidth) {
                                this.gridInstance.getContentTable().width(newwidth);
                                this.gridInstance.getContentTable().children("colgroup").find("col").first().css("width", (20 / $content.find("table").first().width()) * 100 + "%");
                            }
                            else {
                                this.gridInstance.getContentTable().css("width", "100%");
                                this.gridInstance._groupingAction();
                                this.gridInstance.getContentTable().children("colgroup").find("col").first().css("width", ((this.gridInstance.getHeaderTable().find("colgroup").find("col").first().width() / $content.find("table").first().width()) * 100).toFixed(2) + "%");
                            }
                        }
                        this.gridInstance.getHeaderTable().parent().scrollLeft($content.find(".e-content").scrollLeft() - 1);
                    }
                    this.gridInstance._colgroupRefresh();
                    if (this.gridInstance.model.groupSettings.groupedColumns.length && this.gridInstance.model.groupSettings.showGroupedColumn)
                        this.gridInstance._recalculateIndentWidth();
                    if (!(browser.browser == "msie") && this.gridInstance.model.allowScrolling && this.gridInstance.model.scrollSettings.frozenColumns == 0) {
                        var tableWidth = this.gridInstance._calculateWidth();
						if(tableWidth > this.gridInstance.getContentTable().width() || this.gridInstance.getHeaderTable().width() > this.gridInstance.getContentTable().width()){
							this.gridInstance.getHeaderTable().width(tableWidth);
							this.gridInstance.getContentTable().width(tableWidth);
						}
                    }
                    if (this.gridInstance.model.allowResizing && this.gridInstance.getHeaderTable().find(".e-columnheader").css('cursor') == 'default') {
                        var cellIndex = this._getCellIndex(this);
                        var newWidth = _oldWidth + _extra;
                        var args = { columnIndex: cellIndex, column: this.gridInstance.model.columns[cellIndex], oldWidth: _oldWidth, newWidth: newWidth };
                        this.gridInstance._trigger("resized", args);
                    }
                }

            }
			this.gridInstance.model.allowScrolling && this.gridInstance.getScrollObject().refresh();
            this._target = null;
            this._$visualElement.remove();
            this._expand = false;
            this._currentCell = -1;
            this._allowStart = false;

        },
        _getFrozenResizeWidth: function () {
            var $frozenColumnsCol = this.gridInstance.getHeaderTable().find('colgroup').find("col").slice(0, this.gridInstance.model.scrollSettings ? this.gridInstance.model.scrollSettings.frozenColumn : 0), width = 0;
            for (var i = 0; i < $frozenColumnsCol.length; i++) {
                if ($frozenColumnsCol.eq(i).css("display") != "none")
                    width += parseInt($frozenColumnsCol[i].style.width.replace("px", ""));
            }
            return width;
        },
        _diaplayFinder: function () {
            return $(this).css('display') != 'none';
        },
        _resizeColumnUsingDiff: function (_oldWidth, _extra) {
            var proxy = this;
            var currentIndex = this._currntCe = this._currentCell, _extraVal;
            if ($(this._target).parent('tr').hasClass('e-stackedHeaderRow')) {
                var preCol = 0, currentTh = $(this._target), currentSpan = $(currentTh).attr('colspan'), tr = $(currentTh).parent('tr');
                while (currentIndex > 0) {
                    currentIndex--
                    var th = $(tr).children('th')[currentIndex];
                    preCol += parseInt($(th).attr('colspan'))
                }
                this._currentCell = preCol;
            }
            if (this.gridInstance.model.showStackedHeader && !$(this._target).parent('tr').hasClass('e-stackedHeaderRow'))
                this._currentCell = this._currentCell - this.gridInstance.getHeaderTable().find(".e-stackedHeaderCell").length;            
			var $headerCols = this.gridInstance.getHeaderTable().find('colgroup').find("col");
            var $ContentCols = this.gridInstance.getContentTable().find('colgroup').find("col");
            if (!ej.isNullOrUndefined(this.gridInstance.model.detailsTemplate)) {
                this.gridInstance._detailColsRefresh();
                $headerCols = this.gridInstance._$headerCols;
                $ContentCols = this.gridInstance._$contentCols;
            }
            var $headerCol = $headerCols.filter(this._diaplayFinder).eq(!this.gridInstance.model.allowGrouping || !ej.isNullOrUndefined(this.gridInstance.model.detailsTemplate) ? this._currentCell : this._currentCell + this.gridInstance.model.groupSettings.groupedColumns.length)
                    , $ContentCol, $footerCol, $frozenCols = $headerCols.slice(0, this.gridInstance.model.scrollSettings ? this.gridInstance.model.scrollSettings.frozenColumns : 0);
            var _inlineWidth = $headerCol[0].style.width;
            var indent = _oldWidth / parseInt(_inlineWidth);
            _extraVal = _extra = _extra / indent
            var _newWidth = parseInt(_extra) + parseInt(_inlineWidth);
            if (_newWidth > 0 && _extra != 0) {
                if (_newWidth < this._colMinWidth)
                    _newWidth = this._colMinWidth;
                var _extra = _newWidth - _oldWidth;
                if (this.gridInstance.model.scrollSettings && this.gridInstance.model.scrollSettings.frozenColumns) {
                    if (this._currentCell >= 0 && this._currentCell < this.gridInstance.model.scrollSettings.frozenColumns && this._getFrozenResizeWidth() + _extra > this.gridInstance.element.find(".e-headercontent").first().width())
                        return;
                    $ContentCol = $ContentCols.filter(this._diaplayFinder).eq(this._currentCell);
                }
                else
                    $ContentCol = $ContentCols.filter(this._diaplayFinder).eq(!this.gridInstance.model.allowGrouping || !ej.isNullOrUndefined(this.gridInstance.model.detailsTemplate) ? this._currentCell : this._currentCell + this.gridInstance.model.groupSettings.groupedColumns.length);
                if (this.gridInstance.model.showSummary) {
                    $footerCol = this.gridInstance.getFooterTable().find('colgroup').find("col").filter(this._diaplayFinder).eq(this._currentCell);
                    $footerCol.outerWidth(_newWidth);
                }
                if ($(this._target).parent('tr').hasClass('e-stackedHeaderRow')) {
                    this._resizeStackedHeaderColumn($(this._target).parent('tr'), _extraVal, this._currntCe);
                }
                else
                    $headerCol.outerWidth(_newWidth);
                if (this.gridInstance.model.isEdit) {
                    var $editCol = this.gridInstance.getContentTable().find(".e-editedrow,.e-addedrow").find("table").find("colgroup");
                    $($editCol[0].children[this._currentCell - this.gridInstance.model.groupSettings ? this.gridInstance.model.groupSettings.groupedColumns.length : 0]).width(_newWidth);
                }
                if ($(this._target).parent('tr').hasClass('e-stackedHeaderRow')) {
                    if (this.gridInstance.model.groupSettings.groupedColumns.length < 1) {

                        var length = this.gridInstance.getContentTable().find('colgroup').find("col").filter(this._diaplayFinder).length;
                        for (var i = 0; i < this._changedcell.length; i++) {
                            var $conCol = this.gridInstance.getContentTable().find('colgroup').find("col").filter(this._diaplayFinder)[this._changedcell[i]]
                            var width = parseInt((_extraVal)) + parseInt($conCol.style.width);
                            $($conCol).width(width);
                        }
                    }
                    else {
                        var $tables = this.gridInstance.getContentTable().find(".e-recordtable");
                        var $colGroup = $tables.find("colgroup");
                        for (var i = 0; i < this._changedcell.length; i++) {
                            var cellIndex = this._changedcell[i];
                            for (var i = 0 ; i < $colGroup.length; i++) {
                                var width = parseInt((_extraVal)) + parseInt($($colGroup[i].children[cellIndex]).width());
                                $($colGroup[i].children[cellIndex]).width(width);
                            }
                        }
                    }
                }
                else {
                    if (this.gridInstance.model.groupSettings && this.gridInstance.model.groupSettings.groupedColumns.length) {
                        var $tables = this.gridInstance.getContentTable().find(".e-recordtable");
                        var $colGroup = $tables.find("colgroup");
                        var cellIndex = this._currentCell + this.gridInstance._hiddenColumns.length;
                        var colCount = this.gridInstance.model.columns.length;
                        for (var i = 0 ; i < $colGroup.length; i++) {
                            var cols = $($colGroup[i]).find("col");
                            if (cols.length > colCount) cols.splice(0, (cols.length - colCount));
                            $(cols[cellIndex]).width(_newWidth);
                        }
                    }                    
                    $ContentCol.width(_newWidth);
                }
                this.gridInstance._findColumnsWidth();
                if (this.gridInstance.model.scrollSettings && this.gridInstance.model.scrollSettings.frozenColumns) {
                    var frozenColumns = this.gridInstance.getContentTable().find('colgroup').find("col").slice(0, this.gridInstance.model.scrollSettings.frozenColumns)
                        , width = 0, direction;
                    for (i = 0; i < frozenColumns.length; i++)
                        width += parseInt(frozenColumns[i].style.width.replace("px", ""));
                    this.gridInstance.getHeaderContent().find(".e-frozenheaderdiv").width(width);
                    direction = this.gridInstance.model.enableRTL ? "margin-right" : "margin-left";
                    this.gridInstance.getContent().find(".e-frozencontentdiv").width(width).next().css(direction, width + "px");
                    this.gridInstance.getHeaderContent().find(".e-frozenheaderdiv").width(width).next().css(direction, width + "px");
                    this.gridInstance.model.showSummary && this.gridInstance.getFooterContent().find(".e-frozenfooterdiv").width(width);
                }
                this.gridInstance.getHeaderTable().find(".e-columnheader").css("cursor", "default");
            }
        },
        _resizeStackedHeaderColumn: function (currentTr, extra, currentCell) {
            // var currentIndex = this._currntCe;
            this._changedcell = [];
            if (this.gridInstance.model.groupSettings.showGroupedColumn && this.gridInstance.model.groupSettings.groupedColumns.length > 0) {
                this._currentCell++;
                currentCell++;
            }
            var preCol = this._currentCell, currentTh = $(currentTr).find('th')[currentCell], currentSpan = $(currentTh).attr('colspan'), commonExtra = extra / currentSpan, tr = $(currentTh).parent('tr');
            if (currentSpan > 1) {
                var nextTr = tr.next();
                var length = preCol + parseInt(currentSpan);
                for (var i = preCol; i < length; i++) {
                    var curTh = $($(nextTr).find('th'))[i], curCol = $(curTh).attr('colspan');
                    if (curCol > 1) {
                        this._resizeStackedHeaderColumn($(curTh).parent('tr'), commonExtra, i)
                    }
                    else {
                        var $colG = this.gridInstance.getHeaderTable().find('col')[i];
                        this._changedcell.push(i)
                        var width = parseInt(extra) + parseInt($colG.style.width);
                        $($colG).outerWidth(width);
                    }
                }
            }
            else {
                var $colG = this.gridInstance.getHeaderTable().find('col')[this._currentCell];
                var width = parseInt(extra) + parseInt($colG.style.width);
                this._changedcell.push(preCol)
                $($colG).outerWidth(width);
            }
        },
        _triggerResizeEvents: function (event, _x) {
            var _rowobj = this.gridInstance.getHeaderTable().find(".e-columnheader");
            var _childTH = _rowobj.find(".e-headercell").filter(":visible");
            var _outerCell = _childTH[this._currentCell];
            var _oldWidth = _outerCell.offsetWidth;
            var cellIndex = this._getCellIndex(this);
            if (event == "resizeStart") {
                var args = { columnIndex: cellIndex, column: this.gridInstance.model.columns[cellIndex], target: $(_outerCell), oldWidth: _oldWidth };
                this.gridInstance._trigger("resizeStart", args);
            }
            else {
                var _extra = _x - this._orgX;
                var newWidth = _oldWidth + _extra;
                this.gridInstance._colgroupRefresh();
                var args = { columnIndex: cellIndex, column: this.gridInstance.model.columns[cellIndex], target: $(_outerCell), oldWidth: _oldWidth, newWidth: newWidth, extra: _extra };
                this.gridInstance._trigger("resizeEnd", args);
            }
        },
        _mouseUp: function (e) {
            if (this._expand) {
                var _x = e.clientX, _y = e.clientY;
                if (navigator.userAgent.indexOf("WebKit") != -1) {
                    _x = e.pageX;
                    _y = e.pageY;
                }
                if (this.gridInstance.model.allowResizing && this.gridInstance.getHeaderTable().find(".e-columnheader").css('cursor') == 'col-resize') {
                    this._triggerResizeEvents("resizeEnd", _x);
                }
                _x += document.documentElement.scrollLeft;
                this._reSize(_x, _y);
            }
        },
        _getResizableCell: function () {
            var row = this.gridInstance.getHeaderTable().find(".e-columnheader");
            var cell = row.find(".e-headercell").not(".e-hide,.e-detailheadercell");
            var scrollLeft = navigator.userAgent.indexOf("WebKit") != -1 ? document.body.scrollLeft : document.documentElement.scrollLeft;
            for (var i = 0; i < cell.length; i++) {
                point = cell[i].getBoundingClientRect();
                var xlimit = point.left + scrollLeft + 5;
                if (xlimit > this._orgX && $(cell[i]).height() + point.top >= this._orgY) {
                    this._currentCell = i - 1;
                    return;
                }
            }
        },
        _moveVisual: function (_x) {
            /// Used to move the visual element in mouse move
            var _bounds = this.gridInstance.getHeaderContent().find("div").first()[0].getBoundingClientRect();
            if ((_bounds.left + document.documentElement.scrollLeft + _bounds.width < _x) || (_x < _bounds.left + document.documentElement.scrollLeft))
                this._$visualElement.remove();
            else if (this._currentCell != -1)
                this._$visualElement.css({ left: _x, top: this._tableY });
        },
        _mouseDown: function (e) {
            if (this._allowStart && ($(e.target).closest("tr").css("cursor") == 'col-resize')) {
                this._target = e.target;
                var _x = e.clientX, _y = e.clientY;
                if (navigator.userAgent.indexOf("WebKit") != -1) {
                    _x = e.pageX;
                    _y = e.pageY;
                }
                if (this.gridInstance.model.allowResizing && this.gridInstance.getHeaderTable().find(".e-columnheader").css('cursor') == 'col-resize') {
                    if ($(e.target).is(".e-headercelldiv"))
                        e.target = e.target.parentNode;
                    this._target = e.target;
                    this._triggerResizeEvents("resizeStart", _x);
                }
                var gridobj = this;
                _x += document.documentElement.scrollLeft;
                if (e.button != 2)
                    if (this.gridInstance.model.allowResizing && this.gridInstance.model.allowResizeToFit) {
                        gridobj.gridInstance._click++;
                        setTimeout(function () {
                            if (gridobj.gridInstance._click == 1) {
                                gridobj._start(_x, _y);
                            }
                            else if (gridobj.gridInstance._click == 2) {
                                gridobj._columnResizeToFit(e);
                            }
                            gridobj.gridInstance._click = 0;
                        }, 400);
                    }
                    else
                        this._start(_x, _y);
                e.preventDefault();
            }
            return false;
        },
        _columnResizeToFit: function (e) {
            if (this.gridInstance.model.allowResizeToFit && this.gridInstance.getHeaderTable().find(".e-columnheader").css('cursor') == 'col-resize') {
                if ($(e.target).is(".e-headercelldiv"))
                    e.target = e.target.parentNode;
                var $target = $(e.target);
                this._target = $target;
                if ($target.hasClass("e-headercell")) {
                    var targetCell = e.target;
                    var hCellIndex = targetCell.cellIndex;
                    var cellIndex = hCellIndex;
                    this._orgX = e.pageX;
                    this._getResizableCell();
                    if (hCellIndex != this._currentCell) {
                        hCellIndex = cellIndex = this._currentCell;
                        targetCell = e.target.previousSibling;
                    }
                    var $cellDiv = $(targetCell).children('.e-headercelldiv');
                    if (this.gridInstance.model.groupSettings.groupedColumns.length) {
                        cellIndex = hCellIndex - this.gridInstance.model.groupSettings.groupedColumns.length;
                    }
                    var finalWidth = 0, headerWidth = 0, contentWidth = 0;
                    if (cellIndex != -1) {
                        contentWidth = this._getContentWidth(cellIndex);
                        headerWidth = this._getHeaderContentWidth($cellDiv);
                        finalWidth = headerWidth > contentWidth ? headerWidth : contentWidth;
                        finalWidth = finalWidth + (finalWidth * 0.2);
                        var oldWidth = this.gridInstance.getHeaderTable().find('col').eq(hCellIndex).width();
                        var args = { columnIndex: cellIndex, column: this.gridInstance.model.columns[cellIndex], target: $target, oldWidth: oldWidth };
                        this.gridInstance._trigger("resizeStart", args);
						finalWidth =  oldWidth > finalWidth ? finalWidth : (this._colMinWidth < contentWidth ? contentWidth : this._colMinWidth);
                        this.gridInstance.getHeaderTable().find('col').eq(hCellIndex).width(finalWidth);
                        if (this.gridInstance.model.groupSettings.groupedColumns.length) {
                            var $colGroups = this.gridInstance.getContentTable().find('.e-recordtable').find('colgroup');
                            $.each($colGroups, function (indx, colgroup) {
                                $(colgroup).find('col').eq(cellIndex).width(finalWidth);
                            });
                        }
                        else
                            this.gridInstance.getContentTable().find('col').eq(cellIndex).width(finalWidth);
                        var newWidth = this.gridInstance.getHeaderTable().find('col').eq(hCellIndex).width();
                        this.gridInstance._colgroupRefresh();
                        args = { columnIndex: cellIndex, column: this.gridInstance.model.columns[cellIndex], target: $target, oldWidth: oldWidth, newWidth: newWidth, extra: Math.abs(newWidth - oldWidth) };
                        this.gridInstance._trigger("resizeEnd", args);
                        this.gridInstance._columnsWidthCollection[cellIndex] = finalWidth;
                        this.gridInstance.model.columns[cellIndex]["width"] = finalWidth;
                        args = { columnIndex: cellIndex, column: this.gridInstance.model.columns[cellIndex], target: $target, oldWidth: oldWidth, newWidth: newWidth };
                        this.gridInstance._trigger("resized", args);
                    }
                }
            }
        },
        _getContentWidth: function (cellindx) {
            var contentWidth = 0;
            var $span = ej.buildTag('span', {}, {}), proxy = this.gridInstance, tdWidth;
            $.each(proxy._gridRows, function (indx, row) {
                var td = $(row).find('td.e-rowcell').eq(cellindx);
                var content = $(td).html();
                if (proxy.model.columns[cellindx]["isUnbound"])
                    $span.html($(content).children());
                else
                    $span.html(content);
                $(td).html($span);
                tdWidth = td.find('span:first').width();
                if (tdWidth > contentWidth)
                    contentWidth = tdWidth;
                $(td).html(content);
            });
            proxy._refreshUnboundTemplate(this.gridInstance.getContentTable());
            return contentWidth;
        },
        _getHeaderContentWidth: function ($cellDiv) {
            var headerWidth = 0, $span = ej.buildTag('span', {}, {});
            var content = $cellDiv.html();
            $span.html(content);
            $cellDiv.html($span);
            headerWidth = $cellDiv.find('span:first').width();
            if (this.gridInstance.model.allowFiltering && this.gridInstance.model.filterSettings.filterType == "menu")
                headerWidth = headerWidth + $cellDiv.parent().find(".e-filtericon").width() + 10;
            $cellDiv.html(content);
            return headerWidth;
        },
    };
})(jQuery, Syncfusion);;
});