/*!
*  filename: ej.grid.js
*  version : 12.3
*  Copyright Syncfusion Inc. 2001 - 2014. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
*/
(function (fn) {
    typeof define === 'function' && define.amd ? define(["./../common/ej.core","./../common/ej.data","./../common/ej.touch","./../common/ej.draggable","./../common/ej.scroller","./ej.button","./ej.checkbox","./ej.waitingpopup","./ej.radiobutton","./ej.autocomplete","./ej.datepicker","./ej.datetimepicker","./ej.dropdownlist","./ej.dialog","./ej.editor","./ej.pager","./ej.toolbar","./ej.excelfilter"], fn) : fn();
})
(function () {
	
(function ($, ej, undefined) {
    ej.gridFeatures = ej.gridFeatures || {};
    ej.gridFeatures.common = {
        /**
		 * Refresh the grid contents. The template refreshment is based on the argument passed along with this method
         * @alias ejGrid#refreshContent
		 * @return jQuery
		 * @param {boolean} [templateRefresh] When templateRefresh is set true, template and grid contents both are refreshed in grid else only grid content is refreshed
		 * @example 
		 * &lt;div id="Grid"&gt;&lt;/div&gt; 
		 * &lt;script&gt;
		 * // Create grid object.
		 * var gridObj = $("#Grid").data("ejGrid");
		 * gridObj.refreshContent(); // Refreshes the grid contents only
		 * gridObj.refreshContent(true); // Refreshes the template and grid contents
		 * &lt;/script&gt;
		 * @example 
		 * &lt;div id="Grid"&gt;&lt;/div&gt; 
		 * &lt;script&gt;
		 * // Refreshes the grid contents only
		 * $("#Grid").ejGrid("refreshContent");        
		 * // Refreshes the template and grid contents
		 * $("#Grid").ejGrid("refreshContent", true);        
		 * &lt;/script&gt;
         */
        refreshContent: function ( refreshTemplate) {
             refreshTemplate && this.refreshTemplate();
            var args = {};
            args.requestType = ej.Grid.Actions.Refresh;
            this._processBindings(args);
        },

        /**
		 * Resolves row height issue when unbound column is used with FrozenColumn
         * @alias ejGrid#rowHeightRefresh
		 * @return jQuery
		 * @example 
		 * &lt;div id="Grid"&gt;&lt;/div&gt; 
		 * &lt;script&gt;
		 * // Create grid object.
		 * var gridObj = $("#Grid").data("ejGrid");
		 * gridObj.rowHeightRefresh(); // Resolves row height issue
		 * &lt;/script&gt;
		 * @example 
		 * &lt;div id="Grid"&gt;&lt;/div&gt; 
		 * &lt;script&gt;         
		 * // Resolves row height issue
		 * $("#Grid").ejGrid("rowHeightRefresh");   
		 * &lt;/script&gt;
         */
        rowHeightRefresh: function () {
            if (this.model.scrollSettings.frozenColumns > 0 && (this._isUnboundColumn || this.getContentTable().find(".e-templatecell") != null)) {
                var maxHeight = 0, defaultRowHeight = 32;
                var frozenRow = this.model.scrollSettings.frozenRows;
                var rowIndex = frozenRow > 0 ? frozenRow - 1 : 0;
                for (var i = 0; i < this.model.columns.length; i++) {
                    if (this.model.columns[i].isUnbound != undefined || this.model.columns[i].template != undefined) {
                        if (!ej.isNullOrUndefined(this._gridContent.find(".e-frozencontentdiv tr")[rowIndex].getClientRects()[0]))
                            var frozenContentHeight = this._gridContent.find(".e-frozencontentdiv tr")[rowIndex].getClientRects()[0].height;
                        if (!ej.isNullOrUndefined(this._gridContent.find(".e-movablecontentdiv tr")[rowIndex].getClientRects()[0]))
                            var movableContentHeight = this._gridContent.find(".e-movablecontentdiv tr")[rowIndex].getClientRects()[0].height;
                        var arr = [frozenContentHeight, movableContentHeight];
                        maxHeight = ej.max(arr) + (frozenRow > 0 ? 0 : 1);
                        if (this.model.columns[i].visible == true) {
                            if (frozenContentHeight != movableContentHeight)
                                this._unboundRowHeightRefresh(maxHeight, frozenRow);
                            break;
                        }
                        else {
                            if (frozenContentHeight != defaultRowHeight || movableContentHeight != defaultRowHeight)
                                this._unboundRowHeightRefresh(defaultRowHeight, frozenRow);
                        }
                    }
                }
            }
        },

        _unboundRowHeightRefresh: function (rowHeight, frozenRow) {
            if (this._gridContent.find("style").length > 0)
                this._gridContent.find("style").remove()
            if ((this.model.editSettings.allowEditing || this.model.editSettings.allowAdding) && this.model.editSettings.editMode == "normal" && this._isUnboundColumn)
                $("<style type='text/css'>.e-rowcell { height: " + rowHeight + "px;  }.e-grid .e-editedrow .e-rowcell{  padding-top:0.7em;padding-bottom:0.7em;}  </style>").prependTo(this._gridContent);
            else
                $("<style type='text/css'>.e-rowcell{ height: " + rowHeight + "px} </style>").prependTo(this._gridContent);
            if (frozenRow > 0) {
                this._getRowHeights()
                this.model.scrollSettings.height = this._rowHeightCollection[Math.floor(this.model.scrollSettings.height / this._rowHeightCollection[1])] + 18;
                this.getContent().ejScroller("option", { "height": this.model.scrollSettings.height });
            }
        },

        /**
		 * Refresh the grid with new data source
         * @alias ejGrid#dataSource
		 * @return jQuery
         * @param {array} datasource Pass new data source to the grid
		 * @example 
		 * &lt;script&gt;
		 * // Create grid object.
		 * var gridObj = $("#Grid").data("ejGrid");
         * // Refreshes the grid data source
		 * gridObj.dataSource(data); 
		 * &lt;/script&gt;
		 * @example 
		 * &lt;script&gt;
		 * // Refreshes the grid data source
		 * $("#Grid").ejGrid("dataSource", data);        
		 * &lt;/script&gt;
         */
        dataSource: function (dataSource, templateRefresh) {
            if (templateRefresh)
                this._templateRefresh = true;
            this._dataSource(dataSource);
            if (dataSource.length > 0)
               this._currentPage(1);
            else
               this._currentPage(0);
            this._refreshDataSource(dataSource);
            var model = this._refreshVirtualPagerInfo();
            this._showPagerInformation(model)
            if (this.model.scrollSettings.allowVirtualScrolling) {
                this._refreshVirtualContent();
                this.getContent().first().ejScroller("refresh");
                if (this.getContent().ejScroller("isHScroll"))
                  this.getContent().ejScroller("scrollX", 0, true);
                if (this.getContent().ejScroller("isVScroll")) {
                    this.getContent().ejScroller("scrollY", 0, true);
                    this.element.find(".e-gridheader").addClass("e-scrollcss");
                }
                else
                    this.element.find(".e-gridheader").removeClass("e-scrollcss");
            }
        },
        _refreshDataSource: function (dataSource) {
            if (dataSource instanceof ej.DataManager)
                this._dataManager = dataSource;
            else
                this._dataManager = ej.DataManager(dataSource);
            this.refreshContent(true);
            if (!ej.isNullOrUndefined(this. getPager())) {
                this.getPager().ejPager("model.currentPage", 1);
                this._refreshGridPager();
            }
        },
        /**
		 * Hide columns from the grid based on the header text
         * @alias ejGrid#hideColumns
		 * @return jQuery
		 * @param {array/string} headerText you can pass either array of header text of various columns or a header text of a column to hide 
		 * @example 
		 * &lt;script&gt;
		 * // Create grid object.
		 * var gridObj = $("#Grid").data("ejGrid");
		 * gridObj.hideColumns("Order ID"); // Hides column based on the given header text of the column
		 * gridObj.hideColumns(["Order ID", "Customer ID"]); // Hide columns based on the array of header text of the columns given
		 * &lt;/script&gt;
		 * @example 
		 * &lt;script&gt;
		 * // Hide column based on the given header text of the column
		 * $("#Grid").ejGrid("hideColumns", "Order ID"); 
		 * // Hide columns based on the array of header text of the columns given
		 * $("#Grid").ejGrid("hideColumns", ["Order ID", "Customer ID"]); 			
		 * &lt;/script&gt;
         */
        hideColumns: function (c) {
            var i, count = 0, args = {}, index, newHideCol = [];
            if ($.isArray(c)) {
                for (i = 0; i < c.length; i++) {
                    index = $.inArray(c[i], this._visibleColumns);
                    if (index != -1) {
                        this._hiddenColumns.push(c[i]);
                        this._visibleColumns.splice(index, 1);
                    }
                }
            } else {
                index = $.inArray(c, this._visibleColumns);
                if (index != -1) {
                    this._hiddenColumns.push(c);
                    this._visibleColumns.splice(index, 1);
                }
            }
            for (i = 0; i < this.model.columns.length; i++) {
                if ($.inArray(this.model.columns[i].headerText, this._hiddenColumns) != -1) {
                    this.model.columns[i].visible && newHideCol.push(this.model.columns[i]);
                    this.model.columns[i].visible = false;
                    count++;
                }
                if (this._hiddenColumns.length == count)
                    break;
            }
            args.requestType = "refresh";
            this._hideHeaderColumn(this._hiddenColumns);
            if (this.model.allowScrolling && this.model.scrollSettings.frozenColumns > 0) {
                var frozenHide = false;
                for (var i = 0; i < newHideCol.length; i++) {
                    var index = this.model.columns.indexOf(newHideCol[i]);
                    if (index < this.model.scrollSettings.frozenColumns) {
                        this.model.scrollSettings.frozenColumns++;
                        frozenHide = true;
                    }
                }
                if (frozenHide) {
                    var $table = this._renderGridHeader();
                    this.element.find('.e-gridheader').replaceWith($table[0])
                    if (this.model.allowFiltering && this.model.filterSettings.filterType == "filterbar") this._renderFiltering();
                }
            }
            this.refreshTemplate();
            this.sendDataRenderingRequest(args);
            this.rowHeightRefresh();
            if (this.model.allowScrolling) {
                if (this.model.scrollSettings.frozenColumns == 0) {
                    var tableWidth = this._calculateWidth();
                    this.getHeaderTable().width(tableWidth);
                    this.getContentTable().width(tableWidth);
                }
                this.getScrollObject().refresh();
            }
        },
        /**
         * Show columns in the grid based on the header text 
         * @alias ejGrid#showColumns
         * @return jQuery
         * @param {array/string} headerText you can pass either array of header text of various columns or a header text of a column to show 
         * @example 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * gridObj.showColumns("Order ID"); // Shows column based on the given header text of the column
         * gridObj.showColumns(["Order ID", "Customer ID"]); // Shows columns based on the array of header text of the columns given
         * &lt;/script&gt;
         * @example 
         * &lt;script&gt;
         * // Shows column based on the given header text of the column
         * $("#Grid").ejGrid("showColumns", "Order ID"); 
         * // Shows columns based on the array of header text of the columns given
         * $("#Grid").ejGrid("showColumns", ["Order ID", "Customer ID"]); 			
         * &lt;/script&gt;
         */
        showColumns: function (c) {
            var i, count = 0, args = {}, index, column, newVisColumns = [];
            if ($.isArray(c)) {
                for (i = 0; i < c.length; i++) {
                    index = $.inArray(c[i], this._hiddenColumns);
                    if (index != -1) {
                        this._hiddenColumns.splice(index, 1);
                        this._visibleColumns.push(c[i]);
                    }
                }
            } else {
                index = $.inArray(c, this._hiddenColumns);
                if (index != -1) {
                    this._hiddenColumns.splice(index, 1);
                    this._visibleColumns.push(c);
                }
            }
            for (i = 0; i < this.model.columns.length; i++) {
                if ($.inArray(this.model.columns[i].headerText, this._visibleColumns) != -1) {
                    !this.model.columns[i].visible && newVisColumns.push(this.model.columns[i])
                    this.model.columns[i].visible = true;
                    count++;
                }
                if (this._visibleColumns.length == count)
                    break;
            }
            if (this.model.allowScrolling && this.model.scrollSettings.frozenColumns > 0) {
                var frozenHide = false;
                for (var i = 0; i < newVisColumns.length; i++) {
                    var index = this.model.columns.indexOf(newVisColumns[i]);
                    if (index < this.model.scrollSettings.frozenColumns) {
                        this.model.scrollSettings.frozenColumns--;
                        frozenHide = true;
                    }
                }
                if (frozenHide) {
                    var $table = this._renderGridHeader();
                    this.element.find('.e-gridheader').replaceWith($table[0])
                    if (this.model.allowFiltering && this.model.filterSettings.filterType == "filterbar") this._renderFiltering();
                }
            }
            args.requestType = "refresh";
            this._showHeaderColumn(this._visibleColumns);
            this.refreshTemplate();
            this.sendDataRenderingRequest(args);
            this.rowHeightRefresh();
            if (this.model.allowScrolling) {
                this.getScrollObject().refresh();
            }
        },
        /**
		 * Refresh the template of the grid
         * @alias ejGrid#refreshTemplate
		 * @return jQuery
		 * @example 
		 * &lt;script&gt;
		 * // Create grid object.
		 * var gridObj = $("#Grid").data("ejGrid");
         * // Refreshes the template of the grid control
		 * gridObj.refreshTemplate(); 
		 * &lt;/script&gt;
		 * @example 
		 * &lt;script&gt;
		 * // Refreshes the template of the grid control.
		 * $("#Grid").ejGrid("refreshTemplate");        
		 * &lt;/script&gt;
         */
         refreshTemplate: function () {
            this.addInitTemplate();
            if (this.model.editSettings.allowEditing || this.model.editSettings.allowAdding) {
                if (this.model.editSettings.editMode == "normal")
                    this.addEditingTemplate();
                else if (this.model.editSettings.editMode == "dialog" || this.model.editSettings.editMode == "externalform" ||
                    this.model.editSettings.editMode == "inlineform")
                    this.addDialogEditingTemplate();
                else if (this.model.editSettings.editMode == "dialogtemplate" || this.model.editSettings.editMode == "externalformtemplate" ||
                    this.model.editSettings.editMode == "inlineformtemplate")
                    this.addExternalDialogEditingTemplate();
            }
            if (this.model.allowGrouping) this.addGroupingTemplate();
        },
        set_dropColumn: function (from, to) {
            if (this.model.allowReordering && from != to) {
                this.model.columns.splice(to, 0, this.model.columns.splice(from, 1)[0]);
                var columns = this.model.columns;
                var $header = this.getHeaderTable().find(".e-headercell").not(".e-stackedHeaderCell");
				var $headerCell = $header.find(".e-headercelldiv");
				this.getHeaderTable().find("colgroup").replaceWith(this._getMetaColGroup());
				(this.model.detailsTemplate != null || this.model.childGrid != null) && this.getHeaderTable().find("colgroup").prepend(this._getIndentCol());
				
                //Remove and Returns name/value pair of element attributes
				var removeAttr = function (ele) {
				    var names = []; if (ele == undefined) return; 
				    if (["", undefined].indexOf(ele.value) == -1) {
				        names.push({ name: "value", value: ele.value }); ele.value = "";
                    }
				    for (var e = 0, eAttr = ele.attributes, eLen = eAttr.length; e < eLen; e++) {
				        names.push({ name: eAttr[e].name, value: eAttr[e].value });
					}
				    for (var a = 0, aLen = names.length; a < aLen; a++) {
				        $(ele).removeAttr(names[a].name);
				    }				  
				    return names;
				};
                //Add attributes to the ele
				var addAttr = function (coll, ele) {
				    if (ele == undefined) return;
				    for (var e = 0, eLen = coll.length; e < eLen; e++) {
				        if (coll[e].name == "value") ele.value = coll[e].value;
				        $(ele).attr(coll[e].name, coll[e].value);
                    }
				};

				if(this.getHeaderTable().find(".e-filterdiv").length > 0) 
					var $filterCell = this.getHeaderTable().find(".e-filterdiv input");
				var $fState = ej.isNullOrUndefined($filterCell);
				var $attributeCollection = { "cellattributes": [], "headerattributes": [], "filtercellattributes": [], "filterThattributes": [] };               
                var fromIndex = from < to ? from : to;
                var toIndex = from < to ? to : from;                
				//Get and remove attributes
                for (var i = fromIndex, j = 0; i <= toIndex; i++) {                   
                    var hIndx = (this.model.detailsTemplate != null || this.model.childGrid != null) ? i + 1 : i;
                    $attributeCollection.headerattributes[j] = removeAttr($header[hIndx]);
                    $attributeCollection.cellattributes[j] = removeAttr($headerCell[i]);
                    $attributeCollection.filtercellattributes[j] = !$fState ? removeAttr($filterCell[i]) : [];
                    $attributeCollection.filterThattributes[j] = !$fState ? removeAttr($($filterCell[i]).closest("th")[0]) : [];
                    j++;
                    }

				var spliceFrom = from < to ? $attributeCollection.cellattributes.length - 1 : 0;
				var spliceTo = from < to ? 0 : $attributeCollection.cellattributes.length - 1;

				for (var prop in $attributeCollection)
				    $attributeCollection[prop].splice(spliceFrom, 0, $attributeCollection[prop].splice(spliceTo, 1)[0]);				

                //Add attributes
				for (var i = fromIndex, j = 0; i <= toIndex; i++) {
				    var indx = (this.model.detailsTemplate != null || this.model.childGrid != null) ? i + 1 : i;
                    addAttr($attributeCollection.headerattributes[j], $header[indx]);
                    addAttr($attributeCollection.cellattributes[j], $headerCell[i]);
                    !$fState && addAttr($attributeCollection.filtercellattributes[j], $filterCell[i]);
                    !$fState && addAttr($attributeCollection.filterThattributes[j], $($filterCell[i]).closest("th")[0]);
                    j++;
                }
				if (this.model.allowFiltering && ["menu","excel"].indexOf(this.model.filterSettings.filterType) != -1)
				    this._refreshFilterIcon();

				this._columnsWidthCollection.splice(to, 0, this._columnsWidthCollection.splice(from, 1)[0]);

                this._fieldColumnNames = this._headerColumnNames = [];
                for (var count = 0; count < columns.length; count++) {
                    this._fieldColumnNames[columns[count].headerText] = columns[count].field;
                    this._headerColumnNames[columns[count].field] = columns[count].headerText;
                    $($headerCell[count]).text(columns[count].headerText);
                }

                if (this.model.allowSorting) {
                    for (var i = 0; i < this.model.sortSettings.sortedColumns.length; i++) {
                        var opacity = 1;
                        var $sCol = this.model.sortSettings.sortedColumns[i];
                        var sortcolumn = this.getsortColumnByField($sCol.field);
                        var index = this.getColumnIndexByField($sCol.field);
                        var sortindex = $.inArray(sortcolumn, this.model.sortSettings.sortedColumns);
                        imageDirection = $sCol.direction != "descending" ? "e-rarrowup-2x" : "e-rarrowdown-2x";
                        if (this.model.allowMultiSorting) {
                            for (var j = 1; j <= sortindex; j++) {
                                opacity = opacity + 1;
                            }
                            if ($headerCell.eq(index).css("text-align") == "right") {
                                $headerCell.eq(index).prepend(this._createSortNumber(opacity, $headerCell.eq(index)).addClass("e-sortnumber"));
                                $headerCell.eq(index).append(this._createSortElement().addClass("e-" + ($sCol.direction || "ascending") + " " + imageDirection));
                            }
                            else {
                                $headerCell.eq(index).append(this._createSortElement().addClass("e-" + ($sCol.direction || "ascending") + " " + imageDirection));
                                $headerCell.eq(index).append(this._createSortNumber(opacity, $headerCell.eq(index)).addClass("e-sortnumber"));
                            }
                        }
                        else {
                            imageDirection = $sCol.direction != "descending" ? "e-rarrowup-2x" : "e-rarrowdown-2x";
                            $headerCell.eq(index).append(this._createSortElement().addClass("e-" + ($sCol.direction || "ascending") + " " + imageDirection));
                        }
                    }
                }
                var args = {};
                args.requestType = ej.Grid.Actions.Reorder;
                this.addInitTemplate();
                this.sendDataRenderingRequest(args);
            }
        },
        /**
		 * Get the pager of grid..
         * @alias ejGrid#getPager
		 * @return gridPager
		 * @example 
		 * &lt;script&gt;
		 * // Create grid object.
		 * var gridObj = $("#Grid").data("ejGrid");
         * // Gets grid pager of grid control
		 * gridObj.getPager(); 
		 * &lt;/script&gt;
		 * @example 
		 * &lt;script&gt;
		 * // Gets grid pager of grid control
		 * $("#Grid").ejGrid("getPager");        
		 * &lt;/script&gt;
         */
         getPager: function () {
            return this._gridPager;
        },
        /**
		 * Get the footer table element of grid
         * @alias ejGrid#getFooterTable
		 * @return gridFooterTable
		 * @example 
		 * &lt;script&gt;
		 * // Create grid object.
		 * var gridObj = $("#Grid").data("ejGrid");
         * // Gets grid footer table of grid control
		 * gridObj.getFooterTable(); 
		 * &lt;/script&gt;
		 * @example 
		 * &lt;script&gt;
		 * // Gets grid footer table of grid control
		 * $("#Grid").ejGrid("getFooterTable");        
		 * &lt;/script&gt;
         */
        getFooterTable: function () {
            return this._gridFooterTable;
        },

        setGridFooterTable: function (value) {
            this._gridFooterTable = value;
        },
        /**
		 * Get the footer content of grid.
         * @alias ejGrid#getFooterContent
		 * @return gridFooterContent
		 * @example 
		 * &lt;script&gt;
		 * // Create grid object.
		 * var gridObj = $("#Grid").data("ejGrid");
         * // Gets grid footer content of grid control
		 * gridObj.getFooterContent(); 
		 * &lt;/script&gt;
		 * @example 
		 * &lt;script&gt;
		 * // Gets grid footer content of grid control
		 * $("#Grid").ejGrid("getFooterContent");        
		 * &lt;/script&gt;
         */
        getFooterContent: function () {
            return this._gridFooterContent;
        },

        setGridFooterContent: function (value) {
            this._gridFooterContent = value;
        },
        /**
		 * Get the scroller object of grid.
         * @alias ejGrid#getScrollObject
		 * @return scrollObject
		 * @example 
		 * &lt;script&gt;
		 * // Create grid object.
		 * var gridObj = $("#Grid").data("ejGrid");
         * // Gets scroll object of grid control
		 * gridObj.getScrollObject(); 
		 * &lt;/script&gt;
		 * @example 
		 * &lt;script&gt;
		 * // Gets scroll object of grid control
		 * $("#Grid").ejGrid("getScrollObject");        
		 * &lt;/script&gt;
         */
        getScrollObject: function () {
            if (this._scrollObject == null || ej.isNullOrUndefined(this._scrollObject.model))
                this._scrollObject = this.getContent().ejScroller("instance");
            return this._scrollObject;
        },
        setGridPager: function (value) {
            this._gridPager = value;
        },
        /**
         * Get the row height of grid.
         * @alias ejGrid#getRowHeight
         * @return rowHeight
         * @example 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // Gets the row height of the grid
         * gridObj.getRowHeight();  
         * &lt;/script&gt;
         * @example 
         * &lt;script&gt;
         * // Gets the row height of the grid
         * $("#Grid").ejGrid("getRowHeight");   
         * &lt;/script&gt;
         */
        getRowHeight: function () {
            var rowHeight = -1;
            var trColl = this.getContentTable().find('tr:not(.e-virtualrow)');
            if (trColl.length > 1) {
                if (trColl[0].getBoundingClientRect() && this.getContentTable().find("tr")[0].getBoundingClientRect().height) {
                    rowHeight = trColl[0].getBoundingClientRect().height;
                } else
                    rowHeight = trColl[0].offsetHeight;
            }
            return rowHeight == -1 ? 32 : rowHeight;
        },
        /**
		 * Get the current page index in grid pager.
         * @alias ejGrid#getCurrentIndex
		 * @return Current PageIndex
		 * @example 
		 * &lt;script&gt;
		 * // Create grid object.
		 * var gridObj = $("#Grid").data("ejGrid");
         * // Gets the current page index in grid
		 * gridObj.getCurrentIndex();  
		 * &lt;/script&gt;
		 * @example 
		 * &lt;script&gt;
		 * // Gets the current page index in grid
		 * $("#Grid").ejGrid("getCurrentIndex");   
		 * &lt;/script&gt;
         */
        getCurrentIndex: function () {
            return ((this._currentPage() - 1) * (this.model.pageSettings.pageSize));
        },
        /**
		 * Get the column details based on the given column index in grid
         * @alias ejGrid#getColumnByIndex
		 * @return Column Object
		 * @param {number} columnIndex Pass the index of the column to get the corresponding column object
		 * @example 
		 * &lt;script&gt;
		 * // Create grid object.
		 * var gridObj = $("#Grid").data("ejGrid");
         * // Gets the column details based on the given column index
		 * gridObj.getColumnByIndex(1); 
		 * &lt;/script&gt;
		 * @example 
		 * &lt;script&gt;
		 * // Gets the column details based on the given column index
		 * $("#Grid").ejGrid("getColumnByIndex", 1);        
		 * &lt;/script&gt;
         */
        getColumnByIndex: function (index) {
            if (index < this.model.columns.length)
                return this.model.columns[index];
            return null;
        },
        set_currentPageIndex: function (val) {
            var pageSetting = this.model.pageSettings;
            var recordCount = this.model.filterSettings.filteredColumns.length == 0 ? this._searchCount == null ? this._gridRecordsCount : this._searchCount : this._filteredRecordsCount;
            if (pageSetting.totalPages == null)
                pageSetting.totalPages = Math.ceil(recordCount / pageSetting.pageSize);
            if (val > pageSetting.totalPages || val < 1 || val == this._currentPage())
                return false;
            if (ej.isNullOrUndefined(this._prevPageNo))
                this._prevPageNo = this._currentPage();
            this._currentPage(val);
            if (this._currentPage() != this._prevPageNo) {
                var args = {};
                args.requestType = "paging";
                this._isVirtualRecordsLoaded = false;
                this.gotoPage(this._currentPage(), args);
                var model = this._refreshVirtualPagerInfo();
                this._showPagerInformation(model);
                return true;
            }
            else
                return false;
        },
        /**
		 * Expand or collapse the row based on the row state in grid
         * @alias ejGrid#expandCollapse
		 * @return jQuery
		 * @param {object} $target Pass the target object to expand/collapse the row based on its row state
		 * @example 
		 * &lt;script&gt;
		 * // Create grid object.
		 * var gridObj = $("#Grid").data("ejGrid");
         * // Expands or collapses the row based on the row state
		 * gridObj.expandCollapse($("tr td.recordplusexpand > div").first());  
		 * &lt;/script&gt;
		 * @example 
		 * &lt;script&gt;
		 * // Expands or collapses the row based on the row state
		 * $("#Grid").ejGrid("expandCollapse", $("tr td.recordplusexpand > div").first());        
		 * &lt;/script&gt;
         */
        expandCollapse: function ($target) {
            if ($target.prop("tagName") == "DIV" && ($target.parent().hasClass("e-recordplusexpand") || $target.parent().hasClass("e-recordpluscollapse") || $target.parent().hasClass("e-detailrowcollapse") || $target.parent().hasClass("e-detailrowexpand")))
                $target = $target.parent();
            if ($target.hasClass("e-recordplusexpand") && this.model.groupSettings.groupedColumns.length) {
                var cellIndex = $target.index();
                var $rows = $target.closest('tr').next();
                $rows.hide();
                $target.removeClass("e-recordplusexpand").addClass("e-recordpluscollapse").find("div").removeClass("e-gdiagonalnext").addClass("e-gnextforward");
            } else if ($target.hasClass("e-recordpluscollapse") && this.model.groupSettings.groupedColumns.length) {
                var cellIndex = $target.index();
                var $rows = $target.closest('tr').next();
                var toExpandRows = [];
                var $row = $rows;
                if ($($row[0].cells[cellIndex]).hasClass("e-indentcell")) {
                    if ($row.children(".e-indentcell").length == ($target.parent().children('.e-indentcell').length) + 1) {
                        $row.show();
                        var $expand = $row.children(".e-recordplusexpand");
                        if ($expand != null && $expand.length > 0) {
                            toExpandRows.push($expand);
                        }
                    }
                }
                $target.removeClass("e-recordpluscollapse").addClass("e-recordplusexpand").find("div").removeClass("e-gnextforward").addClass("e-gdiagonalnext");
                for (var i = 0; i < toExpandRows.length; i++) {
                    toExpandRows[i].removeClass("e-recordplusexpand").addClass("e-recordpluscollapse").find("div").removeClass("e-gdiagonalnext").addClass("e-gnextforward");
                    this.expandCollapse(toExpandRows[i]);
                }
            } else if ($target.hasClass("e-detailrowexpand")) {
                var cellIndex = $target.index(), proxy = this;
                var rowIndexValue;
                if (this.model.groupSettings.groupedColumns.length > 0)
                    rowIndexValue = this.getIndexByRow($target.closest('tr')) - $target.closest('tr').parents('tr').prevAll('tr').find('td.e-summaryrow').parent().length;
                else
                    rowIndexValue = this.getIndexByRow($target.closest('tr')) - $target.closest('tr').prevAll("tr.e-detailrow").length;
                var $rows = $target.closest('tr').next();
                $rows.hide(0, function () {
                    var args = { masterRow: $target.closest('tr'), detailsRow: $rows, masterData: proxy._currentJsonData[rowIndexValue] };
                    var foreignKeyData = proxy._getForeignKeyData(args.masterData);
                    if (!ej.isNullOrUndefined(foreignKeyData))
                        args.foreignKeyData = foreignKeyData;
                    proxy._trigger("detailsCollapse", args);

                });
                $target.removeClass("e-detailrowexpand").addClass("e-detailrowcollapse").find("div").addClass("e-gnextforward").removeClass("e-gdiagonalnext");
            } else if ($target.hasClass("e-detailrowcollapse")) {
                var cellIndex = $target.index(), proxy = this;
                var rowIndexValue;
                if (this.model.groupSettings.groupedColumns.length > 0)
                    rowIndexValue = this.getIndexByRow($target.closest('tr')) - $target.closest('tr').parents('tr').prevAll('tr').find('td.e-summaryrow').parent().length;
                else
                    rowIndexValue = this.getIndexByRow($target.closest('tr')) - $target.closest('tr').prevAll("tr.e-detailrow").length;
                var detailrow = $target.closest('tr').next();
                if (detailrow.hasClass("e-detailrow"))
                    $rows = detailrow;
                else {
                    var detailtr = ej.buildTag("tr.e-detailrow", "", { 'display': 'none' }, {});
                    var indenttd = ej.buildTag("td.e-detailindentcell");
					var hideGroupColumnCount = !this.model.groupSettings.showGroupedColumn ? this.model.groupSettings.groupedColumns.length : 0;
                    var detailstd = ej.buildTag("td.e-detailcell", "", {}, { colspan: this._visibleColumns.length - hideGroupColumnCount });
                    var detaildiv = ej.buildTag("div");
                    var count = $($target.closest('tr')).parents('.e-grid').length;
                    detaildiv.attr("id", "child" + count + "_grid" + rowIndexValue);
                    $(detailtr).append(indenttd);
                    $(detailtr).append(detailstd);
                    var rowData = this._currentJsonData[rowIndexValue];
                    if (this.model.detailsTemplate)
                    $(detailtr).append(detailstd.append(this._renderEjTemplate(this.model.detailsTemplate, rowData)));

                    $($target.closest('tr')).after(detailtr);
                    this._trigger("detailsDataBound", { detailsElement: detailtr, data: rowData }); //    $(tbody).append(trchild);
                    if (this.model.childGrid) {
                        var temp = this.model.childGrid.queryString,ftemp=this.model.childGrid.foreignKeyField;
                        this.model.childGrid.query = ej.Query().where(ej.isNullOrUndefined(ftemp)? temp: ftemp, "equal", rowData[temp], true);
                        this.model.childGrid["parentDetails"] = {
                            parentID: this._id,
                            parentPrimaryKeys: this.getPrimaryKeyFieldNames(),
                            parentKeyField: temp,
                            parentKeyFieldValue: rowData[temp],
                            parentRowData: rowData
                        }                                                                                                                        
                        $(detailtr).append(detailstd.append(detaildiv));
                    }
                    $rows = detailtr;
                }
                var toExpandRows = [];
                var $row = $rows;
                if ($($row[0].cells[cellIndex]).hasClass("e-detailindentcell")) {
                    $row.show(0, function () {
                        var args = { masterRow: $target.closest('tr'), detailsRow: $rows, masterData: proxy._currentJsonData[rowIndexValue] };
                        var foreignKeyData = proxy._getForeignKeyData(args.masterData);
                        if (!ej.isNullOrUndefined(foreignKeyData))
                            args.foreignKeyData = foreignKeyData;
                        proxy._trigger("detailsExpand", args);
                    });
                    this.model.childGrid && !ej.isNullOrUndefined(detaildiv) && detaildiv.ejGrid(this.model.childGrid);
                    var $expand = $row.children(".e-detailrowexpand");
                    if ($expand != null && $expand.length > 0) {
                        toExpandRows.push($expand);
                    }
                }
                $target.removeClass("e-detailrowcollapse").addClass("e-detailrowexpand").find("div").addClass("e-gdiagonalnext").removeClass("e-gnextforward");
                for (var i = 0; i < toExpandRows.length; i++) {
                    toExpandRows[i].removeClass("e-detailrowexpand").addClass("e-detailrowcollapse").find("div").removeClass("e-gdiagonalnext").addClass("e-gnextforward");
                    this.expandCollapse(toExpandRows[i]);
                }
            }
        },
        _refreshGridPager: function () {
            if (this. getPager() != null) {
                var pagerModel = this.getPager().ejPager("model"), model = {};
                model.currentPage = this._currentPage();
                if (this._filteredRecordsCount == 0 && this.model.currentViewData.length == 0 && (ej.isNullOrUndefined(this._prevPageNo) || this._prevPageNo)) {
                    model.currentPage = 0;
                    this._prevPageNo = pagerModel.currentPage;
                    this.model.pageSettings.currentPage = 0;
                } else if (pagerModel.currentPage == 0 && (ej.isNullOrUndefined(this._prevPageNo) || this._prevPageNo))
                    model.currentPage = this._prevPageNo;
                model.totalRecordsCount = this.model.filterSettings.filteredColumns.length == 0 ? this._searchCount == null ? this._gridRecordsCount : this._searchCount : this._filteredRecordsCount;
                if (ej.util.isNullOrUndefined(model.currentPage))
                    model.currentPage = this._currentPage();
                this.getPager().ejPager("option", model).ejPager("refreshPager");
            }
        },
        _showHeaderColumn: function (showColumns, field) {
            var $head = this.getHeaderTable().find("thead");
            var $headerCell = $head.find("tr").not(".e-stackedHeaderRow").find(".e-headercell");
            var $filterBarCell = $head.find(".e-filterbar").find(".e-filterbarcell");
            var $col = this.getHeaderTable().find("colgroup").find("col"), column;
            for (var i = 0; i < showColumns.length; i++) {
                if (field)
                    column = this.getColumnByField(showColumns[i]);
                else
                    column = this.getColumnByHeaderText(showColumns[i]);
                var index = $.inArray(column, this.model.columns);
                index = this.model.detailsTemplate != null ? index + 1 : index;
                var frznCol = this.model.scrollSettings.frozenColumns;
                if (frznCol != 0 && index >= frznCol)
                    var thIndex = $headerCell.eq(index).removeClass("e-hide").index() + frznCol;
                else
                    var thIndex = $headerCell.eq(index).removeClass("e-hide").index();
                $filterBarCell.eq(thIndex).removeClass("e-hide");
                $col.eq(index).css("display", "");
            }
            if (this.model.showStackedHeader)
                this._refreshStackedHeader();
        },
        _hideHeaderColumn: function (hiddenColumns, field) {
            var $head = this.getHeaderTable().find("thead");
            var $headerCell = $head.find("tr").not(".e-stackedHeaderRow").find(".e-headercell");
            var $filterBarCell = $head.find(".e-filterbar").find(".e-filterbarcell");
            var $col = this.getHeaderTable().find("colgroup").find("col"), column;
            for (var i = 0; i < hiddenColumns.length; i++) {
                if (field)
                    column = this.getColumnByField(hiddenColumns[i]);
                else
                    column = this.getColumnByHeaderText(hiddenColumns[i]);
                var index = $.inArray(column, this.model.columns);
				var dindex = this.model.detailsTemplate!=null ? index+1 : index;
                var frznCol = this.model.scrollSettings.frozenColumns;
                if (frznCol != 0 && index >= frznCol)
                    var thIndex = $headerCell.eq(dindex).addClass("e-hide").index() + frznCol;
                else
                    var thIndex = $headerCell.eq(dindex).addClass("e-hide").index();
                $filterBarCell.eq(thIndex).addClass("e-hide");
                if ($col.length > this.model.columns.length)
                    $col = $col.slice($col.length - this.model.columns.length);
                $col.eq(index).css("display", "none");
            }
            if (this.model.showStackedHeader)
                this._refreshStackedHeader();
        },
        _refreshStackedHeader: function () {
            var stackedRows = this.model.stackedHeaderRows;
            for (var i = 0; i < stackedRows.length; i++) {
                if (this.model.scrollSettings.frozenColumns != 0) {
                    var frznHeader = $(this.getHeaderContent().find(".e-frozenheaderdiv"));
                    var movHeader = $(this.getHeaderContent().find(".e-movableheader"));
                    var newFrzn = this._createStackedRow(stackedRows[i], true);
                    var newMov = this._createStackedRow(stackedRows[i], false);
                    $(frznHeader.find("tr.e-stackedHeaderRow")[i]).replaceWith(newFrzn);
                    $(movHeader.find("tr.e-stackedHeaderRow")[i]).replaceWith(newMov);
                }
                else {
                    var stackedTR = this._createStackedRow(stackedRows[i], false);
                    $(this.getHeaderTable().find("tr.e-stackedHeaderRow")[i]).replaceWith(stackedTR);
                }
            }
            var args = {};
            args.requestType = "refresh";
            if (this.model.allowGrouping && this.model.groupSettings.groupedColumns.length > 0) {
                for(var i=0;i<this.model.groupSettings.groupedColumns.length;i++)
                    this.getHeaderTable().find(".e-stackedHeaderRow").prepend(this._getGroupTopLeftCell());
            }
            this.model.allowScrolling && this._refreshScroller(args);
        },
        _checkSkipAction: function (args) {
            switch (args.requestType) {
                case ej.Grid.Actions.Save:
                case ej.Grid.Actions.Delete:
                    return true;
            }
            return false;
        },
        _unboundTemplateRendering: function (unboundTemplateId) {
            return $("#" + unboundTemplateId).html();
        },
        _processBindings: function (args) {
            this.model.query = this.model.enablePersistence ? new ej.Query() : this.commonQuery.clone();
            if (!this._checkSkipAction(args) && this._trigger("actionBegin", args))
                return true;
            if (this.model.editSettings.editMode == "batch" && args.requestType != "batchsave" && args.requestType != "cancel" && !this._confirmedValue && this._bulkChangesAcquired() && this.model.editSettings.showConfirmDialog) {
                this._confirmDialog.find(".e-content").html(this._getLocalizedLabels("BatchSaveLostChanges"));
                this._confirmDialog.ejDialog("open");
                this._requestArgs = args;
                return false;
            }
            if (!ej.isNullOrUndefined(this.model.dataSource) && args.requestType == "refresh" && this.model.scrollSettings.allowVirtualScrolling) {
                                this._currentPage(1);
                           }
            this._ensureDataSource(args);
            if (this.model.enableRTL) {
                !this.element.hasClass("e-rtl") && this.element.addClass("e-rtl");
            } else {
                this.element.hasClass("e-rtl") && this.element.removeClass("e-rtl")
            }
            if (args.requestType == ej.Grid.Actions.Delete && this.model.groupSettings.groupedColumns.length == 0)
                args.tr.remove();            
            if (this._dataSource() instanceof ej.DataManager && this._dataManager.dataSource.url != undefined && !this._isRemoteSaveAdaptor && args.requestType != ej.Grid.Actions.BeginEdit && args.requestType != ej.Grid.Actions.Cancel && args.requestType != ej.Grid.Actions.Add) {
                var queryPromise = this._dataSource().executeQuery(this.model.query);
                var waitingPopup = this.element.ejWaitingPopup("instance");
                this.element.ejWaitingPopup("show");
                    queryPromise.done(ej.proxy(function (e) {
                        this.element.ejWaitingPopup("hide");
                        this.model.currentViewData = e.result;
                        this._processData(e, args);
                    }, this));

                    queryPromise.fail(ej.proxy(function (e) {
                        this.element.ejWaitingPopup("hide");
                        args.error = e.error;
                        e = [];
                        this.model.currentViewData = [];
                        this._processData(e, args);
                        this._trigger("actionFailure", args);
                    }, this));
            } else
                this.sendDataRenderingRequest(args);
        },
        _createUnboundElement: function (column) {
            var divElement = document.createElement("div");
            divElement.id = this._id + column.headerText.replace(/\s+/g, "") + "_UnboundTemplate";
            var $div = ej.buildTag("div.e-unboundcelldiv"), commands = column["commands"];
            for (var unbounType = 0; unbounType < commands.length; unbounType++) {
                var $button = ej.buildTag("button.e-" + commands[unbounType].type + "button", "", {}, { type: "button" });
                $button.val(commands[unbounType].type);
                $div.append($button);
            }
            $("body").append($(divElement).html($div).hide());
            return divElement;
        },
        _refreshUnboundTemplate: function ($target) {
            if (this._isUnboundColumn) {
                var index = 0;
                for (var column = 0; column < this.model.columns.length; column++) {
                    if (this.model.columns[column]["isUnbound"]) {
                        var $unboundDivs = $target.find(".e-unboundcell.e-" + this.model.columns[column]["headerText"].replace(/\s+/g, "")).find(".e-unboundcelldiv");
                        var commands = $.extend(true,[],this.model.columns[column].commands);
                        for (var j = 0; j < commands.length; j++) {
                            var width = ej.isNullOrUndefined(commands[j].buttonOptions.width) ? "52" : commands[j].buttonOptions.width;
                            var height = ej.isNullOrUndefined(commands[j].buttonOptions.height) ? "30" : commands[j].buttonOptions.height;
                            commands[j].buttonOptions.width = ej.isNullOrUndefined(commands[j].buttonOptions.width) ? "52" : commands[j].buttonOptions.width;
                            commands[j].buttonOptions.height = ej.isNullOrUndefined(commands[j].buttonOptions.height) ? "28" : commands[j].buttonOptions.height;
                            commands[j].buttonOptions.cssClass = ej.isNullOrUndefined(commands[j].buttonOptions.cssClass) ? this.model.cssClass : commands[j].buttonOptions.cssClass;
                            commands[j].buttonOptions.enableRTL = this.model.enableRTL;
                            var $buttons = $unboundDivs.find(".e-" + commands[j].type + "button");
                            if ($target.closest(".e-editcell").length) {
                                if (commands[j].type == "save" || commands[j].type == "cancel")
                                    $buttons.show();
                                else {
                                    $buttons.hasClass("e-deletebutton") && $buttons.hide();
                                    $buttons.hasClass("e-editbutton") && $buttons.hide();
                                }
                            } else {
                                if (commands[j].type == "save" || commands[j].type == "cancel")
                                    $buttons.hide();
                                else {
                                    $buttons.hasClass("e-deletebutton") && $buttons.show();
                                    $buttons.hasClass("e-editbutton") && $buttons.show();
                                }
                            }
                            if ($($buttons[0]).data("ejButton"))
                                $buttons.filter(".e-button").ejButton("destroy");
                            $buttons.ejButton(commands[j].buttonOptions);
                        }
                    } else
                        continue;
                }
            }
        },
        _gridTemplate: function (self, templateId) {
            return self._renderEjTemplate("#" + templateId, this.data, this.index);
        },
        _createTemplateElement: function (column) {
            var scriptElement = document.createElement("script"), t;
            scriptElement.id = (this._id + column.headerText + $.inArray(column, this.model.columns) + "_Template").split(" ").join("");
            scriptElement.type = "text/x-template";    
            if (!ej.isNullOrUndefined(column["templateID"]))
                t = $(column["templateID"]);
            else {
                if (column.template.slice(0, 1) !== "#")
                    scriptElement.text = column.template;
                else
                    t = $(column["template"]);
            }  		            
            if (t) {
                scriptElement.text = t.html();
                scriptElement.type = t.attr("type") || scriptElement.type;
            }
            $("body").append(scriptElement);
            return scriptElement;
        },
        _renderGridPager: function () {
            var $div = $(document.createElement('div'));
            var pagerModel = {};
            this.model.pageSettings.click = this._gPagerClickHandler;
            this.model.pageSettings.totalRecordsCount = this._gridRecordsCount;
            this.model.pageSettings.enableRTL = this.model.enableRTL;
            this.model.pageSettings.locale = this.model.locale;
            this.model.pageSettings.enableQueryString = this.model.pageSettings.enableQueryString;
            if (this.model.allowFiltering && this.model.filterSettings.filterType == "filterbar")
                pagerModel.enableExternalMessage = true;
            $.extend(pagerModel, this.model.pageSettings);
            pagerModel.currentPage = this._currentPage();
            pagerModel.masterObject = this;
            this.setGridPager($div);
            $div.ejPager(pagerModel);
            $div.ejPager("refreshPager");
            pagerModel = $div.ejPager("model");
            this.model.pageSettings.totalPages = pagerModel.totalPages;
            if (this._currentPage() !== pagerModel.currentPage)
                this._currentPage(pagerModel.currentPage);
            if (this.model.pageSettings.enableTemplates) {
                if (!this.model.pageSettings.showDefaults) {
                        $div.children().remove();
                    }
					var $tempHtml;
					if ($(this.model.pageSettings.template)[0].type == 'text/x-jsrender')
					    $tmpHtml = $(this.model.pageSettings.template).hide().html()
				    else
					    $tempHtml = $(this.model.pageSettings.template)[0];
                      var $divPagerContainer = $div.find('.e-pagercontainer');
                      var $customDiv = ej.buildTag('div.e-pagercontainer ');
                      $customDiv.append($tmpHtml);
                      $div.append($customDiv)
                }
              return $div;
        },

        _renderContext: function (e) {
            var menuitems = this.model.contextMenuSettings.contextMenuItems;
            var item, item2, i = 0;
            var ul = ej.buildTag('ul', "", {}, { id: this._id + '_Context' });
            for (i; i < menuitems.length; i++) {
                item = menuitems[i];
                item2 = this._items(item, ul);
                ul.append(item2);
            }
            var customitems = this.model.contextMenuSettings.customContextMenuItems;
            var custom, custom2, j = 0;
            for (j; j < customitems.length; j++) {
                custom = customitems[j];
                custom2 = this._items(custom, ul);
                ul.append(custom2);
            }
            this.element.append(ul);
            $(ul).ejMenu({
                menuType: ej.MenuType.ContextMenu,
                openOnClick: false,
                contextMenuTarget: "#" + this._id,
                click: $.proxy(this._clickevent, this),
                width: "auto",
                beforeOpen: $.proxy(this._menu, this)
            });

            this._conmenu = ul.data("ejMenu");
        },
        _clickevent: function (sender) {
            var args = sender.events.text;
            var tr = $(this._contexttarget.parentNode);
            var c = $(this._contexttarget);
            var columnName = c.attr("ej-mappingname");
            switch (args) {
                case "Add Record": this._startAdd();
                    break;
                case "Edit Record": this.startEdit(tr);
                    break;
                case "Delete Record": this._deleteRow(tr);
                    break;
                case "Save": this.endEdit();
                    break;
                case "Cancel": this.cancelEdit();
                    break;
                case "Sort In Descending Order": var columnSortDirection = ej.sortOrder.Descending;
                    this.sortColumn(columnName, columnSortDirection);
                    break;
                case "Sort In Ascending Order": var columnSortDirection = ej.sortOrder.Ascending;
                    this.sortColumn(columnName, columnSortDirection);
                    break;
                case "Grouping": this.groupColumn(columnName);
                    break;
                case "Ungrouping": this.ungroupColumn(columnName);
                    break;
                case "Next Page":
                case "Previous Page":
                case "Last Page":
                case "First Page": this._page(sender);
                    break;
                default: this._trigger("contextClick", sender);
            }

        },

        _menu: function (sender) {
            var context = this._conmenu.element;
            this._contexttarget = sender.target;
            var td = $(this._contexttarget);
            if (td.hasClass("e-rowcell") && this.model.allowSelection)
                this.selectRows(this.getIndexByRow(td.parent()), null, td);
            var element = sender.target.parentNode.getAttribute("aria-sort");
            var target = sender.target.className;
            var sorting = $(context);
            var value = sender.target.getAttribute("ej-mappingname");
            switch (target) {
                case "e-pager e-js": var a = $(context.find(".e-page"));
                    context.find(".e-head").css("display", "none");
                    context.find(".e-content").css("display", "none");
                    context.find(".e-savcan").css("display", "none");
                    a.css("display", "block");
                    break;
                case "e-headercelldiv": var a = $(context.find(".e-head"));
                    context.find(".e-page").css("display", "none");
                    context.find(".e-content").css("display", "none");
                    context.find(".e-savcan").css("display", "none");
                    a.css("display", "block");
                    break;
                case "e-rowcell e-selectionbackground e-active": var a = $(context.find(".e-content"));
                    context.find(".e-head").css("display", "none");
                    context.find(".e-page").css("display", "none");
                    context.find(".e-savcan").css("display", "none");
                    a.css("display", "block");
                    break;
               default: var a = $(context);
                   return false;
            }
            switch (element) {
                case "ascending": sorting.find(".ascending").parent().css("display", "none");
                    break;
                case "descending": sorting.find(".descending").parent().css("display", "none");
                    break;
            }
            if (this.model.isEdit) {
                var a = $(context.find(".e-savcan"));
                context.find(".e-head").css("display", "none");
                context.find(".e-content").css("display", "none");
                context.find(".e-page").css("display", "none");
                a.css("display", "block");
            }

            if (this.model.pageSettings.currentPage == 1) {
                sorting.find(".previous").parent().css("display", "none");
                sorting.find(".first").parent().css("display", "none");
            }
            else if (this.model.pageSettings.currentPage == this.model.pageSettings.totalPages) {
                sorting.find(".last").parent().css("display", "none");
                sorting.find(".nextpage").parent().css("display", "none");
            }
            if (this.model.groupSettings.groupedColumns.indexOf(value) != -1)
                a.find(".group").parent().css("display", "none");
            else if (this.model.groupSettings.groupedColumns.indexOf(value) == -1)
                a.find(".ungroup").parent().css("display", "none");
            if (this.model.contextOpen)
                this._trigger("contextOpen", sender);
        },

        _items: function (item) {
            if (item.indexOf("Record") != -1) {
                var li = ej.buildTag('li', "", {}, { "class": "e-content" });
                li.css("display", "none");
            }
            else if (item.indexOf("Page") != -1) {
                var li = ej.buildTag('li', "", {}, { "class": "e-page" });
                if (item.indexOf("Next") != -1)
                    var div = ej.buildTag('div', "", {}, { "class": "nextpage" });
                else if (item.indexOf("Previous") != -1)
                    var div = ej.buildTag('div', "", {}, { "class": "previous" });
                else if (item.indexOf("Last") != -1)
                    var div = ej.buildTag('div', "", {}, { "class": "last" });
                else if (item.indexOf("First") != -1)
                    var div = ej.buildTag('div', "", {}, { "class": "first" });
                li.css("display", "none");
            }
            else if (item == "Save" || item == "Cancel") {
                var li = ej.buildTag('li', "", {}, { "class": "e-savcan" });
                li.css("display", "none");
            }
            else {
                var li = ej.buildTag('li', "", {}, { "class": "e-head" });
                if (item.indexOf("Ascending") != -1)
                    var div = ej.buildTag('div', "", {}, { "class": "ascending" });
                else if (item.indexOf("Descending") != -1)
                    var div = ej.buildTag('div', "", {}, { "class": "descending" });
                else if (item == "Grouping")
                    var div = ej.buildTag('div', "", {}, { "class": "group" });
                else if (item == "Ungrouping")
                    var div = ej.buildTag('div', "", {}, { "class": "ungroup" });
                li.css("display", "none");
            }
            li.append(div);
            var a = document.createElement("a");
            a.innerHTML = item;
            li.append(a);
            return li;
        },

        _page: function (send) {
            if (send.events.text == "Next Page") {
                var b = this.model.pageSettings.currentPage;
                ++b;
                this.gotoPage(b);
            }
            else if (send.events.text == "Previous Page") {
                var b = this.model.pageSettings.currentPage;
                if (b > 1) {
                    --b;
                    this.gotoPage(b);
                }
                else
                    this.gotoPage(b);
            }
            else if (send.events.text == "Last Page") {
                var b = this.model.pageSettings.totalPages
                this.gotoPage(b);
            }
            else
                this.gotoPage(1);


        },

        /**
		 * Send a paging request to specified page in grid
         * @alias ejGrid#gotoPage
		 * @return jQuery
		 * @param {number} pageIndex Pass the page index to perform paging at specified page index
		 * @example 
		 * &lt;script&gt;
		 * // Create grid object.
		 * var gridObj = $("#Grid").data("ejGrid");
         * // Sends a paging request to the grid with specified page index
		 * gridObj.gotoPage(3);
		 * &lt;/script&gt;
		 * @example 
		 * &lt;script&gt;
		 * // Sends a paging request to the grid with specified page index
		 * $("#Grid").ejGrid("gotoPage", 3);        
		 * &lt;/script&gt;
         */
        gotoPage: function (pageIndex) {
            if (!this.model.allowPaging && (!this.model.allowScrolling && !this.model.scrollSettings.allowVirtualScrolling))
                return;
            var args = {}, returnValue;
            args.previousPage = this._currentPage();
            this._currentPage(pageIndex);
            args.endIndex = ((this._currentPage() * this.model.pageSettings.pageSize) > this._gridRecordsCount) ? (this._gridRecordsCount) : (this._currentPage() * this.model.pageSettings.pageSize);
            args.startIndex = (this._currentPage() * this.model.pageSettings.pageSize) - this.model.pageSettings.pageSize;
            args.currentPage = pageIndex;
            if (this.model.allowPaging) {
                //this.model.pageSettings.currentPage = pageIndex;
                //this. getPager().ejPager("refreshPager");
                args.requestType = ej.Grid.Actions.Paging;
            }
            if (this.model.scrollSettings.allowVirtualScrolling && this.model.allowScrolling) {
                args.requestType = ej.Grid.Actions.VirtualScroll;
            }
            returnValue = this._processBindings(args);
            if (returnValue)
                this._currentPage(args.previousPage);
            this._primaryKeyValues = [];
        },
        _gPagerClickHandler: function (sender) {
            if (this._prevPageNo == sender.currentPage)
                return;
            this.model.masterObject.gotoPage(sender.currentPage);
            return false;
        },
        _processData: function (e, args) {
            if (e.count == 0 && this.model.currentViewData.length)
                this._gridRecordsCount = e.result.length;
            else
                this._gridRecordsCount = e.count;
            if (this.getPager() != null)
                this.model.pageSettings.totalRecordsCount = this._gridRecordsCount;
            if ((args.requestType == ej.Grid.Actions.Filtering || ej.Grid.Actions.Save || (this.model.filterSettings.filteredColumns.length > 0 && args.requestType == ej.Grid.Actions.Refresh)))
                this._filteredRecordsCount = e.count;
            this.sendDataRenderingRequest(args);
        },
        _ieClearRemover: function (element) {
            var searchBoxHeight = $(element).height();
            element.style.paddingTop = parseFloat(searchBoxHeight / 2) + "px";
            element.style.paddingBottom = parseFloat(searchBoxHeight / 2) + "px";
            element.style.height = "1px";
            element.style.lineHeight = "1px";
        },
        _renderGridFooter: function () {
            if (this.model.summaryRows.length > 0) {
                var _$gridFooter = ej.buildTag("div.e-gridfooter");
                var $table = ej.buildTag("table.e-gridsummary", "", {}, { cellspacing: "0.25px" });
                this.setGridFooterContent(_$gridFooter);
                if (this.model.scrollSettings.frozenColumns > 0) {
                    var $frozenFooterDiv = ej.buildTag("div.e-frozenfooterdiv"), $movableFooter = ej.buildTag("div.e-movablefooter")
                        , $tableClone = $table.clone(), $movableFooterDiv = ej.buildTag("div.e-movablefooterdiv");
                    $movableFooter.append($movableFooterDiv);
                    $table.append(this.getHeaderTable().first().find('colgroup').clone());
                    $tableClone.append(this.getHeaderTable().last().find('colgroup').clone());
                    $frozenFooterDiv.append($table);
                    $movableFooterDiv.append($tableClone);
                    this.setGridFooterTable($table.add($tableClone));
                    this._createSummaryRows(this.getFooterTable());
                    _$gridFooter.append($frozenFooterDiv.add($movableFooter));
                    _$gridFooter.find(".e-frozenfooterdiv").outerWidth(this.getHeaderContent().find(".e-frozenheaderdiv").width())
                          .end().find(".e-movablefooterdiv").outerWidth(this.getContent().find(".e-movablecontentdiv").width());
                }
                else {
                    $table.append(this.getHeaderTable().find('colgroup').clone());
                    this.setGridFooterTable($table);
                    this._createSummaryRows(this.getFooterTable());
                    _$gridFooter.append($table);
                }
                return _$gridFooter;
            } else
                throw "summary row collection is missing";
        },
        _createSummaryRows: function (table, summaryData, aggregates) {
            var col = table.find("col");
            if (table.find("tbody").length > 0)
                table.find("tbody").remove();
            var $tBody = ej.buildTag('tbody'), proxy = this, $tBodyClone = $tBody.clone();
            var summaryCol = this.model.summaryRows;
            if (!ej.isNullOrUndefined(summaryData) && this._isCaptionSummary)
                summaryCol = this._captionSummary();
            $.each(summaryCol, function (indx, row) {
                if (row.showTotalSummary === false && ej.isNullOrUndefined(summaryData)) return true;
                var $tr = ej.buildTag('tr');
                for (var i = 0; i < proxy.model.groupSettings.groupedColumns.length; i++) {
                    $tr.prepend(ej.buildTag('td').addClass("e-indentcell"));
                }
                if (proxy.model.detailsTemplate != null) {
                    if (proxy.model.groupSettings.groupedColumns.length != 0)
                        $tr.children("td.e-indentcell").last().after("<td class='e-summaryrow'></td>");
                    else
                        $tr.prepend("<td class='e-summaryrow'></td>");
                }
                var $cells = proxy.getHeaderTable().find('td').clone().addClass("e-summaryrow"), count = 0;
                for (var i = 0; i < proxy.model.columns.length; i++) {
                    var colindex = proxy.model.columns[i];
                    if (count == 0 && colindex.visible != false) {
                        $cells.eq(i).html(row.title);
                        break;
                    }
                }
                proxy._hideSummaryColumn($cells, col);
                if (proxy.model.scrollSettings.frozenColumns > 0) {
                    var $trClone = $tr.clone();
                    $tBody.append($tr.append($cells.slice(0, proxy.model.scrollSettings.frozenColumns)));
                    $tBodyClone.append($trClone.append($cells.slice(proxy.model.scrollSettings.frozenColumns)));
                }
                else
                    $tBody.append($tr.append($cells));
                $.each(row.summaryColumns, function (cindx, col) {
                    var value = aggregates ? aggregates[indx][col.dataMember] : proxy._getSummaryValues(col, summaryData), prefix = col.prefix ? col.prefix : "";
                    var index = proxy.getColumnIndexByField(col.displayColumn), suffix = col.suffix ? col.suffix : "";
                    if ($($cells[index]).html() != "" && prefix == "")
                        prefix = $($cells[index]).html();
                    $($cells[index]).html(prefix + (col.format ? proxy.formatting(col.format, value,proxy.model.locale) : value) + suffix).css("text-align", proxy.model.columns[index].textAlign);
                });
            });
            if (this.model.scrollSettings.frozenColumns > 0) {
                table.first().append($tBody);
                table.last().append($tBodyClone);
            }
            else
                table.append($tBody);
        },
        _getSummaryValues: function (summaryCol, summaryData) {
            var $value, jsonData;
            if (!ej.isNullOrUndefined(summaryData))
                jsonData = summaryData;
            else if (this.model.filterSettings.filteredColumns.length > 0)
                jsonData = this._filteredRecords;
            else
                jsonData = this._dataSource();
				
            var dbMgr;
            if (jsonData instanceof ej.DataManager){
                dbMgr = jsonData;
                jsonData = jsonData.dataSource.json;
            } else
                dbMgr = ej.DataManager(jsonData);
				
            switch (summaryCol.summaryType) {
                case ej.Grid.SummaryType.Maximum:
                    var obj = ej.max(jsonData, summaryCol.dataMember);
                    $value = obj[summaryCol.dataMember];
                    break;
                case ej.Grid.SummaryType.Minimum:
                    var obj = ej.min(jsonData, summaryCol.dataMember);
                    $value = obj[summaryCol.dataMember];
                    break;
                case ej.Grid.SummaryType.Average:
                    $value = ej.avg(jsonData, summaryCol.dataMember);
                    break;
                case ej.Grid.SummaryType.Sum:
                    $value = ej.sum(jsonData, summaryCol.dataMember);
                    break;
                case ej.Grid.SummaryType.Count:
                    $value = jsonData.length;
                    break;
                case ej.Grid.SummaryType.TrueCount:
                    var predicate = ej.Predicate(summaryCol.dataMember, "equal", true);
                    $value = dbMgr.executeLocal(ej.Query().where(predicate)).length;
                    break;
                case ej.Grid.SummaryType.FalseCount:
                    var predicate = ej.Predicate(summaryCol.dataMember, "equal", false);
                    $value = dbMgr.executeLocal(ej.Query().where(predicate)).length;
                    break;
                case ej.Grid.SummaryType.Custom:
                    var fn = summaryCol.customSummaryValue;
                    if (fn) {
                        if (typeof fn === "string")
                            fn = ej.util.getObject(fn, window);
                        if ($.isFunction(fn))
                            $value = fn.call();
                    }
                    break;
            }
            return $value;
        },
        _hideCaptionSummaryColumn: function () {
            var headerColumn = this.getHeaderTable().find('.e-headercelldiv[ej-mappingname]').first();
            var captionTd = this.getContentTable().find('.e-groupcaption').clone();
            var groupCaptionParent = this.getContentTable().find('.e-groupcaption').parent();
            var colLength = this.model.columns.length - 1;
            if (this._isCaptionSummary) {
                this.getContentTable().find('.e-summaryrow').remove();
                this.getFooterTable().find("tbody td").slice(-colLength).removeClass("e-groupcaptionsummary").addClass("e-summaryrow");
				if(this.getFooterTable() != null){
                     this.getContentTable().find('.e-recordplusexpand').parent().children('.e-indentcell').remove();
				}
                if (!this.model.groupSettings.showGroupedColumn) {
                    if (!headerColumn.is(':visible')) {
                        this.getContentTable().find('.e-groupcaption').addClass("e-hide");
                        for (i = 0; i < captionTd.length; i++) {
                            groupCaptionParent.eq(i).children().not('.e-hide,.e-recordplusexpand').filter('td.e-groupcaptionsummary:first').replaceWith(captionTd.eq(i));
                        }
                    }
                }
            }
            this.getContentTable().find('.e-recordtable').find('.e-indentcell').remove();
        },
        _hideSummaryColumn: function (td, col) {
            if (col.length > this.model.columns.length)
                col = col.slice(col.length - this.model.columns.length);
            if (!this.model.groupSettings.showGroupedColumn && this.model.showSummary) {
                for (i = 0; i < this.model.columns.length; i++) {
                    for (j = 0; j < this.model.groupSettings.groupedColumns.length || j < this._hiddenColumns.length; j++) {
                        var headerColumn = this.getHeaderTable().find('.e-headercelldiv[ej-mappingname]');
                        if (!headerColumn.eq(i).is(':visible')) {
                            col.eq(i).css("display", "none");
                            $(td[i]).addClass("e-hide");
                            break;
                        }
                        else {
                            if (col.eq(i).css("display") == "none")
                                col.eq(i).css("display", "");
                        }
                    }
                }
            }
            else {
                for (i = 0; i < this.model.columns.length; i++) {
                    if (!this.model.columns[i]["visible"]) {
                        col.eq(i).css("display", "none");
                        $(td[i]).addClass("e-hide");
                    }
                    else {
                        if (col.eq(i).css("display") == "none")
                            col.eq(i).css("display", "");
                    }
                }
            }
        },
        _getRowHeights: function () {
            var trs = this.getRows();
            if (trs !== null) {
                this._rowHeightCollection = [];
                if ((this.model.scrollSettings.frozenColumns > 0 && trs[0] !== undefined) || (typeof trs[0].item !== "undefined" && typeof trs[0].length == "number"))
                    trs = trs[0];
                for (var i = 0 ; i < trs.length ; i++) {
                    this._rowHeightCollection[i] = trs[i].offsetTop;
                }
            }
            return this._rowHeightCollection;
        },
        _initScrolling: function () {
            var frozen = [], unfrozen = [], hideColumns = 0;
            for (var columnCount = 0; columnCount < this.model.columns.length; columnCount++) {
                if (this.model.columns[columnCount].visible === false && columnCount < this.model.scrollSettings.frozenColumns)
                    hideColumns++;
                if (this.model.columns[columnCount]["isFrozen"] === true)
                    frozen.push(this.model.columns[columnCount]);
                else
                    unfrozen.push(this.model.columns[columnCount]);
            }
            this.model.scrollSettings.frozenColumns += hideColumns;
            if (frozen.length > 0) {
                var freeze = this.model.scrollSettings.frozenColumns;
                this.model.columns = $.merge($.merge([], frozen), unfrozen);
                this.model.scrollSettings.frozenColumns = frozen.length;
                if(frozen.length != freeze && freeze != 0)
                    this.model.scrollSettings.frozenColumns = freeze;
            }
            if ((this.model.scrollSettings.frozenColumns > 0 || this.model.scrollSettings.frozenRows > 0) && (this.model.allowGrouping || this.model.rowTemplate != null || this.model.detailsTemplate != null || this.model.scrollSettings.allowVirtualScrolling || this.model.editSettings.editMode == "batch")) {
                this._renderAlertDialog();
                this._alertDialog.find(".e-content").text(this._getLocalizedLabels("FrozenNotSupportedException"));
                this._alertDialog.ejDialog("open");
                return;
            }
            if (this.model.scrollSettings.allowVirtualScrolling && this.model.allowScrolling) {
                this.model.pageSettings.pageSize = this.model.pageSettings.pageSize == 12 ? Math.round(this.model.scrollSettings.height / 32) + 1 : this.model.pageSettings.pageSize;
                this.model.pageSettings.totalPages = Math.ceil(this._gridRecordsCount / this.model.pageSettings.pageSize);
            }
            if (this.model.width || this.model.height) {
                this.model.allowScrolling = true;
                if (this.model.width) this.model.scrollSettings.width = this.model.width;
                if (this.model.height) this.model.scrollSettings.height = this.model.height;
            }
        },
        _checkScrollActions: function (requestType) {
            if (requestType == ej.Grid.Actions.Grouping || requestType == ej.Grid.Actions.Ungrouping || requestType == ej.Grid.Actions.Add || requestType == ej.Grid.Actions.Cancel
                || requestType == ej.Grid.Actions.Save || requestType == ej.Grid.Actions.Delete || requestType == ej.Grid.Actions.Filtering || requestType == ej.Grid.Actions.Paging || requestType == ej.Grid.Actions.Refresh)
                return true;
            return false;
        },
        _refreshScroller: function (args) {
            var gridContent = this.getContent().first(), direction;
            if (ej.isNullOrUndefined(gridContent.data("ejScroller")))
                return;
            if (this.model.scrollSettings.frozenColumns > 0) {
                direction = this.model.enableRTL ? "margin-right" : "margin-left";
                gridContent.find(".e-movablecontent").css(direction, gridContent.find(".e-frozencontentdiv").width() + "px");
                this.getHeaderContent().find(".e-movableheader").removeAttr("style").css(direction, this.getHeaderContent().find(".e-frozenheaderdiv").width() + "px");
                this.refreshScrollerEvent();
                gridContent.find(".e-movablecontent").scrollLeft(this.getHeaderContent().find(".e-movableheader").scrollLeft());
            }
            if (this.model.scrollSettings.frozenRows > 0) {
                this._initFrozenRows();
                var temp = this.getScrollObject().model.scrollTop;
                if (args.requestType == ej.Grid.Actions.Add)
                    this.getScrollObject().scrollY(0, true);
                if (!ej.isNullOrUndefined(this.getScrollObject()._v))
                    this.getScrollObject()._v.skipChange = true;
            }
            if (args.requestType == "beginedit") {
                var temp = this.getScrollObject().model.scrollTop;
                this.getScrollObject().scrollY(0, true);
            }
            if (!ej.isNullOrUndefined(this.model.dataSource) && args.requestType == "refresh" && this.model.scrollSettings.allowVirtualScrolling) {
                                this._refreshVirtualContent(1);
                                this.getScrollObject().scrollY(0);
                           }
            gridContent.ejScroller("refresh");
            gridContent.ejScroller("model.enableRTL", this.model.enableRTL);
            if (gridContent.ejScroller("isVScroll") &&  !this.getScrollObject().model.autoHide )
                this.element.find(".e-gridheader").addClass("e-scrollcss");
            else
				this._showHideScroller();
            this._getRowHeights();
            if (temp && args.requestType != ej.Grid.Actions.Add) {
                this._currentTopFrozenRow = 0;
                this.getScrollObject().scrollY(temp, true);
            }
            if (args.requestType == "virtualscroll") {
                var top = this.getScrollObject().model.scrollTop + this.getScrollObject().model.height - (this.getScrollObject().model.height * .3);
                this.getScrollObject().scrollY(top, true);
            }
        },
        _renderScroller: function () {
            if (!this.model.scrollSettings)
                this.model.scrollSettings = {};

            if (typeof (this.model.scrollSettings.width) == "string") {
                var width = this.element.width();
                if (this.model.scrollSettings.width == "auto")
                    this.model.scrollSettings.width = "100%";
                this.model.scrollSettings.width = width * (parseFloat(this.model.scrollSettings.width) / 100)
            }

            if (typeof (this.model.scrollSettings.height) == "string") {
                var height = this.element.height();
                if (this.model.scrollSettings.height == "auto")
                    this.model.scrollSettings.height = "100%";
                this.model.scrollSettings.height = height * (parseFloat(this.model.scrollSettings.height) / 100)
            }

            if ((this.model.scrollSettings.width || this.model.width) && !this._mediaQuery)
                this.element.width(this.model.scrollSettings.width || this.model.width);

            var $content = this.getContent().attr("tabindex", "0"), staticWidth, direction, gridRows = this.getRows();
            
            if (this.model.scrollSettings.frozenColumns > 0) {
                scrollWidth = this.getContent().find(".e-frozencontentdiv").width() + 20;
                if (scrollWidth > this.model.scrollSettings.width) {
                    this.getContent().remove();
                    this.getHeaderTable().eq(1).remove();
                    this._alertDialog.find(".e-content").text(this._getLocalizedLabels("FrozenColumnsViewAlert"));
                    this._alertDialog.ejDialog("open");
                    return;
                }
                staticWidth = this.getContent().find(".e-frozencontentdiv").width();
                direction = this.model.enableRTL ? "margin-right" : "margin-left";
                this.getContent().find(".e-movablecontent").css(direction, staticWidth + "px");
                this.getHeaderContent().find(".e-movableheader").css(direction, staticWidth + "px");
                this.model.scrollSettings["targetPane"] = ".e-movablecontent";
            }
            this._initFrozenRows();
            if (this.model.scrollSettings.autoHide)
                this.model.scrollSettings["show"] = $.proxy(this._showHideScroller,this);
            $content.ejScroller(this.model.scrollSettings);
            if (!this.model.scrollSettings.autoHide) 
                this._showHideScroller();
            this.refreshScrollerEvent();
            var proxy = this;
            if (proxy.model.scrollSettings.allowVirtualScrolling) {
                var model = this._refreshVirtualPagerInfo();
                this._showPagerInformation(model);
                $content.ejScroller({
                    scroll: function (e) {
                        e["reachedEnd"] = this.content()[0].scrollHeight - e.scrollTop == this.content()[0].clientHeight;
                        if((e.source == "button" || e.source == "key" || e.source == "wheel") && proxy.model != null)
							proxy._virtualScroll(e);
                    },
                    thumbEnd: function (e) {
                        if (!$(e.originalEvent.target).hasClass("e-rowcell"))
                            e["reachedEnd"] = this.content()[0].scrollHeight - e.scrollData.sTop == this.content()[0].clientHeight;
                            if(e.scrollData.handler == "e-hhandle")
								return;
							if(proxy.model != null)
								proxy._virtualScroll(e);
                    }
                });
            }
        },
        _showHideScroller: function () {
            if (this.getBrowserDetails().browser != "msie" && this.model.scrollSettings.frozenColumns == 0 && !this._mediaQuery) {
                this.getHeaderContent().find("div table").first().width(this.getContentTable().width());
                this.getHeaderTable().width(this.getContentTable().width());
            }
            if (this.getContent().ejScroller("isVScroll")) {
                this.getHeaderContent().find("div").first().addClass("e-headercontent");
                !this.model.scrollSettings.autoHide && this.getHeaderContent().addClass("e-scrollcss")
            } else 
                this.element.find(".e-gridheader").removeClass("e-scrollcss");
            if (this.getBrowserDetails().browser == "msie" && this.model.scrollSettings.frozenColumns == 0)
                !this.getContent().ejScroller("isVScroll") ? this.getContent().width(this.getHeaderContent().width()) : this.getContent().width(this.getHeaderContent().width() + 18);
        },
        _initFrozenRows: function () {
            var gridRows = this.getRows();
            if (!this.model.currentViewData || this.model.currentViewData.length == 0)
                return;
            if (this.model.scrollSettings.frozenRows > 0 && gridRows != null) {
                this.model.scrollSettings["scroll"] = $.proxy(this._scroll, this);
                this.getContent().find(".e-frozeny").removeClass("e-frozeny")
                    .end().find(".e-frozenrow").removeClass("e-frozenrow");
                if (!ej.isNullOrUndefined(gridRows[0][this.model.scrollSettings.frozenRows - 1]) && !ej.isNullOrUndefined(gridRows[1][this.model.scrollSettings.frozenRows - 1]) && this.model.scrollSettings.frozenColumns > 0)
                    $(gridRows[0][this.model.scrollSettings.frozenRows - 1].cells).add(gridRows[1][this.model.scrollSettings.frozenRows - 1].cells).addClass("e-frozeny").parent().addClass("e-frozenrow");
                else
                    $(gridRows[this.model.scrollSettings.frozenRows - 1].cells).addClass("e-frozeny").parent().addClass("e-frozenrow");
                this.model.scrollSettings.height = this._rowHeightCollection[Math.floor(this.model.scrollSettings.height / this._rowHeightCollection[1])] + 18;
            }
            else
                delete this.model.scrollSettings["scroll"];
        },
        refreshScrollerEvent: function () {
            var proxy = this;
            this.getContent().find(".e-content,.e-movablecontent").scroll(ej.proxy(function (e) {
                if (this.model.scrollSettings.targetPane)
                    this.getHeaderContent().find(".e-movableheader").scrollLeft($(e.currentTarget).scrollLeft());
                else
                    this.getHeaderContent().find("div").first().scrollLeft($(e.currentTarget).scrollLeft());
                if (this.model.scrollSettings.frozenRows > 0 && this.model.editSettings.editMode.indexOf("inlineform") != -1 && this.model.isEdit) {
                    var scrollTop = e.target.scrollTop;
                    this.getContent().find(".e-content").scrollTop(0);
                    this.getScrollObject().scrollY(this.getScrollObject().model.scrollTop + scrollTop, true);
                }
            }, this));
            this.element.find(".e-gridheader").find(".e-headercontent,.e-movableheader").scroll(ej.proxy(function (e) {
                var $currentTarget = $(e.currentTarget);
                if (this.model.scrollSettings.targetPane) {
                    this.getContent().find(".e-movablecontent").scrollLeft($currentTarget.scrollLeft());
                    this.model.showSummary && this.getFooterContent().find(".e-movablefooter").scrollLeft($currentTarget.scrollLeft());;
                }
                else {
                    this.model.showSummary && this.getFooterContent().scrollLeft($currentTarget.scrollLeft());
                    this.getContent().find(".e-content").first().scrollLeft($currentTarget.scrollLeft());
                }
            }, this));
        },
        _renderByFrozenDesign: function () {
            var $div = $(document.createElement('div')), col = this._getMetaColGroup().find("col"), colgroups = {};
            colgroups["colgroup1"] = $div.append(ej.buildTag("colgroup").append(col.splice(0, this.model.scrollSettings.frozenColumns))).html();
            colgroups["colgroup2"] = $div.html(ej.buildTag("colgroup").append(col)).html();
            this.getContent().find("div").first().get(0).innerHTML = $.render[this._id + "_FrozenTemplate"]({ datas: this.model.currentViewData }, colgroups);
            this.setGridContentTable(this.getContent().find(".e-table").attr("role", "grid"));
        },
        addFrozenTemplate: function () {
            var template = "<div class='e-frozencontentdiv'>"
            + "<table cellspacing='0.25px' class='e-table'>{{:~colgroup1}}<tbody>"
            + "{{for datas tmpl='" + this._id + "_JSONFrozenTemplate'/}}"
            + "</tbody></table></div>"
            + "<div class='e-movablecontent'><div class='e-movablecontentdiv'><table cellspacing='0.25px' class='e-table'>{{:~colgroup2}}<tbody>"
            + "{{for datas tmpl='" + this._id + "_JSONTemplate'/}}"
            + "</tbody></table></div></div>", templates = {};
            templates[this._id + "_FrozenTemplate"] = template;
            $.templates(templates);
        },
        _getTopRow: function (offsetTop) {
            var currentTopRow = this.model.scrollSettings.frozenRows, i = 0;
            if (offsetTop > 10) {
                for (var i = 0; i < this._rowHeightCollection.length; i++) {
                    if (this._rowHeightCollection[i] > offsetTop) {
                        currentTopRow = this.model.scrollSettings.frozenRows + i - 1;
                        break;
                    }
                }
            }
            return { imaginaryIndex: currentTopRow, actualIndex: i };
        },
        _showHideRow: function (from, to, action, scrollPosition) {
            var rows = this.getRows();
            if (this.model.scrollSettings.frozenColumns > 0)
                $(rows[0]).slice(from, to).add($(rows[1]).slice(from, to).toArray())[action]();
            else
                $(rows).slice(from, to)[action]();
            this._currentTopFrozenRow = action == "show" ? from : to;
            this.getScrollObject()._changevHandlerPosition(scrollPosition);
        },
        _scroll: function (args) {
            if (args.scrollData != null && args.scrollData.dimension != "width") {
                args.cancel = true;
                var rows = this.getRows(), indexes = this._getTopRow(args.scrollTop), currentTopRow = indexes.imaginaryIndex, frozenRows;
                if (currentTopRow > this._currentTopFrozenRow)
                    this._showHideRow(this.model.scrollSettings.frozenRows, currentTopRow, "hide", this._rowHeightCollection[indexes.actualIndex]);
                else if (currentTopRow < this._currentTopFrozenRow)
                    this._showHideRow(currentTopRow, this._currentTopFrozenRow + 1, "show", this._rowHeightCollection[indexes.actualIndex]);
                args.model.scrollTop = args.scrollTop;
            }
            else {
                if (this.getScrollObject()._v != null)
                    this.getScrollObject()._v.skipChange = true;
            }
        },
        _renderAlertDialog: function () {
            var $contentDiv = ej.buildTag('div.e-content', this._getLocalizedLabels("frozenColumnsMessage"))
                , $buttons = ej.buildTag('span.e-buttons', "<input type='button' id=" + this._id + 'ConfirmDialogOK' + " value='" + this._getLocalizedLabels("OkButton") + "'/>");
            this._alertDialog = ej.buildTag('div#' + this._id + 'AlertDialog');
            this._alertDialog.append($contentDiv).append($buttons);
            this.element.append(this._alertDialog);
            $buttons.find("input").ejButton({
                cssClass: this.model.cssClass,
                showRoundedCorner: true,
                size: "mini",
                click: $.proxy(function (args) {
                    this._alertDialog.ejDialog("close");
                }, this)
            });
            this._renderFDialog(this._id + 'AlertDialog');
            this._alertDialog.ejDialog({ width: "auto", enableModal: true });
        },
        _renderFDialog: function (id) {
            $("#" + id).ejDialog({ showOnInit: false, "enableRTL": this.model.enableRTL, "cssClass": this.model.cssClass, "showHeader": false, width: 260, enableResize: false, allowKeyboardNavigation: false, content: "#" + this._id });
        },
        _virtualScroll: function (e) {
            if (e != null) {
                var flag = 0;
                var recordCount = this.model.filterSettings.filteredColumns.length == 0 ? this._searchCount == null ? this._gridRecordsCount : this._searchCount : this._filteredRecordsCount;
                var pageInfo = this.model.pageSettings;
                var tbody = this.getContentTable()[0].tBodies[0];
                var virtualRows = $(tbody).find('tr.e-virtualrow');
                pageInfo.totalPages = Math.ceil(recordCount / pageInfo.pageSize);
                if (e.scrollTop !== undefined)
                    e.model.scrollTop = e.scrollTop;
                if (e.reachedEnd != undefined) e.model.reachedEnd = e.reachedEnd;
                var currentPageNo = this._calculateCurrenPage(virtualRows, this.getContentTable(), e.model);
                if (currentPageNo > pageInfo.totalPages)
                    currentPageNo = pageInfo.totalPages;
                if (pageInfo.currentPage != currentPageNo && $.inArray((currentPageNo - 1) * pageInfo.pageSize, this.virtualLoadedPages) == -1) {
                    this._isVirtualRecordsLoaded = false;
                }
                if (!this._isVirtualRecordsLoaded) {                    
                    if ($.inArray((currentPageNo - 1) * pageInfo.pageSize, this.virtualLoadedPages) == -1) {
                        if (this.model.scrollSettings.virtualScrollMode == "continuous" && !e.reachedEnd)
                            return
                        if (currentPageNo == pageInfo.totalPages && $.inArray((currentPageNo - 2) * pageInfo.pageSize, this.virtualLoadedPages) == -1) {
                            flag++;
                            this.set_currentPageIndex(currentPageNo - 1);
                        }
                        if (flag == 1) this._lastRow = true;
                        this.set_currentPageIndex(currentPageNo);
                    }
                    pageInfo.currentPage = currentPageNo;
                }
                else
                    pageInfo.currentPage = currentPageNo;
                var model = this._refreshVirtualPagerInfo();
                this._showPagerInformation(model);
            }
        },

        _createPagerStatusBar: function () {
            var $statusBar = this.element.find(".e-pagerstatusbar");
            if ($statusBar.length)
                $statusBar.remove();
            var $pagermsgDiv = ej.buildTag('div.e-pagermsgdiv');
            this.$pagerStatusBarDiv = ej.buildTag('div.e-pagerstatusbar').append($pagermsgDiv);
            this.$pagerStatusBarDiv.appendTo(this.element);
            this.$pagerStatusBarDiv.css("display", "none");
        },
        _refreshVirtualContent: function (currentPage) {
            var rowHeight = this.getRowHeight();
            var recordsCount = this.model.filterSettings.filteredColumns.length == 0 ? this._searchCount == null ? this._gridRecordsCount : this._searchCount : this._filteredRecordsCount;
            if (currentPage != null) {
                this._currentPage(currentPage);
                var model = this._refreshVirtualPagerInfo();
                this._showPagerInformation(model);
            }
            var currentIndex = this.getCurrentIndex();
            var tbody = this.getContentTable()[0].tBodies[0];
            if (this.getCurrentIndex() > 0) {
                var virtualTRTop = document.createElement("tr");
                $(virtualTRTop).addClass("e-virtualrow").css("height", rowHeight * currentIndex).prependTo(tbody);
            } if (currentIndex + this.model.pageSettings.pageSize <= recordsCount) {
                var virtualTRBottom = document.createElement("tr");
                var virtualHeight = this.model.scrollSettings.virtualScrollMode == "normal" ? rowHeight * (recordsCount - (currentIndex + this.model.pageSettings.pageSize)) : 1;
                $(virtualTRBottom).addClass("e-virtualrow").css("height",virtualHeight).appendTo($(tbody));
            }
            this.virtualLoadedPages = new Array();
            this.virtualLoadedPages.push(currentIndex >= 0 ? currentIndex : 0);
            var focusTR = $(tbody).find('tr:not(.e-virtualrow)').attr('name', currentIndex >= 0 ? currentIndex : 0)[0];
            if (focusTR && focusTR.previousSibling && ($(focusTR.previousSibling).hasClass("e-virtualrow") || focusTR.previousSibling.offsetTop > (currentIndex * this.getContent().height()))) {
                this.getContent().children("div").first().scrollTop(this.getContent().find(".content").scrollTop() - (this.getContent().find(".content").scrollTop() - focusTR.offsetTop));
                this._isVirtualRecordsLoaded = true;
            }
        },

        _calculateCurrenPage: function (virtualRows, target, args) {
            var pageSize = this.model.pageSettings.pageSize;
            var currentPage, diff, proxy = this, trEle;
            if (args.scrollTop >= this._scrollValue) {
                currentPage = Math.ceil((args.scrollTop + this.model.scrollSettings.height) / this.getRowHeight() / pageSize);
                if (args.virtualScrollMode == "continuous" && args.reachedEnd) {
                    currentPage = this.virtualLoadedPages[this.virtualLoadedPages.length - 1] / pageSize + 2;
                }
            }
            else
                currentPage = Math.floor((args.scrollTop + this.model.scrollSettings.height) / this.getRowHeight() / pageSize);
            if ($.inArray((currentPage - 1) * pageSize, this.virtualLoadedPages) != -1) {
                var viewTr = this.getContentTable().find("tr").filter(function () { if (this.offsetHeight + this.offsetTop >= args.scrollTop && this.offsetHeight + this.offsetTop <= args.scrollTop + proxy.model.scrollSettings.height) return true; })
                diff = args.scrollTop >= this._scrollValue ? ":last" : ":first";
                trEle = viewTr.filter(diff).eq(0);
                currentPage = trEle.hasClass("e-virtualrow") ? currentPage : parseInt(trEle.attr("name"), 10) / pageSize + 1;
            }
            this._scrollValue = args.scrollTop;
            for (var index = 0; index < virtualRows.length; index++) {
                var val = virtualRows[index];
                if (val.offsetTop + val.offsetHeight >= args.scrollTop) {
                    var prevVirtualPage = this._calculatePrevPage(virtualRows, target, args);
                    this._prevPageNo = prevVirtualPage;
                    if ((currentPage != this.model.pageSettings.totalPages) && currentPage != prevVirtualPage + 1 && $(val).next().is("tr[name=" + (currentPage - 1) * pageSize + "]"))
                        currentPage -= 1;
                    if (currentPage == 0)
                        currentPage = 1;
                    return currentPage > this.model.pageSettings.totalPages ? this.model.pageSettings.totalPages : currentPage;
                }
            }
            return currentPage;
        },
        _calculatePrevPage: function (virtualRows, target, args) {
            for (var i = 0; i < virtualRows.length; i++) {
                var val = virtualRows[i];
                if (val.offsetTop + val.offsetHeight >= args.scrollTop) {
                    var trElement = $(val).prevAll('tr[name]')[0];
                    if (trElement != null) {
                        return Math.ceil(parseInt($(trElement).attr('name'), 10) / this.model.pageSettings.pageSize) + 1;
                    }
                }
            }
            return -1;
        },
        _refreshVirtualPagerInfo: function () {
            var model = {};
            model.pageSize = this.model.pageSettings.pageSize;
            model.currentPage = this._currentPage();
            model.totalRecordsCount = this.model.filterSettings.filteredColumns.length == 0 ? this._searchCount == null ? this._gridRecordsCount : this._searchCount : this._filteredRecordsCount;
            model.totalPages = Math.ceil(model.totalRecordsCount / model.pageSize);

            return model;
        },
        _showPagerInformation: function (model) {
            var from = (model.currentPage - 1) * model.pageSize;
            $(this.$pagerStatusBarDiv).find("div:first").html(String.format(this._getLocalizedLabels("PagerInfo"), model.currentPage, model.totalPages, model.totalRecordsCount), from, from + model.pageSize);
            $(this.$pagerStatusBarDiv).css('display', 'block');
        },
		_cellMerging: function (args) {
            args.colMerge = function (range) {
                if (this.cell.className.indexOf("e-colmerge") == -1) {
                    this.cell.className += " e-colmerge";
                    if (this.model.columns.length - this.cell.cellIndex < range)
                        range = this.model.columns.length - this.cell.cellIndex;
                    this.cell.colSpan = range;
                    for (var i = 1; i < range; i++) {
                        if (!ej.isNullOrUndefined(this.cell.parentElement.children[this.cell.cellIndex + i]))
                            this.cell.parentElement.children[this.cell.cellIndex + i].className += " e-hide";
                    }
                }
            };
            args.rowMerge = function (range) {
                if (this.cell.className.indexOf("e-rowmerge") == -1) {
                    this.cell.className += " e-rowmerge";
                    if (this.model.currentViewData.length - this.cell.parentElement.rowIndex < range)
                        range = this.model.currentViewData.length - this.cell.parentElement.rowIndex;
                    this.cell.rowSpan = range;
                    for (var i = 0; i < range - 1; i++) {
                        var ele = this.cell.parentNode.parentNode;
                        if (!ej.isNullOrUndefined(ele.children[this.cell.parentElement.rowIndex + i].nextSibling)) {
                            if (!($(".e-grid").children().is('.e-dialog')) || ($(".e-grid").find('.e-dialog').attr("style").indexOf("display: none")) != -1)
                                ele.children[this.cell.parentElement.rowIndex + i].nextSibling.children[this.cell.cellIndex].className += " e-merged e-hide";
                        }
                        else
                            break;
                    }
                }
            };
            args.merge = function (col, row) {
                if (col > 1 && row > 1) {
                    if (this.cell.className.indexOf("e-colmerge") == -1) {
                        this.cell.className += " e-colmerge";
						if (this.model.currentViewData.length - this.cell.parentElement.rowIndex < row)
							row = this.model.currentViewData.length - this.cell.parentElement.rowIndex;
                        if (!($(".e-grid").children().is('.e-dialog')) || ($(".e-grid").find('.e-dialog').attr("style").indexOf("display: none")) != -1) {
                            for (var i = 0; i < row ; i++) {
                                var ele = this.cell.parentNode.parentNode;
                                if (!ej.isNullOrUndefined(ele.children[this.cell.parentElement.rowIndex + i])) {
                                    var selectCell = ele.children[this.cell.parentElement.rowIndex + i].children[this.cell.cellIndex];
									if (this.model.columns.length - selectCell.cellIndex < col)
										col = this.model.columns.length - selectCell.cellIndex;
                                    selectCell.colSpan = col;
                                    for (var j = 1; j < col; j++) {
                                        if (!ej.isNullOrUndefined(selectCell.parentElement.children[this.cell.cellIndex + j]))
                                            selectCell.parentElement.children[this.cell.cellIndex + j].className += " e-hide";
                                    }
                                }
                                else
                                    break;
                            }
                        }
                        else {
                            this.cell.colSpan = col;
                            for (var j = 1; j < col; j++) {
                                if (!ej.isNullOrUndefined(this.cell.nextSibling))
                                    parentElement.children[this.cell.cellIndex + j].className += " e-hide";
                            }
                        }
                        args.rowMerge(row);
                    }
                }
                else {
                    if (col > 1)
                        args.colMerge(col);
                    if (row > 1)
                        args.rowMerge(row);
                }
            };
        },
        _replacingContent: function () {
            var temp = document.createElement('div');
            var currentIndex = this.getCurrentIndex();
            var contentTable = this.getContentTable()[0];
            var colGroup = $(contentTable).find("colgroup").first();
            var rowHeight = this.getRowHeight();
            colGroup.replaceWith(this._getMetaColGroup());
            this.model.detailsTemplate != null && colGroup.prepend(this._getIndentCol());
            var tbody = contentTable.tBodies[0];
            var cloneEle = $(tbody).clone();
            var elementTbody = $("<tbody></tbody>").append($.render[this._id + "_JSONTemplate"](this.model.currentViewData));
            var proxy = this;
            this.virtualLoadedPages.push(currentIndex >= 0 ? currentIndex : 0);
            var orderedVirtualPages = ej.dataUtil.mergeSort(ej.distinct(this.virtualLoadedPages));
            var tempTbody = $("<tbody></tbody>");
            $(elementTbody).children('tr').attr('name', currentIndex);
            var minValue = ej.dataUtil.min(orderedVirtualPages);
            var maxValue = ej.dataUtil.max(orderedVirtualPages);
            $(cloneEle).find('tr.e-virtualrow').remove();
            $(cloneEle).append($(elementTbody).children('tr'));
            $.each(orderedVirtualPages, function (index, val) {
                $(tempTbody).append($(cloneEle).find('tr[name=' + val + ']'));
                if (val != 0) {
                    var prevValue = val == minValue ? minValue : orderedVirtualPages[index - 1];
                    var virtualTRMiddle = document.createElement("tr");
                    var middleRows = val - prevValue - proxy.model.pageSettings.pageSize;
                    if (middleRows > 0)
                        $(virtualTRMiddle).addClass("e-virtualrow").css("height", rowHeight * middleRows).insertBefore($(tempTbody).children('tr[name=' + val + ']:first'));
                }
                if (val == maxValue) {
                    var virtualTRBottom = document.createElement("tr");
                    var bottomRows = proxy._gridRecordsCount - maxValue - proxy.model.pageSettings.pageSize;
                    if (bottomRows > 0)
                        $(virtualTRBottom).addClass("e-virtualrow").css("height", rowHeight * bottomRows).appendTo(tempTbody);
                }
            });
            if (minValue > 0) {
                var virtualTRTop = document.createElement("tr");
                $(virtualTRTop).addClass("e-virtualrow").css("height", rowHeight * minValue).prependTo(tempTbody);
            }
            var focusTR = $(tbody).html($(tempTbody).html()).find("tr[name=" + currentIndex + "]")[0];
            if ((focusTR && focusTR.previousSibling && ($(focusTR.previousSibling).hasClass("e-virtualrow") || focusTR.previousSibling.offsetTop > (currentIndex * this.getContent().height()))
            && (this._gridRecordsCount - currentIndex > this.model.pageSettings.pageSize || focusTR.offsetParent.offsetHeight - focusTR.offsetTop < this.getContent().height())) || this._lastRow) {
                if (this._lastRow) this._lastRow = false;
                this._isVirtualRecordsLoaded = true;
                this.getContent().children("div").first().scrollTop(this.getContent().find(".content").scrollTop() - (this.getContent().find(".content").scrollTop() - focusTR.offsetTop));
            }
            $(temp).append($("<table></table>").append(tempTbody));
            $(contentTable).get(0).replaceChild(this.model.rowTemplate != null ? temp.firstChild.lastChild : temp.firstChild.firstChild, $(contentTable).get(0).lastChild);
            this._currentJsonData = this.model.currentViewData;
            this._gridRows = $(contentTable).get(0).rows;
            var lastVirtualRow = $(contentTable).find(".e-virtualrow").last();
            var lastVirtualRowHeight = this.model.scrollSettings.virtualScrollMode == "normal" ? (lastVirtualRow.height() - ($(contentTable).height() - (this._gridRecordsCount * rowHeight))) : 1;
            lastVirtualRow.css("height",lastVirtualRowHeight);           
            this._eventBindings();
        },
        _refreshPagerTotalRecordsCount: function () {
            if (this.model.filterSettings.filteredColumns.length)
                this.getPager().ejPager({ totalRecordsCount: this._searchCount == null ? this._filteredRecordsCount : this._searchCount, currentPage: this._currentPage() });
            else
                this.getPager().ejPager({ totalRecordsCount: this._searchCount == null ? this._gridRecordsCount : this._searchCount, currentPage: this._currentPage() });
        },
        _maxZindex: function () {
            var maxZ = 1;
            maxZ = Math.max.apply(null, $.map($('body *'), function (e, n) {
                if ($(e).css('position') == 'absolute')
                    return parseInt($(e).css('z-index')) || 1;
            }));
            if (maxZ == undefined || maxZ == null)
                maxZ = 1;
            return maxZ;
        },
        _keyPressed: function (action, target, e) {
            var $target = $(target);
            if (!this.model.allowKeyboardNavigation || (target.tagName == 'INPUT' && e.code != 40 && e.code != 38 && e.code != 13 && e.code != 27 && e.code != 9) || String.fromCharCode(e.code).toLowerCase() == this.element[0].accessKey.toLowerCase())
                return true;
			if(this.model.allowFiltering && ($target.hasClass('e-filtertext') && e.code==13))
				return true;
            if ((this.model.editSettings.editMode == "dialog" || this.model.editSettings.editMode == "dialogtemplate") && $(target).closest("#" + this._id + "EditForm").length)
                return true;
            else if ($(target).parent().siblings("#" + this._id + "EditForm").length)
                return true;
            if (e.code == 13 && $target.parent().hasClass("e-unboundcelldiv"))
                return true;
            if (e.code == 13 && target.tagName == 'INPUT' && $target.parent().is("#" + this._id + "_search"))
                action = "searchRequest";
            if (this.getPager() != null)
                var pager = this.getPager().ejPager("model"), pageIndex = pager.currentPage;
            var returnValue = false, curEl, $target = $(target);

            switch (action) {
                case "insertRecord":
                    if (ej.gridFeatures.edit)
                        this._toolbarOperation(this._id + "_add");
                    break;
                case "searchRequest":
                    this.search($target.val());
                    break;
                case "saveRequest":
                    if (ej.gridFeatures.edit) {
                           $target.blur();
                        if (this.model.editSettings.editMode == "batch")
                            this._moveCurrentCell("down");
                        else
                            this._toolbarOperation(this._id + "_update");
                    }
                    break;
                case "cancelRequest":
                    if (ej.gridFeatures.edit)
                        this._toolbarOperation(this._id + "_cancel");
                    break;
                case "deleteRecord":
                    if (ej.gridFeatures.edit)
                        this._toolbarOperation(this._id + "_delete");
                    break;
                case "editRecord":
                    if (ej.gridFeatures.edit)
                        this._toolbarOperation(this._id + "_edit");
                    break;
                case "totalGroupCollapse":
                    if (ej.gridFeatures.group)
                        this.collapseAll();
                    break;
                case "totalGroupExpand":
                    if (ej.gridFeatures.group)
                        this.expandAll();
                    break;
                case "selectedGroupExpand":
                    if (ej.gridFeatures.group) {
                        this._$currentTr = $(this.getRows()).eq(this._selectedRow());
                        curEl = this._$currentTr.parents("tr").first().prev().find(".e-recordpluscollapse");
                        this.expandCollapse(curEl);
                    }
                    break;
                case "selectedGroupCollapse":
                    if (ej.gridFeatures.group) {
                        this._$currentTr = $(this.getRows()).eq(this._selectedRow());
                        curEl = this._$currentTr.parents("tr").first().prev().find(".e-recordplusexpand");
                        this.expandCollapse(curEl);
                    }
                    break;
                case "firstRowSelection":
                    if (ej.gridFeatures.selection)
                        this.selectRows(0);
                    break;
                case "lastRowSelection":
                    if (ej.gridFeatures.selection)
                        this.selectRows($(this.getRows()).length - 1);
                    break;
                case "upArrow":
                    if (ej.gridFeatures.selection) {
                        if ((target["type"] == "text" || target["type"] == "checkbox") && this.model.isEdit && this.model.editSettings.editMode != "batch")
                            return true;
                        if (this._selectedRow() != 0) {
                            this.selectRows(this._selectedRow() - 1);
                            if (this.model.editSettings.editMode == "batch")
                                this._moveCurrentCell("up");
                        }
                        if (this._previousRowCellIndex && this._previousRowCellIndex[0][0] != 0) {
                            this.selectCells([[this._previousRowCellIndex[0][0] - 1, this._previousRowCellIndex[0][1]]]);
                            if (this.model.editSettings.editMode == "batch")
                                this._moveCurrentCell("down");
                        }
                    }
                    break;
                case "downArrow":
                    if (ej.gridFeatures.selection) {
                        if ((target["type"] == "text" || target["type"] == "checkbox") && this.model.isEdit && this.model.editSettings.editMode != "batch")
                            return true;
                        var lastRow = $(this.getRows()).length - 1;
                        if (this.model.scrollSettings.frozenColumns > 0 && !ej.isNullOrUndefined(this.getRows()[0]))
                            lastRow = this.getRows()[0].length - 1;
                        if (this._selectedRow() != lastRow) {
                            this.selectRows(this._selectedRow() + 1);
                            if (this.model.editSettings.editMode == "batch")
                                this._moveCurrentCell("down");
                        }
                        if (this._previousRowCellIndex && this._previousRowCellIndex[0][0] != lastRow && this._allowcellSelection) {
                            this.selectCells([[this._previousRowCellIndex[0][0] + 1, this._previousRowCellIndex[0][1]]]);
                            if (this.model.editSettings.editMode == "batch")
                                this._moveCurrentCell("down");
                        }
                    }
                    break;
                case "rightArrow":
                    if (ej.gridFeatures.selection && this._allowcellSelection) {
                        if ((target["type"] == "text" || target["type"] == "checkbox") && this.model.isEdit && this.model.editSettings.editMode != "batch")
                            return true;
                        var lastRow = $(this.getRows()).length - 1;
                        if (this._previousRowCellIndex && this._previousRowCellIndex[0][1] == this.model.columns.length - 1 && this._previousRowCellIndex[0][0] != lastRow) {
                            this.selectCells([[this._previousRowCellIndex[0][0] + 1, [0]]]);
                        } else if (this._previousRowCellIndex && this._previousRowCellIndex[0][1] != this.model.columns.length - 1)
                            this.selectCells([[this._previousRowCellIndex[0][0], [parseInt(this._previousRowCellIndex[0][1]) + 1]]]);

                    }
                    break;
                case "leftArrow":
                    if (ej.gridFeatures.selection && this._allowcellSelection) {
                        if ((target["type"] == "text" || target["type"] == "checkbox") && this.model.isEdit && this.model.editSettings.editMode != "batch")
                            return true;
                        if (this._previousRowCellIndex && this._previousRowCellIndex[0][1] == 0 && this._previousRowCellIndex[0][0] != 0)
                            this.selectCells([[this._previousRowCellIndex[0][0] - 1, [this.model.columns.length - 1]]]);
                        else if (this._previousRowCellIndex && this._previousRowCellIndex[0][1] != 0)
                            this.selectCells([[this._previousRowCellIndex[0][0], [parseInt(this._previousRowCellIndex[0][1]) - 1]]]);

                    }
                    break;
                case "firstCellSelection":
                    if (ej.gridFeatures.selection && this._allowcellSelection) {
                        if ((target["type"] == "text" || target["type"] == "checkbox") && this.model.isEdit && this.model.editSettings.editMode != "batch")
                            return true;
                        var lastRow = $(this.getRows()).length - 1;
                        lastRow > -1 && this.selectCells([[0, [0]]]);
                    }
                    break;
                case "lastCellSelection":
                    if (ej.gridFeatures.selection && this._allowcellSelection) {
                        if ((target["type"] == "text" || target["type"] == "checkbox") && this.model.isEdit && this.model.editSettings.editMode != "batch")
                            return true;
                        var lastRow = $(this.getRows()).length - 1;
                        lastRow > -1 && this.selectCells([[lastRow, [this.model.columns.length - 1]]]);
                    }
                    break;
                case "nextPage":
                    if (this.getPager() != null)
                        pageIndex = pageIndex + 1;
                    break;
                case "previousPage":
                    if (this.getPager() != null)
                        pageIndex = pageIndex - 1;
                    break;
                case "lastPage":
                    if (this.getPager() != null)
                        pageIndex = pager.totalPages;
                    break;
                case "firstPage":
                    if (this.getPager() != null)
                        pageIndex = 1;
                    break;
                case "nextPager":
                    if (this.getPager() != null)
                        pageIndex = Math.ceil(pager.currentPage / pager.pageCount) * pager.pageCount + 1;
                    break;
                case "previousPager":
                    if (this.getPager() != null)
                        pageIndex = (Math.floor(pager.currentPage / pager.pageCount) - 1) * pager.pageCount + 1;
                    break;
                case "moveCellLeft":
                    if (this.model.editSettings.editMode == "batch")
                        returnValue = this._moveCurrentCell("left");
                    else
                        returnValue = true;
                    break;
                case "moveCellRight":
                    if (this.model.editSettings.editMode == "batch" && $target)
                        returnValue = this._moveCurrentCell("right");
                    else
                        returnValue = true;
                    break;
                default:
                    returnValue = true;
            }
            if (this. getPager() != null && pager.currentPage !== pageIndex)
                this.getPager().ejPager("goToPage", pageIndex);
            return returnValue;
        },
        _findColumnsWidth: function () {
            var j = this.getHeaderTable().find(".e-headercell").not(".e-stackedHeaderCell"), index = 0;
            if (j.eq(0).hasClass("e-detailheadercell"))
                index = 1;
            for (var i = 0; i < this.model.columns.length; i++) 
                this._columnsWidthCollection[i] = j.eq(i + index).outerWidth();
        },
        _calculateWidth: function () {
            var j = this.getHeaderTable().find("colgroup").find("col"), width = 0;
            for (var i = 0; i < j.length; i++)
                width += j.eq(i).width();
            return width;

        },
        _initIndicators: function () {
            var indicatorId = this._id + "_ColumnDropIndicator";
            if ($("#" + indicatorId).length)
                $("#" + indicatorId).remove();
            this._Indicator = document.createElement("DIV");
            $(this._Indicator).attr('id', indicatorId).addClass("e-columndropindicator").addClass("e-dropAcceptor").appendTo(document.body);
            $(this._Indicator).css({ "display": "none" });

        },
        /**
         * Re-order the column in grid
         * @alias ejGrid#reorderColumns
         * @return jQuery
         * @param {string} fromFieldName Pass the from field name of the column needs to be changed
         * @param {string} toFieldName Pass the to field name of the column needs to be changed
         * @example 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // Reorders the column based on the given index
         * gridObj.reorderColumns("OrderID", "CustomerID"); 
         * &lt;/script&gt;
         * @example 
         * &lt;script&gt;
         * // Reorders the column based on the given index
         * $("#Grid").ejGrid("reorderColumns", "OrderID", "CustomerID");
         * &lt;/script&gt;
         */
        reorderColumns: function (fromfname, tofname) {
            var fromindex = this.model.columns.indexOf(this.getColumnByField(fromfname));
            var toindex = this.model.columns.indexOf(this.getColumnByField(tofname));
            this.set_dropColumn(fromindex, toindex);
            if (this.model.showStackedHeader)
                this._refreshStackedHeader();
        },
        /**
		 * Add or remove columns in grid column collections
         * @alias ejGrid#columns
		 * @return jQuery
		 * @param {array/string} columndetails Pass array of columns or string of field name to add/remove the column in grid 
		 * @param {string} [action] Pass add/remove action to be performed. By default "add" action will perform
		 * @example 
		 * &lt;script&gt;
		 * // Create grid object.
		 * var gridObj = $("#Grid").data("ejGrid");
         * // remove grid column
		 * gridObj.columns("OrderID", "remove");
         * // Add new column into grid or modified already existing column in the grid.
		 * gridObj.columns("CustomerID", "add"); 
		 * &lt;/script&gt;
		 * @example 
		 * &lt;script&gt;
		 * // remove grid column
		 * $("#Grid").ejGrid("columns","OrderID", "remove");   
		 * // Add new column into grid or modified already existing column in the grid.			
		 * $("#Grid").ejGrid("columns","CustomerID", "add");    			
		 * &lt;/script&gt;
         */
        columns: function (details, action) {
            if (ej.isNullOrUndefined(details)) return;
            var isString = false;
            if (typeof details === "string") {
                details = [details];
                isString = true;
            }
            else if (details instanceof Array && details.length && typeof details[0] === "string")
                isString = true;
            for (i = 0; i < details.length; i++) {
                var index = $.inArray(this.getColumnByField(isString ? details[i] : details[i]["field"]), this.model.columns);
                if (action == "add" || ej.isNullOrUndefined(action)) {
                    if (index == -1)
                        this.model.columns.push(isString ? { field: details[i] } : details[i]);
                    else
                        this.model.columns[index] = isString ? { field: details[i] } : details[i];
                }
                else {
                    if (index != -1)
                        this.model.columns.splice(index, 1);
                }
            }
            var $header = this.element.find(".e-gridheader");
            this.element[0].replaceChild(this._renderGridHeader()[0], $header[0]);         
            this._headerCellgDragDrop();
            this.model.allowReordering && this._headerCellreorderDragDrop();
            this.model.showColumnChooser && this._renderColumnChooserData(true);
            this.refreshContent(true);
        },
        _enableRowHover: function () {
            if (this.model.enableRowHover)
                this._on(this.element, "mouseenter mouseleave", ".e-gridcontent tr td", this._rowHover);
            else
                this._off(this.element, "mouseenter mouseleave", ".e-gridcontent tr td");
        },
        _rowHover: function (e) {
            if (!this.model.enableRowHover)
                return;
            var $target = $(e.target);
            var $gridRows = $(this.getRows());
            if (($target.hasClass("e-rowcell") && $target.closest("#" + this._id + "EditForm").length) || !$target.hasClass("e-rowcell"))
                return;
            if (e.type == "mouseenter" && !this._dragActive) {
                if (this.model.scrollSettings.frozenColumns > 0 && !ej.isNullOrUndefined($gridRows[0]) && !ej.isNullOrUndefined($gridRows[1]))
                    $gridRows = $($gridRows[0]).add($gridRows[1]);
                $gridRows.removeClass("e-hover");
                var index = this.getIndexByRow($target.parent());
                index != -1 && this.getRowByIndex(index).addClass("e-hover");
            } else {
                if (this.model.scrollSettings.frozenColumns > 0 && !ej.isNullOrUndefined($gridRows[0]) && !ej.isNullOrUndefined($gridRows[1]))
                    $gridRows = $($gridRows[0]).add($gridRows[1]);
                $gridRows.removeClass("e-hover");
            }
            return false;
        },
        _rightClickHandler: function (e) {
            e.preventDefault();
            if (e.which == 3) {
                var args = {};
                $target = $(e.target);
                $gridRow = $(this.getRows());
                if (this.getContentTable().has($target).length) {
                    var index = $gridRow.index($target.parent());
                    if (index == -1)
                        return;
                    args = { rowIndex: index, row: this.getRowByIndex(index), data: this._currentJsonData[index], cellIndex: $target.index(), cellValue: $target.html(), cell: $target };
                }
                else if (this.getHeaderTable().has($target).length) {
                    var index = 0
                    $th = this.getHeaderTable().find('th').not('.e-detailheadercell,.e-grouptopleftcell,.e-filterbarcell');
                    if ($target.is('.e-headercelldiv'))
                        index = $th.index($target.closest('.e-headercell'));
                    else
                        index = $th.index($target);
                    if (index == -1)
                        return;
                    args = { headerIndex: index, headerText: this.getColumnFieldNames()[index], headerCell: $th.eq(index), column: this.getColumnByIndex(index) }
                }
                else if ($target.is('.e-pager') || (this. getPager() != null && this.getPager().has($target).length)) {
                    args = { pager: this.model.pageSettings }
                }
                this._trigger("rightClick", args);
            }
        },
        _touchGrid: function (e) {
            var curPage = this._currentPage();
            var lastPage = this._gridRecordsCount / this.model.pageSettings.pageSize;
            var totPage = lastPage == 0 ? lastPage : (parseInt(lastPage, 10) + 1);
            switch (e.type) {
                case "swipeleft":
                    if (this.model.allowPaging && curPage != totPage && !this.model.isEdit)
                        this.element.ejGrid("gotoPage", curPage + 1);
                    break;
                case "swiperight":
                    if (this.model.allowPaging && curPage > 1 && !this.model.isEdit)
                        this.element.ejGrid("gotoPage", curPage - 1);
                    break;
            }
        },
        _recorddblClickHandler: function () {
            var args = {};
            args = { rowIndex: this._selectedRow(), row: this.getRowByIndex(this._selectedRow()), data: this._currentJsonData[this._selectedRow()], cell: $target };
            this._trigger("recordDoubleClick", args);
        },
        _recordClick: function (e) {
            var args = {};
            $target = $(e.target);
            if ($target.closest(".e-grid").attr("id") !== this._id) return;
            if (!$target.is('.e-rowcell') && !$target.closest("td").is(".e-rowcell"))
                return;
            var index = this.getIndexByRow($target.closest('tr'));
            args = { rowIndex: index, row: this.getRowByIndex(index), data: this._currentJsonData[index], cell: $target.closest("td") };
            this._trigger("recordClick", args);
        },
        _headerMouseDown: function (e) {
            if (this.model.allowResizing)
                this._resizer._mouseDown(e);
            if (($(e.target).hasClass("e-headercelldiv") && !$(e.target).parent().hasClass("e-grouptopleftcell")) || $(e.target).hasClass("e-headercell")) {
                var $headercell = $(e.target).hasClass("e-headercelldiv") ? $(e.target).parent() : $(e.target);
                this.model.enableHeaderHover && $headercell.removeClass("e-hover e-headercell-hover").addClass("e-headercellactive e-active");
            }
        },
        _headerHover: function (e) {
            var $target = $(e.target);
            if (e.type == "mouseover" || e.type == "mousemove" || e.type == "touchmove" || e.type == "MSPointerMove") {
                if (this.model.allowResizing || this.model.allowResizeToFit)
                    this._resizer._mouseHover(e);

                if (this.model.enableHeaderHover && !this._dragActive && (($target.hasClass("e-headercelldiv") && !$target.parent().hasClass("e-grouptopleftcell")) || $target.hasClass("e-headercell"))) {
                    if ($target.hasClass("e-headercelldiv"))
                        $target = $target.parent();
                    this.getHeaderTable().find(".e-columnheader").find(".e-headercell-hover").removeClass("e-headercell-hover").removeClass("e-hover");
                    $target.addClass("e-headercell-hover e-hover");
                }

            } else
                this.model.enableHeaderHover && this.getHeaderTable().find(".e-columnheader").find(".e-headercell-hover").removeClass("e-headercell-hover").removeClass("e-hover");
        },
        _colgroupRefresh: function () {
            var gridheaderCol = $(this.getHeaderTable()).find('colgroup')[0];
            var gridcontentCol = $(this.getContentTable()).find('colgroup')[0];
            var headerColClone = $(gridheaderCol).clone();
            var contentColClone = $(gridcontentCol).clone();
            $(gridcontentCol).remove();
            $(gridheaderCol).remove();
            $(headerColClone).prependTo(this.getHeaderTable());
            $(contentColClone).prependTo(this.getContentTable());
        },
        _detailColsRefresh: function () {
            this._$headerCols = this.getHeaderTable().children("colgroup").find("col");
            this._$contentCols = this.getContentTable().children("colgroup").find("col");
            var colCount = this.model.columns.length;
            if (this._$headerCols.length > colCount) this._$headerCols.splice(0, (this._$headerCols.length - colCount));
            if (this._$contentCols.length > colCount) this._$contentCols.splice(0, (this._$contentCols.length - colCount));
        },
        _headerdblClickHandler: function (e) {
            if (this.model.allowResizeToFit)
                this._resizer._columnResizeToFit(e);
        },        
       
        _mouseUp: function (e) {
            if (this.model.allowResizing)
                this._resizer._mouseUp(e);
        },

        _mouseMove: function (e) {
            if (this.model.allowResizing)
                this._resizer._mouseMove(e);
        },
        _setModel: function (options) {
            for (var prop in options) {
                switch (prop) {
                    case "enableResponsiveRow":
                       if (options[prop]) {
                            this.element.addClass("e-responsive");
                            if (this.model.minWidth) {
                                this._removeMedia();
                            }
                            if (this.model.allowFiltering) {
                                this.element.find('.e-filterDialoge').remove();
                                this._renderFilterDialogs();
                                this._renderResponsiveFilter();
                                this.element.find('.e-gridtoolbar').remove();
                            }
                        } else {
                            this.element.removeClass("e-responsive");
                            if (this.model.minWidth)
                                this._addMedia();
                            if (this.model.allowFiltering) {
                                $('body').find('.e-filterDialoge').remove();
                                this._renderFilterDialogs();
                            }
                       }
                       if (this.model.allowFiltering || this.model.allowSorting) {
                           var index = this.model.toolbarSettings.toolbarItems.indexOf('responsiveFilter');
                           index != -1 && this.model.toolbarSettings.toolbarItems.splice(index, 1);
                           var sortIndex = this.model.toolbarSettings.toolbarItems.indexOf('responsiveSorting');
                           sortIndex != -1 && this.model.toolbarSettings.toolbarItems.splice(sortIndex, 1);
                           this.element.find('.e-gridtoolbar').remove();
                           this._renderToolBar().insertBefore(this.element.find(".e-gridheader").first());
                       }
                        break;
                    case "showColumnChooser":
                        if (options[prop])
                            this._renderColumnChooser();
                        else {
                            this.element.find(".e-ccButton").remove()
                            $("#" + this._id + 'ccDiv_wrapper').remove();
                        }
                        break;
                    case "showDeleteConfirmDialog":
                        this.model.editSettings.showDeleteConfirmDialog = options[prop];
                        if (options[prop])
                            this._renderConfirmDialog();
                        else
                            this.element.find("#" + this._id + 'ConfirmDialog_wrapper').remove()
                        break;
                    case "showConfirmDialog":
                        this.model.editSettings.showConfirmDialog = options[prop];
                        if (options[prop])
                            this._renderConfirmDialog();
                        else
                            this.element.find("#" + this._id + 'ConfirmDialog_wrapper').remove()
                        break;
                    case "pageSettings":
                        var pageModel = this.getPager().ejPager("model");
                        if (ej.isNullOrUndefined(options[prop]["currentPage"]) || pageModel.currentPage != this._currentPage()) {
                            for (var pageProp in options[prop]) {
                                if (pageProp != "currentPage" && options[prop][pageProp] === pageModel[pageProp])
                                    delete options[prop][pageProp];
                            }
                            if ($.isEmptyObject(options[prop]))
                                break;
							options[prop]["currentPage"] = this._currentPage();
                            this.getPager().ejPager("option", options[prop]);
							this._currentPage(this._currentPage()>pageModel.totalPages?pageModel.totalPages:this._currentPage());
                            this.refreshContent();
                        }
                        break;
                    case "allowPaging":
                        this.model.allowPaging = options[prop];
                        if (options[prop] && this.element.children(".e-pager").length == 0) {
                            this.element.append(this._renderGridPager());
                            this.refreshContent();
                            this.getPager().ejPager("refreshPager");
                        } else {
                            this.getPager().remove();
                            this.setGridPager(null);
                            this.refreshContent();
                            if (this.model.filterSettings.filterType == "filterbar" && this.model.allowFiltering)
                                this._createPagerStatusBar();
                        }
                        break;
                    case "allowGrouping":
                        if (options[prop] && this.element.children(".e-groupdroparea").length == 0) {
                            this.model.allowGrouping = options[prop];
                            this.addGroupingTemplate();
                            this.element.prepend(this._renderGroupDropArea());
                            this._enableGroupingEvents();
                            this._headerCellgDragDrop();
                        } else
                            this.element.children(".e-groupdroparea").remove();
                        break;
                    case "groupSettings":
                        $.extend(this.model.groupSettings, options[prop]);
                        this.refreshTemplate();
						if (!ej.isNullOrUndefined(options[prop]["groupedColumns"])) {
                            var args = {};
                            args.columnName = this.model.groupSettings.groupedColumns[this.model.groupSettings.groupedColumns.length - 1];
                            args.requestType = ej.Grid.Actions.Grouping;
                            $(".e-grid").find(".e-groupdroparea").empty();
                            for (var i = 0; i < this.model.groupSettings.groupedColumns.length - 1; i++)
                                this._addColumnToGroupDrop(this.model.groupSettings.groupedColumns[i]);
                            this._processBindings(args);
                        }
                        if (this.model.groupSettings.showToggleButton) {
                            var $table = this._renderGridHeader().find("table");
                            this.element.children(".e-gridheader").find("table").replaceWith($table);
                            this.setGridHeaderTable($table);
                            this.setWidthToColumns();
                        }
                        if (!this.model.groupSettings.enableDropAreaAnimation)
                            this.expandGroupDropArea();
                        else
                            this.collapseGroupDropArea();
                        break;
                    case "cssClass":
                        this.element.removeClass(this.model.cssClass).addClass(options[prop]);
                        break;
                    case "allowFiltering":
                    case "filterSettings":
                        if (prop == "filterSettings")
                            $.extend(this.model.filterSettings, options[prop]);
                        else
                            this.model.allowFiltering = options[prop];
                        this._$fDlgIsOpen && (this._isExcelFilter ? this._excelFilter.closeXFDialog() : this._closeFilterDlg())
                        if (!this.model.allowFiltering) {
                            if (this.model.filterSettings.filterType == ej.Grid.FilterType.FilterBar)
                                this.getHeaderTable().find(".e-filterbar").remove();
                            else if (this.model.filterSettings.filterType == ej.Grid.FilterType.Menu || this.model.filterSettings.filterType == ej.Grid.FilterType.Excel)
                                this.getHeaderTable().find(".e-columnheader").find(".e-filtericon").remove()
                                    .end().find(".e-headercellfilter").removeClass("e-headercellfilter");
                            this.model.filterSettings.filteredColumns = [];
                            this.refreshContent();
                        } else {
                            if (this.model.filterSettings.filterType == ej.Grid.FilterType.FilterBar) {
                                this.getHeaderTable().find(".e-filterbar").remove();
                                this.getHeaderTable().find(".e-columnheader").find(".e-filtericon").remove()
                                    .end().find(".e-headercellfilter").removeClass("e-headercellfilter");
                                this._renderFiltering();
                                if (this.model.filterSettings.showFilterBarStatus && !this.model.allowPaging)
                                    this._createPagerStatusBar();
                                else if (this.model.filterSettings.showFilterBarStatus && this.model.allowPaging)
                                    this.getPager().ejPager({ enableExternalMessage: true });
                                var $filterbar = this.getHeaderTable().find(".e-filterbar");
                                for (var i = 0; i < this.model.groupSettings.groupedColumns.length; i++)
                                    $filterbar.prepend(this._getEmptyFilterBarCell());
                            } else if (this.model.filterSettings.filterType == ej.Grid.FilterType.Menu || this.model.filterSettings.filterType == ej.Grid.FilterType.Excel) {
                                this.getHeaderTable().find(".e-columnheader").find(".e-filtericon").remove()
                                    .end().find(".e-headercellfilter").removeClass("e-headercellfilter");
                                this.getHeaderTable().find(".e-filterbar").remove();
                                this.getHeaderTable().find(".e-columnheader").find(".e-headercell").addClass("e-headercellfilter").append(ej.buildTag('div.e-filtericon e-icon e-filterset'));
                                if (this.model.filterSettings.filterType == ej.Grid.FilterType.Excel) {
                                    this._isExcelFilter = true;
                                    this._renderExcelFilter();                                                                        
                                } else if (this._isExcelFilter) {
                                    this._isExcelFilter = false;
                                    this._excelFilter.resetExcelFilter();
                                    this._excelFilter = null;
                                }
                                this._renderFilterDialogs();
                                this.model.filterSettings.filteredColumns = [];
                                this.refreshContent();
                            }
                            this._enableFilterEvents();
                        }
                        break;
                    case "enableRowHover":
                        this.model.enableRowHover = options[prop];
                        this._enableRowHover();
                        break;
                    case "allowScrolling":
                    case "scrollSettings":
                        var $content = this.getContent();
                        if (!ej.util.isNullOrUndefined(options["scrollSettings"]))
                            $.extend(this.model.scrollSettings, options["scrollSettings"]);
                        if (options["scrollSettings"]["frozenColumns"] !== undefined || options["scrollSettings"]["frozenRows"] !== undefined || 
                            options["scrollSettings"]["allowVirtualScrolling"] !== undefined || options["scrollSettings"]["virtualScrollMode"] !== undefined) {
                            var model = this.model;
                            model.query = this.commonQuery.clone();
                            if(options["scrollSettings"]["virtualScrollMode"] != undefined)
                                model.pageSettings.currentPage = 1;
                            this.element.ejGrid("destroy").ejGrid(model);
                        }
                        else {
                            if (!ej.util.isNullOrUndefined(options["allowScrolling"]))
                                this.model.allowScrolling = options["allowScrolling"];
                            !ej.util.isNullOrUndefined($content.data("ejScroller")) && $content.ejScroller("destroy");
                            if (this.model.allowScrolling) {
                                this.getHeaderTable().parent().addClass("e-headercontent");
                                this._renderScroller();
                            } else {
                                this.element.children(".e-gridheader").removeClass("e-scrollcss");
                                this.element.get(0).style.width.length == 0 && this.element.css("width", "auto");
                            }
                        }
                        break;
                    case "locale":
                        this.model.locale = options[prop];
                        var model = this.model;
                        model.query = this.commonQuery.clone();
                        this.element.ejGrid("destroy").ejGrid(model);
                        break;
                    case "dataSource":
                        this.resetModelCollections();
                        this._refreshDataSource(this._dataSource());
                        if (this._gridRecordsCount && this.model.allowFiltering) {
                            this._initColumns(this.model.currentViewData[0] != undefined ? this.model.currentViewData[0] : this.model.currentViewData.value);
                            this._renderFilterDialogs();
                        }
                        break;
					case "selectedRowIndex":
                        if (this._selectedRow() != -1 && $.inArray(this._selectedRow(), this.selectedRowsIndexes) == -1)
                            this.selectRows(this._selectedRow());
                        else if (this._selectedRow() == -1) {
                            this.clearSelection();
                            this.selectedRowsIndexes = [];
                        }
                        break;                                                                     
                    case "editType":
                        if (this._selectedRow() != -1 && $.inArray(this._selectedRow(), this.selectedRowsIndexes) == -1)
                            this.selectRows(this._selectedRow());
                        break;
                    case "editSettings":
                        $.extend(this.model.editSettings, options[prop]);
                        this._processEditing();
                        this.refreshBatchEditMode();
                        this._tdsOffsetWidth = [];
                        $("#" + this._id + "_dialogEdit_wrapper,#" + this._id + "_dialogEdit").remove();
                        $("#" + this._id + "_externalEdit").remove();
                        if (this.model.editSettings.allowEditing || this.model.editSettings.allowAdding) {
                            if (this.model.editSettings.editMode == "dialog" || this.model.editSettings.editMode == "dialogtemplate")
                                this.element.append(this._renderDialog());
                            else if (this.model.editSettings.editMode == "externalform" || this.model.editSettings.editMode == "externalformtemplate")
                                this.element.append(this._renderExternalForm());
                        }
                        this._enableEditingEvents();
                        break;
                    case "showSummary":
                    case "summaryRows":
                        if (prop == "showSummary" && !options[prop])
                            this.element.children(".e-gridfooter").remove();
                        else {
                            var $content = this.element.find(".e-gridcontent").first();
                            this._renderGridFooter().insertAfter($content);
                        }
                        break;
                    case "enableAltRow":
                        this.model.enableAltRow = options[prop];
                        this.addInitTemplate();
                        this.refreshContent();
                        break;
                    case "toolbarSettings":
                        $.extend(this.model.toolbarSettings, options[prop]);
                        this.element.children(".e-gridtoolbar").remove();
                        if (this.model.toolbarSettings.showToolbar)
                            this._renderToolBar().insertBefore(this.element.find(".e-gridheader").first());
                        break;
				    case "selectionSettings":
                        $.extend(this.model.selectionSettings, options[prop]);
						this._allowrowSelection = this._allowcellSelection = this._allowcolumnSelection = false;						
                        this._initSelection();
                        break;
                    case "sortSettings":
                        $.extend(this.model.sortSettings, options[prop]);
                        this.refreshContent();
                        break;
                    case "enableRTL":
                        this.model.enableRTL = options[prop];
                        this.refreshContent();
                        break;
                    case "allowSelection":
                        if (options[prop])
                            this._off(this.element, "click")._on(this.element, "click", this._clickHandler);
                        break;
                    case "query":
                        this.commonQuery = $.extend(true, {}, options[prop]);
                        break;
                }
            }

        },
        /**
         * Reset the model collections like pageSettings, groupSettings, filterSettings, sortSettings and summaryRows.
         * @alias ejGrid#resetModelCollections
         * @return jQuery		 
         * @example 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // Reset model collections
         * gridObj.resetModelCollections(); 
         * &lt;/script&gt;
         * @example 
         * &lt;script&gt;
         * // Reset model collections
         * $("#Grid").ejGrid("resetModelCollections");
         * &lt;/script&gt;
         */
        resetModelCollections: function () {
            this.model.groupSettings.groupedColumns = [];
            this.model.filterSettings.filteredColumns = [];
            this.model.sortSettings.sortedColumns = [];
            this.model.pageSettings.currentPage = this.defaults.pageSettings.currentPage;
            this.model.summaryRows = [];
        }
    };
})(jQuery, Syncfusion);;
(function ($, ej, undefined) {
    ej.gridFeatures = ej.gridFeatures || {};
    ej.gridFeatures.edit = {
        _processEditing: function () {
            var query = this._columnToSelect();
            this.model.query._fromTable != "" && query.from(this.model.query._fromTable);
            if (this._dataSource() instanceof ej.DataManager && query.queries.length) {
                var queryPromise = this._dataSource().executeQuery(query);
                queryPromise.done(ej.proxy(function (e) {
                    this._dropDownManager = ej.DataManager(e.result);
                    if (this.model.editSettings.editMode == "normal") this.addEditingTemplate();
                    else if (this.model.editSettings.editMode == "batch") this.addBatchEditTemplate();
                    else if (this.model.editSettings.editMode == "dialog" ||
                        this.model.editSettings.editMode == "externalform" ||
                        this.model.editSettings.editMode == "inlineform")
                        this.addDialogEditingTemplate();
                    else this.addExternalDialogEditingTemplate();
                }, this));
            } else {
                if (this.model.editSettings.editMode == "normal") this.addEditingTemplate();
                else if (this.model.editSettings.editMode == "batch") this.addBatchEditTemplate();
                else if (this.model.editSettings.editMode == "dialog" ||
                    this.model.editSettings.editMode == "externalform" ||
                    this.model.editSettings.editMode == "inlineform")
                    this.addDialogEditingTemplate();
                else this.addExternalDialogEditingTemplate();
            }
        },
        addEditingTemplate: function () {
            if (this.model.columns.length == 0)
                return;
            var $tbody = ej.buildTag('tbody');
            var $tr = ej.buildTag('tr');
            var $td = ej.buildTag('td', "", {}, { colSpan: this.model.scrollSettings.frozenColumns > 0 ? this.model.scrollSettings.frozenColumns : this.model.columns.length });
            var $form = ej.buildTag('form', "", {}, { id: this._id + "EditForm", "class": "gridform" });
            var $table = ej.buildTag('table.e-table', "", {}, { cellspacing: 0.25 });
            var $innerTbody = ej.buildTag('tbody');
            var $innerTr = ej.buildTag('tr');
            $tbody.append($tr);
            $tr.append($td);
            $td.append($form);
            var $colGroup = $(document.createElement('colgroup'));
            $form.append($table);
            $table.append($colGroup);
            $innerTbody.append($innerTr).appendTo($table);
            if (this.model.scrollSettings.frozenColumns > 0) {
                var $tbodyClone = $tbody.clone();
                $tbodyClone.find("td").first().prop("colSpan", this.model.columns.length - this.model.scrollSettings.frozenColumns);
            }
            for (var columnCount = 0; columnCount < this.model.columns.length; columnCount++) {
                var $innerTd = ej.buildTag('td.e-rowcell');
                $innerTr.append($innerTd.get(0));
                if (ej.isNullOrUndefined(this.model.columns[columnCount]["isUnbound"]) && ej.isNullOrUndefined(this.model.columns[columnCount]["template"])) {
                    this._initCellEditType(columnCount, $innerTd);
                } else if (this.model.columns[columnCount]["template"]) {
                    var helpers = {};
                    helpers["_" + this._id + "ColumnTemplating"] = ej.proxy(this._gridTemplate, null, this);
                    $.views.helpers(helpers);
                    $("#" + this._id + this.model.columns[columnCount].headerText + columnCount + "_Template").remove();
                    var scriptElement = this._createTemplateElement(this.model.columns[columnCount]);
                    $innerTd.addClass("e-templatecell").html("{{:~_" + this._id + "ColumnTemplating('" + scriptElement.id + "')}}");
                } else if (this.model.columns[columnCount]["isUnbound"]) {
                    var helpers = {};
                    helpers["_" + this._id + "UnboundTemplate"] = this._unboundTemplateRendering;
                    $.views.helpers(helpers);
                    $("#" + this._id + this.model.columns[columnCount].headerText + "_UnboundTemplate").remove();
                    divElement = this._createUnboundElement(this.model.columns[columnCount]);
                    $innerTd.addClass("e-unboundcell").addClass("e-" + this.model.columns[columnCount]["headerText"].replace(/\s+/g, "")).html("{{:~_" + this._id + "UnboundTemplate('" + divElement.id + "')}}");
                    this.model.scrollSettings.frozenColumns > 0 && $innerTd.addClass("e-frozenunbound");
                    this._isUnboundColumn = true;
                }
                if (this.model.columns[columnCount]["textAlign"] != undefined)
                    $innerTd.css("text-align", this.model.columns[columnCount]["textAlign"]);
                this.model.columns[columnCount]["allowEditing"] == false && $innerTd.find(".e-field").attr("disabled", true).addClass("e-disable");
                if (this.model.columns[columnCount]["isPrimaryKey"] === true) {
                    $innerTd.find(".e-field").attr("disabled", true).addClass("e-disable");
                    this._primaryKeys.push($.trim(this.model.columns[columnCount].field));
                    this._primaryKeys = $.unique(this._primaryKeys);
                }
                if (this.model.columns[columnCount]["isIdentity"] === true)
                    $innerTd.find(".e-field").addClass("e-identity");
                var $col = $(document.createElement('col'));
                if (this.model.columns[columnCount]["priority"]) {
                    $innerTd.addClass("e-table-priority-" + this.model.columns[columnCount]["priority"]);
                    $col.addClass("e-table-priority-" + this.model.columns[columnCount]["priority"]);
                }
                if (this.model.columns[columnCount]["visible"] === false) {
                    $col.css("display", "none");
                    $innerTd.addClass("e-hide");
                }
                if (!ej.isNullOrUndefined(this.model.columns[columnCount]["cssClass"])) {
                    $innerTd.addClass(this.model.columns[columnCount]["cssClass"]);
                }
                !this.model.groupSettings.showGroupedColumn && $innerTd.addClass("{{for ~groupedColumns}}" +
                    " {{if #data == '" + this.model.columns[columnCount]["field"] + "'}}e-hide{{/if}}" +
                    "{{/for}}") && $col.css("display", "none");
                $colGroup.append($col);
                if (columnCount == this.model.scrollSettings.frozenColumns - 1) {
                    $innerTr = $tbodyClone.find("tr").last();
                    $colGroup = $tbodyClone.find("colgroup");
                    $.templates(this._id + "_JSONFrozenEditingTemplate", $tbody.html());
                    $tbody = $tbodyClone;
                }
            }
            $.templates(this._id + "_JSONEditingTemplate", $tbody.html());
        },

        addDialogEditingTemplate: function () {
            if (this.model.columns.length == 0)
                return;
            var $tbody = ej.buildTag('div');
            var $form = ej.buildTag('form.gridform', "", {}, { id: this._id + "EditForm" });
            var $table = ej.buildTag('table', "", {}, { cellspacing: "14px" });
            var $innerTr, $labelTd, $valueTd, trElement, tdElement;
            for (var columnCount = 0; columnCount < this.model.columns.length; columnCount++) {
                if (this.model.editSettings.editMode == "dialog") {
                    trElement = 'tr';
                    tdElement = 'td';
                }
                else trElement = tdElement = 'div';
                $innerTr = ej.buildTag(trElement);
                $labelTd = ej.buildTag(tdElement, "", { "text-align": "right" }).addClass("e-label");
                $valueTd = ej.buildTag(tdElement, "", { "text-align": "left" }).addClass("e-rowcell");
                 if (this.model.columns[columnCount]["priority"] && this.model.editSettings.editMode == "inlineform") 
                    $innerTr.addClass("e-table-priority-" + this.model.columns[columnCount]["priority"]);
                $innerTr.append($labelTd.get(0)).append($valueTd.get(0));
                if (this.model.columns[columnCount].headerText == undefined)
                    this.model.columns[columnCount].headerText = this.model.columns[columnCount].field;
                $labelTd.append("<label for='" + this.model.columns[columnCount].field + "'>" + this.model.columns[columnCount].headerText + "</label>");
                if (ej.isNullOrUndefined(this.model.columns[columnCount]["isUnbound"]) && ej.isNullOrUndefined(this.model.columns[columnCount]["template"]))
                    this._initCellEditType(columnCount, $valueTd);
                else if (this.model.columns[columnCount]["template"]) {
                    var helpers = {};
                    helpers["_" + this._id + "ColumnTemplating"] = ej.proxy(this._gridTemplate, null, this);
                    $.views.helpers(helpers);
                    $("#" + this._id + this.model.columns[columnCount].headerText + columnCount + "_Template").remove();
                    var scriptElement = this._createTemplateElement(this.model.columns[columnCount]);
                    $valueTd.addClass("e-templatecell").html("{{:~_" + this._id + "ColumnTemplating('" + scriptElement.id + "')}}");
                } else if (this.model.columns[columnCount]["isUnbound"]) {
                    var helpers = {};
                    helpers["_" + this._id + "UnboundTemplate"] = this._unboundTemplateRendering;
                    $.views.helpers(helpers);
                    $("#" + this._id + this.model.columns[columnCount].headerText + "_UnboundTemplate").remove();
                    divElement = this._createUnboundElement(this.model.columns[columnCount]);
                    $valueTd.addClass("e-unboundcell").addClass("e-" + this.model.columns[columnCount]["headerText"].replace(/\s+/g, "")).html("{{:~_" + this._id + "UnboundTemplate('" + divElement.id + "')}}");
                    this.model.scrollSettings.frozenColumns > 0 && $innerTd.addClass("e-frozenunbound");
                    this._isUnboundColumn = true;
                    $innerTr.addClass("e-hide");
                }
                this.model.columns[columnCount]["allowEditing"] == false && $valueTd.find(".e-field").attr("disabled", true).addClass("e-disable");
                if (this.model.columns[columnCount]["isPrimaryKey"] === true)
                    $valueTd.find(".e-field").attr("disabled", true).addClass("e-disable");
                if (this.model.columns[columnCount]["visible"] === false)
                    $innerTr.addClass("e-hide");
                 if (!ej.isNullOrUndefined(this.model.columns[columnCount]["cssClass"])) {
                    $innerTd.addClass(columns[i]["cssClass"]);
                }
                if (this.model.editSettings.editMode == "dialog") {
                    $form.append($table);
                    $table.append($innerTr);
                } else
                    $form.append($innerTr);
                $form.appendTo($tbody);
                if (this.model.columns[columnCount]["isPrimaryKey"] === true) {
                    $valueTd.find(".e-field").attr("disabled", true).addClass("e-disable");
                    this._primaryKeys.push($.trim(this.model.columns[columnCount].field));
                    this._primaryKeys = $.unique(this._primaryKeys);
                }
            }
            if (this.model.editSettings.editMode == "dialog") $form.append($table);
            $tbody = this.renderDiaglogButton($form, $tbody);
            $.templates(this._id + "_JSONDialogEditingTemplate", $tbody.html());
        },
        _editEventTrigger: function (args) {
            if (args.requestType == "save" || args.requestType == "delete") {
                var params = {
                    data: args.data,
                    action: args.action !== undefined ? args.action : args.requestType,
                };
                if (!ej.isNullOrUndefined(args.foreignKeyData))
                    params.foreignKeyData = args.foreignKeyData;
                this._trigger("end" + params.action.charAt(0).toUpperCase() + params.action.slice(1), params);
            }
        },
        _compiledDropDownTemplate: function (valueField, textField, colType, format) {
            var helpers = { _gridFormatting: this.formatting };
            $.views.helpers(helpers);
            var $select = ej.buildTag('select');
            var $option = ej.buildTag("option", ej.isNullOrUndefined(textField) ? "{{:text}}" : colType == "date" && format != null ? "{{:~_gridFormatting('" + format + "'," + textField + ",'"+ this.model.locale +"')}}" : "{{:" + textField + "}}", {}, { value: ej.isNullOrUndefined(valueField) ? "{{:value}}" : "{{:" + valueField + "}}" });
            $select.append($option);
            return $.templates($select.html());
        },
        _initCellEditType: function (columnCount, element) {
            if (this.model.columns[columnCount]["foreignKeyValue"])
                this.model.columns[columnCount]["editType"] = "dropdownedit";
            if (this.model.columns[columnCount]["editTemplate"])
                this.model.columns[columnCount]["editType"] = "edittemplate";
            if (ej.isNullOrUndefined(this.model.columns[columnCount]["editType"]))
                if (this.model.columns[columnCount]["type"] == "date" || this.model.columns[columnCount]["type"] == "datetime")
                    this.model.columns[columnCount]["editType"] = this.model.columns[columnCount]["type"] + "picker";
                else
                    this.model.columns[columnCount]["editType"] = "stringedit";
            if (this.model.isResponsive)
                element.attr("data-cell", this.model.columns[columnCount]["headerText"]);
            switch (this.model.columns[columnCount]["editType"]) {
                case "edittemplate":
                    var temp = this.model.columns[columnCount].editTemplate.create;
                    if (typeof temp == "string") {
                        var temp1 = ej.util.getObject(temp, window);
                        if (!$.isFunction(temp1)) {
                            if ($(temp).length == 1 && $(temp).get(0).tagName == "SCRIPT")
                                var $edittemplate = $($(temp).html()).attr({ id: this._id + this.model.columns[columnCount].field, name: this.model.columns[columnCount].field });
                            else
                                var $edittemplate = $(temp).attr({ id: this._id + this.model.columns[columnCount].field, name: this.model.columns[columnCount].field });
                        }
                        else
                            var $edittemplate = $(temp1()).attr({ id: this._id + this.model.columns[columnCount].field, name: this.model.columns[columnCount].field });
                    }
                    else
                        var $edittemplate = $(temp()).attr({ id: this._id + this.model.columns[columnCount].field, name: this.model.columns[columnCount].field });
                    element.append($edittemplate);
                    break;
                case "stringedit":
                    element.html(ej.buildTag('input.e-field e-ejinputtext', "", {}, { value: "{{:#data['" + this.model.columns[columnCount].field + "']}}", id: this._id + this.model.columns[columnCount].field, name: this.model.columns[columnCount].field }));
                    break;
                case "booleanedit":
                    element.html('{{if ' + this.model.columns[columnCount].field + '}} <input class="e-field e-checkbox" type ="checkbox" id=' + this._id + this.model.columns[columnCount].field + ' name=' + this.model.columns[columnCount].field + ' checked="checked"></input>{{else}} <input class="e-field e-checkbox" type ="checkbox" id=' + this._id + this.model.columns[columnCount].field + ' name=' + this.model.columns[columnCount].field + ' > {{/if}}');
                    if (this.model.editSettings.editMode == "normal")
                        element.addClass("e-boolcell");
                    break;
                case "numericedit":
                    var $numericText = ej.buildTag('input.e-numerictextbox e-field', "", {}, { type: "text", value: "{{:#data['" + this.model.columns[columnCount].field + "']}}", id: this._id + this.model.columns[columnCount].field, name: this.model.columns[columnCount].field });
                    element.append($numericText);
                    break;
                case "datepicker":
                case "datetimepicker":
                    var $datePicker = ej.buildTag('input.e-' + this.model.columns[columnCount]["editType"] + ' e-field', "", {}, { type: "text", value: "{{:#data['" + this.model.columns[columnCount].field + "']}}", id: this._id + this.model.columns[columnCount].field, name: this.model.columns[columnCount].field });
                    element.append($datePicker);
                    break;
                case "dropdownedit":
                    var currColumn = this.model.columns[columnCount];
                    if (ej.isNullOrUndefined(currColumn.dataSource)) {
                        var arrayOfDatas;
                        var query = new ej.Query().select(currColumn.field);
                        if (ej.isNullOrUndefined(this._dropDownManager) || (!this._dataManager.dataSource.offline && this._dataManager.dataSource.json))
                            arrayOfDatas = this._dataManager.executeLocal(query);
                        else
                            arrayOfDatas = this._dropDownManager.executeLocal(query);
                        var selectedItems = [];
                        var uniqueData = uniqueData = ej.dataUtil.mergeSort(ej.distinct(arrayOfDatas));
                        for (var index = 0; index < uniqueData.length; index++)
                            selectedItems.push({ text: uniqueData[index], value: uniqueData[index] });
                    }
                    else
                        selectedItems = currColumn.dataSource;
                    var dropDownTemplate;
                    var fieldName = ej.isNullOrUndefined(currColumn.foreignKeyField) ? currColumn.field : currColumn.foreignKeyField;
                    if (currColumn.foreignKeyValue)
                        dropDownTemplate = this._compiledDropDownTemplate(fieldName, currColumn.foreignKeyValue, currColumn.type, currColumn.format);
                    else
                        dropDownTemplate = this._compiledDropDownTemplate();
                    element.get(0).innerHTML = ["<select>", dropDownTemplate.render(selectedItems), "</select>"].join("");
                    element.find("select").prop({ id: this._id + currColumn.field, name: currColumn.field }).addClass("e-field e-dropdownlist");
                    break;
            }
        },
        addBatchEditTemplate: function () {
            if (this.model.columns.length == 0)
                return;
            var $outerDiv = ej.buildTag('div', "", { display: "none" }, { id: this._id + "_BulkEditTemplate" }), i, columnCount, $innerDiv;
            for (i = 0, columnCount = this.model.columns.length; i < columnCount; i++) {
                if (!this.model.columns[i]["template"] || !this.model.columns[i]["isUnbound"]) {
                    $innerDiv = ej.buildTag('div', "", {}, { id: this.model.columns[i].field + "_BulkEdit" });
                    this._initCellEditType(i, $innerDiv);
                    $outerDiv.append($innerDiv);
                }
                if (this.model.columns[i]["isPrimaryKey"] === true) {
                    this._primaryKeys.push($.trim(this.model.columns[i].field));
                    this._primaryKeys = $.unique(this._primaryKeys);
                }
                if (this.model.columns[i]["isIdentity"] === true)
                    $innerDiv.find(".e-field").addClass("e-identity");
            }
            if ($outerDiv.children().length)
                this._bulkEditTemplate = $outerDiv;

        },
        addExternalDialogEditingTemplate: function () {
            if (this.model.columns.length == 0)
                return;
            for (var columnCount = 0; columnCount < this.model.columns.length; columnCount++) {
                if (this.model.columns[columnCount]["isPrimaryKey"] === true) {
                    this._primaryKeys.push($.trim(this.model.columns[columnCount].field));
                    this._primaryKeys = $.unique(this._primaryKeys);
                }
            }
            var $tbody = ej.buildTag('div', "", { 'display': 'none' });
            var $form = ej.buildTag('form.gridform', "", {}, { id: this._id + "EditForm" });
            var cloneElement;
            if (this.model.editSettings.editMode == "dialogtemplate" && this.model.editSettings.dialogEditorTemplateID != null)
                cloneElement = this.model.editSettings.dialogEditorTemplateID;
            else if (this.model.editSettings.editMode == "externalformtemplate" && this.model.editSettings.externalFormTemplateID != null)
                cloneElement = this.model.editSettings.externalFormTemplateID;
            else
                cloneElement = this.model.editSettings.inlineFormTemplateID;

            $form.html($(cloneElement).html());
            $tbody = this.renderDiaglogButton($form, $tbody);
            $.templates(this._id + "_JSONdialogTemplateMode", $tbody.html());
        },
        _editdblClickHandler: function (e) {
            var $target = $(e.target);
            if ($target.hasClass("e-rowcell")) {
                if (!this.model.isEdit) {
                    this._$currentTr = (this.model.scrollSettings.frozenColumns > 0 || this.model.scrollSettings.frozenRows > 0)
                        ? this.getRowByIndex($target.closest('tr').index())
                        : $target.closest('tr');
                    this.startEdit(this._$currentTr);
                }
            }
            return false;
        },
        _columnToSelect: function () {
            var column = [];
            for (var i = 0; i < this.model.columns.length; i++) {
                if (this.model.columns[i]["editType"] === ej.Grid.EditingType.Dropdown && ej.isNullOrUndefined(this.model.columns[i]["dataSource"]))
                    column.push(this.model.columns[i].field);
            }
            if (column.length)
                return ej.Query().select(column);
            return ej.Query();
        },
        _renderExternalForm: function () {
            var $externalform = ej.buildTag("div", "", { display: "none" }, { id: this._id + "_externalEdit", 'class': "e-form-container" });
            var $eformHeader = ej.buildTag("div", "", "", { id: this._id + "_eFormHeader", 'class': "e-form-titlebar" });
            var $eformTitle = ej.buildTag("span", "", "", { 'class': "e-form-title" });
            var $eformToggleBtn = ej.buildTag("div", "", "", { id: this._id + "_eFormToggleBtn", 'class': "e-form-togglebtn" });
            var $eformToggleIcon = ej.buildTag("span", "", "", { 'class': "e-form-toggle-icon e-icon" });
            $eformToggleBtn.append($eformToggleIcon);
            $eformHeader.append($eformTitle).append($eformToggleBtn);

            var $eformContent = ej.buildTag("div", "", "", { id: this._id + "_eFormContent", 'class': "e-form-content" });
            var $eform = ej.buildTag("div", "", "", { id: this._id + "_externalForm", 'class': "e-externalform" });
            var $contentOuterDiv = ej.buildTag("div", "", "", { 'class': "e-externalformedit" });
            $eform.append($contentOuterDiv);
            $eformContent.append($eform);
            return $externalform.append($eformHeader).append($eformContent);;
        },
        _buttonClick: function (e) {
            if (e.type == "close") {
                if (!this.model.isEdit)
                    return;
                this.model.isEdit = false;
                this.element.ejGrid("cancelEdit");
                this.refreshToolbar();
                return;
            }
            if (e.keyCode !== undefined && e.keyCode != 13 || this.model == null)
                return true;
            if (this.model.editSettings.editMode == "dialog" || this.model.editSettings.editMode == "dialogtemplate") {
                if (e.target.id == "EditDialog_" + this._id + "_Save") {
                    if (this.element.ejGrid("endEdit").length !== undefined)
                        $("#" + this._id + "_dialogEdit").ejDialog("close");
                } else if (e.target.id == "EditDialog_" + this._id + "_Cancel") {
                    this.element.ejGrid("cancelEdit");
                    $("#" + this._id + "_dialogEdit").ejDialog("close");
                }
            }
            else if (this.model.editSettings.editMode == "externalform" || this.model.editSettings.editMode == "externalformtemplate") {
                if ($(e.target).hasClass("e-form-toggle-icon")) {
                    this.element.ejGrid("cancelEdit");
                    $("#" + this._id + "_externalEdit").css("display", "none");
                }
                else {
                    if (e.target.id == "EditExternalForm_" + this._id + "_Save") {
                        if (this.element.ejGrid("endEdit").length !== undefined)
                            $("#" + this._id + "_externalEdit").css("display", "none");
                    } else if (e.target.id == "EditExternalForm_" + this._id + "_Cancel") {
                        this.element.ejGrid("cancelEdit");
                        $("#" + this._id + "_externalEdit").css("display", "none");
                    }
                }
            }
            else if (this.model.editSettings.editMode == "inlineform" || this.model.editSettings.editMode == "inlineformtemplate") {
                if (e.target.id == "InlineEditForm_" + this._id + "_Save")
                    this.element.ejGrid("endEdit");
                else if (e.target.id == "InlineEditForm_" + this._id + "_Cancel")
                    this.element.ejGrid("cancelEdit");
            }
            else
                this.element.ejGrid("cancelEdit");
        },
        _enableEditingEvents: function () {
            if (this.model.editSettings.allowEditing || this.model.editSettings.allowAdding) {
                if (this.model.editSettings.allowEditing && this.model.editSettings.editMode != "batch" && this.model.editSettings.allowEditOnDblClick)
                    this._on(this.element, "dblclick", ".e-gridcontent", this._editdblClickHandler);
                else
                    this._off(this.element, "dblclick", ".e-gridcontent");
                this._off($("#" + this._id + "_dialogEdit"), "click keypress", "#EditDialog_" + this._id + "_Save ,#EditDialog_" + this._id + "_Cancel");
                if (this.model.editSettings.editMode == "dialog" || this.model.editSettings.editMode == "dialogtemplate") {
                    this._on($("#" + this._id + "_dialogEdit"), "click keypress", "#EditDialog_" + this._id + "_Save ,#EditDialog_" + this._id + "_Cancel", this._buttonClick);
                }
                else if (this.model.editSettings.editMode == "externalform" || this.model.editSettings.editMode == "externalformtemplate") {
                    this._on($("#" + this._id + "_externalEdit"), "click keypress", "#EditExternalForm_" + this._id + "_Save ,#EditExternalForm_" + this._id + "_Cancel", this._buttonClick);
                    $(this.element).on("click", ".e-form-toggle-icon", $.proxy(this._buttonClick, this));
                }
                else if (this.model.editSettings.editMode == "batch")
                    this._on($(document), "mousedown", this._saveCellHandler);

                else if (this.model.editSettings.editMode == "inlineform" || this.model.editSettings.editMode == "inlineformtemplate")
                    $(this.element).on("click keypress", "#InlineEditForm_" + this._id + "_Save ,#InlineEditForm_" + this._id + "_Cancel", $.proxy(this._buttonClick, this));

            } else {
                this._off($("#" + this._id + "_dialogEdit"), "click", "#EditDialog_" + this._id + "_Save ,#EditDialog_" + this._id + "_Cancel");
                $(this.element).off("click", ".e-icon");
                this._off($("#" + this._id + "_externalEdit"), "click", "#EditExternalForm_" + this._id + "_Save ,#EditExternalForm_" + this._id + "_Cancel");
                $(this.element).off("click", ".e-form-toggle-icon");
                $(this.element).off("click", "#InlineEditForm_" + this._id + "_Save ,#InlineEditForm_" + this._id + "_Cancel");
            }
        },

        _deleteRow: function ($tr) {
            if (!this.model.editSettings.allowDeleting)
                return;
            if (this.model.editSettings.editMode == "batch")
                this._bulkDelete(this.getIndexByRow($tr));
            else {
                if (this._primaryKeys.length == 0 && !this.model.editSettings.allowEditing && !this.model.editSettings.allowAdding) {
                    for (i = 0; i < this.model.columns.length; i++) {
                        if (this.model.columns[i]["isPrimaryKey"] === true) {
                            this._primaryKeys.push($.trim(this.model.columns[i].field));
                            this._primaryKeys = $.unique(this._primaryKeys);
                        }
                    }
                }
                if (this._selectedRow() == -1 && ej.isNullOrUndefined($tr)) {
                    alert(this._getLocalizedLabels("DeleteOperationAlert"));
                    return;
                }
                if (ej.isNullOrUndefined($tr))
                    $tr = this.getRowByIndex(this._selectedRow());
                this._primaryKeyValues = [];
                for (var index = 0; index < this._primaryKeys.length; index++) {
                    var column = this.getColumnByField(this._primaryKeys[index]);
                    var indx = $.inArray(column, this.model.columns);
                    this._primaryKeyValues.push($tr.find(".e-rowcell").eq(indx).html());
                }
                var deleteManager = ej.DataManager(this._currentJsonData);
                var query = new ej.Query();
                for (var i = 0; i < this._primaryKeys.length; i++)
                    query = query.where(this._primaryKeys[i], ej.FilterOperators.equal, this._primaryKeyValues[i]);
                currentData = deleteManager.executeLocal(query);
                var args = {};
                args.tr = $tr;
                args.data = currentData[0];
                var foreignKeyData = this._getForeignKeyData(args.data);
                if (!ej.isNullOrUndefined(foreignKeyData))
                    args.foreignKeyData = foreignKeyData;
                args.requestType = ej.Grid.Actions.Delete;
                if (this._trigger("actionBegin", args))
                    return true;
                this._cDeleteData = currentData;
                var promise;
                if (this._dataSource() instanceof ej.DataManager) {
                    promise = this._dataManager.remove(this._primaryKeys[0], currentData[0][this._primaryKeys[0]]);
                    var proxy = this;
                    if ($.isFunction(promise.promise)) {
                        promise.done(function(e) {
                            proxy._processBindings(args);
                            proxy._primaryKeyValues = [];
                            proxy._cDeleteData = null;
                        });
                        promise.fail(function(e) {
                            args.error = e
                            proxy._trigger("actionFailure", args)
                        });
                    } else
                        this._processBindings(args);
                } else
                    this._processBindings(args);
                if (promise == undefined || !$.isFunction(promise.promise)) {
                    this._primaryKeyValues = [];
                    this._cDeleteData = null;
                }
            }
        },
        /**
		 * Send an edit record request in grid
         * @alias ejGrid#startEdit
		 * @return jQuery
		 * @param {object} $tr Pass the tr- selected row element to be edited in grid
		 * @example 
		 * &lt;script&gt;
		 * // Create grid object.
		 * var gridObj = $("#Grid").data("ejGrid");
         * // Sends an edit record request to the grid
		 * gridObj.startEdit($(".gridcontent tr").first()); 
		 * &lt;/script&gt;
		 * @example 
		 * &lt;script&gt;
		 * // Sends an edit record request to the grid
		 * $("#Grid").ejGrid("startEdit", $(".gridcontent tr").first());        
		 * &lt;/script&gt;
         */
        _htmlEncode: function (html) {
            var str = html.replace(/&amp;/g, '&').replace(/&lt;/g, '<').replace(/&gt;/g, '>').replace(/&quot;/g, '"').replace(/&apos;/g, '\'');
            return str;
        },
        startEdit: function ($tr) {
            if (!this.model.editSettings.allowEditing)
                return;
            if (this._selectedRow() == -1 && ej.isNullOrUndefined($tr)) {
                alert(this._getLocalizedLabels("EditOperationAlert"));
                return;
            }
            if (ej.isNullOrUndefined($tr)) {
                this._currentTrIndex = this._selectedRow();
                this._$currentTr = this.getRowByIndex(this._currentTrIndex);
            } else {
                this._currentTrIndex = $tr.index();
                this._$currentTr = $tr;
            }
            for (var index = 0; index < this._primaryKeys.length; index++) {
                var column = this.getColumnByField(this._primaryKeys[index]);
                var indx = $.inArray(column, this.model.columns);
                this._primaryKeyValues.push(this._htmlEncode(this._$currentTr.find(".e-rowcell").eq(indx).html()));
            }
            var args = { row: this._$currentTr, rowIndex: this._currentTrIndex, primaryKey: this._primaryKeys, primaryKeyValue: this._primaryKeyValues };
            var cancel = this._trigger("beginEdit", args);
            if (cancel) {
                this._primaryKeyValues = [];
                return;
            }
            args.requestType = ej.Grid.Actions.BeginEdit;
            this._processBindings(args);

        },
         _startAdd: function() {
            if (!this.model.editSettings.allowAdding)
                return;
            if (this.model.editSettings.editMode == "batch")
                this._bulkAddRow();
            else {
                var cloneData = {};
                for (var i = 0; i < this.model.columns.length; i++)
                    cloneData[this.model.columns[i].field] = !ej.isNullOrUndefined(this.model.columns[i].defaultValue) ? this.model.columns[i].defaultValue : "";
                var args = {};
                args.data = cloneData;
                var foreignKeyData = this._getForeignKeyData(args.data);
                if (!ej.isNullOrUndefined(foreignKeyData))
                    args.foreignKeyData = foreignKeyData;
                args.requestType = "add";
                this.clearSelection();
                var returnValue = this._processBindings(args);
                if (!returnValue)
                    this._selectedRow(0);
                var groupedColumns = this.model.groupSettings.groupedColumns.length;
                if (groupedColumns > 1) {
                    var $editCol = this.getContentTable().find(".e-addedrow").find("table").find("colgroup").children();
                    $($editCol.slice(0, groupedColumns - 1)).css('width', this.getHeaderTable().find('colgroup').children()[0].style.width);
                }
            }
        },
        /**
		 * Send a save request in grid.
         * @alias ejGrid#endEdit
		 * @return jQuery
		 * @example 
		 * &lt;script&gt;
		 * // Create grid object.
		 * var gridObj = $("#Grid").data("ejGrid");
         * // Sends a save request to the grid
		 * gridObj.endEdit(); 
		 * &lt;/script&gt;
		 * @example 
		 * &lt;script&gt;
		 * // Sends a save request to the grid
		 * $("#Grid").ejGrid("endEdit");        
		 * &lt;/script&gt;
         */
        endEdit: function () {
            if (this.model.isEdit) {
                var formElement, $formElement;
                if (!this.editFormValidate())
                    return true;
                var obj = {};
                var editedRowWrap;
                if (this.model.editSettings.editMode == "batch")
                    this.saveCell();
                else {
                    formElement = this.model.scrollSettings.frozenColumns > 0 ? this.element.find(".gridform") : document.getElementById(this._id + "EditForm");
                    $formElement = $(formElement);
                    if (this.model.editSettings.editMode == "normal" || this.model.editSettings.editMode == "inlineform" || this.model.editSettings.editMode == "inlineformtemplate")
                        editedRowWrap = $formElement.closest('tr');
                    else
                        editedRowWrap = $formElement.closest('div');
                    formElement = this.model.scrollSettings.frozenColumns > 0 ? formElement[0] : formElement;
                    for (var index = 0; index < formElement.length; index++) {
                        if (editedRowWrap.hasClass("e-addedrow") && $(formElement[index]).hasClass("e-identity"))
                            continue;
                        var columnName = formElement[index].name, $element = $(formElement[index]);
                        if (columnName != undefined) {
                            if (columnName == "") {
                                if (formElement[index].id.indexOf("Save") != -1 || formElement[index].id.indexOf("Cancel")!= -1)
                                    columnName = "";
                                else
                                    columnName = formElement[index].id.replace(this._id, "");
                            }
                            if (columnName != "" && obj[columnName] == null) {
                                var column = this.getColumnByField(columnName), value = formElement[index].value;
                                if (!ej.isNullOrUndefined(column) && (column.editType == "edittemplate")) {
                                    if (formElement[index].type == 'hidden') index++;
                                    if (formElement[index].type != 'hidden') {
                                        var temp1 = column.editTemplate.read; $element = $(formElement[index]);
                                        if (typeof temp1 == "string")
                                            temp1 = ej.util.getObject(temp1, window);
                                        value = temp1($element);
                                    }
                                }
                                else if ($(formElement[index]).hasClass("e-datepicker")) {
                                    value = $element.ejDatePicker("model.value");
                                }
                                else if ($(formElement[index]).hasClass("e-datetimepicker")) {
                                    value = $element.ejDateTimePicker("model.value");
                                }
                                else if ($element.is(".e-numerictextbox"))
                                    value = $element.ejNumericTextbox("getValue");
                                else if ($element.data("ejDropDownList")) {
                                    value = $element.ejDropDownList("getSelectedValue");
                                }
                                if (column == null)
                                    value = !isNaN(parseFloat(value)) && isFinite(value) ? parseFloat(value) : value;
                                else if (column.type == "number" && value.length)
                                    value = parseFloat(value);
                                var originalvalue;
                            if (formElement[index].type != "checkbox")
                                originalvalue = value;
                            else
                                originalvalue = $(formElement[index]).is(':checked');
                            if (columnName.indexOf(".") != -1)
                                ej.createObject(columnName, originalvalue, obj);
                            else
                                obj[columnName] = originalvalue;
                            }
                        }
                        if (index == formElement.length - 1 && $formElement.length > 1 && $formElement.index(formElement) == 0) {
                            formElement = $formElement[1];
                            index = -1;
                        }

                    }
                    var args = { data: obj };
                    var foreignKeyData = this._getForeignKeyData(args.data);
                    if (!ej.isNullOrUndefined(foreignKeyData))
                        args.foreignKeyData = foreignKeyData;
                    args.requestType = ej.Grid.Actions.Save;
                    args.selectedRow = this._selectedRow();
                    var currentData;
                    if (this._trigger("actionBegin", args))
                        return true;
                    if (editedRowWrap.hasClass("e-editedrow")) {
                        this._cModifiedData = obj;
                        args.action = "edit";
                    } else if (editedRowWrap.hasClass("e-addedrow")) {
                        this._cAddedRecord = obj;
                        args.action = "add";
                    }
                    this._updateAction(args);
                }
            }
        },
        _updateAction: function (args) {
            var promise;
            if (this._dataSource() instanceof ej.DataManager && (!this._dataManager.dataSource.offline && this._dataManager.dataSource.json !== undefined) || (this._dataSource().adaptor instanceof ej.remoteSaveAdaptor)) {
                if (!ej.isNullOrUndefined(this._cModifiedData))
                    promise = this._dataManager.update(this._primaryKeys[0], args.data);
                else
                    promise = this._dataManager.insert(args.data);
				this.model.isEdit = false;
                var proxy = this;
                if ($.isFunction(promise.promise)) {
                    promise.done(function (e) {
                        proxy._processBindings(args);
                        proxy._cModifiedData = null;
                        proxy._cAddedRecord = null;
                        proxy._primaryKeyValues = [];
                    });
                    promise.fail(function (e) {
                        args.error = ej.isNullOrUndefined(this._cModifiedData) ? e : e.error;
                        proxy._trigger("actionFailure", args)
                    });
                } else
                    proxy._processBindings(args);
            } else
                this._processBindings(args);
            if (promise == undefined || !$.isFunction(promise.promise)) {
                this._cModifiedData = null;
                this._cAddedRecord = null;
                this._primaryKeyValues = [];
            }
        },
        /**
		 * Send a cancel request in grid.
         * @alias ejGrid#cancelEdit
		 * @return jQuery
		 * @example 
		 * &lt;script&gt;
		 * // Create grid object.
		 * var gridObj = $("#Grid").data("ejGrid");
         * // Sends a cancel request to the grid
		 * gridObj.cancelEdit(); 
		 * &lt;/script&gt;
		 * @example 
		 * &lt;script&gt;
		 * // Sends a cancel request to the grid
		 * $("#Grid").ejGrid("cancelEdit");        
		 * &lt;/script&gt;
         */
        cancelEdit: function () {
            var args = {};
            $("#" + this._id + "EditForm").find(".e-datepicker").ejDatePicker("destroy");
            args.requestType = ej.Grid.Actions.Cancel;
            this._processBindings(args);
            this._primaryKeyValues = [];
            this._currentData = null;
        },
        /**
         * Refresh the toolbar items in grid.
         * @alias ejGrid#refreshToolbar
         * @return jQuery
         * @example 
         * &lt;div id="Grid"&gt;&lt;/div&gt; 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // Refreshes the toolbar items state
         * gridObj.refreshToolbar(); 
         * &lt;/script&gt;
         * @example 
         * &lt;div id="Grid"&gt;&lt;/div&gt; 
         * &lt;script&gt;
         * // Refreshes the toolbar items state
         * $("#Grid").ejGrid("refreshToolbar");        
         * &lt;/script&gt;
         */
        refreshToolbar: function () {
            var $toolbar = $("#" + this._id + "_toolbarItems");
            var lis = $toolbar.find("li");
            $toolbar.ejToolbar("enableItem", lis);
            for (var i = 0; i < lis.length; i++) {
                switch (lis[i].id) {
                    case this._id + "_add":
                    case this._id + "_edit":
                    case this._id + "_delete":
                        if (this.model.isEdit) {
                            $(lis[i]).hasClass("e-hover") && $(lis[i]).removeClass("e-hover");
                            this._disabledToolItems.push(lis[i]);
                        }
                        break;
                    case this._id + "_update":
                    case this._id + "_cancel":
                        if (!this.model.isEdit) {
                            $(lis[i]).hasClass("e-hover") && $(lis[i]).removeClass("e-hover");
                            this._disabledToolItems.push(lis[i]);
                        }
                        break;
                }
            }

            $toolbar.ejToolbar("disableItem", this._disabledToolItems);
            $toolbar.ejToolbar("model.enableRTL", this.model.enableRTL);
            this._disabledToolItems = $();

        },
        _getHiddenCount: function (elements) {
            var count = 0;
            for (var i = 0; i < elements.length; i++) {
                if (elements.eq(i).hasClass("e-hide"))
                    count++;
            }
            return count;
        },
        _edit: function (args) {
            var editingManager = ej.DataManager(this._currentJsonData);
            var queryManager = new ej.Query();
            if (this.model.allowFiltering)
                this._previousFilterCount = this._filteredRecordsCount;
            for (var index = 0; index < this._primaryKeys.length; index++)
                queryManager = queryManager.where(this._primaryKeys[index], ej.FilterOperators.equal, this._primaryKeyValues[index]);
            this._currentData = editingManager.executeLocal(queryManager);
            var temp = document.createElement('div');
            var $temp = $(temp), $tempSecondTR;
            if (this.model.editSettings.editMode == "normal") {
                temp.innerHTML = ['<table>', $.render[this._id + "_JSONEditingTemplate"](this._currentData, { groupedColumns: this.model.groupSettings.groupedColumns }), '</table>'].join("");
                var $tr = $temp.find("tr").first(), detailCount = 0, $tempFirstTR, firstHidden = this.model.columns.length
                , $currentTrFr = args.row.first();
                if (this.model.scrollSettings.frozenColumns > 0) {
                    $temp.prepend(['<table>', $.render[this._id + "_JSONFrozenEditingTemplate"](this._currentData, { groupedColumns: this.model.groupSettings.groupedColumns }), '</table>'].join(""));
                    $tr.splice(0, 0, $temp.find("table").first().find("tr").first().get(0));
                    $currentTrLa = args.row.last();
                    $tempLastTR = $tr.last();
                }
                $tempFirstTR = $temp.find("tr").first();
                $temp.find('td').not(".e-rowcell").addClass("e-editcell e-normaledit");
                var $select = $temp.find("select.e-field");
                for (var i = 0; i < $select.length; i++)
                    $select.eq(i).val(this._currentData[0][$select[i].name]);
                if (this.model.groupSettings.groupedColumns.length >= 2) {
                    var $indentCell = args.row.find("td.e-indentcell");
                    $temp.find("tr").first().prepend($indentCell);
                }
                if (this.model.detailsTemplate != null || this.model.childGrid != null) {
                    detailCount++;
                    $temp.find(".e-editcell").find("tr").prepend(args.row.find("[class*='detailrow']"));
                }
                if (this.model.scrollSettings.frozenColumns > 0) {
                    $temp.find(".e-editcell").get(1).colSpan = this.model.columns.length - this.model.scrollSettings.frozenColumns - args.row.last().find(".e-hide").length + detailCount;
                    firstHidden = this.model.scrollSettings.frozenColumns;
                    $currentTrLa.hasClass("e-alt_row") && $tempLastTR.addClass("e-alt_row")
                }
                $temp.find(".e-editcell").get(0).colSpan = firstHidden - $currentTrFr.find("td").not(":visible").length + detailCount;
                $currentTrFr.hasClass("e-alt_row") && $tempFirstTR.addClass("e-alt_row");
                $tempFirstTR.find('.e-templatecell').replaceWith($currentTrFr.find('.e-templatecell').removeClass('e-active'));
                $currentTrFr.empty().replaceWith($tempFirstTR.addClass("e-editedrow"));
                if (this.model.scrollSettings.frozenColumns > 0)
                    $currentTrLa.empty().replaceWith($tempLastTR.addClass("e-editedrow"));
                this._refreshUnboundTemplate($tr.find(".gridform"));
                this._gridRows = this.getContentTable().first().find(".e-rowcell").closest("tr").toArray();
                if (this.model.scrollSettings.frozenColumns > 0)
                    this.getScrollObject().scrollY(this.getScrollObject().model.scrollTop, true);
                if (this.model.scrollSettings.frozenColumns > 0) 
                    this._gridRows = [this._gridRows, this.getContentTable().last().find(".e-rowcell").closest("tr").toArray()];
            }
            else if (this.model.editSettings.editMode == "inlineform" || this.model.editSettings.editMode == "inlineformtemplate") {
                var hideCount = !this.model.groupSettings.showGroupedColumn ? this.model.groupSettings.groupedColumns.length : 0;
                var detailCount = 0;
                temp.innerHTML = this.model.editSettings.editMode == "inlineform" ? $.render[this._id + "_JSONDialogEditingTemplate"](this._currentData) : $.render[this._id + "_JSONdialogTemplateMode"](this._currentData);
                var $select = $temp.find("select.e-field");
                for (var i = 0; i < $select.length; i++)
                    $select.eq(i).val(this._currentData[0][$select[i].name]);
                var tr = ej.buildTag('tr');
                var td = ej.buildTag('td');
                tr.addClass("e-editedrow");
                td.addClass("e-inlineformedit");
                td.html($(temp).children());
                tr.append(td);
                if (this.model.scrollSettings.frozenColumns > 0) {
                    var $trClone = tr.clone();
                    $trClone.find("td").empty().prop("colspan", this.model.scrollSettings.frozenColumns);
                    args.row.eq(1).after(tr).end().eq(0).after($trClone);
                    this._gridRows = [this._gridRows, this.getContentTable().last().find("tr").toArray()];
                }
                else
                    args.row.after(tr);
                this._gridRows = this.getContentTable().first().find(".e-rowcell,.e-inlineformedit").closest("tr").toArray();
                if (this.model.scrollSettings.frozenColumns > 0)
                    td.prop("colspan", this.model.columns.length - this.model.scrollSettings.frozenColumns - tr.find("form").children().not(":visible").length - hideCount + detailCount);
                else
                    td.prop("colspan", this.model.columns.length -  tr.find("form").children().not(":visible").length - hideCount + detailCount);
                if (this.model.scrollSettings.frozenColumns > 0)
                    this._gridRows = [this._gridRows, this.getContentTable().last().find("tr").toArray()];
                $("#" + this._id + "_inlineFormTitle").text(this._getLocalizedLabels("EditFormTitle") + this._currentData[0][this._primaryKeys[0]]);
                args.row.find("input").attr('disabled', 'disabled').addClass("e-disable");
            }
            else {
                $temp.addClass("e-editedrow");
                temp.innerHTML = this.model.editSettings.editMode == "dialog" || this.model.editSettings.editMode == "externalform" ? $.render[this._id + "_JSONDialogEditingTemplate"](this._currentData) : $.render[this._id + "_JSONdialogTemplateMode"](this._currentData);
                var $select = $temp.find("select.e-field");
                for (var i = 0; i < $select.length; i++)
                    $select.eq(i).val(this._currentData[0][$select[i].name]);
                if (this.model.editSettings.editMode == "dialog" || this.model.editSettings.editMode == "dialogtemplate") {
                    $("#" + this._id + "_dialogEdit").html($(temp));
                    var model = {};
                    model.cssClass = this.model.cssClass;
                    model.enableRTL = this.model.enableRTL;
                    model.width = "auto";
                    model.enableResize = this.phoneMode;
                    model.close = $.proxy(this._buttonClick, this);
                    model.content = "#" + this._id;
                    model.enableModal = true;
                    model.allowKeyboardNavigation = false;
                    model.title = this._getLocalizedLabels("EditFormTitle") + this._currentData[0][this._primaryKeys[0]];
                    $("#" + this._id + "_dialogEdit").ejDialog(model);
                    $("#" + this._id + "_dialogEdit").ejDialog("open");
                }
                else {
                    $("#" + this._id + "_externalEdit").css("display", "block").css('z-index', this._maxZindex() + 1);
                    $(".e-externalformedit").html($(temp));
                    $("#" + this._id + "_eFormHeader").find(".e-form-title").text(this._getLocalizedLabels("EditFormTitle") + this._currentData[0][this._primaryKeys[0]]);
                    this._externalFormPosition();
                    args.row.find("input").attr('disabled', 'disabled').addClass("e-disable");
                }
            }
        },
        _add: function (args) {
            var temp = document.createElement('div');
            if ((!(this._dataSource() instanceof ej.DataManager) || this._dataManager.dataSource.url == undefined) && this.model.groupSettings.groupedColumns.length == 0 && this.model.scrollSettings.frozenColumns == 0 && this.model.scrollSettings.frozenRows == 0)
                !(this._dataSource() instanceof ej.DataManager) ? this._dataSource().splice(0, 1) : this._dataSource().dataSource.json.splice(0, 1);
            this._previousFilterCount = this._filteredRecordsCount;
            if (this.model.editSettings.editMode == "normal") {
                var $tempFirstTR, $temp = $(temp), frozenColSpan = this.model.columns.length;
                temp.innerHTML = ['<table>', $.render[this._id + "_JSONEditingTemplate"](args.data, { groupedColumns: this.model.groupSettings.groupedColumns }), '</table>'].join("");
                var $select = $(temp).find('select.e-field');
                for (var i = 0; i < $select.length; i++)
                    $select.eq(i).val(args.data[$select[i].name]);
                if (this.model.scrollSettings.frozenColumns > 0) {
                    $tempLastTR = $temp.find("table").first().find("tr").first();
                    $temp.prepend(['<table>', $.render[this._id + "_JSONFrozenEditingTemplate"](args.data, { groupedColumns: this.model.groupSettings.groupedColumns }), '</table>'].join(""));
                }
                $tempFirstTR = $temp.find("tr").first();
                var td = $(temp).find(".e-editcell").get(0);
                $(temp).find('td').first().addClass("e-editcell");
                if (this.model.allowPaging && this.model.pageSettings.pageSize <= this.model.currentViewData.length && this.model.groupSettings.groupedColumns.length == 0)
                    this.getContentTable().get(0).lastChild.removeChild(this.getContentTable().get(0).lastChild.lastChild);
                if (this.model.detailsTemplate != null && $(this.getContentTable().get(0).lastChild.lastChild).children('.e-detailrowexpand').length)
                    this.getContentTable().get(0).lastChild.removeChild(this.getContentTable().get(0).lastChild.lastChild);
                if (this.model.currentViewData.length == 0 || this.getContentTable().find('td.e-rowcell').length == 0)
                    this.getContentTable().find('tr').first().replaceWith($(temp).find("tr").first().addClass("e-addedrow e-normaledit"));
                else {
                    if (this.model.editSettings.rowPosition == "top")
                        this.getContentTable().first().find('tbody').first().prepend($tempFirstTR.addClass("e-addedrow e-normaledit"));
                    else if (this.model.editSettings.rowPosition == "bottom")
                        this.getContentTable().first().find('tbody').first().append($tempFirstTR.addClass("e-addedrow e-normaledit"));
                    if (this.model.scrollSettings.frozenColumns > 0)
                        this.getContentTable().last().find('tbody').first().prepend($tempLastTR.addClass("e-addedrow e-normaledit"));
                }
                var $editTr = this.getContentTable().find("tr.e-addedrow");
                if (this.model.detailsTemplate != null)
                    $editTr.find('tr').first().prepend(ej.buildTag('td.e-detailrowcollapse'));
                var hideCount = !this.model.groupSettings.showGroupedColumn ? this.model.groupSettings.groupedColumns.length : 0;
                if (this.model.groupSettings.groupedColumns.length) {
                    for (var i = 0; i < this.model.groupSettings.groupedColumns.length; i++) {
                        if (i == 0)
                            $editTr.prepend(ej.buildTag("td.e-indentcell"));
                        else {
                            $editTr.find("tr").prepend(ej.buildTag("td.e-indentcell"));
                        }
                    }
                    if (this.model.groupSettings.groupedColumns.length >= 2)
                        $editTr.find("td.e-editcell").prop("colspan", (this.model.columns.length + (this.model.groupSettings.groupedColumns.length - 1) - this._hiddenColumns.length - hideCount));
                    else
                        $editTr.find("td.e-editcell").prop("colspan", (this.model.columns.length - this._hiddenColumns.length - hideCount));
                } else if (this.model.detailsTemplate != null)
                    $editTr.find(".e-editcell").prop("colspan", (this.model.columns.length - this._hiddenColumns.length - hideCount + 1));
                else {
                    if (this.model.scrollSettings.frozenColumns > 0) {
                        $editTr.find(".e-editcell").last().prop("colspan", (this.model.columns.length - this.model.scrollSettings.frozenColumns - $tempLastTR.find("td").not(":visible").length - hideCount));
                        frozenColSpan = this.model.scrollSettings.frozenColumns;
                    }
                    $editTr.find(".e-editcell").first().prop("colspan", (frozenColSpan - $tempFirstTR.find("td").not(":visible").length - hideCount));

                }
                this._refreshUnboundTemplate($editTr.find(".gridform"));
                this._gridRows = this.getContentTable().first().find(".e-rowcell").closest("tr").toArray();
                if (this.model.scrollSettings.frozenColumns > 0)
                    this._gridRows = [this._gridRows, this.getContentTable().last().find(".e-rowcell").closest("tr").toArray()];
            }
            else if (this.model.editSettings.editMode == "inlineform" || this.model.editSettings.editMode == "inlineformtemplate") {
                temp.innerHTML = this.model.editSettings.editMode == "inlineform" ? $.render[this._id + "_JSONDialogEditingTemplate"](args.data) : $.render[this._id + "_JSONdialogTemplateMode"](args.data);
                var $select = $(temp).find('select.e-field');
                for (var i = 0; i < $select.length; i++)
                    $select.eq(i).val(args.data[$select[i].name]);
                var hideCount = !this.model.groupSettings.showGroupedColumn ? this.model.groupSettings.groupedColumns.length : 0;
                var detailCount = 0;
                var tr = ej.buildTag('tr');
                var td = ej.buildTag('td');
                tr.addClass("e-addedrow");
                td.addClass("e-inlineformedit e-editcell");
                td.html($(temp).children());
                tr.append(td);
                var hideCount = !this.model.groupSettings.showGroupedColumn ? this.model.groupSettings.groupedColumns.length : 0;
                if (this.model.groupSettings.groupedColumns.length) {
                    for (var i = 0; i < this.model.groupSettings.groupedColumns.length; i++) {
                        tr.prepend(ej.buildTag("td.e-indentcell"));
                    }
                } else
                    tr.find("td.e-editcell").prop("colspan", (this.model.columns.length - this._hiddenColumns.length - hideCount));
                if (this.model.scrollSettings.frozenColumns > 0) {
                    var $trClone = tr.clone(), $divs = td.find(".gridform").children();
                    $trClone.find("td").empty().prop("colSpan", this.model.scrollSettings.frozenColumns - this._getHiddenCount($divs.slice(0, this.model.scrollSettings.frozenColumns)));
                    td.prop("colSpan", this.model.columns.length - this.model.scrollSettings.frozenColumns - this._getHiddenCount($divs.slice(this.model.scrollSettings.frozenColumns)));
                    this.getContentTable().first().find('tbody').first().prepend($trClone);
                    this.getContentTable().last().find('tbody').first().prepend(tr);
                }
                else {
                    td.prop("colspan", this.model.columns.length - this._hiddenColumns.length - hideCount + detailCount);
                    if (this.model.currentViewData.length == 0 || this.getContentTable().find('td.e-rowcell').length == 0)
                        this.getContentTable().find('tr').first().replaceWith($(tr));
                    else
                        if (this.model.allowPaging && this.model.pageSettings.pageSize <= this.model.currentViewData.length && this.model.groupSettings.groupedColumns.length == 0)
                            this.getContentTable().get(0).lastChild.removeChild(this.getContentTable().get(0).lastChild.lastChild);
                    if (this.model.editSettings.rowPosition == "top")
                        this.getContentTable().first().find('tbody').first().prepend(tr);
                    else if (this.model.editSettings.rowPosition == "bottom")
                        this.getContentTable().first().find('tbody').first().append(tr);
                }
                
                if (this.model.detailsTemplate != null && $(this.getContentTable().get(0).lastChild.lastChild).children('.e-detailrowexpand').length)
                    this.getContentTable().get(0).lastChild.removeChild(this.getContentTable().get(0).lastChild.lastChild);
                $("#" + this._id + "_inlineFormTitle").text(this._getLocalizedLabels("AddFormTitle"));
                this._refreshUnboundTemplate($("#" + this._id + "EditForm"));
                this._gridRows = this.getContentTable().first().find(".e-rowcell,.e-inlineformedit").closest("tr").toArray();
                if (this.model.scrollSettings.frozenColumns > 0)
                    this._gridRows = [this._gridRows, this.getContentTable().last().find(".e-rowcell").closest("tr").toArray()];
            }
            else {
                $(temp).addClass("e-addedrow");
                temp.innerHTML = this.model.editSettings.editMode == "dialog" || this.model.editSettings.editMode == "externalform" ? $.render[this._id + "_JSONDialogEditingTemplate"](args.data) : $.render[this._id + "_JSONdialogTemplateMode"](args.data);
                var $select = $(temp).find('select.e-field');
                for (var i = 0; i < $select.length; i++)
                    $select.eq(i).val(args.data[$select[i].name]);
                if (this.model.editSettings.editMode == "dialog" || this.model.editSettings.editMode == "dialogtemplate") {
                    $("#" + this._id + "_dialogEdit").html($(temp));
                    var model = {};
                    model.cssClass = this.model.cssClass;
                    model.width = "auto";
                    model.enableResize = this.phoneMode;
                    model.content = "#" + this._id;
                    model.enableModal = true;
                    model.close = $.proxy(this._buttonClick, this);
                    model.enableRTL = this.model.enableRTL;
                    model.allowKeyboardNavigation = false;
                    model.title = this._getLocalizedLabels("AddFormTitle");
                    $("#" + this._id + "_dialogEdit").ejDialog(model);
                    $("#" + this._id + "_dialogEdit").ejDialog("open");
                }
                else {
                    $("#" + this._id + "_externalEdit").css("display", "block").css('z-index', this._maxZindex() + 1);
                    $(".e-externalformedit").html($(temp));
                    $("#" + this._id + "_eFormHeader").find(".e-form-title").text(this._getLocalizedLabels("AddFormTitle"));
                    this._externalFormPosition();
                }
            }
            if (this.model.allowPaging) {
                if (this.model.filterSettings.filteredColumns.length)
                    this.getPager().ejPager({ totalRecordsCount: this._searchCount == null ? this._filteredRecordsCount : this._searchCount, currentPage: this._currentPage() });
                else
                    this.getPager().ejPager({ totalRecordsCount: this._searchCount == null ? this._gridRecordsCount : this._searchCount, currentPage: this._currentPage() });
                this._refreshGridPager();
            }
        },
        editFormValidate: function () {
            if ($.isFunction($.validator)) {
                if (this.model.scrollSettings.frozenColumns > 0) {
                    var forms = this.element.find(".gridform");
                    return forms.length > 1 ? forms.eq(0).validate().form() && forms.eq(1).validate().form() : forms.validate().form();
                }
                return $("#" + this._id + "EditForm").validate().form();
            }
            return true;
        },
        _refreshAltRow: function () {
            var $gridRows = this.getContentTable().get(0).rows;
            for (var r = 0; r < $gridRows.length; r++) {
                var $row = $($gridRows[r]);
                $row.hasClass("e-alt_row") && $row.removeClass("e-alt_row");
                if ($row.index() % 2 != 0)
                    $row.addClass("e-alt_row");
            }
        },
        _editCompleteAction: function (args) {
            var $form = this.element.find(".gridform");
            this.model.isEdit = true;
            this.setWidthToColumns();
            if (ej.Grid.Actions.Add == args.requestType) {
                $form.find(".e-field:disabled").not(".e-identity").removeAttr("disabled").removeClass("e-disable");
                for (var i = 0; i < this.model.groupSettings.groupedColumns.length - 1; i++)
                    $form.find("colgroup").prepend(this._getIndentCol());
            }
            if (this._tdsOffsetWidth.length == 0 || this.model.groupSettings.groupedColumns.length)
                this._setoffsetWidth();
            this.model.editSettings.editMode != "dialogtemplate" && this._refreshEditForm(args);
            if (this.model.scrollSettings.frozenColumns > 0 && (this.model.editSettings.editMode == "inlineform" || this.model.editSettings.editMode == "inlineformtemplate")) {
                if (args.requestType == "beginedit")
                    args.row.eq(0).next().find("td").height(args.row.eq(1).next().find("td").height());
                else
                    this.getContentTable().first().find("tr").first().find("td").height(this.getContentTable().last().find("tr").first().find("td").height());
            }
            if (this.model.scrollSettings.frozenRows > 0 && args.requestType == "beginedit")
                this._initFrozenRows();
            if ($.isFunction($.validator))
                this._initValidator();
        },
        _refreshEditForm: function (args) {
            var form = this.model.scrollSettings.frozenColumns > 0 ? this.element.find(".gridform") : document.getElementById(this._id + "EditForm");
            var elementFocused = false,columnIndex;
            var $formElement = $(form).find("input,select"), percent = 86;
            if (this._isUnboundColumn || this.getContentTable().find(".e-templatecell") != null)
                $formElement = $formElement.filter(function () { return (!$(this).closest("td").hasClass("e-unboundcell") && !$(this).closest("td").hasClass("e-templatecell")) })
            for (var i = 0; i < $formElement.length; i++) {
                var $element = $formElement.eq(i);
                var inputWidth, column = this.getColumnByField($element.prop("name"));
                if (this.model.editSettings.editMode == "externalform" || this.model.editSettings.editMode == "externalformtemplate" || this.model.editSettings.editMode == "inlineform" || this.model.editSettings.editMode == "inlineformtemplate")
                    $element.parent().css("width", ej.dataUtil.max(this._tdsOffsetWidth) + "px");
                if (column != null)
                    columnIndex = $.inArray(column, this.model.columns);
                if (this.model.editSettings.editMode == "batch") {
                    percent = 95;
                }
                else if (this.model.editSettings.editMode == "normal")
                    percent = 96;
                inputWidth = this._tdsOffsetWidth[i] * (percent / 100);
                if (column !=null && columnIndex !== undefined && (columnIndex < this.model.columns.length && this.model.columns[columnIndex].editTemplate)) {
                    var temp = { rowdata: this._currentJsonData[this._bulkEditCellDetails.rowIndex], column: this.model.columns, element: $element };
                    var temp1 = this.model.columns[columnIndex].editTemplate.write;
                    if (!ej.isNullOrUndefined(args) && args.requestType == "add") temp.rowdata = {};
                    if (typeof temp1 == "string")
                        temp1 = ej.util.getObject(temp1, window);
                    temp1(temp);
                }
                else if ($element.hasClass("e-numerictextbox")) {
                    var params = { width: inputWidth }, value = $element.val(), customParams = this.getColumnByField($element.prop("name"));
                    if (customParams["width"] && typeof customParams["width"] == "string" && customParams["width"].indexOf("%") != -1 && (this.model.editSettings.editMode == "normal" || this.model.editSettings.editMode == "batch"))
                        params.width = "100%";
                    params.enableRTL = this.model.enableRTL;
                    params.showSpinButton = true;
                    params.cssClass = this.model.cssClass;
                    if (value.length)
                        params.value = parseFloat(value);
                    if ($element.hasClass("e-disable"))
                        params.enabled = false;
                    if (!ej.isNullOrUndefined(customParams["editParams"]))
                        $.extend(params, customParams["editParams"]);
                    $element.ejNumericTextbox(params);
                    $element.prop("name", $element.prop("name").replace(this._id, ""));
                } else if ($element.hasClass("e-datepicker")) {
                    var params = { width: inputWidth }, column = this.getColumnByField($element.prop("name"));
                    if (column["width"] && typeof column["width"] == "string" && column["width"].indexOf("%") != -1 && (this.model.editSettings.editMode == "normal" || this.model.editSettings.editMode == "batch"))
                        params.width = "100%";
                    params.enableRTL = this.model.enableRTL;
                    params.cssClass = this.model.cssClass;
                    params.displayDefaultDate = true;
                    params.showPopupButton = false;
                    params.watermarkText = this._getLocalizedLabels("DatePickerWaterMark");
                    if ($element.val().length)
                        params.value = new Date($element.val());
                    if ($element.hasClass("e-disable"))
                        params.enabled = false;
                    if (column["format"] !== undefined && column.format.length > 0) {
                        var toformat = new RegExp("\\{0(:([^\\}]+))?\\}", "gm");
                        var formatVal = toformat.exec(column.format);
                        params.dateFormat = formatVal[2];
                    }
                    if (!ej.isNullOrUndefined(column["editParams"]))
                        $.extend(params, column["editParams"]);
                    $element.ejDatePicker(params);
                }
                else if ($element.hasClass("e-datetimepicker")) {
                    var column = this.getColumnByField($element.prop("name")),
                        params = {
                            width: inputWidth,
                            enableRTL: this.model.enableRTL,
                            cssClass: this.model.cssClass,
                            showPopupButton: false
                        };
                    if (column["width"] && typeof column["width"] == "string" && column["width"].indexOf("%") != -1 && (this.model.editSettings.editMode == "normal" || this.model.editSettings.editMode == "batch"))
                        params.width = "100%";
                    if ($element.val().length)
                        params.value = new Date($element.val());
                    if ($element.hasClass("e-disable"))
                        params.enabled = false;
                    if (column["format"] !== undefined && column.format.length > 0) {
                        var toformat = new RegExp("\\{0(:([^\\}]+))?\\}", "gm");
                        var formatVal = toformat.exec(column.format);
                        params.dateTimeFormat = formatVal[2];
                    }
                    if (!ej.isNullOrUndefined(column["editParams"]))
                        $.extend(params, column["editParams"]);
                    $element.ejDateTimePicker(params);
                }
                else if ($element.hasClass("e-dropdownlist")) {
                    var column = this.getColumnByField($element.prop("name")),
                        params = {
                            width: inputWidth,
                            enableRTL: this.model.enableRTL
                        };
                    if (column["width"] && typeof column["width"] == "string" && column["width"].indexOf("%") != -1 && (this.model.editSettings.editMode == "normal" || this.model.editSettings.editMode == "batch"))
                        params.width = "100%";
                    if (!ej.isNullOrUndefined(column["editParams"]))
                        $.extend(params, column["editParams"]);
                    $element.ejDropDownList(params);
                    $element.ejDropDownList("setSelectedValue", args.requestType == "add" ? $element.val("") : $element.val());
                    if ($element.hasClass("e-disable"))
                        $element.ejDropDownList("disable");
                }
                    //else if ($element.hasClass("checkbox"))
                    //{
                    //    var value = $element.prop("checked");
                    //    $element.ejCheckBox({
                    //        id: $element[0].id,
                    //        checked: value
                    //    });
                    //}
                else {
                    switch ($element.prop('tagName')) {
                        case "INPUT":
                            if ($element.attr("type") != "checkbox") {
                                $element.css("text-align", $element.attr("name") != null && this.getColumnByField($element.attr("name")) != null ?
                                this.getColumnByField($element.attr("name")).textAlign : "center");
                                if (this.model.editSettings.editMode == "batch"){
                                    $element.width('100%').height(28);
									if (ej.browserInfo().name == "msie" && parseInt(ej.browserInfo().version, 10) == 8)
									   $element.css("line-height", "22px");
							    }
                                else if (this.model.editSettings.editMode == "normal"){
                                    $element.css('width', '100%').css("height", "30px");
									if (ej.browserInfo().name == "msie" && parseInt(ej.browserInfo().version, 10) == 8)
									   $element.css("line-height", "24px");
								}	
                                else{
                                    $element.outerWidth(inputWidth).height(28);
									if (ej.browserInfo().name == "msie" && parseInt(ej.browserInfo().version, 10) == 8)
									   $element.css("line-height", "26px");
								}

                            }
                            else
                                $element.width(inputWidth > 0 ? ($element.width() > inputWidth ? inputWidth : $element.width()) : 1);
                            break;
                        case "SELECT":
                            $element.width(inputWidth).height(28);
                            break;
                    }
                }
                if (!$element.is(":disabled") && !elementFocused && (!$element.is(":hidden") || typeof $element.data("ejDropDownList") == "object")) {
                    this._focusElements($element.closest('td'));
                    elementFocused = true;
                }
            }

        },
        _focusElements: function ($currentCell) {
            if ($currentCell.length) {
                var $childElem = $currentCell.children();
                if ($childElem[0].tagName.toLowerCase() == "select" || $childElem[0].tagName.toLowerCase() == "input") {
                    $childElem.focus().select();
                    $childElem[0].focus();
                }
                else if ($childElem.find(".e-field.e-dropdownlist").length)
                    $childElem.find(".e-ddl").focus();
                else
                    $childElem.find('input:visible,select').first().select().focus();
            }
        },
        _renderToolBar: function () {
            var $div = ej.buildTag('div.e-gridtoolbar', "", {}, { id: this._id + "_toolbarItems" });
            var $ul = ej.buildTag("ul");
            (!ej.isNullOrUndefined(this.model.toolbarSettings.toolbarItems) && this.model.toolbarSettings.toolbarItems.length) && this._renderLi($ul);
            $div.append($ul);
            var $customUl = ej.buildTag("ul");
            $div.append($customUl);
            (!ej.isNullOrUndefined(this.model.toolbarSettings.customToolbarItems) && this.model.toolbarSettings.customToolbarItems.length) && this._renderCustomLi($customUl);
            var model = {};
            model.click = this._toolBarClick;
            model.cssClass = this.model.cssClass;
            model.enableRTL = this.model.enableRTL;
            model.enableSeprator = false;
            $div.ejToolbar(model);
            $div.ejToolbar("disableItem", this._disabledToolItems);
            this._disabledToolItems = $();
            return $div;
        },
        _renderCustomLi: function ($ul) {
            for (var i = 0; i < this.model.toolbarSettings.customToolbarItems.length; i++) {
                var $li = ej.buildTag("li", "", {}, { title: this.model.toolbarSettings.customToolbarItems[i] });
                switch (typeof this.model.toolbarSettings.customToolbarItems[i]) {
                    case "string":
                        var $item = ej.buildTag("a.e-toolbaricons e-icon", "", {}).addClass(this.model.toolbarSettings.customToolbarItems[i]);
                        break;
                    case "object":
                        $li.attr("title", this.model.toolbarSettings.customToolbarItems[i]["templateID"].replace("#", ""));
                        var $item = $(this.model.toolbarSettings.customToolbarItems[i]["templateID"]).hide().html();
                        break;
                }
                $li.html($item);
                $ul.append($li);
            }
        },
        _renderLi: function ($ul) {
            if ($.isFunction(window.matchMedia)) {
                if (this.model.enableResponsiveRow && window.matchMedia("(max-width: 320px)")) {
                    var searchIndex = this.model.toolbarSettings.toolbarItems.indexOf('search');
                    searchIndex != -1 && this.model.toolbarSettings.toolbarItems.splice(searchIndex, 1);
                    if (this.model.allowFiltering)
                        this.model.toolbarSettings.toolbarItems.push('responsiveFilter');
                    if (this.model.allowSorting) {
                        this.model.toolbarSettings.toolbarItems.push('responsiveSorting');
                    }
                    searchIndex != -1 && this.model.toolbarSettings.toolbarItems.push('search');
                }
            }
            for (var i = 0; i < this.model.toolbarSettings.toolbarItems.length; i++) {
                var $li = ej.buildTag("li", "", {}, { id: this._id + "_" + this.model.toolbarSettings.toolbarItems[i], title: this._getLocalizedLabels(this.model.toolbarSettings.toolbarItems[i].slice(0, 1).toUpperCase() + this.model.toolbarSettings.toolbarItems[i].slice(1)), "tabindex": "0" });
                this._renderLiContent($li, this.model.toolbarSettings.toolbarItems[i]);
                $ul.append($li);
            }
        },
        _renderLiContent: function ($li, item) {
            var $a, $input;
            switch (item) {
                case "add":
                    $a = ej.buildTag("a.e-addnewitem e-toolbaricons e-icon e-addnew", "", {});
                    break;
                case "edit":
                    $a = ej.buildTag("a.e-edititem e-toolbaricons e-icon e-edit", "", {});
                    break;
                case "delete":
                    $a = ej.buildTag("a.e-deleteitem e-toolbaricons e-icon e-delete", "", {});
                    break;
                case "update":
                    $a = ej.buildTag("a.e-saveitem e-toolbaricons e-disabletool e-icon e-save", "", {});
                    this._disabledToolItems.push($li.get(0));
                    break;
                case "cancel":
                    $a = ej.buildTag("a.e-cancel e-toolbaricons e-disabletool e-icon e-gcancel", "", {});
                    this._disabledToolItems.push($li.get(0));
                    break;
				
                case "search":
                    $a = ej.buildTag("a.e-searchitem e-toolbaricons e-disabletool e-icon e-searchfind", "", {});
                    if (!this.model.enableResponsiveRow) {
                        $input = ej.buildTag("input.e-ejinputtext", "", {}, { type: "text" });
                        $li.append($input);
                    }
                    this.model.allowSearching = true;
                    break;
				case "printGrid":
					 $a = ej.buildTag("a.e-print e-toolbaricons e-icon", "", {});
					 break;
                case "excelExport":
                    $a = ej.buildTag("a.e-toolbaricons e-excelIcon e-icon", "", {});
                    break;
                case "wordExport":
                    $a = ej.buildTag("a.e-toolbaricons e-wordIcon e-icon", "", {});
                    break;
                case "pdfExport":
                    $a = ej.buildTag("a.e-toolbaricons e-pdfIcon e-icon", "", {});
                    break;
                case "responsiveFilter":
                    $a = ej.buildTag("a.e-toolbaricons e-filterset e-icon", "", {});
                    break;
                case "responsiveSorting":
                    $a = ej.buildTag("a.e-toolbaricons e-respponsiveSorting e-icon", "", {});
                    break;
            }
            $li.append($a);

        },
        _toolBarClick: function (Sender) {
            var $gridEle = $(this.itemsContainer).closest(".e-grid"), gridInstance = $gridEle.ejGrid("instance"), gridId = $gridEle.attr('id');
            if (Sender.event == undefined && Sender.target.tagName == "INPUT" && Sender.currentTarget.id == gridId + "_search")
                return;
            $.isFunction($.fn.ejDatePicker) && $("#" + gridId + "EditForm").find(".e-datepicker").ejDatePicker("hide");
            var currentTarget = Sender.currentTarget; var target = Sender.target;
            var args = { itemName: currentTarget.title, itemId: currentTarget.id, currentTarget: currentTarget, target: target, itemIndex: $(currentTarget).index(), itemCurrentTarget: currentTarget.outerHTML, gridModel:JSON.stringify(gridInstance.model), itemTarget: target.outerHTML, toolbarData: Sender };
            if ($gridEle.ejGrid("instance")._trigger("toolbarClick", args))
                return;
            switch (args.itemId) {
                case gridId + "_add":
                    gridInstance._toolbarOperation(gridId + "_add");
                    break;
                case gridId + "_edit":
                    gridInstance._toolbarOperation(gridId + "_edit");
                    break;
                case gridId + "_delete":
                    gridInstance._toolbarOperation(gridId + "_delete");
                    break;
                case gridId + "_update":
                    gridInstance._toolbarOperation(gridId + "_update");
                    break;
                case gridId + "_cancel":
                    if (gridInstance.model.editSettings.editMode == "batch")
                        gridInstance.cancelEdit();
                    else
                        gridInstance._toolbarOperation(gridId + "_cancel");
                    break;
                case gridId + "_search":
                    if (gridInstance.model.enableResponsiveRow) {
                        if (ej.isNullOrUndefined(gridInstance.element.find('.e-responsesearch')[0])) {
                            var $div = ej.buildTag('div.e-gridtoolbar', "", {}, { id: this._id + "_toolbarItems" });
                            var $ul = ej.buildTag('div.e-responsesearch', '', { 'width': '95%', 'height': '38px', 'margin-top': '7px', 'margin-left': '6px' });
                            var $span = ej.buildTag('span.e-ttoltxt', '', { width: '98%', 'margin-left': '2%' }, { id: gridInstance._id + "_search" });
							$a = ej.buildTag("span.e-searchitem e-toolbaricons e-disabletool e-icon e-searchfind", "", { 'position': 'absolute', 'margin-left': '-7%', 'margin-top': '1%' });
                            var $input = ej.buildTag("input.e-ejinputtext", "", { width: '97%', 'height': '30px' }, { type: "search", id: gridInstance._id + "_search" });
                            $span.append($input);
                            $span.append($a);
                            $ul.append($span);
                            $div.append($ul);
                            $div.ejToolbar({
                                click: function (sender) {
                                    gridInstance._toolbarOperation(gridId + "_search", $(sender.currentTarget).find("input").val());
                                }
                            });
                            $input.bind('keyup', function (e) {
                                if ($input.val() != '') {
                                    $a.removeClass('e-searchfind');
                                    $a.addClass('e-cancel')
                                }
                                else {
                                    $a.removeClass('e-cancel');
                                    $a.addClass('e-searchfind');
                                }
                            });
                            $a.click(function () {
                                if ($a.hasClass('e-cancel')) {
                                    $input.val('');
                                    $a.removeClass('e-cancel');
                                    $a.addClass('e-searchfind');
                                }
                            })
                            $div.insertBefore(gridInstance.getHeaderContent());
                        }
                        else {
                            if (gridInstance.element.find('.e-responsesearch').css('display') == 'block')
                                gridInstance.element.find('.e-responsesearch').css('display', 'none');
                            else
                                gridInstance.element.find('.e-responsesearch').css('display', 'block');
                        }
                    }
                    else
                        gridInstance._toolbarOperation(gridId + "_search", $(Sender.currentTarget).find("input").val());
                    break;
				case gridId + "_printGrid":
                    gridInstance._toolbarOperation(gridId + "_printGrid");
                    break;
                case gridId + "_excelExport":
                    gridInstance._toolbarOperation(gridId + "_excelExport");
                    break;
                case gridId + "_wordExport":
                    gridInstance._toolbarOperation(gridId + "_wordExport");
                    break;
                case gridId + "_pdfExport":
                    gridInstance._toolbarOperation(gridId + "_pdfExport");
                    break;
                case gridId + "_responsiveFilter":
                    gridInstance._toolbarOperation(gridId + "_responsiveFilter");
                    break;
                case gridId + "_responsiveSorting":
                    gridInstance._toolbarOperation(gridId + "_responsiveSorting");
                    break;
            }
            return false;
        },

        _toolbarOperation: function (operation, searchEle) {
            var $gridEle = this.element, gridObject = $gridEle.ejGrid("instance"), batchEnable = gridObject.model.editSettings.editMode == "batch", gridId = $gridEle.attr('id'), fieldName;
            gridObject._exportTo = gridObject["export"];
            switch (operation) {
                case gridId + "_add":
                    if (batchEnable)
                        gridObject._bulkAddRow();
                    else
                        gridObject._startAdd();
                    break;
                case gridId + "_edit":
                    if (batchEnable) {
					    if (gridObject._bulkEditCellDetails.columnIndex == -1) {
                            alert(this._getLocalizedLabels("EditOperationAlert"));
                            return;
                        }
                        fieldName = gridObject.model.columns[gridObject._bulkEditCellDetails.columnIndex].field;
                        fieldName && gridObject.editCell(gridObject._bulkEditCellDetails.rowIndex, fieldName);
                    }
                    else
                        gridObject.startEdit();
                    break;
                case gridId + "_delete":
                    if (this.model.editSettings.showDeleteConfirmDialog)
                        this._confirmDialog.find(".e-content").html(this._getLocalizedLabels("ConfirmDelete")).end().ejDialog("open");
                    else
                        batchEnable ? this._bulkDelete() : this._deleteRow();
                    break;
                case gridId + "_update":
                    if (batchEnable)
                        this.model.editSettings.showConfirmDialog ? this._confirmDialog.find(".e-content").html(this._getLocalizedLabels("BatchSaveConfirm")).end().ejDialog("open") : this.batchSave();
                    else
                        gridObject.endEdit();
                    break;
                case gridId + "_cancel":
                    if (batchEnable) {
                        if ($("#" + gridId + "ConfirmDialog").ejDialog("isOpened") === true)
                            this._triggerConfirm();
                        else
                            gridObject.cancelEditCell();
                    }
                    else
                        gridObject.cancelEdit();
                    break;
                case gridId + "_search":
                    $gridEle.ejGrid("search", searchEle);
                    break;
				case gridId + "_printGrid":
                    this.print();
                    break;
                case gridId + "_excelExport":
                    gridObject._exportTo(gridObject.model.exportToExcelAction, 'excelExporting', gridObject.model.allowMultipleExporting);
                    break;
                case gridId + "_wordExport":
                    gridObject._exportTo(gridObject.model.exportToWordAction, 'wordExporting', gridObject.model.allowMultipleExporting);
                    break;
                case gridId + "_pdfExport":
                    gridObject._exportTo(gridObject.model.exportToPdfAction, 'pdfExporting', gridObject.model.allowMultipleExporting);
                    break;
                case gridId + "_responsiveFilter":
                    $("#responsiveFilter").css('display', 'block');
                    setTimeout(function () { gridObject.element.css('display', 'none'), 0 });
                    break;
                case gridId + "_responsiveSorting":
                    this._sortColumns = []; this._removeSortCol = []
                    for (var i = 0; i < this.model.sortSettings.sortedColumns.length; i++) {
                        this._sortColumns.push({ field: this.model.sortSettings.sortedColumns[i].field, direction: this.model.sortSettings.sortedColumns[i].direction });
                    }
                    if (ej.isNullOrUndefined($("#responsiveSort")[0])) {
                        var $dlg = $("#responsiveFilter").clone().css('display', 'block');
                        $dlg.insertAfter(this.element);
                        $dlg.attr('id', 'responsiveSort');
                        gridObject._setSortingButton();
                        var $btnDiv = ej.buildTag('div.btnContainer', '', { width: '100%', 'bottom': '0px', 'position': 'absolute' });
                        var $inputOk = ej.buildTag('input.e-resposnsiveFilterBtnLeft', 'OK', { 'width': '45.6%' });
                        var $inputCancel = ej.buildTag('input.e-resposnsiveFilterBtnRight', 'Cancel', { 'width': '46%' });
                        var $closeIcon = ej.buildTag('div.e-resFIlterRigthIcon');
                        var $cspanIcon = ej.buildTag('span.e-icon e-responsiveClose e-resIcon');
                        $dlg.find('.e-resFilterleftIcon').remove();
                        $dlg.find('.labelRes').text('Sorting');
                        $dlg.find('.e-resFilterDialogHeaderDiv').append($closeIcon.append($cspanIcon))
                        $dlg.find('.e-resFilterDialogHeaderDiv').find('.e-resFIlterRigthIcon').click(function (e) {
                            $("#responsiveSort").css('display', 'none');
                            gridObject.element.css('display', 'block');
                        })
                        var $divIcon = ej.buildTag('div.e-resFilterleftIcon', '', { 'margin-top': '3%' });
                        var $spanIcon = ej.buildTag('span.e-icon e-resIcon e-responsiveSortClear');
                        $divIcon.click(function () {
                            $dlg.find('.e-responsivefilterColDiv').find('.e-button').remove();
                            gridObject._setSortingButton(true);
                            for (var i = 0; i < gridObject._sortColumns.length; i++) {
                                if (gridObject._removeSortCol.indexOf(gridObject._sortColumns[i].field) == -1)
                                    gridObject._removeSortCol.push(gridObject._sortColumns[i].field);
                            }
                            gridObject._sortColumns = [];
                        });
                        $dlg.find('.e-resFilterDialogHeaderDiv').prepend($divIcon.append($spanIcon));
                        $dlg.append($btnDiv);
                        $btnDiv.append($inputOk).append($inputCancel);
                        $inputOk.ejButton({
                            text: 'OK', type: 'button',
                            click: $.proxy(this._resSortOperation, this)
                        })
                        $inputCancel.ejButton({
                            text: 'Cancel', type: 'button',
                            click: function () {
                                $("#responsiveSort").css('display', 'none');
                                gridObject.element.css('display', 'block');
                                gridObject._sortColumns = [];
                                $dlg.find('.e-responsivefilterColDiv').find('.e-button').remove();
                                gridObject._setSortingButton();
                            }
                        })
                    }
                    else {
                        $("#responsiveSort").find('.e-responsivefilterColDiv').find('.e-button').remove();
                        this._setSortingButton();
                    }
                    $("#responsiveSort").find('.e-responsivefilterColDiv').find('.e-filternone').remove();
                    $("#responsiveSort").css('display', 'block');
                    setTimeout(function () { gridObject.element.css('display', 'none'), 0 });
                    break;
            }
            return false;
        },
        _resSortOperation: function (sender) {
            for (var i = 0; i < this._removeSortCol.length; i++)
                this.removeSortedColumns(this._removeSortCol[i]);
            for (var i = 0 ; i < this._sortColumns.length; i++) {
                if (this.model.allowMultiSorting)
                    this.multiSortRequest = true;
                this.sortColumn(this._sortColumns[i].field, this._sortColumns[i].direction);
            }
            $("#responsiveSort").css('display', 'none');
            this.element.css('display', 'block');
        },
        _setSortingButton: function (clear) {
            var $sortDiv = $("#responsiveSort");
            var gridObj = this;
            this._sortCols = [];
            if (ej.isNullOrUndefined($sortDiv.find('.e-responsivefilterColDiv').find('.e-button')[0])) {
                $sortDiv.find('.e-responsivefilterColDiv').each(function (index, object) {
                    var $btnDiv = ej.buildTag('div', '', { 'float': 'right', 'margin-right': '2%', 'margin-top': '-1%' })
                    var fieldName = $(object).attr('ej-MappingName');
                    var $but = ej.buildTag('button#' + fieldName + ".e-sortingBtn", '');
                    $(object).append($btnDiv.append($but));
                    var btnText = 'None', icon = '';
                    if (!clear) {
                        for (var sortC = 0; sortC < gridObj.model.sortSettings.sortedColumns.length; sortC++) {
                            if (gridObj.model.sortSettings.sortedColumns[sortC].field == fieldName) {
                                btnText = gridObj.model.sortSettings.sortedColumns[sortC].direction == 'ascending' ? 'Ascending' : 'Descending';
                                icon = btnText == 'Ascending' ? 'e-resIcon e-respponsiveSortingAsc' : 'e-resIcon e-respponsiveSortingDesc';
                            }
                        }
                        if (icon != '') {
                            $but.ejButton({
                                text: btnText, type: 'button',
                                height: 28,
                                width: 120,
                                cssClass: 'e-resSortIconBtn',
                                id: fieldName,
                                prefixIcon: icon,
                                imagePosition: "imageright",
                                contentType: "textandimage",
                                showRoundedCorner: true,
                                click: $.proxy(gridObj._resSortButClick, gridObj)
                            })
                        }
                        else {
                            $but.ejButton({
                                text: btnText, type: 'button',
                                height: 28,
                                cssClass: 'e-resSortIconBtn',
                                width: 120,
                                id: fieldName,
                                showRoundedCorner: true,
                                click: $.proxy(gridObj._resSortButClick, gridObj)
                            })
                        }
                    }
                    else {
                        $but.ejButton({
                            text: btnText, type: 'button',
                            height: 28,
                            width: 120,
                            id: fieldName,
                            showRoundedCorner: true,
                            click: $.proxy(gridObj._resSortButClick, gridObj)
                        })
                    }
                });
            }
        },
        _sortOperation: function (field, direction) {
            if (this._removeSortCol.indexOf(field) != -1) {
                this._sortColumns.splice(this._removeSortCol.indexOf(field), 1);
            }
            for (var column = 0; column < this._sortColumns.length; column++) {
                if (this._sortColumns[column]["field"] == field)
                    break;
            }
            if (this.model.allowMultiSorting) {
                this.multiSortRequest = true;
                if (column != -1) {
                    this._sortColumns.splice(column, 1);
                    this._removeSortCol.push(field);
                }
            }
            else {
                $("#responsiveFilter").find('.e-responsivefilterColDiv').find('.e-button').removeClass('e-disable');
                var $divColg = $("#responsiveFilter").find('.e-responsivefilterColDiv').not(".e-responsivefilterColDiv[ej-mappingname='" + field + "']");
                var $btn = $divColg.find('.e-button').addClass('e-disable');
                $btn.text('None');
                if (this._sortColumns.length > 0) {
                    this._removeSortCol.push(this._sortColumns[0].field);
                    this._sortColumns = [];
                }
            }
            this._sortColumns.push({ field: field, direction: direction });
        },
        _resSortButClick: function (sender) {
            var text = '', prefixIcon = '', fieldName = sender.model.id;
            var obj = $("#" + sender.model.id).ejButton('instance');
            if (sender.model.text == 'None') {
                text = 'Ascending';
                prefixIcon = 'e-resIcon e-respponsiveSortingAsc';
                this._sortOperation(fieldName, 'ascending');
            }
            else if (sender.model.text == 'Ascending') {
                text = 'Descending';
                prefixIcon = 'e-resIcon e-respponsiveSortingDesc';
                this._sortOperation(fieldName, 'descending');
            }
            else {
                obj.model.text = 'None';
                obj.model.prefixIcon = '';
                obj.type = 'button';
                obj.model.contentType = "text";
                obj._render();
                for (var column = 0; column < this._sortColumns.length; column++) {
                    if (this._sortColumns[column]["field"] == fieldName)
                        break;
                }
                this._removeSortCol.push(fieldName);
                this._sortColumns.splice(column, 1);
                $("#responsiveFilter").find('.e-responsivefilterColDiv').find('.e-button').removeClass('e-disable');
                return;
            }
            obj.model.text = text; obj.model.prefixIcon = 'e-resIcon ' + prefixIcon; obj.model.imagePosition = "imageright";
            obj.model.contentType = "textandimage"; obj._render();
        },
        renderDiaglogButton: function (form, tbody) {
            var btnId;
            if (this.model.editSettings.editMode == "externalform" || this.model.editSettings.editMode == "externalformtemplate")
                btnId = "EditExternalForm_";
            else if (this.model.editSettings.editMode == "inlineform" || this.model.editSettings.editMode == "inlineformtemplate") {
                btnId = "InlineEditForm_";
                var inlineTitleBar = ej.buildTag("div", "", "", { id: this._id + "_inlineFormTitle", 'class': "e-inlineform-titlebar" });
                inlineTitleBar.appendTo(tbody);
            }
            else
                btnId = "EditDialog_";
            var savebtn = ej.buildTag('input', "", { 'margin-left': '30px' }, { type: "button", id: btnId + this._id + "_Save" });
            savebtn.ejButton({ cssClass: this.model.cssClass, enableRTL: this.model.enableRTL, text: this._getLocalizedLabels("SaveButton"), width: "100" });
            var cancelbtn = ej.buildTag('input', "", { 'margin-left': '19px', 'margin-right': '13px' }, { type: "button", id: btnId + this._id + "_Cancel" });
            cancelbtn.ejButton({ cssClass: this.model.cssClass, enableRTL: this.model.enableRTL, text: this._getLocalizedLabels("CancelButton"), width: "100" });
            var btnDiv = (this.model.editSettings.editMode != "dialog" && this.model.editSettings.editMode != "dialogtemplate") ? ej.buildTag('div', "", "", { 'class': "e-editform-btn" }) : ej.buildTag('div');
            btnDiv.append(savebtn);
            btnDiv.append(cancelbtn);
            form.appendTo(tbody);
            if (this.model.editSettings.editMode != "dialog" && this.model.editSettings.editMode != "dialogtemplate")
                btnDiv.appendTo(tbody);
            else
                form.append(btnDiv);
            return tbody;
        },
        _externalFormPosition: function () {
            var pos = $(this.element).offset();
            var width = $(this.element).width();
            var height = $(this.element).height();
            var DivElement = $("#" + this._id + "_externalEdit");
            switch (this.model.editSettings.formPosition) {
                case "topright":
                    $(DivElement).find('.e-form-toggle-icon').removeClass('e-bottomleft').addClass('e-topright');
                    $(DivElement).css({ "left": (pos.left + width + 1) + "px", "top": pos.top + "px", "position": "absolute", "width": "290px" });
                    $("#" + this._id + "_eFormContent").height("auto");
                    break;
                case "bottomleft":
                    $(DivElement).find('.e-form-toggle-icon').removeClass('e-topright').addClass('e-bottomleft');
                    $(DivElement).css({ "left": (pos.left) + "px", "top": (pos.top + height + 1) + "px" });
                    $("#" + this._id + "_eFormContent").width("100%");
                    break;
            }
        },
        _setoffsetWidth: function () {
            var tds, $form = this.model.scrollSettings.frozenColumns > 0 ? this.element.find(".gridform") : $("#" + this._id + "EditForm");
            if (this._gridRecordsCount == 0 && this.model.editSettings.editMode != "batch")
                return;
            if (this.model.editSettings.editMode == "batch")
                tds = $form.closest("td");
            else if (this.model.editSettings.editMode == "inlineform" || this.model.editSettings.editMode == "inlineformtemplate" || this.model.editSettings.editMode == "externalform" || this.model.editSettings.editMode == "externalformtemplate")
                tds = $form.find(".e-rowcell").not(".e-unboundcell,.e-templatecell");
            else
                tds = $form.find("tr").find(".e-rowcell").not(".e-unboundcell,.e-templatecell");
            for (var i = 0; i < tds.length; i++)
                this._tdsOffsetWidth[i] = tds.get(i).offsetWidth;
        },
        _bulkChangesAcquired: function () {
            if (this.batchChanges.added.length > 0 || this.batchChanges.changed.length || this.batchChanges.deleted.length)
                return true;
            return false;
        },
        _renderDialog: function () {
            var $dialog = ej.buildTag("div.e-dialog e-dialog-content e-shadow e-widget-content", "", { display: "none" }, { id: this._id + "_dialogEdit" });
            return $dialog;
        },
        /**
         * Get the data of currently edited cell value in "batch" edit mode
         * @alias ejGrid#getCurrentEditCellData
         * @return jQuery
         * @example 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // Get data of currently edited cell value
         * gridObj.getCurrentEditCellData(); 
         * &lt;/script&gt;
         * @example 
         * &lt;script&gt;
         * // Get data of currently edited cell value
         * $("#Grid").ejGrid("getCurrentEditCellData");        
         * &lt;/script&gt;
         */
        getCurrentEditCellData: function () {
            if (this.model.isEdit && $("#" + this._id + "EditForm").length) {
                var $element = $("#" + this._id + this._bulkEditCellDetails.fieldName), cellValue;
                switch (this._bulkEditCellDetails.cellEditType) {
                    case ej.Grid.EditingType.String:
                        cellValue = $element.val();
                        break;
                    case ej.Grid.EditingType.Numeric:
                        cellValue = $element.ejNumericTextbox("getValue");
                        $element.ejNumericTextbox("getValue");
                        break;
                    case ej.Grid.EditingType.Dropdown:
                        cellValue = this._bulkEditCellDetails.isForeignKey ? { "value": $element.ejDropDownList("getSelectedValue"), "text": $element.ejDropDownList("getSelectedItem") } : $element.ejDropDownList("getSelectedValue");
                        break;
                    case ej.Grid.EditingType.Boolean:
                        cellValue = $element.is(':checked');
                        break;
                    case ej.Grid.EditingType.DatePicker:
                        cellValue = $element.ejDatePicker("model.value");
                        break;
                    case ej.Grid.EditingType.DateTimePicker:
                        cellValue = $element.ejDateTimePicker("model.value");
                        break;
                }
                if (typeof cellValue == "string" && cellValue.length && this.model.columns[this._bulkEditCellDetails.columnIndex].type == "number")
                    cellValue = parseFloat(cellValue);
                return cellValue;
            }
            return null;
        },
        cancelEditCell: function () {
            if (this.model.isEdit) {
                var tr = this.getRows()[this._bulkEditCellDetails.rowIndex], cellData = {}, cell;
                cellData[this._bulkEditCellDetails.fieldName] = this._bulkEditCellDetails.cellValue;
                if ($(tr).hasClass("e-insertedrow"))
                    cell = tr.cells[this._bulkEditCellDetails.columnIndex + this.model.groupSettings.groupedColumns.length];
                else
                    cell = tr.cells[this._bulkEditCellDetails.columnIndex];
                $(cell).removeClass("e-editedbatchcell").empty().html($($.templates[this._id + "_JSONTemplate"].render(cellData))[0].cells[this._bulkEditCellDetails.columnIndex].innerHTML);
                this.model.isEdit = false;
                this.element.focus();
            }
        },
        saveCell: function (preventSaveEvent) {
            if (this.model.isEdit) {
                if (!this.editFormValidate())
                    return true;
                var $form = $("#" + this._id + "EditForm"), $targetTR = $form.closest("tr"), $targetTD = $form.closest("td"), $toolBar, formattedValue
                , args = {}, column = this.model.columns[this._bulkEditCellDetails.columnIndex], $element = $("#" + this._id + this._bulkEditCellDetails.fieldName);
                args = {
                    columnName: column.field,
                    value: this.getCurrentEditCellData(),
                    rowData: this._bulkEditCellDetails.rowData,
                    previousValue: this._bulkEditCellDetails.cellValue,
                    columnObject: column,
                    cell: $targetTD,
                    isForeignKey: this._bulkEditCellDetails.isForeignKey
                };
                if (!preventSaveEvent && this._trigger("cellSave", args)) {
                    this._focusElements(args.cell);
                    this._bulkEditCellDetails.cancelSave = true;
                    return;
                }
                if (this._bulkEditCellDetails.cellEditType == "datetimepicker" || this._bulkEditCellDetails.cellEditType == "dropdownedit" || this._bulkEditCellDetails.cellEditType == "datepicker")
                    $element[$element.data("ejWidgets")[0]]("destroy");
                if (!ej.isNullOrUndefined(column.format)) {
                    formattedValue = this.formatting(column.format, args.isForeignKey ?
                                              (!isNaN(parseFloat(args.value.text)) && isFinite(args.value.text)
                                              ? parseFloat(args.value.text)
                                              : args.value.text) : args.value);
                    args.cell.empty().html(formattedValue);
                }
                if (this._bulkEditCellDetails.cellEditType == "edittemplate") {
                    var temp1 = column.editTemplate.read;
                    if (typeof temp1 == "string")
                        temp1 = ej.util.getObject(temp1, window);
                    args.value = temp1($element);
                    args.rowData[this._bulkEditCellDetails["fieldName"]] = args.value;
                    args.cell.empty().html(args.value);
                }
                else {
                    if (args.columnObject.type == "boolean" || args.columnObject.editType == "booleanedit") {
                        var cellData = {};
                        cellData[args.columnObject.field] = args.value;
                        args.cell.empty().html($($.templates[this._id + "_JSONTemplate"].render(cellData))[0].cells[this._bulkEditCellDetails.columnIndex].innerHTML);
                    }
                    else {
                        if (ej.isNullOrUndefined(column.format))
                            args.cell.empty().html(args.isForeignKey ? args.value.text : args.value)
                    }
                }
                var isValueModified = ((this._bulkEditCellDetails.cellEditType == "datepicker" || this._bulkEditCellDetails.cellEditType == "datetimepicker") && args.value instanceof Date && args.previousValue instanceof Date) ? (args.value.getTime() !== args.previousValue.getTime()) : (args.value !== args.previousValue);
                this.model.isEdit = false;
                if (isValueModified) {
                    this._enableSaveCancel();
                    args.cell.addClass("e-updatedtd e-icon e-gupdatenotify");
                    if (typeof args.rowData[this._bulkEditCellDetails["fieldName"]] == "string" && args.rowData[this._bulkEditCellDetails["fieldName"]].length)
                        args.rowData[this._bulkEditCellDetails["fieldName"]] = args.isForeignKey ? args.value.value.toString() : args.value.toString();
                    else
                        args.rowData[this._bulkEditCellDetails["fieldName"]] = args.isForeignKey ? (!isNaN(parseInt(args.value.value)) ? parseInt(args.value.value) : args.value.value) : args.value;
                    if ($.inArray(args.rowData, this.batchChanges.changed) == -1 && $.inArray(args.rowData, this.batchChanges.added) == -1)
                        this.batchChanges.changed.push(args.rowData);
                }
                $targetTR.removeClass("e-editedrow");
                args.cell.removeClass("e-editedbatchcell");
            }
        },
        _enableSaveCancel: function () {
            if (this.model.toolbarSettings.showToolbar) {
                $toolBar = this.element.find("#" + this._id + "_toolbarItems");
                $toolBar.ejToolbar("enableItemByID", this._id + "_update");
                $toolBar.ejToolbar("enableItemByID", this._id + "_cancel");
            }
        },

        setCellValue: function (index, fieldName, cellValue) {
            var data = this.getDataByIndex(index), tr = this.getRows()[index], dataIndex
                , columnIndex = this.getColumnIndexByField(fieldName);
            data[fieldName] = cellValue;
            if ($(tr).hasClass("e-insertedrow"))
                tr.cells[columnIndex + this.model.groupSettings.groupedColumns.length].innerHTML = cellValue;
            else {
                $.inArray(data, this.batchChanges.changed) == -1 && this.batchChanges.changed.push(data);
                tr.cells[columnIndex].innerHTML = cellValue;
            }
            this._enableSaveCancel();
        },
        setDefaultData: function (defaultData) {
            if (ej.isNullOrUndefined(defaultData)) {
                var fieldNames = this.getColumnFieldNames();
                defaultData = $.extend(true, {}, this._bulkEditCellDetails._data[0]);
                for (var field in defaultData) {
                    var index = $.inArray(field, fieldNames);
                    index == -1 && delete defaultData[field];
                    if (defaultData.hasOwnProperty(field)) {
                        if (!ej.isNullOrUndefined(this.model.columns[index]["defaultValue"])) {
                            defaultData[field] = this.model.columns[index]["defaultValue"];
                        }
                        else {
                            switch (typeof defaultData[field]) {
                                case "number":
                                    defaultData[field] = 0;
                                    break;
                                case "string":
                                    defaultData[field] = "";
                                    break;
                                case "boolean":
                                    defaultData[field] = false;
                                    break;
                                case "object":
                                    if ($.isArray(defaultData[field]))
                                        defaultData[field] = new Array();
                                    else
                                        defaultData[field] = "";
                            }
                        }
                    }
                }
            }
            this._bulkEditCellDetails.defaultData = defaultData;
        },
        _bulkDelete: function (index) {
            if (ej.isNullOrUndefined(index))
                index = this._selectedRow();
		    if (index == -1) {
                alert(this._getLocalizedLabels("DeleteOperationAlert"));
                return;
            }
            var tr = this.getRows()[index], $tr = $(tr), data = this.getDataByIndex(index), args = {};
            args = {
                primaryKey: this._primaryKeys,
                rowIndex: index,
                rowData: data,
                row: $tr
            };
            if (this._trigger("beforeBatchDelete", args))
                return;
            if ($tr.hasClass("e-insertedrow")) {
                $tr.remove();
                index = $.inArray(tr, this._bulkEditCellDetails.insertedTrCollection);
                if (index != -1) {
                    this._bulkEditCellDetails.insertedTrCollection.splice(index, 1);
                    this.batchChanges.added.splice(index, 1);
                }
            }
            else {
                $tr.hide();
                this.batchChanges.deleted.push(data);
            }
            this._enableSaveCancel();
            this._selectedRow(-1);
            args = {};
            this._trigger("batchDelete", args);
        },
        _bulkAddRow: function (defaultData) {
            var args = {}, $tr, editCellIndex, rows = this.getRows();
            if (!ej.isNullOrUndefined(defaultData))
                this._bulkEditCellDetails.defaultData = defaultData;
            ej.isNullOrUndefined(this._bulkEditCellDetails.defaultData) && this.setDefaultData();
            args = {
                defaultData: $.extend(true, {}, this._bulkEditCellDetails.defaultData),
                primaryKey: this._primaryKeys,
            };
            if (this._trigger("beforeBatchAdd", args))
                return;
            $tr = $($.render[this._id + "_JSONTemplate"](args.defaultData)).addClass("e-insertedrow");
            rows != null && $(rows[0]).hasClass("e-alt_row") && $tr.removeClass("e-alt_row");
            if (this.model.editSettings.rowPosition == "top")
                this.getContentTable().first().find('tbody').first().prepend($tr);
            else if (this.model.editSettings.rowPosition == "bottom")
                this.getContentTable().first().find('tbody').first().append($tr);
			if (this._gridRecordsCount === 0)
                this.getContentTable().find("tbody .emptyrecord").first().remove();
            this._gridRows = this.getContentTable().find("td.e-rowcell").closest("tr").toArray();
            for (var i = 0; i < this.model.groupSettings.groupedColumns.length; i++)
                $tr.prepend(ej.buildTag("td.e-indentcell"));
            this._bulkEditCellDetails.insertedTrCollection.push($tr.get(0));
            this.batchChanges.added.push(args.defaultData);
            this._enableSaveCancel();
            var rowindex = this._gridRows.length - 1;
            if (this.model.editSettings.rowPosition == "bottom")
            {
                editCellIndex = this._findNextEditableCell(0);
                this.selectRows(rowindex);
                this.editCell(rowindex, this.model.columns[editCellIndex].field);
            }
            else
            {
                editCellIndex = this._findNextEditableCell(0);
                this.selectRows(0);
                this.editCell(0, this.model.columns[editCellIndex].field);
            }
            $tr.find(".e-rowcell").addClass("e-updatedtd e-icon e-gupdatenotify");
            args = { defaultData: args.defaultData };
            $.extend(args, {
                columnObject: this.model.columns[editCellIndex],
                columnIndex: editCellIndex,
                row: $tr,
                primaryKey: this._primaryKeys,
                cell: $($tr[0].cells[editCellIndex])
            });
            this._trigger("batchAdd", args);
        },
        getDataByIndex: function (rowIndex) {
            var $tr = $(this.getRows()[rowIndex]), insertedRowIndex, currentRowData, index;
            if ($tr.hasClass("e-insertedrow")) {
                insertedRowIndex = $.inArray($tr[0], this._bulkEditCellDetails.insertedTrCollection);
                return this.batchChanges.added[insertedRowIndex];
            }
            else
                return this._bulkEditCellDetails._data[rowIndex - this._bulkEditCellDetails.insertedTrCollection.length];

        },
        /**
         * It is used to refresh and reset the changes made in "batch" edit mode
         * @alias ejGrid#refreshBatchEditChanges
         * @return jQuery
         * @example 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * gridObj.refreshBatchEditChanges(); 
         * // It is used to refresh and reset the changes made in batch edit mode
         * &lt;/script&gt;
         * @example 
         * &lt;script&gt;
         * // It is used to refresh and reset the changes made in batch edit mode
         * $("#Grid").ejGrid("refreshBatchEditChanges");
         * &lt;/script&gt;
         */
        refreshBatchEditChanges: function () {
            this._bulkEditCellDetails = {
                cellValue: null,
                rowIndex: -1,
                _data: null,
                columnIndex: -1,
                fieldName: null,
                cellEditType: "",
                cancelSave: false,
                defaultData: null,
                insertedTrCollection: [],
                rowData: null,
                isForeignKey: false
            };
            this.batchChanges = {
                added: [],
                deleted: [],
                changed: []
            };
        },
        refreshBatchEditMode: function () {
            if (this.model.editSettings.editMode == "batch") {
                this.refreshBatchEditChanges();
                this._bulkEditCellDetails._data = $.extend(true, [], this.getCurrentViewData());
            }
        },
        /**
         * Cancel the modified changes in grid control when edit mode is "batch".
         * @alias ejGrid#batchCancel
         * @return jQuery
         * @example 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * gridObj.batchCancel();
         * // Cancel added, edited, and deleted changes made in grid
         * &lt;/script&gt;
         * @example 
         * &lt;script&gt;
         * // Cancel added, edited, and deleted changes made in grid
         * $("#Grid").ejGrid("batchCancel");
         * &lt;/script&gt;
         */
        batchCancel: function () {
            this.cancelEdit();
        },
        /**
		 * Save the modified changes to data source in grid control when edit mode is "batch".
         * @alias ejGrid#batchSave
		 * @return jQuery
		 * @example 
		 * &lt;script&gt;
		 * // Create grid object.
		 * var gridObj = $("#Grid").data("ejGrid");
         * // Save added, edited, and deleted changes to source of data
		 * gridObj.batchSave(); 
		 * &lt;/script&gt;
		 * @example 
		 * &lt;script&gt;
		 * // Save added, edited, and deleted changes to source of data
		 * $("#Grid").ejGrid("batchSave");
		 * &lt;/script&gt;
         */
        batchSave: function () {
            var args = {}, deferedObject, gridObject = this;
            this.saveCell();
            args["batchChanges"] = this.getBatchChanges();
            if (this._trigger("beforeBatchSave", args))
                return;
            args = {};
            args.requestType = "batchsave";
            var deferedObject = this._dataManager.saveChanges(this.getBatchChanges(), this._primaryKeys[0], this.model.query._fromTable);
            if (this._dataManager instanceof ej.DataManager && !this._dataManager.dataSource.offline) {
                deferedObject.done(function (e) {
                    gridObject._processBindings(args);
                });
            }
            else
                this._processBindings(args);

        },
        /**
         * Get the batch changes of edit, delete and add operations of grid.
         * @alias ejGrid#getBatchChanges
         * @return jQuery
         * @example
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // Gets the edit, delete, and add changes of a grid
         * gridObj.getBatchChanges(); 
         * &lt;/script&gt;
         * @example
         * &lt;script&gt;
         * // Gets the edit, delete, and add changes of a grid
         * $("#Grid").ejGrid("getBatchChanges");        
         * &lt;/script&gt;
         */
        getBatchChanges: function () {
            return this.batchChanges;
        },
        /**
         * Edit a particular cell based on the row index and field name provided in "batch" edit mode.
         * @alias ejGrid#editCell
         * @return jQuery
         * @param { number } index Pass row index to edit particular cell
         * @param { string } fieldName Pass the field name of the column to perform batch edit 
         * @example
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // Edit particular cell based on row index and column field name
         * gridObj.editCell(2, "OrderID"); 
         * &lt;/script&gt;
         * @example
         * &lt;script&gt;
         * // Edit particular cell based on row index and column field name
         * $("#Grid").ejGrid("editCell", 2, "OrderID");
         * &lt;/script&gt;
         */
        editCell: function (index, fieldName) {
            var $form = $("#" + this._id + "EditForm");
            this.model.isEdit && this.saveCell();
            if ($.isFunction($.validator) && $form.length && $form.validate().errorList.length)
                return;
            var $targetTR = $(this.getRows()[index]), columnIndex = this.getColumnIndexByField(fieldName), $targetTd = $targetTR.find(".e-rowcell").eq(columnIndex), column = this.model.columns[columnIndex], rowData = this.getDataByIndex(index);
            var args = {
                validationRules: ej.isNullOrUndefined(column.validationRules) ? {} : $.extend(true, {}, column.validationRules),
                columnName: column.field,
                value: rowData[fieldName],
                rowData: rowData,
                primaryKey: this._primaryKeys,
                columnObject: column,
                cell: $targetTd,
                isForeignKey: !ej.isNullOrUndefined(column.foreignKeyValue) && this.model.editSettings.editMode == "batch" ? true : false,
            }, isEditable = true;
            if (this._trigger("cellEdit", args))
                return;
			if($targetTR.hasClass("e-insertedrow")) args.requestType="add";		
            if ($.inArray(fieldName, this._primaryKeys) != -1 || args.columnObject.allowEditing === false || args.columnObject.template || args.columnObject.isUnbound) {
                $.extend(this._bulkEditCellDetails, {
                    cellValue: args.value,
                    rowIndex: index,
                    fieldName: fieldName,
                    rowData: args.rowData,
                    columnIndex: columnIndex,
                    isForeignKey: ej.isNullOrUndefined(args.columnObject.foreignKeyValue) ? false : true
                });
                isEditable = false;
            }
            if ($targetTR.hasClass("e-insertedrow") && (!args.columnObject.template && !args.columnObject.isUnbound))
                isEditable = true;
            if (isEditable) {
                $.extend(this._bulkEditCellDetails, {
                    rowIndex: index,
                    cellValue: args.value,
                    columnIndex: columnIndex,
                    fieldName: fieldName,
                    cellEditType: args.columnObject.editType,
                    rowData: rowData,
                    isForeignKey: ej.isNullOrUndefined(args.columnObject.foreignKeyValue) ? false : true
                });
                this._renderBulkEditObject(args, $targetTd);
                $targetTR.addClass("e-editedrow");
                args.cell.addClass("e-editedbatchcell");
            }
        },
        _findNextEditableCell: function (columnIndex) {
            var endIndex = this.model.columns.length;
            for (var i = columnIndex; i < endIndex; i++) {
                if (!this.model.columns[i].template && !this.model.columns[i].isUnbound)
                    return i;
            }
            return -1;
        },
        _findNextCell: function (columnIndex, direction) {
            var splittedColumn, visibleColumns = [], predicate, rows = this.getRows();
            predicate = ej.Predicate("visible", "equal", true).and("template", "notequal", true);
            if (!$(rows[this._bulkEditCellDetails.rowIndex]).hasClass("e-insertedrow"))
                predicate = predicate.and("allowEditing", "notequal", false);
            splittedColumn = direction == "right" ? this.model.columns.slice(columnIndex) : this.model.columns.slice(0, columnIndex + 1).reverse();
            visibleColumns = ej.DataManager(splittedColumn).executeLocal(ej.Query().where(predicate));
            if (visibleColumns.length == 0 && (!(direction == "left" && this._bulkEditCellDetails.rowIndex == 0) && !(direction == "right" && this._bulkEditCellDetails.rowIndex + 1 == this.getRows().length))) {
                splittedColumn = direction == "right" ? this.model.columns.slice(0, columnIndex) : this.model.columns.slice(columnIndex).reverse();
                visibleColumns = ej.DataManager(splittedColumn).executeLocal(ej.Query().where(predicate));
                this._bulkEditCellDetails.rowIndex = visibleColumns.length && direction == "right" ? this._bulkEditCellDetails.rowIndex + 1 : this._bulkEditCellDetails.rowIndex - 1;
            }
            return visibleColumns.length ? $.inArray(visibleColumns[0], this.model.columns) : -1;
        },
        _moveCurrentCell: function (direction) {
            var editCellIndex, rowIndex = this._bulkEditCellDetails.rowIndex, currentRow, $form = $("#" + this._id + "EditForm");
            if (this._bulkEditCellDetails.rowIndex == -1 && this._bulkEditCellDetails.columnIndex == -1)
                return true;
            switch (direction) {
                case "right":
                    if ((this._bulkEditCellDetails.rowIndex == this.getRows().length - 1 && this._bulkEditCellDetails.columnIndex == this.model.columns.length - 1) || (!this.element.is(document.activeElement) && $form.length == 0))
                        return true;
                    if (this._bulkEditCellDetails.columnIndex == this.model.columns.length - 1) {
                        editCellIndex = 0;
                        this._bulkEditCellDetails.rowIndex = this._bulkEditCellDetails.rowIndex + 1;
                    }
                    else
                        editCellIndex = this._bulkEditCellDetails.columnIndex + 1;
                    if (this.model.columns[editCellIndex].template === true || this.model.columns[editCellIndex].visible === false || this.model.columns[editCellIndex].allowEditing === false)
                        editCellIndex = this._findNextCell(editCellIndex, direction);
                    this._bulkEditCellDetails.rowIndex != rowIndex && this.selectRows(this._bulkEditCellDetails.rowIndex);
                    editCellIndex != -1 && this.editCell(this._bulkEditCellDetails.rowIndex, this.model.columns[editCellIndex].field);
                    break;
                case "left":
                    if ((this._bulkEditCellDetails.rowIndex == 0 && this._bulkEditCellDetails.columnIndex == 0) || (!this.element.is(document.activeElement) && $form.length == 0))
                        return true;
                    if (this._bulkEditCellDetails.columnIndex == 0) {
                        editCellIndex = this.model.columns.length - 1;
                        this._bulkEditCellDetails.rowIndex = this._bulkEditCellDetails.rowIndex - 1;
                        this.selectRows(this._bulkEditCellDetails.rowIndex);
                    }
                    else
                        editCellIndex = this._bulkEditCellDetails.columnIndex - 1;
                    if (this.model.columns[editCellIndex].template === true || this.model.columns[editCellIndex].visible === false || this.model.columns[editCellIndex].allowEditing === false)
                        editCellIndex = this._findNextCell(editCellIndex, direction);
                    this._bulkEditCellDetails.rowIndex != rowIndex && this.selectRows(this._bulkEditCellDetails.rowIndex);
                    editCellIndex != -1 && this.editCell(this._bulkEditCellDetails.rowIndex, this.model.columns[editCellIndex].field);
                    break;
                case "up":
                    if (this._bulkEditCellDetails.rowIndex == 0)
                        return;
                    editCellIndex = this._bulkEditCellDetails.columnIndex;
                    this.selectRows(this._bulkEditCellDetails.rowIndex - 1);
                    this.editCell(this._bulkEditCellDetails.rowIndex - 1, this.model.columns[this._bulkEditCellDetails.columnIndex].field);
                    break;
                case "down":
                    if (this._bulkEditCellDetails.rowIndex == this.getRows().length - 1)
                        return;
                    editCellIndex = this._bulkEditCellDetails.columnIndex;
                    this.selectRows(this._bulkEditCellDetails.rowIndex + 1);
                    this.editCell(this._bulkEditCellDetails.rowIndex + 1, this.model.columns[this._bulkEditCellDetails.columnIndex].field);
                    break;

            }
            addedRow = !$(this.getRows()[this._bulkEditCellDetails.rowIndex]).hasClass("e-insertedrow");
            if (editCellIndex != -1 && (this.model.columns[editCellIndex].isUnbound || (this.model.columns[editCellIndex].isPrimaryKey && addedRow) || this.model.columns[editCellIndex].template))
                this.element.focus();
            return false;
        },
        _renderBulkEditObject: function (cellEditArgs, $td) {
            var $form = ej.buildTag("form", "", {}, { id: this._id + "EditForm" }), $bulkEditTemplate = this._bulkEditTemplate, mappingName = this._id + cellEditArgs.columnObject.field, $element, htmlString, cellData = {};
            cellData[cellEditArgs.columnObject.field] = cellEditArgs.value; var args={requestType:cellEditArgs.requestType};
            $td.empty();
            htmlString = $bulkEditTemplate.find("#" + cellEditArgs.columnObject.field + "_BulkEdit").html();
            $element = $($.templates(htmlString).render(cellData));
            if ($element.get(0).tagName == "SELECT") {
                $element.val(cellData[cellEditArgs.columnObject.field]);
                $element.val() == null && $element.val($element.find("option").first().val());
            }
            $form.append($element);
            $td.append($form);
            this._setoffsetWidth();
            this._refreshEditForm(args);
            if ($.isFunction($.validator) && !$.isEmptyObject(cellEditArgs.validationRules)) {
                this._initValidator();
                this.setValidationToField(cellEditArgs.columnObject.field, cellEditArgs.validationRules);
            }
            this.model.isEdit = true;
        },
        _triggerConfirm: function (args) {
            if (args !== undefined && document.activeElement.value == this._getLocalizedLabels("OkButton")) {
                if (this._confirmDialog.find(".e-content").text() == this._getLocalizedLabels("BatchSaveConfirm"))
                    this.batchSave();
                else if (this._confirmDialog.find(".e-content").text() == this._getLocalizedLabels("ConfirmDelete"))
                    this.model.editSettings.editMode == "batch" ? this._bulkDelete() : this._deleteRow();
                else {
                    this._confirmedValue = true;
                    this._processBindings(this._requestArgs);
                }
            }
            else {
                if (this._confirmDialog.find(".e-content").text() != this._getLocalizedLabels("BatchSaveConfirm") && this._confirmDialog.find(".e-content").text() != this._getLocalizedLabels("ConfirmDelete")) {
                    switch (this._requestArgs.requestType) {
                        case "grouping":
                            this.model.groupSettings.groupedColumns.pop();
                            break;
                        case "ungrouping":
                            this.model.groupSettings.groupedColumns.push(this._requestArgs.columnName);
                            break;
                        case "sorting":
                            this._cSortedDirection = this._cSortedColumn = null;
                            break
                        case "filtering":
                            this.model.filterSettings.filteredColumns.reverse().splice(0, this._requestArgs.currentFilterObject);
                            this.model.filterSettings.filteredColumns.reverse();
                            break;
                        case "paging":
                            this._currentPage(this._requestArgs.previousPage);
                            this.getPager().ejPager("model.currentPage", this._requestArgs.previousPage);
                            break

                    }
                }
                this._confirmedValue = false;
            }
            this._requestArgs = null;
            this._confirmDialog.ejDialog("close");
        },
        _saveCellHandler: function (e) {
            var $target = $(e.target);
            e.stopPropagation();
            if ($target.closest(".e-popup").length == 0 && $target.closest(".e-rowcell").find("#" + this._id + "EditForm").length == 0)
                this.saveCell();
        },
        _initValidator: function () {
            var gridObject = this, elements = this.model.scrollSettings.frozenColumns > 0 ? this.element.find(".gridform") : $("#" + this._id + "EditForm");
            for (var i = 0; i < elements.length ; i++) {
                elements.eq(i).validate({
                    errorClass: 'e-field-validation-error',
                    errorElement: 'div',
                    wrapper: "div",
                    errorPlacement: function (error, element) {
                        var $td = element.closest("td"), $container = $(error).addClass("e-error")
                        , $tail = ej.buildTag("div.e-errortail e-toparrow"), $container;
                        $td.find(".e-error").remove();
                        if (element.parent().hasClass("e-in-wrap"))
                            $container.insertAfter(element.closest(".e-widget"));
                        else
                            $container.insertAfter(element);
                        $container.prepend($tail)
                        gridObject.model.editSettings.editMode != "dialog" && $container.offset({ left: element.offset().left, top: element.offset().top + element.height() });
                        $container.fadeIn("slow");
                    },

                });
            }
        },
        setValidation: function () {
            for (var i = 0; i < this.model.columns.length; i++) {
                if (!ej.isNullOrUndefined(this.model.columns[i]["validationRules"])) {
                    this.setValidationToField(this.model.columns[i].field, this.model.columns[i].validationRules);
                }
            }
        },
        /**
		 * Set validation to a field during editing.
         * @alias ejGrid#setValidationToField
		 * @return jQuery
		 * @param {string} fieldName Specify the field name of the column to set validation rules
		 * @param {object} rules Specify the validation rules for the field
		 * @example 
		 * &lt;script&gt;
		 * // Create grid object.
		 * var gridObj = $("#Grid").data("ejGrid");
		 * // It is used to set validation to a field during editing
		 * gridObj.setValidationToField("OrderID", { required: true }); 
		 * &lt;/script&gt;
		 * @example 
		 * &lt;script&gt;
		 * // It is used to set validation to a field during editing
		 * $("#Grid").ejGrid("setValidationToField", "OrderID", { required: true });
		 * &lt;/script&gt;
         */
        setValidationToField: function (name, rules) {
            var ele = $("#" + this._id + name).length > 0 ? $("#" + this._id + name) : $("#" + name);
            ele.rules("add", rules);
            var validator = $("#" + this._id + "EditForm").validate();
            validator.settings.messages[name] = {};
            if (!ej.isNullOrUndefined(rules["required"])) {
                if (!ej.isNullOrUndefined(rules["messages"] && rules["messages"]["required"]))
                    var message = rules["messages"]["required"];
                else
                    var message = $.validator.messages.required;
                if (message.indexOf("This field") == 0)
                    message = message.replace("This field", this.getColumnByField(name).headerText);
                else
                    message = this.getColumnByField(name).headerText + " " + message;
                validator.settings.messages[name]["required"] = message;
                if (ele.hasClass("e-datepicker"))
                    ele.ejDatePicker({watermarkText: ""});
            }
        },
        _renderConfirmDialog: function () {
            var $contentDiv = ej.buildTag('div.e-content', this._getLocalizedLabels("BatchSaveConfirm"))
            , $buttons = ej.buildTag('span.e-buttons', "<input type='button' id=" + this._id + 'ConfirmDialogOK' + " value='" + this._getLocalizedLabels("OkButton") + "' /> "
                + "<input type='button' id=" + this._id + 'ConfirmDialogCancel' + " value='" + this._getLocalizedLabels("CancelButton") + "' />");

            this._confirmDialog = ej.buildTag('div#' + this._id + 'ConfirmDialog');
            this._confirmDialog.append($contentDiv).append($buttons);
            this.element.append(this._confirmDialog);
            $buttons.find("input").ejButton({
                cssClass: this.model.cssClass,
                showRoundedCorner: true,
                size: "mini",
                click: $.proxy(this._triggerConfirm, this)
            });
            this._renderFDialog(this._id + 'ConfirmDialog');
            this._confirmDialog.ejDialog({ width: "auto", enableModal: true });
        },
        _unboundClickHandler: function (e) {
            var $target = $(e.target);
            if ($target.hasClass("e-button") && ($target.hasClass("e-disable") || $target.prop("disabled"))) return;
            var $editTrLen = 0;
            if ($target.hasClass("e-unboundcelldiv"))
                return;
            if ($target.hasClass("e-cancelbutton"))
                this.model.isEdit = false;
            if (this.model.editSettings.editMode == "inlineform" || this.model.editSettings.editMode == "inlinetemplate")
                $editTrLen = $("#" + this._id).find(".e-editedrow").length;
            this.model.allowSelection && this.selectRows(this.getIndexByRow($target.closest("tr")) - $editTrLen);
            $.isFunction($.fn.ejDatePicker) && $("#" + this._id + "EditForm").find(".e-datepicker").ejDatePicker("hide");
            if ($target.hasClass("e-editbutton")) {
                var index = this.getIndexByRow($target.closest("tr"));
                if (this.model.isEdit)
                    this.cancelEdit();
                var $tr = this.getRowByIndex(index);
                this.startEdit($tr);
            } else if ($target.hasClass("e-deletebutton")) {
                var index = this.getIndexByRow($target.closest("tr"));
                var $tr = this.getRowByIndex(index);
                this._deleteRow($tr);
            }
            else if ($target.hasClass("e-savebutton"))
                this.endEdit();
            else if ($target.hasClass("e-cancelbutton"))
                this.cancelEdit();
        },
          /**
         * Add a new record in grid control even allowAdding is set as false.
         * @alias ejGrid# addRecord
         * @return jQuery
         * @example 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // Sends an add new record request to the grid
         * gridObj.addRecord(); 
         * &lt;/script&gt;
         * @example 
         * &lt;script&gt;
         * // add new record to the grid
         * $("#Editing").ejGrid("addRecord",{OrderID:12333})       
       * &lt;/script&gt;
       */
        addRecord: function (data, serverChange) {
            if (data) {
                if (!serverChange) {
                    this._dataManager.insert(data);
                    this.getContentTable().prepend($.render[this._id + "_JSONTemplate"](data));
                    if (this.model.allowPaging && this.getPager() != null) {
                        var model = this.getPager().ejPager("model");
                        model.totalRecordsCount++;
                        this.getRowByIndex(model.pageSize - 1).remove();
                        this.getPager().ejPager("refreshPager");
                    }
                } else {
                    var args = { data: data };
                    args.action = "add";
                    args.selectedRow = this._selectedRow();
                    this._cAddedRecord = data;
                    args.requestType = ej.Grid.Actions.Save;
                    this._updateAction(args);
                }
            } else
                this._startAdd();
        },
        /**
         * Update a edited record in grid control even allowEditing is set as false.
         * @alias ejGrid#updateRecord
         * @return jQuery
         * @param {string} fieldName Pass the primary key field Name of the column
         * @param {array} data Pass the edited json data of record need to be update.
         * @example 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // Sends a update record request to the grid
         * gridObj.updateRecord("OrderID", { OrderID: 10249, EmployeeID: 3 }); 
         * &lt;/script&gt;
         * @example 
         * &lt;script&gt;
         * // Sends a update record request to the grid
         * $("#Grid").ejGrid("updateRecord", "OrderID", { OrderID: 10249, EmployeeID: 3 });        
         * &lt;/script&gt;
         */
        updateRecord: function (keyField, data, action) {
            this._updateDeleteRecord(keyField, data, "update");
        },
        _updateDeleteRecord: function (keyField, data, action) {
            var dataMgr = ej.DataManager(this._currentJsonData), dataFilter, index, $row, $newrow;
            dataFilter = dataMgr.executeLocal(ej.Query().where(keyField, ej.FilterOperators.equal, data[keyField]));
            if (dataFilter.length) {
                index = $.inArray(dataFilter[0], this._currentJsonData);
                if (index != -1) {
                    $row = this.getRowByIndex(index);
                    if (action == "update") {
                        $newrow = $($.render[this._id + "_JSONTemplate"](data));
                        $row.replaceWith($newrow);
                        !$row.hasClass("e-alt_row") && $newrow.removeClass("e-alt_row");
                    }
                    else {
                        this._deleteRow($row);
                    }
                }
            }
            this._dataManager[action](keyField, data);
        },
        /**
         * Delete a record in grid control even allowDeleting is set as false
         * @alias ejGrid#deleteRecord
         * @return jQuery
         * @param {string} fieldName Pass the primary key field Name of the column
         * @param {array} data Pass the json data of record need to be delete.
         * @example 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // Sends a delete record request to the grid
         * gridObj.deleteRecord("OrderID", { OrderID: 10249, EmployeeID: 3 }); 
         * &lt;/script&gt;
         * @example 
         * &lt;script&gt;
         * // Sends a delete record request to the grid
         * $("#Grid").ejGrid("deleteRecord", "OrderID", { OrderID: 10249, EmployeeID: 3 });        
         * &lt;/script&gt;
         */
        deleteRecord: function (keyField, data) {
            this._updateDeleteRecord(keyField, data, "remove");
        },
    };
})(jQuery, Syncfusion);;
(function ($, ej, undefined) {
    ej.gridFeatures = ej.gridFeatures || {};
    ej.gridFeatures.sort = {
        _addSortElementToColumn: function (field, direction) {
            var column = this.getColumnByField(field), imageDirection;
            var index = $.inArray(column, this.model.columns);
            var sortcolumn = this.getsortColumnByField(field);
            var sortindex = $.inArray(sortcolumn, this.model.sortSettings.sortedColumns);
            var $headerCellDiv = this.getHeaderTable().find("thead tr:not('.e-stackedHeaderRow')").find(".e-headercell").not(".e-detailheadercell").eq(index).find(".e-headercelldiv");
			direction=ej.isNullOrUndefined(direction) ? "ascending" : direction;
            $headerCellDiv.find(".e-ascending,.e-descending").remove();
            imageDirection = direction != "descending" ? "e-rarrowup-2x" : "e-rarrowdown-2x";
            var opacity = 1;
            if (this.model.allowSorting && this.model.allowMultiSorting && this.model.sortSettings.sortedColumns.length > 1) {
                for (var i = 1; i <= sortindex; i++) {
                    opacity = opacity + 1;
                }
                if ($headerCellDiv.css("text-align") == "right") {
                    $headerCellDiv.prepend(this._createSortNumber(opacity, $headerCellDiv).addClass("e-sortnumber"));
                    $headerCellDiv.append(this._createSortElement().addClass("e-" + (direction || "ascending") + " " + imageDirection));
                }
                else {
                    $headerCellDiv.prepend(this._createSortNumber(opacity, $headerCellDiv).addClass("e-sortnumber"));
                    $headerCellDiv.append(this._createSortElement().addClass("e-" + (direction || "ascending") + " " + imageDirection));
                }
            }
            else
            $headerCellDiv.append(this._createSortElement().addClass("e-" + (direction || "ascending") + " " + imageDirection));
            $headerCellDiv.parent().attr("aria-sort", direction);
        },
        _removeSortElementFromColumn: function (field) {
            var column = this.getColumnByField(field);
            var index = $.inArray(column, this.model.columns);
            var $headerCellDiv = this.getHeaderTable().find("thead").find(".e-headercell").not(".e-detailheadercell").eq(index).find(".e-headercelldiv");
            $headerCellDiv.find(".e-ascending,.e-descending").remove();
            $headerCellDiv.parent().removeAttr("aria-sort");
        },
        _sortCompleteAction: function (args) {
            var imageDirection;
            this.getHeaderTable().find(".e-columnheader").find(".e-headercelldiv")
                    .find(".e-ascending,.e-descending,.e-number").remove();
            this.getHeaderTable().find("[aria-sort]").removeAttr("aria-sort");
            for (var i = 0; i < this.model.sortSettings.sortedColumns.length; i++)
                this._addSortElementToColumn(this.model.sortSettings.sortedColumns[i].field, this.model.sortSettings.sortedColumns[i].direction);
            if (this.model.groupSettings.groupedColumns.length && this._$curSElementTarget != null) {
                var $element = this._checkEinGroupDrop($.trim(this._$curSElementTarget.text()));
                if (!ej.isNullOrUndefined($element)) {
                    imageDirection = args.columnSortDirection == "ascending" ? "e-rarrowup-2x" : "e-rarrowdown-2x";
                    $element.find(".e-ascending,.e-descending").removeClass().addClass("e-icon e-" + args.columnSortDirection + " " + imageDirection);
                }
            }
            this.multiSortRequest = false;
			this.setWidthToColumns();
        },
        /**
         * Remove a column or collection of columns from a sorted column collections in grid.
         * @alias ejGrid#removeSortedColumns
         * @return jQuery
         * @param {array/string} fieldName Pass array of field names of the columns to remove a collection of sorted columns or pass a string of field name to remove a column from sorted column collections
         * @example 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // Removes a column from sorted column collections
         * gridObj.removeSortedColumns("OrderID"); 
         * // Removes specified collection of columns from sorted column collections
         * gridObj.removeSortedColumns(["CustomerID", "ShipCity"]); 
         * &lt;/script&gt;
         * @example 
         * &lt;script&gt;
         * // Removes a column from sorted column collections
         * $("#Grid").ejGrid("removeSortedColumns", "OrderID");        
         * // Removes specified collection of columns from sorted column collections
         * $("#Grid").ejGrid("removeSortedColumns", ["CustomerID", "ShipCity"]);        
         * &lt;/script&gt;
         */
        removeSortedColumns: function (fieldName) {
            if ($.isArray(fieldName)) {
                for (var i = 0; i < fieldName.length; i++) {
                    this._removeSortedColumnFromCollection(fieldName[i]);
                }
            }
            else
                this._removeSortedColumnFromCollection(fieldName);
            this.multiSortRequest = true;
            this.sortColumn(null, null);
        },
        _removeSortedColumnFromCollection: function (fieldName) {
            for (var i = 0; i < this.model.sortSettings.sortedColumns.length; i++) {
                if (this.model.sortSettings.sortedColumns[i].field == fieldName) {
                    this.model.sortSettings.sortedColumns.splice(i, 1);
                    break;
                }
            }
        },
        /**
		 * Clear the sorting from columns in the grid
         * @alias ejGrid#clearSorting
		 * @return jQuery
		 * @example 
		 * &lt;script&gt;
		 * // Create grid object.
		 * var gridObj = $("#Grid").data("ejGrid");
         * // Clears the sorting from columns in the grid
		 * gridObj.clearSorting(); 
		 * &lt;/script&gt;
		 * @example 
		 * &lt;script&gt;
		 * // Clears the sorting from columns in the grid
		 * $("#Grid").ejGrid("clearSorting");        
		 * &lt;/script&gt;
         */
        clearSorting: function () {
            var proxy = this;
            this.model.sortSettings.sortedColumns = $.grep(this.model.sortSettings.sortedColumns, function (value, index) {
                if ($.inArray(value.field, proxy.model.groupSettings.groupedColumns) != -1)
                    return true;
                return false;
            });
            this._$prevSElementTarget = null;
            this._$curSElementTarget = null;
            this.refreshContent();
        },
        /**
         * Send a sorting request in grid.
         * @alias ejGrid#sortColumn
         * @return jQuery
         * @param {string} columnName Pass the field name of the column as columnName for which sorting have to be performed
         * @param {string} [sortingDirection] Pass the sort direction ascending/descending by which the column have to be sort. By default it is sorting in an ascending order
         * @example 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * gridObj.sortColumn("OrderID", "ascending"); // Sends a sorting request to the grid with specified columnName and sortDirection
         * &lt;/script&gt;
         * @example 
         * &lt;script&gt;
         * // Sends a sorting request to the grid with specified columnName and sortDirection
         * $("#Grid").ejGrid("sortColumn", "OrderID", "ascending");        
         * &lt;/script&gt;
         */
        sortColumn: function (columnName, columnSortDirection) {
            if (!this.model.allowSorting || $.inArray(columnName, this._disabledSortableColumns) != -1 || (columnName != null && columnName.length == 0))
                return;
            var args = {};
            if (!this.multiSortRequest) {
                var proxy = this;
                this.model.sortSettings.sortedColumns = $.grep(this.model.sortSettings.sortedColumns, function (value, index) {
                    if ($.inArray(value.field, proxy.model.groupSettings.groupedColumns) != -1)
                        return true;
                    return false;
                });
            }
            args.requestType = ej.Grid.Actions.Sorting;
            this._cSortedColumn = args.columnName = columnName;
            this._cSortedDirection = args.columnSortDirection = columnSortDirection === undefined ? ej.sortOrder.Ascending : columnSortDirection;
            if (this._cSortedColumn !== null) {
                this._removeSortedColumnFromCollection(columnName);
                this.model.sortSettings.sortedColumns.push({ field: this._cSortedColumn, direction: this._cSortedDirection });
            }
            var returnValue = this._processBindings(args);
            if (returnValue)
                this._cSortedDirection = this._cSortedColumn = null;
            this._primaryKeyValues = [];
        },
        _createSortElement: function () {
            return ej.buildTag('span.e-icon', "&nbsp;");
        },
        _renderMultiTouchDialog: function () {
            this._customPop = ej.buildTag("div.e-gridpopup", "", { display: "none" });
            var $content = ej.buildTag("div.e-content"), $downTail = ej.buildTag("div.e-downtail e-tail");
            if (this.model.allowMultiSorting) {
                var $selElement = ej.buildTag("span.e-sortdirect e-icon");
                $content.append($selElement);
            }
            if (this.model.selectionType == "multiple") {
                var $selElement = ej.buildTag("span.e-rowselect e-icon");
                $content.append($selElement);
            }
            this._customPop.append($content);
            this._customPop.append($downTail);
            this.element.append(this._customPop);
        },

    };
})(jQuery, Syncfusion);;
(function ($, ej, undefined) {
    ej.gridFeatures = ej.gridFeatures || {};
    ej.gridFeatures.filter = {
        /**
		 * Get the filter bar of grid
         * @alias ejGrid#getFilterBar
		 * @return gridFilterBar
		 * @example 
		 * &lt;script&gt;
		 * // Create grid object.
		 * var gridObj = $("#Grid").data("ejGrid");
         * // Gets filter bar of grid control
		 * gridObj.getFilterBar(); 
		 * &lt;/script&gt;
		 * @example 
		 * &lt;script&gt;
		 * // Gets filter bar of grid control
		 * $("#Grid").ejGrid("getFilterBar");        
		 * &lt;/script&gt;
         */
        getFilterBar: function () {
            return this._gridFilterBar;
        },

        setGridFilterBar: function (value) {
            this._gridFilterBar = value;
        },
        /**
		 * Send a filtering request to grid.
         * @alias ejGrid#filterColumn
		 * @return jQuery
		 * @param {string} fieldName Pass the field name of the column 
		 * @param {string} filterOperator string/integer/dateTime operator
		 * @param {string/number} filterValue Pass the value to be filtered in a column
		 * @param {string} predicate Pass the predicate as and/or
		 * @param {boolean} [matchcase] Pass the match case valueas true/false
		 * @example 
		 * &lt;script&gt;
		 * // Create grid object.
		 * var gridObj = $("#Grid").data("ejGrid");
         * // Sends a filtering request to the grid
		 * gridObj.filterColumn("OrderID","equal","10248","and", true);
		 * &lt;/script&gt;
         * @example
		 * &lt;script&gt;
		 * // Sends a filtering request to the grid
		 * $("#Grid").ejGrid("filterColumn","OrderID","equal","10248","and", true);
		 * &lt;/script&gt;
         */
        filterColumn: function (fieldName, filterOperator, filterValue, predicate, matchcase, actualFilterValue) {
            if (!this.model.allowFiltering)
                return;
            var args = {};
            args.requestType = ej.Grid.Actions.Filtering;
            args.currentFilterObject = [];
            if (!$.isArray(filterOperator))
                filterOperator = $.makeArray(filterOperator);
            if (!$.isArray(filterValue))
                filterValue = $.makeArray(filterValue);
            var firstLoop = false;
            var filterCol = this._filterCollection;
            if (ej.util.isNullOrUndefined(this._currentFilterColumn))
                this._currentFilterColumn = this.getColumnByField(fieldName);
            for (var index = 0; index < filterOperator.length; index++) {
                var filterObject = {
                    field: fieldName,
                    operator: filterOperator[index],
                    value: filterValue[index],
                    matchcase: matchcase,
                    predicate: predicate,
                    actualFilterValue: actualFilterValue
                };
                if (this.model.filterSettings.filterType == "filterbar")
                    this._$colType = this._currentFilterColumn.type;
                if (this.model.filterSettings.filteredColumns.length == 0 && filterObject.value !== "") {
                    if (this._$colType == "date" && (filterOperator == "equal" || filterOperator == "notequal") && typeof (filterObject.value) !== "string")
                        this._setDateFilters(filterObject);
                    else
                        this.model.filterSettings.filteredColumns.push(filterObject);
                } else {
                    var proxy = this;
                    if (!firstLoop) {
                        var dataManger = ej.DataManager(this.model.filterSettings.filteredColumns);
                        var query = new ej.Query().where("field", ej.FilterOperators.equal, filterObject.field);
                        var object = dataManger.executeLocal(query);
                        for (var i = 0; i < object.length; i++) {
                            var objectIndex = $.inArray(object[i], this.model.filterSettings.filteredColumns)
                            if (objectIndex != -1)
                                this.model.filterSettings.filteredColumns.splice(objectIndex, 1);
                        }
                    }
                    if (filterObject.value !== "") {
                        if (this._$colType == "date" && (filterOperator == "equal" || filterOperator == "notequal") && typeof (filterObject.value) !== "string")
                            this._setDateFilters(filterObject);
                        else
                            this.model.filterSettings.filteredColumns.push(filterObject);
                    }
                }
                firstLoop = true;
                args.currentFilterObject.push(filterObject);
            }
            args.filterCollection = this.model.filterSettings.filteredColumns;
            args.currentFilteringColumn = fieldName;
            var returnValue = this._processBindings(args);
            if (returnValue) {
                this.model.filterSettings.filteredColumns.reverse().splice(0, filterOperator.length);
                this.model.filterSettings.filteredColumns.reverse();
            }

        },
        /**
         * Send a search request to grid with specified string passed in it
         * @alias ejGrid#search
         * @return jQuery
         * @param {string} searchString Pass the string to search in Grid records
         * @example 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // Sends a search request to the grid
         * gridObj.search("France"); 
         * &lt;/script&gt;
         * @example
         * &lt;script&gt;
         * // Sends a search request to the grid
         * $("#Grid").ejGrid("search", "France");        
         * &lt;/script&gt;
         */
        search: function (searchString) {
            var args = {};
            args.requestType = ej.Grid.Actions.Search;
            args.keyValue = searchString;
            this._searchString = searchString;
            this._processBindings(args);
            this._primaryKeyValues = [];
        },
        _filterBarHandler: function (e) {
            var keycode = e.keyCode;
            if ((this.model.filterSettings["filterBarMode"] == "immediate" || keycode == 13) && keycode != 9) {
                var $target = $(e.target);
                this.filterStatusMsg = "";
                var fieldName = $target.prop("id").replace("_filterBarcell", "");
                var column = this.getColumnByField(fieldName);
                if (column == null)
                    return;
                this._currentFilterColumn = column;
                if (this._currentFilterColumn != this._oldFilterColumn)
                    this.filterValueOldLength = 0;
                this._currentFilterbarValue = $target.val();
                this.filterValueCurrentLength = this._currentFilterbarValue.length;
                if (((this.filterValueCurrentLength == 0 && this.filterValueOldLength == 0) || this._currentFilterbarValue == this.OldfilterValue) && this._currentFilterColumn == this._oldFilterColumn) {
                    this._showFilterMsg();
                    return;
                }
                this._skipFilterProcess = this._checkForSkipInput();
                if (!this._skipFilterProcess) {
                    this._processFilter();
                } else {
                    if (this._currentFilterColumn.type == "string") {
                        this.filterStatusMsg = "Invalid Filter Data";
                        this._showFilterMsg();
                    } else {
                        this._skipFilterProcess = false;
                        this._showFilterMsg();
                        return;
                    }
                }
            }
        },
        _renderResponsiveFilter: function () {
            var $outerDiv = ej.buildTag('div#responsiveFilter.resFilterDiv', '', { 'width': '100%', 'padding': '0px' });
            var height = $(window).height() + 1;
            var headerHieght = height * (8 / 100);
            var width = this.element.height() > height ? $(window).width() + 16.5 : $(window).width();
            var $columnDiv = ej.buildTag('div.columnDiv', '', { width: '100%' });
            for (var i = 0; i < this.model.columns.length; i++) {
                var $cDiv = ej.buildTag('div.e-responsivefilterColDiv', '', { width: '100%' }, { 'ej-MappingName': this.model.columns[i].field });
                var $span = ej.buildTag('span', this.model.columns[i].headerText, { 'margin-left': '4%' });
                $cDiv.append($span);
                $columnDiv.append($cDiv);
            }
            $outerDiv.append($columnDiv);
            this.element.append($outerDiv);
            var gridObj = this;
            var widt = this.element.outerWidth();
            var $headerDiv = ej.buildTag('div.e-resFilterDialogHeaderDiv', '', { 'height': headerHieght });
            var $span = ej.buildTag('div.labelRes', '<span>Filter</span>');
            var $resIcon = ej.buildTag('div.e-resFilterleftIcon', '', { 'margin-top': '3%' });
            var $resspan = ej.buildTag('span.e-icon e-responsiveFilterClear e-resIcon', '', { 'font-size': '23px' });
            var $divIcon = ej.buildTag('div.e-resFIlterRigthIcon', '', { 'float': 'right', 'margin-top': '3%' }, { closeDialogue: 'responsiveFilter', gridEle: true });
            var $spanIcon = ej.buildTag('span.e-icon e-responisveClose e-resIcon', '', { 'font-size': '23px' }, { closeDialogue: 'responsiveFilter', gridEle: true });
            $divIcon.click(function (e) {
                $("#responsiveFilter").css('display', 'none');
                gridObj.element.css('display', 'block');
            });
            $resIcon.click(function (e) {
                $("#responsiveFilter").find('.e-responsivefilterColDiv').find('.e-filternone').click();
            });
            $headerDiv.append($resIcon.append($resspan));
            $headerDiv.append($span).append($divIcon.append($spanIcon));
            $outerDiv.prepend($headerDiv);
            $outerDiv.insertAfter(this.element);
            $(".resFilterDiv").bind('keydown', $.proxy(this._responsiveDialogueKeyUp, this))
            $outerDiv.css('display', 'none');
            $(".e-responsivefilterColDiv").bind('click', $.proxy(this._mouseClickHandler, this));
        },
        _closeDivIcon: function (sender) {
            var $div = $(sender.target);
            if (!ej.isNullOrUndefined($div.attr('closeDialogue'))) {
                var $dialog = $("#" + $div.attr('closeDialogue'));
                if (!ej.isNullOrUndefined($dialog.data('ejDialog')))
                    $dialog.ejDialog('close');
                else
                    $dialog.css('display', 'none');
            }
            if (!ej.isNullOrUndefined($div.attr('gridEle'))) {
                this.element.css('display', 'block');
            }
            if (!ej.isNullOrUndefined($div.attr('openDialogue'))) {
                if (this.model.enableResponsiveRow || $div.attr('closeDialogue').indexOf('Custom') != -1) {
                    var $dialog = $("#" + $div.attr('openDialogue'));
                    if (!ej.isNullOrUndefined($dialog.data('ejDialog')))
                        $dialog.ejDialog('open');
                    else
                        $dialog.css('display', 'block');
                }
                else
                    this.element.css('display', 'block');
            }
        },
        _setResponsiveFilterIcon: function () {
            var $div = $("#responsiveFilter").find('.columnDiv'), $proxy = this;
            $div.find('.e-filtericon').remove();
            for (var i = 0; i < this.model.filterSettings.filteredColumns.length; i++) {
                var column = this.model.filterSettings.filteredColumns[i];
                var $selcDiv = $div.find('.e-responsivefilterColDiv[ej-MappingName=' + column.field + ']');
                var $divIcon = ej.buildTag('div.e-filtericon e-icon e-resIcon e-filterset e-filternone e-filterreset', '', { float: 'right', height: '22px', width: '21px', 'font-size': '20px', 'margin-right': '3%', 'margin-top': '2%' });
                var $iconSapn = ej.buildTag('span.e-filtericon e-icon e-resIcon e-filterset e-filternone', '', {}, { 'colType': column.type });
                $selcDiv.find('.e-filternone').remove();
                $selcDiv.append($divIcon);
                $iconSapn.click(function (e) {
                    var $target = e.target;
                    $proxy._$colType = $target.attr('colType');
                    $proxy._fltrClrHandler();
                    $target.remove();
                })
            }
        },
        _renderExcelFilter: function () {
            var model = {
                instance: this,
                showSortOptions: this.model.allowSorting,
                allowFormatFiltering: this.model.filterSettings.allowFormatFiltering,
                allowCaseSensitive: this.model.filterSettings.enableCaseSensitivity,
                maxFilterLimit: this.model.filterSettings.maxFilterChoices,
                filterHandler: ej.proxy(this._filterHandler, this),
                actionBegin: "actionBegin",
                actionComplete: "actionComplete"
            };
            this._excelFilter = new ej.excelFilter(model);
        },
        _filterHandler: function (args) {
            var arg = {}, fQMgr;
            arg.requestType = args.action == "sorting" ? args.action : "filtering";
            var temp = this.model.filterSettings.filteredColumns;
            if (args.action == "filtering") {
                fQMgr = ej.DataManager(this.model.filterSettings.filteredColumns);
                var query = new ej.Query().where("field", ej.FilterOperators.equal, args.fieldName);
                var object = fQMgr.executeLocal(query);
                for (var i = 0; i < object.length; i++) {
                    var objectIndex = $.inArray(object[i], this.model.filterSettings.filteredColumns)
                    if (objectIndex != -1)
                        this.model.filterSettings.filteredColumns.splice(objectIndex, 1);
                }
                ej.merge(this.model.filterSettings.filteredColumns, args.filterCollection);
                args.currentFilterCollection = args.filterCollection;
            }
            else if (args.action == "clearfiltering") {
                var filterObj = args.filterDetails;
                delete this._excelFilter._predicates[0][args.fieldName];
                this.filterColumn(filterObj.field, filterObj.operator, filterObj.value, filterObj.predicate);
                return;
            }
            else if (args.action == "sorting") {
                var sortObj = args.sortDetails;
                if (ej.gridFeatures.sort)
                    this.sortColumn(sortObj.field, sortObj.direction);
                this._excelFilter.closeXFDialog();
                return;
            }

            arg.currentFilteringColumn = args.fieldName;
            arg.predicated = args.ejpredicate;
            var returnValue = this._processBindings(arg);
            if (returnValue)
                this.model.filterSettings.filteredColumns = temp;
        },
        _renderFiltering: function () {
            var $headerTable = this.getHeaderTable();
            var $tr = ej.buildTag('tr.e-filterbar'), $trClone;
            if (this.model.detailsTemplate || this.model.childGrid) $tr.append(ej.buildTag('th.e-filterbarcell e-mastercell'));
            for (var column = 0; column < this.model.columns.length; column++) {
                var $input = ej.buildTag('input.e-ejinputtext e-filtertext', "", {}, { title: this.model.columns[column]["field"] + "'s filterbar cell", type: "text", id: this.model.columns[column]["field"] + "_filterBarcell" });
                var $th = ej.buildTag('th.e-filterbarcell'), $div = ej.buildTag('div.e-filterdiv'), $span = ej.buildTag('span.e-cancel e-icon e-hide');
                if (this.model.enablePersistence && this.model.filterSettings.filteredColumns.length > 0 && this.model.filterSettings.filterType == "filterbar") {
                    for (var fColumn = 0; fColumn < this.model.filterSettings.filteredColumns.length; fColumn++) {
                        if (this.getColumnIndexByField(this.model.filterSettings.filteredColumns[fColumn].field) == column) {
                            if (this.model.filterSettings.filteredColumns[fColumn].operator == "greaterthan")
                                $input.val(">" + this.model.filterSettings.filteredColumns[fColumn].value);
                            else if (this.model.filterSettings.filteredColumns[fColumn].operator == "lessthan")
                                $input.val("<" + this.model.filterSettings.filteredColumns[fColumn].value);
                            else if (this.model.filterSettings.filteredColumns[fColumn].operator == "notequal")
                                $input.val("!=" + this.model.filterSettings.filteredColumns[fColumn].value);
                            else
                                $input.val(this.model.filterSettings.filteredColumns[fColumn].value);
                        }
                    }
                }
                if (this.model.columns[column]["allowFiltering"] === false) {
                    $input.attr("disabled", true).addClass("e-disable");
                    this._disabledFilterableColumns.push(this.model.columns[column]["headerText"]);
                }
                this.model.columns[column]["visible"] === false && $th.addClass("e-hide");
                $div.append($input).append($span);
                $tr.append($th.append($div));
                if (column == this.model.scrollSettings.frozenColumns - 1) {
                    $trClone = $tr.clone();
                    $headerTable.find("thead").first().append($trClone);
                    $tr.empty();
                }
            }
            $headerTable.find("thead").last().append($tr);
            if (ej.browserInfo().name == "msie" && ej.browserInfo().version < 10) {
                var filterBarCell = $headerTable.find("thead").find(".e-filtertext");
                for (var cell = 0; cell < filterBarCell.length; cell++)
                    this._ieClearRemover(filterBarCell[cell]);
            }
            this.setGridFilterBar($tr);
        },
        _closeFilterDlg: function () {
            if (!ej.isNullOrUndefined($("#" + this._id + "_" + this._$colType + "Dlg").data('ejDialog')))
                $("#" + this._id + "_" + this._$colType + "Dlg").ejDialog('close');
            else
                $("#" + this._id + "_" + this._$colType + "Dlg").css('display', 'none');
            this._$fDlgIsOpen = false;
        },
        _filterBarClose: function (e) {
            var $target = $(e.target);
            if (e.type == "click" && $target.hasClass("e-cancel")) {
                var $targetText = $target.prev();
                $targetText.focus().val("");
                $targetText.trigger("keyup");
                e.stopPropagation();
            }
            if (e.type == "focusin" && $target.hasClass("e-filtertext")) {
                $target = $(e.target).next();
                this.getFilterBar().find(".e-cancel").addClass("e-hide");
                $target.removeClass("e-hide");
            }
        },
        _processFilter: function () {
            if (!this._alreadyFilterProcessed) {
                this._alreadyFilterProcessed = true;
                this._startTimer();
            } else {
                this._stopTimer();
                this._startTimer();
            }
        },
        _startTimer: function () {
            var proxy = this;
            this._timer = window.setTimeout(
                function () {
                    proxy._onTimerTick();
                },
                1500);
        },
        _stopTimer: function () {
            this._oldFilterColumn = this._currentFilterColumn;
            this.filterValueOldLength = this.filterValueCurrentLength;
            if (this._timer != null)
                window.clearTimeout(this._timer);
        },

        _onTimerTick: function () {
            this.OldfilterValue = this._currentFilterbarValue;
            this._findPredicate();
            var result = null;
            var matchcase = this._currentFilterColumn.type == "string" ? false : true;
            if (this._currentFilterColumn.foreignKeyValue && this._currentFilterColumn.dataSource && this._currentFilterbarValue != "")
                result = this._fltrForeignKeyValue(this._operator, this._currentFilterbarValue, matchcase,
                         this._currentFilterColumn.dataSource, this._currentFilterColumn.foreignKeyField,
                         this._currentFilterColumn.foreignKeyValue, this._currentFilterColumn.type);
            if (!this._skipFilterProcess) {
                if (ej.isNullOrUndefined(result))
                    this.filterColumn(this._currentFilterColumn.field, this._operator, this._currentFilterbarValue, this._predicate, matchcase);
                else
                    this.filterColumn(this._currentFilterColumn.field, result.operator, result.value, result.value.length > 1 ? "or" : this._predicate, matchcase, result.filterValue);
            }
            else
                this.filterStatusMsg = "Invalid Filter Data";
            this._showFilterMsg();
            this._stopTimer();
        },

        _findPredicate: function () {
            var _value = this._currentFilterbarValue.replace(/ && /i, " and ").replace(" || ", " or ");
            var _predicateFinder = _value.split(' ');
            this._predicate = "and";
            if (_predicateFinder.length != 0) {
                if ($.isFunction(ej.Predicate[_predicateFinder[1]])) {
                    this._skipFilterProcess = false;
                    this._predicate = _predicateFinder[1];
                    var valuesArray = _value.split(" " + _predicateFinder[1] + " ");
                    var tempOperator = [];
                    var filterValues = [];
                    for (var i = 0; i < valuesArray.length; i++) {
                        this._validateFilterValue(valuesArray[i]);
                        tempOperator.push(this._operator);
                        if (this._currentFilterColumn.type == "number")
                            filterValues.push(this._currentFilterbarValue);
                        else if (this._currentFilterColumn.type == "string")
                            filterValues.push(valuesArray[i]);
                    }
                    this._currentFilterbarValue = filterValues;
                    this._operator = tempOperator;
                } else
                    this._validateFilterValue($.trim(this._currentFilterbarValue));
            } else
                this._validateFilterValue($.trim(this._currentFilterbarValue));
        },

        _validateFilterValue: function (_value) {
            switch (this._currentFilterColumn.type) {
                case "number":
                    this._operator = ej.FilterOperators.equal;
                    var stringSkipInput = new Array(">", "<", "=", "!");
                    for (var i = 0; i < _value.length; i++) {
                        if (jQuery.inArray(_value[i], stringSkipInput) != -1) {
                            break;
                        }
                    }
                    if (i != _value.length) {
                        this._getOperator(_value.substring(i));
                        if (i != 0)
                            this._currentFilterbarValue = _value.substring(0, i);
                    }
                    if (this._currentFilterbarValue != "" && _value.length >= 1)
                        this._currentFilterbarValue = parseFloat(this._currentFilterbarValue);
                    else
                        this._currentFilterbarValue = _value.length > 1 ? parseFloat(_value) : _value;
                    break;
                case "date":
                case "datetime":
                    this._operator = ej.FilterOperators.equal;
                    this._getOperator(_value);
                    var _format;
                    if (ej.isNullOrUndefined(this._currentFilterColumn.format)) {
                        if (this._currentFilterColumn.type == "date")
                            _format = Globalize.culture().calendar.patterns.d; //System Date format
                        else
                            _format = Globalize.culture().calendar.patterns.f; //System DateTime format
                    }
                    else
                        _format = this._currentFilterColumn.format.split(':')[1].replace('}', "");
                    if (this._currentFilterbarValue != "") {
                        var filterbarValue = Globalize.parseDate(this._currentFilterbarValue, _format);
                        if (!ej.isNullOrUndefined(filterbarValue))
                            this._currentFilterbarValue = Globalize.parseDate(this._currentFilterbarValue, _format);
                        else
                            this.filterStatusMsg = "Invalid Filter Data";
                    }
                    break;
                case "string":
                    this._operator = ej.FilterOperators.startsWith;
                    break;
                case "boolean":
                    if (this._currentFilterbarValue.toLowerCase() == "true" || this._currentFilterbarValue == "1")
                        this._currentFilterbarValue = true;
                    else if (this._currentFilterbarValue.toLowerCase() == "false" || this._currentFilterbarValue == "0")
                        this._currentFilterbarValue = false;
                    this._operator = ej.FilterOperators.equal;
                    break;
                default:
                    this._operator = ej.FilterOperators.equal;
            }
        },
        _getOperator: function (_value) {
            if (_value.charAt(0) == "=") {
                this._operator = ej.FilterOperators.equal;
                this._currentFilterbarValue = _value.substring(1);
            }
            if (ej.data.operatorSymbols[_value.charAt(0)] !== undefined || ej.data.operatorSymbols[_value.slice(0, 2)] !== undefined) {
                this._operator = ej.data.operatorSymbols[_value.charAt(0)];
                this._currentFilterbarValue = _value.substring(1);
                if (this._operator === undefined) {
                    this._operator = ej.data.operatorSymbols[_value.slice(0, 2)];
                    this._currentFilterbarValue = _value.substring(2);
                }
            }
            if (this._operator == ej.FilterOperators.lessThan || this._operator == ej.FilterOperators.greaterThan) {
                if (this._currentFilterbarValue.charAt(0) == "=") {
                    this._operator = this._operator + "orequal";
                    this._currentFilterbarValue = this._currentFilterbarValue.substring(1);
                }
            }

        },

        _checkForSkipInput: function () {
            var isSkip = false;
            var skipInput = new Array("=", " ", "!");
            var context = this;
            if (this._currentFilterColumn.type == "number") {
                if (ej.data.operatorSymbols[this._currentFilterbarValue] !== undefined || $.inArray(this._currentFilterbarValue, skipInput) != -1)
                    isSkip = true;
            }
            if (this._currentFilterColumn.type == "string") {
                var stringSkipInput = new Array(">", "<", "=", "!");
                for (var i = 0; i < this._currentFilterbarValue.length; i++) {
                    if ($.inArray(this._currentFilterbarValue[i], stringSkipInput) != -1)
                        isSkip = true;
                }
            }
            return isSkip;
        },
        _showFilterMsg: function () {
            var index = $.inArray(this._currentFilterColumn, this.filterColumnCollection);
            if (this._currentFilterbarValue !== "" && index == -1)
                this.filterColumnCollection.push(this._currentFilterColumn);
            if (this._currentFilterbarValue == "" && index != -1) {
                this.filterColumnCollection.splice(index, 1);
            }
            if ((!this._skipFilterProcess || this.filterColumnCollection.length > 0) && this.filterStatusMsg != "Invalid Filter Data") {
                for (var index = 0; index < this.filterColumnCollection.length; index++) {
                    if (index > 0)
                        this.filterStatusMsg += " && ";
                    this.filterStatusMsg += this.filterColumnCollection[index].headerText + ": " + $("#" + this.filterColumnCollection[index].field + "_filterBarcell").val();
                }
            }

            if (this.model.allowPaging)
                this.getPager().ejPager("model.externalMessage", this.filterStatusMsg);
            else {
                this.$pagerStatusBarDiv.find("div").html(this.filterStatusMsg);
                if (this.filterStatusMsg.length)
                    this.$pagerStatusBarDiv.css("display", "block");
                else
                    this.$pagerStatusBarDiv.hide();
            }
            if (this.filterStatusMsg == "Invalid Filter Data") {
                index = $.inArray(this._currentFilterColumn, this.filterColumnCollection);
                this.filterColumnCollection.splice(index, 1);
            }
            this.filterStatusMsg = "";
        },
        _renderFilterDialogs: function () {
            var $strDlg, $numDlg, $boolDlg, $dateDlg, $datetimeDlg;

            $.each(this.model.columns, ej.proxy(function (indx, col) {
                if (col.type == "string" && !$strDlg) {
                    $strDlg = true;
                    !this._isExcelFilter ? this._renderStringDialog() : this._excelFilter.renderDialog("string");
                } else if (col.type == "number" && !$numDlg) {
                    $numDlg = true;
                    !this._isExcelFilter ? this._renderNumDialog() : this._excelFilter.renderDialog("number");
                } else if (col.type == "date" && !$dateDlg) {
                    $dateDlg = true;
                    !this._isExcelFilter ? this._renderDateDialog(col.field) : this._excelFilter.renderDialog("date");
                } else if (col.type == "datetime" && !$datetimeDlg) {
                    $datetimeDlg = true;
                    this._renderDateTimeDialog();
                } else if (col.type == "boolean" && !$boolDlg) {
                    $boolDlg = true;
                    !this._isExcelFilter ? this._renderBoolDialog() : this._excelFilter.renderDialog("boolean");
                }
            }, this));
        },
        _renderStringDialog: function () {
            var $id = this._id + "_stringDlg";
            if ($("#" + $id).length > 0) return;
            var $content = ej.buildTag("div#" + $id + ".e-dlgcontainer e-filterDialoge");
            $content.appendTo("body");
            if (!this.model.isResponsive || !this._mediaStatus)
                this._renderFDialog($id);
            this._renderDlgContent($content, "string");

        },
        _renderBoolDialog: function () {
            var $id = this._id + "_booleanDlg";
            if ($("#" + $id).length > 0) return;
            var $content = ej.buildTag("div#" + $id + ".e-dlgcontainer e-filterDialoge");
            $content.appendTo("body");
            if (!this.model.isResponsive || !this._mediaStatus)
                this._renderFDialog($id);
            if (!this.model.filterSettings.showPredicate)
                $("#" + $id).ejDialog({ minHeight: 90 });
            else
                $("#" + $id).ejDialog({ minHeight: 136 });
            this._renderDlgContent($content, "boolean");
        },
        _renderNumDialog: function () {
            var $id = this._id + "_numberDlg";
            if ($("#" + $id).length > 0) return;
            var $content = ej.buildTag("div#" + $id + ".e-dlgcontainer e-filterDialoge");
            $content.appendTo("body");
            if (!this.model.isResponsive || !this._mediaStatus)
                this._renderFDialog($id);
            this._renderDlgContent($content, "number");
        },
        _renderDateDialog: function (col) {
            var $id = this._id + "_dateDlg";
            if ($("#" + $id).length > 0) return;
            var $content = ej.buildTag("div#" + $id + ".e-dlgcontainer e-filterDialoge");
            $content.appendTo("body");
            if (!this.model.isResponsive || !this._mediaStatus)
                this._renderFDialog($id);
            this._renderDlgContent($content, "date", col);

        },
        _renderDateTimeDialog: function () {
            var $id = this._id + "_datetimeDlg";
            if ($("#" + $id).length > 0) return;
            var $content = ej.buildTag("div#" + $id + ".e-dlgcontainer e-filterDialoge");
            $content.appendTo("body");
            if (!this.model.isResponsive || !this._mediaStatus)
                this._renderFDialog($id);
            this._renderDlgContent($content, "datetime");
        },
        _renderFDialog: function (id) {
            $("#" + id).ejDialog({ showOnInit: false, "enableRTL": this.model.enableRTL, "cssClass": this.model.cssClass, "showHeader": false, width: 260, enableResize: false, allowKeyboardNavigation: false, content: "#" + this._id });
        },
        _renderDlgContent: function (content, type, col) {
            content.addClass("e-grid");
            var $predicate = ej.buildTag("div.e-predicate"), $operator = ej.buildTag("div.e-operator"), $value = ej.buildTag("div.e-value");
            var $strOp = this._getLocalizedLabels("StringMenuOptions");
            var $numOp = this._getLocalizedLabels("NumberMenuOptions");
            var $drdown = ej.buildTag("input#" + this._id + type + "_ddinput", {}, {}, { "type": "text" });
            var $drdownDiv = ej.buildTag("div#" + this._id + type + "_dropdown");
            var $drdownUl = ej.buildTag("ul");
            var $radio = ej.buildTag("input", {}, {}, { "type": "radio", "name": this._id + "_predicate" + type, "value": "or" });
            var $andRadio = ej.buildTag("input", {}, {}, { "type": "radio", "name": this._id + "_predicate" + type, "value": "and", "checked": "checked" });
            var $cbox;
            $predicate.append($andRadio)
                .append(ej.buildTag("span.e-caption").html(this._getLocalizedLabels("PredicateAnd")))
                .append($radio)
                .append(ej.buildTag("span.e-caption").html(this._getLocalizedLabels("PredicateOr")));
            !this.model.filterSettings.showPredicate && $predicate.hide();
            if (type == "string") {
                $cbox = ej.buildTag("input", {}, {}, { "type": "checkbox" });
                $predicate.append($cbox)
                    .append(ej.buildTag("span.e-caption").html(this._getLocalizedLabels("MatchCase")));
                $.each($strOp, function (indx, operator) {
                    $drdownUl.append(ej.buildTag("li", {}, {}, { "value": operator.value }).html(operator.text));
                });
            }
            if (type == "number" || type == "date" || type == "datetime") {
                $.each($numOp, function (indx, operator) {
                    $drdownUl.append(ej.buildTag("li", {}, {}, { "value": operator.value }).html(operator.text));
                });
            }
            if (type != "boolean") {
                $drdownDiv.append($drdownUl);
                $operator.append($drdown);
                $operator.append($drdownDiv);
            }
            var $tBox = ej.buildTag("input", {}, {}, { "type": "text" });
            var $tchkBox = ej.buildTag("input", {}, {}, { "type": "checkbox" });
            var filterVal = this.model.enableResponsiveRow ? 'Ok' : 'Filter';
            var clearVal = this.model.enableResponsiveRow ? 'Cancel' : 'Clear';
            var $filter = ej.buildTag("input.e-filter", {}, {}, { "type": "button", "value":this._getLocalizedLabels( filterVal) });
            var $clear = ej.buildTag("input.e-clear", {}, {}, { "type": "button", "value": this._getLocalizedLabels(clearVal) });
            $value.append(ej.buildTag("span.e-caption").html(this._getLocalizedLabels("Filter") + " : "));
            content.append($predicate);
            if (type == "boolean")
                $value.append($tchkBox);
            else {
                $value.append(ej.buildTag("br")).append($tBox);
                content.append($operator);
            }
            content.append($value);
            content.append(ej.buildTag("div.e-dlgBtns").append($filter)
                .append($clear));
            if (type != "boolean")
                $drdown.ejDropDownList({ "cssClass": this.model.cssClass, "enableRTL": this.model.enableRTL, "targetID": this._id + type + "_dropdown", width: "100%", height: "26px", selectedItemIndex: 0 });
            $radio.ejRadioButton({ "cssClass": this.model.cssClass, "enableRTL": this.model.enableRTL });
            $andRadio.ejRadioButton({ "cssClass": this.model.cssClass, "enableRTL": this.model.enableRTL, checked: true });
            if ($cbox)
                $cbox.ejCheckBox({ "cssClass": this.model.cssClass, "enableRTL": this.model.enableRTL });
            content.css("display", "none");
            this._createButton("filter", $filter);
            this._createButton("clear", $clear);
            if (type == "number")
                $tBox.ejNumericTextbox({ "cssClass": this.model.cssClass, "enableRTL": this.model.enableRTL, "value": 0, showSpinButton: false, height: "26px", decimalPlaces: 2, width: "100%" });
            else if (type == "date") {
                $tBox.attr("id", this._id + col)
                $tBox.ejDatePicker({ "cssClass": this.model.cssClass, "enableRTL": this.model.enableRTL, width: "100%", watermarkText: this._getLocalizedLabels("DatePickerWaterMark") });
            }
            else if (type == "datetime")
                $tBox.ejDateTimePicker({ "cssClass": this.model.cssClass, "enableRTL": this.model.enableRTL, width: "100%" });
            else if (type == "boolean")
                $tchkBox.ejCheckBox({ "cssClass": this.model.cssClass, "enableRTL": this.model.enableRTL });
            else if (type == "string") {
                $tBox.attr("id", this._id + "_acString");
                $tBox.ejAutocomplete({
                    "cssClass": this.model.cssClass, "enableRTL": this.model.enableRTL, "dataSource": this._dataSource(), width: "100%", height: 26, enableDistinct: true, focusIn: function (args) {
                        var $dropdown = this.element.closest(".e-dialog").find(".e-dropdownlist");
                        var $matchcase = this.element.closest(".e-dialog").find(".e-checkbox").prop("checked");
                        this.model.filterType = $dropdown.val();
                        this.model.caseSensitiveSearch = $matchcase;
                    }
                });
            }
        },
        _createButton: function (name, element) {
            var $func = name == "filter" ? ej.proxy(this._fltrBtnHandler, this) : ej.proxy(this._fltrClrHandler, this);
            element.ejButton({ "cssClass": this.model.cssClass, "enableRTL": this.model.enableRTL, "click": $func });
        },
        _getIdField: function () {
            var $key;
            $.each(this.model.columns, function (indx, col) {
                if (col.key) {
                    $key = col.field;
                    return false;
                }
            });
            return $key;
        },
        _filterCompleteAction: function () {
            if (this.model.allowPaging)
                this._refreshGridPager();
            if (this.model.filterSettings.filterType == "menu" || this._isExcelFilter) {
                if (!this._isExcelFilter)
                    this._closeFilterDlg();
                else if (this._excelFilter._openedFltr) {
                    this._excelFilter.closeXFDialog();
                }
                var column = this.getColumnByField(this._$curFieldName);
                var index = $.inArray(column, this.model.columns), proxy = this, _addicon = false;
                $.each(this.model.filterSettings.filteredColumns, function (indx, col) {
                    if (col.field == proxy._$curFieldName) {
                        _addicon = true;
                        return false;
                    }
                    else if (col.isComplex) {
                        if (col.predicates[0].field == proxy._$curFieldName) {
                            _addicon = true;
                            return false;
                        }
                    }
                });
                var $fIcon = this.getHeaderTable().find("thead").find(".e-headercell").not(".e-detailheadercell").eq(index).find(".e-filtericon");
                if (_addicon)
                    $fIcon.addClass("e-filteredicon e-filternone");
                else
                    $fIcon.removeClass("e-filteredicon e-filternone");
            }
        },
        _refreshFilterIcon: function () {
            if (!this.model.filterSettings.filteredColumns.length)
                return;
            var filteredCols = ej.distinct(this.model.filterSettings.filteredColumns, "field", true), _$headerCells = this.getHeaderTable().find("thead").find(".e-headercell").not(".e-detailheadercell"), index, col;
            if (this.model.allowReordering)
                _$headerCells.find(".e-filtericon").removeClass("e-filteredicon e-filternone");
            for (var i = 0, flen = filteredCols.length; i < flen; i++) {
                col = filteredCols[i]
                index = this.getColumnIndexByField(col.isComplex ? col.predicates[0].field : col.field);
                _$headerCells.eq(index).find(".e-filtericon").addClass("e-filteredicon e-filternone");
            }
        },
        _setFilterFieldValues: function (id) {
            var $fVal = "", proxy = this;
            var flchk = -1;
            $.each(this.model.filterSettings.filteredColumns, function (indx, value) {
                if (value.field == proxy._$curFieldName)
                    flchk = indx;
            });
            if (flchk == -1 && this._$colType != "boolean") {
                if (this._$colType == "string") {
                    $(".e-predicate input[type='checkbox']").ejCheckBox({
                        checked: false, change: function (args) {
                            this.element.closest(".e-dialog").find(".e-autocomplete").val($fVal);
                        }
                    });
                }
                $(".e-predicate input[name =" + this._id + "_predicate" + this._$colType + "]:first").ejRadioButton({ checked: true });
                $("#" + this._id + this._$colType + "_ddinput").ejDropDownList({
                    selectedItemIndex: 0, change: function (args) {
                        this.element.closest(".e-dialog").find(".e-autocomplete").val($fVal);
                    }
                });
            }
            if (this._$curFieldName != this._$prevFieldName) {
                $.each(this.model.filterSettings.filteredColumns, function (indx, col) {
                    if (col.field == proxy._$curFieldName) {
                        var index;
                        var option = proxy._$colType == "number" || proxy._$colType == "date" ? "Number" : "String";
                        var $dlist = proxy._getLocalizedLabels(option + "MenuOptions");
                        for (index = 0; index < $dlist.length; index++) {
                            if ($dlist[index].value.toLowerCase() == col.operator)
                                break;
                        }
                        if (proxy._$colType == "string")
                            $(".e-predicate input[type='checkbox']").ejCheckBox({ checked: col.matchcase });
                        $("input[value=" + col.predicate + "]").ejRadioButton({ checked: true });
                        $("#" + proxy._id + proxy._$colType + "_ddinput").ejDropDownList({ selectedItemIndex: index });
                        $fVal = col.actualFilterValue != null ? col.actualFilterValue : col.value;
                        return false;
                    }
                });
                if (this._$colType == "boolean") {
                    if ($fVal && $fVal != "")
                        $(id).find(".e-value input").attr("checked", true);
                    else
                        $(id).find(".e-value input").attr("checked", false);
                } else
                    $(id).find(".e-value input").val($fVal);
            }
        },
        _fltrBtnHandler: function (e) {
            var id = this._id + "_" + this._$colType + "Dlg";
            var $par = $("#" + id);
            var $input = $par.find(".e-value input"), $operator, result;
            var value = $input.val(), matchcase = undefined, filterValue;
            if (this._$colType == "number") {
                $input = $input.filter(".e-numerictextbox");
                value = parseFloat($input.ejNumericTextbox("getValue"));
                matchcase = true;
            }
            if (this._$colType == "string")
                matchcase = $par.find(".e-predicate input[type='checkbox']").is(":checked");
            if (this._$colType == "date") {
                value = $("#" + this._id + this._$colForeignKeyField).val();
                value = Globalize.parseDate(value, this._$colFormat);
                matchcase = true;
            }
            if (this._$colType == "boolean") {
                value = $input.ejCheckBox("model.checked") != null ? $input.ejCheckBox("model.checked") : false;
                $operator = "equal";
            } else
                $operator = $("#" + this._id + this._$colType + "_ddinput").ejDropDownList("getSelectedValue").toLowerCase();
            if (this._$colForeignKeyValue && this._$colDropdownData)
                result = this._fltrForeignKeyValue($operator, value, matchcase, this._$colDropdownData, this._$colForeignKeyField, this._$colForeignKeyValue);
            if (ej.isNullOrUndefined(result))
                this.filterColumn(this._$curFieldName, $operator, value, $par.find(".e-predicate input[type='radio']:checked").attr("value"), matchcase);
            else {
                if ($par.find(".e-predicate input[type='radio']:checked").css("display") == "none" && result.value.length > 1)
                    this.filterColumn(this._$curFieldName, result.operator, result.value, "or", matchcase, result.filterValue);
                else
                    this.filterColumn(this._$curFieldName, result.operator, result.value, $par.find(".e-predicate input[type='radio']:checked").attr("value"), matchcase, result.filterValue);
            }
            if (this.model.isResponsive) {
                $par.css('display', 'none');
                this._setResponsiveFilterIcon();
                this.element.css('display', 'block');
                if (this.model.allowScrolling && (!this.model.enableResponsiveRow || !this.model.minWidth))
                    this.getScrollObject().refresh();
            }
        },
        _fltrClrHandler: function (e) {
            var id = "#" + this._id + "_" + this._$colType + "Dlg";
            if (this._$colType == "boolean")
                $(id).find(".e-value input").ejCheckBox("model.checked", false);
            else
                if (this._$colType == "number")
                    $(id).find('.e-numerictextbox').ejNumericTextbox("model.value", "");
                else
                    $(id).find(".e-value input").val("");
            if (this._$colType == "date") {
                for (var j = 0; j < this.model.filterSettings.filteredColumns.length; j++) {
                    if (this.model.filterSettings.filteredColumns[j].isComplex) {
                        var preobject = this.model.filterSettings.filteredColumns[j].predicates;
                        if (this.model.filterSettings.filteredColumns.length == 1) {
                            this.model.filterSettings.filteredColumns = preobject;
                        }
                        else {
                            this.model.filterSettings.filteredColumns[j] = preobject[0];
                            this.model.filterSettings.filteredColumns.push(preobject[1]);
                        }
                    }
                }
            }
            this.filterColumn(this._$curFieldName, "", "", "or");
        },

        _fltrForeignKeyValue: function (operator, value, matchcase, dataSource, fieldName, mapFieldName, colType) {
            if (ej.isNullOrUndefined(matchcase))
                matchcase = true;
            var operatorCol = [], query, filterValue;
            var data = ej.DataManager(dataSource);
            if (colType == "date") {
                var $prevDate = new Date(value.setDate(value.getDate() - 1));
                var $nextDate = new Date(value.setDate(value.getDate() + 2));
                if (operator == "equal" || operator == "notequal") {
                    if (operator == "equal")
                        query = new ej.Query().where(ej.Predicate(mapFieldName, ">", $prevDate, !matchcase)
                            .and(mapFieldName, "<", $nextDate, !matchcase)).select(fieldName);
                    else
                        query = new ej.Query().where(ej.Predicate(mapFieldName, "<=", $prevDate, !matchcase)
                           .or(mapFieldName, ">=", $nextDate, !matchcase)).select(fieldName);
                }
                else
                    query = new ej.Query().where(mapFieldName, operator, value, !matchcase).select(fieldName);
            }
            else
                query = new ej.Query().where(mapFieldName, operator, value, !matchcase).select(fieldName);
            filterValue = value;
            value = data.executeLocal(query);
            operatorCol.push("equal");
            for (i = 1; i < value.length ; i++) {
                operatorCol.push("equal");
            }
            return { operator: operatorCol, value: value, filterValue: filterValue };
        },
        _setDateFilters: function (filterObject) {
            var $prevDate = new Date(filterObject.value.setDate(filterObject.value.getDate() - 1));
            var $nextDate = new Date(filterObject.value.setDate(filterObject.value.getDate() + 2));
            var $prevObj = $.extend({}, filterObject);
            var $nextObj = $.extend({}, filterObject);
            $prevObj.value = $prevDate;
            $nextObj.value = $nextDate;
            if (filterObject.operator == "equal") {
                $prevObj.operator = "greaterthan";
                $prevObj.predicate = "and";
                $nextObj.operator = "lessthan";
                $nextObj.predicate = "and";
            } else {
                $prevObj.operator = "lessthanorequal";
                $prevObj.predicate = "or";
                $nextObj.operator = "greaterthanorequal";
                $nextObj.predicate = "or";
            }
            pred = ej.Predicate($prevObj.field, $prevObj.operator, $prevObj.value, false);
            predicate = pred[$nextObj.predicate](ej.Predicate($nextObj.field, $nextObj.operator, $nextObj.value, false));
            this.model.filterSettings.filteredColumns.push(predicate);
        },
    };
})(jQuery, Syncfusion);;
(function ($, ej, undefined) {
    ej.gridFeatures = ej.gridFeatures || {};
    ej.gridFeatures.group = {
        _renderGroupDropArea: function () {
            if (!this.model.groupSettings.enableDropAreaAutoSizing)
                this.model.groupSettings.enableDropAreaAnimation = this.model.groupSettings.enableDropAreaAutoSizing;
            var dragLabel = this.model.groupSettings.enableDropAreaAnimation ? "" : this._getLocalizedLabels("GroupDropArea");
            var $div = ej.buildTag("div.e-groupdroparea", dragLabel);
            this.model.groupSettings.enableDropAreaAutoSizing && $div.append(ej.buildTag("div.e-animatebutton e-icon").addClass(this.model.groupSettings.enableDropAreaAnimation ? "e-animatebuttondown e-gdownarrow" : "e-animatebuttonup e-guparrow"));
            return $div;
        },
        _getColGroup: function (gridObjectId) {
            var gridObject = this.getRsc("helpers", gridObjectId);
            if (gridObject.model.groupSettings.groupedColumns.length == 1)
                var level = this.data.items.level === undefined ? 0 : this.data.items.level - 1;
            else
                var level = this.data.items.level === undefined ? gridObject.model.groupSettings.groupedColumns.length : this.data.items.level - 1;
            var $div = $(document.createElement("div"));
            var $colGroup;
            if (gridObject._isCaptionSummary)
                $colGroup = gridObject._getCaptionColGroup(level);
            else {
                $colGroup = gridObject._getMetaColGroup();
                if (level != gridObject.model.groupSettings.groupedColumns.length && gridObject.model.groupSettings.groupedColumns.length > 1)
                    $colGroup.prepend(gridObject._getIndentCol());
            }
            $div.html($colGroup);
            return $div.html();
        },
        _colSpanAdjust: function (gridObjectId, type, captionDetails) {
            var gridObject, groupData;
            if (ej.isNullOrUndefined(gridObjectId)) {
                gridObject = this;
                groupData = captionDetails;
            }
            else {
                gridObject = this.getRsc("helpers", gridObjectId);
                groupData = this;
            }
            if (gridObject.model.groupSettings.groupedColumns.length == 1) {
                var level = groupData.data.items.level === undefined ? 1 : groupData.data.items.level - 1;
                if (type == "groupcaption")
                    gridObject._currentJsonData = gridObject._currentJsonData.concat(groupData.data.items);
            } else {
                var level = groupData.data.items.level === undefined ? gridObject.model.groupSettings.groupedColumns.length : groupData.data.items.level - 1;
                if (type == "groupcaption" && groupData.data.items.level === undefined)
                    gridObject._currentJsonData = gridObject._currentJsonData.concat(groupData.data.items);
            }
            var hideGroupColumnCount = !gridObject.model.groupSettings.showGroupedColumn ? gridObject.model.groupSettings.groupedColumns.length : 0;
            var colspan = gridObject.model.columns.length + gridObject.model.groupSettings.groupedColumns.length - level - gridObject._hiddenColumns.length - hideGroupColumnCount;
            colspan = gridObject.model.detailsTemplate != null ? colspan + 1 : colspan;

            if (gridObject._isCaptionSummary && type == "groupcaption") {
                var index = [];
                var row = gridObject._captionSummary();
                $.each(row[0].summaryColumns, function (cindx, col) {
                    index.push(gridObject.getColumnIndexByField(col.displayColumn) - gridObject._hiddenColumns.length);
                });
                if (index.length > 0)
                    colspan = ej.min(index);
                if (!gridObject.model.groupSettings.showGroupedColumn) 
                    colspan = groupData.data.items.childLevels != null ? (groupData.data.items.childLevels + 2) : 1;
                else 
                    colspan = groupData.data.items.childLevels != null ? colspan + (groupData.data.items.childLevels + 1) : colspan;
                colspan = gridObject.model.detailsTemplate != null ? colspan + 1 : colspan;
            }
            return colspan;
        },
        _captionEncode: function (gridObjectId) {
            var gridObject = this.getRsc("helpers", gridObjectId);
            var column = gridObject.getColumnByField(this.data.field);
            return column.disableHtmlEncode;
        },
        _captionFormat: function (gridObjectId) {
            var gridObject = this.getRsc("helpers", gridObjectId);
            var keyValue;
            var column = gridObject.getColumnByField(this.data.field);
            if (column.foreignKeyValue && column.dataSource)
                keyValue = gridObject._foreignKeyBinding(column, this.data.key);
            else
                keyValue = this.data.key;
            var formatted = column.format ? gridObject.formatting(column.format, keyValue,gridObject.model.locale) : keyValue;
            return column.headerText + ": " + formatted + " - " + this.data.count + " " + gridObject._getLocalizedLabels("GroupCaptionFormat");
        },
        _getCaptionColGroup: function (level) {
            var cloneColGroup = this.getHeaderTable().find("colgroup").clone();
            var colColl = cloneColGroup.find("col");
            var indentCol = colColl.length - this.model.columns.length;
            if (this.model.detailsTemplate != null)
                indentCol = indentCol - 1;
            cloneColGroup.find("col:lt(" + indentCol + ")").remove();
            if (level > 0 && level != this.model.groupSettings.groupedColumns.length) {
                if (this.model.groupSettings.groupedColumns.length > 2 && level != this.model.groupSettings.groupedColumns.length - 1) {
                    for (var i = 0; i < this.model.groupSettings.groupedColumns.length - level; i++) {
                        cloneColGroup.prepend(this._getIndentCol());
                    }
                }
                else
                    cloneColGroup.prepend(this._getIndentCol());
            }
            return cloneColGroup;
        },
        _groupSummaryRow: function (item, aggregates, gridObjectId) {
            var gridObject = this.getRsc("helpers", gridObjectId);
            if (gridObject.model.showSummary) {
                if (!ej.isNullOrUndefined(item.level) && !gridObject._isCaptionSummary) return;
                if (gridObject.getFooterTable() == null)
                    gridObject._renderGridFooter();
                gridObject._createSummaryRows(gridObject.getFooterTable(), item.records == null ? item : item.records,aggregates);
                if (gridObject._isCaptionSummary) {
                    var index = [];
                    var row = gridObject._captionSummary();
                    $.each(row[0].summaryColumns, function (cindx, col) {
                        index.push(gridObject.getColumnIndexByField(col.displayColumn));
                    });
                    if (index.length > 0)
                        colIndex = ej.min(index);
                    var colLength = gridObject.model.columns.length;
                    if (!gridObject.model.groupSettings.showGroupedColumn) {
                        gridObject.getFooterTable().find("tbody td").slice(-(colLength - 1)).removeClass("e-summaryrow").addClass("e-groupcaptionsummary");
                    }
                    else {
                        gridObject.getFooterTable().find("tbody td").slice(-(colLength - colIndex)).removeClass("e-summaryrow").addClass("e-groupcaptionsummary");
                    }
                }
                if (!gridObject.model.groupSettings.showGroupedColumn) {
                  var groupedcolumns = gridObject.model.groupSettings.groupedColumns;
                  var count=0;
                  var gridfooterrow = gridObject.getFooterTable().children('tbody').find('tr');
                  for (var j = 0; j < gridObject.model.summaryRows.length; j++) {
                  for (var k = 0; k < gridObject.model.summaryRows[j].summaryColumns.length; k++) {
                  for (var i = 0; i < groupedcolumns.length; i++) {
                      if (groupedcolumns[i] == gridObject.model.summaryRows[j].summaryColumns[k].displayColumn){
                      count++;
                      if (gridObject.model.summaryRows[j].summaryColumns.length == count)
                      { 
                          $(gridfooterrow[j]).addClass("e-hide")
                      }}}}
                  count=0;
                   }}
                return gridObject.getFooterTable().find("tbody").html();
            }
        },
        addGroupingTemplate: function () {
            var tbody = document.createElement('tbody');
            var expandTd = "<td class='e-recordplusexpand'><div class='e-icon e-gdiagonalnext'></div></td>";
            var proxy = this;
            var helpers = {};
            helpers["_" + proxy._id + "ColSpanAdjust"] = this._colSpanAdjust;
            helpers["_" + proxy._id + "Colgroup"] = this._getColGroup;
            helpers["_" + proxy._id + "CaptionFormat"] = this._captionFormat;
            helpers["_" + proxy._id + "GroupSummaryRow"] = this._groupSummaryRow;
            helpers["_" + proxy._id + "CaptionEncode"] = this._captionEncode;
            helpers[proxy._id + "Object"] = this;
            $.views.helpers(helpers);
            var caption = " ~_" + proxy._id + "CaptionFormat('" + proxy._id + "Object')";
            var cpationTd = expandTd + "<td class='e-groupcaption' colspan='{{:~_" + proxy._id + "ColSpanAdjust('" + proxy._id + "Object" + "','groupcaption') }}'>{{if ~_" + proxy._id + "CaptionEncode('" + proxy._id + "Object')}}{{html:" + caption + "}}{{else}}{{:" + caption + "}}{{/if}}</td";
            if (this._isCaptionSummary && this.model.showSummary)
                cpationTd = cpationTd + "{{:~_" + proxy._id + "GroupSummaryRow(items, aggregates,'" + proxy._id + "Object')}}";
            var captionTr = "<tr>" + cpationTd + "</tr>";
            var $tbody = ej.buildTag("tbody");
            $tbody.html("{{if items.GROUPGUID}}" +
                "{{for items tmpl='" + proxy._id + "_GroupingTemplate'/}}" +
                "{{else}}" +
                "{{for items tmpl='" + proxy._id + "_JSONTemplate'/}}" +
                "{{/if}}");
            var indentTd = "<td class='e-indentcell'></td>";
            var table = "<table class='e-table {{if items.GROUPGUID}}{{else}}e-recordtable{{/if}}' cellspacing='0.25px' >" +
                "{{:~_" + proxy._id + "Colgroup('" + proxy._id + "Object')}}" +
                $tbody.html() + (this._isCaptionSummary ? "</table>" : "{{:~_" + proxy._id + "GroupSummaryRow(items,aggregates,'" + proxy._id + "Object')}}" +
            "</table>");
            var tableTd = "<td class='e-tabletd' colspan='{{:~_" + proxy._id + "ColSpanAdjust('" + proxy._id + "Object" + "','table')}}'>" + table + "</td>";
            var tr = "<tr>" + indentTd + tableTd + "</tr>";
            $.templates(proxy._id + "_GroupingTemplate", captionTr + tr);
        },
        _getGroupTopLeftCell: function () {
            var $th = ej.buildTag("th.e-grouptopleftcell");
            $th.append(ej.buildTag("div.e-headercelldiv e-emptyCell", "&nbsp;"));
            return $th;
        },
        _getEmptyFilterBarCell: function () {
            return ej.buildTag("th.e-filterbarcell");
        },
        _groupingAction: function () {
            var $groupTopCell = this.getHeaderTable().find("thead").find(".e-columnheader").find(".e-grouptopleftcell"), $col = this.getHeaderTable().find("colgroup").find("col");
            var groupColumn = $groupTopCell.length;
            if (groupColumn) {
                this.getHeaderTable().find("colgroup").replaceWith(this._getMetaColGroup());
                (this.model.detailsTemplate != null || this.model.childGrid != null) && this.getHeaderTable().find("colgroup").prepend(this._getIndentCol());
                $groupTopCell.remove();
                this.getHeaderTable().find("thead").find(".e-filterbar").find(".e-filterbarcell:lt(" + groupColumn + ")").remove();
            }
            !this.model.allowResizeToFit && this.setWidthToColumns();
            for (var i = 0; i < this.model.groupSettings.groupedColumns.length; i++) {
                this.getHeaderTable().find("colgroup").prepend(this._getIndentCol());
                this.getHeaderTable().find("thead").find(".e-columnheader").prepend(this._getGroupTopLeftCell());
                this.getHeaderTable().find("thead").find(".e-filterbar").prepend(this._getEmptyFilterBarCell());

            }
            this.getHeaderTable().find("thead").find("th.e-grouptopleftcell").last().addClass("e-lastgrouptopleftcell");
        },
        /**
		 * Send a column grouping request in grid.
         * @alias ejGrid#groupColumn
		 * @return jQuery
		 * @param {string} fieldName Pass the field Name of the column to be grouped in grid control
		 * @example 
		 * &lt;script&gt;
		 * // Create grid object.
		 * var gridObj = $("#Grid").data("ejGrid");
         * // Sends a group column request to the grid
		 * gridObj.groupColumn("OrderID"); 
		 * &lt;/script&gt;
		 * @example 
		 * &lt;script&gt;
		 * // Sends a group column request to the grid
		 * $("#Grid").ejGrid("groupColumn", "OrderID");        
		 * &lt;/script&gt;
         */
        groupColumn: function (columnName) {
            if (!this.model.allowGrouping || $.inArray(columnName, this._disabledGroupableColumns) != -1)
                return;
            if (ej.isNullOrUndefined(this.getColumnByField(columnName)) || $.inArray(columnName, this.model.groupSettings.groupedColumns) != -1)
                return;
            this.model.groupSettings.groupedColumns.push(columnName);
            for (var i = 0; i < this.model.sortSettings.sortedColumns.length; i++) {
                if (this.model.sortSettings.sortedColumns[i].field == columnName) {
                    break;
                }
            }
            this.model.sortSettings.sortedColumns.length == i && this.model.sortSettings.sortedColumns.push({ field: columnName, direction: ej.sortOrder.Ascending });
            var args = {};
            args.columnName = columnName;
            args.requestType = ej.Grid.Actions.Grouping;
            var returnValue = this._processBindings(args);
            if (returnValue)
                this.model.groupSettings.groupedColumns.pop();
            this._primaryKeyValues = [];
        },
        /**
         * Un-group a column from grouped columns collection in grid
         * @alias ejGrid#ungroupColumn
         * @return jQuery
         * @param {string} fieldName Pass the field Name of the column to be ungrouped from grouped column collection
         * @example 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // Sends an ungroup column request to the grid
         * gridObj.ungroupColumn("OrderID"); 
         * &lt;/script&gt;
         * @example 
         * &lt;script&gt;
         * // Sends an ungroup column request to the grid
         * $("#Grid").ejGrid("ungroupColumn", "OrderID");        
         * &lt;/script&gt;
         */
        ungroupColumn: function (columnName) {
            if (!this.model.allowGrouping)
                return;
            if ($.inArray(columnName, this.model.groupSettings.groupedColumns) != -1)
                this.model.groupSettings.groupedColumns.splice($.inArray(columnName, this.model.groupSettings.groupedColumns), 1);
            else
                return null;
            var args = {};
            for (var i = 0; i < this.model.sortSettings.sortedColumns.length; i++) {
                if (this.model.sortSettings.sortedColumns[i].field == columnName) {
                    if (this._scolumns.indexOf(columnName) != -1 && this.model.allowSorting && this.model.allowMultiSorting || this._gridSort == columnName)
                        if (this.model.allowSorting && this.model.allowMultiSorting) {
                            var no = $.inArray(columnName, this._scolumns);
                            this._scolumns.splice(no, 1);
                            break;
                        }
                        else {
                            this._gridSort = null;
                            break;
                        }
                    else
                        this.model.sortSettings.sortedColumns.splice(i, 1);
                    break;
                }
            }
            args.columnName = columnName;
            args.requestType = ej.Grid.Actions.Ungrouping;
            var returnValue = this._processBindings(args);
            if (returnValue)
                this.model.groupSettings.groupedColumns.push(columnName);
            this._primaryKeyValues = [];
        },
        /**
         * Collapse the group drop area in grid
         * @alias ejGrid#collapseGroupDropArea
         * @return jQuery
         * @example 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // Collapse the group drop area of the grid
         * gridObj.collapseGroupDropArea(); 
         * &lt;/script&gt;
         * @example 
         * &lt;script&gt;
         * // Collapse the group drop area of the grid
         * $("#Grid").ejGrid("collapseGroupDropArea");        
         * &lt;/script&gt;
         */
        collapseGroupDropArea: function () {
            var $groupDropArea = this.element.find(".e-groupdroparea").first(), proxy = this;
            this.model.groupSettings.groupedColumns.length == 0 && this.model.groupSettings.enableDropAreaAnimation && $groupDropArea.animate({ height: "10px" }, 200, function () {
                if (proxy.model != null && proxy.model.groupSettings.groupedColumns.length == 0) {
                    $(this).html("").append(ej.buildTag("div.e-animatebutton e-animatebuttondown e-icon e-gdownarrow"));
                    $(this).dequeue().css("height", "auto");
                }
            });
        },
        /**
         * Expand the group drop area in grid.
         * @alias ejGrid#expandGroupDropArea
         * @return jQuery
         * @example 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // Expands the group drop area of the grid
         * gridObj.expandGroupDropArea(); 
         * &lt;/script&gt;
         * @example 
         * &lt;script&gt;
         * // Expands the group drop area of the grid
         * $("#Grid").ejGrid("expandGroupDropArea");        
         * &lt;/script&gt;
         */
        expandGroupDropArea: function () {
            var $groupDropArea = this.element.find(".e-groupdroparea").first(), proxy = this;
            this.model.groupSettings.groupedColumns.length == 0 && proxy.model.groupSettings.enableDropAreaAnimation && $groupDropArea.animate({ height: "30px" }, 150, function () {
                proxy.model.groupSettings.groupedColumns.length == 0 && $groupDropArea.html(proxy._getLocalizedLabels("GroupDropArea")).append(ej.buildTag("div.e-animatebutton e-animatebuttonup e-icon e-guparrow"));
                $groupDropArea.dequeue().css("height", "30px");
            });
        },
        _enableGroupingEvents: function () {
            if (this.model.allowGrouping) {
                this._on(this.element, "click", ".e-groupdroparea,.e-groupheadercell", this._groupHeaderCellClick);
                //to avoid ungrouping issue.
                this._on(this.element, "mousedown", ".e-groupheadercell", function (e) {
                    return false;
                });
            }

        },
        _recalculateIndentWidth: function () {
            var proxy = this;
            var browserDetails = this.getBrowserDetails();
            var indentWidth = this.getHeaderTable().find(".e-lastgrouptopleftcell").width(), newWidth = indentWidth, perPixel = indentWidth / 30, $col;
            if (perPixel >= 1)
                newWidth = (30 / perPixel);
            this.getHeaderTable().find("colgroup").find("col").slice(0, this.model.groupSettings.groupedColumns.length).css("width", newWidth + "px");
            indentWidth = this.getHeaderTable().find(".e-lastgrouptopleftcell").width();
            if (indentWidth > 30 || (this._isCaptionSummary && indentWidth >= 30)) {
                if (this._isCaptionSummary) {
                    var colgroup = this.getContentTable().find("table").filter(":not(.e-recordtable)").children("colgroup");
                    $.each(colgroup, function (index, item) {
                        var indentCol = $(item).find("col").length - proxy.model.columns.length;
                        if (proxy.model.detailsTemplate != null)
                        {
                            if (indentCol > 0)
                            indentCol = indentCol - 1;
                        }
                        $(item).find("col").slice(0, indentCol).css("width", newWidth + "px");
                    });
                }
                else
                    this.getContentTable().find("table").filter(":not(.e-recordtable)").children("colgroup").find("col:first-child").css("width", indentWidth + "px");
                $col = this.getContentTable().find("colgroup").first().find("col").slice(0, this.model.groupSettings.groupedColumns.length);
                if (browserDetails.browser != "msie")
                    $col.css("width", newWidth + "px");
                else
                    $col.first().css("width", ((indentWidth / this.element.width()) * 100) + "%");
            } else
                this.getContentTable().find("colgroup").first().find("col").slice(0, this.model.groupSettings.groupedColumns.length).css("width", newWidth + "px");

        },
        /**
		 * Get the column field name from the given header text in grid.
         * @alias ejGrid#getFieldNameByHeaderText
		 * @return fieldName
		 * @param {string} headerText Pass header text of the column to get its corresponding field name
		 * @example 
		 * &lt;script&gt;
		 * // Create grid object.
		 * var gridObj = $("#Grid").data("ejGrid");
         * // Gets the column field name from the given headerText
		 * gridObj.getFieldNameByHeaderText("Order ID"); 
		 * &lt;/script&gt;
		 * @example 
		 * &lt;script&gt;
		 * // Gets the column field name from the given headerText
		 * $("#Grid").ejGrid("getFieldNameByHeaderText", "Order ID");
		 * &lt;/script&gt;
         */
        getFieldNameByHeaderText: function (headerText) {
            if (ej.isNullOrUndefined(this._fieldColumnNames[headerText]))
                return null;
            return this._fieldColumnNames[headerText];
        },
        /**
         * Get the column header text from the given field name in grid.
         * @alias ejGrid#getHeaderTextByFieldName
         * @return headerText
         * @param {string} field Pass field name of the column to get its corresponding header text
         * @example 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * gridObj.getHeaderTextByFieldName("OrderID"); // Gets the column header text from the given field name
         * &lt;/script&gt;
         * @example 
         * &lt;script&gt;
         * // Gets the column header text from the given field name
         * $("#Grid").ejGrid("getHeaderTextByFieldName", "OrderID");
         * &lt;/script&gt;
         */
        getHeaderTextByFieldName: function (field) {
            if (ej.isNullOrUndefined(this._headerColumnNames[field]))
                return null;
            return this._headerColumnNames[field];
        },
        /**
         * Expand all the group caption rows in grid.
         * @alias ejGrid#expandAll
         * @return jQuery
         * @example 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // Expand all the group caption rows
         * gridObj.expandAll(); 
         * &lt;/script&gt;
         * @example 
         * &lt;script&gt;
         * // Expand all the group caption rows
         * $("#Grid").ejGrid("expandAll");        
         * &lt;/script&gt;
         */
        expandAll: function () {
            var recordPlus = this.element.find(".e-recordpluscollapse");
            var detailRow = this.element.find(".e-detailrowcollapse");
            if (recordPlus.length != 0) {
                for (var i = 0; i < recordPlus.length; i++)
                    this.expandCollapse($(recordPlus[i]));
            }
            if (detailRow.length != 0) {
                for (var i = 0; i < detailRow.length; i++)
                    this.expandCollapse($(detailRow[i]));
            }
        },
        /**
		 * Collapse all the group caption rows in grid
         * @alias ejGrid#collapseAll
		 * @return jQuery
		 * @example 
		 * &lt;script&gt;
		 * // Create grid object.
		 * var gridObj = $("#Grid").data("ejGrid");
         * // Collapse all the group caption rows
		 * gridObj.collapseAll(); 
		 * &lt;/script&gt;
		 * @example 
		 * &lt;script&gt;
		 * // Collapse all the group caption rows
		 * $("#Grid").ejGrid("collapseAll");        
		 * &lt;/script&gt;
         */
        collapseAll: function () {
            var recordPlus = this.element.find(".e-recordplusexpand");
            var detailRow = this.element.find(".e-detailrowexpand");
            if (recordPlus.length != 0) {
                for (var i = 0; i < recordPlus.length; i++)
                    this.expandCollapse($(recordPlus[i]));
            }
            if (detailRow.length != 0) {
                for (var i = 0; i < detailRow.length; i++)
                    this.expandCollapse($(detailRow[i]));
            }
        },
        _group: function (args) {
            if (this.model.groupSettings.groupedColumns.length && this.model.currentViewData) {
                this._currentJsonData = [];
                var $tbody = this.getContentTable().children('tbody');
                $tbody.empty();
                var temp = document.createElement('div');
                if (!this.model.groupSettings.showGroupedColumn) {
                    this._hideHeaderColumn(this.model.groupSettings.groupedColumns, true);
                    this.getContentTable().children("colgroup").replaceWith(this.getHeaderTable().find('colgroup').clone());
                }
                if (args.requestType == "reorder")
                    this._isReorder = true;
                else
                    this._isReorder = false;
                var $col = this.getContentTable().children("colgroup").find('col');
                var length = $col.length - this.model.columns.length;
                if (this.model.detailsTemplate != null)
                    length--;
                if ($col.length > this.model.columns.length)
                    this.getContentTable().children("colgroup").find('col:lt(' + length + ')').remove();
                this.getContentTable().find("colgroup").first().replaceWith(this._getMetaColGroup());
                var dlen;
                if (this.model.detailsTemplate != null) {
                    dlen = this.model.groupSettings.groupedColumns.length + 1;
                }
                else
                    dlen = this.model.groupSettings.groupedColumns.length;
                for (var i = 0; i < dlen; i++)
                    this.getContentTable().children("colgroup").prepend(this._getIndentCol());
                temp.innerHTML = ['<table>', $.render[this._id + "_GroupingTemplate"](this.model.currentViewData, { groupedColumns: this.model.groupSettings.groupedColumns }), '</table>'].join("");
                this.getContentTable().get(0).replaceChild(temp.firstChild.firstChild, this.getContentTable().get(0).lastChild);
                this._hideCaptionSummaryColumn();
                this._groupingAction();
                this._gridRows = this.getContentTable().find(".e-recordtable").find("tbody").find("tr").toArray();
                this._eventBindings();
            }
        },
        _ungroup: function () {
            if (!ej.isNullOrUndefined(this.model.detailsTemplate))
                this._detailsOuterWidth = null;
            var $header = this.element.children(".e-gridheader");
            var $filterInput = $header.find(".e-filterbar").find("th").find("input");
            $header.find("div").first().empty().append(this._renderGridHeader().find("table"));
            this.setGridHeaderContent($header);
            if (this.model.allowFiltering && this.model.filterSettings.filterType == "filterbar") {
                this._renderFiltering();
                var filterThNew = this.element.children(".e-gridheader").find(".e-filterbar").find("th").find("input");
                for (var i = 0; i < $filterInput.length; i++)
                    filterThNew.eq(i).val($filterInput.eq(i).val());
            }
            if (!this.model.groupSettings.showGroupedColumn)
                this._hideHeaderColumn(this.model.groupSettings.groupedColumns, true);
            this.element.find(".e-gridcontent").children("div").first().empty().append(this._renderGridContent().find("table").first());
            this.setGridContent(this.element.find(".e-gridcontent"));
            if (this.model.groupSettings.groupedColumns.length != 0)
                this._gridRows = this.getContentTable().find(".e-recordtable").find("tbody").find("tr").toArray();
            else
                this._gridRows = this.getContentTable().get(0).rows;
            this._eventBindings();
        },
        _groupHeaderCellClick: function (e) {
            var $target = $(e.target);
            if ($target.hasClass("e-ungroupbutton")) {
                var columnName = $.trim($target.parent().text());
                var field = this.getFieldNameByHeaderText(columnName);
                this.ungroupColumn(field);
            } else if ($target.hasClass("e-togglegroupbutton")) {
                var columnName = $.trim($target.parent().text()), field;
                field = this.getFieldNameByHeaderText(columnName);
                $target.hasClass("e-toggleungroup") && this.ungroupColumn(field);
            } else if ($target.hasClass("e-animatebutton")) {
                if (!this.model.groupSettings.enableDropAreaAnimation) {
                    this.model.groupSettings.enableDropAreaAnimation = true;
                    this.collapseGroupDropArea();
                } else {
                    this.expandGroupDropArea();
                    this.model.groupSettings.enableDropAreaAnimation = false;
                }
            }
            else {
                $target.addClass("e-headercelldiv").attr("ej-mappingname", $target.text())
                this._mouseClickHandler(e);
                $target.removeClass("e-headercelldiv").removeAttr("ej-mappingname");
            }

            return false;
        },
        _captionSummary: function () {
            var summary = null;
            for (k = 0; k < this.model.summaryRows.length; k++) {
                if (this.model.summaryRows[k].showCaptionSummary == true) {
                    summary = $(this.model.summaryRows[k]);
                    break;
                }
            }
            return summary;
        },
        _dropAreaHover: function (e) {
            var $target = $(e.target), proxy = this;
            if (e.type == "mouseenter") {
                if (this._dragActive) {
                    if ($target.hasClass("e-groupdroparea"))
                        $target.addClass("e-hover");
                } else
                    $target.removeClass("e-hover");
                $target.hasClass("e-groupheadercell") && this.model.groupSettings.showUngroupButton && $target.find(".e-ungroupbutton").show(150);
            } else if (e.type == "mouseleave") {
                if ($target.hasClass("e-groupdroparea")) {
                    $target.find(".e-ungroupbutton").hide(150);
                    $target.removeClass("e-hover");
                }
                $target.hasClass("e-groupheadercell") && this.model.groupSettings.showUngroupButton && $target.find(".e-ungroupbutton").hide(150);
            }
            return false;
        },
        _groupingCompleteAction: function (args) {
            var $groupDrop = this.element.children(".e-groupdroparea");
            if (this.model.groupSettings.groupedColumns.length && $groupDrop.find(".e-grid-icon").length == 0)
                $groupDrop.empty();
            if (this._initialRender) {
                for (var i = 0; i < this.model.groupSettings.groupedColumns.length; i++)
                    this._addColumnToGroupDrop(this.model.groupSettings.groupedColumns[i]);
                this._refreshGridPager();
            } else
                this._addColumnToGroupDrop(args.columnName);
            this.getHeaderTable().find(".e-columnheader").find(".e-headercelldiv").find(".e-ascending,.e-descending,.e-number").remove();
            for (var i = 0; i < this.model.sortSettings.sortedColumns.length; i++)
                this._addSortElementToColumn(this.model.sortSettings.sortedColumns[i].field, this.model.sortSettings.sortedColumns[i].direction);
            if (!this._initialRender && ej.gridFeatures.dragAndDrop)
                this._groupHeaderCelldrag();
            this.model.allowScrolling && this.getContentTable().parent().scrollLeft(this.getHeaderTable().parent().scrollLeft() - 1);
            this.element.children(".e-cloneproperties").remove();
			if (ej.gridFeatures.filter && ["menu", "excel"].indexOf(this.model.filterSettings.filterType))
                this._refreshFilterIcon();
        },
        _ungroupingCompleteAction: function (args) {
            var $groupDrop = this.element.children(".e-groupdroparea");
            this._removeColumnFromDrop(args.columnName);
            this.getHeaderTable().find(".e-columnheader").find(".e-headercelldiv").find(".e-ascending,.e-descending,.e-number").remove();
            for (var i = 0; i < this.model.sortSettings.sortedColumns.length; i++)
                this._addSortElementToColumn(this.model.sortSettings.sortedColumns[i].field, this.model.sortSettings.sortedColumns[i].direction);
            if (this.model.groupSettings.groupedColumns.length == 0) {
                $groupDrop.html(this.model.groupSettings.enableDropAreaAnimation ? "" : this._getLocalizedLabels("GroupDropArea"));
                this.model.groupSettings.enableDropAreaAutoSizing && $groupDrop.append(ej.buildTag("div.e-animatebutton e-icon").addClass(this.model.groupSettings.enableDropAreaAnimation ? "e-animatebuttondown e-gdownarrow" : "e-animatebuttonup e-guparrow"));
                $groupDrop.css("height", "auto");
            }
            if (ej.gridFeatures.dragAndDrop)
                this._headerCellgDragDrop();
            if (this.model.allowReordering && ej.gridFeatures.dragAndDrop)
                this._headerCellreorderDragDrop();
            this.model.allowScrolling && this.getContentTable().parent().scrollLeft(this.getHeaderTable().parent().scrollLeft() + 10);
            this.element.children(".e-cloneproperties").remove();
			if (ej.gridFeatures.filter && ["menu", "excel"].indexOf(this.model.filterSettings.filterType))
                this._refreshFilterIcon();
        },
        _getToggleButton: function () {
            return ej.buildTag("span.e-togglegroupbutton e-icon e-groupbutton", "&nbsp;");
        },
        _checkEinHeader: function (field) {
            var $headerCell = this.element.children(".e-gridheader").find("thead").find(".e-columnheader").find(".e-headercell");
            for (var i = 0; i < $headerCell.length; i++) {
                if ($.trim($headerCell.eq(i).text()) == field)
                    return $headerCell.eq(i);
                else if (this.model.allowSorting && this.model.allowMultiSorting) {
                    var header = $($headerCell.eq(i)).clone();
                    header.find(".e-number").remove();
                    if ($.trim(header.text()) == field)
                        return header;
                }
            }
            return null;

        },

        _checkEinGroupDrop: function (field) {
            var $groupHeaderCell = this.element.children(".e-groupdroparea").find(".e-grid-icon");
            for (var i = 0; i < $groupHeaderCell.length; i++) {
                if ($.trim($groupHeaderCell.eq(i).text()) == field)
                    return $groupHeaderCell.eq(i);
            }
            return null;
        },

        _addColumnToGroupDrop: function (field) {
            var $groupedColumn = ej.buildTag("div.e-grid-icon e-groupheadercell"), $groupDropArea = this.element.find(".e-groupdroparea").first();
            var $childDiv = ej.buildTag("div"), imageDirection = "e-rarrowup-2x";
            var column = this.getColumnByField(field)
            if (column.disableHtmlEncode)
                $groupedColumn.append($childDiv.text(column.headerText));
            else
                $groupedColumn.append($childDiv.html(column.headerText));
            var $headerCell = this._checkEinHeader(column.headerText);
            if (this.model.groupSettings.showToggleButton) {
                $childDiv.append(this._getToggleButton().addClass("e-toggleungroup"));
                $headerCell.find(".e-headercelldiv").find(".e-togglegroupbutton").remove().end().append(this._getToggleButton().addClass("e-toggleungroup"));
            }
            var direction = "ascending";
            if ($headerCell.find(".e-ascending,.e-descending").length) {
                direction = $headerCell.find(".e-ascending,.e-descending").hasClass("e-ascending") ? "ascending" : "descending";
                imageDirection = direction == "ascending" ? "e-rarrowup-2x" : "e-rarrowdown-2x";
            }
            $childDiv.append(this._createSortElement().addClass("e-" + direction + " " + imageDirection));
            this.model.groupSettings.showUngroupButton && $childDiv.append(ej.buildTag("span.e-ungroupbutton e-icon e-cancel", " ", {}, { title: "Click here to ungroup" }));
            $groupDropArea.append($groupedColumn).css("height", "auto");
            var left = $groupedColumn.offset().left, $cloned = $groupedColumn.clone().css("position", "absolute"), proxy = this;
            $groupedColumn.css("visibility", "hidden")
            $groupDropArea.append($cloned).dequeue();
            $cloned.css({ "left": left + 150 }).animate({ left: left }, 150, function (e) {
                $groupedColumn.css("visibility", "visible");
                $cloned.remove();
            });
        },
        _removeColumnFromDrop: function (field) {
            var headerText = this.getHeaderTextByFieldName(field), proxy = this, $groupDropArea = this.element.children(".e-groupdroparea");
            var $groupHeaderCell = $groupDropArea.css("height", "30px").find(".e-grid-icon");
            for (var i = 0; i < $groupHeaderCell.length; i++) {
                if ($.trim($groupHeaderCell.eq(i).text()) == headerText) {
                    if (this.model.groupSettings.groupedColumns.length == 0) {
                        this.collapseGroupDropArea();
                    } else
                        $groupHeaderCell.eq(i).remove();
                }
            }
        },
        _setAggreatedCollection: function (clonedQuery) {
            if (this._dataSource() instanceof ej.DataManager && this._dataManager.dataSource.url != undefined && !this._isRemoteSaveAdaptor)
                return;
            var data;            
            data = this._dataManager.executeLocal(clonedQuery).result;
            this._aggregatedCollection = data;
        },        
        _setAggregates: function (data, collection) {
            var indx, pred, query = new ej.Query();
            data = data || this.model.currentViewData, collection = collection || this._aggregatedCollection;
            var dLen = data.length, cLen;
            if (dLen != 0)
            pred = ej.Predicate("field", "equal", data[0].field)["and"]("key", "equal", data[0].key);
            for (indx = 1; indx < dLen; indx++) {
                pred = pred["or"](ej.Predicate("field", "equal", data[indx].field)["and"]("key", "equal", data[indx].key));
            }
            collection = pred ? new ej.DataManager(collection).executeLocal(query.where(pred)) : collection;
            cLen = collection.length;
			if (data.length > 0) {
				for (indx = 0; indx < cLen; indx++) {
					if(indx > 0  && indx < cLen - 1) continue;
					data[indx].count = collection[indx].count; /*Updating the count*/
					if (data[indx].items.GROUPGUID)
						this._setAggregates(data[indx].items, collection[indx].items);
					if (this.model.showSummary) { /*Adding extra property which will contain aggregates*/
						var agg = data[indx]["aggregates"] = [];
						var rows = this.model.summaryRows, scolumns, summaryData;
						for (var row = 0, rlen = rows.length; row < rlen; row++) {
							scolumns = rows[row].summaryColumns, obj = {};
							for (var col = 0, clen = scolumns.length; col < clen; col++) {
								summaryData = collection[indx].items.level ? collection[indx].items.records : collection[indx].items;
								obj[scolumns[col].dataMember] = this._getSummaryValues(scolumns[col], summaryData);
							}
							agg.push(obj);
						}
					}
				}
			}
        },
    };
})(jQuery, Syncfusion);;
(function ($, ej, undefined) {
    ej.gridFeatures = ej.gridFeatures || {};
    ej.gridFeatures.dragAndDrop = {
        _headerCellgDragDrop: function () {
            var proxy = this;
            this.dragHeaderElement();
            var $droppableElements = this.element.children("div.e-groupdroparea");
            $droppableElements.ejDroppable({
                accept: $droppableElements,
                drop: function (event, ui) {
                    if (ej.isNullOrUndefined(ui.helper) || !ui.helper.is(":visible"))
                        return;
                    if (ui.draggable.attr("aria-sort") == "ascending" || ui.draggable.attr("aria-sort") == "descending") {
                        var scolumn = proxy.getColumnByHeaderText($.trim(ui.draggable.text()));
                        if (proxy.model.allowSorting && proxy.model.allowMultiSorting)
                            proxy._scolumns.push(scolumn.field);
                        else
                            proxy._gridSort = scolumn.field;
                    }
                    var column = proxy.getColumnByHeaderText($.trim(ui.helper.text()));
                    ui.helper.remove();
                    if ($.inArray(column["headerText"], proxy._disabledGroupableColumns) != -1)
                        return;
                    if (!ej.isNullOrUndefined(column.field))
                        proxy.groupColumn(column.field);
                }
            });
        },
        _headerCellreorderDragDrop: function () {
            var proxy = this;
            this.dragHeaderElement();
            var $droppableElements = this.element.find(".e-headercelldiv");
            $droppableElements.ejDroppable({
                accept: $droppableElements,
                drop: function (event, ui) {
                    if (ej.isNullOrUndefined(ui.helper) || !ui.helper.is(":visible"))
                        return;
                    if (ui.draggable.attr("aria-sort") == "ascending" || ui.draggable.attr("aria-sort") == "descending") {
                        var scolumn = proxy.getColumnByHeaderText($.trim(ui.draggable.text()));
                        if (proxy.model.allowSorting && proxy.model.allowMultiSorting)
                            proxy._scolumns.push(scolumn.field);
                        else
                            proxy._gridSort = scolumn.field;
                    }
                    var column = proxy.getColumnByHeaderText($.trim(ui.helper.text()));
                    ui.helper.remove();
                    if ($.inArray(column["headerText"], proxy._disabledGroupableColumns) != -1)
                        return;
                    var header = $(event.dropTarget).clone();
                    header.find(".e-number").remove();
                    if (!ej.isNullOrUndefined(column.field)) {
                        if (proxy.model.allowSorting && proxy.model.allowMultiSorting)
                            if (event.dropTarget.hasClass("e-number") || event.dropTarget.hasClass("e-icon")) {
                                var toColumn = proxy.getColumnByHeaderText($.trim(header.text()));
                            }
                            else {
                                var toColumn = proxy.getColumnByHeaderText($.trim(header.text()));
                            }
                        else {
                              if (event.dropTarget.hasClass("e-icon"))
                                var toColumn = proxy.getColumnByHeaderText($.trim($(event.dropTarget.parent()).text()));
                              else
                                var toColumn = proxy.getColumnByHeaderText($.trim($(event.dropTarget).text()));
                             }
                        proxy.reorderColumns(column.field, toColumn.field);
                    }
                }
            });
        },

        dragHeaderElement: function () {
            var proxy = this;
            var $dragableElements = this.element.children("div.e-gridheader").find("th.e-headercell").not(".e-headertemplate,.e-detailheadercell");
            var $visualElement = ej.buildTag('div.e-cloneproperties e-grid', "", { 'height': '20px', 'z-index': 2 }),column;
            //header element columnDrag
            $dragableElements.ejDraggable({
                cursorAt: { top: -50, left: -2 },
                helper: function (event, ui) {
                    if (proxy.element.find(".e-dragclone").length > 0) proxy.element.find(".e-dragclone").remove();
                    var $th;
                    if ($(event.sender.target).hasClass("e-headercell"))
                        $th = $(event.sender.target);
                    else
                        $th = $(event.sender.target).closest("th");
                    column = proxy.getColumnByField($th.find(".e-headercelldiv").attr("ej-mappingname"));
                    if (proxy.model.allowSorting && proxy.model.allowMultiSorting) {
                        var header = $($th).clone();
                        header.find(".e-number").remove();
                        return $visualElement.text(header.text()).clone().width($th.outerWidth() + 2).height($th.height() + 2).css({ "font-size": parseInt(($th.height() + 3) / 2) }).addClass("e-dragclone").appendTo(proxy.element);
                    }
                    else
                        return $visualElement.text($th.text()).clone().width($th.outerWidth() + 2).height($th.height() + 2).css({ "font-size": parseInt(($th.height() + 3) / 2) }).addClass("e-dragclone").appendTo(proxy.element);
                },
                dragStart: function (args) {
                    var target = args.target;
                    var data = { target: target, draggableType: "headercell", column: column };
                    if (proxy._resizer != null && proxy._resizer._expand) {
                        $(".e-dragclone").remove();
                        return false;
                    }
                    proxy._dragActive = true;
                    var $target = proxy.element.find(".e-groupdroparea");
                    if (proxy.model.allowGrouping)
                        proxy.expandGroupDropArea();
                    if (proxy._trigger("columnDragStart", data))
                        return false;
                },
                drag: function (args) {
                    var $target = $(args.target);
                    var data = { target: $target, draggableType: "headercell", column: column };
                    if (proxy._trigger("columnDrag", data))
                        return false;

                    if ($target.hasClass('e-headercelldiv') && proxy.model.allowReordering) {
                        document.body.style.cursor = '';
                        $target.addClass("e-allowDrop");
                        proxy.getHeaderTable().find(".e-reorderindicate").removeClass("e-reorderindicate");
                        $target.parent().addClass("e-reorderindicate");
                    }
                    if ($target.hasClass('e-groupdroparea') || $target.closest('.e-groupdroparea').length) {
                        document.body.style.cursor = '';
                        $target.addClass("e-allowDrop");
                    } else
                        document.body.style.cursor = 'not-allowed';
                },
                dragStop: function (args) {
                    if (!args.element.dropped) {
                        var $target = $(args.target);
                        var data = { target: $target, draggableType: "headercell", column: column };
                        proxy._trigger("columnDrop", data);
                        proxy.element.find(".e-groupdroparea").removeClass("e-hover");
                        proxy.getHeaderTable().find(".e-columnheader").find(".e-headercellactive").removeClass("e-headercellactive").removeClass("e-active");
                        $(".e-dragclone").remove();
                        proxy._dragActive = false;
                        proxy.getHeaderTable().find(".e-reorderindicate").removeClass("e-reorderindicate");
                        if (proxy.model.allowGrouping)
                            proxy.collapseGroupDropArea();
                        document.body.style.cursor = '';
                        $(proxy._Indicator).css('display', 'none');
                    }
                }
            });
        },
        _groupHeaderCelldrag: function () {
            //grouped header cell drag.
            var $visualElement = ej.buildTag('div.e-cloneproperties e-grid', "", { 'height': '20px', 'z-index': 2 });
            var proxy = this;
            var $groupedHeaderCells = this.element.children(".e-groupdroparea").find(".e-groupheadercell");
            $groupedHeaderCells.ejDraggable({
                cursorAt: { top: -35, left: -2 },
                helper: function (event, ui) {
                    var $div = $(event.sender.target).closest(".e-grid-icon");
                    return $visualElement.text($(event.sender.target).closest(".e-groupheadercell").text()).clone().width($div.width() + 2).height($div.height() + 2).addClass("e-dragclone").appendTo(proxy.element);
                },
                dragStart: function (args) {
                    var target = args.target;
					args.model.cursorAt = { top: -35, left: -2 };
                    var data = { target: target, draggableType: "groupheadercell" };
                    if (proxy._trigger("columnDragStart", data))
                        return false;
                },
                drag: function (args) {
                    $(".Sibling").remove();
                    var $target = $(args.target);
                    var data = { target: $target, draggableType: "groupheadercell" };
                    if (proxy._trigger("columnDrag", data))
                        return false;
                    if ($target.closest('div.e-gridcontent').length) {
                        document.body.style.cursor = '';
                        $target.addClass("e-allowDrop");
                    } else
                        document.body.style.cursor = 'not-allowed';
                },
                dragStop: function (args) {
                    if (!args.element.dropped) {
                        var $target = $(args.target);
                        var data = { target: $target, draggableType: "groupheadercell" };
                        proxy._trigger("columnDrop", data);
                        $(".e-dragclone").remove();
                        document.body.style.cursor = '';
                    }
                }
            });

            //grid content drop
            var $contentDroppableElements = this.element.children(".e-gridcontent");
            $contentDroppableElements.ejDroppable({
                accept: proxy.element.children("div.e-groupdroparea").find(".e-groupheadercell"),
                drop: function (event, ui) {
                    if (ej.isNullOrUndefined(ui.helper) || !ui.helper.is(":visible") || !ui.draggable.hasClass("e-groupheadercell"))
                        return;
                    var field = proxy.getFieldNameByHeaderText($.trim(ui.draggable.text()));
                    ui.helper.remove();
                    if (!ej.isNullOrUndefined(field))
                        proxy.ungroupColumn(field);


                }
            });
        },
    };
})(jQuery, Syncfusion);;
(function ($, ej, undefined) {
    ej.gridFeatures = ej.gridFeatures || {};
    ej.gridFeatures.selection = {
        /**
         * Select rows in grid.
         * @alias ejGrid#selectRows
         * @return jQuery
         * @param { number } fromIndex It is used to set the starting index of row for selecting rows.
         * @param { number } toIndex It is used to set the ending index of row for selecting rows.
         * @example 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // Selects rows based on the given index
         * gridObj.selectRows(1, 4); 
         * &lt;/script&gt;
         * @example 
         * &lt;script&gt;
         * // Selects rows based on the given index
         * $("#Grid").ejGrid("selectRows", 1, 4);
         * &lt;/script&gt;
         */
        selectRows: function (rowIndex, toIndex, target) {
            if (!this.model.allowSelection)
                return false;
            var $gridRows = $(this.getRows());
            var args = {};  
			var Data = this._currentJsonData[rowIndex];
			if(this.model.scrollSettings.allowVirtualScrolling){			
				var pageSize = this.model.pageSettings.pageSize;
				var nameIndx = this.getRowByIndex(rowIndex).attr("name");                
				var pageIndex = !ej.isNullOrUndefined(nameIndx) ? (parseInt(nameIndx)/pageSize) + 1 : rowIndex;
				var $vLen = this.getRowByIndex(rowIndex).prevAll(".e-virtualrow").length;
				var trIndex = (rowIndex - $vLen)%(pageSize);
				var query = ej.Query().page(pageIndex,pageSize);
				var result = this._dataManager.executeLocal(query);
				Data = result[trIndex];
			}
		    args = { rowIndex: rowIndex, row: $gridRows.eq(rowIndex), data: Data, target: target, prevRow: this.getRowByIndex(this._previousIndex), prevRowIndex : this._previousIndex };
            if (this._trigger("rowSelecting", args))
                return;
            if ((this.model.editSettings.allowEditing || this.model.editSettings.allowAdding) && this.model.isEdit && this.model.enableAutoSaveOnSelectionChange) {
                if (this.model.editSettings.editMode == "externalform" || this.model.editSettings.editMode == "externalformtemplate")
                    $("#" + this._id + "_externalEdit").css("display", "none");
                if (this.endEdit())
                    return;
                var $gridRows = $(this.getRows());
            }
            if (ej.isNullOrUndefined(toIndex) || ej.isNullOrUndefined(rowIndex)) {
                rowIndex = ej.isNullOrUndefined(rowIndex) ? toIndex : rowIndex;
                switch (this.model.selectionType) {
                    case ej.Grid.SelectionType.Multiple:
                        if (this.multiSelectCtrlRequest) {
                            var selectedRowIndex = $.inArray(rowIndex, this.selectedRowsIndexes);
                            selectedRowIndex != -1 && this.clearSelection(rowIndex) && this.selectedRowsIndexes.splice(selectedRowIndex, 0);
                            if (selectedRowIndex == -1) {
                                this.selectedRowsIndexes.push(rowIndex);
                                this.getRowByIndex(rowIndex).attr("aria-selected", "true").find('.e-rowcell, .e-detailrowcollapse, .e-detailrowexpand').addClass("e-selectionbackground e-active");
                            }
                            break;
                        }
                    case ej.Grid.SelectionType.Single:
                        this.clearSelection();
                        this.clearColumnSelection();
                        this.selectedRowsIndexes = [];
                        this.selectedRowsIndexes.push(rowIndex);
                        this.getRowByIndex(rowIndex).attr("aria-selected", "true").find('.e-rowcell, .e-detailrowcollapse, .e-detailrowexpand').addClass("e-selectionbackground e-active");
                        break;
                }
            } else {
                if (this.model.selectionType == ej.Grid.SelectionType.Multiple) {
                    this.clearSelection();
                    this.clearColumnSelection();
                    this.selectedRowsIndexes = [];
                    rows = rowIndex - toIndex < 0 ? this.getRowByIndex(rowIndex, toIndex + 1) : this.getRowByIndex(toIndex, rowIndex + 1);
                    for (var i = 0; i < rows.length; i++)
                        this.selectedRowsIndexes.push(rows[i].rowIndex);
                    $(rows).attr("aria-selected", "true").find('.e-rowcell, .e-detailrowcollapse, .e-detailrowexpand').addClass("e-selectionbackground e-active");
                }
            }
            if (this._selectedRow() !== rowIndex)
                this._selectedRow(rowIndex);
            var args = { rowIndex: this._selectedRow(), row: this.getRowByIndex(this._selectedRow()), data: Data, target: target, prevRow: this.getRowByIndex(this._previousIndex), prevRowIndex : this._previousIndex };
            this._previousIndex = this.selectedRowsIndexes.length ? rowIndex : undefined;
            this._trigger("rowSelected", args);
            // this.multiSelectCtrlRequest = false;
        },

        /**
         * Select cells in grid.
         * @alias ejGrid#selectCells
         * @return jQuery
         * @param { object } rowCellIndexes It is used to set the starting index of row and indexes of cells for that corresponding row for selecting cells.
         * @example 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // Selects cells based on the given index
         * gridObj.selectCells([[1, [4, 3, 2]]]); 
         * &lt;/script&gt;
         * @example 
         * &lt;script&gt;
         * // Selects cells based on the given index
         * $("#Grid").ejGrid("selectCells", [[1, [4, 3, 2]]]);
         * &lt;/script&gt;
         */
        selectCells: function (rowCellIndexes) {
            if (!this.model.allowSelection && !this._allowcellSelection)
                return false;
            var $cell = $(this.getRowByIndex(rowCellIndexes[0][0]).find(".e-rowcell:eq(" + rowCellIndexes[0][1] + ")"));
            if(!ej.isNullOrUndefined(this._previousRowCellIndex))
                var previousRowCell = $(this.getRowByIndex(this._previousRowCellIndex[0][0]).find(".e-rowcell:eq("+this._previousRowCellIndex[0][1]+")"))	
            var args = { currentCell: $cell, cellIndex: rowCellIndexes[0][1], data: this._currentJsonData[rowCellIndexes[0][0]], previousRowCellIndex: this._previousRowCellIndex, previousRowCell: previousRowCell };
            if (this.model.selectionType == "multiple") {
                args["isCtrlPressed"] = this.multiSelectCtrlRequest;
                args["isShiftPressed"] = this._multiSelectShiftRequest;
            }
            if (this._trigger("cellSelecting", args))
                return;
            switch (this.model.selectionType) {
                case ej.Grid.SelectionType.Multiple:
                    if (this.multiSelectCtrlRequest) {
                        var selectedCellIndex = $.inArray(rowCellIndexes[0][0], this._rowIndexesColl);
                        if (selectedCellIndex != -1)
                            this.selectedRowCellIndexes[selectedCellIndex].cellIndex.push(parseInt(rowCellIndexes[0][1].toString()));
                        else {
                            if ($.inArray(rowCellIndexes[0][0], this._rowIndexesColl) == -1)
                                this._rowIndexesColl.push(rowCellIndexes[0][0]);
                            this.selectedRowCellIndexes.push({ rowIndex: rowCellIndexes[0][0], cellIndex: rowCellIndexes[0][1] });
                        }
                        $cell.addClass("e-cellselectionbackground e-activecell");
                        break;
                    }
                    else if (this._multiSelectShiftRequest) {
                        this.clearCellSelection();
                        this.clearColumnSelection();
                        this.selectedRowCellIndexes = [];
                        var previousRowIndex = this._previousRowCellIndex[0][0];
                        var previousCellIndex = parseInt(this._previousRowCellIndex[0][1]);
                        var currentRowIndex = rowCellIndexes[0][0];
                        var currentCellIndex = parseInt(rowCellIndexes[0][1]);
                        var newCellColl = [];
                        var min, max;
                        if (currentRowIndex > previousRowIndex) {
                            for (var i = previousRowIndex; i <= currentRowIndex; i++) {
                                newCellColl = [];
                                min = i == previousRowIndex ? previousCellIndex : 0;
                                max = i == currentRowIndex ? currentCellIndex : this.model.columns.length;
                                for (var j = min; j <= max; j++) {
                                    newCellColl.push(j);
                                    $(this.getRowByIndex(i).find(".e-rowcell:eq(" + j + ")")).addClass("e-cellselectionbackground e-activecell");
                                }
                                this.selectedRowCellIndexes.push({ rowIndex: i, cellIndex: newCellColl });
                            }
                        } else {
                            for (var i = previousRowIndex; i >= currentRowIndex; i--) {
                                newCellColl = [];
                                min = i == previousRowIndex ? previousCellIndex : this.model.columns.length;
                                max = i == currentRowIndex ? currentCellIndex : 0;
                                for (var j = min; j >= max; j--) {
                                    newCellColl.push(j);
                                    $(this.getRowByIndex(i).find(".e-rowcell:eq(" + j + ")")).addClass("e-cellselectionbackground e-activecell");
                                }
                                this.selectedRowCellIndexes.push({ rowIndex: i, cellIndex: newCellColl });
                            }
                        }
                        break;
                    }
                case ej.Grid.SelectionType.Single:
                    this.clearCellSelection();
                    this.clearColumnSelection();
                    this.selectedRowCellIndexes = [];
                    if ($.inArray(rowCellIndexes[0][0], this._rowIndexesColl) == -1)
                       this._rowIndexesColl.push(rowCellIndexes[0][0]);
                    this.selectedRowCellIndexes.push({ rowIndex: rowCellIndexes[0][0], cellIndex: rowCellIndexes[0][1] });
                    $(this.getRowByIndex(rowCellIndexes[0][0]).find(".e-rowcell:eq(" + rowCellIndexes[0][1] + ")")).addClass("e-cellselectionbackground e-activecell");
                    break;
            }
            var args = { currentCell: $cell, cellIndex: rowCellIndexes[0][1], data: this._currentJsonData[rowCellIndexes[0][0]], selectedRowCellIndex: this.selectedRowCellIndexes, previousRowCellIndex: this._previousRowCellIndex, previousRowCell: previousRowCell};
            if (!this._multiSelectShiftRequest) this._previousRowCellIndex = rowCellIndexes;
            if (this._trigger("cellSelected", args))
                return;
        },

        /**
         * Select columns in grid.
         * @alias ejGrid#selectColumns
         * @return jQuery
         * @param { number } fromIndex It is used to set the starting index of column for selecting columns.
         * @example 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // Selects columns based on the given index
         * gridObj.selectColumns(1,4); 
         * &lt;/script&gt;
         * @example 
         * &lt;script&gt;
         * // Selects columns based on the given index
         * $("#Grid").ejGrid("selectColumns", 1, 4);
         * &lt;/script&gt;
         */
        selectColumns: function (columnIndex, toIndex) {
            if (!this.model.allowcolumnSelection && !this.model.allowSelection)
                return false;
            var gridRows = this.getRows();
            var prevColumnHeaderCell = this.getHeaderTable().find("th.e-headercell:visible")[this._previousColumnIndex];
            var args = { columnIndex: columnIndex == undefined ? toIndex : columnIndex, headerCell: $(this.getHeaderTable().find("th.e-headercell:visible")[columnIndex]), column: this.model.columns[columnIndex], previousColumnIndex: this._previousColumnIndex, prevColumnHeaderCell: prevColumnHeaderCell };
            if (this.model.selectionType == "multiple") {
                args["isCtrlPressed"] = this.multiSelectCtrlRequest;
                args["isShiftPressed"] = this._multiSelectShiftRequest;
            }
            if (this._trigger("columnSelecting", args))
                return;
            if (ej.isNullOrUndefined(toIndex) || ej.isNullOrUndefined(columnIndex)) {
                columnIndex = ej.isNullOrUndefined(columnIndex) ? toIndex : columnIndex;
                switch (this.model.selectionType) {
                    case ej.Grid.SelectionType.Multiple:
                        if (this.multiSelectCtrlRequest) {
                            var selectedColumnIndex = $.inArray(columnIndex, this.selectedColumnIndexes);
                            selectedColumnIndex != -1 && this.clearColumnSelection(columnIndex) && this.selectedColumnIndexes.splice(selectedColumnIndex, 0);
                            if (selectedColumnIndex == -1) {
                                this.selectedColumnIndexes.push(columnIndex);
                                for (var i = 0; i < gridRows.length; i++) {
                                    $(gridRows[i].cells[columnIndex]).addClass("e-columnselection");
                                }
                                $(this.getHeaderTable().find("th.e-headercell:visible")[columnIndex]).addClass("e-columnselection");
                            }
                            break;
                        }
                    case ej.Grid.SelectionType.Single:
                        this.clearSelection();
                        this.clearCellSelection();
                        this.clearColumnSelection();
                        this.selectedColumnIndexes = [];
                        this.selectedColumnIndexes.push(columnIndex);
                        for (var i = 0; i < gridRows.length; i++) {
                            $(gridRows[i].cells[columnIndex]).addClass("e-columnselection");
                        }
                        $(this.getHeaderTable().find("th.e-headercell:visible")[columnIndex]).addClass("e-columnselection");
                        break;
                }
            } else {
                if (this.model.selectionType == ej.Grid.SelectionType.Multiple) {
                    this.clearColumnSelection();
                    this.selectedColumnIndexes = [];
                    var startIndex = columnIndex > toIndex ? toIndex : columnIndex;
                    var endIndex = columnIndex > toIndex ? columnIndex + 1 : toIndex + 1;
                    for (var i = startIndex; i < endIndex; i++) {
                        for (var j = 0; j < gridRows.length; j++) {
                            $(gridRows[j].cells[i]).addClass("e-columnselection");
                        }
                        $(this.getHeaderTable().find("th.e-headercell:visible")[i]).addClass("e-columnselection");
                        this.selectedColumnIndexes.push(i);
                    }
                }
            }
            var args = { columnIndex: columnIndex == undefined ? toIndex : columnIndex, headerCell: $(this.getHeaderTable().find("th.e-headercell:visible")[columnIndex]), column: this.model.columns[columnIndex], selectedColumnIndex: this.selectedColumnIndexes, previousColumnIndex: this._previousColumnIndex, prevColumnHeaderCell: prevColumnHeaderCell};
            this._previousColumnIndex = this.selectedColumnIndexes.length ? columnIndex : undefined;
            if (this._trigger("columnSelected", args))
                return;
        },
        /**
         * Clear all the row selection or at specific row selection based on the index provided
         * @alias ejGrid#clearSelection
         * @return jQuery
         * @param {number} [index] If index of the row is specified then it will remove the selection from the particular row else it will clears all of the row selection
         * @example 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * gridObj.clearSelection(2);  // Removes the selection based on the row index
         * gridObj.clearSelection();  // clears all of the row selection
         * &lt;/script&gt;
         * @example 
         * &lt;script&gt;
         * // Removes the selection based on the row index
         * $("#Grid").ejGrid("clearSelection", 2);   
         * // clears all of the row selection
         * $("#Grid").ejGrid("clearSelection");        
         * &lt;/script&gt;
         */
        clearSelection: function (index) {
            if (this._selectedRow() >= -1) {
                var $gridRows = $(this.getRows()), index;
                if (!ej.isNullOrUndefined(index)) {
                    this.getRowByIndex(index).removeAttr("aria-selected").find(".e-selectionbackground").removeClass("e-selectionbackground").removeClass("e-active");
                    index = $.inArray(index, this.selectedRowsIndexes);
                    if (index != -1)
                        this.selectedRowsIndexes.splice(index, 1);
                } else {
                    if (this.model.scrollSettings.frozenColumns > 0)
                        $gridRows = $($gridRows[0]).add($gridRows[1]);
                    $gridRows.removeAttr("aria-selected").find(".e-rowcell, .e-detailrowcollapse, .e-detailrowexpand").removeClass("e-selectionbackground").removeClass("e-active");
                }
                if (!this.selectedRowsIndexes.length)
                    this._selectedRow(-1);
            }
            return true;
        },
        /**
         * It is used to clear all the cell selection.
         * @alias ejGrid#clearCellSelection
         * @return jQuery
         * @example 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * gridObj.clearCellSelection();  // clears all of the cell selection
         * &lt;/script&gt;
         * @example 
         * &lt;script&gt;         
         * // clears all of the cell selection
         * $("#Grid").ejGrid("clearCellSelection");        
         * &lt;/script&gt;
         */
        clearCellSelection: function () {
            if (this._allowcellSelection) {
                var $gridRows = $(this.getRows());
                $gridRows.find(".e-rowcell, .e-detailrowcollapse, .e-detailrowexpand").removeClass("e-cellselectionbackground").removeClass("e-activecell");
                this.selectedRowCellIndexes = [];
                this._rowIndexesColl = [];
            }
            return true;
        },

        /**
        * It is used to clear all the row selection or at specific row selection based on the index provided.
        * @alias ejGrid#clearColumnSelection
        * @return jQuery
        * @param {number} [index] If index of the column is specified then it will remove the selection from the particular column else it will clears all of the column selection
        * @example 
        * &lt;script&gt;
        * // Create grid object.
        * var gridObj = $("#Grid").data("ejGrid");
        * gridObj.clearColumnSelection(2);  // Removes the selection based on the column index
        * gridObj.clearColumnSelection();  // clears all of the column selection
        * &lt;/script&gt;
        * @example 
        * &lt;script&gt;
        * // Removes the selection based on the column index
        * $("#Grid").ejGrid("clearColumnSelection", 2);   
        * // clears all of the column selection
        * $("#Grid").ejGrid("clearColumnSelection");        
        * &lt;/script&gt;
        */
        clearColumnSelection: function (index) {
            if (this._allowcolumnSelection) {
                var $gridRows = $(this.getRows());
                if (!ej.isNullOrUndefined(index)) {
                    for (var i = 0; i < $gridRows.length; i++) {
                        $($gridRows[i].cells[index]).removeClass("e-columnselection");
                    }
                    $(this.getHeaderTable().find("th.e-headercell:visible")[index]).removeClass("e-columnselection");
                    this.selectedColumnIndexes.splice(0, index);

                } else {
                    $gridRows.find(".e-rowcell").removeClass("e-columnselection");
                    $(this.getHeaderTable().find("th.e-headercell:visible")).removeClass("e-columnselection");
                    this.selectedColumnIndexes = [];
                }
            }
            return true;
        },
        /**
         * Get the selected records details in grid.
         * @alias ejGrid#getSelectedRecords
         * @return selectedRecords
         * @example 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // Gets the selected row list
         * gridObj.getSelectedRecords();
         * &lt;/script&gt;
         * @example 
         * &lt;script&gt;
         * // Gets the selected row list
         * $("#Grid").ejGrid("getSelectedRecords");        
         * &lt;/script&gt;
         */
        getSelectedRecords: function () {
            var records = [];
            for (var i = 0; i < this.selectedRowsIndexes.length; i++) {
                if (this.selectedRowsIndexes[i] != -1)
                    records.push(this._currentJsonData[this.selectedRowsIndexes[i]]);
            }
            return records;
        },
        _setCurrentRow: function (requestType) {
            if (requestType == ej.Grid.Actions.Refresh || requestType == ej.Grid.Actions.Filtering || requestType == ej.Grid.Actions.Sorting || requestType == ej.Grid.Actions.Delete || requestType == ej.Grid.Actions.Save || requestType == ej.Grid.Actions.Cancel || requestType == ej.Grid.Actions.Paging) {
                this._selectedRow(-1);
                this.selectedRowsIndexes = [];
            }
        },
        _renderMultiTouchDialog: function () {
            this._customPop = ej.buildTag("div.e-gridpopup", "", { display: "none" });
            var $content = ej.buildTag("div.e-content"), $downTail = ej.buildTag("div.e-downtail e-tail");
            if (this.model.allowMultiSorting) {
                var $selElement = ej.buildTag("span.e-sortdirect e-icon");
                $content.append($selElement);
            }
            if (this.model.selectionType == ej.Grid.SelectionType.Multiple) {
                var $selElement = ej.buildTag("span.e-rowselect e-icon");
                $content.append($selElement);
            }
            this._customPop.append($content);
            this._customPop.append($downTail);
            this.element.append(this._customPop);
        },
    };
})(jQuery, Syncfusion);;
(function ($, ej, undefined) {
	ej.gridFeatures = ej.gridFeatures || {};
   /**   
    * @classdesc The grid can be easily configured to the DOM element, such as div. you can create a grid with a highly customizable look and feel.
    * @class ejGrid
    * @param {object} options - settings for grid
    * @requires jQuery
    * @requires jquery.easing.min.js
    * @requires jquery.globalize.min.js    
    * @requires jsrender.min.js
    * @requires ej.core.js
    * @requires ej.data.js
    * @requires ej.grid.js
    * @requires ej.pager.js
    * @requires ej.scroller.js
    * @requires ej.waitingpopup.js
    * @requires ej.radiobutton.js
    * @requires ej.dropdownlist.js
    * @requires ej.dialog.js
    * @requires ej.button.js
    * @requires ej.autocomplete.js
    * @requires ej.checkbox.js
    * @requires ej.datepicker.js
    * @requires ej.datetimepicker.js
    * @requires ej.editor.js
    * @requires ej.toolbar.js
    * @example
    * &lt;div id="Grid"&gt;&lt;/div&gt; 
    * &lt;script&gt;
    * // Create Grid
    * $('#Grid').ejGrid({
    *     dataSource: window.gridData
    * });         
    * &lt;/script&gt;
    */
    ej.widget("ejGrid", "ej.Grid", /** @lends ejGrid# */ {
        //Root Css Class
        _rootCSS: "e-grid",
        // widget element will be automatically set in this
        element: null,
        validTags: ["div"],
        // user defined model will be automatically set in this
        model: null,
        keyConfigs: /** @lends ejGrid# */{
            focus: "e",
            insertRecord: "45", //Insert
            deleteRecord: "46", // delete
            editRecord: "113", //F2
            saveRequest: "13", // enter
            cancelRequest: "27", //Esc
            nextPage: "34", // PgDn
            previousPage: "33", // PgUp
            lastPage: "ctrl+alt+34", //"CtrlAltPgDn",
            firstPage: "ctrl+alt+33", //"CtrlPlusAltPlusPgUp",
            nextPager: "alt+34", //"AltPlusPgDown",
            previousPager: "alt+33", //"AltPlusPgUp",
            firstCellSelection: "36", //"Home",
            lastCellSelection: "35", //"End",
            firstRowSelection: "ctrl+36", //"CtrlPlusHome",
            lastRowSelection: "ctrl+35", //"CtrlPlusEnd",
            upArrow: "38", //Up arrow
            downArrow: "40", //Down arrow
            rightArrow: "39", //Right arrow
            leftArrow: "37", //Left arrow
            moveCellRight: "9", //tab
            moveCellLeft: "shift+9", //shifttab
            selectedGroupExpand: "alt+40", //"AltPlusDownArrow",
            totalGroupExpand: "ctrl+40", //"CtrlPlusDownArrow",
            selectedGroupCollapse: "alt+38", //"AltPlusUpArrow",
            totalGroupCollapse: "ctrl+38" //"CtrlPlusUpArrow",
        },
        _ignoreOnPersist: [
            "query", "isEdit", "toolbarClick", "queryCellInfo", "mergeCellInfo", "currentViewData", "enableAltRow", "enableRTL","contextClick","contextOpen",
            "rowDataBound", "rowTemplate", "detailsDataBound", "detailsTemplate", "childGrid", "summaryRows", "toolbarSettings",
            "editSettings", "allowMultiSorting", "enableAutoSaveOnSelectionChange", "locale", "allowScrolling", "allowCellMerging",
            "allowTextWrap", "cssClass", "dataSource", "groupSettings.enableDropAreaAnimation", "enableRowHover", "showSummary",
            "enableHeaderHover", "allowKeyboardNavigation", "scrollSettings.frozenRows", "scrollSettings.frozenColumns", "enableTouch", "editSettings.rowPosition", "contextMenuSettings.enableContextMenu",
        ],
        ignoreOnExport: [
            "isEdit", "toolbarClick", "query", "queryCellInfo", "selectionType", "currentViewData", "enableAltRow", "enableRTL", "rowDataBound", "rowTemplate",
            "detailsDataBound", "detailsTemplate", "editSettings", "pageSettings", "enableAutoSaveOnSelectionChange", "localization", "allowScrolling",
            "cssClass", "dataSource", "groupSettings.enableDropAreaAnimation", "enableRowHover", "allowSummary",
            "enableHeaderHover", "allowKeyboardNavigation"
        ],
        observables: ["dataSource", "selectedRowIndex", "pageSettings.currentPage"],
        _tags: [{
            tag: "columns",
            attr: ["allowEditing", "allowFiltering", "allowGrouping", "allowSorting", "cssClass", "customAttributes", "dataSource", "defaultValue",
			"disableHtmlEncode", "editTemplate", "editType", "foreignKeyField", "foreignKeyValue", "headerTemplateID", "headerText", "isFrozen",
			"isIdentity", "isPrimaryKey", "isUnbound", "textAlign", "templateID", "textAlign", "headerTextAlign",
            "validationRules.minLength","validationRules.maxLength", "validationRules.range","validationRules.number", "validationRules.required",
            "editParams.decimalPlaces", [{tag:"commands", attr:["type","buttonOptions"]}]            
            ],
            content: "template"
        },{
            tag: "summaryRows",
            attr: ["showCaptionSummary", "showTotalSummary", [{
                tag: "summaryColumns", attr: ["customSummaryValue", "dataMember", "displayColumn", "summaryType"]
            }]]
        },{
            tag: "stackedHeaderRows",
            attr: [
            [{
            tag: "stackedHeaderColumns", attr:["headerText","column"]
            }]]            
        },{ 
			tag:"filterSettings.filteredColumns", attr: []
		},{ 
			tag:"sortSettings.sortedColumns", attr: [] 
		}],
        _dataSource: ej.util.valueFunction("dataSource"),
        _selectedRow: ej.util.valueFunction("selectedRowIndex"),
        _currentPage: ej.util.valueFunction("pageSettings.currentPage"),
        // default model
        defaults: /** @lends ejGrid# */ {

            /**		
             * This specifies the grid to show the paginated data. Also enables pager control at the bottom of grid for dynamic navigation through data source. Paging can be further customized through “pageSettings” property.
             * @default false
             * @type {boolean}
             * @example            
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *     dataSource:window.gridData,
             *     allowPaging:true                      
             * });
             * &lt;/script&gt;                 
             */
            allowPaging: false,
            /**		
             * Gets or sets a value that indicates whether to enable column chooser on grid. On enabling feature able to show/hide grid columns                       
             * @default false
             * @type {boolean}
             * @example            
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *     dataSource:window.gridData,
             *     showColumnChooser:true                      
             * });
             * &lt;/script&gt;                 
             */
            showColumnChooser: false,
            /**		
             * Gets or sets a value that indicates whether to  enable the dynamic sorting behaviour on grid data. Sorting can be done through clicking on particular column header.
             * @default false
             * @type {boolean}
             * @example  
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    dataSource:window.gridData,
             *    allowSorting:true                       
             * });
             * &lt;/script&gt; 
             */
            allowSorting: false,
            /**		
            * Gets or sets a value that indicates stacked header should be shown on grid layout when the property “stackedHeaderRows” is set.  
            * @default false
            * @type {boolean}
            * @example  
            * &lt;div id="Grid"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#Grid").ejGrid({
            *    dataSource:window.gridData,
            *    allowSorting:true,
            *    showStackedHeader:true,
            *    stackedHeaderRows:[{stackedHeaderColumns:[{headerText:"ID & Freight",column:"CustomerID"}
			*	 ,{headerText:"Frieght",column:"Freight,EmployeeID,OrderDate"}
			*	 ,{headerText:"Date & Location Top Level",column:"ShipCity"}
			*	   ]}
			*	  ],
            *    columns: [
            *       { field: "CustomerID", headerText: "Customer ID", width: 80 },
            *        { field: "EmployeeID", headerText: "Employee ID", width: 75, textAlign: ej.TextAlign.Right },
            *       { field: "Freight", width: 75, format: "{0:C}", textAlign: ej.TextAlign.Right },
            *        { field: "OrderDate", headerText: "Order Date", width: 80, format: "{0:MM/dd/yyyy}", textAlign: ej.TextAlign.Right },
            *       { field: "ShipCity", headerText: "Ship City", width: 110 }
            *       ]
            * });
            * &lt;/script&gt; 
            */
            showStackedHeader: false,
            /**		
            * Gets or sets an object that indicates to managing the collection of stacked header rows for the grid.
            * @remark
            * We must set the showStackedHeader as true
            * @default []
            * @name ejGrid#stackedHeaderRows
            * @type {array}
            * @example  
            * &lt;div id="Grid"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#Grid").ejGrid({
            *    dataSource:window.gridData,
            *    allowSorting:true,
            *    showStackedHeader:true,
            *    stackedHeaderRows:[{stackedHeaderColumns:[{headerText:"ID & Freight",column:"CustomerID"}
			*	 ,{headerText:"Frieght",column:"Freight,EmployeeID,OrderDate"}
			*	 ,{headerText:"Date & Location Top Level",column:"ShipCity"}
			*	   ]}
			*	  ],
            *    columns: [
            *       { field: "CustomerID", headerText: "Customer ID", width: 80 },
            *        { field: "EmployeeID", headerText: "Employee ID", width: 75, textAlign: ej.TextAlign.Right },
            *       { field: "Freight", width: 75, format: "{0:C}", textAlign: ej.TextAlign.Right },
            *        { field: "OrderDate", headerText: "Order Date", width: 80, format: "{0:MM/dd/yyyy}", textAlign: ej.TextAlign.Right },
            *       { field: "ShipCity", headerText: "Ship City", width: 110 }
            *       ]
            * });
            * &lt;/script&gt; 
            */
            /**		
             * Gets or sets a value that indicates whether to add stacked header columns into the stacked header rows
             * @remarks
             * We must enable the showStackedHeader 
             * @name ejGrid#stackedHeaderRows->stackedHeaderColumns
             * @default []
             * @type {array}
             * @example  
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    dataSource:window.gridData,
             *    allowSorting:true,
             *    showStackedHeader:true,
             *    stackedHeaderRows:[{stackedHeaderColumns:[{headerText:"ID & Freight",column:"CustomerID"}
             *	 ,{headerText:"Frieght",column:"Freight,EmployeeID,OrderDate"}
             *	 ,{headerText:"Date & Location Top Level",column:"ShipCity"}
             *	   ]}
             *	  ],
             *    columns: [
             *       { field: "CustomerID", headerText: "Customer ID", width: 80 },
             *        { field: "EmployeeID", headerText: "Employee ID", width: 75, textAlign: ej.TextAlign.Right },
             *       { field: "Freight", width: 75, format: "{0:C}", textAlign: ej.TextAlign.Right },
             *        { field: "OrderDate", headerText: "Order Date", width: 80, format: "{0:MM/dd/yyyy}", textAlign: ej.TextAlign.Right },
             *       { field: "ShipCity", headerText: "Ship City", width: 110 }
             *       ]
             * });
             * &lt;/script&gt; 
             **/
             /**		
             * Gets or sets a value that indicates the header text for the particular stacked header column.
             * @remarks
             * We must enable the showStackedHeader 
             * @name ejGrid#stackedHeaderRows->stackedHeaderColumns->headerText
             * @default null
             * @type {string}
             * @example  
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    dataSource:window.gridData,
             *    allowSorting:true,
             *    showStackedHeader:true,
             *    stackedHeaderRows:[{stackedHeaderColumns:[{headerText:"ID & Freight",column:"CustomerID"}
             *	 ,{headerText:"Frieght",column:"Freight,EmployeeID,OrderDate"}
             *	 ,{headerText:"Date & Location Top Level",column:"ShipCity"}
             *	   ]}
             *	  ],
             *    columns: [
             *       { field: "CustomerID", headerText: "Customer ID", width: 80 },
             *        { field: "EmployeeID", headerText: "Employee ID", width: 75, textAlign: ej.TextAlign.Right },
             *       { field: "Freight", width: 75, format: "{0:C}", textAlign: ej.TextAlign.Right },
             *        { field: "OrderDate", headerText: "Order Date", width: 80, format: "{0:MM/dd/yyyy}", textAlign: ej.TextAlign.Right },
             *       { field: "ShipCity", headerText: "Ship City", width: 110 }
             *       ]
             * });
             * &lt;/script&gt; 
             **/
            /**		
            * Gets or sets a value that indicates the header text for the particular stacked header column.
            * @remarks
            * We must enable the showStackedHeader 
            * @name ejGrid#stackedHeaderRows->stackedHeaderColumns->column
            * @default null
            * @type {string}
            * @example  
            * &lt;div id="Grid"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#Grid").ejGrid({
            *    dataSource:window.gridData,
            *    allowSorting:true,
            *    showStackedHeader:true,
            *    stackedHeaderRows:[{stackedHeaderColumns:[{headerText:"ID & Freight",column:"CustomerID"}
            *	 ,{headerText:"Frieght",column:"Freight,EmployeeID,OrderDate"}
            *	 ,{headerText:"Date & Location Top Level",column:"ShipCity"}
            *	   ]}
            *	  ],
            *    columns: [
            *       { field: "CustomerID", headerText: "Customer ID", width: 80 },
            *        { field: "EmployeeID", headerText: "Employee ID", width: 75, textAlign: ej.TextAlign.Right },
            *       { field: "Freight", width: 75, format: "{0:C}", textAlign: ej.TextAlign.Right },
            *        { field: "OrderDate", headerText: "Order Date", width: 80, format: "{0:MM/dd/yyyy}", textAlign: ej.TextAlign.Right },
            *       { field: "ShipCity", headerText: "Ship City", width: 110 }
            *       ]
            * });
            * &lt;/script&gt; 
            **/
			stackedHeaderRows: [],
            /**		
             * Gets or sets a value that indicates whether to enable dynamic filtering behaviour on grid. Filtering can be used to limit the records displayed using required criteria and this can be further customized through “filterSettings” property
             * @default false
             * @type {boolean}
             * @example  
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    dataSource:window.gridData,
             *    allowFiltering:true                       
             * });
             * &lt;/script&gt;
             */
            allowMultipleExporting:false,
            allowFiltering: false,
            /**		
             * Gets or sets a value that indicates whether user can select rows on grid. On enabling feature, selected row will be highlighted. 
             * @default true
             * @type {boolean}
             * @example 
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    dataSource:window.gridData,
             *    allowSelection:true                      
             * });
             * &lt;/script&gt; 
             */
            allowSelection: true,
            /**		
             * Gets or sets a value that indicates whether to enable dynamic grouping behaviour. Grouping can be done by drag on drop desired columns to grid’s GroupDropArea. This can be further customized through “groupSettings” property.
             * @default false
             * @type {boolean}
             * @example 
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    dataSource:window.gridData,
             *    allowGrouping:true                      
             * });
             * &lt;/script&gt; 
             */
            allowGrouping: false,
            /**		
             * Gets or sets a value that indicates summary rows should be shown on grid layout when the property “summaryRows” is set
             * @remarks
             * showSummary must be set as true.
             * summaryRows and summaryColumns must be given. See {@link ejGrid#summaryRows}
             * @default false
             * @type {boolean}
             * @example 
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *     dataSource:window.gridData,
             *     columns: [{ field: "OrderID"}, { field: "Freight" }, { field: "ShipCity" }],
             *     showSummary:true,
             *     summaryRows:[{ title: "sum", summaryColumns: [{summaryType:ej.Grid.SummaryType.Count,displayColumn:"Freight",dataMember:"Freight"}]}]       
             * });
             * &lt;/script&gt;  
             */
            showSummary: false,
            /**		
             * Gets or sets a value that indicates whether to enable dynamic resizabiliy of columns. . Resize the width of the columns by simply click and move the particular column header line
             * @remarks
             * When allowResizing is enabled then we must specify the following properties
             * 1. allowScrolling must be set as true
             * 2. Provide the scrollSettings after enable the allowScrolling. See{@link ejGrid#scrollSettings}            
             * @default false
             * @type {boolean}
             * @example 
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *     dataSource:window.gridData,
             *     allowResizing:true,
             *     allowScrolling:true,
             *     scrollSettings:{width:300,height:300}
             * });
             * &lt;/script&gt; 
             */
            allowResizing: false,
            /**		
            * Gets or sets a value that indicates whether the Content will wrap to the next line if the content exceeds the boundary of the Column Cells.
            * @default false
            * @type {boolean}
            * @example 
            * &lt;div id="Grid"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#Grid").ejGrid({
            *    dataSource:window.gridData,
            *    allowTextWrap:true                      
            * });
            * &lt;/script&gt; 
            */
            allowTextWrap: false,
			/**		
             * Gets or sets a value that indicates whether to customizing cell based on our needs.
             * @remarks
             * Provide the mergeSettings after enable the allowCellMerging. See{@link ejGrid#mergeSettings}            
             * @default false
             * @type {boolean}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   allowCellMerging:true,
             * });
             * &lt;/script&gt; 
             */
            allowCellMerging: false,
            /**		
             * Gets or sets a  value that indicates whether to enable mouse over effect on corresponding grid row.
             * @default true
             * @type {boolean}
             * @example 
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    dataSource:window.gridData,
             *    enableRowHover:true
             * });
             * &lt;/script&gt; 
             */
            enableRowHover: true,
            /**		
             * Gets or sets a value that indicates whether to persist the grid model state in page using applicable medium i.e., HTML5 localStorage or cookies
             * @default false
             * @type {boolean}
             * @example  
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *     dataSource:window.gridData,
             *     allowGrouping: true,
             *     enablePresistence:true
             * });
             * &lt;/script&gt; 
             */
            enablePersistence: false,
            /**		
             * Gets or sets a value that indicates to select the row while initializing the grid
             * @remarks
             * allowSelection must be set as true.
             * @default -1
             * @type {number}
             * @example 
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *     dataSource:window.gridData,
             *     selectedRowIndex:1
             * });
             * &lt;/script&gt; 
             */
            selectedRowIndex: -1,
            /**		
             * Gets or sets a value that indicates whether to enable dynamic searching behaviour in grid. Currently search box can be enabled through “toolbarSettings”
             * @remarks
             * While enabling allowSearching then we must enable toolbar in the grid and add search option in the toolbaritem. See {@link ejGrid#toolbarSettings}
             * @default false
             * @type {boolean}
             * @example 
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *     dataSource:window.gridData,
             *     allowSearching: true,
             *     toolbarSettings:{showToolbar:true,toolbarItems:[ej.Grid.ToolBarItems.Search]}
             * });
             * &lt;/script&gt; 
             */
            allowSearching: false,
            /**		
             * Gets or sets a value that indicates whether to enable mouse over effect  on the corresponding column header cell of the grid
             * @default false
             * @type {boolean}
             * @example 
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    dataSource:window.gridData,
             *    enableHeaderHover:true
             * });
             * &lt;/script&gt; 
             */
            enableHeaderHover: false,
            /**		
             * Gets or sets a value that indicates whether to enable the columns reordering behaviour in the grid.  Reordering can be done through by drag and drop the particular column from one index to another index within the grid.
             * @default false
             * @type {boolean}
             * @example  			
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    dataSource:window.gridData,
             *    allowReordering:true
             * });
             * &lt;/script&gt; 
             */
            allowReordering: false,
            /**		
             * Gets or sets a value that indicates whether to enable keyboard support for performing grid actions. selectionType – Gets or sets a value that indicates whether to enable single row or multiple rows selection behaviour in grid. Multiple selection can be done through by holding CTRL and clicking the grid rows
             * @default true
             * @type {boolean}
             * @example 
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *     dataSource:window.gridData,
             *     allowKeyboardNavigation:false
             * });
             * &lt;/script&gt; 
             */
            allowKeyboardNavigation: true,
            /**		
             * To Disable the mouse swipe property as false.
             * @default true
             * @type {boolean}
             * @example 
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *     dataSource:window.gridData,
             *     enableTouch:false
             * });
             * &lt;/script&gt; 
             */
            enableTouch: true,
            /**		
             * The row selection behavior of grid. Accepting types are "single" and "multiple".
             * @remarks
             * allowSelection must be set as true while using selectionType.
             * @default ej.Grid.SelectionType.Single
             * @type {enum}
             * @example 
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    dataSource:window.gridData,
             *    selectionType:"multiple"
             * });
             * &lt;/script&gt; 
             */
            selectionType: "single",
            /**		
			 * Gets or sets the data to render  the grid with records
			 * @default null
			 * @type {object}
			 * @example 
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
			 * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    dataSource:window.gridData
             * });
             * &lt;/script&gt; 
			 */
            dataSource: null,
            /**		
			 * Gets or sets a value that indicates to render the grid with custom theme. allowScrolling – Gets or sets a value that indicates whether to enable the scrollbar in the grid and view the records by scroll through the grid manually
			 * @default ""
			 * @type {string}
			 * @example 
			 * &lt;div id="Grid"&gt;&lt;/div&gt;
             * &lt;style type="text/css"&gt;
             *    .gradient-green {
             *        font-family: cursive;
             *    }
             *    .gradient-green .e-alt_row {
             *        background: none repeat scroll 0 0 #71A409;
             *    }
             * &lt;/style&gt;
			 * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    dataSource:window.gridData,
             *    cssClass: "gradient-green"
             * });
             * &lt;/script&gt; 
			 */
            cssClass: "",
            /**		
             * Gets or sets a value that indicates whether to enable the scrollbar in the grid and view the records by scroll through the grid manually
             * @remarks
             * Provide the scrollSettings after enable the allowScrolling. See{@link ejGrid#scrollSettings}            
             * @default false
             * @type {boolean}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   allowScrolling:true,
             *   scrollSettings:{width:300,height:100}
             * });
             * &lt;/script&gt; 
             */
            allowScrolling: false,
            /**		
             * Gets or sets a value that indicates whether to customizing the user interface (UI) as locale-specific in order to display regional data i.e. in a language and culture specific to a particular country or region.
             * @default "en-US"
             * @type {string}
             * @example 
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * ej.Pager.locale["es-ES"] = {
             *    pagerInfo: "{0} de {1} páginas ({2} artículos)"
             * };
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   allowPaging:true,
             *   locale : "es-ES" 
             * });
             * &lt;/script&gt;             
             */
            locale: "en-US",
            /**		
             * Gets or sets a value that indicates whether to enable the save action in the grid  through row selection
             * @remarks
             * When enableAutoSaveOnSelectionChange property value as false, then we must include edit option in toolbar and also set allowEditing as true.
             * @default true
             * @type {boolean}
             * @example 
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *     dataSource:window.gridData,
             *     editSettings: { allowEditing: true },
             *     toolbarSettings: { showToolbar: true, toolbarItems: ["cancel", "save"]},
             *     columns: [{ field: "OrderID", isPrimaryKey: true }, { field: "CustomerID" }, { field: "ShipCity" }],
             *     enableAutoSaveOnSelectionChange: false
             * });
             * &lt;/script&gt; 
             */
            enableAutoSaveOnSelectionChange: true,
            /**		
             * Gets or sets a value that indicates whether to enable multi columns sorting behaviour in grid. Sort multiple columns by holding CTRL and click on the corresponding column header.
             * @remarks
             * allowSorting must be set as true while enabling allowMultiSorting. 
             * @default false
             * @type {boolean}
             * @example 
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   allowSorting:true,
             *   allowMultiSorting:true
             * });
             * &lt;/script&gt; 
             */
            allowMultiSorting: false,
            exportToExcelAction:"",
            exportToWordAction:"",
            exportToPdfAction:"",
            /**		
             * Gest or sets an object that indicates whether to customize the editing behaviour of the grid.
             * @type {Object}
             */
            editSettings: /** @lends ejGrid# */ {
                /**		
                 * Gets or sets a value that indicates whether  to enable the edit action in the editing mode.
                 * @remarks
                 * When allowEditing is enabled then we must set columns property "isPrimaryKey" as true for primary column.
                 * We can edit the record in the grid by the following ways.
                 *   1. Enable toolbar in the grid and add editing option in the toolbaritem and click the "edit" icon which is in the toolbar. See {@link ejGrid#toolbarSettings}
                 *   2. Press function key F2.
                 *   3. Double click on the record.
                 * @alias ejGrid#editSettings->allowEditing
                 * @default false
                 * @type {boolean}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *     dataSource: window.gridData,
                 *     columns: [{ field: "OrderID", isPrimaryKey: true }, { field: "CustomerID" }, { field: "ShipCity" }],
                 *     editSettings: { allowEditing: true },
                 *     toolbarSettings: { showToolbar: true, toolbarItems: ["edit"] }
                 * });
                 * &lt;/script&gt;              
                 */
                allowEditing: false,
                /**		
                 * Gets or sets a value that indicates whether  to enable insert action in the editing mode.
                 * @remarks
                 * When allowAdding is enabled then we must set columns property "isPrimaryKey" as true for primary column.
                 * We can add a new record in the grid by the following ways.
                 *   1. Enable toolbar in the grid and include add record option in the toolbaritem and click the "add" icon which is in the toolbar. See {@link ejGrid#toolbarSettings}
                 *   2. Press Insert key.                 
                 * @alias ejGrid#editSettings->allowAdding
                 * @default false
                 * @type {boolean}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *     dataSource: window.gridData,
                 *     columns: [{ field: "OrderID", isPrimaryKey: true }, { field: "CustomerID" }, { field: "ShipCity" }],
                 *     editSettings: { allowAdding: true },
                 *     toolbarSettings: { showToolbar: true, toolbarItems: ["add"] }                             
                 * });
                 * &lt;/script&gt;                 
                 */
                allowAdding: false,
                /**		
                 * Gets or sets a value that indicates whether  to enable the delete action in the editing mode.
                 * @remarks
                 * When allowDeleting is enabled then we must set columns property "isPrimaryKey" as true for primary column.
                 * We can delete a record in the grid by the following ways.
                 *   1. Enable toolbar in the grid and include delete option in the toolbaritem and click the "delete" icon which is in the toolbar. See {@link ejGrid#toolbarSettings}
                 *   2. Press Delete key. 
                 * @alias ejGrid#editSettings->allowDeleting
                 * @default false
                 * @type {boolean}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 *&lt;script&gt;
                 * $("#Grid").ejGrid({
                 *     dataSource: window.gridData,
                 *     columns: [{ field: "OrderID", isPrimaryKey: true }, { field: "CustomerID" }, { field: "ShipCity" }],
                 *     editSettings: { allowDeleting: true },
                 *     toolbarSettings: { showToolbar: true, toolbarItems: ["delete"] }      
                 * });
                 * &lt;/script&gt;                  
                 */
                allowDeleting: false,
                /**		
                 * Gets or sets a value that indicates whether to define the mode of editing See {@link editMode}
                 * @remarks
                 * When allowAdding/allowEditing is enabled then we must set columns property "isPrimaryKey" as true for primary column.
                 * We must enable allowEditing or allowAdding property
                 * If allowAdding is enable then we must enable toolBar in the grid and include the "add" option as the toolBarItem. See {@link ejGrid#toolbarSettings}
                 * @alias ejGrid#editSettings->editMode
                 * @default ej.Grid.EditMode.Normal
                 * @type {enum}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt;
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *     dataSource: window.gridData,
                 *     columns: [{ field: "OrderID", isPrimaryKey: true }, { field: "CustomerID" }, { field: "ShipCity" }],
                 *     editSettings: { allowEditing: true, editMode: ej.Grid.EditMode.Dialog },
                 *     toolbarSettings: { showToolbar: true, toolbarItems: ["edit"] }                             
                 * });
                 * &lt;/script&gt;                          
                 */
                editMode: "normal",
                /**		
                 * This specifies to set the position of an adding new row either in the top or bottom of the grid
                 * @remarks
                 * When allowAdding/allowEditing is enabled then we must set columns property "isPrimaryKey" as true for primary column.
                 * We must enable allowEditing or allowAdding property
                 * If allowAdding is enable then we must enable toolBar in the grid and include the "add" option as the toolBarItem. See {@link ejGrid#toolbarSettings}
                 * @alias ejGrid#editSettings->rowPosition
                 * @default ej.Grid.RowPosition.top
                 * @type {enum}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt;
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *     dataSource: window.gridData,
                 *     columns: [{ field: "OrderID", isPrimaryKey: true }, { field: "CustomerID" }, { field: "ShipCity" }],
                 *     editSettings: { allowEditing: true, allowAdding:true, rowPosition:"bottom" },
                 *     toolbarSettings: { showToolbar: true, toolbarItems: ["add"]  },                             
                 * });
                 * &lt;/script&gt;                          
                 */
                rowPosition: "top",
                /**		
                 * This specifies the id of the template. This template can be used to display the data that you require to be edited using the Dialog Box
                 * @remarks
                 * When dialogEditorTemplateID is used then we must set columns property "isPrimaryKey" as true for primary column.
                 * We must enable allowEditing or allowAdding property
                 * If allowAdding is enable then we must enable toolBar in the grid and include the "add" option as the toolBarItem. See {@link ejGrid#toolbarSettings}
                 * While using dialogEditorTemplateID then editMode must be "ej.Grid.EditMode.DialogTemplate". See {@link editMode}
                 * Provide the template in the script tag and select type as "text/template" and assign the script id as the "dialogEditorTemplateID"
                 * @alias ejGrid#editSettings->dialogEditorTemplateID
                 * @default null
                 * @type {string}
                 * @example               
                 * &lt;div id="Grid"&gt;&lt;/div&gt;
                 * &lt;script id="template" type="text/template"&gt;
                 *    &lt;table&gt;
                 *        &lt;tr&gt;
                 *            &lt;td&gt;OrderID&lt;/td&gt;
                 *            &lt;td&gt;
                 *                &lt;input id="OrderID" name="OrderID" value="{{: OrderID}}" disabled="disabled" /&gt;&lt;/td&gt;
                 *        &lt;/tr&gt;
                 *        &lt;tr&gt;
                 *            &lt;td&gt;CustomerID&lt;/td&gt;
                 *            &lt;td&gt;
                 *                &lt;input id="CustomerID" name="CustomerID" value="{{: CustomerID}}" /&gt;&lt;/td&gt;
                 *        &lt;/tr&gt;
                 *        &lt;tr&gt;
                 *            &lt;td&gt;EmployeeID&lt;/td&gt;
                 *            &lt;td&gt;
                 *                &lt;input id="EmployeeID" name="EmployeeID" value="{{: EmployeeID}}" /&gt;&lt;/td&gt;
                 *        &lt;/tr&gt;
                 *    &lt;/table&gt;
                 * &lt;/script&gt;
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *     dataSource: window.gridData,
                 *     columns: [{ field: "OrderID", isPrimaryKey: true }, { field: "CustomerID" }, { field: "ShipCity" }],
                 *     editSettings: { allowEditing: true, editMode: ej.Grid.EditMode.DialogTemplate, dialogEditorTemplateID: "#template" },
                 *     toolbarSettings: { showToolbar: true, toolbarItems: ["edit"] }                             
                 * });
                 * &lt;/script&gt;                
                 */
                dialogEditorTemplateID: null,
                /**		
                 * Gets or sets a value that indicates whether  to enable the editing action while double click on the record
                 * @remarks
                 * When allowEditOnDblClick is set as false then we must enable toolbar in the grid and also include "edit" option in toolbaritem. Because if false is set then, record is not edited while double click on the row.
                 * We must enable allowEditing property
                 * When allowEditOnDblClick is used then we must set columns property "isPrimaryKey" as true for primary column.
                 * @alias ejGrid#editSettings->allowEditOnDblClick
                 * @default true
                 * @type {boolean}
                 * @example
                 * Defining editEvent with edit option:
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt; 
                 * $("#Grid").ejGrid({
                 *     dataSource: window.gridData,
                 *     columns: [{ field: "OrderID", isPrimaryKey: true }, { field: "CustomerID" }, { field: "ShipCity" }],
                 *     editSettings: { allowEditing: true, allowEditOnDblClick: false },
                 *     toolbarSettings: { showToolbar: true, toolbarItems: ["edit"] }      
                 * });
                 * &lt;/script&gt; 
                 */
                allowEditOnDblClick: true,
                /**		
                 * - This specifies the id of the template. This template can be used to display the data that you require to be edited using the External edit form
                 * @remarks
                 * We must enable allowEditing or allowAdding property
                 * If allowAdding is enable then we must enable toolBar in the grid and include the "add" option as the toolBarItem. See {@link ejGrid#toolbarSettings}
                 * When externalFormTemplateID is used then we must set columns property "isPrimaryKey" as true for primary column.
                 * While using externalFormTemplateID then editMode must be "ej.Grid.EditMode.ExternalFormTemplate". See {@link editMode}
                 * Provide the template in the script tag and select type as "text/template" and assign the script id as the "externalFormTemplateID"
                 * @alias ejGrid#editSettings->externalFormTemplateID
                 * @default null
                 * @type {string}
                 * @example               
                 * &lt;div id="Grid"&gt;&lt;/div&gt;
                 * &lt;script id="template" type="text/template"&gt;
                 *    &lt;table&gt;
                 *        &lt;tr&gt;
                 *            &lt;td&gt;OrderID&lt;/td&gt;
                 *            &lt;td&gt;
                 *                &lt;input id="OrderID" name="OrderID" value="{{: OrderID}}" disabled="disabled" /&gt;&lt;/td&gt;
                 *        &lt;/tr&gt;
                 *        &lt;tr&gt;
                 *            &lt;td&gt;CustomerID&lt;/td&gt;
                 *            &lt;td&gt;
                 *                &lt;input id="CustomerID" name="CustomerID" value="{{: CustomerID}}" /&gt;&lt;/td&gt;
                 *        &lt;/tr&gt;
                 *        &lt;tr&gt;
                 *            &lt;td&gt;EmployeeID&lt;/td&gt;
                 *            &lt;td&gt;
                 *                &lt;input id="EmployeeID" name="EmployeeID" value="{{: EmployeeID}}" /&gt;&lt;/td&gt;
                 *        &lt;/tr&gt;
                 *    &lt;/table&gt;
                 * &lt;/script&gt;
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *     dataSource: window.gridData,
                 *     columns: [{ field: "OrderID", isPrimaryKey: true }, { field: "CustomerID" }, { field: "ShipCity" }],
                 *     editSettings: { allowEditing: true, editMode: ej.Grid.EditMode.ExternalFormTemplate, externalFormTemplateID: "#template" },
                 *     toolbarSettings: { showToolbar: true, toolbarItems: ["edit"] }                             
                 * });
                 * &lt;/script&gt;                
                 */
                externalFormTemplateID: null,
                /**		
                 * This specifies the id of the template. This template can be used to display the data that you require to be edited using the Inline edit form 
                 * @remarks
                 * We must enable allowEditing or allowAdding property
                 * If allowAdding is enable then we must enable toolBar in the grid and include the "add" option as the toolBarItem. See {@link ejGrid#toolbarSettings}
                 * When inlineFormTemplateID is used then we must set columns property "isPrimaryKey" as true for primary column.
                 * While using inlineFormTemplateID then editMode must be "ej.Grid.EditMode.InlineFormTemplate". See {@link editMode}
                 * Provide the template in the script tag and select type as "text/template" and assign the script id as the "inlineFormTemplateID"
                 * @alias ejGrid#editSettings->inlineFormTemplateID
                 * @default null
                 * @type {string}
                 * @example               
                 * &lt;div id="Grid"&gt;&lt;/div&gt;
                 * &lt;script id="template" type="text/template"&gt;
                 *    &lt;table&gt;
                 *        &lt;tr&gt;
                 *            &lt;td&gt;OrderID&lt;/td&gt;
                 *            &lt;td&gt;
                 *                &lt;input id="OrderID" name="OrderID" value="{{: OrderID}}" disabled="disabled" /&gt;&lt;/td&gt;
                 *        &lt;/tr&gt;
                 *        &lt;tr&gt;
                 *            &lt;td&gt;CustomerID&lt;/td&gt;
                 *            &lt;td&gt;
                 *                &lt;input id="CustomerID" name="CustomerID" value="{{: CustomerID}}" /&gt;&lt;/td&gt;
                 *        &lt;/tr&gt;
                 *        &lt;tr&gt;
                 *            &lt;td&gt;EmployeeID&lt;/td&gt;
                 *            &lt;td&gt;
                 *                &lt;input id="EmployeeID" name="EmployeeID" value="{{: EmployeeID}}" /&gt;&lt;/td&gt;
                 *        &lt;/tr&gt;
                 *    &lt;/table&gt;
                 * &lt;/script&gt;
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *     dataSource: window.gridData,
                 *     columns: [{ field: "OrderID", isPrimaryKey: true }, { field: "CustomerID" }, { field: "ShipCity" }],
                 *     editSettings: { allowEditing: true, editMode: ej.Grid.EditMode.InlineTemplateForm, inlineFormTemplateID: "#template" },
                 *     toolbarSettings: { showToolbar: true, toolbarItems: ["edit"] }                             
                 * });
                 * &lt;/script&gt;                
                 */
                inlineFormTemplateID: null,
                /**		
                 * This specifies  to set the position of an External edit form either in the top-right or bottom-left of the grid
                 * @remarks
                 * We must enable allowEditing or allowAdding property.
                 * If allowAdding is enable then we must enable toolBar in the grid and include the "add" option as the toolBarItem. See {@link ejGrid#toolbarSettings}
                 * When formPosition is used then editMode must be "ej.Grid.EditMode.ExternalFormTemplate" or "ej.Grid.editMode.ExternalForm".
                 * We must set columns property "isPrimaryKey" as true for primary column.
                 * @alias ejGrid#editSettings->formPosition
                 * @default ej.Grid.FormPosition.BottomLeft
                 * @type {enum}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt;
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *     dataSource: window.gridData,
                 *     columns: [{ field: "OrderID", isPrimaryKey: true }, { field: "CustomerID" }, { field: "ShipCity" }],
                 *     editSettings: { allowAdding: true, allowEditing: true, editMode: ej.Grid.EditMode.ExternalForm, formPosition: ej.Grid.FormPosition.BottomLeft },
                 *     toolbarSettings: { showToolbar: true, toolbarItems: ["edit"] }                             
                 * });
                 * &lt;/script&gt;    
                 */
                formPosition: "bottomleft",
                /**		
                 * Gets or sets a value that indicates whether the confirm dialog has to be shown while saving or discarding the batch changes  
                 * @remarks
                 * We must set the editMode as batch.
                 * We must enable allowEditing,allowAdding or allowDeleting property                 
                 * @alias ejGrid#editSettings->showConfirmDialog
                 * @default true
                 * @type {boolean}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt;
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *     dataSource: window.gridData,
                 *     columns: [{ field: "OrderID", isPrimaryKey: true }, { field: "CustomerID" }, { field: "ShipCity" }],
                 *     editSettings: { allowEditing: true, editMode: ej.Grid.EditMode.Batch, showConfirmDialog:false },
                 *     toolbarSettings: { showToolbar: true, toolbarItems: ["edit","update","cancel"] }                             
                 * });
                 * &lt;/script&gt;                          
                 */
                showConfirmDialog: true,
                /**		
                 * Gets or sets a value that indicates whether the confirm dialog  has to be shown while deleting record
                 * @remarks
                 * We must enable allowDeleting property                 
                 * @alias ejGrid#editSettings->showDeleteConfirmDialog
                 * @default false
                 * @type {boolean}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt;
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *     dataSource: window.gridData,
                 *     columns: [{ field: "OrderID", isPrimaryKey: true }, { field: "CustomerID" }, { field: "ShipCity" }],
                 *     editSettings: { allowDeleting: true, showDeleteConfirmDialog:true },
                 *     toolbarSettings: { showToolbar: true, toolbarItems: ["edit","update","cancel"] }                             
                 * });
                 * &lt;/script&gt;                          
                 */
                showDeleteConfirmDialog: false
            },
            /**		
            * This property is used to configure the selection behaviour of the grid.            
            * @type Object
            */
            selectionSettings: /** @lends ejGrid# */ {

                /**		
                * Gets or sets  a value that indicates whether to add the default selection actions as a seleciton mode.See {@link selectionMode}
                * @remarks
                * We must enable allowSelection property
                * @alias ejGrid#selectionSettings->selectionMode
                * @default ["row"]
                * @type {enum}
                * @example
                * &lt;div id="Grid"&gt;&lt;/div&gt; 
                * &lt;script&gt;
                * $("#Grid").ejGrid({
                *    dataSource:window.gridData,
                *    allowSelection: true,   
                *    selectionSettings: {selectionMode: ["row","cell","column"] }
                * });
                * &lt;/script&gt;
                */
                selectionMode: ["row"],

                /**		
                * Gets or sets a value that indicates whether to enable the toggle selction behaviour for row, cell and column.
                * @remarks
                * When enableToggle is defined in selectionSettings then "allowSelection" must be set as true.
                * @alias ejGrid#selectionSettings->enableToggle
                * @default false
                * @type {boolean}
                * @example
                * &lt;div id="Grid"&gt;&lt;/div&gt; 
                * &lt;script&gt;
                * $("#Grid").ejGrid({
                *     dataSource:  window.gridData,
                *     allowSelection: true,   
                *     selectionSettings: {enableToggle: true }
                * });
                * &lt;/script&gt;
                */
                enableToggle: false
            },

            /**		
             * Gets or sets an object that indicates whether to modify the pager default configuration.     
             * @type Object
             */
            pageSettings: /** @lends ejGrid# */ {
                /**		
                 * Gets or sets a value that indicates whether to define the number of records displayed per page
                 * @remarks
                 * When pageSize is defined in pageSettings then "allowPaging" must be set as true.
                 * @alias ejGrid#pageSettings->pageSize
                 * @default 12
                 * @type {number}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *     dataSource: window.gridData,
                 *     allowPaging: true,   
                 *     pageSettings: { pageSize: 2 }
                 * });
                 * &lt;/script&gt;
                 */
                pageSize: 12,
                /**		
                 * Gets or sets a value that indicates whether to define the number of pages displayed in the pager for navigation
                 * @remarks
                 * When pageCount is defined in pageSettings then "allowPaging" must be set as true.
                 * @alias ejGrid#pageSettings->pageCount
                 * @default 8
                 * @type {number}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *     dataSource: window.gridData,
                 *     allowPaging: true,    
                 *     pageSettings: { pageCount: 1 }
                 * });
                 * &lt;/script&gt;
                 */
                pageCount: 8,
                /**		
                 * Gets or sets a value that indicates whether to define which page to display currently in the grid
                 * @remarks
                 * When currentPage is defined in pageSettings then "allowPaging" must be set as true.
                 * The currentPage must be less than or equal to total number of pages.
                 * @alias ejGrid#pageSettings->currentPage
                 * @default 1
                 * @type {number}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *     dataSource:  window.gridData,
                 *     allowPaging: true,   
                 *     pageSettings: { currentPage: 1 }
                 * });
                 * &lt;/script&gt;
                 */
                currentPage: 1,
                /**		
                 * Get the value of total number of pages in the grid. The totalPages value is calculated based on pagesize and totalrecords of grid
                 * @remarks
                 * There is no need to set value for this property.
                 * @alias ejGrid#pageSettings->totalPages
                 * @default null
                 * @type {number}  
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt;
                 * &lt;div id="print"&gt;&lt;/div&gt;
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *     dataSource:  window.gridData,
                 *     allowPaging: true    
                 * });
                 * var value = $("#Grid").ejGrid("option", "pageSettings.totalPages");
                 * $("#print").text("TotalPages: " + value);
                 * &lt;/script&gt;
                 */
                totalPages: null,
                /**
				* Gets or sets a value that indicates whether to  enables pager template for the grid.
                * @remarks
                * If enableTemplates property set as true, need to give templateId property.
                * @alias ejGrid#pageSettings->enableTemplates
                * @default false
                * @type {bool}  
                * @example
				* &lt;div id="Grid"&gt;&lt;/div&gt; 
				* &lt;script id="pagerTemplate" type="text/x-jsrender"&gt;
				*  &lt;input type="text" id="txtPageNumber"  value="" style="width: 45px; border: none; cursor: text" /&gt;
				* &lt;input type="button" value="Go" style="border: none; cursor: pointer" id="btnGo" onclick="gotoPage(this)" /&gt;
				* &lt;/script&gt;
				* &lt;script&gt;
				* $("#Grid").ejGrid({
				*  dataSource:window.gridData,
				*  pageSettings:{enableTemplates:true,template:"#pagerTemplate"}
				* });
				* &lt;/script&gt;
				*/
                enableTemplates: false,
                /**
				* Gets or sets a value that indicates whether to  enables default pager for the grid.
                * @alias ejGrid#pageSettings->showDefaults
                * @default true
                * @type {bool}  
                * @example
				* &lt;div id="Grid"&gt;&lt;/div&gt; 
				* &lt;script id="pagerTemplate" type="text/x-jsrender"&gt;
				*  &lt;input type="text" id="txtPageNumber"  value="" style="width: 45px; border: none; cursor: text" /&gt;
				* &lt;input type="button" value="Go" style="border: none; cursor: pointer" id="btnGo" /&gt;
				* &lt;/script&gt;
				* &lt;script&gt;
				* $("#Grid").ejGrid({
				*  dataSource:window.gridData,
				*  pageSettings:{showDefaults:false,enableTemplates:true,templateID:"#pagerTemplate"}
				* });
				* &lt;/script&gt;
				*/
                showDefaults: false,
                /**
				* Gets or sets a value that indicates to add the template as a pager template for grid.
                * @remarks
                * If enableTemplates property set as true, need to give templateId property.
                * @alias ejGrid#pageSettings->template
                * @default null
                * @type {string}  
                * @example
				* &lt;div id="Grid"&gt;&lt;/div&gt; 
				* &lt;script id="pagerTemplate" type="text/x-jsrender"&gt;
				*  &lt;input type="text" id="txtPageNumber"  value="" style="width: 45px; border: none; cursor: text" /&gt;
				* &lt;input type="button" value="Go" style="border: none; cursor: pointer" id="btnGo" /&gt;
				* &lt;/script&gt;
				* &lt;script&gt;
				* $("#Grid").ejGrid({
				*  dataSource:window.gridData,
				*  pageSettings:{enableTemplates:true,template:"#pagerTemplate"}
				* });
				* &lt;/script&gt;
				*/
                template: null,
                /**		
                 * Get the value of total number of records which is bound to  the grid. The totalRecordsCount value is calculated based on dataSource bound to the grid.
                 * @remarks
                 * There is no need to set value for this property.
                 * @alias ejGrid#pageSettings->totalRecordsCount
                 * @default null
                 * @type {number}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt;
                 * &lt;div id="print"&gt;&lt;/div&gt;
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *     dataSource:  window.gridData,
                 *     allowPaging: true
                 * });
                 * var value = $("#Grid").ejGrid("option", "pageSettings.totalRecordsCount");
                 * $("#print").text("TotalRecordsCount: " + value);
                 * &lt;/script&gt;
                 */
                totalRecordsCount: null,
                /**		
                 * Gets or sets a value that indicates whether  to pass the current page information as a query string along with the url while navigating to other page.
                 * @remarks
                 * When currentPage is defined in pageSettings then "allowPaging" must be set as true.
                 * @alias ejGrid#pageSettings->enableQueryString
                 * @default false
                 * @type {boolean}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *     dataSource:  window.gridData,
                 *     allowPaging: true,   
                 *     pageSettings: {enableQueryString: true }
                 * });
                 * &lt;/script&gt;
                 */
                enableQueryString: false
            },
            /**		
             * Gets or sets an object that indicates whether to customize the grouping behaviour of the grid. 
             * @type {Object}             
             */
            groupSettings: /** @lends ejGrid# */ {
                /**		
                 * – Gets or sets a value that indicates whether to showthe group button image(toggle button)in the column header and also in the grouped column in the group drop area .  It can be used to group/ungroup the columns by click on the toggle button. 
                 * @remarks 
                 * When showToggleButton is enabled then "allowGrouping" must be set as true.
                 * @alias ejGrid#groupSettings->showToggleButton
                 * @default false
                 * @type {boolean}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *     dataSource:window.gridData,
                 *     allowGrouping:true,
                 *     groupSettings:{showToggleButton:true}
                 * });
                 * &lt;/script&gt;   
                 */
                showToggleButton: false,
                 /**		
                  * Gets or sets a value that indicates whether to  enable the animation effects to the group drop area
                  * @remarks
                  * allowGrouping must be set as true.
                  * @alias ejGrid#groupSettings->enableDropAreaAnimation
                  * @default true
                  * @type {boolean}
                  * @example
                  * &lt;div id="Grid"&gt;&lt;/div&gt; 
                  * &lt;script&gt;
                  * $("#Grid").ejGrid({
                  *    dataSource:window.gridData,
                  *    allowGrouping: true,
                  *    enableDropAreaAnimation:true                        
                  * });
                  * &lt;/script&gt;            
                  */
                enableDropAreaAnimation: true,
                 /**		
                  * Gets or sets a value that indicates whether to   hide the grouped columns from the grid
                  * @remarks
                  * When showGroupedColumn is enabled then "allowGrouping" must be set as true.
                  * @alias ejGrid#groupSettings->showGroupedColumn
                  * @default false
                  * @type {boolean}
                  * @example
                  * &lt;div id="Grid"&gt;&lt;/div&gt; 
                  * &lt;script&gt;
                  * $("#Grid").ejGrid({
                  *     dataSource:window.gridData,
                  *     allowGrouping:true,
                  *     groupSettings:{showGroupedColumn:false}
                  * });
                  * &lt;/script&gt; 
                  */
                showGroupedColumn: true,
                 /**		
                  * Gets or sets a value that indicates whether to  enable the close button in the grouped column  which is in the group drop area to ungroup the grouped column
                  * @remarks
                  * When showUngroupButton is enabled then "allowGrouping" and showToggleButton must be set as true.
                  * @alias ejGrid#groupSettings->showUngroupButton
                  * @default false
                  * @type {boolean}
                  * @example
                  * &lt;div id="Grid"&gt;&lt;/div&gt; 
                  * &lt;script&gt;
                  * $("#Grid").ejGrid({
                  *     dataSource:window.gridData,
                  *     allowGrouping:true,
                  *     groupSettings:{showToggleButton: true, showUngroupButton:true}
                  * });
                  * &lt;/script&gt; 
                  */
                showUngroupButton: true,
                /**		
                 * Gets or sets a value that indicates whether to  enable animation button option in the group drop area of the grid.
                 * @remarks
                 * When enableDropAreaAutoSizing is enabled then "allowGrouping" must be set as true.
                 * @alias ejGrid#groupSettings->enableDropAreaAutoSizing
                 * @default false
                 * @type {boolean}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *     dataSource:window.gridData,
                 *     allowGrouping:true,
                 *     groupSettings:{enableDropAreaAutoSizing: true}
                 * });
                 * &lt;/script&gt; 
                 */
                enableDropAreaAutoSizing: true,
                /**		
                 * Gets or sets a value that indicates whether to add grouped columns programmatically at initial load
                 * @remarks
                 * When groupedColumns is specified then "allowGrouping" must be set as true.
                 * @alias ejGrid#groupSettings->groupedColumns
                 * @default []
                 * @type {object}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *     dataSource:window.gridData,
                 *     allowGrouping:true,
                 *     groupSettings:{groupedColumns:["OrderID"]}
                 * });
                 * &lt;/script&gt; 
                 */
                groupedColumns: []
            },

            /**		
           * Gets or sets an object that indicates whether to customize the context menu behaviour of the grid.
           * @type {Object}             
           */

            contextMenuSettings: {
                /**
                 * Gets or sets a value that indicates whether to enable the context menu action in the grid.
                 * @remarks
                 * We must provide the Contextmenu Items. See{@link toolbarItems}
                 * If the above options added in contextmenu as a contextmenu item then we must enable allowEditing, allowDeleting , allowAdding , allowGrouping , allowSorting and allowPaging.
                 * @alias ejGrid#contextMenuSettings->enableContextMenu
                 * @default false
                 * @type {boolean}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *    dataSource: window.gridData,
                 *    columns:[{field: "OrderID", isPrimaryKey: true},{field: "EmployeeID"}],
                 *    editSettings: { allowDeleting: true, allowEditing: true, allowAdding: true },
                 *    allowGrouping: true,
                 *    allowSorting: true,
                 *    allowPaging: true,
                 *    contextMenuSettings: { enableContextMenu: true }
                 * });
                 * &lt;/script&gt; 
                 */
                enableContextMenu: false,
                /**		
                 * Gets or sets a value that indicates whether to add the default context menu actions as a context menu items
                 *If enableContextMenu is true it will show all the items related to the target, if u want selected items from contextmenu u have to mention in the contextMenuItems
                 * @remarks
                 * We must enable enableContextMenu property
                 * @alias ejGrid#contextMenuSettings->contextMenuItems
                 * @default []
                 * @type {array}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *    dataSource:window.gridData,
                 *    columns:[{field: "OrderID", isPrimaryKey: true},{field: "EmployeeID"}],
                 *    editSettings: { allowDeleting: true, allowEditing: true, allowAdding: true },
                 *    allowGrouping: true,
                 *    allowSorting: true,
                 *    allowPaging: true,
                 *    contextMenuSettings: { enableContextMenu: true, contextMenuItems:["Add Record,Edit Record,Delete Record"]  }
                 * });
                 * &lt;/script&gt;
                 */
                contextMenuItems: ["Add Record", "Edit Record", "Delete Record", "Sort In Ascending Order", "Sort In Descending Order", "Next Page", "Last Page", "Previous Page", "First Page", "Save", "Cancel", "Grouping", "Ungrouping"],
                /**		
                 * Gets or sets a value that indicates whether to add custom contextMenu items within the toolbar to perform any action in the grid
                 * @remarks
                 * We must enable enableContextMenu property
                 * @alias ejGrid#contextMenuSettings->customContextMenuItems
                 * @default []
                 * @type {array}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;style type="text/css" class="cssStyles"&gt;
                 * &lt;/style&gt;
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *   dataSource:window.gridData, 
                 *   contextMenuSettings: { enableContextMenu: true, customContextMenuItems:["Hidden Columns,Visible Columns"]  }
                 * });
                 * &lt;/script&gt;
                 */
                customContextMenuItems: []
            },
            /**		
             * Gets or sets an object that indicates whether to customize the filtering behaviour of the grid
             * @type {Object}             
             */
            filterSettings: /** @lends ejGrid# */ {
                /**		
                 * This specifies the grid to show the filterBar or filterMenu to the grid records. See {@link filterType}
                 * @remarks
                 * When filterType is specified then "allowFiltering" must be set as true.
                 * @alias ejGrid#filterSettings->filterType
                 * @default ej.Grid.FilterType.FilterBar
                 * @type {enum}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *    dataSource:window.gridData,
                 *    allowFiltering: true, 
                 *    filterSettings: {  filterType: "menu" }                     
                 * });
                 * &lt;/script&gt;
                 */
                filterType: "filterbar",
                /**		
                 * This specifies the grid to starts the filter action while typing in the filterBar or after pressing the enter key. based on the filterBarMode. See {@link filterBarMode}
                 * @remarks
                 * When filterBarMode is specified then "allowFiltering" must be set as true and filterType must be "filterbar".
                 * @alias ejGrid#filterSettings->filterBarMode
                 * @default ej.Grid.FilterBarMode.Immediate
                 * @type {enum} 
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *    dataSource:window.gridData,
                 *    allowFiltering: true, 
                 *    filterSettings:{ filterBarMode: ej.Grid.FilterBarMode.OnEnter }                
                 * });
                 * &lt;/script&gt;
                 */
                filterBarMode: "immediate",
                /**		
                 * This specifies the grid to show  the filter text within the grid pager itself.
                 * @remarks
                 * When filterBarMode is specified then "allowFiltering" must be set as true and filterType must be "filterbar".
                 * @alias ejGrid#filterSettings->showFilterBarMessage
                 * @default true
                 * @type {boolean}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *    dataSource:window.gridData,
                 *    allowFiltering: true, 
                 *    filterSettings: {  showFilterBarStatus: true }                        
                 * });
                 * &lt;/script&gt;
                 */
                showFilterBarStatus: true,
                statusBarWidth: 450,
                /**		
                 * Gets or sets a value that indicates whether to enable the predicate options in the filtering menu  
                 * @remarks
                 * When showPredicate is specified then "allowFiltering" must be set as true and filterType must be "menu".
                 * @alias ejGrid#filterSettings->showPredicate
                 * @default false
                 * @type {boolean}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *    dataSource:window.gridData,
                 *     allowFiltering: true, 
                 *     filterSettings: { showPredicate:true, filterType:"menu"}                       
                 * });
                 * &lt;/script&gt;
                 */
                showPredicate: false,
                /**		
                 * Gets or sets a value that indicates whether to define the filtered columns details programmatically at initial load   
                 * @remarks
                 * When filteredColumns is specified then "allowFiltering" must be set as true and filterType must be "menu".
                 * @alias ejGrid#filterSettings->filteredColumns
                 * @default []
                 * @type {object}                 
                 */
                filteredColumns: [],                
                /**		
                * Gets or sets a value that indicates the maximum number of filter choices that can be showed in the excel styled filter menu. 
                * @remarks
                * When maxFilterChoices is specified then "allowFiltering" must be set as true and filterType must be "excel".
                * @alias ejGrid#filterSettings->maxFilterChoices
                * @default 1000
                * @type {number}
                * @example
                * &lt;div id="Grid"&gt;&lt;/div&gt; 
                * &lt;script&gt;
                * $("#Grid").ejGrid({
                *    dataSource:window.gridData,
                *     allowFiltering: true, 
                *     filterSettings: { maxFilterChoices:200, filterType:"excel"}                       
                * });
                * &lt;/script&gt;
                */
                maxFilterChoices: 1000,
                /**		
                * Gets or sets a value that indicates to perform the filter operation with case sensitive in excel styled filter menu mode
                * @remarks
                * When enableCaseSensitivity is specified then "allowFiltering" must be set as true and filterType must be "excel".
                * @alias ejGrid#filterSettings->enableCaseSensitivity
                * @default false
                * @type {boolean}
                * @example
                * &lt;div id="Grid"&gt;&lt;/div&gt; 
                * &lt;script&gt;
                * $("#Grid").ejGrid({
                *    dataSource:window.gridData,
                *     allowFiltering: true, 
                *     filterSettings: { enableCaseSensitivity:true, filterType:"excel"}                       
                * });
                * &lt;/script&gt;
                */
                enableCaseSensitivity:false
            },
            /**		
             * Gets or sets a value that indicates whether to customize the sorting behaviour of the grid.
             * @type {Object}           
             */
            sortSettings: /** @lends ejGrid# */ {

                /**		
                 * Gets  or sets a value that indicates whether to define the sorted Columns details programmatically at initial load
                 * @remarks
                 * allowSorting must be set as true.
                 * @alias ejGrid#sortSettings->sortedColumns
                 * @default []
                 * @type {object}
                 * @example                 
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;div id="print"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *    dataSource:window.gridData,
                 *    columns:[{field: "OrderID"},{field: "EmployeeID"}],
                 *    allowSorting: true,
                 *    sortSettings: {sortedColumns: [{field:"EmployeeID", direction:"ascending"}] }                  
                 * });
                 * var sortColumn = $("#Grid").ejGrid("option", "sortSettings.sortedColumns");
                 * $("#print").text(sortColumn);
                 * &lt;/script&gt;
                 */

                /**
                 * Gets or sets a value that indicates whether to define the field name of the column to be sort
                 * @remarks
                 * allowSorting must be set as true.
                 * @name ejGrid#sortSettings->sortedColumns->field 	          
                 * @default -
                 * @type {string}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt;          
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *   dataSource:window.gridData,
                 *   columns:[{field: "OrderID"},{field: "EmployeeID"}],
                 *   sortSettings: {sortedColumns: [{field:"EmployeeID"}] }             
                 * });
                 * &lt;/script&gt;  
                 */

                /**
                 * Gets  or sets a value that indicates whether to define the direction to sort the column.
                 * @remarks
                 * allowSorting must be set as true.
                 * @name ejGrid#sortSettings->sortedColumns->direction 	          
                 * @default -
                 * @type {string}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt;          
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *   dataSource:window.gridData,
                 *   columns:[{field: "OrderID"},{field: "EmployeeID"}],
                 *   sortSettings: {sortedColumns: [{field:"EmployeeID", direction:"descending"}] }                    
                 * });
                 * &lt;/script&gt;  
                 */
                sortedColumns: []
            },
            /**		
             * Gets or sets an object that indicates whether to enable the toolbar in the grid and add toolbar items
             * @type {Object}             
             */
            toolbarSettings: /** @lends ejGrid# */ {
                /**		
                 * Gets or sets a value that indicates whether to enable  toolbar in the grid.
                 * @remarks
                 * We must provide the toolbarItems. See{@link toolbarItems}
                 * If editing options added in toolbar as a toolbar item then we must enable allowEditing, allowDeleting and allowAdding.
                 * @alias ejGrid#toolbarSettings->showToolbar
                 * @default false
                 * @type {boolean}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *    dataSource: window.gridData,
                 *    columns:[{field: "OrderID", isPrimaryKey: true},{field: "EmployeeID"}],
                 *    editSettings: { allowEditing: true },
                 *    toolbarSettings: { showToolbar: true, toolbarItems: [ej.Grid.ToolBarItems.Edit] }
                 * });
                 * &lt;/script&gt; 
                 */
                showToolbar: false,
                /**		
                 * Gets or sets  a value that indicates whether  to add the default editing actions as a toolbar items
                 * @remarks
                 * We must enable showToolbar property
                 * @alias ejGrid#toolbarSettings->toolbarItems
                 * @default []
                 * @type {enum}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *    dataSource:window.gridData,
                 *    columns:[{field: "OrderID", isPrimaryKey: true},{field: "EmployeeID"}],
                 *    editSettings: { allowDeleting: true, allowEditing: true, allowAdding: true },
                 *    toolbarSettings: { showToolbar: true, toolbarItems: [ej.Grid.ToolBarItems.Add, ej.Grid.ToolBarItems.Edit, ej.Grid.ToolBarItems.Delete, ej.Grid.ToolBarItems.Update, ej.Grid.ToolBarItems.Cancel] }
                 * });
                 * &lt;/script&gt;
                 */
                toolbarItems: [],
                /**		
                 * Gets or sets a value that indicates whether  to add custom toolbar items within the toolbar to perform any action in the grid 
                 * @remarks
                 * We must enable showToolbar property
                 * @alias ejGrid#toolbarSettings->customToolbarItems
                 * @default []
                 * @type {object}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;style type="text/css" class="cssStyles"&gt;
                 *   .Expand:before
                 *   {
                 *     content:"\e627";
                 *   }
                 * &lt;/style&gt;
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *   dataSource:window.gridData, 
                 *   toolbarSettings:{showToolbar:true,customToolbarItems:["Expand"]}
                 * });
                 * &lt;/script&gt;
                 */
                customToolbarItems: []
            },
            minWidth:0,
            /**		
             * Gets or sets an object that indicates whether to customize the scrolling behaviour of the grid.
             * @type {Object}
             */
            scrollSettings: /** @lends ejGrid# */
            {
                /**		
                 * This specify the grid to show the horizontal scroll bar, to scroll and view the grid contents
                 * @remarks
                 * We must enable allowScrolling property
                 * @alias ejGrid#scrollSettings->width
                 * @default 250
                 * @type {number}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *    dataSource:window.gridData,
                 *    allowScrolling: true,
                 *    scrollSettings:{ width:300 }
                 * });
                 * &lt;/script&gt; 
                 */
                width: "auto",
                /**		
                 * This specify the grid to show the vertical scroll bar, to scroll and view the grid contents.
                 * @remarks
                 * We must enable allowScrolling property
                 * @alias ejGrid#scrollSettings->height
                 * @default 0
                 * @type {number}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *    dataSource:window.gridData,
                 *    allowScrolling: true,
                 *    scrollSettings:{ height:100 }
                 * });
                 * &lt;/script&gt; 
                 */
                height: 0,
                /**		
                 * This specify the grid to enable/disable touch control for scrolling.
                 * @remarks
                 * We must enable allowScrolling property
                 * @alias ejGrid#scrollSettings->enableTouchScroll
                 * @default true
                 * @type {boolean}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *    dataSource:window.gridData,
                 *    allowScrolling: true,
                 *    scrollSettings:{ enableTouchScroll:true }
                 * });
                 * &lt;/script&gt; 
                 */
                enableTouchScroll: true,
                /**		
                 * This specify the grid to to view data that you require without buffering the entire load of a huge database
                 * @remarks
                 * 1.We must enable allowScrolling property
                 * 2.Sets the height and width size
                 * @alias ejGrid#scrollSettings->allowVirtualScrolling
                 * @default false
                 * @type {boolean}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *    dataSource:window.gridData,
                 *    allowScrolling: true,
                 *    scrollSettings:{width:300,height:100,allowVirtualScrolling:true}
                 * });
                 * &lt;/script&gt; 
                 */
                allowVirtualScrolling: false,
                /**		
                * This is used to define the mode of virtual scrolling in grid. See {@link virtualScrollMode}
                * @remarks                 
                * We must enable allowScrolling and allowVirtualScrolling property                 
                * @alias ejGrid#scrollSettings->virtualScrollMode
                * @default ej.Grid.VirtualScrollMode.Normal
                * @type {enum}
                * @example
                * &lt;div id="Grid"&gt;&lt;/div&gt;
                * &lt;script&gt;
                * $("#Grid").ejGrid({
                *     dataSource: window.gridData,                     
                *     allowScrolling:true,
                *     scrollSettings:{ width:500 , height: 550 , allowVirtualScrolling:true, virtualScrollMode:ej.Grid.VirtualScrollMode.Normal }
                * });
                * &lt;/script&gt;                          
                */
                virtualScrollMode:"normal",
                /**		
                 * This specify the grid to freeze particular rows at the time of scrolling.
                 * @remarks
                 * We must enable allowScrolling property
                 * @alias ejGrid#scrollSettings->frozenRows
                 * @default 0
                 * @type {number}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *     dataSource:window.gridData,
                 *     allowScrolling: true,               
                 *     scrollSettings:{width:300,height:200,frozenRows:2 }
                 * });
                 * &lt;/script&gt; 
                 */
                frozenRows: 0,
                /**		
                 * This specify the grid to freeze particular columns  at the time of scrolling.
                 * @remarks
                 * We must enable allowScrolling property
                 * @alias ejGrid#scrollSettings->frozenColumns
                 * @default 0
                 * @type {number}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *     dataSource:window.gridData,
                 *     allowScrolling: true,               
                 *     scrollSettings:{width:500,height:100,frozenColumns:2 }
                 * });  
                 * &lt;/script&gt; 
                 */
                frozenColumns: 0
            },
            /**		
             * Gets or sets an object that indicates to managing the collection of summary rows for the grid.
             * @remarks
             * We must enable showSummary property
             * @default []
             * @name ejGrid#summaryRows
             * @type {array}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *      dataSource:window.gridData,
             *      showSummary: true,
             *      columns:[{field: "OrderID"},{field: "Freight"}],
             *      summaryRows: [{
             *         title: "Sum",
             *         summaryColumns: [{
             *            summaryType: ej.Grid.SummaryType.Sum,
             *            displayColumn: "Freight",
             *            dataMember: "Freight"
             *         }]
             *      }]                                    
             * });
             * &lt;/script&gt; 
             */

            /**
             * This specifies the grid to show the title for the summary rows.  
             * @remarks
             * showSummary must be true and summaryRows must be given while using title.
             * @name ejGrid#summaryRows->title 	          
             * @default ""
             * @type {string}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *      dataSource:window.gridData,  
             *      showSummary: true,
             *      columns:[{field: "OrderID"},{field: "Freight"}],
             *      summaryRows: [{
             *         title: "Sum",
             *         summaryColumns: [{
             *            summaryType: ej.Grid.SummaryType.Sum,
             *            displayColumn: "Freight",
             *            dataMember: "Freight"
             *         }]
             *      }]                                    
             * });
             * &lt;/script&gt;
             */

            /**
             * Gets or sets a value that indicates whether to show the summary value within the group caption area for the corresponding summary column while grouping the column
             * @remarks
             * showSummary and allowGrouping must be true. summaryRows must be given while using showCaptionSummary.
             * @name ejGrid#summaryRows->showCaptionSummary 	          
             * @default false
             * @type {boolean}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *      dataSource:window.gridData,  
             *      columns:[{field: "OrderID"},{field: "Freight"}],
             *      allowGrouping: true,
             *      showSummary: true,
             *      summaryRows: [{
             *         title: "Sum",
             *         summaryColumns: [{
             *            summaryType: ej.Grid.SummaryType.Sum,
             *            displayColumn: "Freight",
             *            dataMember: "Freight"
             *         }],
             *         showCaptionSummary: true
             *      }]                                    
             * });
             * &lt;/script&gt;           
             */

            /**
             * Gets or sets a value that indicates whether to show the total summary value  the for the corresponding summary column. The summary row is added after the grid content.
             * @remarks
             * showSummary and allowGrouping must be true. summaryRows must be given while using showTotalSummary.
             * @name ejGrid#summaryRows->showTotalSummary 	          
             * @default true
             * @type {boolean}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *      dataSource:window.gridData, 
             *      columns:[{field: "OrderID"},{field: "Freight"}],
             *      showSummary: true,
             *      summaryRows: [{
             *         title: "Sum",
             *         summaryColumns: [{
             *            summaryType: ej.Grid.SummaryType.Sum,
             *            displayColumn: "Freight",
             *            dataMember: "Freight"
             *         }],
             *         showTotalSummary: true
             *      }]                                    
             * });
             * &lt;/script&gt; 
             */

            /**
             * Gets or sets a value that indicates whether to add summary columns into the summary rows.
             * @remarks            
             * showSummary must be true and summaryRows must be given while using summaryColumns.
             * @name ejGrid#summaryRows->summaryColumns 	          
             * @default []
             * @type {object}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *      dataSource:window.gridData, 
             *      columns:[{field: "OrderID"},{field: "Freight"}],
             *      showSummary: true,
             *      summaryRows: [{
             *         title: "Sum",
             *         summaryColumns: [{
             *            summaryType: ej.Grid.SummaryType.Sum,
             *            displayColumn: "Freight",
             *            dataMember: "Freight"
             *         }]
             *      }]                                    
             * });
             * &lt;/script&gt; 
             */

            /**
             * Gets or sets a value that indicates the type of calculations to be performed for the corresponding summary column
             * @remarks            
             * showSummary must be true and summaryRows must be given while using summaryColumns and their properties.
             * @name ejGrid#summaryRows->summaryColumns->summaryType     
             * @default []
             * @type {object}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *      dataSource:window.gridData, 
             *      columns:[{field: "OrderID"},{field: "Freight"}],
             *      showSummary: true,
             *      summaryRows: [{
             *         title: "Sum",
             *         summaryColumns: [{
             *            summaryType: ej.Grid.SummaryType.Sum,
             *            displayColumn: "Freight",
             *            dataMember: "Freight"
             *         }]
             *      }]                                    
             * });
             * &lt;/script&gt; 
             */

            /**
             * Gets or sets a value that indicates to define the target column at which to display the summary.
             * @remarks            
             * showSummary must be true and summaryRows must be given while using summaryColumns and their properties.
             * @name ejGrid#summaryRows->summaryColumns->displayColumn 	          
             * @default null
             * @type {string}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *      dataSource:window.gridData,
             *      columns:[{field: "OrderID"},{field: "Freight"}],
             *      showSummary: true,
             *      summaryRows: [{
             *         title: "Sum",
             *         summaryColumns: [{
             *            summaryType: ej.Grid.SummaryType.Sum,
             *            displayColumn: "Freight",
             *            dataMember: "Freight"
             *         }]
             *      }]                                    
             * });
             * &lt;/script&gt; 
             */

            /**
             * This specifies summary column used to perform the summary calculation
             * @remarks            
             * showSummary must be true and summaryRows must be given while using summaryColumns and their properties.
             * @name ejGrid#summaryRows->summaryColumns->dataMember 	          
             * @default null
             * @type {string}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *      dataSource:window.gridData,
             *      columns:[{field: "OrderID"},{field: "Freight"}],
             *      showSummary: true,
             *      summaryRows: [{
             *         title: "Sum",
             *         summaryColumns: [{
             *            summaryType: ej.Grid.SummaryType.Sum,
             *            displayColumn: "Freight",
             *            dataMember: "Freight"
             *         }]
             *      }]                                    
             * });
             * &lt;/script&gt; 
             */

            /**
             * Gets or sets a value that indicates the format for the text applied on the column
             * @remarks            
             * showSummary must be true and summaryRows must be given while using summaryColumns and their properties.
             * @name ejGrid#summaryRows->summaryColumns->format 	          
             * @default null
             * @type {string}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *      dataSource:window.gridData,
             *      columns:[{field: "OrderID"},{field: "Freight"}],
             *      showSummary: true,
             *      summaryRows: [{
             *         title: "Sum",
             *         summaryColumns: [{
             *            summaryType: ej.Grid.SummaryType.Sum,
             *            displayColumn: "Freight",
             *            dataMember: "Freight",
             *            format: "{0:C2}"
             *         }]
             *      }]                                    
             * });
             * &lt;/script&gt; 
             */

            /**
             * Gets or sets a value that indicates the text displayed after the summary column value
             * @remarks            
             * showSummary must be true and summaryRows must be given while using summaryColumns and their properties.
             * @name ejGrid#summaryRows->summaryColumns->suffix 	          
             * @default null
             * @type {string}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *      dataSource:window.gridData,
             *      columns:[{field: "OrderID"},{field: "Freight"}],
             *      showSummary: true,
             *      summaryRows: [{
             *         title: "Sum",
             *         summaryColumns: [{
             *            summaryType: ej.Grid.SummaryType.Sum,
             *            displayColumn: "Freight",
             *            dataMember: "Freight",
             *            suffix: "/-"
             *         }]
             *      }]                                    
             * });
             * &lt;/script&gt; 
             */

            /**
             * Gets or sets a value that indicates the text displayed before the summary column value
             * @remarks            
             * showSummary must be true and summaryRows must be given while using summaryColumns and their properties.
             * @name ejGrid#summaryRows->summaryColumns->prefix 	          
             * @default null
             * @type {string}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *      dataSource:window.gridData,
             *      showSummary: true,
             *      summaryRows: [{
             *         title: "Sum",
             *         summaryColumns: [{
             *            summaryType: ej.Grid.SummaryType.Sum,
             *            displayColumn: "Freight",
             *            dataMember: "Freight",
             *            prefix : "Currency:"
             *         }]
             *      }]                                    
             * });
             * &lt;/script&gt; 
             */
			 
			 /**
             * This defines the text alignment of a particular column header cell value. See {@link headerTextAlign}
             * @remarks
             * It is optional.
             * @name ejGrid#columns->headerTextAlign 	          
             * @default ej.TextAlign.Left
             * @type {enum}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   columns:[{field:"OrderID",headerTextAlign:ej.TextAlign.Center},{field:"CustomerID",headerTextAlign:ej.TextAlign.Right},{field:"ShipCity"}]
             * });
             * &lt;/script&gt; 
             */

            /**
             * Gets or sets a value that indicates the text displayed in the summary column as a value
             * @remarks            
             * showSummary must be true and summaryRows must be given while using summaryColumns and their properties.
             * The summaryType property must be set as Custom.
             * @name ejGrid#summaryRows->summaryColumns->customSummaryValue 	          
             * @default null
             * @type {string}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *      dataSource:window.gridData,
             *      columns:[{field: "OrderID"},{field: "Freight"}],
             *      showSummary: true,
             *      summaryRows: [{
             *         title: "Sum",
             *         summaryColumns: [{
             *            summaryType: ej.Grid.SummaryType.Custom,
             *            displayColumn: "Freight",
             *            dataMember: "Freight",
             *            customSummaryValue : "Currency"
             *         }]
             *      }]                                    
             * });    
             * &lt;/script&gt; 
             */
            summaryRows: [],
            /**		
             * Align content in the grid control from right to left by setting the property as true.
             * @default false
             * @type {boolean}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   enableRTL:true,
             * });
             * &lt;/script&gt; 
             */
            enableRTL: false,
            /**		
             * Gets or sets a value that indicates whether to enable the alternative rows differentiation in the grid records based on corresponding theme.
             * @default true
             * @type {boolean}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   enableAltRow:true,
             * });
             * &lt;/script&gt; 
             */
            enableAltRow: true,
            currentViewData: null,
            /**		
             * This specifies the grid to add the details row for the corresponding master row
             * @default null
             * @type {string}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script id="templateData" type="text/x-jsrender"&gt;
             * &lt;table&gt;
             * &lt;tr&gt;
             * &lt;td&gt;
             * &lt;img src="styles/images/Employees/{{:EmployeeID}}.png" alt="{{:EmployeeID}}"/&gt;
             * &lt;/td&gt;
             * &lt;/tr&gt;
             * &lt;/table&gt;
             * &lt;/script&gt;
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   detailsTemplate:"#templateData",
             *   detailsDataBound: "detailGridData",
             * });             
             * &lt;/script&gt;             
             */
            detailsTemplate: null,
            /**		
            * This specifies the grid to add the grid control inside the grid row of the parent with expand/collapse options
            * @default null
            * @type {object}
            * @example 	       
            * &lt;div id="Grid"&gt;&lt;/div&gt;
            * &lt;script&gt;
            * $("#Grid").ejGrid({
            *   dataSource:window.gridData,
            *    childGrid: {
            * dataSource: window.employeeView,
            * queryString: "EmployeeID",
            * }
            * });
            * &lt;/script&gt;
            */
            childGrid: null,
            /**		
             * Gets or sets a value that indicates to render the grid with template rows. The template row must be a table row. That table row must have the JavaScript render binding format ({{:columnName}}) then the grid data source binds the data to the corresponding table row of the template.
             * @default null
             * @type {string}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script id="templateData" type="text/x-jsrender"&gt;
             * &lt;tr&gt;
             * &lt;td&gt;
             * &lt;img src="styles/images/Employees/{{:EmployeeID}}.png" alt="{{:EmployeeID}}"/&gt;
             * &lt;/td&gt;
             * &lt;td&gt;
             * {{:EmployeeID}}
             * &lt;/td&gt;
             * &lt;/tr&gt;
             * &lt;/script&gt;
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *  dataSource:window.gridData,
             *   rowTemplate:"#templateData",
             *   columns:[{headerText:"Employeephoto"},{field:"EmployeeID",headerText:"EmployeeID"}],
             * });
             * &lt;/script&gt;
             */
            rowTemplate: null,
            /**		
             * Triggered detail template row is initialized.
             * @remarks
             * Template must be bind to detailsTemplate property while using this event
             * @event
			 * @name ejGrid#detailsDataBound 	
			 * @param {Object} argument Event parameters from grid              
			 * @param {boolean}  argument.cancel Returns the cancel option value.
			 * @param {object}  argument.detailsElement Returns details row element.
             * @param {object}  argument.data Returns the details row data.
			 * @param {object}  argument.model Returns the grid model.
			 * @param {string}  argument.type Returns the name of the event.
			 * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt;
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    detailsDataBound: function (args){}
             * });
             * &lt;/script&gt;
             */
            detailsDataBound: null,
            /**    
             * Triggered every time a request is made to access row information, element and data.
             * @event
             * @name ejGrid#rowDataBound 	
             * @param {Object} argument Event parameters from grid              
             * @param {object}  argument.row Returns grid row.
             * @param {boolean}  argument.cancel Returns the cancel option value.
             * @param {object}  argument.data Returns current row record object (JSON).
             * @param {object} argument.foreignKeyData Returns the foreign key record object (JSON).
             * @param {object}  argument.model Returns the grid model.
             * @param {string}  argument.type Returns the name of the event.
             * @example 
             * &lt;div id="Grid"&gt;&lt;/div&gt;
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    rowDataBound: function (args){}
             * });
             * &lt;/script&gt;
             */
            rowDataBound: null,
            /**    
             * Triggered every time a request is made to access particular cell information, element and data.
             * @event
             * @name ejGrid#queryCellInfo 	
             * @param {Object} argument Event parameters from grid              
             * @param {object}  argument.cell Returns grid cell.
             * @param {boolean}  argument.cancel Returns the cancel option value.
             * @param {object}  argument.data Returns current row record object (JSON).
             * @param {string}  argument.text Returns the text value in the cell.
             * @param {object} argument.column Returns the column object.
             * @param {object} argument.foreignKeyData Returns the foreign key record object (JSON).
             * @param {object}  argument.model Returns the grid model.
             * @param {string}  argument.type Returns the name of the event.
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    queryCellInfo: function (args){}
             * });
             * &lt;/script&gt;
             */
            queryCellInfo: null,
            /**
             * @callback mergeColback(int no)
               @callback mergeRowback(int no)
               @callback merge(int no , int no)
              */
			 /**    
             * Triggered every time a request is made to access particular cell information, element and data.
             * @event
             * @name ejGrid#mergeCellInfo 	
             * @param {Object} argument Event parameters from grid              
             * @param {object}  argument.cell Returns grid cell.
             * @param {boolean}  argument.cancel Returns the cancel option value.
             * @param {object}  argument.data Returns current row record object (JSON).
             * @param {string}  argument.text Returns the text value in the cell.
             * @param {object}  argument.column Returns the column object.
             * @param  {mergeRowback} argument.rowMerge Returns the merge rows in grid.
             * @param  {mergeColback}argument.colMerge Returns the merge column in grid.
             * @param  {merge} argument.merge Returns the merge the rows and columns in grid.
             * @param {object}  argument.model Returns the grid model.
             * @param {string}  argument.type Returns the name of the event.
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    mergeCellInfo: function (args){}
             * });
             * &lt;/script&gt;
             */
            mergeCellInfo: null,
            /**    
             * Triggered when the grid is rendered completely.
             * @event
             * @name ejGrid#create 	
             * @param {Object} argument Event parameters from grid             
             * @param {boolean}  argument.cancel Returns the cancel option value.
             * @param {object}  argument.model Returns the grid model.
             * @param {string}  argument.type Returns the name of the event.
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt;
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    create: function (args){}
             * });
             * &lt;/script&gt;
             */
            create: null,
            /**    
             * Triggered for every grid action before its starts.
             * @event
             * @name ejGrid#actionBegin              
             * @param {Object} argument Event parameters when grid is initialized:          
             * @param {boolean}  argument.cancel Returns the cancel option value.
             * @param {object}  argument.model Returns the grid model.
             * @param {string}  argument.type Returns the name of the event.
             
             * @param {Object} argument Event parameters when grid paging action starts:
             * @param {boolean}  argument.cancel Returns the cancel option value.
             * @param {number} argument.currentPage  Returns the current selected page number.
             * @param {number} argument.previousPage  Returns the previous selected page number.
             * @param {number} argument.endIndex Returns the end row index of that current page.
             * @param {object}  argument.model Returns the grid model.
             * @param {string}  argument.requestType Returns request type.
             * @param {number} argument.startIndex  Returns the start row index of that current page.
             * @param {string}  argument.type Returns the name of the event.
 
             * @param {Object} argument Event parameters when grid sorting action starts:
             * @param {boolean}  argument.cancel Returns the cancel option value.
             * @param {string}  argument.columnName Returns the current grouped column field name.
             * @param {object}  argument.model Returns the grid model.
             * @param {string}  argument.requestType Returns request type.
             * @param {string}  argument.type Returns the name of the event. 
             * @param {string}  argument.columnSortDirection  Returns the column sort direction.
 
             * @param {Object} argument Event parameters when grid grouping action starts:
             * @param {boolean}  argument.cancel Returns the cancel option value.
             * @param {string}  argument.columnName Returns the current grouped column field name.
             * @param {object}  argument.model Returns the grid model.
             * @param {string}  argument.requestType Returns request type.
             * @param {string}  argument.type Returns the name of the event.        
 
             * @param {Object} argument Event parameters when grid record editing action starts:
             * @param {boolean}  argument.cancel Returns the cancel option value.
             * @param {object}  argument.row  Returns current edited row.
             * @param {object}  argument.model Returns the grid model.
             * @param {string} argument.originalEventType Returns the current action event type.
             * @param {string} argument.primaryKey Returns primary key.
             * @param {string} argument.primaryKeyValue Returns primary key value.
             * @param {string}  argument.requestType Returns request type.
             * @param {number}  argument.rowIndex Returns the edited row index.
             * @param {string}  argument.type Returns the name of the event.
 
             * @param {Object} argument Event parameters when grid record save action starts:
             * @param {boolean}  argument.cancel Returns the cancel option value.
             * @param {object}  argument.data Returns the record object (JSON).
             * @param {object}  argument.foreignKeyData Returns the foreign key record object (JSON).
             * @param {object}  argument.model Returns the grid model.
             * @param {number}  argument.selectedRow Returns the selected row index.
             * @param {string}  argument.requestType Returns request type.
             * @param {string}  argument.type Returns the name of the event. 
 
             * @param {Object} argument Event parameters when grid record cancel action starts:
             * @param {boolean}  argument.cancel Returns the cancel option value.
             * @param {object}  argument.model Returns the grid model.
             * @param {string}  argument.requestType Returns request type.
             * @param {string}  argument.type Returns the name of the event. 
 
             * @param {Object} argument Event parameters when grid record delete action starts:
             * @param {boolean}  argument.cancel Returns the cancel option value.
             * @param {object}  argument.data Returns the record object (JSON).
             * @param {object}  argument.foreignKeyData Returns the foreign key record object (JSON).
             * @param {object}  argument.model Returns the grid model.
             * @param {string}  argument.requestType Returns request type.
             * @param {object}  argument.tr Returns selected row for delete.
             * @param {string}  argument.type Returns the name of the event.
 
             * @param {Object} argument Event parameters when add new record action starts:
             * @param {boolean}  argument.cancel Returns the cancel option value.
             * @param {object}  argument.data Returns the record object (JSON).
             * @param {object}  argument.model Returns the grid model.
             * @param {string}  argument.requestType Returns request type.
             * @param {string}  argument.type Returns the name of the event.
 
             * @param {Object} argument Event parameters when grid filtering action starts:
             * @param {boolean}  argument.cancel Returns the cancel option value.
             * @param {object}  argument.currentFilteringColumn Returns current filtering column field name.
             * @param {object}  argument.filterCollection Returns filter details.
             * @param {object}  argument.model Returns the grid model.
             * @param {string}  argument.requestType Returns request type.
             * @param {string}  argument.type Returns the name of the event.
 
             * @example 
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    actionBegin: function (args){}
             * });
             * &lt;/script&gt;
             */
            actionBegin: null,
            /**    
             * Triggered for every grid action success event.
             * @event
             * @name ejGrid#actionComplete 	
             * @param {Object} argument Arguments in actionComplete when grid is initialized.     
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.requestType Returns request type.
             * @param {string} argument.type Returns the name of the event.
             
             * @param {Object} argument Arguments in actionComplete after grid paging action is completed.
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {number} argument.currentPage Returns the current selected page number.
             * @param {number} argument.previousPage Returns the previous selected page number.
             * @param {number} argument.endIndex Returns the end row index of that current page.
             * @param {object} argument.model Returns the grid model.				
             * @param {string} argument.originalEventType Returns current action event type.
             * @param {string} argument.requestType Returns request type.
             * @param {number} argument.startIndex Returns the start row index of the current page.
             * @param {object} argument.target Returns grid element.
             * @param {string} argument.type Returns the name of the event.
             
             * @param {object} argument Arguments in actionComplete after grid sorting action is completed.				
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {string} argument.columnName Returns the current sorted column field name.
             * @param {string} argument.columnSortDirection Returns the column sort direction.
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.originalEventType Returns current action event type.
             * @param {string} argument.requestType Returns request type.
             * @param {object} argument.target Returns grid element.
             * @param {string} argument.type Returns the name of the event.
             
             * @param {object} argument Arguments in actionComplete after grid grouping action is completed.
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {string} argument.columnName Returns the current grouped column field name.
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.originalEventType Returns current action event type.
             * @param {string} argument.requestType Returns request type.
             * @param {object} argument.target Returns grid element.
             * @param {string} argument.type Returns the name of the event.
             
             * @param {object} argument Arguments in actionComplete after grid record editing action is completed.
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {object} argument.row Returns current edited row.
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.originalEventType Returns current action event type.
             * @param {string} argument.primaryKey Returns primary key.
             * @param {string} argument.primaryKeyValue Returns primary key value.
             * @param {string} argument.requestType Returns request type.
             * @param {number} argument.rowIndex Returns the edited row index.
             * @param {object} argument.target Returns grid element.
             * @param {string} argument.type Returns the name of the event.
             
             * @param {object} argument Arguments in actionComplete after grid record save action is completed.
             * @param {object} argument.cancel Returns the cancel option value.
             * @param {object} argument.data Returns the record object (JSON).
             * @param {number} argument.selectedRow Returns the selectedRow index.
             * @param {object} argument.foreignKeyData Returns the foreign key record object (JSON).
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.originalEventType Returns current action event type.
             * @param {string} argument.requestType Returns request type.
             * @param {object} argument.target Returns grid element.
             * @param {string} argument.type Returns the name of the event.
             
             * @param {object} argument Arguments in actionComplete after grid record cancel action is completed.
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.originalEventType Returns current action event type.
             * @param {string} argument.requestType Returns request type.
             * @param {object} argument.target Returns grid element.
             * @param {string} argument.type Returns the name of the event.
             
             * @param {object} argument Arguments in actionComplete after grid record delete action is completed.
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {object} argument.data Returns the record object (JSON).
             * @param {object} argument.foreignKeyData Returns the foreign key record object (JSON).
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.originalEventType Returns current action event type.
             * @param {string} argument.requestType Returns request type.
             * @param {object} argument.target Returns grid element.
             * @param {object} argument.tr Returns selected row for delete.
             * @param {string} argument.type Returns the name of the event.
             
             * @param {object} argument Arguments in actionComplete after add new record action is completed.
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {object} argument.data Returns empty record object (JSON).
             * @param {object} argument.foreignKeyData Returns the foreign key record object (JSON).
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.originalEventType Returns current action event type.
             * @param {string} argument.requestType Returns request type.
             * @param {object} argument.target Returns grid element.
             * @param {string} argument.type Returns the name of the event.
             
             * @param {object} argument Arguments in actionComplete after grid filtering action is completed.
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {string} argument.currentFilteringColumn Returns current filtering column field name.
             * @param {object} argument.filterCollection Returns filter details.
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.originalEventType Returns current action event type.
             * @param {string} argument.requestType Returns request type.
             * @param {object} argument.target Returns grid element.
             * @param {string} argument.type Returns the name of the event.
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    actionComplete: function (args) {}
             * }); 
             * &lt;/script&gt;
             */
            actionComplete: null,
            /**    
             * Triggered for every grid action server failure event.
             * @event
             * @name ejGrid#actionFailure	
             * @param {Object} argument Arguments in actionComplete when grid is initialized.     
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.requestType Returns request type.
             * @param {string} argument.type Returns the name of the event.
             * @param {object} argument.error Returns the error return by server.
             
             * @param {Object} argument Arguments in actionComplete after grid paging action is completed.
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {number} argument.currentPage Returns the current selected page number.
             * @param {number} argument.previousPage Returns the previous selected page number.
             * @param {number} argument.endIndex Returns the end row index of that current page.
             * @param {object} argument.model Returns the grid model.				
             * @param {string} argument.originalEventType Returns current action event type.
             * @param {string} argument.requestType Returns request type.
             * @param {number} argument.startIndex Returns the start row index of the current page.
             * @param {object} argument.target Returns grid element.
             * @param {string} argument.type Returns the name of the event.
             * @param {object} argument.error Returns the error return by server.
             
             * @param {object} argument Arguments in actionComplete after grid sorting action is completed.				
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {string} argument.columnName Returns the current sorted column field name.
             * @param {string} argument.columnSortDirection Returns the column sort direction.
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.originalEventType Returns current action event type.
             * @param {string} argument.requestType Returns request type.
             * @param {object} argument.target Returns grid element.
             * @param {string} argument.type Returns the name of the event.
             * @param {object} argument.error Returns the error return by server.
             
             * @param {object} argument Arguments in actionComplete after grid grouping action is completed.
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {string} argument.columnName Returns the current grouped column field name.
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.originalEventType Returns current action event type.
             * @param {string} argument.requestType Returns request type.
             * @param {object} argument.target Returns grid element.
             * @param {string} argument.type Returns the name of the event.
             * @param {object} argument.error Returns the error return by server.
             
             * @param {object} argument Arguments in actionComplete after grid record editing action is completed.
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {object} argument.row Returns current edited row.
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.originalEventType Returns current action event type.
             * @param {string} argument.primaryKey Returns primary key.
             * @param {string} argument.primaryKeyValue Returns primary key value.
             * @param {string} argument.requestType Returns request type.
             * @param {number} argument.rowIndex Returns the edited row index.
             * @param {object} argument.target Returns grid element.
             * @param {string} argument.type Returns the name of the event.
             * @param {object} argument.error Returns the error return by server.
             
             * @param {object} argument Arguments in actionComplete after grid record save action is completed.
             * @param {object} argument.cancel Returns the cancel option value.
             * @param {object} argument.data Returns the record object (JSON).
             * @param {number} argument.selectedRow Returns the selectedRow index.
             * @param {object} argument.foreignKeyData Returns the foreign key record object (JSON).
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.originalEventType Returns current action event type.
             * @param {string} argument.requestType Returns request type.
             * @param {object} argument.target Returns grid element.
             * @param {string} argument.type Returns the name of the event.
             * @param {object} argument.error Returns the error return by server.
             
             * @param {object} argument Arguments in actionComplete after grid record delete action is completed.
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {object} argument.data Returns the record object (JSON).
             * @param {object} argument.foreignKeyData Returns the foreign key record object (JSON).
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.originalEventType Returns current action event type.
             * @param {string} argument.requestType Returns request type.
             * @param {object} argument.target Returns grid element.
             * @param {object} argument.tr Returns selected row for delete.
             * @param {string} argument.type Returns the name of the event.
             * @param {object} argument.error Returns the error return by server.
             
             * @param {object} argument Arguments in actionComplete after add new record action is completed.
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {object} argument.data Returns empty record object (JSON).
             * @param {object} argument.foreignKeyData Returns the foreign key record object (JSON).
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.originalEventType Returns current action event type.
             * @param {string} argument.requestType Returns request type.
             * @param {object} argument.target Returns grid element.
             * @param {string} argument.type Returns the name of the event.
             * @param {object} argument.error Returns the error return by server.
             
             * @param {object} argument Arguments in actionComplete after grid filtering action is completed.
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {string} argument.currentFilteringColumn Returns current filtering column field name.
             * @param {object} argument.filterCollection Returns filter details.
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.originalEventType Returns current action event type.
             * @param {string} argument.requestType Returns request type.
             * @param {object} argument.target Returns grid element.
             * @param {string} argument.type Returns the name of the event.
             * @param {object} argument.error Returns the error return by server.
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    actionFailure: function (args) {}
             * }); 
             * &lt;/script&gt;
             */
            actionFailure: null,
            /**    
             * Triggered before the record is going to be edited.
             * @remarks
             * allowEditing and allowSelection must be set as true
             * @event
             * @name ejGrid#beginEdit 	
             * @param {Object} argument Arguments when beginEdit event is triggered.  
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {object} argument.row Returns the current edited row.
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.primaryKey Returns primary key.
             * @param {string} argument.primaryKeyValue Returns primary key value.
             * @param {number} argument.rowIndex Returns the edited row index.
             * @param {string} argument.type Returns the name of the event.
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    beginEdit: function (args) {}
             * });
             * &lt;/script&gt;
             */
            beginEdit: null,
		    /**    
             * Triggered after the record is edited.
             * @event
             * @name ejGrid#endEdit 	
             * @param {Object} argument Arguments when endEdit event is triggered.  
             * @param {object} argument.model Returns the grid model.
		     * @param {object} argument.data Returns modified data.             
             * @param {string} argument.type Returns the name of the event.
             * @example 
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    endEdit: function (args) {}
             * });
             * &lt;/script&gt;
             */
            endEdit: null,
	        /**    
             * Triggered after the record is added.
             * @event
             * @name ejGrid#endAdd 	
             * @param {Object} argument Arguments when endAdd event is triggered.  
             * @param {object} argument.model Returns the grid model.
		     * @param {object} argument.data Returns added data.
             * @param {string} argument.type Returns the name of the event.             
             * @example 
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    endAdd: function (args) {}
             * });
             * &lt;/script&gt;
             */
            endAdd: null,
		    /**    
             * Triggered after the record is deleted.
             * @event
             * @name ejGrid#endDelete 	
             * @param {Object} argument Arguments when endDelete event is triggered.  
             * @param {object} argument.model Returns the grid model.
		     * @param {object} argument.data Returns deleted data.
             * @param {string} argument.type Returns the name of the event.             
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    endDelete: function (args) {}
             * });
             * &lt;/script&gt;
             */
            endDelete: null,
			 /**    
             * Triggered before the batch add.
             * @event
             * @name ejGrid#beforeBatchAdd 	
             * @param {Object} argument Arguments when beforeBatchAdd event is triggered.  
             * @param {object} argument.model Returns the grid model.
		     * @param {object} argument.data Returns deleted data.
             * @param {string} argument.type Returns the name of the event.
             * @param {object} argument.defaultData Returns the default data object.
             * @param {string} argument.primaryKey Returns primaryKey.
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    beforeBatchAdd: function (args) {}
             * });
             * &lt;/script&gt;
             */
            beforeBatchAdd: null,
            /**    
             * Triggered before the batch save.
             * @event
             * @name ejGrid#beforeBatchSave 	
             * @param {Object} argument Arguments when beforeBatchSave event is triggered.  
             * @param {object} argument.model Returns the grid model.
		     * @param {object} argument.data Returns deleted data.
             * @param {string} argument.type Returns the name of the event.
             * @param {object} argument.batchChanges Returns the changed record object.
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    beforeBatchSave: function (args) {}
             * });
             * &lt;/script&gt;
             */
            beforeBatchSave: null,
            /**    
             * Triggered before the batch delete.
             * @event
             * @name ejGrid#beforeBatchDelete 	
             * @param {Object} argument Arguments when beforeBatchDelete event is triggered.  
             * @param {object} argument.model Returns the grid model.
		     * @param {object} argument.data Returns deleted data.
             * @param {string} argument.type Returns the name of the event.
             * @param {string} argument.primaryKey Returns primaryKey.
             * @param {number} argument.rowIndex Returns the row index.
             * @param {object} argument.rowData Returns the row data.
             * @param {object} argument.row Returns the row element.
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    beforeBatchDelete: function (args) {}
             * });
             * &lt;/script&gt;
             */
            beforeBatchDelete: null,
            /**    
             * Triggered when record batch add.
             * @event
             * @name ejGrid#batchAdd 	
             * @param {Object} argument Arguments when batchAdd event is triggered.  
             * @param {object} argument.model Returns the grid model.
		     * @param {object} argument.data Returns deleted data.
             * @param {string} argument.type Returns the name of the event.
             * @param {object} argument.columnObject Returns the column object.
             * @param {number} argument.columnIndex Returns the column index.
             * @param {object} argument.row Returns the row element.
             * @param {object} argument.primaryKey Returns the primaryKey.            
             * @param {object} argument.cell Returns the cell object.   
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    batchAdd: function (args) {}
             * });
             * &lt;/script&gt;
             */
            batchAdd: null,
            /**    
             * Triggered when record batch delete.
             * @event
             * @name ejGrid#batchDelete 	
             * @param {Object} argument Arguments when batchDelete event is triggered.  
             * @param {object} argument.model Returns the grid model.
		     * @param {object} argument.data Returns deleted data.
             * @param {string} argument.type Returns the name of the event.              
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    batchDelete: function (args) {}
             * });
             * &lt;/script&gt;
             */
            batchDelete: null,
            /**    
             * Triggered when record cell save.
             * @event
             * @name ejGrid#cellSave 	
             * @param {Object} argument Arguments when cellSave event is triggered.  
             * @param {object} argument.model Returns the grid model.
		     * @param {object} argument.data Returns deleted data.
             * @param {string} argument.type Returns the name of the event.
             * @param {string} argument.columnName Returns the column name.
             * @param {string} argument.value Returns the cell value.
             * @param {object} argument.rowData Returns the row data object.
             * @param {string} argument.previousValue Returns the previous value of the cell.
             * @param {object} argument.columnObject Returns the column object.
             * @param {object} argument.cell Returns the cell object.
             * @param {boolean} argument.isForeignKey Returns isForeignKey option value.
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    cellSave: function (args) {}
             * });
             * &lt;/script&gt;
             */
            cellSave: null,            
            /**    
             * Triggered when record cell edit.
             * @event
             * @name ejGrid#cellEdit 	
             * @param {Object} argument Arguments when cellEdit event is triggered.  
             * @param {object} argument.model Returns the grid model.
		     * @param {object} argument.data Returns deleted data.
             * @param {string} argument.type Returns the name of the event.
             * @param {object} argument.validationRules Returns the validation rules.
             * @param {string} argument.columnName Returns the column name.
             * @param {string} argument.value Returns the cell value.
             * @param {object} argument.rowData Returns the row data object.
             * @param {string} argument.previousValue Returns the previous value of the cell.
             * @param {object} argument.columnObject Returns the column object.
             * @param {object} argument.cell Returns the cell object.
             * @param {boolean} argument.isForeignKey Returns isForeignKey option value.
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    cellEdit: function (args) {}
             * });
             * &lt;/script&gt;
             */
            cellEdit: null,
            /**    
             * Triggered when column resize start.
             * @event
             * @name ejGrid#resizeStart 	
             * @param {Object} argument Arguments when resizeStart event is triggered.  
             * @param {object} argument.model Returns the grid model.
		     * @param {object} argument.data Returns deleted data.
             * @param {string} argument.type Returns the name of the event.             
             * @param {number} argument.columnIndex Returns the column index.            
             * @param {object} argument.column Returns the column object.            
             * @param {object} argument.target Returns the grid object.
             * @param {number} argument.oldWidth Returns the old width value.            
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    resizeStart: function (args) {}
             * });
             * &lt;/script&gt;
             */
            resizeStart: null,
            /**    
             * Triggered when column resize end.
             * @event
             * @name ejGrid#resizeEnd 	
             * @param {Object} argument Arguments when resizeEnd event is triggered.  
             * @param {object} argument.model Returns the grid model.
		     * @param {object} argument.data Returns deleted data.
             * @param {string} argument.type Returns the name of the event.             
             * @param {number} argument.columnIndex Returns the column index.            
             * @param {object} argument.column Returns the column object.            
             * @param {object} argument.target Returns the grid object.
             * @param {number} argument.oldWidth Returns the old width value. 
             * @param {number} argument.newWidth Returns the new width value.
             * @param {number} argument.extra Returns the extra width value.            
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    resizeEnd: function (args) {}
             * });
             * &lt;/script&gt;
             */
            resizeEnd: null,
            /**    
             * Triggered after column resized.
             * @event
             * @name ejGrid#resized 	
             * @param {Object} argument Arguments when resized event is triggered.  
             * @param {object} argument.model Returns the grid model.
		     * @param {object} argument.data Returns deleted data.
             * @param {string} argument.type Returns the name of the event.             
             * @param {number} argument.columnIndex Returns the column index.            
             * @param {object} argument.column Returns the column object.            
             * @param {object} argument.target Returns the grid object.
             * @param {number} argument.oldWidth Returns the old width value. 
             * @param {number} argument.newWidth Returns the new width value.                      
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    resized: function (args) {}
             * });
             * &lt;/script&gt;
             */
            resized: null,
            /**    
             * Triggered initial load.
             * @event
             * @name ejGrid#load 	
             * @param {Object} argument Arguments when load event is triggered.  
             * @param {object} argument.model Returns the grid model.
		     * @param {object} argument.data Returns deleted data.
             * @param {string} argument.type Returns the name of the event.                                       
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    load: function (args) {}
             * });
             * &lt;/script&gt;
             */
            load: null,
            /**    
             * Triggered when grid going to destroy.
             * @event
             * @name ejGrid#destroy 	
             * @param {Object} argument Arguments when destroy event is triggered.  
             * @param {object} argument.model Returns the grid model.
		     * @param {object} argument.data Returns deleted data.
             * @param {string} argument.type Returns the name of the event.                                       
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    destroy: function (args) {}
             * });
             * &lt;/script&gt;
             */
            destroy: null,
            /**    
             * Triggered before the row is going to be selected.
             * @remarks
             * allowSelection must be set as true
             * @event
             * @name ejGrid#rowSelecting
             * @param {Object} argument Arguments when rowSelecting event is triggered.  
             * @param {number} argument.rowIndex Returns the selected row index value.
             * @param {object} argument.row Returns the selected row element.
             * @param {object} argument.prevRow Returns the previous selected row element.
             * @param {number} argument.prevRowIndex Returns the previous selected row index.
             * @param {object} argument.data Returns current record object (JSON).
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.type Returns the name of the event.
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    rowSelecting: function (args) {}
             * });
             * &lt;/script&gt;
             */
            rowSelecting: null,
            /**    
             * Triggered after the row is selected.
             * @remarks
             * allowSelection must be set as true
             * @event
             * @name ejGrid#rowSelected 	
             * @param {Object} argument Arguments when rowSelected event is triggered.  
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {object} argument.data Returns current record object (JSON).
             * @param {object} argument.foreignKeyData Returns the foreign key record object (JSON).
             * @param {number} argument.rowIndex Returns the row index of the selected row.
             * @param {object} argument.row Returns the current selected row.
             * @param {object} argument.prevRow Returns the previous selected row element.
             * @param {number} argument.prevRowIndex Returns the previous selected row index.
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.type Returns the name of the event.
             * @example 
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    rowSelected: function (args) {}
             * });
             * &lt;/script&gt;
             */
            rowSelected: null,
            /**    
            * Triggered before the cell is going to be selected.
            * @remarks
            * allowSelection must be set as true and selectionMode must contains cell in array
            * @event
            * @name ejGrid#cellSelecting
            * @param {Object} argument Arguments when cellSelecting event is triggered.  
            * @param {number} argument.cellIndex Returns the selected cell index value.
            * @param {number} argument.previousRowCellIndex Returns the previous selected cell index value.
            * @param {object} argument.currentCell Returns the selected cell element.
            * @param {object} argument.previousRowCell Returns the previous selected cell element.
            * @param {object} argument.data Returns current record object (JSON).
            * @param {array}  argument.previousRowCellIndex Returns the previously selected row cell index values
            * @param {boolean} argument.isCtrlKeyPressed Returns whether the ctrl key is pressed while selecting cell
            * @param {boolean} argument.isShiftKeyPressed Returns whether the shift key is pressed while selecting cell
            * @param {object} argument.model Returns the grid model.
            * @param {string} argument.type Returns the name of the event.
            * @example
            * &lt;div id="Grid"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#Grid").ejGrid({
            *    cellSelecting: function (args) {}
            * });
            * &lt;/script&gt;
            */
            cellSelecting: null,
            /**    
           * Triggered after the cell is selected.
           * @remarks
           * allowSelection must be set as true and selectionMode must contains cell in array
           * @event
           * @name ejGrid#cellSelected
           * @param {Object} argument Arguments when cellSelecting event is triggered.  
           * @param {number} argument.cellIndex Returns the selected cell index value.
           * @param {number} argument.previousRowCellIndex Returns the previous selected cell index value.
           * @param {object} argument.currentCell Returns the selected cell element.
           * @param {object} argument.previousRowCell Returns the previous selected cell element.
           * @param {object} argument.data Returns current record object (JSON).
           * @param {array}  argument.selectedRowCellIndex Returns the selected row cell index values.
           * @param {boolean} argument.cancel Returns the cancel option value.
           * @param {object} argument.model Returns the grid model.
           * @param {string} argument.type Returns the name of the event.
           * @example
           * &lt;div id="Grid"&gt;&lt;/div&gt; 
           * &lt;script&gt;
           * $("#Grid").ejGrid({
           *    cellSelected: function (args) {}
           * });
           * &lt;/script&gt;
           */
            cellSelected: null,
            /**    
           * Triggered before the column is going to be selected.
           * @remarks
           * allowSelection must be set as true and selectionMode must contains column in array
           * @event
           * @name ejGrid#columnSelecting
           * @param {Object} argument Arguments when columnSelecting event is triggered.  
           * @param {number} argument.columnIndex Returns the selected column index value.
           * @param {number} argument.previousColumnIndex Returns the previous selected column index value.
           * @param {object} argument.headerCell Returns the selected header cell element.
           * @param {object} argument.prevColumnHeaderCell Returns the previous selected header cell element.
           * @param {object} argument.column Returns corresponding column object (JSON).
           * @param {array}  argument.previousColumnIndex Returns the previously selected column index values
           * @param {boolean} argument.isCtrlKeyPressed Returns whether the ctrl key is pressed while selecting cell
           * @param {boolean} argument.isShiftKeyPressed Returns whether the shift key is pressed while selecting cell
           * @param {object} argument.model Returns the grid model.
           * @param {string} argument.type Returns the name of the event.
           * @example
           * &lt;div id="Grid"&gt;&lt;/div&gt; 
           * &lt;script&gt;
           * $("#Grid").ejGrid({
           *    columnSelecting: function (args) {}
           * });
           * &lt;/script&gt;
           */
            columnSelecting: null,
            /**    
           * Triggered after the column is selected.
           * @remarks
           * allowSelection must be set as true and selectionMode must contains column in array
           * @event
           * @name ejGrid#columnSelected
           * @param {Object} argument Arguments when columnSelected event is triggered.  
           * @param {number} argument.columnIndex Returns the selected cell index value.
           * @param {number} argument.previousColumnIndex Returns the previous selected column index value.
           * @param {object} argument.headerCell Returns the selected header cell element.
           * @param {object} argument.prevColumnHeaderCell Returns the previous selected header cell element.
           * @param {object} argument.column Returns corresponding column object (JSON).
           * @param {array}  argument.selectedColumnsIndex Returns the selected columns values.
           * @param {boolean} argument.cancel Returns the cancel option value.
           * @param {object} argument.model Returns the grid model.
           * @param {string} argument.type Returns the name of the event.
           * @example
           * &lt;div id="Grid"&gt;&lt;/div&gt; 
           * &lt;script&gt;
           * $("#Grid").ejGrid({
           *    columnSelected: function (args) {}
           * });
           * &lt;/script&gt;
           */
            columnSelected: null,
            /**    
			 * Triggered when column dragging begins.
			 * @event
             * @remarks
             * allowGrouping or allowReordering must be set as true
			 * @name ejGrid#columnDragStart 	
			 * @param {Object} argument Arguments when columnDragStart event is triggered.  
			 * @param {boolean} argument.cancel Returns the cancel option value.
			 * @param {object} argument.draggableType Returns draggable element type.
             * @param {object} argument.column Returns the draggable column object.
			 * @param {object} argument.model Returns the grid model.
			 * @param {object} argument.target Returns drag start element.
			 * @param {string} argument.type Returns the name of the event.
			 * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
			 * $("#Grid").ejGrid({
			 *     columnDragStart: function (args) {}
			 * });
             * &lt;/script&gt;
			 */
            columnDragStart: null,
            /**    
             * Triggered when the column is being dragged.
             * @remarks
             * allowGrouping or allowReordering must be set as true
             * @event
             * @name ejGrid#columnDrag 	
             * @param {Object} argument Arguments when columnDrag event is triggered.  
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {object} argument.draggableType Returns draggable element type.
             * @param {object} argument.column Returns the draggable column object.
             * @param {object} argument.model Returns the grid model.
             * @param {object} argument.target Returns target elements based on mouse move position.
             * @param {string} argument.type Returns the name of the event.
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    columnDrag: function (args) {}
             * });
             * &lt;/script&gt;
             */
            columnDrag: null,
            /**    
             * Triggered when the column is dropped.
             * @remarks
             * allowGrouping or allowReordering must be set as true
             * @event
             * @name ejGrid#columnDrop 	
             * @param {Object} argument Arguments when columnDrop event is triggered.  
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {object} argument.draggableType Returns draggable element type.
             * @param {object} argument.column Returns the draggable column object.
             * @param {object} argument.model Returns the grid model.
             * @param {object} argument.target Returns dropped dragged element.
             * @param {string} argument.type Returns the name of the event.
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt;
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *  columnDrop: function (args) {}
             * });
             * &lt;/script&gt;
             */
            columnDrop: null,
            /**    
             * Triggered when record is clicked.
             * @remarks
             * allowSelection must be set as true
             * @event
             * @name ejGrid#recordClick 	
             * @param {Object} argument Arguments when recordClick event is triggered.  
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {object} argument.data Returns current record object (JSON).
             * @param {number} argument.rowIndex Returns the row index of the selected row.
             * @param {object} argument.row Returns the current selected row.
             * @param {object} argument.cell Returns the current selected cell.
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.type Returns the name of the event.
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    recordClick: function (args) {}
             * });
             * &lt;/script&gt;
             */
            recordClick: null,
            /**    
             * Triggered when record is double clicked.
             * @remarks
             * allowSelection must be set as true
             * @event
             * @name ejGrid#recordDoubleClick 	
             * @param {Object} argument Arguments when recordDoubleClick event is triggered.  
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {object} argument.data Returns current record object (JSON).
             * @param {number} argument.rowIndex Returns the row index of the selected row.
             * @param {object} argument.row Returns the current selected row.
             * @param {object} argument.cell Returns the current selected cell.
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.type Returns the name of the event.
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    recordDoubleClick: function (args) {}
             * });
             * &lt;/script&gt;
             */
            recordDoubleClick: null,
            /**    
             * Triggered when right clicked on grid element.
             * @event
             * @name ejGrid#rightClick 	
             * @param {Object} argument Arguments when rightClick event is triggered.  
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {object} argument.currentData Returns current record object (JSON).
             * @param {number} argument.rowIndex Returns the row index of the selected row.
             * @param {object} argument.row Returns the current selected row.
             * @param {object} argument.data Returns the selected row data object.
             * @param {number} argument.cellIndex Returns the cell index of the selected cell.
             * @param {string} argument.cellValue Returns the cell value.
             * @param {object} argument.cell Returns the cell object.
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.type Returns the name of the event.
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    rightClick: function (args) {}
             * });
             * &lt;/script&gt;
             */
            rightClick: null,
            /**    
             * Triggered when detail template row is clicked to collapse.
             * @remarks
             * detailsTemplate and detailsDataBound must be specified.
             * @event
             * @name ejGrid#detailsCollapse 	
             * @param {Object} argument Arguments when detailsCollapse event is triggered.  
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {object} argument.detailsRow Returns detail row element.
             * @param {object} argument.masterData Returns master row of detail row record object (JSON).
             * @param {object} argument.foreignKeyData Returns the foreign key record object (JSON).
             * @param {object} argument.masterRow Returns master row element.
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.type Returns the name of the event.
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    detailsCollapse: function (args) {}
             * });
             * &lt;/script&gt;
             */
            detailsCollapse: null,
            /**    
             * Triggered when detail template row is clicked to expand.
             * @remarks
             * detailsTemplate and detailsDataBound must be specified.
             * @event
             * @name ejGrid#detailsExpand 	
             * @param {Object} argument Arguments when detailsExpand event is triggered.  
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {object} argument.detailsRow Returns detail row element.
             * @param {object} argument.masterData Returns master row of detail row record object (JSON).
             * @param {object} argument.foreignKeyData Returns the foreign key record object (JSON).
             * @param {object} argument.masterRow Returns master row element.
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.type Returns the name of the event.
             * @example 
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    detailsExpand: function (args) {}
             * });
             * &lt;/script&gt;
             */
            detailsExpand: null,
            /**    
			 * Triggered when toolbar item is clicked in grid.
             * @remarks
             * showToolbar must be set as true and also add the toolbarItems.
			 * @event
			 * @name ejGrid#toolBarClick 	
			 * @param {Object} argument Arguments when toolBarClick event is triggered.  
			 * @param {boolean} argument.cancel Returns the cancel option value.
			 * @param {object} argument.currentTarget Returns the current item.
			 * @param {object} argument.model Returns the grid model.
			 * @param {boolean} argument.status Returns the status of toolbar item which denotes its enabled state
			 * @param {object} argument.target Returns the target item.
			 * @param {string} argument.type Returns the name of the event.
			 * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
			 * $("#Grid").ejGrid({
			 *    toolbarClick: function (args) {}
			 * });
             * &lt;/script&gt;
			 */
            toolbarClick: null,
            /**    
			 * Triggered before the context menu is opened.
             * @remarks
             * enableContextMenu must be set as true and also add the contextMenuItems.
			 * @event
			 * @name ejGrid#contextOpen	
			 * @param {Object} argument Arguments when contextOpen event is triggered.  
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {object} argument.currentTarget Returns the current item.
             * @param {object} argument.model Returns the grid model.
             * @param {boolean} argument.status Returns the status of contextmenu item which denotes its enabled state
             * @param {object} argument.target Returns the target item.
             * @param {string} argument.type Returns the name of the event.
			 * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
			 * $("#Grid").ejGrid({
			 *    contextOpen: function (args) {}
			 * });
             * &lt;/script&gt;
			 */

            contextOpen: null,
            /**    
            * Triggered when context menu item is clicked
            * @remarks
            * enableContextMenu must be set as true and also add the contextMenuItems.
			* @event
            * @name ejGrid#contextClick 	
            * @param {Object} argument Arguments when contextClick event is triggered.  
            * @param {boolean} argument.cancel Returns the cancel option value.
            * @param {object} argument.currentTarget Returns the current item.
            * @param {object} argument.model Returns the grid model.
            * @param {boolean} argument.status Returns the status of contextmenu item which denotes its enabled state
            * @param {object} argument.target Returns the target item.
            * @param {string} argument.type Returns the name of the event.
            * @example
            * &lt;div id="Grid"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#Grid").ejGrid({
            *    contextClick: function (args) {}
            * });
            * &lt;/script&gt;
            */
            contextClick: null,

            /**		
             * Gets or sets an object  that indicates to render the grid with specified columns
             * @name ejGrid#columns 
             * @default []
             * @type {array}
             * @example 
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData
             * });
             * var value = $("#Grid").ejGrid("option", "columns");
             * &lt;/script&gt; 
             */

            /**
             * Gets or sets a value that indicates to display the columns in the grid mapping  with column name of the dataSource.
             * @remarks
             * We must need to specify the field property of the column because the columns which are specified in the field property is only bound to the grid.
             * @name ejGrid#columns->field 	          
             * @default ""
             * @type {string}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   columns:[{field:"OrderID"}]
             * });
             * &lt;/script&gt; 
             */

            /**
			 * Gets or sets a value that indicates to display the title of that particular column.
             * @remarks
             * It is optional if the headerText is not mentioned then it will consider the field name as headerText
             * @name ejGrid#columns->headerText 	          
             * @default ""
             * @type {string}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   columns:[{field:"OrderID",headerText:"Order ID"},{field:"CustomerID",headerText:"Customer ID"}]
             * });
             * &lt;/script&gt; 
			 */

            /**
			 * Gets or sets a value that indicates whether to enable dynamic grouping behaviour for particular column.
             * @remarks
             * It is optional if we need to disable the grouping behaviour for particular column then set this property as false.
             * @name ejGrid#columns->allowGrouping 	          
             * @default true
             * @type {boolean}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   allowGrouping:true,
             *   columns:[{field:"OrderID"},{field:"CustomerID",allowGrouping:false},{field:"ShipCity"}]
             * });
             * &lt;/script&gt; 
			 */

            /**
             * Gets or sets a value that indicates whether to enable dynamic filtering behaviour for particular column.
             * @remarks
             * It is optional if we need to disable the filtering behaviour for particular column then set this property as false.
             * @name ejGrid#columns->allowFiltering 	          
             * @default true
             * @type {boolean}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   allowFiltering:true,
             *   columns:[{field:"OrderID"},{field:"CustomerID",allowFiltering:false},{field:"ShipCity"}]
             * });
             * &lt;/script&gt; 
             */

            /**
             * Gets or sets a value that indicates whether to enable dynamic sorting behaviour for particular column.
             * @remarks
             * It is optional if we need to disable the sorting behaviour for particular column then set this property as false.
             * @name ejGrid#columns->allowSorting 	          
             * @default true
             * @type {boolean}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   allowSorting:true,
             *   columns:[{field:"OrderID"},{field:"CustomerID",allowSorting:false},{field:"ShipCity"}] 
             * });
             * &lt;/script&gt; 
             */

            /**
             * Gets or sets a value that indicates whether to enable editing behaviour for particular column.
             * @remarks
             * It is optional if we need to disable the editing behaviour for particular column then set this property as false.
             * @name ejGrid#columns->allowEditing 	          
             * @default true
             * @type {boolean}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   editSettings:{allowEditing:true},
             *   columns:[{field:"OrderID"},{field:"CustomerID",allowEditing:false},{field:"ShipCity"}] 
             * });
             * &lt;/script&gt; 
             */

            /**
             * Gets or sets a value that indicates whether to bind the column which are not in the datasource 
             * @remarks
             * If we need to bind the column to the grid which is not in the datasource then we must enable isUnBound property.
             * There is no need to specify field property if the column is unBound.
             * @name ejGrid#columns->isUnbound 	          
             * @default false
             * @type {boolean}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   columns:[{field:"OrderID",isUnbound:false},{field:"CustomerID"},{field:"ShipCity",headerText:"ShipCity"}]
             * });
             * &lt;/script&gt; 
             */

            /**
             * Gets or sets a value that indicates whether to  enables column template for a particular column.
             * @remarks
             * Need to bind the templateID, if the columnTemplate is set as true.
             * @name ejGrid#columns->template 	          
             * @default false
             * @type {boolean}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script id="columnTemplate" type="text/x-jsrender"&gt;
             * &lt;img src="styles/images/Employees/{{:EmployeeID}}.png" alt="{{:EmployeeID}}"/&gt;
             * &lt;/script&gt;
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *  dataSource:window.gridData,
             *  columns:[{headerText:"Employee",template:true,templateID:"#columnTemplate"},{field:"EmployeeID"}]
             * });
             * &lt;/script&gt;
             */

            /**
             * Gets or sets a value that indicates to render the element(based on edit type)  for editing the grid record. . See {@link editingType}
             * @remarks
             * allowEditing must be set as true.
             * It is optional.
             * @name ejGrid#columns->editType 	          
             * @default ej.Grid.EditingType.String
             * @type {enum}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   editSettings:{allowEditing:true},
             *   columns:[{field:"OrderID"},{field:"CustomerID"},{field:"Freight",editType:ej.Grid.EditingType.Numeric, editParams: { decimalPlaces: 2 }}]
             * });
             * &lt;/script&gt; 
             */

            /**
            * Gets or sets a template that displays a custom editor used to edit column values. See {@link editTemplate}
            * @remarks
            * allowEditing must be set as true.
            * It is optional.
            * @default null
            * @type {object}
            * @name ejGrid#columns->editTemplate 	          
            * @example
            * &lt;div id="Grid"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#Grid").ejGrid({
            *   dataSource:window.gridData,
            *   editSettings:{allowEditing:true},
            *   columns:[{field:"OrderID"},{field:"CustomerID"},
            *             { field: "EmployeeID",editTemplate: { create: function () { return "&lt;input&gt;"; }, read: function (args) { return args.ejMaskEdit("get_StrippedValue"); }, write: function (args) { args.element.ejMaskEdit({ width: "100%" ,maskFormat: "9",value: args.rowdata !== undefined ? args.rowdata["EmployeeID"]: "" }); } } }]
            * });
            * &lt;/script&gt; 
            */

            /**
             * Gets or sets a value that indicates to align the text within the column. See {@link textAlign}
             * @remarks
             * It is optional.
             * @name ejGrid#columns->textAlign 	          
             * @default ej.TextAlign.Left
             * @type {enum}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   columns:[{field:"OrderID",textAlign:ej.TextAlign.Center},{field:"CustomerID",textAlign:ej.TextAlign.Right},{field:"ShipCity"}]
             * });
             * &lt;/script&gt; 
             */

            /**
             * Gets or sets a value that indicates the column is act as a primary key(read-only) of the grid. The editing is performed based on the primary key column
             * @remarks
             * When editing is enable then we must set isPrimaryKey property as true for the primary key column.
             * @name ejGrid#columns->isPrimaryKey 	          
             * @default false
             * @type {boolean}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({             
             *   dataSource:window.gridData,
             *   editSettings:{allowEditing:true},
             *   columns:[{field:"OrderID",isPrimaryKey:true},{field:"CustomerID"},{field:"ShipCity"}]
             * });
             * &lt;/script&gt; 
             */

            /**
             * Gets or sets a value that indicates thecolumn has an identity in the database.            
             * @name ejGrid#columns->isIdentity 	          
             * @default false
             * @type {boolean}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   columns:[{field:"OrderID"},{field:"CustomerID",isIdentity:true},{field:"ShipCity"}]
             * });
             * &lt;/script&gt; 
             */

            /**
             * Gets or sets a value that indicates whether this column is visible in the grid.
             * @remarks
             * It is optional.
             * @name ejGrid#columns->visible 	          
             * @default true
             * @type {boolean}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   columns:[{field:"OrderID"},{field:"CustomerID",visible:false},{field:"ShipCity"}]
             * });
             * &lt;/script&gt; 
             */

            /**
			 * Gets or sets a value that indicates to bind the external datasource to the particular column when columnEditType as "dropdownedit" and also it is used to bind the datasource to the foreign key column while editing the grid. 
             * //Where data is array of JSON objects of text and value for the drop-down and array of JSON objects for foreign key column.
             * @remarks
             * We must specify the dataSource property.
             * @name ejGrid#columns->dataSource 	          
             * @default null
             * @type {array}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt;  
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   columns:[{field:"OrderID"},{field:"CustomerID",visible:false},{field:"ShipCity"}]
             * });
             * &lt;/script&gt;
             */

            /**
             * Gets or sets a value that indicates to provide custom css for an individual column.
             * @name ejGrid#columns->cssClass 	          
             * @default -
             * @type {string}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;style class="temp"&gt;
             * .temp{
             * color:green;}
             * &lt;/style&gt;
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   columns:[{field:"OrderID"},{field:"CustomerID",cssClass:"temp"},{field:"ShipCity"}]
             * });
             * &lt;/script&gt; 
             */

            /**
             * Gets or sets a value that indicates to display the specified default value while adding a new record to the grid
             * @remarks
             * It is optional.allowAdding must be true while using this property.
             * @name ejGrid#columns->defaultValue 	          
             * @default -
             * @type {string/number/boolean/date}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt;          
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   editSettings: {allowAdding: true},
             *   toolbarSettings: { showToolbar: true, toolbarItems: [ej.Grid.ToolBarItems.Add] },
             *   columns:[{field:"OrderID"},{field:"CustomerID"},{field:"ShipCity",defaultValue:"ABC"}]
             * });
             * &lt;/script&gt;
             */

            /**
			 * Gets or sets a value that indicates to add the template within the header element of the particular column.
             * @remarks
             * It is optional.
             * @name ejGrid#columns->headerTemplateID 	          
             * @default null
             * @type {string}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;div id="customerTemplate"&gt;
             * &lt;span class="e-userlogin e-icon headericon"&gt;&lt;/span&gt;
             *  CUS ID
             * &lt;/div&gt;
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   columns:[{field:"OrderID",headerTemplateID: "#customerTemplate"},{field:"CustomerID"},{field:"ShipCity"}]
             * });
             * &lt;/script&gt;
             */

            /**
			 * Gets or sets a value that indicates to define the width for a particular column in the grid.
             * @remarks
	     * The column width support units in percent, px, number.
             * It is optional.
             * @name ejGrid#columns->width 	          
             * @default -
             * @type {number}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt;          
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   columns:[{field:"OrderID",width:50},{field:"CustomerID",width:"15%"},{field:"ShipCity",width:"70px"}]
             * });
             * &lt;/script&gt;
             */

            /**
             * Gets or sets a value that indicates to define foreign key field name of the grid datasource.
             * @remarks
             * It is optional. If the foreignKeyField name is not specified then it will take the field name from the "field" property.
             * We must specify the data source for column dataSource property
             * @name ejGrid#columns->foreignKeyField  	          
             * @default null
             * @type {string}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt;          
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   columns:[{field:"OrderID"},{field:"EmployeeID",foreignKeyField:"EmployeeID",foreignKeyValue:"FirstName",headerText:"FirstName",dataSource:window.employeeData },{field:"ShipCity"}]
             * });
             * &lt;/script&gt;
             */

            /**
             * Gets or sets a value that indicates to bind the field which is in foreign column datasource based on the foreignKeyField
             * @remarks
             * We must specify the data source for column dataSource property
             * @name ejGrid#columns->foreignKeyValue  	          
             * @default null
             * @type {string}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt;  
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   columns:[{field:"OrderID"},{field:"EmployeeID",foreignKeyField:"EmployeeID",foreignKeyValue:"FirstName",dataSource:window.employeeData,headerText:"FirstName"},{field:"ShipCity"}]
             * });
             * &lt;/script&gt; 
             */

            /**
             * Gets or sets a value that indicates to define constraints for saving data to the database.
             * @remarks
             * allowEditing or allowAdding must be set as true. It is must to add the validations script. They are jquery.validate.min.js and jquery.validate.unobtrusive.min.js
             * @name ejGrid#columns->validationRules 	          
             * @type {object}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt;          
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   editSettings: {allowEditing: true, allowAdding: true},
             *   columns:[{field:"OrderID", validationRules: { required: true, number: true }},{field:"CustomerID"},{field:"ShipCity"}] 
             * });
             * &lt;/script&gt; 
             */

            /**
             * Gets or sets a value that indicates the format for the text applied on the column
             * @name ejGrid#columns->format 	          
             * @default -
             * @type {string}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt;          
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   columns:[{field:"OrderID"},{field:"CustomerID"},{field:"Freight",format:"{0:C}"}]
             * });
             * &lt;/script&gt;  
             */

            /**
             * Gets or sets a value that indicates the attribute values to the td element of a particular column
             * @name ejGrid#columns->customAttributes 	          
             * @default -
             * @type {object}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt;          
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   columns:[{field:"OrderID"},{field:"CustomerID",customAttributes:{"style":"color:red"}},{field:"Freight"}]
             * });
             * &lt;/script&gt;  
             */

            /**
             * Gets or sets a value that indicates to add the template as a particular column data .
             * @remarks
             * If you want to use templateID for the column template, then columnTemplate must be set as true.
             * @name ejGrid#columns->templateID 	          
             * @default null
             * @type {string}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script id="columnTemplate" type="text/x-jsrender"&gt;
             * &lt;img src="styles/images/Employees/{{:EmployeeID}}.png" alt="{{:EmployeeID}}"/&gt;
             * &lt;/script&gt;
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *  dataSource:window.gridData,
             *  columns:[{headerText:"Employee",template:true,templateID:"#columnTemplate"},{field:"EmployeeID"}]
             * });
             * &lt;/script&gt;
             */

            /**
             * Gets or sets a value that indicates to render the grid content and header with an html elements
             * @remarks
             * It is optional if we need to disable the htmlencode behaviour for particular column then set this property as false
             * @name ejGrid#columns->disableHtmlEncode	          
             * @default false
             * @type {boolean}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *     dataSource:window.gridData,
             *     columns:[{field:"OrderID",headerText:"&lt;div&gtOrder ID&lt;/div&gt;",disableHtmlEncode:true}
             *   });
             * &lt;/script&gt;
            **/

            /**  
             * You can use this property to freeze selected columns in grid at the time of scrolling.
             * @remarks
             * We must enable allowScrolling property
             * @name ejGrid#columns->isFrozen            
             * @default false
             * @type {boolean}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({             
             *   dataSource:window.gridData,
             *   allowScrolling: true,               
             *   scrollSettings:{width:500,height:100 }
             *   columns:[{field:"OrderID",isFrozen:true},{field:"CustomerID"},{field:"ShipCity"}]
             * });
             * &lt;/script&gt; 
             **/

            /**
             * Gets or sets an object  that indicates to define a command column in the grid.
             * @remarks
             * isUnbound must be true while declaring commands button.
             * @name ejGrid#columns->commands 	          
             * @default []
             * @type {array}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *     dataSource:window.gridData,
             *     editSettings:{allowEditing:true,allowAdding:true,allowDeleting:true},
             *     columns:[
             *            { field: "OrderID", isPrimaryKey: true },  
             *            { field: "EmployeeID" },
             *            {
             *               headerText: "Manage Records",
             *               commands: [
             *                   { type: ej.Grid.UnboundType.Edit, buttonOptions: { text: "Edit" } },
             *                   { type: ej.Grid.UnboundType.Delete, buttonOptions: { text: "Delete" } },
             *                   { type: ej.Grid.UnboundType.Save, buttonOptions: { text: "Save" } },
             *                   { type: ej.Grid.UnboundType.Cancel, buttonOptions: { text: "Cancel" } }
             *                ],
             *               isUnbound: true,
             *               width: 130
             *            }
             *     ] 
             * });
             * &lt;/script&gt; 
             */

            /**
             * Gets or sets a value that indicates to add the command column button. See {@link unboundType}
             * @remarks
             * isUnbound must be true while declaring commands button.
             * @name ejGrid#columns->commands->type	          
             * @default -
             * @type {enum}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *     dataSource:window.gridData,
             *     editSettings:{allowEditing:true,allowAdding:true,allowDeleting:true},
             *     columns:[
             *            { field: "OrderID", isPrimaryKey: true },  
             *            { field: "EmployeeID" },
             *            {
             *               headerText: "Manage Records",
             *               commands: [
             *                   { type: ej.Grid.UnboundType.Edit, buttonOptions: { text: "Edit" } },
             *                   { type: ej.Grid.UnboundType.Delete, buttonOptions: { text: "Delete" } },
             *                   { type: ej.Grid.UnboundType.Save, buttonOptions: { text: "Save" } },
             *                   { type: ej.Grid.UnboundType.Cancel, buttonOptions: { text: "Cancel" } }
             *                ],
             *               isUnbound: true, width: 130
             *            }
             *     ] 
             * });
             * &lt;/script&gt; 
             */

            /**
             * Gets or sets an object that indicates to define all the button options which are available in ejButton.
             * @remarks
             * isUnBound must be true while declaring commands button.
             * @name ejGrid#columns->commands->buttonOptions
             * @default -
             * @type {object}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *     dataSource:window.gridData,
             *     editSettings:{allowEditing:true,allowAdding:true,allowDeleting:true},
             *     columns:[
             *            { field: "OrderID", isPrimaryKey: true },  
             *            { field: "EmployeeID" },
             *            {
             *               headerText: "Manage Records",
             *               commands: [
             *                   { type: ej.Grid.UnboundType.Edit, buttonOptions: { text: "Edit" } },
             *                   { type: ej.Grid.UnboundType.Delete, buttonOptions: { text: "Delete" } },
             *                   { type: ej.Grid.UnboundType.Save, buttonOptions: { text: "Save" } },
             *                   { type: ej.Grid.UnboundType.Cancel, buttonOptions: { text: "Cancel" } }
             *                ],
             *               isUnbound: true, width: 130
             *            }
             *     ] 
             * });
             * &lt;/script&gt; 
             */

            /**
             * Gets or sets a value that indicates to customize ejNumericTextbox of an editable column. See {@link editingType}
             * @name ejGrid#columns->editParams           
             * @default -
             * @type {object}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *     dataSource:window.gridData,
             *     editSettings:{allowEditing:true,allowAdding:true,allowDeleting:true},
             *     columns:[{ field: "OrderID"}, { field: "Freight", editType: ej.Grid.EditingType.Numeric, editParams: { decimalPlaces: 2 }}]
             *   });
             * &lt;/script&gt;  
             */

            /**
            * Gets or sets a value that indicates to specify the datatype of the specified columns.
            * @name ejGrid#columns->type 	          
            * @default -
            * @type {string}
            * @example
            * &lt;div id="Grid"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#Grid").ejGrid({
            *     dataSource:window.gridData,
            *     columns:[{ field: "OrderID"}, { field: "Verified",type: "boolean" }]
            *   });
            * &lt;/script&gt;  
            */

            columns: [],
			/**		
            * Query the dataSource from the table for Grid.
            * @name ejGrid#query
            * @default null
            * @type {object}
            * @example       
            * &lt;div id="Grid"&gt;&lt;/div&gt; <br> 
            * &lt;script type="text/javascript"&gt;
			* var queryOrder=ej.Query().select(["OrderID", "CustomerID"]); 
            * $("#Grid").ejGrid({
            *   dataSource: window.gridData,
            *   query: queryOrder
			* });  
            * &lt;/script&gt;
            */
            query: null,
            isEdit: false,
            /**		
            * Gets or sets a value that indicates whether the grid design has be to made responsive.
            * @name ejGrid#isResponsive
            * @default false
            * @type boolean
            * @example       
            * &lt;div id="Grid"&gt;&lt;/div&gt; <br> 
            * &lt;script type="text/javascript"&gt; 
            * $("#Grid").ejGrid({
            *   dataSource: window.gridData,
                isResponsive: true 
			* });  
            * &lt;/script&gt;
            */
            isResponsive: false,
             /**		
            * Gets or sets a value that indicates whether the grid rows has to be rendered as detail view in mobile mode
            * @name ejGrid#enableResponsiveRow
            * @default false
            * @type boolean
            * @example       
            * &lt;div id="Grid"&gt;&lt;/div&gt; <br> 
            * &lt;script type="text/javascript"&gt; 
            * $("#Grid").ejGrid({
            *   dataSource: window.gridData,
                isResponsive: true,
                enableResponsiveRow: true    
			* });  
            * &lt;/script&gt;
            */
            enableResponsiveRow: false,
        },
        dataTypes: {
            dataSource: "data",
            query:"data",
            columns: "array",
			childGrid: "parent",
            summaryRows: "array",
			stackedHeaderRows: "array",
            toolbarSettings: {
                toolbarItems: "array",
                customToolbarItems: "array"
            },
            contextMenuSettings: {
                contextMenuItems: "array",
                customContextMenuItems: "array"
            },
            selectionSettings: {
                selectionMode: "array"
            },
            sortSettings: {
                sortedColumns: "array"
            },
            filterSettings: {
                filteredColumns: "array",
                filterType: "enum",
                filterBarMode: "enum",
            },
            groupSettings: {
                groupedColumns: "array"
            },
            editSettings: {
                editMode: "enum",
                formPosition: "enum",
                rowPosition: "enum",
            }
        },

        _columns: function (index, property, value, old) {
            var $header = this.element.find(".e-gridheader");
            $header.find("div").first().empty().append(this._renderGridHeader().find("table"));
            this._headerCellgDragDrop();
            this.refreshContent(true);
            this._trigger("refresh");
        },
        _summaryRows: function (index, property, value, old) {
            if (property == "showTotalSummary" || property == "showCaptionSummary"){
                var indx = index.summaryRows;
                var val = value.toLowerCase() == "true" || value.toLowerCase() == "false" ? ej.parseJSON(value) : false;
                this.option("summaryRows")[indx][property] = val;                  
            }         
            this.element.find(".e-gridfooter").remove();
            this._renderGridFooter().insertAfter(this.getContent());                 
            if (property == "showCaptionSummary" || property == "title") {                
                this._isCaptionSummary = this.option("summaryRows")[indx]["showCaptionSummary"];
                this.model.showSummary = this._isCaptionSummary;
                if(this.model.groupSettings.groupedColumns.length != 0)
                    this._refreshCaptionSummary(); 
            }                                                      
        },
        _summaryRows_summaryColumns: function (index, property, value, old) {            
            if (property == "displayColumn" || property == "dataMember") {                
                if(ej.isNullOrUndefined(this.getColumnByField(value)))
                    return;
            }            
            this._createSummaryRows(this.getFooterTable());
            if(this.element.find(".e-groupcaptionsummary").length != 0)
                this._refreshCaptionSummary();  
        },
        _stackedHeaderRows_stackedHeaderColumns:function(index, property, value, old){
           this._refreshStackedHeader();
        },
        _sortSettings_sortedColumns: function (index, property, value, old) {
            var colName, direction;            
            var sortObj = this.model.sortSettings.sortedColumns[index["sortSettings.sortedColumns"]];
            if (property == "field") {               
                colName = this.getColumnByField(value) != null ? value : null;                
                direction =  (sortObj.direction == "ascending" || sortObj.direction == "descending") ? sortObj.direction : null;
            }
            else if (property == "direction") {               
                colName = this.getColumnByField(sortObj.field) != null ? sortObj.field : null;    
                direction =  (value == "ascending" || value == "descending") ? value : null;   
            }
            if(colName != null && direction != null)
                this.sortColumn(colName, direction);              
        },
        _filterSettings_filteredColumns: function (index, property, value, old) {
            var field, operator, matchcase, predicate, filtervalue;           
            var filterObj = this.model.filterSettings.filteredColumns[index["filterSettings.filteredColumns"]];
            switch (property) {
                case "field":
                    field = this.getColumnByField(value) != null ? value : null; 
                    operator = this._map(ej.FilterOperators, filterObj.operator);
                    filtervalue = filterObj.value;
                    predicate = (filterObj.predicate == "and" || filterObj.predicate == "or") ? filterObj.predicate : null;
                    matchcase = filterObj.matchcase;
                    break;
                case "matchcase":
                    field = this.getColumnByField(filterObj.field) != null ? filterObj.field : null; 
                    operator = this._map(ej.FilterOperators, filterObj.operator);
                    filtervalue = filterObj.value;
                    predicate = (filterObj.predicate == "and" || filterObj.predicate == "or") ? filterObj.predicate : null;
                    matchcase = value.toLowerCase() == "true" || value.toLowerCase() == "false" ? ej.parseJSON(value) : false;
                    break;
                case "operator":
                    field = this.getColumnByField(filterObj.field) != null ? filterObj.field : null; 
                    operator = this._map(ej.FilterOperators, value);
                    filtervalue = filterObj.value;
                    predicate = (filterObj.predicate == "and" || filterObj.predicate == "or") ? filterObj.predicate : null;
                    matchcase = filterObj.matchcase;
                    break;
                case "predicate":
                    field = this.getColumnByField(filterObj.field) != null ? filterObj.field : null; 
                    operator = this._map(ej.FilterOperators, filterObj.operator);
                    filtervalue = filterObj.value;
                    predicate = (value == "and" || value == "or") ? value : null;
                    matchcase = filterObj.matchcase;
                    break;
                case "value":
                    field = this.getColumnByField(filterObj.field) != null ? filterObj.field : null; 
                    operator = this._map(ej.FilterOperators, filterObj.operator);
                    filtervalue = value;
                    predicate = (filterObj.predicate == "and" || filterObj.predicate == "or") ? filterObj.predicate : null;
                    matchcase = filterObj.matchcase;
                    break;
            }
            if(field != null && operator != null && filtervalue != null && predicate != null && matchcase != null)
                this.filterColumn(field, operator, filtervalue, predicate, matchcase);
        },
        _map: function (object, value){
            var data = $.map(object, function (obj) {              
                if(obj === value)
                  return obj; 
            });
            return data.length != 0 ? data[0] : null;
        },
		_refreshCaptionSummary: function(){
            var temp = document.createElement('div');                
            temp.innerHTML = ['<table>', $.render[this._id + "_GroupingTemplate"](this.model.currentViewData, { groupedColumns: this.model.groupSettings.groupedColumns }), '</table>'].join("");
            this.getContentTable().get(0).replaceChild(temp.firstChild.firstChild, this.getContentTable().get(0).lastChild);
            this.refreshContent();
        },
        /**
         * Get the content table element of grid
         * @return gridContentTable
         * @example 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // Gets content table of grid control
         * gridObj.getContentTable();
         * &lt;/script&gt;
         * @example 
         * &lt;script&gt;
         * // Gets content table of grid control
         * $("#Grid").ejGrid("getContentTable");        
         * &lt;/script&gt;
         */
        getContentTable: function () {
            return this._gridContentTable;
        },

        setGridContentTable: function (value) {
            this._gridContentTable = value;
        },
        /**
		 * Get the content div element of grid.
		 * @return gridContent
		 * @example 
		 * &lt;script&gt;
		 * // Create grid object.
		 * var gridObj = $("#Grid").data("ejGrid");
         * // Gets content of grid control
		 * gridObj.getContent(); 
		 * &lt;/script&gt;
		 * @example 
		 * &lt;script&gt;
		 * // Gets content of grid control
		 * $("#Grid").ejGrid("getContent");        
		 * &lt;/script&gt;
         */
        getContent: function () {
            return this._gridContent;
        },

        setGridContent: function (value) {
            this._gridContent = value;
        },
        /**
          * Get the header content div element of grid..
          * @return gridHeaderContent
          * @example 
          * &lt;script&gt;
          * // Create grid object.
          * var gridObj = $("#Grid").data("ejGrid");
          * // Gets grid header content of grid control
          * gridObj.getHeaderContent(); 
          * &lt;/script&gt;
          * @example 
          * &lt;script&gt;
          * // Gets grid header content of grid control
          * $("#Grid").ejGrid("getHeaderContent");        
          * &lt;/script&gt;
          */
        getHeaderContent: function () {
            return this._gridHeaderContent;
        },

        setGridHeaderContent: function (value) {
            this._gridHeaderContent = value;
        },
        /**
		 * Get the header table element of grid
		 * @return gridHeaderTable
		 * @example 
		 * &lt;script&gt;
		 * // Create grid object.
		 * var gridObj = $("#Grid").data("ejGrid");
		 * gridObj.getHeaderTable(); 
         * // Gets header table of grid control
		 * &lt;/script&gt;
		 * @example 
		 * &lt;script&gt;
		 * // Gets header table of grid control
		 * $("#Grid").ejGrid("getHeaderTable");        
		 * &lt;/script&gt;
         */
        getHeaderTable: function () {
            return this._gridHeaderTable;
        },

        setGridHeaderTable: function (value) {
            this._gridHeaderTable = value;
        },
        /**
         * Get the rows(tr element)of grid  which is displayed in the current page.
         * @return gridRows
         * @example 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // Gets grid rows of grid control
         * gridObj.getRows(); 
         * &lt;/script&gt;
         * @example 
         * &lt;script&gt;
         * // Gets grid rows of grid control
         * $("#Grid").ejGrid("getRows");        
         * &lt;/script&gt;
         */
        getRows: function () {
            return this._gridRows;
        },
        /**
        * Get the records filtered or searched in Grid
        * @return filteredRecords
        * @example 
        * &lt;script&gt;
        * // Create grid object.
        * var gridObj = $("#Grid").data("ejGrid");
        * // Gets the filtered or searched records in Grid
        * gridObj.getFilteredRecords();  
        * &lt;/script&gt;
        * @example 
        * &lt;script&gt;
        * // Gets the filtered or searched records in Grid
        * $("#Grid").ejGrid("getFilteredRecords");   
        * &lt;/script&gt;
        */
        getFilteredRecords: function () {
            return this._filteredRecords;
        },
        /**
		 * Get the rows(tr element) from the given from and to row index in grid
		 * @return gridRows
		 * @param {number} from Pass the from index from which the rows to be returned
		 * @param {number} to Pass the to index to which the rows to be returned
		 * @example 
		 * &lt;script&gt;
		 * // Create grid object.
		 * var gridObj = $("#Grid").data("ejGrid");
         * // Gets the rows from the specified row index 
		 * gridObj.getRowByIndex(3, 6);  
		 * &lt;/script&gt;
		 * @example 
		 * &lt;script&gt;
		 * // Gets the rows from the specified row index
		 * $("#Grid").ejGrid("getRowByIndex", 3, 6);   
		 * &lt;/script&gt;
         */
        getRowByIndex: function (from, to) {
            try {
                var gridRows = this.getRows(), $gridRows = $(gridRows), $row = $();
                if (ej.isNullOrUndefined(to)) {
                    if (this.model.scrollSettings.frozenColumns > 0) {
                        $row.push(gridRows[0][from]);
                        $row.push(gridRows[1][from]);
                        return $row;
                    }
                    return $(gridRows[from]);
                } else {
                    if (this.model.scrollSettings.frozenColumns > 0) {
                        $row.push($gridRows.eq(0).slice(from, to));
                        $row.push($gridRows.eq(0).slice(from, to));
                        return $row;
                    }
                    return $($gridRows.slice(from, to));
                }
            } catch (e) {
                return $();
            }
        },
        /**
         * Get the column index of the given field in grid.
         * @return Column Index
         * @param {string} fieldName Pass the field name of the column to get the corresponding column index
         * @example 
         * &lt;div id="Grid"&gt;&lt;/div&gt; 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // Gets the column index based on the given field name
         * gridObj.getColumnIndexByField("OrderID"); 
         * &lt;/script&gt;
         * @example 
         * &lt;div id="Grid"&gt;&lt;/div&gt; 
         * &lt;script&gt;
         * // Gets the column index based on the given field name
         * $("#Grid").ejGrid("getColumnIndexByField", "OrderID");        
         * &lt;/script&gt;
         */
        getColumnIndexByField: function (field) {
            for (var column = 0; column < this.model.columns.length; column++) {
                if (this.model.columns[column]["field"] == field)
                    break;
            }
            return column;
        },
        /**
		 * Get the row index based on the given tr element in grid.
		 * @return row index
		 * @param {object} $tr Pass the tr element in grid content to get its row index
		 * @example 
		 * &lt;script&gt;
		 * // Create grid object.
		 * var gridObj = $("#Grid").data("ejGrid");
         * // Gets the row index based on the given row
		 * gridObj.getIndexByRow($(".gridcontent tr").first()); 
		 * &lt;/script&gt;
		 * @example 
		 * &lt;script&gt;
		 * // Gets the row index based on the given row
		 * $("#Grid").ejGrid("getIndexByRow", $(".gridcontent tr").first());        
		 * &lt;/script&gt;
         */
        getIndexByRow: function ($tr) {
            var gridRows = this.getRows(), $gridRows = $(gridRows), rowIndex;
            if (this.model.scrollSettings.frozenColumns > 0) {
                rowIndex = $(gridRows[0]).index($tr);
                if (rowIndex == -1)
                    rowIndex = $(gridRows[1]).index($tr);
                return rowIndex;
            } else
                return $gridRows.index($tr);
        },
        /**
         * Get the names of primary key columns  in Grid
         * @return primary key fields
         * @example 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // Gets the names of primary key columns
         * gridObj.getPrimaryKeyFieldNames(); 
         * &lt;/script&gt;
         * @example 
         * &lt;script&gt;
         * // Gets the names of primary key columns
         * $("#Grid").ejGrid("getPrimaryKeyFieldNames");        
         * &lt;/script&gt;
         */
        getPrimaryKeyFieldNames: function () {
            if (this._primaryKeys.length != 0)
                return this._primaryKeys;
            for (var key = 0, col = this.model.columns, cLen = col.length; key < cLen; key++) {
                if (col[key]["isPrimaryKey"])
                    this._primaryKeys.push(col[key]["field"]);
            }
            return this._primaryKeys;
        },
        /**
         * Get the names of all the visible column collections in grid
         * @return visibleColumns
         * @example 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // Gets the names of all the visible column collections
         * gridObj.getVisibleColumnNames(); 
         * &lt;/script&gt;
         * @example 
         * &lt;script&gt;
         * // Gets the names of all the visible column collections
         * $("#Grid").ejGrid("getVisibleColumnNames");        
         * &lt;/script&gt;
         */
        getVisibleColumnNames: function (headerText) {
            return this._visibleColumns;
        },
        /**
        * Get the names of all the hidden column collections in grid.
        * @return hiddenColumns
        * @example 
        * &lt;script&gt;
        * // Create grid object.
        * var gridObj = $("#Grid").data("ejGrid");
        * // Gets names of all the hidden column collections
        * gridObj.getHiddenColumnNames(); 
        * &lt;/script&gt;
        * @example 
        * &lt;script&gt;
        * // Gets names of all the hidden column collections
        * $("#Grid").ejGrid("getHiddenColumnNames");        
        * &lt;/script&gt;
        */
        getHiddenColumnNames: function (headerText) {
            return this._hiddenColumns;
        },
        /**
         * Get the column details based on the given field in grid
         * @return Column Object
         * @param {string} fieldName Pass the field name of the column to get the corresponding column object
         * @example 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // Gets the column details based on the given field name
         * gridObj.getColumnByField("OrderID");
         * &lt;/script&gt;
         * @example 
         * &lt;script&gt;
         * // Gets the column details based on the given field name
         * $("#Grid").ejGrid("getColumnByField", "OrderID");        
         * &lt;/script&gt;
         */
        getColumnByField: function (field) {
            for (var column = 0; column < this.model.columns.length; column++) {
                if (this.model.columns[column]["field"] == field)
                    break;
            }
            return column == this.model.columns.length ? null : this.model.columns[column];
        },
        getsortColumnByField: function (field) {
            for (var column = 0; column < this.model.sortSettings.sortedColumns.length; column++) {
                if (this.model.sortSettings.sortedColumns[column]["field"] == field)
                    break;
            }
            return column == this.model.sortSettings.sortedColumns.length ? null : this.model.sortSettings.sortedColumns[column];
        },
        /**
         * Get the column details based on the given header text in grid.
         * @return Column Object
         * @param {string} headerText Pass the header text of the column to get the corresponding column object
         * @example 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // Gets the column details based on the given headerText
         * gridObj.getColumnByHeaderText("Order ID"); 
         * &lt;/script&gt;
         * @example 
         * &lt;script&gt;
         * // Gets the column details based on the given headerText
         * $("#Grid").ejGrid("getColumnByHeaderText", "Order ID");        
         * &lt;/script&gt;
         */
        getColumnByHeaderText: function (headerText) {
            for (var column = 0; column < this.model.columns.length; column++) {
                if (this.model.columns[column]["headerText"] == headerText)
                    break;
            }
            return column == this.model.columns.length ? null : this.model.columns[column];
        },
        /**
         * Get the current page data source of grid..
         * @return currentJsonData
         * @example 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // Gets current view data of grid control
         * gridObj.getCurrentViewData(); 
         * &lt;/script&gt;
         * @example 
         * &lt;script&gt;
         * // Gets current view data of grid control
         * $("#Grid").ejGrid("getCurrentViewData");        
         * &lt;/script&gt;
         */
        getCurrentViewData: function () {
            return this._currentJsonData;
        },
        /**
		 * Get the list of field names from column collection in grid.
		 * @return columnFieldNames
		 * @example 
		 * &lt;script&gt;
		 * // Create grid object.
		 * var gridObj = $("#Grid").data("ejGrid");
         * // Gets the column field names based on the given index
		 * gridObj.getColumnFieldNames(); 
		 * &lt;/script&gt;
		 * @example 
		 * &lt;script&gt;
		 * // Gets the column field names based on the given index
		 * $("#Grid").ejGrid("getColumnFieldNames");        
		 * &lt;/script&gt;
         */
        getColumnFieldNames: function () {
            var columnNames = [];
            for (var column = 0; column < this.model.columns.length; column++) {
                if (this.model.columns[column]["field"])
                    columnNames.push(this.model.columns[column]["field"]);
            }
            return columnNames;
        },
        /**
         * Get the browser details
         * @return browserDetails
         * @example 
         * &lt;div id="Grid"&gt;&lt;/div&gt; 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // Gets the browser details of the application being run
         * gridObj.getBrowserDetails(); 
         * &lt;/script&gt;
         * @example 
         * &lt;div id="Grid"&gt;&lt;/div&gt; 
         * &lt;script&gt;
         * // Gets the browser details of the application being run
         * $("#Grid").ejGrid("getBrowserDetails");        
         * &lt;/script&gt;
         */
        getBrowserDetails: function () {
            var b = navigator.userAgent.match(/(firefox|chrome|opera|msie|safari)\s?\/?(\d+(.\d+)*)/i);
            if (!!navigator.userAgent.match(/Trident\/7\./))
                return { browser: "msie", version: $.uaMatch(navigator.userAgent).version };
            return { browser: b[1].toLowerCase(), version: b[2] };
        },
        _initPrivateProperties: function () {
            this._click = 0;
            this._gridHeaderTable = null;
            this._gridWidth = this.element.width();
            this._id = this.element.attr("id");
            this._gridRows = null;
            this._gridContentTable = null;
            this._gridContent = null;
            this._gridSort = null;
            this._gridHeaderContent = null;
            this._gridFooterContent = null;
            this._gridFooterTable = null;
            this._gridRecordsCount = this._dataSource() !== null ? (this.model.pageSettings.totalRecordsCount == null ? this._dataSource().length : this.model.pageSettings.totalRecordsCount) : 0;
            this._links = null;
            this._gridPager = null;
            this._cSortedColumn = null;
            this._cSortedDirection = null;
            this._$curSElementTarget = null;
            this._gridFilterBar = null;
            this._$curFieldName = null;
            this._$prevFieldName = null;
            this._mediaStatus = false;
            this._$fDlgIsOpen = false;
            this._$colType = null;
            this._$colFormat = null;
            this._$prevColType = null;
            this._$prevSElementTarget = null;
            this._currentFilterColumn = null;
            this._filteredRecordsCount = null;
            this._filteredRecords = [];
            this.filterColumnCollection = [];
            this._previousFilterCount = null;
            this._excelFilter = null;
            this._isExcelFilter = this.model.filterSettings.filterType == "excel";
            this._primaryKeys = [];
            this._primaryKeyValues = [];
            this._modifiedRecords = [];
            this._addedRecords = [];
            this._tdsOffsetWidth = [];
            this._deletedRecords = [];
            this._disabledToolItems = $();
            this._validationRules = {};
            this._groupedColumns = [];
            this._scolumns = [];
            this._currentJsonData = [];
            this._groupingColumnIndex = 0;
            this._dataManager = this._dataSource() instanceof ej.DataManager ? this._dataSource() : this._dataSource() != null ? ej.DataManager(this._dataSource()) : null;
            if (this._dataManager != null && this.model.allowScrolling && this.model.scrollSettings.allowVirtualScrolling && this.model.pageSettings.totalRecordsCount != null && this._dataManager.dataSource.json != null)
                this._dataManager.dataSource.json.splice(this.model.pageSettings.totalRecordsCount);
            this._isRemoteSaveAdaptor = (this._dataSource() instanceof ej.DataManager && this._dataSource().adaptor instanceof ej.remoteSaveAdaptor);
            this._disabledSortableColumns = [];
            this._disabledGroupableColumns = [];
            this._disabledFilterableColumns = [];
            this._hiddenColumns = [];
            this._visibleColumns = [];
            this._sortedColumns = [];
            this.multiSortRequest = false;
            this.multiSelectCtrlRequest = false;
            this._multiSelectShiftRequest = false;
            this._enableSelectMultiTouch = false;
            this._enableSortMultiTouch = false;
            this._templateRefresh = false;
            this._initialRender = false;
            this._fieldColumnNames = {};
            this._headerColumnNames = {};
            this.selectedRowsIndexes = [];
            this._isReorder = false;
            this._searchString = "";
            this._searchCount = null;
            this._columnsWidthCollection = [];
            this._Indicator = null;
            this._resizer = null;
            this._bulkEditCellDetails = {
                cellValue: null,
                rowIndex: -1,
                columnIndex: -1,
                fieldName: null,
                _data: null,
                cellEditType: "",
                cancelSave: false,
                defaultData: null,
                insertedTrCollection: [],
                rowData: null
            };
            this.batchChanges = {
                added: [],
                deleted: [],
                changed: []
            };
            this._bulkEditTemplate = $();
            this._confirmDialog = null;
            this._confirmedValue = false;
            this._lastRow = false;
            this._isVirtualRecordsLoaded = false;
            this._scrollValue = 0;
            this._currentTopFrozenRow = this.model.scrollSettings.frozenRows;
            this._rowHeightCollection = [];
            this._scrollObject = null;
            this._customPop = null;
            this.selectedRowCellIndexes = [];
            this._rowIndexesColl = [];
            this.selectedColumnIndexes = [];
            this.commonQuery = $.extend(true, {}, this.model.query);
            if (ej.gridFeatures.group) {
                this._rowCol = this._captionSummary();
                this._isCaptionSummary = (this._rowCol != null && this._rowCol.length) > 0 ? true : false;
            }
            this.phoneMode = this.model.isResponsive && document.documentElement.clientWidth < 360 ? true : false;
            if (this.model.selectionSettings.selectionMode.length > 0)
                this._initSelection();
            this._mediaQuery = false;
            this._columnChooserList = null;
            this._$headerCols = null;
            this._$contentCols = null;
            this._detailsOuterWidth = null;
        },
        _init: function () {
            this._trigger("load");
            if (ej.isNullOrUndefined(this.model.query) || !(this.model.query instanceof ej.Query))
                this.model.query = ej.Query();
            if (ej.gridFeatures.common)
                this._initScrolling();
            this._initPrivateProperties();
            if (this.model.enableResponsiveRow)
                this.element.addClass("e-responsive");
            if (ej.gridFeatures.edit) {
                if (this.model.editSettings.allowEditing || this.model.editSettings.allowAdding)
                    this._processEditing();
            }
            this._checkDataBinding();
        },
        _initColumns: function (object) {
            while (object.items != undefined)
                object = object.items[0];
            if (this.model.columns.length == 0 && object) {
                for (var field in object) {
                    if (object.hasOwnProperty(field) && (typeof (object[field]) != "object" || object[field] instanceof Date)) {
                        var value = object[field];
                        this.model.columns.push({
                            field: field,
                            type: value != null ? (value.getDay ? (value.getHours() > 0 || value.getMinutes() > 0 || value.getSeconds() > 0 || value.getMilliseconds() > 0 ? "datetime" : "date") : typeof (value)) : null
                        });
                    }
                }
                this.model.columns.length && this._renderAfterColumnInitialize();
            } else {
                for (var index = 0; index < this.model.columns.length; index++) {
                    if (ej.isNullOrUndefined(this.model.columns[index].type)) {
                        var $field;
                        if (this.model.columns[index].dataSource && this.model.columns[index].foreignKeyValue)
                            $field = this.model.columns[index].dataSource[0][this.model.columns[index].foreignKeyValue];
                        else
                            $field = !ej.isNullOrUndefined(this.model.columns[index].field) ? ej.getObject(this.model.columns[index].field, object) : null;
                        this.model.columns[index].type = $field != null ? ($field.getDay ? ($field.getHours() > 0 || $field.getMinutes() > 0 || $field.getSeconds() > 0 || $field.getMilliseconds() > 0 ? "datetime" : "date") : typeof ($field)) : null;
                    }
                    else if (this.model.columns[index]["type"] == "date" && this.model.columns[index].format == undefined)
                        if (ej.isNullOrUndefined(Globalize))
                            $.extend(this.model.columns[index], { format: "{0:" + Globalize.culture().calendars.standard.patterns.d + "}" });
                        else
                            $.extend(this.model.columns[index], { format: "{0:M/d/yyyy}" });
                    else if (this.model.columns[index]["type"] == "datetime" && this.model.columns[index].format == undefined)
                        if (ej.isNullOrUndefined(Globalize))
                            $.extend(this.model.columns[index], { format: "{0:" + Globalize.culture().calendars.standard.patterns.d + " " + Globalize.culture().calendars.standard.patterns.t + "}" });
                        else
                            $.extend(this.model.columns[index], { format: "{0:M/d/yyyy h:mm tt}" });
                }
            }
        },
		_initSelection: function(){	
            var mode = this.model.selectionSettings.selectionMode;
            for (i = 0; i < mode.length; i++) {			
                this["_allow" + mode[i] + "Selection"] = true;
            }
		},
        _checkDataBinding: function () {
            if (this.model.enablePersistence)
                this.model.query = new ej.Query();
            this._initialRenderings();
            this._initialRender = true;
            this.model.enableRTL && this.element.addClass("e-rtl");
            if (this.model.allowFiltering && (this.model.filterSettings.filterType == "menu" || this.model.filterSettings.filterType == "excel")) {
                               this._isExcelFilter && this._renderExcelFilter();
                                this._renderFilterDialogs();
                            }
            if (this.model.cssClass != null)
                this.element.addClass(this.model.cssClass);
            if (this.model.showColumnChooser)
                this._renderColumnChooser();
            if (this.model.allowGrouping)
                this.element.append(this._renderGroupDropArea());
            if (this.model.toolbarSettings.showToolbar)
                this.element.append(this._renderToolBar());
            var columns = this.model.columns;
            if (columns && columns.length) {
                var expands = [];
                if (typeof columns[0] === "string")
                    for (var i = 0; i < columns.length; i++)
                        columns[i] = { field: columns[i] };
                for (var i = 0; i < columns.length; i++) {
                    if (!columns[i].field || columns[i].field.indexOf('.') === -1) continue;
                    this._getExpands(columns[i].field, expands);
                }
                this.model.query.expand(expands);
                this._renderAfterColumnInitialize();
            }
            if (this.model.allowPaging)
                this.element.append(this._renderGridPager());
			if (this.model.contextMenuSettings.enableContextMenu)
                 this.element.append(this._renderContext());
            if ($.isFunction($.fn.ejWaitingPopup)) {
                this.element.ejWaitingPopup({ showOnInit: false });
                $("#" + this._id + "_WaitingPopup").addClass("e-gridwaitingpopup");
            }
            if (this._dataSource() instanceof ej.DataManager) {
                this.element.ejWaitingPopup("show");
                if (this._dataSource().ready != undefined) {
                    var proxy = this;
                    this._dataSource().ready.done(function (args) {
                        proxy._initDataSource();
                        proxy.model.dataSource = ej.DataManager(args.result);
                    });
                } else {
                    this.element.ejWaitingPopup("show");
                    this._initDataSource();
                }
            } else {
                this._ensureDataSource();
                this._trigger("actionBegin");
                this._initGridRender();
            }
        },
		 _renderColumnChooser: function () {
            var $columnButton = ej.buildTag("button .e-ccButton", 'Columns', { 'float': 'right' }).attr("type", "button");
            this.element.prepend($columnButton);
            $columnButton.ejButton({
                prefixIcon: "e-down-arrow",
                imagePosition:"imageright",
				contentType:"textandimage",
				type: 'button',
				click: $.proxy(this._ccClickHandler, this),
                width:90
            });
			var buttHeight=$columnButton.outerHeight();
			$columnButton.css('margin-top',0-(buttHeight));
            var $mainDiv = ej.buildTag("div");
            var $outerDiv = ej.buildTag("div .e-grid e-columnChooser",'',{},{id:this._id+"ccDiv"});
            var $searchBox = ej.buildTag("div.e-searchbox e-fields").append(ej.buildTag("input#" + this._id + "_SearchBox.e-ejinputtext e-filtertext", {}, {}, { "type": "text" }))
            var $sapnDiv = ej.buildTag('span .e-searchfind e-icon')
            $searchBox.append($sapnDiv);
            var $listOuterDiv=ej.buildTag('div','', {'height':'228px'},{id:this._id+"liScrollerDiv"})            
            this._renderColumnChooserData(false);
            $listOuterDiv.append(this._columnChooserList);          
            $outerDiv.append($searchBox);
            $outerDiv.append($listOuterDiv);
           
            var $splitterDiv = ej.buildTag('div .e-columnChooserSplitter', '', {'border-bottom':'0px' });
            $outerDiv.append($splitterDiv);
            $buttonDiv = ej.buildTag('div', '', { 'float': 'right', 'margin-top': '6px','margin-right':'-13px' });
            var $addButton = ej.buildTag("button", 'Done');
            var $cancelButton = ej.buildTag("button", 'Cancel', { 'margin-right': '20px','margin-left':'6px' });
            $buttonDiv.append($addButton);
            $buttonDiv.append($cancelButton);
            $outerDiv.append($buttonDiv);
            $addButton.ejButton({
                click: $.proxy(this._addButtonCC, this),
                showRoundedCorner:true,
                width:66
            });
            $cancelButton.ejButton({
                click: $.proxy(this._cancelButtonHandler, this),
                showRoundedCorner:true,
                width:66
            });
              $outerDiv.insertBefore(this.element)
              $outerDiv.ejDialog({ width: 'auto', beforeClose: $.proxy(this._columnChooserBeforeClose, this), showOnInit: false, allowKeyboardNavigation: false, enableResize: false, "enableRTL": this.model.enableRTL, "cssClass": this.model.cssClass, showHeader: false, width: 260 });
              if (ej.browserInfo().name == "msie" && ej.browserInfo().version < 10) {
                  var searchBox = $(".e-columnChooser").find("input#" + this._id + "_SearchBox")[0];
                  this._ieClearRemover(searchBox);
              }
        },
        _renderColumnChooserData: function (refresh) {
            var $listBox = ej.buildTag("div", '', { 'margin-left': '0px', 'width': '250px' });
            for (var index = 0; index < this.model.columns.length; index++) {
                var column = this.model.columns[index];
                var $innerDiv = ej.buildTag('div', '', {}, { 'class': 'e-columnChooserListDiv' });
                var styleAttr = {}
                var colValue = ej.isNullOrUndefined(column.headerText) ? column.field : column.headerText;
                var $input = ej.buildTag('input', '', styleAttr, { 'id': column.field.replace(".","_"), 'value': colValue, 'type': 'checkbox' });
                var label = ej.buildTag('label', colValue, { 'font-size': '13px' }, { 'for': column.field });
                $innerDiv.append($input);
                $innerDiv.append(label);
                $listBox.append($innerDiv);
                $input.ejCheckBox({
                    checked: !ej.isNullOrUndefined(column.visible) ? column.visible : true
                });
            }
            if (!refresh)
                this._columnChooserList = $listBox;
            else {
                this._columnChooserList.empty().append($listBox.children());
                $("#" + this._id + "liScrollerDiv").is(":visible") && $("#" + this._id + "liScrollerDiv").ejScroller('refresh');
            }
        },
		 _columnChooserBeforeClose: function () {
		     $(".e-columnChoosertail").remove();
		     $(".e-columnChoosertailAlt").remove();
		     for (index = 0; index < this.model.columns.length; index++) {
		         var chkState = !ej.isNullOrUndefined(this.model.columns[index].visible) ? this.model.columns[index].visible : true
		         var chkBox = $("#" + this.model.columns[index].field).ejCheckBox('model.checked', chkState);
		     }
			  $("#" + this._id + "_SearchBox").val('');
			 var args={};
			 args.target={};args.target.value='';
			 this._columnChooserSearch(args);
		 },
		 _columnChooserSearch: function (e) {
            if (e.type == 'click') {
                e.target.value = '';
                $("#"+this._id+"_SearchBox").val('');
            }
            var val = e.target.value;
			var span=$("#"+this._id+"_SearchBox").next('span')
            if (val != '') {
                span.removeClass("e-searchfind");
                span.addClass("e-cancel");
            }
            else {
                span.removeClass("e-cancel");
                span.addClass("e-searchfind");
            }
            $(".e-cancel").bind('click', $.proxy(this._columnChooserSearch, this));
            var currentCheckedItemsData = this.model.columns;
            var columnCollection = [];
            if (val != '') 
                currentCheckedItemsData = ej.DataManager(this.model.columns).executeLocal(ej.Query().where("headerText", ej.FilterOperators.startsWith, val,true));
            currentCheckedItemsData.forEach(function (obj) {
                columnCollection.push(obj.field);
            });
            if (!ej.isNullOrUndefined($("#nomatches")[0]))
                $("#nomatches").remove();
            var div = $("#"+this._id+"ccDiv").find("#"+this._id+"liScrollerDiv")

            for (var index = 0; index < this.model.columns.length; index++) {
                var column = this.model.columns[index];
                if (columnCollection.indexOf(column.field) == -1)
                    $("#ej" + column.field).parent('div').css('display', 'none');
                else
                    $("#ej" + column.field).parent('div').css('display', 'block');

            }

            if (columnCollection.length == 0) {
                var $labeldiv = ej.buildTag('div#nomatches', '');
                var $label = ej.buildTag('span', 'No Matches Found');
                $labeldiv.append($label);
                $(div).append($labeldiv);
            }
            $("#"+this._id+"liScrollerDiv").ejScroller('refresh')
        },
		_addButtonCC: function () {
            this._visibleColumns = [];
            this._hiddenColumns = [];
            for (index = 0; index < this.model.columns.length; index++) {
                var chkBox = $("#" + this.model.columns[index].field.replace(".", "_")).data("ejCheckBox");
                var column = this.getColumnByHeaderText(chkBox.model.value);
                if (chkBox.model.checked)
                    this._visibleColumns.push(column.headerText);
                else
                    this._hiddenColumns.push(column.headerText);
            }
            this.showColumns(this._visibleColumns);
            this.hideColumns(this._hiddenColumns);
            $("#"+this._id+"ccDiv").ejDialog('close');
            $(".e-columnChoosertail").remove();
        },
		_cancelButtonHandler: function () {
		    $("#" + this._id + "ccDiv").ejDialog('close');
		    $(".e-columnChoosertailAlt").remove();
            $(".e-columnChoosertail").remove();
		},
		_ccClickHandler: function (e) {
		    var dlgWidth = 230, xPos;
		    xPos = $(".e-ccButton").offset().left + $(".e-ccButton").width();
		    var dialogObj = $("#" + this._id + "ccDiv").data('ejDialog')
		    if (dialogObj && dialogObj.isOpened()) {
		        dialogObj.close();
		        $(".e-columnChoosertail").remove();
		        $(".e-columnChoosertailAlt").remove();
		    }
		    else {
		        $("#" + this._id + "ccDiv").ejDialog({ width: '230px', height: '309px', position: { X: xPos - dlgWidth, Y: $(".e-ccButton").offset().top + 35 } })
                   .ejDialog("open");
		        var maxZindex = parseInt($("#" + this._id + "ccDiv_wrapper").css('z-index'));
		        var $tailDiv = ej.buildTag("div.e-columnChoosertail", '', { 'display': 'block', 'position': 'absolute', 'left': xPos - 29, 'top': $(".e-ccButton").offset().top + 15 });
		        var $tailDiv2 = ej.buildTag("div.e-columnChoosertailAlt", '', { 'display': 'block', 'z-index': maxZindex + 2, 'position': 'absolute', 'left': xPos - 29, 'top': $(".e-ccButton").offset().top + 16 });
		        $tailDiv.insertBefore($("#" + this._id + "ccDiv_wrapper"));
		        $tailDiv2.insertBefore($("#" + this._id + "ccDiv_wrapper"));
		    }
		    $("#" + this._id + "liScrollerDiv").ejScroller({ height: '228', width: '230', buttonSize: 0 })
		    $("#" + this._id + "liScrollerDiv").ejScroller('refresh');
		    $(".e-ejinputtext").bind('keyup', $.proxy(this._columnChooserSearch, this))
		},
        _initDataSource: function () {
            this._ensureDataSource();
            this._trigger("actionBegin");
            var queryPromise = this._dataSource().executeQuery(this.model.query);
            if (this._dataManager.dataSource.table != null)
                this._dataManager.dataSource.table.css("display", "none");
            queryPromise.done(ej.proxy(function (e) {
                this.element.ejWaitingPopup("hide");
                this.model.currentViewData = e.result;
                if (this.model.pageSettings.totalRecordsCount != null && this.model.filterSettings.filteredColumns.length == 0)
                    this._gridRecordsCount = this.model.pageSettings.totalRecordsCount;
                else if (e.count == 0 && e.result.length)
                    this._gridRecordsCount = e.result.length;
                else
                    this._gridRecordsCount = e.count;
                if (this.getPager() != null)
                    this.model.pageSettings.totalRecordsCount = this._gridRecordsCount;
                this._initGridRender();
            }, this));
            var proxy = this;
            queryPromise.fail(function (e) {
                var args = { error: e.error };
                proxy._trigger("actionFailure", args)
            })
        },
        _initialRenderings: function () {
            if (this.model.groupSettings.groupedColumns.length) {
                var sortedColumns = new Array();
                for (var i = 0; i < this.model.sortSettings.sortedColumns.length; i++) {
                    if (ej.isNullOrUndefined(this.model.sortSettings.sortedColumns[i].direction))
                        this.model.sortSettings.sortedColumns[i].direction = ej.sortOrder.Ascending;
                    sortedColumns.push(this.model.sortSettings.sortedColumns[i].field);
                }
                for (var i = 0; i < this.model.groupSettings.groupedColumns.length; i++) {
                    if ($.inArray(this.model.groupSettings.groupedColumns[i], sortedColumns) == -1)
                        this.model.sortSettings.sortedColumns.push({ field: this.model.groupSettings.groupedColumns[i], direction: ej.sortOrder.Ascending });
                }
            }
        },
        _getExpands: function (field, arr) {
            var splits = field.split('.'), tmp = "";
            splits.splice(splits.length - 1, 1);
            for (var i = 0; i < splits.length; i++, tmp = "") {
                for (var j = 0; j < i; j++)
                    tmp += splits[j] + "/";
                tmp = tmp + splits[i];
                if (arr.indexOf(tmp) === -1)
                    arr.push(tmp);
            }
        },
        _renderAfterColumnInitialize: function () {
            this.element.append(this._renderGridHeader());
            if (this.model.allowFiltering && this.model.filterSettings.filterType == "filterbar")
                this._renderFiltering();
            if (this.model.allowPaging)
                this.element.append(this.element.find(".e-pager").first());
        },
        _ensureDataSource: function (args) {
            if (this._dataSource() == null && !(this._dataSource() instanceof ej.DataManager)){
				if(!ej.isNullOrUndefined(args) && args.requestType == "add")
					this.dataSource([]);				
				else
					return;
			}
            this.model.query.requiresCount();
            var queryManagar = this.model.query;
            if (!(this._dataSource() instanceof ej.DataManager))
                this.model.currentViewData = this._dataSource();
            if ((!(this._dataSource() instanceof ej.DataManager) || this._dataManager.dataSource.url == undefined) && (this.model.editSettings.allowEditing || this.model.editSettings.allowAdding) && (!ej.isNullOrUndefined(this._cModifiedData) || !ej.isNullOrUndefined(this._cAddedRecord))) {
                if (ej.isNullOrUndefined(this._cAddedRecord)) {
                    for (var index = 0; index < this._primaryKeys.length; index++)
                        queryManagar = queryManagar.where(this._primaryKeys[index], ej.FilterOperators.equal, this._primaryKeyValues[index]);
                    var currentData = this._dataManager.executeLocal(queryManagar);
                    if (!(this._dataSource() instanceof ej.DataManager))
                        this._dataSource().splice($.inArray(currentData.result[0], this._dataSource()), 1, this._cModifiedData);
                    else
                        $.extend(this._dataSource().dataSource.json[$.inArray(currentData.result[0], this._dataSource().dataSource.json)], this._cModifiedData);
                    this._cModifiedData = null;
                } else {
                    (this._dataSource() instanceof ej.DataManager) ? this._dataSource().dataSource.json.unshift(this._cAddedRecord) : this._dataSource().splice(0, 0, this._cAddedRecord);
                    this._cAddedRecord = null;
                }
                queryManagar.queries = [];
                this.model.isEdit = false;
            }

            if (this.model.editSettings.allowDeleting && !ej.isNullOrUndefined(this._cDeleteData) && (!(this._dataSource() instanceof ej.DataManager) || this._dataManager.dataSource.url == undefined)) {
                if (!(this._dataSource() instanceof ej.DataManager)) {
                    var index = $.inArray(this._cDeleteData[0], this._dataSource());
                    this._dataSource().splice(index, 1);
                }
                else {
                    var index = $.inArray(this._cDeleteData[0], this._dataSource().dataSource.json);
                    this._dataSource().dataSource.json.splice(index, 1);
                }
            }

            if (this.model.sortSettings.sortedColumns.length) {
                for (var i = this.model.sortSettings.sortedColumns.length - 1; i >= 0; i--)
                    queryManagar.sortBy(this.model.sortSettings.sortedColumns[i].field, this.model.sortSettings.sortedColumns[i].direction);

            }

            if (this.model.allowSearching && this._searchString.length) {
                queryManagar.search(this._searchString, this.getColumnFieldNames(), ej.FilterOperators.contains, true);
                if (args.requestType == "searching")
                    this._currentPage(1);
                if (!(this._dataSource() instanceof ej.DataManager))
                this._filteredRecords = this._dataManager.executeLocal(queryManagar).result;
            }

            if (this.model.allowFiltering && this.model.filterSettings.filteredColumns.length) {
                var predicate, firstFilterCondition = this.model.filterSettings.filteredColumns[0];
                if (this._isExcelFilter) {
                    if (ej.isNullOrUndefined(this._excelFilter._predicates[0]))
                        this._excelFilter.getPredicate(this.model.filterSettings.filteredColumns, null, true);
                    var predicates = this._excelFilter._predicates[0];
                    for (var prop in predicates) {
                        var obj = predicates[prop], isTake = obj["from"]!=undefined;
                        if (isTake) 
                           queryManagar.skip(obj["from"] == "top" ? 0 : this._gridRecordsCount - obj["take"]).take(obj["take"]);                                     
                        else
                            predicate = predicate != undefined ? predicate["and"](obj) : obj;
                    }
                }
                else {
                    if (!firstFilterCondition.isComplex)
                        predicate = ej.Predicate(firstFilterCondition.field, firstFilterCondition.operator, firstFilterCondition.value, !firstFilterCondition.matchcase);
                    else
                        predicate = firstFilterCondition;
                    for (var i = 1; i < this.model.filterSettings.filteredColumns.length; i++) {
                        if (!this.model.filterSettings.filteredColumns[i].isComplex)
                            predicate = predicate[this.model.filterSettings.filteredColumns[i].predicate](this.model.filterSettings.filteredColumns[i].field, this.model.filterSettings.filteredColumns[i].operator, this.model.filterSettings.filteredColumns[i].value, !this.model.filterSettings.filteredColumns[i].matchcase);
                        else
                            predicate = predicate["and"](this.model.filterSettings.filteredColumns[i]);
                    }
                }
                predicate && queryManagar.where(predicate);
                if (!(this._dataSource() instanceof ej.DataManager)) {
                    var fresults = this._dataManager.executeLocal(queryManagar);
                    this._filteredRecordsCount = isTake ? fresults.result.length : fresults.count;
                    var lastPage = (this._filteredRecordsCount % this.model.pageSettings.pageSize == 0) ? (this._filteredRecordsCount / this.model.pageSettings.pageSize) : (parseInt(this._filteredRecordsCount / this.model.pageSettings.pageSize, 10) + 1);
                    if (this._currentPage() > lastPage)
                        this._currentPage(lastPage);
                    this._filteredRecords = this._dataManager.executeLocal(queryManagar).result;
                } else if (!ej.isNullOrUndefined(args) && args.requestType == ej.Grid.Actions.Filtering)
                    this._currentPage(1);               
            }


            if (this.model.allowPaging || (this.model.scrollSettings.allowVirtualScrolling && this.model.allowScrolling)) {
                if (this._currentPage() == 0) {
                    if (this._prevPageNo == 0 || this._prevPageNo == null)
                        this._currentPage(1);
                    else
                        this._currentPage(this._prevPageNo);
                }
                queryManagar.page(this._currentPage(), this.model.pageSettings.pageSize);
            }

            if (this.model.allowGrouping) {
                var cloned = queryManagar.clone();
                if (this.model.allowPaging && this.model.groupSettings.groupedColumns.length) {
                    cloned.queries = cloned.queries.slice(0, cloned.queries.length - 1);
                }
                for (var i = 0; i < this.model.groupSettings.groupedColumns.length; i++) {
                    queryManagar.group(this.model.groupSettings.groupedColumns[i]);
                    cloned.group(this.model.groupSettings.groupedColumns[i]);
                }
                if (this.model.groupSettings.groupedColumns.length)
                    this._setAggreatedCollection(cloned);
            }
            if (args != undefined && args.requestType == "add" && (!(this._dataSource() instanceof ej.DataManager) || this._dataManager.dataSource.url == undefined) && this.model.groupSettings.groupedColumns.length == 0 && this.model.scrollSettings.frozenColumns == 0 && this.model.scrollSettings.frozenRows == 0)
                !(this._dataSource() instanceof ej.DataManager) ? this._dataSource().unshift(args.data) : this._dataSource().dataSource.json.unshift(args.data);
            if ((!(this._dataSource() instanceof ej.DataManager) || this._dataManager.dataSource.url == undefined)) {
                var result = this._dataManager.executeLocal(queryManagar);
                this.model.currentViewData = result.result;
                this._gridRecordsCount = result.count;
                this._searchCount = this._searchString.length ? result.count : null;
                this.model.groupSettings.groupedColumns.length && this._setAggregates();
            }

        },
        _initGridRender: function () {
            this.addInitTemplate();
            if (this.model.scrollSettings.frozenColumns > 0)
                this.addFrozenTemplate();
            this.model.allowGrouping && this.addGroupingTemplate();
            if (this.model.allowResizing || this.model.allowResizeToFit)
                this._resizer = new ej.Grid.gridResize(this);
			if (this.model.allowTextWrap == true)
                this.element.addClass("e-wrap");
            this.render();
            if (this.model.allowGrouping && ej.gridFeatures.dragAndDrop)
                this._headerCellgDragDrop();
            if (this.model.allowReordering && ej.gridFeatures.dragAndDrop) {
                this._headerCellreorderDragDrop();
                this._initIndicators();
            }
            this._wireEvents();           
            this._initialRender = false;
            if (this.model.width && !this.model.allowScrolling)
                this.element.width(this.model.width);
            if (this.model.editSettings.allowEditing || this.model.editSettings.allowAdding)
                this._processEditing();
            if (this.model.allowFiltering && (this.model.filterSettings.filterType == "menu" || this.model.filterSettings.filterType == "excel")) {
                this._isExcelFilter && this._renderExcelFilter();
				this._renderFilterDialogs();               
			   if (this.model.enableResponsiveRow)
                    this._renderResponsiveFilter();
            }
        },
        _getMetaColGroup: function () {
            var $colgroup = ej.buildTag("colgroup");
            for (var i = 0; i < this.model.columns.length; i++) {
                var $col = $(document.createElement("col"));
                this.model.columns[i]["visible"] === false && $col.css("display", "none");
                !ej.isNullOrUndefined(this.model.columns[i]["cssClass"]) && $col.addClass(this.model.columns[i]["cssClass"]);
                if (!this.model.groupSettings.showGroupedColumn && $.inArray(this.model.columns[i]["field"], this.model.groupSettings.groupedColumns) != -1)
                    $col.css("display", "none");
                $colgroup.append($col);
            }
            return $colgroup;
        },
        _alternateRow: function () {
            return this.getIndex() % 2 == 0 ? "" : "e-alt_row";
        },
        addInitTemplate: function () {
            var headerCellDiv = this.element.find(".e-headercelldiv"), templates = {};
            var tbody = document.createElement('tbody'), $tbody = $(tbody);
            if (this.model.rowTemplate == null) {
                var tr = document.createElement('tr'),
                    $tr = $(tr),
                    columns = this.model.columns,
                    i;
                if (this._gridRecordsCount)
                    this._initColumns(this.model.currentViewData[0] != undefined ? this.model.currentViewData[0] : this.model.currentViewData.value);
                var helpers = { _gridFormatting: this.formatting };
                $.views.helpers(helpers);

                var viewHelper = {};
                viewHelper["_foreignKey"] = this._foreignKeyBinding; // move to common methods
                $.views.helpers(viewHelper);

                if (this.model.detailsTemplate || this.model.childGrid || this.model.detailsDataBound) {
                    var $tdDetailCell = ej.buildTag("td.e-detailrowcollapse", "<div class='e-icon e-gnextforward'></div>");
                    $tr.append($tdDetailCell);
                }
                for (i = 0; i < this.model.columns.length; i++) {
                    var $tdCell = ej.buildTag("td.e-rowcell");
                    if (this.model.isResponsive)
                        $tdCell.attr("data-cell", this.model.columns[i]["headerText"]);
                    columns[i]["visible"] == false && $tdCell.addClass("e-hide");
                    !this.model.groupSettings.showGroupedColumn && $tdCell.addClass("{{for ~groupedColumns}}" +
                        " {{if #data == '" + this.model.columns[i]["field"] + "'}}e-hide{{/if}}" +
                        "{{/for}}");
                    if (!ej.isNullOrUndefined(columns[i]["templateID"] || columns[i]["template"])) {
                        var viewHelper = {};
                        viewHelper["_" + this._id + "ColumnTemplating"] = ej.proxy(this._gridTemplate, null, this);
                        $.views.helpers(viewHelper);
                        $("#" + this._id + columns[i].headerText + i + "_Template").remove();
                        var scriptElement = this._createTemplateElement(columns[i]);
                        this.model.columns[i]["allowGrouping"] = this.model.columns[i]["allowFiltering"] = this.model.columns[i]["allowSorting"] = false;
                        $tdCell.addClass("e-templatecell").html("{{:~_" + this._id + "ColumnTemplating('" + scriptElement.id + "')}}");
                    } else {
                        var splits = (columns[i].field || "").split("."), sLen = splits.length - 1, braces = "";
                        while (sLen) {
                            braces += "(";
                            sLen--;
                        }
						var columnType=columns[i].type || columns[i].editType
                        switch (columnType) {
                            case "boolean":
							case "booleanedit":
                                $tdCell.addClass("e-boolrowcell").html('{{if ' + columns[i].field + '}} <input type ="checkbox" disabled="disabled" checked="checked"></input>{{else}} <input type ="checkbox" disabled="disabled"  ></input> {{/if}}');
                                break;
                            default:
                                if (columns[i].disableHtmlEncode)
                                    $tdCell.html("{{html:" + "#data['" + splits.join("'] || {})['") + "']}}");
                                else
                                    $tdCell.html("{{:" + braces + "#data['" + splits.join("'] || {})['") + "']}}");
                        }
                        if (columns[i]["format"] != undefined && (!columns[i]["foreignKeyValue"] && !columns[i]["dataSource"]))
                            $tdCell.html("{{:~_gridFormatting('" + columns[i]["format"] + "',"+ braces + "#data['" + splits.join("'] || {})['") +"'],'"+ this.model.locale +"')}}");
                        if (columns[i]["foreignKeyValue"] && columns[i]["dataSource"]) {
                            var foreignKeyColumn = columns[i]["field"] != columns[i]["foreignKeyField"] ? columns[i]["field"] : columns[i]["foreignKeyField"];
                            $tdCell.html("{{:~_foreignKey('" + JSON.stringify(columns[i]) + "',#data['" + foreignKeyColumn + "'],'" + this._id + "Object" + "')}}");
                        }
                        if (columns[i]["isUnbound"]) {
                            var viewHelper = {};
                            viewHelper["_" + this._id + "UnboundTemplate"] = this._unboundTemplateRendering;
                            $.views.helpers(viewHelper);
                            this.model.columns[i]["allowGrouping"] = this.model.columns[i]["allowFiltering"] = this.model.columns[i]["allowSorting"] = false;
                            $("#" + this._id + columns[i].headerText + "_UnboundTemplate").remove();
                            divElement = this._createUnboundElement(columns[i]);
                            $tdCell.addClass("e-unboundcell").addClass("e-" + columns[i]["headerText"].replace(/\s+/g, "")).html("{{:~_" + this._id + "UnboundTemplate('" + divElement.id + "')}}");
                            this.model.scrollSettings.frozenColumns > 0 && $tdCell.addClass("e-frozenunbound");
                            this._isUnboundColumn = true;
                        }

                    }
                    if (!this.phoneMode && columns[i]["textAlign"] != undefined) {
                        $tdCell.css("text-align", columns[i]["textAlign"]);
                        $(headerCellDiv[i]).css("text-align", columns[i]["textAlign"]);
                    }
                    if (!this.phoneMode && !ej.isNullOrUndefined(columns[i]["headerTextAlign"])) {
                        $(headerCellDiv[i]).css("text-align", columns[i]["headerTextAlign"]);
                    }
                    if (!ej.isNullOrUndefined(columns[i]["cssClass"])) {
                        $tdCell.addClass(columns[i]["cssClass"]);
                    }
                    if (!ej.isNullOrUndefined(columns[i]["priority"]))
                        $tdCell.addClass("e-table-priority-" + columns[i]["priority"]);
                    if (!ej.isNullOrUndefined(columns[i]["customAttributes"]))
                        $tdCell.attr(columns[i]["customAttributes"]);
                    $tdCell.attr("role", "gridcell");
                    $tr.append($tdCell);
                    if (this.model.enableAltRow) {
                        helpers["_" + this._id + "AlternateRow"] = this._alternateRow;
                        $.views.helpers(helpers);
                        $tr.addClass("{{:~_" + this._id + "AlternateRow()}}");
                    }
                    $tr.attr("role", "row");
                    if (this.model.scrollSettings.frozenColumns > 0 && this.model.scrollSettings.frozenColumns == i + 1) {
                        tbody.appendChild(tr);
                        templates[this._id + "_JSONFrozenTemplate"] = $tbody.html();
                        $tr.empty();
                        $tbody.empty();
                    }
                }
                tbody.appendChild(tr);
            }
            templates[this._id + "_JSONTemplate"] = this.model.rowTemplate != null ? $(this.model.rowTemplate).html() : $tbody.html();
            $.templates(templates);
        },
        /**
         * Creates a grid control
         * @return jQuery
         * @example 
         * &lt;div id="Grid"&gt;&lt;/div&gt; 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // It renders the grid.
         * gridObj.render(); 
         * &lt;/script&gt;
         * @example 
         * &lt;div id="Grid"&gt;&lt;/div&dgt; 
         * &lt;script&gt;
         * // It renders the grid.
         * $("#Grid").ejGrid("render");        
         * &lt;/script&gt;
         */
        // Grid rendering parts
        render: function () {
            this._renderGridContent().insertAfter(this.element.children(".e-gridheader"));
            this.model.allowResizeToFit && this.setWidthToColumns();
            if (this.model.allowGrouping && ej.gridFeatures.dragAndDrop)
                this._groupHeaderCelldrag();
            this.model.showSummary = this.model.summaryRows.length > 0 || this.model.showSummary;
            if (this.model.showSummary) {
                this._renderGridFooter().insertAfter(this.getContent());
                this._hideCaptionSummaryColumn();
            }
            this._initialEndRendering();

        },
        _createStackedRow: function (stackedHeaderRow, frozenHeader) {
            var $tr = ej.buildTag('tr.e-columnheader e-stackedHeaderRow');
            var sHeader = [];
            for (var c = 0; c < this.model.columns.length; c++) {
                var column = this.model.columns[c];
                if (column.visible != false) {
                    var headerText = ''
                    var sColumn = stackedHeaderRow.stackedHeaderColumns;
                    for (var col = 0; col < sColumn.length; col++) {
                        if (sColumn[col].column.indexOf(column.field) != -1)
                            headerText = sColumn[col].headerText;
                    }
                    sHeader.push(headerText);
                }
            }
            var colsPanList = []
            for (var i = 0; i < sHeader.length; i++) {
                var colSpan = 1;
                for (var j = i + 1; j < sHeader.length; j++) {
                    if (sHeader[i] == sHeader[j]) {
                        colSpan++;
                    }
                    else
                        break;
                }
                colsPanList.push({ sapnCount: colSpan, headerText: sHeader[i] })
                i += colSpan - 1;
            }
            var $tr = ej.buildTag('tr.e-columnheader e-stackedHeaderRow');
            var frzCol = this.model.scrollSettings.frozenColumns;
            if (this.model.allowScrolling && frzCol > 0) {
                var frozenColspanList = [];
                var forzenColumn = 0, index = 0, frzHideCol = 0;
                for (var i = 0; i < this.model.columns.length; i++) {
                    var col = this.model.columns[i];                    
                    if ( i < frzCol && col.visible == false)
                        frzHideCol++;
                }                
                forzenColumn = frzCol - frzHideCol;
                while (forzenColumn > 0) {
                    var spanC = colsPanList[index].sapnCount;
                    if (colsPanList[index].sapnCount < forzenColumn) {
                        frozenColspanList.push(colsPanList[index])
                        if (!frozenHeader)
                            colsPanList.splice(index, 1);
                        else
                            index++;
                    }
                    else if (colsPanList[index].sapnCount > forzenColumn) {
                        colsPanList[index].sapnCount = colsPanList[index].sapnCount - forzenColumn
                        if (frozenHeader)
                            frozenColspanList.push({ sapnCount: forzenColumn, headerText: colsPanList[index].headerText });
                    }
                    else {
                        frozenColspanList.push(colsPanList[index])
                        if (!frozenHeader)
                            colsPanList.splice(index, 1);
                    }
                    forzenColumn -= spanC;
                }
                if (frozenHeader)
                    colsPanList = frozenColspanList
            }
            for (var c = 0; c < colsPanList.length; c++) {
                var $th = ej.buildTag('th.e-headercell e-stackedHeaderCell e-default', colsPanList[c].headerText, {}, { 'colspan': colsPanList[c].sapnCount });
                $tr.append($th);
            }
            return $tr;
        },
        _renderGridHeaderInternalDesign: function (columns, frozenHeader) {
            var $table = ej.buildTag('table.e-table', "", {}, { cellspacing: "0.25px", role: "grid" });
            var $thead = ej.buildTag('thead');
            var $tbody = ej.buildTag('tbody.e-hide');
            var $columnHeader = ej.buildTag('tr.e-columnheader');
            var $colGroup = $(document.createElement('colgroup'));
            var $rowBody = $(document.createElement('tr'));
            if (this.model.detailsTemplate || this.model.childGrid || this.model.detailsDataBound) {
                $columnHeader.append(ej.buildTag('th.e-headercell e-detailheadercell', '<div></div>'));
                $colGroup.append(this._getIndentCol());
            }
            if (this.model.showStackedHeader) {
                for (var index = 0; index < this.model.stackedHeaderRows.length; index++) {
                    var $tr = this._createStackedRow(this.model.stackedHeaderRows[index], frozenHeader);
                    $thead.append($tr);
                }
            }
            for (var columnCount = 0; columnCount < columns.length; columnCount++) {
                var $headerCell = ej.buildTag('th.e-headercell e-default', "", {}, { role: "columnheader" });
                var bodyCell = document.createElement('td');
                var $headerCellDiv = ej.buildTag('div.e-headercelldiv', columns[columnCount]["headerText"] === undefined ? columns[columnCount]["headerText"] = columns[columnCount]["field"] : columns[columnCount]["headerText"], {}, { "ej-mappingname": columns[columnCount]["field"] });
                if (columns[columnCount].disableHtmlEncode)
                    $headerCellDiv.text(columns[columnCount]["headerText"]);
                $headerCell.append($headerCellDiv);
                if (this.model.allowFiltering && (this.model.filterSettings.filterType == "menu" || this.model.filterSettings.filterType == "excel") &&
                (columns[columnCount]["allowFiltering"] == undefined ||
                    columns[columnCount]["allowFiltering"] === true)){
                    $headerCell.append(ej.buildTag('div.e-filtericon e-icon e-filterset'));
					if (ej.browserInfo().name == "msie" && ej.browserInfo().version == "8.0" && this.model.enableRTL)
                        $($headerCellDiv).css("padding","0 0 0 2em");
                }
                var col = document.createElement('col');
                if (columns[columnCount]["priority"])
                    $(bodyCell).addClass("e-table-priority-" + columns[columnCount]["priority"]);
                $rowBody.append(bodyCell);
                $columnHeader.append($headerCell);
                $colGroup.append(col);
                if (columns[columnCount]["visible"] === false)
                    $headerCell.addClass("e-hide") && $(col).css("display", "none") && this._hiddenColumns.push(columns[columnCount].headerText);
                else {
                    this._visibleColumns.push(columns[columnCount].headerText);
                    columns[columnCount]["visible"] = true;
                }
				if (!ej.isNullOrUndefined(columns[columnCount]["headerTextAlign"]))
                    $headerCellDiv.css("text-align", columns[columnCount]["headerTextAlign"]);
                else if (columns[columnCount]["textAlign"] != undefined)
                    $headerCellDiv.css("text-align", columns[columnCount]["textAlign"]);
                columns[columnCount]["allowSorting"] === false && this._disabledSortableColumns.push(columns[columnCount].field);
                columns[columnCount]["allowGrouping"] === false && this._disabledGroupableColumns.push(columns[columnCount].headerText);
                if (!ej.isNullOrUndefined(columns[columnCount]["cssClass"])) {
                    $headerCell.addClass(this.model.columns[columnCount]["cssClass"]);
                    $(col).addClass(this.model.columns[columnCount]["cssClass"]);
                }
                if (!ej.isNullOrUndefined(this.model.columns[columnCount]["headerTemplateID"])) {
                    $headerCellDiv.html($(this.model.columns[columnCount]["headerTemplateID"]).hide().html()).parent().addClass("e-headertemplate");
                    var index = $.inArray(this.model.columns[columnCount].headerText, this._disabledGroupableColumns);
                    index == -1 && this._disabledGroupableColumns.push(this.model.columns[columnCount].headerText);
                }
                if (this.model.groupSettings.showToggleButton && $.inArray(columns[columnCount].headerText, this._disabledGroupableColumns) == -1) {
                    if ($.inArray(columns[columnCount].field, this.model.groupSettings.groupedColumns) != -1)
                        $headerCellDiv.append(this._getToggleButton().addClass("e-toggleungroup"));
                    else
                        $headerCellDiv.append(this._getToggleButton().addClass("e-togglegroup"));
                }
				if (this.model.isResponsive)
                    $headerCell.attr("title", columns[columnCount].headerText);
                if (columns[columnCount]["priority"]) {
                    $headerCell.attr("data-priority", columns[columnCount]["priority"]).addClass("e-table-priority-" + columns[columnCount]["priority"]);
                    $(col).addClass("e-table-priority-" + columns[columnCount]["priority"]);
                }
                this._columnsWidthCollection.push(columns[columnCount]["width"]);
                if (columns[columnCount]["width"] == undefined && this.model.commonWidth !== undefined)
                    this._columnsWidthCollection[columnCount] = this.model.commonWidth;
                this._fieldColumnNames[columns[columnCount].headerText] = columns[columnCount].field;
                this._headerColumnNames[columns[columnCount].field] = columns[columnCount].headerText;
                this.model.allowFiltering && ("menu" == this.model.filterSettings.filterType || this._isExcelFilter) && $headerCell.addClass("e-headercellfilter");
            }
            $thead.append($columnHeader);
            $tbody.append($rowBody);
            $table.append($colGroup).append($thead).append($tbody);
            return $table;
        },
        _renderGridHeader: function () {
            var $div = ej.buildTag('div.e-gridheader'), temp, $frozenDiv, $movableDiv;
            var $innerDiv = ej.buildTag('div');
            if (this.model.allowScrolling)
                $innerDiv.addClass("e-headercontent");
            this.setGridHeaderContent($div);
            this._hiddenColumns = [];
            this._columnsWidthCollection = [];
            this._visibleColumns = [];
            this._disabledGroupableColumns = [];
            this._fieldColumnNames = {};
            this._headerColumnNames = {};
            if (this.model.scrollSettings.frozenColumns > 0) {
                $frozenDiv = ej.buildTag("div.e-frozenheaderdiv", this._renderGridHeaderInternalDesign(this.model.columns.slice(0, this.model.scrollSettings.frozenColumns), true));
                $movableDiv = ej.buildTag("div.e-movableheader", ej.buildTag("div.e-movableheaderdiv", this._renderGridHeaderInternalDesign(this.model.columns.slice(this.model.scrollSettings.frozenColumns), false)));
                $innerDiv.append($frozenDiv).append($movableDiv);
            } else
                $innerDiv.append(this._renderGridHeaderInternalDesign(this.model.columns));
            $div.html($innerDiv);
			if (this.model.isResponsive)
                $div.addClass("e-textover");
            this.setGridHeaderTable(this.getHeaderContent().find(".e-table"));
            return $div;
        },
        _renderGridContent: function () {
            var $div = ej.buildTag('div.e-gridcontent');
            var $innderDiv = ej.buildTag('div');
            var $table = ej.buildTag('table.e-table', "", {}, { cellspacing: "0.25px" });
            var $tbody = $(document.createElement('tbody'));
            $table.append(this.getHeaderTable().find('colgroup').clone()).append($tbody);
            $innderDiv.html($table);
            $div.html($innderDiv);
            this.setGridContentTable($table);
            this.setGridContent($div);
            $table.attr("role", "grid");
            if (this._dataSource() == null) {
                var $emptyTd = ej.buildTag('td', this._getLocalizedLabels("EmptyRecord"), {}, { colSpan: this.model.columns.length });
                $tbody.append($(document.createElement("tr")).append($emptyTd));
                this.setWidthToColumns();
            } else {
                var args = {};
                if (this.model.groupSettings.groupedColumns.length) {
                    if (this._initialRender)
                        args.columnName = this.model.groupSettings.groupedColumns[this.model.groupSettings.groupedColumns.length - 1];
                    args.requestType = ej.Grid.Actions.Grouping;
                } else
                    args.requestType = ej.Grid.Actions.Refresh;
                this.sendDataRenderingRequest(args);
            }
            if (this._isCaptionSummary && args.requestType == "grouping" && this.model.groupSettings.groupedColumns.length > 1) {
                var colgroup = this.getContentTable().find(".e-table").not(".e-recordtable").children("colgroup");
                var $cols1 = $(this.getContentTable().find(".e-recordtable")[0]).children("colgroup").find("col");
                for (i = 0; i < colgroup.length; i++) {
                    var colCount = $(colgroup[i]).find("col").length;
                    $(colgroup[i]).find("col:gt(" + (colCount - $cols1.length - 1) + ")").remove();
                    $(colgroup[i]).append($cols1.clone());
                }
            }
            return $div;
        },
        /**
         * Print the grid control
         * @return jQuery
         * @example 
         * &lt;div id="Grid"&gt;&lt;/div&gt; 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // It prints the grid.
         * gridObj.print(); 
         * &lt;/script&gt;
         * @example 
         * &lt;div id="Grid"&gt;&lt;/div&dgt; 
         * &lt;script&gt;
         * // It prints the grid.
         * $("#Grid").ejGrid("print");        
         * &lt;/script&gt;
         */
			print:function(){
			var allowPaging=this.model.allowPaging;
			var elementClone=this.element.clone();	
			if(allowPaging){
				this.model.allowPaging=false;
				this.refreshContent();
				this.getPager().css('display','none');
				elementClone=this.element.clone();
				this.model.allowPaging=true;
				if(!this.model.allowScrolling){
					this.refreshContent();
					this.getPager().css('display','block');
					}
				}			
				
			if(this.model.allowScrolling){
				var scrollWidth=this.model.scrollSettings.width,scrollHeight=this.model.scrollSettings.height;
			    var scrollContent=this.getContent().find('.e-content')[0];
				$(elementClone.find('.e-gridcontent')).height(scrollContent.scrollHeight);
			    $(elementClone.find('.e-gridcontent')).ejScroller({width:scrollContent.scrollWidth,height:scrollContent.scrollHeight});
			    elementClone.width(scrollContent.scrollWidth);
				if(this.model.allowPaging){
					this.refreshContent();
					this.getPager().css('display','block');
					}
			}
			if (this.model.toolbarSettings.showToolbar)
			    elementClone.find(".e-gridtoolbar").remove();
			ej.print(elementClone);	
			},

        "export": function (action, serverEvent, multipleExport) {
            var modelClone = $.extend(true, {}, this.model);
            for (var i = 0; i < modelClone.columns.length; i++) {
                if (modelClone.columns[i].editType != undefined) {
                    switch (modelClone.columns[i].editType) {
                        case "stringedit":
                            modelClone.columns[i].editType = "string";
                            break;
                        case "numericedit":
                            modelClone.columns[i].editType = "numeric";
                            break;
                        case "dropdownedit":
                            modelClone.columns[i].editType = "dropdown";
                            break;
                        case "booleanedit":
                            modelClone.columns[i].editType = "boolean";
                            break;
                        default:
                            break;
                    }
                }
            }
            for (var i = 0; i < modelClone.filterSettings.filteredColumns.length; i++) {
                if (modelClone.filterSettings.filteredColumns[i].operator == "equal")
                    modelClone.filterSettings.filteredColumns[i].operator = "equals";
                else if (modelClone.filterSettings.filteredColumns[i].operator == "notequal")
                    modelClone.filterSettings.filteredColumns[i].operator = "notequals";
            }
            var attr = { action: action, method: 'post' };
            var form = ej.buildTag('form', "", null, attr);
            var gridob = this;
            if (this.ignoreOnExport) {
                for (var i = 0; i < this.ignoreOnExport.length; i++) {
                    delete modelClone[this.ignoreOnExport[i]];
                }
            }
            if (ej.raiseWebFormsServerEvents) {
                var args = { model: modelClone, originalEventType: serverEvent };
                var clientArgs = { model: JSON.stringify(modelClone) };
                ej.raiseWebFormsServerEvents(serverEvent, args, clientArgs);
            }
            else {
                var gridobjectArray = {};
                if (multipleExport) {
                    $('body').find('.e-grid').each(function (index, object) {
                        var gridObject = $(object).data('ejGrid');
                        if (!ej.isNullOrUndefined(gridObject)) {
                            var modelClone = JSON.parse(JSON.stringify(gridObject.model));
                            if (gridob.ignoreOnExport) {
                                for (var i = 0; i < gridob.ignoreOnExport.length; i++) {
                                    delete modelClone[gridob.ignoreOnExport[i]];
                                }
                                gridobjectArray[index] = JSON.stringify(modelClone);
                                var inputAttr = { name: 'GridModel', type: 'hidden', value: JSON.stringify(modelClone) }
                                var input = ej.buildTag('input', "", null, inputAttr);
                                form.append(input);
                            }
                        }
                    });
                }
                else {
                    var inputAttr = { name: 'GridModel', type: 'hidden', value: JSON.stringify(modelClone) }
                    var input = ej.buildTag('input', "", null, inputAttr);
                    form.append(input);
                    form.append(this);
                }
                $('body').append(form);
                form.submit();
            }
            return true;
        },
        sendDataRenderingRequest: function (args) {
            if (this._templateRefresh) {
                this.refreshTemplate();
                this._templateRefresh = false;
            }
            if (args.requestType == "add" || (this.model.currentViewData != null && this.model.currentViewData.length)) {
                switch (args.requestType) {
                    case ej.Grid.Actions.Refresh:
                    case ej.Grid.Actions.Paging:
                    case ej.Grid.Actions.Sorting:
                    case ej.Grid.Actions.Filtering:
                    case ej.Grid.Actions.Save:
                    case ej.Grid.Actions.Cancel:
                    case ej.Grid.Actions.Delete:
                    case ej.Grid.Actions.Search:
                    case ej.Grid.Actions.Reorder:
                    case ej.Grid.Actions.BatchSave:
                        if (this.model.groupSettings.groupedColumns.length == 0) {
                            var temp = document.createElement('div'),temp1, insertIndex = -1, isRemoteAdaptor = false;
                            if (!this.model.isResponsive)
                                this.getContentTable().find("colgroup").first().replaceWith(this._getMetaColGroup());
                            (this.model.detailsTemplate != null || this.model.childGrid != null || this.model.detailsDataBound != null) && this.getContentTable().find("colgroup").first().prepend(this._getIndentCol());
                            var currentPage = this._currentPage();
                            if (this.model.editSettings.editMode == "externalform" || this.model.editSettings.editMode == "externalformtemplate")
                                $("#" + this._id + "_externalEdit").css("display", "none");
                            if (this.model.scrollSettings.frozenColumns > 0)
                                temp.innerHTML = this._renderByFrozenDesign();
                            else {
                                temp.innerHTML = ['<table>', $.render[this._id + "_JSONTemplate"](this.model.currentViewData), '</table>'].join("");
								if(args.data) {
									temp1 = document.createElement('div');
									temp1.innerHTML = ['<table>', $.render[this._id + "_JSONTemplate"](args.data), '</table>'].join("");
									if (this._dataSource() instanceof ej.DataManager && args.requestType == ej.Grid.Actions.Save) {
									    insertIndex = this._getDataIndex(this.model.currentViewData, args.data);
									    isRemoteAdaptor = this._dataSource().adaptor instanceof ej.remoteSaveAdaptor;
								}
								}
                                var tableEle = this.getContentTable().get(0);
                                var tbodyEle = tableEle.lastChild;
                                var rindex = this.getContentTable().first().find('tbody').first();
                                if ((args.requestType == "save" || args.requestType == "cancel") && this.model.editSettings.editMode != "batch") {
                                    if (this.model.editSettings.editMode.indexOf("inlineform") != -1)
										rowIndex = !ej.isNullOrUndefined(args.selectedRow) ? args.selectedRow : this._selectedRow();
									else
										rowIndex = this.getContentTable().find('.e-' + args.action + 'edrow').index();
                                    var a = this._currentTrIndex;
                                    if (rowIndex == -1)
                                        rowIndex = a;
                                    if (this.model.detailsTemplate != null) {
                                        rowTr = $(tbodyEle.childNodes[rowIndex]);
                                        rowEle = $(tbodyEle.childNodes).not('.e-detailrow');
                                        for (var i = 0; i < rowEle.length; i++) {
                                            if (rowTr.is(rowEle[i]))
                                                rowIndex = i;
                                        }
                                    }

                                    if (this.model.editSettings.editMode == "normal" || this.model.editSettings.editMode == "inlineform" || this.model.editSettings.editMode == "inlineformtemplate") {                                      
                                        $oldChild = this.getContentTable().find('.e-addedrow').get(0);
                                        $editedTr = this.getContentTable().find('.e-editedrow');
                                        $newChild = ($editedTr.length || args.requestType == "cancel") ? temp.firstChild.firstChild.firstChild : temp1.firstChild.firstChild.lastChild;
                                        if ($editedTr.length) {
                                            $newChild = temp.firstChild.firstChild.childNodes[rowIndex];
                                            if (this.model.editSettings.editMode == "inlineform" || this.model.editSettings.editMode == "inlineformtemplate") {
                                                $oldChild = $editedTr.prev('tr').get(0);
                                                $editedTr.remove();
                                            } else
                                                $oldChild = $editedTr.get(0);
                                            $($newChild).find('.e-templatecell').replaceWith($($oldChild).find('.e-templatecell'));
                                            if (args.requestType == "cancel") {
                                                $($oldChild).replaceWith($($newChild));
                                            } else if (!ej.isNullOrUndefined(this._filteredRecordsCount) && this._filteredRecordsCount < this._previousFilterCount) {
                                                if (this.model.detailsTemplate != null && $($oldChild).next('tr.e-detailrow').length)
                                                    tbodyEle.removeChild($($oldChild).next('tr.e-detailrow').get(0));
                                                $($oldChild).remove();
                                                if (this.model.allowPaging && this.model.pageSettings.pageSize <= this.model.currentViewData.length && this.model.groupSettings.groupedColumns.length == 0)
                                                    tbodyEle.appendChild(temp.firstChild.firstChild.lastChild);
                                            } else {
												var $eRow = $(tbodyEle).find(".e-editedrow");
                                                $eRow.find("select.e-dropdownlist").ejDropDownList("destroy");
                                                $eRow.find(".e-datepicker").ejDatePicker("destroy");
                                                $eRow.find(".e-datetimepicker").ejDateTimePicker("destroy");
                                                tbodyEle.replaceChild($newChild, $oldChild);
                                            }
                                        } else {
                                            if (args.requestType == "cancel" || this._dataSource() instanceof ej.DataManager || this._currentPage() != 1 || (args.requestType == "save" && !ej.isNullOrUndefined(this._filteredRecordsCount) && this._filteredRecordsCount == this._previousFilterCount)) {
                                                if (!ej.isNullOrUndefined($oldChild)) {
                                                    $($oldChild).remove();
                                                    if (this._dataSource() instanceof ej.DataManager && insertIndex != -1) {
                                                        if (insertIndex == 0)
                                                            tbodyEle.insertBefore($newChild, tbodyEle.children[insertIndex]);
                                                        else
                                                            $($newChild).insertAfter(tbodyEle.children[insertIndex - 1]);                                                        
                                                    }
                                                    else if ((!(this._dataSource() instanceof ej.DataManager) || isRemoteAdaptor) && this._currentPage() != 1 && args.requestType == "save")
                                                        $(tbodyEle).prepend($(temp.firstChild.firstChild.firstChild));
                                                    if (this.model.allowPaging && this.model.pageSettings.pageSize <= this.model.currentViewData.length && this.model.groupSettings.groupedColumns.length == 0 &&
                                                        ((this._dataSource() instanceof ej.DataManager && insertIndex == -1 && (!isRemoteAdaptor && args.requestType != "save")) ||
                                                        (args.requestType != "save" && !(this._dataSource() instanceof ej.DataManager))))
                                                        tableEle.lastChild.appendChild(temp.firstChild.firstChild.lastChild);
                                                }
                                                if (args.requestType == "cancel" && this._selectedRow() != -1)
                                                    this.clearSelection();

                                            } else if (this.model.currentViewData.length == 1) {
                                                $(tbodyEle).empty();
                                                tbodyEle.appendChild($newChild);
                                            } else if (this.model.editSettings.rowPosition == "bottom") {
                                                rindex.prepend($oldChild);
                                                tbodyEle.replaceChild($newChild, $oldChild);
                                            } else
                                                tbodyEle.replaceChild($newChild, $oldChild);
                                        }
                                    } else if (this.model.editSettings.editMode == "dialog" || this.model.editSettings.editMode == "dialogtemplate" || this.model.editSettings.editMode == "externalform" || this.model.editSettings.editMode == "externalformtemplate") {
                                        $editedTr = this.element.find('.e-editedrow');
                                        if (args.requestType == "cancel" || (!$editedTr.length && !ej.isNullOrUndefined(this._filteredRecordsCount) && this._filteredRecordsCount == this._previousFilterCount)) {
                                            $newChild = temp.firstChild.firstChild.childNodes[rowIndex];
                                            $oldChild = tbodyEle.childNodes[rowIndex];
                                            $($oldChild).replaceWith($($newChild));
                                            this.clearSelection();
                                            this.model.allowPaging && this._refreshGridPager();

                                        } else if ($editedTr.length) {
                                            $newChild = temp.firstChild.firstChild.childNodes[rowIndex];
                                            $oldChild = tbodyEle.childNodes[rowIndex];
											if (this.model.allowCellMerging != null) {
                                                if ($($oldChild.childNodes).hasClass("e-merged")) {
                                                    var index = $($oldChild).children('.e-merged').index();
                                                    var count = $oldChild.children[index].colSpan;
                                                    for (var i = 0 ; i < count; i++) {
                                                        $newChild.childNodes[index + i].className += " e-merged e-hide";
                                                        $newChild.childNodes[index].colSpan = i + 1;
                                                    }
                                                }
                                            }
                                            if (this.model.detailsTemplate != null)
                                                $oldChild = $(tbodyEle.childNodes).not('.e-detailrow').eq(rowIndex).get(0);
                                            if (!ej.isNullOrUndefined(this._filteredRecordsCount) && this._filteredRecordsCount < this._previousFilterCount) {
                                                if (this.model.detailsTemplate != null && $($oldChild).next('tr.e-detailrow').length)
                                                    tbodyEle.removeChild($($oldChild).next('tr.e-detailrow').get(0));
                                                $($oldChild).remove();
                                                if (this.model.allowPaging && this.model.pageSettings.pageSize <= this.model.currentViewData.length)
                                                    tbodyEle.appendChild(temp.firstChild.firstChild.lastChild);
                                            } else
                                                tbodyEle.replaceChild($newChild, $oldChild);
                                        } else if (this.model.currentViewData.length == 1 && this.getContentTable().find('td.e-rowcell').length == 0) {
                                            $newChild = temp.firstChild.firstChild.firstChild;
                                            $(tbodyEle).empty();
                                            tbodyEle.appendChild($newChild);
                                        } else {
                                            newChild = ($editedTr.length || args.requestType == "cancel") ? temp.firstChild.firstChild.firstChild : temp1.firstChild.firstChild.lastChild;
                                            if (!(this._dataSource() instanceof ej.DataManager)) {
                                                if (this._currentPage() == 1)
                                            this.getContentTable().find('tbody').first().prepend($(newChild));
                                                else
                                                    this.getContentTable().find('tbody').first().prepend($(temp.firstChild.firstChild.firstChild));
                                                if (this.model.allowPaging && this.model.pageSettings.pageSize <= this.model.currentViewData.length)
                                                tbodyEle.removeChild(tbodyEle.lastChild);
                                            }
                                            else if (insertIndex != -1) {
                                                if (insertIndex == 0)
                                                    tbodyEle.insertBefore(newChild, tbodyEle.children[insertIndex]);
                                                else
                                                    $(newChild).insertAfter(tbodyEle.children[insertIndex - 1]);
                                                if (this.model.allowPaging && (this.model.pageSettings.pageSize <= this.model.currentViewData.length || insertIndex == this.model.pageSettings.pageSize - 1))
                                                    tbodyEle.removeChild(tbodyEle.lastChild);
                                            }
                                            if (this.model.detailsTemplate != null && $(tableEle.lastChild.lastChild).children('.e-detailrowexpand').length)
                                                tbodyEle.removeChild(tbodyEle.lastChild);
                                        }
                                    }
                                    if (this.model.enableAltRow)
                                        this._refreshAltRow();
                                } else if (args.requestType == "delete") {
                                    if (this._isUnboundColumn) {
                                        $editedrow = this.element.find('.e-editedrow');
                                        $oldChild = this.getContentTable().find('.e-editedrow').get(0);
                                        $newChild = ($editedrow.length) ? temp.firstChild.firstChild.firstChild : temp1.firstChild.firstChild.lastChild;

                                        if ($editedrow.length != 0 && (this.model.editSettings.editMode == "normal" || this.model.editSettings.editMode == "externalform" || this.model.editSettings.editMode == "externalformtemplate")) {
                                            $($oldChild).replaceWith($($newChild));
                                        }
                                        else if (this.model.editSettings.editMode == "inlineform" || this.model.editSettings.editMode == "inlineformtemplate") {
                                            $oldChild = $editedrow.prev('tr').get(0);
                                            $editedrow.remove();
                                        }
                                        else
                                            $oldChild = $editedrow.get(0);
                                    }
                                    if (this.model.allowPaging && this.model.pageSettings.pageSize <= this.model.currentViewData.length)
                                        tbodyEle.appendChild(temp.firstChild.firstChild.lastChild);
                                    if (this.model.detailsTemplate != null) {
                                        var visibleRow = this.getContentTable().find('.e-detailrow:visible');
                                        $.each(visibleRow, function (indx, item) {
                                            if (visibleRow.eq(indx).closest('tr').prev().children('.e-detailrowexpand').length == 0)
                                                visibleRow.eq(indx).remove();
                                        });
                                    }
                                    if (this.model.enableAltRow)
                                        this._refreshAltRow();
                                } else
                                    this.getContentTable().get(0).replaceChild(this.model.rowTemplate != null ? temp.firstChild.lastChild : temp.firstChild.firstChild, this.getContentTable().get(0).lastChild);

                            }
                            this._currentJsonData = this.model.currentViewData;
                            this._gridRows = this.getContentTable().get(0).rows;
                            if (this.model.scrollSettings.frozenColumns > 0)
                                this._gridRows = [this._gridRows, this.getContentTable().get(1).rows];
                            this._eventBindings();
                            var model = {};
                            if ((args.requestType == "sorting" || args.requestType == "filtering") && this.model.scrollSettings.allowVirtualScrolling) {
                                if (args.requestType == "filtering") {
                                    this.getContent().first().ejScroller("refresh").ejScroller("isVScroll") ? this.element.find(".gridheader").addClass("e-scrollcss") : this.element.find(".gridheader").removeClass("e-scrollcss");
                                    var model = this._refreshVirtualPagerInfo();
                                }
                                this._refreshVirtualContent(currentPage, model);
                                args.requestType == "filtering" && this.getContent().first().ejScroller("refresh");
                            }
                            if (this.model.allowPaging) {
                                if (this.model.filterSettings.filteredColumns.length)
                                    this.getPager().ejPager({ totalRecordsCount: this._searchCount == null ? this._filteredRecordsCount : this._searchCount, currentPage: this._currentPage() });
                                else
                                    this.getPager().ejPager({ totalRecordsCount: this._searchCount == null ? this._gridRecordsCount : this._searchCount, currentPage: this._currentPage() });
                                this._refreshGridPager();
                            }
                            break;
                        }
                    case ej.Grid.Actions.Grouping:
                        this._group(args);
                        this._refreshStackedHeader();
                        break;
                    case ej.Grid.Actions.BeginEdit:
                        this._edit(args);
                        break;
                    case ej.Grid.Actions.Add:
                        this._add(args);
                        break;
                    case ej.Grid.Actions.Ungrouping:
                        this._ungroup(args);
                        break;
                    case ej.Grid.Actions.VirtualScroll:
                        !this._isVirtualRecordsLoaded && this._replacingContent();
                        break;
                }
            } else
                this.getContentTable().find('tbody').empty().first().append(this._getEmptyTbody());
            this._completeAction(args);
        },
        _completeAction: function (args) {
            this.model.isEdit = false;
            this._confirmedValue = false;
            if (ej.Grid.Actions.Grouping == args.requestType && ej.isNullOrUndefined(args.columnName))
                return;
            this.setWidthToColumns();
            if (ej.Grid.Actions.UnGrouping == args.requestType || this.model.groupSettings.groupedColumns.length && !$("#" + this._id + "EditForm").length)
                this._recalculateIndentWidth();
            if (ej.Grid.Actions.Paging == args.requestType || ej.Grid.Actions.BatchSave == args.requestType)
                this._refreshGridPager();
            else if ((ej.Grid.Actions.Sorting == args.requestType && this.model.allowSorting) || ej.Grid.Actions.Refresh == args.requestType) {
                if (ej.gridFeatures.sort && this.getHeaderTable() !== null)
                    this._sortCompleteAction(args);
                if(this.model.allowPaging){		
					var pageModel=this.getPager().ejPager("option");
					this._currentPage(pageModel.currentPage);
					delete pageModel.currentPage;
					$.extend(this.model.pageSettings, pageModel);
					delete this.model.pageSettings.masterObject;
					this._refreshGridPager();
				}
                if (!this._initialRender && (this.model.scrollSettings.frozenRows > 0 || this.model.scrollSettings.frozenColumns > 0))
                    this._refreshScroller(args);
            } else if (ej.Grid.Actions.Delete == args.requestType || ej.Grid.Actions.Save == args.requestType || ej.Grid.Actions.Search == args.requestType) {
                this._editEventTrigger(args);
                if (this.model.allowPaging)
                    this._refreshPagerTotalRecordsCount();
            } else if (ej.Grid.Actions.Filtering == args.requestType)   
                this._filterCompleteAction();
            else if (ej.Grid.Actions.BeginEdit == args.requestType || ej.Grid.Actions.Add == args.requestType)
                this._editCompleteAction(args);
            else if (ej.Grid.Actions.Grouping == args.requestType || ej.Grid.Actions.Ungrouping == args.requestType)
                this["_" + args.requestType + "CompleteAction"](args);
            if (this.model.toolbarSettings.showToolbar)
                this.refreshToolbar();
            if (!this._initialRender && this.model.showSummary && this.model.summaryRows.length > 0) {
                this.getFooterTable().find('colgroup').remove();
                this.getFooterTable().append(this.getHeaderTable().find("colgroup").clone());
                this._createSummaryRows(this.getFooterTable());
            }
            if (!this._initialRender && ej.gridFeatures.selection) {
                this._setCurrentRow(args.requestType);
                this.getHeaderTable().find(".e-columnselection").removeClass("e-columnselection");
                this.selectedColumnIndexes = [];
            }
            this.model.editSettings.editMode == "batch" && this.refreshBatchEditMode();
            if (!this._initialRender && this.model.allowScrolling && (this._checkScrollActions(args.requestType) || (this.model.editSettings.editMode.indexOf("inline") != -1 && args.requestType == "beginedit")) ||
                (this.model.scrollSettings.virtualScrollMode == "continuous" && args.requestType == "virtualscroll"))
                this._refreshScroller(args);
            if (this._customPop != null && args.requestType != "sorting") {
                this._customPop.hide();
            }
            if (this.model.allowScrolling && (ej.Grid.Actions.Filtering == args.requestType || ej.Grid.Actions.Paging == args.requestType || ej.Grid.Actions.Sorting == args.requestType ||
                ej.Grid.Actions.Grouping == args.requestType || ej.Grid.Actions.Ungrouping == args.requestType)) {
                this.getContentTable().find("tr:last").find("td").addClass("e-lastrowcell");
            }
            this._trigger("actionComplete", args);
            if ((ej.Grid.Actions.BeginEdit == args.requestType || ej.Grid.Actions.Add == args.requestType) && $.isFunction($.validator))
                this.setValidation();
        },
        _getForeignKeyData: function (data) {
            var proxy = this;
            var column;
            for (i = 0; i < this.model.columns.length; i++) {
                if (this.model.columns[i].foreignKeyValue && this.model.columns[i].dataSource) {
                    var fieldName = ej.isNullOrUndefined(proxy.model.columns[i]["foreignKeyField"]) ? proxy.model.columns[i]["field"] : proxy.model.columns[i]["foreignKeyField"];
                    this.model.columns[i].dataSource.filter(function (col) {
                        var value = data[proxy.model.columns[i]["field"]];
                        var fValue = !isNaN(parseFloat(value)) && isFinite(value) ? parseFloat(value) : value;
                        if (col[fieldName] == fValue)
                            return column = col;
                    });
                }
            }
            return column;
        },
        _foreignKeyBinding: function (curColumn, cellValue, gridId) {
            if (typeof (curColumn) == "string")
                curColumn = JSON.parse(curColumn);
            var cellData;
            curColumn.dataSource.filter(function (col) {
                if (col[curColumn.foreignKeyField] == cellValue)
                    return cellData = curColumn.type == "date" ? new Date(col[curColumn.foreignKeyValue]) : col[curColumn.foreignKeyValue];
            });
            if (curColumn.format) {
                var gridObj = ej.isNullOrUndefined(gridId) ? this : this.getRsc("helpers", gridId);
                cellData = gridObj.formatting(curColumn.format, cellData,gridObj.model.locale);
            }
            return cellData;
        },
        _getDataIndex: function (data, item) {
            var flag = 0, _plen;
            for (var d = 0, len = data.length; d < len; d++) {
                for(var key = 0, _plen = this._primaryKeys.length; key < _plen; key++) {
                 if (data[d][this._primaryKeys[key]] != item[this._primaryKeys[key]])
                     continue;                                  
                 else if(key == _plen-1)
                     flag = 1;
              }
               if(flag) return d;      
            }
            return -1;
        },
        _eventBindings: function () {
            var rowLength = this.model.frozenColumns > 0 ? this._gridRows[0].length : this._gridRows.length;
            var trIndex=0;
			var prev;
			var pageSize = this.model.pageSettings.pageSize;
			if (ej.gridFeatures.common)
                this._refreshUnboundTemplate(this.getContentTable());
            if (this._gridRecordsCount != 0) {
                if (this.model.queryCellInfo != null || this.model.rowDataBound != null || this.model.mergeCellInfo != null) {
                    for (var row = 0; row < rowLength; row++){
						trIndex = row; 
						if(this.model.scrollSettings.allowVirtualScrolling && row < pageSize)
						{
							for(var i=0;i<this.model.query.queries.length;i++)
								prev = this.model.query.queries[i].fn == "onPage" && this.model.query.queries[i].e.pageIndex - 1;
							var value = pageSize * prev;
							if(value != 0)
								trIndex = this.getContentTable().find("tr[name="+value+"]").eq(row).index();
						}
						if(this.getRowByIndex(trIndex).hasClass("e-virtualrow") || ej.isNullOrUndefined(this._currentJsonData[row]))
							break;	
						this._rowEventTrigger(this.getRowByIndex(trIndex), this._currentJsonData[row]);
					}
				}
            }
        },
        _rowEventTrigger: function (row, data) {
            var args = { row: row, data: data };
            this._trigger("rowDataBound", args);
            var tdCells = row.cells;
            var $tdRowcells = $(row).find(".e-rowcell");
            for (var cellIndex = 0; cellIndex < $tdRowcells.length; cellIndex++) {
                var args = { cell: $tdRowcells[cellIndex], data: data, text: $tdRowcells[cellIndex].innerHTML };
                var foreignKeyData = this._getForeignKeyData(args.Data);
                if ($($tdRowcells[cellIndex]).hasClass("e-rowcell"))
                    args.column = this.model.columns[cellIndex];
                if (!ej.isNullOrUndefined(foreignKeyData))
                    args.foreignKeyData = foreignKeyData;
				if (this.model.allowCellMerging == true) {
                    this._cellMerging(args);
                    this._trigger("mergeCellInfo", args);
                }
                this._trigger("queryCellInfo", args);
            }

        },
        formatting: function (formatstring, str,locale) {
            formatstring = formatstring.replace(/%280/g, "\"").replace(/&lt;/g, "<").replace(/&gt;/g, ">");
            locale = Globalize.cultures[locale] ? locale : "en-US";
            var s = formatstring;
            var frontHtmlidx, FrontHtml, RearHtml, lastidxval;
            frontHtmlidx = formatstring.split("{0:");
            lastidxval = formatstring.split("}");
            FrontHtml = frontHtmlidx[0];
            RearHtml = lastidxval[1];
            if (typeof (str) == "string" && $.isNumeric(str))
                str = Number(str);
            if (formatstring.indexOf("{0:") != -1) {
                var toformat = new RegExp("\\{0(:([^\\}]+))?\\}", "gm");
                var formatVal = toformat.exec(formatstring);
                if (formatVal != null && str != null) {
                    if (FrontHtml != null && RearHtml != null)
                        str = FrontHtml + Globalize.format(str, formatVal[2],locale) + RearHtml;
                    else
                        str = Globalize.format(str, formatVal[2],locale);
                } else if (str != null)
                    str = str;
                else
                    str = "";
                return str;
            } else if (this.data != null && this.data.Value == null) {
                $.each(this.data, function (dataIndex, dataValue) {
                    s = s.replace(new RegExp('\\{' + dataIndex + '\\}', 'gm'), dataValue);
                });
                return s;
            } else {
                return this.data.Value;
            }
        },
        
        setWidthToColumns: function () {
            var $cols1 = this.getContentTable().children("colgroup").find("col");
            var $cols2 = this.getHeaderTable().children("colgroup").find("col");
            var width = this.element.width(), frozenWidth = 0, columnsTotalWidth = 0;
            if (this.model.groupSettings.groupedColumns.length && !this.model.allowScrolling && this.model.groupSettings.showGroupedColumn) {
                var browserDetails = this.getBrowserDetails();
                if (browserDetails.browser == "msie" && parseInt(browserDetails.version, 10) > 8)
                    $cols1.first().css("width", ((30 / width) * 100) + "%");
            }
            if (!ej.isNullOrUndefined(this.model.detailsTemplate)) {
                var headerIndx = this.model.groupSettings.groupedColumns.length;
                var contentIndx = this.model.groupSettings.groupedColumns.length != 0 ? 1 : 0;
                $cols1.eq(contentIndx).css("width", this._detailsOuterWidth);
                $cols2.eq(headerIndx).css("width", this._detailsOuterWidth);
            }
            this._detailColsRefresh();
            $cols1 = this._$headerCols;
            $cols2 = this._$contentCols;

            for (var i = 0; i < $cols2.length; i++) {
                if (this.model.allowResizeToFit && this.model.columns[i]["width"] === undefined) {
                    hCellIndex = this.model.groupSettings.groupedColumns.length ? (i + this.model.groupSettings.groupedColumns.length) : i;
                    var contentWidth = this._resizer._getContentWidth(i);
                    var headerWidth = this._resizer._getHeaderContentWidth(this.getHeaderTable().find('.e-headercelldiv').eq(hCellIndex));
                    var finalWidth = contentWidth > headerWidth ? contentWidth : headerWidth;
                    finalWidth = finalWidth + (finalWidth * 0.2);
                    this._columnsWidthCollection[i] = finalWidth;
                    columnsTotalWidth = columnsTotalWidth + finalWidth;
                }
                if (!ej.isNullOrUndefined(this._columnsWidthCollection[i])) {
                    $cols1.eq(i).width(this._columnsWidthCollection[i]);
                    $cols2.eq(i).width(this._columnsWidthCollection[i]);
                } else if (this.model.allowScrolling) {
                    var colWidth = (width / this.model.columns.length).toFixed(2), bSize = this.model.scrollSettings.buttonSize || 18, cWidth = colWidth - (width / bSize);
                    $cols1.eq(i).css("width", cWidth + "px");
                    $cols2.eq(i).css("width", cWidth + "px");
                    this._columnsWidthCollection[i] = parseFloat(cWidth);
                }
            }
			if (columnsTotalWidth > width && this.model.allowResizeToFit) {
                this.model.allowScrolling =true;
                this.model.scrollSettings.width = width;
                this.getHeaderTable().parent().addClass("e-headercontent");
				this.getHeaderTable().width(width);
            }
            if (this.model.isEdit) {
                var clonedCol = $cols1.clone(), $colGroup = this.model.scrollSettings.frozenColumns > 0 ? this.getContent().find(".gridform").find("colgroup") : $("#" + this._id + "EditForm").find("colgroup");
                this.model.scrollSettings.frozenColumns > 0 && $colGroup.first().empty().append(clonedCol.splice(0, this.model.scrollSettings.frozenColumns));
                $colGroup.last().empty().append(clonedCol);
                if(this.model.detailsTemplate != null||this.model.childGrid !=null)
                $colGroup.prepend(this._getIndentCol());
            }
            if (this.model.groupSettings.groupedColumns.length) {
                var $grouedColGroup = this.getContentTable().find(".e-recordtable").children("colgroup");
                for (var i = 0; i < $grouedColGroup.length; i++) {
                    var clonedCol = $cols1.clone();
                    var detailsWidth = this._detailsOuterWidth != null ? this._detailsOuterWidth : "30px";
                    if (this.model.detailsTemplate != null || this.model.childGrid != null) clonedCol.splice(0, 0, $(this._getIndentCol()).width(detailsWidth)[0]);
                    $grouedColGroup.eq(i).empty().append(clonedCol);
                }
            }
            if (this.model.scrollSettings.frozenColumns > 0) {
                var totalWidth = 0, frozenWidth;
                for (var i = 0; i < this._columnsWidthCollection.length; i++) {
                    totalWidth += this._columnsWidthCollection[i];
                    if (this.model.scrollSettings.frozenColumns - 1 == i)
                        frozenWidth = Math.ceil(totalWidth);
                }
                this.getContent().find(".e-frozencontentdiv").outerWidth(frozenWidth)
                    .end().find(".e-movablecontentdiv").outerWidth(totalWidth - frozenWidth);
                this.getHeaderContent().find(".e-frozenheaderdiv").outerWidth(frozenWidth)
                    .end().find(".e-movableheaderdiv").outerWidth(totalWidth - frozenWidth);
            }
        },
        _initialEndRendering: function () {
            // use this method to add behaviour after grid render.
            if (this.model.editSettings.allowEditing || this.model.editSettings.allowAdding) {
                if (this.model.editSettings.editMode == "dialog" || this.model.editSettings.editMode == "dialogtemplate")
                    this.element.append(this._renderDialog());
                else if (this.model.editSettings.editMode == "externalform" || this.model.editSettings.editMode == "externalformtemplate")
                    this.element.append(this._renderExternalForm());
            }
            if (this._selectedRow() != -1)
                this.selectRows(this._selectedRow());
            (this.model.editSettings.editMode == "batch" || this.model.editSettings.showDeleteConfirmDialog) && this._renderConfirmDialog();
            this.model.scrollSettings.frozenColumns > 0 && this._renderAlertDialog();
            if (this.model.allowMultiSorting || this.model.selectionType == "mulitple")
                this._renderMultiTouchDialog();
            if (this.model.scrollSettings.frozenColumns > 0 && !this.model.allowScrolling) {
                this.getContent().remove();
                this.getHeaderTable().eq(1).remove();
                this._alertDialog.find(".e-content").text(this._getLocalizedLabels("FrozenColumnsScrollAlert"));
                this._alertDialog.ejDialog("open");
                return;
            }
            this.model.scrollSettings.allowVirtualScrolling && this._createPagerStatusBar();
            this._getRowHeights();
            this.model.allowScrolling && this._renderScroller();
            this._addMedia();
            if (this.model.scrollSettings.allowVirtualScrolling) {
                this._refreshVirtualContent();
				this.getContent().first().ejScroller("refresh");
                if (this.getContent().ejScroller("isVScroll")){
                    this.element.find(".e-gridheader").addClass("e-scrollcss");
                    this.getHeaderTable().first().width(this.getContentTable().width());
                }
                else
                    this.element.find(".e-gridheader").removeClass("e-scrollcss");
            }
            if (this.model.allowFiltering && this.model.filterSettings.filterType == "filterbar" && !this.model.allowPaging && !this.model.scrollSettings.allowVirtualScrolling)
                this._createPagerStatusBar();
            if (ej.gridFeatures.common)
                this.rowHeightRefresh()
            if (ej.gridFeatures.filter && ["menu", "excel"].indexOf(this.model.filterSettings.filterType) != -1)
                this._refreshFilterIcon();
        },
        _addMedia: function () {
			if(this.model.allowScrolling)
				this.model._scrollWidth = this.model.scrollSettings.width;
            if (this.model.minWidth && !this.model.enableResponsiveRow) {
                this._$onresize = $.proxy(this._windowonresize, this);
                $(window).bind("resize", this._$onresize);
                if ($.isFunction(window.matchMedia)){
                    var mediaFilterObj = window.matchMedia("(max-width: 768px)");
                    this._mediaStatus = mediaFilterObj.matches;
                }
                this._windowonresize();
            }
        },
        _mediaQueryUpdate: function (addScroller) {
            if (addScroller) {
                if (this.model.minWidth && !this.element.hasClass("e-responsive") && !this._scrollerAddedOnMedia) {
                    this.getContentTable().css("min-width", this.model.minWidth);
                    this.getHeaderTable().css("min-width", this.model.minWidth);
                    this.model.allowScrolling = true;
                    this._mediaQuery = true;
                    this.model.scrollSettings.width = this.getContent().width();
                    this.element.find(".e-gridheader").first().find("div").first().addClass("e-headercontent");
                    this._renderScroller();
                    this._mediaQuery = false;
                    this._scrollerAddedOnMedia = true;
                }
                this.getContent().ejScroller({ width: this.getHeaderContent().outerWidth(), height: this.model.scrollSettings.height });
            } else if (this._scrollerAddedOnMedia) {
                if (this.getHeaderContent().hasClass("e-scrollcss")) {
                    this.getHeaderContent().removeClass("e-scrollcss");
                    this.getHeaderContent().find(".e-headercontent").first().removeClass("e-headercontent");
                }
                if (this.getContent().data("ejScroller"))
                    this.getContent().ejScroller("destroy");
                this.getContentTable().css("min-width", "");
                this.getHeaderTable().css("min-width", "");
                this._scrollerAddedOnMedia = false;
            }
        },
        _windowonresize: function () {
			var $width = $(window).width()<= this.model._scrollWidth || ej.isNullOrUndefined(this.model._scrollWidth) ? "auto" : this.model._scrollWidth;
            this.element.css("width",$width);
			this.getHeaderContent().css("width",$width);
			this.getContent().css("width",$width);
            this._mediaQueryUpdate(this.getContent().width() < this.getContent().find('table').width());
        },
        _removeMedia: function () {
            $(window).unbind("resize", this._$onresize);
            this.getContentTable().css("min-width", "");
            this.getHeaderTable().css("min-width", "");
            this.model.scrollSettings.width = "auto";
            if (this.getContent().data("ejScroller"))
                this.getContent().ejScroller("destroy");
        },
        _getRowHeights: function () {
            var trs = this.getRows();
            if (trs !== null) {
                this._rowHeightCollection = [];
                if ((this.model.scrollSettings.frozenColumns > 0 && trs[0] !== undefined && trs[1] !== undefined) || (typeof trs[0].item !== "undefined" && typeof trs[0].length == "number" && typeof trs[1].item !== "undefined" && typeof trs[1].length == "number")) {
                    frotrs = trs[0];
                    movtrs = trs[1];
                    for (var i = 0 ; i < frotrs.length ; i++) {
                        this._rowHeightCollection[i] = frotrs[i].offsetTop >= movtrs[i].offsetTop ? frotrs[i].offsetTop : movtrs[i].offsetTop;
                    }
                }
                else {
                    for (var i = 0 ; i < trs.length ; i++) {
                        this._rowHeightCollection[i] = trs[i].offsetTop;
                    }
                }
            }
            return this._rowHeightCollection;
        },
        _getEmptyTbody: function () {
            var $emptyTd = ej.buildTag('td.emptyrecord', this._getLocalizedLabels("EmptyRecord"), {}, { colSpan: this.model.columns.length });
            return $(document.createElement("tr")).append($emptyTd);
        },
        _getIndentCol: function () {
            return ej.buildTag("col", "", { width: "30px" });
        },
        _createSortElement: function () {
            return ej.buildTag('span.e-icon', "&nbsp;");
        },
        _createSortNumber: function (number, header) {
            if (header.css("text-align") == "right")
                return ej.buildTag('span.e-number', number, { "color": "white", "font-size": "9px", "float": "left" });
            else
                return ej.buildTag('span.e-number', number, { "color": "white", "font-size": "9px", "float": "right" });
        },
        _wireEvents: function () {
            this._on(this.element, ($.isFunction($.fn.tap) && this.model.enableTouch) ? "tap" : "click", this._clickHandler);
            this._on(this.element, ($.isFunction($.fn.tap) && this.model.enableTouch) ? "tap" : "click", ".e-gridheader", this._mouseClickHandler);
            if (ej.gridFeatures.common) {
                this._on(this.element, "dblclick", ".e-gridcontent", this._recorddblClickHandler);
                if (this.model.rightClick)
                    this._on(this.element, "contextmenu", this._rightClickHandler);
                this._on(this.element, "click", ".e-gridcontent", this._recordClick);
                this._enableRowHover();
                if (this.model.enableTouch)
                    this._on(this.element, "swipeleft swiperight", ".e-gridcontent .e-table", $.proxy(this._touchGrid, this));
                else
                    this.element.addClass("e-touch");
                this._on(this.element, "mousedown", ".e-gridheader", this._headerMouseDown);
                this._on(this.element, "mouseover mouseleave", ".e-gridheader", this._headerHover);
                this._on(this.element, ej.eventType.mouseMove, ".e-gridheader", this._headerHover);
                this.model.allowResizeToFit && this._on(this.element, "dblclick", ".e-gridheader", this._headerdblClickHandler);
                if (this.model.allowResizing) {
                    this._on(this.element, ej.eventType.mouseMove, this._mouseMove);
                    this._on(this.element, "mouseup", this._mouseUp);
                }
				if (this.model.allowKeyboardNavigation) {
					this.element[0].tabIndex = 0;
					this.element[0].accessKey = "e";
					this._on(this.element, "keyup", this._keyDownHandler);
                }
            }
            if (ej.gridFeatures.edit) {
                this._enableEditingEvents();
                this._on(this.element, "click", ".e-gridcontent .e-unboundcelldiv", this._unboundClickHandler);
            }
            if (this.model.allowGrouping) {
                this._enableGroupingEvents();
                this._on(this.element, "mouseenter mouseleave", ".e-groupdroparea,.e-groupheadercell", this._dropAreaHover);
               
            }
            if (!this.model.editSettings.allowEditing)
                this._on(this.element, "dblclick", ".e-gridcontent", this._recorddblClickHandler);
            this._enableFilterEvents();
        },
        _enableFilterEvents: function () {
            if (this.model.allowMultiSorting || this.model.selectionType == "multiple" || this.model.allowFiltering)
                this._on($(document), "click", this._docClickHandler);
            if (this.model.allowFiltering) {
                var proxy = this, $target;
                this._off(this.element, "keyup", ".e-filterbar input")._on(this.element, "keyup", ".e-filterbar input", this._filterBarHandler);
                this._on(this.element, "focus click", ".e-filterbar", this._filterBarClose);
            }
        },
        _docClickHandler: function (e) {
            var details = this.getBrowserDetails();
            if (this._customPop != null && this.element.find(e.target).length == 0)
                this._customPop.hide();
            if (this.model.allowFiltering) {
                if (this.model.filterSettings.filterType == "menu" || this.model.filterSettings.filterType == "excel") {
                    if (this._$colType && ($(e.target).find(".e-grid.e-dlgcontainer").length > 1 || $(e.target).find(".e-excelfilter").length > 1))
                        if (details.browser == "msie")
                            e.target.tagName != "BODY" && (!this.isExcelFilter ? this._closeFilterDlg() : this._excelFilter.closeXFDialog(e));
                        else
                            !this._isExcelFilter ? this._closeFilterDlg() : this._excelFilter.closeXFDialog(e);
                } else if (!$(e.target).hasClass("e-filtertext"))
                    this.getFilterBar().find(".e-cancel").addClass("e-hide");
            }

        },
        _mouseClickHandler: function (e) {
            var $temp = $(e.target), $target;
            if (this.getHeaderTable().find('.e-columnheader').not('.e-stackedHeaderRow').css('cursor') == "col-resize")
                return;
           if ($temp.hasClass("e-headercelldiv"))
					$target = this.getHeaderTable().find(".e-headercelldiv[ej-mappingname='" + $.trim($($temp.parent()).text()).replace(/\s/g, "") + "']");
				else if ($(e.target).is(".e-ascending, .e-descending"))
					$target = $(e.target.parentNode);
				else
                    $target = $(e.target);
            if (this._$fDlgIsOpen && this.model.allowFiltering && (this.model.filterSettings.filterType == "menu" || this._isExcelFilter)) {
                $.fx.off = true;
                if (this._isExcelFilter)
                    this._excelFilter.closeXFDialog();
                else if ($("#" + this._id + "_" + this._$prevColType + "Dlg").data("ejDialog") != undefined)
                    $("#" + this._id + "_" + this._$prevColType + "Dlg").ejDialog("close");
                $.fx.off = false;
            }
            this.getHeaderTable().find(".e-columnheader").find(".e-headercellactive").removeClass("e-headercellactive").removeClass("e-active");
            if ($target.hasClass("e-headercelldiv") || (!$target.hasClass("e-togglegroupbutton") && $target.closest(".e-headercelldiv").length && $.inArray($target[0].tagName, ["SELECT", "INPUT", "TEXTAREA"]) == -1)) {
                if (!this.model.allowSorting || ej.gridFeatures.sort === undefined)
                    return;
                $target = $target.hasClass("e-headercelldiv") ? $target : $target.closest(".e-headercelldiv");
                var columnName = $target.attr("ej-mappingname");
                var columnSortDirection = ej.sortOrder.Ascending;
                this._$prevSElementTarget = this._$curSElementTarget;
                this._$curSElementTarget = $target;
                if ($target.find('span').hasClass("e-ascending"))
                    var columnSortDirection = ej.sortOrder.Descending;
                else
                    var columnSortDirection = ej.sortOrder.Ascending;
                if (e["pointerType"] == "touch" && this._customPop != null && !this._customPop.is(":visible") && this._customPop.find(".e-sortdirect").hasClass("e-spanclicked"))
                    this._customPop.show();
                if (e["pointerType"] == "touch" && this._customPop != null && (this._customPop.find(".e-rowselect").is(":visible") || !this._customPop.find(".e-sortdirect").hasClass("e-spanclicked")) && this.model.allowMultiSorting) {
                    var $offset = $target.offset();
                    this._customPop.removeAttr("style");
                    this._customPop.offset({ left: $offset.left, top: $offset.top - this.getHeaderTable().find(".e-columnheader").height() }).find(".e-sortdirect").show().end()
                        .find(".e-rowselect").hide().end().show();
                }
                if (this.model.allowMultiSorting && (e.ctrlKey || this._enableSortMultiTouch))
                    this.multiSortRequest = true;
                if (e.shiftKey && $.inArray(columnName, this.model.groupSettings.groupedColumns) == -1) {
                    this._removeSortedColumnFromCollection(columnName);
                    this.multiSortRequest = true;
                    columnName = null;
                }
                if (!ej.isNullOrUndefined(columnName))
                this.sortColumn(columnName, columnSortDirection);
            } else if ($target.hasClass("e-togglegroupbutton") && this.model.allowGrouping) {
                var field = $target.parent().attr("ej-mappingname");
                $target.hasClass("e-togglegroup") && this.groupColumn(field);
                $target.hasClass("e-toggleungroup") && this.ungroupColumn(field);
            } else if ($target.hasClass("e-filtericon") || $target.hasClass("e-filteredicon") || $target.hasClass('e-responsivefilterColDiv') || $target.parent().hasClass('e-responsivefilterColDiv')) {
                var columnName = $target.parent().find(".e-headercelldiv").attr("ej-mappingname") || $target.attr("ej-mappingname") || $($target.parent()).attr("ej-mappingname");
                this._$prevFieldName = this._$curFieldName;
                if (this.model.allowFiltering) {
                    var proxy = this;
                    $.each(this.model.columns, function (indx, col) {
                        if (col.field == columnName) {
                            proxy._$colType = col.type;
                            proxy._$curFieldName = col.field;
                            proxy._$colFormat = col.format;
                            proxy._$colForeignKeyField = col.foreignKeyField ? col.foreignKeyField : col.field;
                            proxy._$colForeignKeyValue = col.foreignKeyValue;
                            proxy._$colDropdownData = col.dataSource;
                        }
                    });
                    if (!this._isExcelFilter) {
                        var $id = "#" + this._id + "_" + this._$colType + "Dlg";
                        if (this._$colType == "string") {
                            if (this._$colForeignKeyValue && this._$colDropdownData)
                                $("#" + this._id + "_acString").ejAutocomplete({ fields: { text: proxy._$colForeignKeyValue, key: proxy._$colForeignKeyField }, dataSource: proxy._$colDropdownData });
                            else
                                $("#" + this._id + "_acString").ejAutocomplete({ fields: { text: proxy._$curFieldName, key: this._getIdField() }, dataSource: this._dataSource() });
                        } else if (this._$colType == "date") {
                            if (this._$colFormat != undefined) {
                                this._$colFormat = this._$colFormat.replace("{0:", "").replace("}", "");
                                $($id).find(".e-datewidget input").ejDatePicker({ dateFormat: this._$colFormat.replace("{0:", "").replace("}", "") });
                            }
                            else
                                $($id).find(".e-datewidget input").ejDatePicker({ dateFormat: "MM/dd/yyyy" });
                        }
                        else if (this._$colType == "datetime") {
                            if (this._$colFormat != undefined) {
                                this._$colFormat = this._$colFormat.replace("{0:", "").replace("}", "");
                                $($id).find(".e-datetimewidget input").ejDateTimePicker({ dateFormat: this._$colFormat.replace("{0:", "").replace("}", "") });
                            }
                            this._setFilterFieldValues($id);
                        }
                    }
                    this._mediaStatus = document.documentElement.clientWidth < 768;
                    if (this.model.isResponsive && this._mediaStatus) {
                        var gridObj = this;
                        var $headerDiv = ej.buildTag('div.e-resFilterDialogHeaderDiv');
                        var $titleSapn = ej.buildTag('div.labelRes', '<span>Filter</span>');
                        var $dlgBtn = ej.buildTag('div.e-filterMenuBtn');
                        var $inputOk = ej.buildTag('input.e-resposnsiveFilterBtnLeft');
                        var $inputCancel = ej.buildTag('input.e-resposnsiveFilterBtnRight');

                        $headerDiv.append($titleSapn);
                        $headerDiv.css('width', '100%');
                        var $dlgClone = $($id).css('padding-left', '0px');
                        if ($target.parent().hasClass('e-responsivefilterColDiv') && $target.hasClass('e-filternone')) {
                            proxy._fltrClrHandler();
                            $target.remove();
                            $("#responsiveFilter").css('display', 'block');
                            // this.element.css('display', 'block');
                        }
                        else {
                            this.element.css('display', 'none');
                            setTimeout(function () { $("#responsiveFilter").css('display', 'none'), 0 });
                            if (!this._isExcelFilter) {
                                var btnText = this.model.enableResponsiveRow ? 'OK' : 'Filter', clearText = this.model.enableResponsiveRow ? 'Cancel' : 'Clear';
                                $inputOk.ejButton({ text: btnText, type: 'button', click: $.proxy(this._fltrBtnHandler, this) });
                                $inputCancel.ejButton({
                                    text: clearText,type:'button', click: function () {
                                        if (clearText == 'Clear') {
                                            proxy.element.css('display', 'block');
                                            proxy._fltrClrHandler();
                                        }
                                        $($id).css('display', 'none');
										if($inputCancel.hasClass("e-resposnsiveFilterBtnRight"))
											proxy.element.css('display', 'block');
                                    }
                                });
                                if ($target.parent().hasClass('e-responsivefilterColDiv') && $target.hasClass('e-filternone')) {
                                    proxy._fltrClrHandler();
                                    $target.remove();
                                }
                                else {
                                    $dlgClone.addClass('e-resMenuFltr');
                                    $dlgClone.css('height', $(window).height() - 1).css('width', $(window).width() - 2);
                                    $dlgClone.find('.e-operator').addClass('e-resFilterOperator');
                                    $dlgClone.find('.e-value').addClass('e-resFilterOperator');
                                    var $btnContainer = $dlgClone.find('.e-dlgBtns').remove().addClass('e-filterMenuBtn');
                                    $dlgClone.append($dlgBtn.append($inputOk).append($inputCancel));
                                    if (ej.isNullOrUndefined($dlgClone.find('.e-resFilterDialogHeaderDiv')[0])) {
                                        $dlgClone.insertAfter(this.element);
                                        var $backIcon = ej.buildTag('div.e-resFilterleftIcon', '', {}, { closeDialogue: $id.slice(1), openDialogue: 'responsiveFilter' });
                                        var $spanIcon = ej.buildTag('span.e-icon e-resIcon e-responisveBack', '', {}, { closeDialogue: $id.slice(1), openDialogue: 'responsiveFilter' })
                                        $backIcon.click(function (e) {
                                           $dlgClone.css('display','none');
                                            if (gridObj.model.enableResponsiveRow)
                                               $("#responsiveFilter").css('display','block');
                                            else
                                               gridObj.element.css('display','block');
                                        })
                                        $headerDiv.append($backIcon.append($spanIcon));
                                        var $closeIcon = ej.buildTag('div.e-resFIlterRigthIcon', '', {}, { closeDialogue: $id.slice(1), gridEle: true });
                                        var $closeSpan = ej.buildTag('span.e-icon e-resIcon e-responisveClose', '', {}, { closeDialogue: $id.slice(1), gridEle: true })
                                        $closeIcon.click(function (e) {
                                            $dlgClone.css('display', 'none');
                                            gridObj.element.css('display', 'block');
                                        });
                                        var $ejWid = $($dlgClone.find('.e-value').find('input:last'));
                                        if (proxy._$colType == 'string') {
                                            var model = $($dlgClone.find('.e-value').find('input:last')).ejAutocomplete('model');
                                            $ejWid.ejAutocomplete('destroy').ejAutocomplete({enableDistinct:true, dataSource: model.dataSource, fields: model.fields, width: model.width, focusIn: function (args) { 
												var $dropdown = this.element.closest(".e-filterDialoge").find(".e-dropdownlist");
												this.model.filterType = $dropdown.val();
											}});
                                        }
                                        $headerDiv.append($closeIcon.append($closeSpan));
                                        $dlgClone.prepend($headerDiv);
                                    }
                                    $dlgClone.find('.e-responsiveLabelDiv').remove();
                                    var $label = ej.buildTag('div.e-responsiveLabelDiv', '', { 'margin-left': '5%', 'font-size': '17px', 'margin-top': '5%' }).append(ej.buildTag('span', this.getHeaderTextByFieldName(columnName), { 'font-weight': 'bold' }));
                                    $label.insertAfter($dlgClone.find('.e-resFilterDialogHeaderDiv'));
                                    $dlgClone.fadeIn(100, "easeOutQuad", function () {
                                    });
                                }
                            }
                            else {
                                this._excelDlg = $id = "#" + this._id + this._$colType + "_excelDlg";
                                if (ej.isNullOrUndefined($dlgClone.find('.e-resFilterDialogHeaderDiv')[0])) {
                                    $inputOk.ejButton({
                                        text: 'OK', type: 'button', click: function (sender) {
                                            gridObj._excelFilter._openedFltr = $(gridObj._excelDlg);
                                            gridObj._excelFilter._fltrBtnHandler();
                                            gridObj._setResponsiveFilterIcon();
                                            gridObj.element.css('display', 'block');
                                        }
                                    });
                                    $inputCancel.ejButton({ text: 'Cancel', type: 'button', click: function () { $($id).css('display', 'none'); proxy.element.css('display', 'block') } });
                                    $($id).children().not('.e-searchcontainer').remove();
                                    var excelObj = this._excelFilter;
                                    var $backIcon = ej.buildTag('div.e-resFilterleftIcon', '', {}, { closeDialogue: $id.slice(1), openDialogue: 'responsiveFilter' });
                                    var $spanIcon = ej.buildTag('span.e-icon e-resIcon e-responisveBack', '', {}, { closeDialogue: $id.slice(1), openDialogue: 'responsiveFilter' })
                                    $backIcon.click(function (e) {
                                        $.proxy(gridObj._closeDivIcon(e), this);
                                    })
                                    $headerDiv.append($backIcon.append($spanIcon));
                                    var $closeIcon = ej.buildTag('div.e-resFIlterRigthIcon', '', {}, { closeDialogue: $id.slice(1), gridEle: true });
                                    var $closeSpan = ej.buildTag('span.e-icon e-resIcon e-responisveCustomFilter', '', {}, { closeDialogue: $id.slice(1), gridEle: true })
                                    $closeIcon.click(function (e) {
                                        $.proxy(gridObj._closeDivIcon(e), this);
                                    })
                                    if (proxy._$colType != 'boolean')
                                        $headerDiv.append($closeIcon.append($closeSpan));
                                    $($id).css('padding', '0px');
                                    var $searchContainer = $($id).css('height', $(window).height() - 2);
                                    $searchContainer.css('width', $(window).width() - 2);
                                    var $searchBox = $searchContainer.find('.e-searchcontainer .e-searchbox').css('margin-top', '10px');
                                    $searchBox.children().css('margin-top', '10px');
                                    var $checkBoxDiv = $searchContainer.find('.e-checkboxlist');
                                    var scrolWidth = $(window).width() * (97 / 100), scrollHeight = $(window).height() * (65 / 100);
                                    $($searchContainer.find('.e-searchcontainer')).addClass('e-resSearch');
                                    var $btn = $searchContainer.find('.e-resSearch .e-btncontainer').remove();
                                    $btn.find('input:first').css('width', '45.6%');
                                    $btn.find('input:first').addClass('e-resposnsiveFilterBtnLeft');
                                    $btn.find('input:last').addClass('e-resposnsiveFilterBtnRight');
                                    $searchContainer.find('.e-excelLabel').remove();
                                    var $labelDiv = ej.buildTag('div.e-excelLabel', 'Order Id', { 'font-weight': 'bold', 'margin-top': '10px' });
                                    var $searchBox = $searchContainer.find('.e-searchcontainer');
                                    $labelDiv.insertAfter($searchContainer.find('.e-searchcontainer .e-searchbox'));
                                    $searchContainer.prepend($headerDiv);
                                    $($id).append($dlgBtn.append($inputOk).append($inputCancel))
                                    $checkBoxDiv.ejScroller({ height: scrollHeight, width: scrolWidth }).ejScroller('refresh');
                                }
                                this._excelFilter.openXFDialog({ field: columnName, enableResponsiveRow: true, displayName: this.getHeaderTextByFieldName(columnName), dataSource: this._dataSource(), position: { X: xPos, Y: yPos }, dimension: { height: $(window).height(), width: $(window).width() }, cssClass: "resFilter", type: this._$colType, format: this._$colFormat });
                                $($id).insertAfter(this.element);
                                !ej.isNullOrUndefined($($id).parents('.e-grid')[0]) && $($id).remove();
                                $closeIcon.click(function (e) {
                                    $(gridObj._excelDlg).css('display', 'none');
                                    var height = $(window).height() - 5, width = $(window).width();
                                    excelObj._openCustomFilter('equal');
                                    var $dlgClone = $id = $("#" + gridObj._id + gridObj._$colType + "_CustomFDlg").addClass('e-responsviesExcelFilter');
                                    if (ej.isNullOrUndefined($dlgClone.find('.e-resFilterDialogHeaderDiv')[0])) {
                                        var $headerDivCustom = ej.buildTag('div.e-resFilterDialogHeaderDiv');
                                        var $titleSapn = ej.buildTag('div.labelRes', '<span>Custom Filter</span>');
                                        $headerDivCustom.append($titleSapn);
                                        var $backIcon = ej.buildTag('div.e-resFilterleftIcon', '', {}, { closeDialogue: gridObj._id + gridObj._$colType + "_CustomFDlg", openDialogue: gridObj._excelDlg.slice(1) });
                                        var $spanIcon = ej.buildTag('span.e-icon e-resIcon e-responisveBack', '', {}, { closeDialogue: gridObj._id + gridObj._$colType + "_CustomFDlg", openDialogue: gridObj._excelDlg.slice(1) })
                                        $backIcon.click(function (e) {
                                            $dlgClone.css('display','none');
                                            if (gridObj.model.enableResponsiveRow)
                                               $("#responsiveFilter").css('display','block');
                                            else
                                                gridObj.element.css('display','block');
                                        });
                                        $headerDivCustom.append($backIcon.append($spanIcon));
                                        var $closeIconCust = ej.buildTag('div.e-resFIlterRigthIcon', '', {}, { closeDialogue: gridObj._id + gridObj._$colType + "_CustomFDlg", gridEle: true });
                                        var $closeSpan = ej.buildTag('span.e-icon e-resIcon e-responisveClose', '', {}, { closeDialogue: gridObj._id + gridObj._$colType + "_CustomFDlg", gridEle: true })
                                        $headerDivCustom.append($closeIconCust.append($closeSpan));
                                        $closeIconCust.click(function (e) {
                                            $dlgClone.css('display', 'none');
                                            gridObj.element.css('display', 'block');
                                        })
                                        $dlgClone.prepend($headerDivCustom);
                                        $dlgClone.insertAfter(gridObj.element);
                                        $dlgClone.find('.e-dlgfields').css('width', '100%');
                                        var $firstDiv = $dlgClone.find('.e-dlgfields:first').css('width', '92%').css('margin-left', '6%');
                                        $firstDiv.css('margin-top', '4%');
                                        var colName = $dlgClone.find('.e-dlgfields').find('.e-fieldset legend').text();
                                        var $labelDiv = ej.buildTag('div.e-responsiveLabelDiv', colName, { 'margin-left': '6%' });
                                        $labelDiv.insertAfter($firstDiv);
                                        var $fieldSet = $dlgClone.find('.e-dlgfields').find('.e-fieldset').find('table').css('width', '61%');
                                        $dlgClone.find('.e-dlgfields').find('.e-fieldset').replaceWith($fieldSet);
                                        var $fieldDiv = $fieldSet.parent('div').addClass('e-responsiveExcelFilterFieldDiv');
                                        var $ddl = $fieldSet.find('.e-dropdownlist')
                                        $fieldSet.find('.e-dropdownlist').each(function (index, object) {
                                            var ds = $(object).ejDropDownList('model.dataSource');
                                            var wid = $(window).width() * (40 / 100);
                                            $(object).ejDropDownList('destroy').ejDropDownList({ width: wid, popupWidth: wid + "px", dataSource: ds });
                                        });
                                        $fieldSet.find('.e-autocomplete').each(function (index, object) {
                                            var model = $(object).ejAutocomplete('model.dataSource');
                                            var wid = $(window).width() * (40 / 100);
                                            $(object).ejAutocomplete('destroy').ejAutocomplete({ width: wid, dataSource: model.dataSource, fields: model.fields });
                                        });
                                        $fieldSet.find('.e-datepicker').each(function (index, object) {
                                            var ds = $(object).ejDatePicker('model.dataSource');
                                            var wid = $(window).width() * (40 / 100);
                                            $(object).ejDatePicker('destroy').ejDatePicker({ width: wid });
                                        });
                                        var $okClone = $inputOk.clone(), $cancelClone = $inputCancel.clone();
                                        $okClone.ejButton({
                                            text: 'OK', type: 'button', click: function (sender) {
                                                gridObj._excelFilter._openedFltr = $dlgClone;
                                                gridObj._excelFilter._fltrBtnHandler();
                                                if ($dlgClone.hasClass('e-dlgcustom'))
                                                    $dlgClone.ejDialog('close');
                                                gridObj._setResponsiveFilterIcon();
                                                gridObj.element.css('display', 'block');
                                            }
                                        });
                                        $cancelClone.ejButton({ text: 'Cancel', type: 'button', click: function () { $dlgClone.ejDialog('close'); proxy.element.css('display', 'block') } });
                                        $dlgClone.append($dlgBtn.clone().append($okClone).append($cancelClone))
                                        var $btnContainer = $dlgClone.find('.e-dlgfields .e-btncontainer').remove();
                                        $btnContainer.find('input:first').addClass('e-resposnsiveFilterBtnLeft');
                                        $btnContainer.find('input:first').css('width', '45.6%')
                                        $btnContainer.find('input:last').addClass('e-resposnsiveFilterBtnRight');
                                    }
                                    gridObj.element.css('display', 'none');
                                    $dlgClone.ejDialog({ enableModal: false, height: height, width: width, position: { X: 0, Y: 0 }, enableResize: false, showHeader: false }).ejDialog('open');
                                })
                                var $searchdiv = ej.buildTag('div');
                            }
                        }
                    }
                    else {
                        $($id).ejDialog({ position: { X: "", Y: "" } });
                        var docWidth = $(document).width(), dlgWidth = document.documentElement.clientWidth < 800 ? 130 : 250, xPos = $target.position().left + 18, yPos = $target.position().top + 2;
                        var marginLeft = e.clientX - xPos;
                        if (docWidth - e.clientX <= dlgWidth)
                            xPos = docWidth - dlgWidth - marginLeft;
                        if (!this._isExcelFilter)
                            $($id).ejDialog({ position: { X: xPos, Y: yPos }, width: dlgWidth })
                            .ejDialog("open");
                        else
                            this._excelFilter.openXFDialog({ field: columnName, displayName: this.getHeaderTextByFieldName(columnName), dataSource: this._dataSource(), position: { X: xPos, Y: yPos }, type: this._$colType, format: this._$colFormat });
                    }
                    this._setFilterFieldValues($id);
                    if (this._$colType == "number")
                        $($id).find(".e-numerictextbox").ejNumericTextbox({ width: "100%" });
                    this._$prevColType = this._$colType;
                    this._$fDlgIsOpen = true;
                }
            }

            e.preventDefault();

        },
        _responsiveFilterClose: function () {
            this.element.css('display', 'block');
        },
        _clickHandler: function (e) {
            var $target = $(e.target), fieldName, $form = $("#" + this._id + "EditForm"), index, columnIndex, rowIndex;
            if ($target.hasClass("e-button") && ($target.hasClass("e-disable") || $target.prop("disabled"))) return;
            if ($target.closest(".e-grid").attr("id") !== this._id) return;
            if ($target.closest("#" + this._id + "EditForm").length)
                return;
            if ($target.hasClass("e-rowcell") || $target.closest("td").is(".e-rowcell") || ($target.hasClass("e-headercell") && ((e.clientY - $target.offset().top) < ($target.height() / 4)))) {
                if (this._bulkEditCellDetails.cancelSave) {
                    this._bulkEditCellDetails.cancelSave = false;
                    return;
                }
                if (this.model.editSettings.editMode == "batch" && ($.isFunction($.validator) && $form.length && $form.validate().errorList.length > 0))
                    return;
                this.model.editSettings.editMode == "batch" && this.element.focus();
                index = $target.closest("tr").hasClass("e-insertedrow") ? this.model.groupSettings.groupedColumns.length : 0;
                columnIndex = $target.hasClass("e-rowcell") ? $target.index() : $target.parent().index() - index;
                columnIndex = this.model.detailsTemplate != null||this.model.childGrid !=null ? columnIndex - 1 : columnIndex;
                rowIndex = this.getIndexByRow($target.closest("tr"));
                this._bulkEditCellDetails.columnIndex = columnIndex;
                this._bulkEditCellDetails.rowIndex = rowIndex;
                if (this.model.allowSelection && ej.gridFeatures.selection) {
                    if (this.model.selectionType == "multiple") {
                        if (e.ctrlKey || this._enableSelectMultiTouch) {
                            this.multiSelectCtrlRequest = true;
                        }
                        if (e.shiftKey) {
                            this._multiSelectShiftRequest = true;
                            if (this._allowcellSelection && rowIndex > -1)
                                this.selectCells([[rowIndex, [columnIndex]]]);
                            if (this._allowrowSelection) 
                                    this.selectRows(this._previousIndex, this.getIndexByRow($target.closest('tr')), $target);
                            if (this._allowcolumnSelection && $target.hasClass("e-headercell") && ((e.clientY - $target.offset().top) < ($target.height() / 4)))
                                this.selectColumns(this._previousColumnIndex, $target.index());
                        }
                        if (e["pointerType"] == "touch" && this._customPop != null && !this._customPop.is(":visible") && this._customPop.find(".e-rowselect").hasClass("e-spanclicked"))
                            this._customPop.show();
                        if (e["pointerType"] == "touch" && this._customPop != null && (this._customPop.find(".e-sortdirect").is(":visible") || !this._customPop.find(".e-rowselect").hasClass("e-spanclicked")) && this.model.selectionType == "multiple") {
                            this._customPop.removeAttr("style");
                            var offset = $target.offset();
                            this._customPop.offset({ top: 0, left: 0 }).offset({ left: offset.left, top: offset.top - this.getRowHeight() }).find(".e-sortdirect").hide().end()
                                .find(".e-rowselect").show().end().show();
                        }
                    }
                    if (!this._multiSelectShiftRequest) {
                        if (this._allowcellSelection && rowIndex > -1) {
                            if (this.model.selectionSettings.enableToggle && this.selectedRowCellIndexes.length == 1 &&
                                this.selectedRowCellIndexes[0].rowIndex == rowIndex && this.selectedRowCellIndexes[0].cellIndex.length == 1 &&
                                parseInt(this.selectedRowCellIndexes[0].cellIndex) == columnIndex)
                                this.clearCellSelection();
                            else
                                this.selectCells([[rowIndex, [columnIndex]]]);
                        }
                        if (this._allowrowSelection && rowIndex > -1) {
                            if (this.model.selectionSettings.enableToggle && this.getSelectedRecords().length == 1 && $.inArray(this.getIndexByRow($target.closest('tr')), this.selectedRowsIndexes) != -1)
                                this.clearSelection(this.getIndexByRow($target.closest('tr')));
                            else
                                this.selectRows(this.getIndexByRow($target.closest('tr')), null, $target);
                        }
                        if (this._allowcolumnSelection && $target.hasClass("e-headercell") && ((e.clientY - $target.offset().top) < ($target.height() / 4))) {
                            if (this.model.selectionSettings.enableToggle && this.selectedColumnIndexes.length == 1 && $.inArray($target.index(), this.selectedColumnIndexes) != -1)
                                this.clearColumnSelection($target.index());
                            else
                                this.selectColumns($target.index());
                        }
                        this.multiSelectCtrlRequest = false;
                    }
                    this._multiSelectShiftRequest = false;
                }
				
                fieldName = this.model.columns[this._bulkEditCellDetails.columnIndex]["field"];
                if (fieldName)
                    this.model.editSettings.allowEditing && this.model.editSettings.editMode == ej.Grid.EditMode.Batch && this.editCell($.inArray($target.closest("tr").get(0), this.getRows()), fieldName);
            }
            if ($target.hasClass("e-rowselect") || $target.hasClass("e-sortdirect")) {
                if (!$target.hasClass("e-spanclicked")) {
                    $target.addClass("e-spanclicked");
                    if ($target.hasClass("e-rowselect"))
                        this._enableSelectMultiTouch = true;
                    if ($target.hasClass("e-sortdirect"))
                        this._enableSortMultiTouch = true;
                } else {
                    $target.removeClass("e-spanclicked");
                    if ($target.hasClass("e-rowselect"))
                        this._enableSelectMultiTouch = false;
                    if ($target.hasClass("e-sortdirect"))
                        this._enableSortMultiTouch = false;
                    this._customPop.hide();
                }
            }			
            if (ej.gridFeatures.common) {
                this.expandCollapse($target);
            if (this.model.childGrid && $target.hasClass("e-gdiagonalnext") || $target.hasClass("e-gnextforward"))
                e.stopPropagation();
            }
			if ($target.is(".e-filtericon") && $target.closest(".e-detailrow").length != 0)
                e.stopPropagation();
            if (this.model.allowFiltering && (this.model.filterSettings.filterType == "menu" || this._isExcelFilter) && !$target.is(".e-filtericon") && $target.closest(".e-dlgcontainer").length != 1)
                !this._isExcelFilter ? this._closeFilterDlg() : this._excelFilter.closeXFDialog(e);
        },
        /**
         * Destroy the grid widget
		 * all events bound using this._on will be unbind automatically and bring the control to pre-init state.
		 * @alias ejGrid#destroy
		 * @return jQuery
		 * @example 
		 * &lt;script&gt;
		 * var gridObj = $("#Grid").data("ejGrid");
		 * gridObj.destroy(); // destroy the Grid
		 * &lt;/script&gt;
		 * @example 
		 * &lt;script&gt;
		 * // destroy the Grid
		 * $("#Grid").ejGrid("destroy");        
		 * &lt;/script&gt;
         */
        _destroy: function () {
            /// <summary>This function is  used to destroy the Grid Object</summary>
            this.element.find(".e-gridheader").find(".e-headercontent,.e-movableheader")
                .add(this.getContent().find(".e-content,.e-movablecontent")).unbind('scroll');
            var editForm = $("#" + this._id + "EditForm");
            if (editForm.length) {
                var $formEle = editForm.find('.e-field'), $element;
                for (var i = 0; i < $formEle.length; i++) {
                    $element = $($formEle[i]);
                    if ($element.hasClass('e-datetimepicker'))
                        $element.ejDateTimePicker("destroy");
                    else if ($element.hasClass('e-datepicker'))
                        $element.ejDatePicker("destroy");
                    else if ($element.hasClass('e-dropdownlist'))
                        $element.ejDropDownList("destroy");
                }
                editForm.remove();
            }
            if (this._confirmDialog)
                this._confirmDialog.ejDialog("destroy");
            if (this.model.allowFiltering && this.model.filterSettings.filterType == "menu") {
                var proxy = this, $colType;
                $.each(this.model.columns, function (indx, col) {
                    $colType = col.type;
                    $("#" + proxy._id + $colType + "_ddinput_popup_wrapper").remove();
                    if ($colType == "string")
                        $("#" + proxy._id + "_stringDlg").find('.e-autocomplete').ejAutocomplete("destroy");
                    else if ($colType == "date")
                        $("#" + proxy._id + "_dateDlg").find('.e-datepicker').ejDatePicker("destroy");
                    else if ($colType == "datetime")
                        $("#" + proxy._id + "_datetimeDlg").find('.e-datetimepicker').ejDateTimePicker("destroy");
                    else if ($colType == "number")
                        $("#" + proxy._id + "_numberDlg").find('.e-numerictextbox').ejNumericTextbox("destroy");
                });
            }
            if (this._$onresize)
                $(window).unbind("resize", this._$onresize);
            this.element.empty().removeClass("e-grid " + this.model.cssClass);
            this.element.ejWaitingPopup("destroy");
        },
        _getLocalizedLabels: function (property) {
            return (ej.Grid.locale[this.model.locale] === undefined || ej.Grid.locale[this.model.locale][property] === undefined) ? ej.Grid.locale["en-US"][property] : ej.Grid.locale[this.model.locale][property];
        },
    });
    if (ej.gridFeatures.common)
        $.extend(ej.Grid.prototype, ej.gridFeatures.common);
    if (ej.gridFeatures.edit)
        $.extend(ej.Grid.prototype, ej.gridFeatures.edit);
    if (ej.gridFeatures.filter)
        $.extend(ej.Grid.prototype, ej.gridFeatures.filter);
    if (ej.gridFeatures.group)
        $.extend(ej.Grid.prototype, ej.gridFeatures.group);
    if (ej.gridFeatures.selection)
        $.extend(ej.Grid.prototype, ej.gridFeatures.selection);
    if (ej.gridFeatures.sort)
        $.extend(ej.Grid.prototype, ej.gridFeatures.sort);
    if (ej.gridFeatures.dragAndDrop)
        $.extend(ej.Grid.prototype, ej.gridFeatures.dragAndDrop);

    ej.Grid.locale = {};

    ej.Grid.locale["en-US"] = {
        EmptyRecord: "No records to display",
        GroupDropArea: "Drag a column header here to group its column",
        DeleteOperationAlert: "No records selected for delete operation",
        EditOperationAlert: "No records selected for edit operation",
        SaveButton: "Save",
        OkButton: "OK",
        CancelButton: "Cancel",
        EditFormTitle: "Details of ",
        AddFormTitle: "Add New Record",
        Notactionkeyalert: "This Key-Combination is not avaiable",
        Keyconfigalerttext: "This Key-Combination has already been assigned to ",
        GroupCaptionFormat: "items",
        BatchSaveConfirm: "Are you sure you want to save changes?",
        BatchSaveLostChanges: "Unsaved changes will be lost. Are you sure you want to continue?",
        ConfirmDelete: "Are you sure you want to Delete Record?",
        PagerInfo: "{0} of {1} pages ({2} items)",
        FrozenColumnsViewAlert: "Frozen columns should be in grid view area",
        FrozenColumnsScrollAlert: "Enable allowScrolling while using frozen Columns",
        FrozenNotSupportedException: "Frozen Columns and Rows are not supported for Grouping, Row Template, Detail Template and Batch Editing",
        Add: "Add",
        Edit: "Edit",
        Delete: "Delete",
        Update: "Update",
        Cancel: "Cancel",
        PrintGrid: "Print",
        ExcelExport: "Excel Export",
        WordExport: "Word Export",
        PdfExport: "PDF Export",
        StringMenuOptions: [{ text: "StartsWith", value: "StartsWith" }, { text: "EndsWith", value: "EndsWith" }, { text: "Contains", value: "Contains" }, { text: "Equal", value: "Equal" }, { text: "NotEqual", value: "NotEqual" }],
        NumberMenuOptions: [{ text: "LessThan", value: "LessThan" }, { text: "GreaterThan", value: "GreaterThan" }, { text: "LessThanOrEqual", value: "LessThanOrEqual" }, { text: "GreaterThanOrEqual", value: "GreaterThanOrEqual" }, { text: "Equal", value: "Equal" }, { text: "NotEqual", value: "NotEqual" }],
        PredicateAnd: "AND",
        PredicateOr: "OR",
        Filter: "Filter",
        MatchCase: "Match Case",
        Clear: "Clear",
        ResponsiveFilter: "Filter",
        ResponsiveSorting: "Sort",
        Search: "Search",
        DatePickerWaterMark: "Select date"
    };
    ej.Grid.Actions = {
        /** Used to specify paging action in grid   */
        Paging: "paging",
        /** Used to specify sorting action in grid   */
        Sorting: "sorting",
        /** Used to specify filtering action in grid   */
        Filtering: "filtering",
        /** Used to specify begin edit action in grid   */
        BeginEdit: "beginedit",
        /** Used to specify saving action in grid   */
        Save: "save",
        /** Used to specify adding action in grid   */
        Add: "add",
        /** Used to specify deleting action in grid   */
        Delete: "delete",
        /** Used to specify cancelling action in grid   */
        Cancel: "cancel",
        /** Used to specify grouping action in grid   */
        Grouping: "grouping",
        /** Used to specify un-grouping action in grid   */
        Ungrouping: "ungrouping",
        /** Used to specify refresh action in grid   */
        Refresh: "refresh",
        /** Used to specify reordering action in grid   */
        Reorder: "reorder",
        /** Used to specify searching action in grid   */
        Search: "searching",
        /** Used to specify batch save action in grid   */
        BatchSave: "batchsave",
        /** Used to specify virtual scroll action in grid   */
        VirtualScroll: "virtualscroll"
    };
    /**
     * Enum for various grid summary type	 
     * @enum {string}
     * @global 
     */
    ej.Grid.SummaryType = {
        /**  Creates grid with summary type as Average */
        Average: "average",
        /**  Creates grid with summary type as Minimum */
        Minimum: "minimum",
        /**  Creates grid with summary type as Maximum */
        Maximum: "maximum",
        /**  Creates grid with summary type as Count */
        Count: "count",
        /**  Creates grid with summary type as Sum */
        Sum: "sum",
        /**  Creates grid with summary type as TrueCount */
        TrueCount: "truecount",
        /**  Creates grid with summary type as FalseCount */
        FalseCount: "falsecount",
        /**  Creates grid with summary type as Custom */
        Custom: "custom"
    };
    /**
	 * Enum for specifying edit mode in grid 
	 * @enum {string}
	 * @global 
	 */
    ej.Grid.EditMode = {
        /**  Creates grid with editMode as Normal */
        Normal: "normal",
        /**  Creates grid with editMode as Dialog */
        Dialog: "dialog",
        /**  Creates grid with editMode as DialogTemplate */
        DialogTemplate: "dialogtemplate",
        /**  Creates grid with editMode as Batch */
        Batch: "batch",
        /**  Creates grid with editMode as ExternalForm */
        ExternalForm: "externalform",
        /**  Creates grid with editMode as ExternalFormTemplate */
        ExternalFormTemplate: "externalformtemplate",
        /**  Creates grid with editMode as InlineForm */
        InlineForm: "inlineform",
        /**  Creates grid with editMode as InlineTemplateForm */
        InlineTemplateForm: "inlineformtemplate"
    };

    /**
      * Enum for specifying row position in grid 
      * @enum {string}
      * @global 
      */
    ej.Grid.Rowposition = {
        /** Add new row in the top of the grid */
        Top: "top",
        /** Add new row in the bottom of the grid */
        Bottom: "bottom",
    };
    /**
	 * Enum for specifying form position in grid 
	 * @enum {string}
	 * @global 
	 */
    ej.Grid.FormPosition = {
        /**  Creates grid with formPosition as BottomLeft */
        BottomLeft: "bottomleft",
        /**  Creates grid with formPosition as TopRight */
        TopRight: "topright"
    };
    /**
	 * Enum for specifying various editing type in grid	 
	 * @enum {string}
	 * @global 
	 */
    ej.Grid.EditingType = {
        /**  Allows to set edit type as string edit type */
        String: "stringedit",
        /**  Allows to set edit type as boolean edit type */
        Boolean: "booleanedit",
        /**  Allows to set edit type as numeric edit type */
        Numeric: "numericedit",
        /**  Allows to set edit type as drop down edit type */
        Dropdown: "dropdownedit",
        /**  Allows to set edit type as date picker edit type */
        DatePicker: "datepicker",
        /**  Allows to set edit type as date time picker edit type */
        DateTimePicker: "datetimepicker",
    };
    /**
	 * Enum for specifying various unbound type in grid	 
	 * @enum {string}
	 * @global 
	 */
    ej.Grid.UnboundType = {
        /** Used to specify unbound type as Edit   */
        Edit: "edit",
        /** Used to specify unbound type as Save   */
        Save: "save",
        /** Used to specify unbound type as Delete   */
        Delete: "delete",
        /** Used to specify unbound type as Cancel   */
        Cancel: "cancel"
    };
    /**
	 * Enum for specifying various tool bar items in grid	 
	 * @enum {string}
	 * @global 
	 */
    ej.Grid.ToolBarItems = {
        /** Used to add toolbar item for adding records    */
        Add: "add",
        /** Used to add toolbar item for editing records    */
        Edit: "edit",
        /** Used to add toolbar item for deleting records    */
        Delete: "delete",
        /** Used to add toolbar item for updating records    */
        Update: "update",
        /** Used to add toolbar item for cancelling records    */
        Cancel: "cancel",
        /** Used to add toolbar item for searching records    */
        Search: "search",
        /** Used to add toolbar item for printing grid    */
        PrintGrid: "printGrid",
         /** Used to add toolbar item for exproting grid to excel    */
        ExcelExport: "excelExport",
        /** Used to add toolbar item for exporting grid to word    */
        WordExport: "wordExport",
        /** Used to add toolbar item for exporting grid to pdf    */
        PdfExport: "pdfExport"
    };
    /**
     * Enum for various grid filtering type	 
     * @enum {string}
     * @global 
     */
    ej.Grid.FilterType = {
        /**  Creates grid with filtering type as Menu */
        Menu: "menu",
        /**  Creates grid with filtering type as FilterBar */
        FilterBar: "filterbar",
        /** Creates grid with filtering type as Excel */
        Excel: "excel"
    };

    /**
	 * Enum for specifying various filter bar mode in grid	 
	 * @enum {string}
	 * @global 
	 */
    ej.Grid.FilterBarMode = {
        /** Used to set filter bar mode as Immediate mode */
        Immediate: "immediate",
        /** Used to set filter bar mode as OnEnter mode */
        OnEnter: "onenter"
    };
    /**
     * Enum for various selection type in grid 
     * @enum {string}
     * @global 
     */
    ej.Grid.SelectionType = {
        /**  Support for Single selection only in grid */
        Single: "single",
        /**  Support for multiple selections in grid */
        Multiple: "multiple"
    };
     /**
     * Enum for various virtual scroll mode in grid 
     * @enum {string}
     * @global 
     */
    ej.Grid.VirtualScrollMode = {
        /** Used to set the Normal mode virtual paging*/
        Normal: "normal",
        /** Used to set the Continuous mode virtual paging*/
        Continuous: "continuous"
    };
    /**
    * Enum for various selection mode in grid 
    * @enum {string}
    * @global 
    */
    ej.Grid.SelectionMode = {
	    /**  Support for Row selection in grid */
        Row: "row",
        /**  Support for Cell selection in grid */
        Cell: "cell",       
        /**  Support for Column selection in grid */
        Column: "column"
    };
})(jQuery, Syncfusion);;
(function ($, ej, undefined) {
    ej.Grid = ej.Grid || {};
    ej.Grid.gridResize = function (instance) {
        this.$headerTable = instance.getHeaderTable();
        this.gridInstance = instance;
        this._colMinWidth = 15;
        this._$visualElement = $();
        this._currentCell = -1;
        this._allowStart = false;
        this._oldWidth = null;
        this._orgX = null;
        this._orgY = null;
        this._extra = null;
        this._expand = false;
        this._target = null;
    }

    ej.Grid.gridResize.prototype = {
        _mouseHover: function (e) {
            if (this._$visualElement.is(":visible"))
                return;
            if ($(e.target).is(".e-headercelldiv"))
                e.target = e.target.parentNode;
            var $target = $(e.target);
            if ($target.hasClass("e-headercell")) {
                var _resizableCell = e.target;
                var location = _resizableCell.getBoundingClientRect(), _x = 0, _y = 0;
                if (e.type = "mousemove") {
                    _x = e.clientX;
                    _y = e.clientY;
                }
                else if (e.type = "touchmove") {
                    _x = evt.originalEvent.changedTouches[0].clientX;
                    _y = evt.originalEvent.changedTouches[0].clientY;
                }
                else if (e.type = "MSPointerMove") {
                    _x = e.originalEvent.clientX;
                    _y = e.originalEvent.clientY;
                }
                if (this.gridInstance.model.scrollSettings && this.gridInstance.model.scrollSettings.frozenColumns)
                    var _nlx = this.gridInstance.getHeaderContent().width() + this.gridInstance.element.children(".e-gridheader").find(".e-columnheader").offset().left;
                else
                    var _nlx = this.gridInstance.getHeaderTable().width() + this.gridInstance.element.children(".e-gridheader").find(".e-columnheader").offset().left;
                if (((_x >= (location.left + document.documentElement.scrollLeft + _resizableCell.offsetWidth - 5)) || ((_x <= (location.left + 3)))) && (_x < _nlx) && (_x >= location.left) && (_y <= location.top + document.documentElement.scrollTop + e.target.offsetHeight)) {
                    this.gridInstance.model.showStackedHeader && $($target.parents('thead')).find('tr').css("cursor", "col-resize");
                    !this.gridInstance.model.showStackedHeader && $target.parent().css("cursor", "col-resize");
                    if ($(e.target).hasClass('e-stackedHeaderCell'))
                        this._currentCell = this.gridInstance.getHeaderContent().find(".e-headercell:visible").index(_resizableCell);
                    else
                        this._currentCell = this.gridInstance.getHeaderContent().find(".e-headercell:visible").not(".e-stackedHeaderCell").index(_resizableCell);
                    this._allowStart = true;
                }
                else {
                    $target.parent().css("cursor", "pointer");
                    this._allowStart = false;
                    this._currentCell = -1;
                }
            }
        },
        _start: function (_x, _y) {
            var _myrow = this.gridInstance.getHeaderTable().find(".e-columnheader");
            var _cells, _mycel;
            if ($(this._target).hasClass('e-stackedHeaderCell'))
                _cells = _myrow.find(".e-headercell")
            else
                _cells = _myrow.find(".e-headercell").not(".e-stackedHeaderCell");
            if (this._currentCell != -1 && this._currentCell < _cells.length)
                _mycel = _cells[this._currentCell];
            if (typeof (_mycel) == 'undefined')
                return;
            var _j = _mycel.getBoundingClientRect();
            this._tableY = _j.top + parseInt(navigator.userAgent.indexOf("WebKit") != -1 ? document.body.scrollTop : document.documentElement.scrollTop);
            if (this._allowStart) {
                this._$visualElement = $(document.createElement('div'));
                _height = this.gridInstance.element.find(".e-gridcontent").first().height() + this.gridInstance.element.find(".e-gridheader").height();
                if (this.gridInstance.model.showStackedHeader && this.gridInstance.model.stackedHeaderRows.length > 0) {
                    var headerRow = this.gridInstance.getHeaderTable().find('tr.e-columnheader')
                    var lenght = headerRow.length;
                    var currentIndex = $(this._target).parent('tr')[0].rowIndex;
                    for (var i = 0; i < currentIndex; i++) {
                        _height = _height - $(headerRow[i]).height();
                    }
                    // _height = _height - $(".e-stackedHeaderRow").height();
                }
                this._$visualElement.addClass("e-reSizeColbg").appendTo(this.gridInstance.element).css({ height: _height + 'px', cursor: 'col-resize' });
                this._$visualElement.css({ left: _x, top: this._tableY });
                this._oldWidth = _mycel.offsetWidth;
                this._orgX = _x;
                this._orgY = _y;
                this._extra = _x - this._orgX;
                this._expand = true;
            }
            else {
                this._currentCell = -1;
            }
        },
        _mouseMove: function (e) {
            if (this._expand) {
                var _x = 0, _y = 0;
                if (e.type = "mousemove") {
                    _x = e.clientX;
                    _y = e.clientY;
                }
                else if (e.type = "touchmove") {
                    _x = evt.originalEvent.changedTouches[0].clientX;
                    _y = evt.originalEvent.changedTouches[0].clientY;
                }
                else if (e.type = "MSPointerMove") {
                    _x = e.originalEvent.clientX;
                    _y = e.originalEvent.clientY;
                }
                if (navigator.userAgent.indexOf("WebKit") != -1) {
                    _x = e.pageX;
                    _y = e.pageY;
                }
                _x += document.documentElement.scrollLeft;
                e.preventDefault();
                this._moveVisual(_x);
            }
            else
                this._mouseHover(e);
        },
        _getCellIndex: function (e) {
            var $target = $(e._target);
            var targetCell = e._target;
            var hCellIndex = targetCell.cellIndex;
            var cellIndex = hCellIndex;
            if (e.gridInstance.model.groupSettings.groupedColumns.length) {
                cellIndex = hCellIndex - e.gridInstance.model.groupSettings.groupedColumns.length;
            }
            return cellIndex;
        },
        _reSize: function (_x, _y) {
            // Function used for Resizing the column
            var proxy = this;
            var resized = false, $content;
            if (this.gridInstance.model.scrollSettings && this.gridInstance.model.scrollSettings.frozenColumns)
                this._initialTableWidth = this.gridInstance.getHeaderTable().first().parent().width() + this.gridInstance.getHeaderTable().last().parent().width();
            else
                this._initialTableWidth = this.gridInstance.getHeaderTable().parent().width();
            !this.gridInstance.model.enableRTL && this._getResizableCell();
            var _rowobj = $(this._target).parents('thead');
            if (this._currentCell != -1 && this._expand) {
                this._expand = false;
                var _childTH = _rowobj.find(".e-headercell").filter(":visible");
                var _outerCell = _childTH[this._currentCell];
                var _oldWidth = _outerCell.offsetWidth;
                var _extra = _x - this._orgX;
                //Check whether the column minimum width reached
                if (parseInt(_extra) + parseInt(_oldWidth) > this._colMinWidth) {
                    if (_extra != 0)
                        _rowobj.css("cursor", 'default');
                    this._resizeColumnUsingDiff(_oldWidth, _extra);
                    $content = this.gridInstance.element.find(".e-gridcontent").first();
                    this.gridInstance.model.allowScrolling && $content.ejScroller("refresh");
                    var browser = this.gridInstance.getBrowserDetails();
                    if (browser.browser == "msie" && this.gridInstance.model.allowScrolling) {
                        var oldWidth = this.gridInstance.getContentTable().width(), newwidth = this.gridInstance._calculateWidth();
                        if (this.gridInstance.model.scrollSettings && this.gridInstance.model.scrollSettings.frozenColumns > 0) {
                            this.gridInstance.getHeaderTable().last().width(newwidth - this.gridInstance.getHeaderContent().find(".e-frozenheaderdiv").width());
                            this.gridInstance.getContentTable().last().width(newwidth - this.gridInstance.getContent().find(".e-frozencontentdiv").width());
                            this.gridInstance.model.showSummary && this.gridInstance.getFooterTable().last().width(newwidth - this.gridInstance.getFooterContent().find(".e-frozenfootertdiv").width());
                        }
                        else {
							if (newwidth > oldWidth) {
								this.gridInstance.getHeaderTable().width(newwidth);
								this.gridInstance.getContentTable().width(newwidth);
								this.gridInstance.model.showSummary && this.gridInstance.getFooterTable().width(newwidth);
							}
                        }
                        if (parseInt(browser.version, 10) > 8 && this.gridInstance.model.groupSettings && this.gridInstance.model.groupSettings.groupedColumns.length) {
                            if (newwidth > oldWidth) {
                                this.gridInstance.getContentTable().width(newwidth);
                                this.gridInstance.getContentTable().children("colgroup").find("col").first().css("width", (20 / $content.find("table").first().width()) * 100 + "%");
                            }
                            else {
                                this.gridInstance.getContentTable().css("width", "100%");
                                this.gridInstance._groupingAction();
                                this.gridInstance.getContentTable().children("colgroup").find("col").first().css("width", ((this.gridInstance.getHeaderTable().find("colgroup").find("col").first().width() / $content.find("table").first().width()) * 100).toFixed(2) + "%");
                            }
                        }
                        this.gridInstance.getHeaderTable().parent().scrollLeft($content.find(".e-content").scrollLeft() - 1);
                    }
                    this.gridInstance._colgroupRefresh();
                    if (this.gridInstance.model.groupSettings.groupedColumns.length && this.gridInstance.model.groupSettings.showGroupedColumn)
                        this.gridInstance._recalculateIndentWidth();
                    if (!(browser.browser == "msie") && this.gridInstance.model.allowScrolling && this.gridInstance.model.scrollSettings.frozenColumns == 0) {
                        var tableWidth = this.gridInstance._calculateWidth();
						if(tableWidth > this.gridInstance.getContentTable().width() || this.gridInstance.getHeaderTable().width() > this.gridInstance.getContentTable().width()){
							this.gridInstance.getHeaderTable().width(tableWidth);
							this.gridInstance.getContentTable().width(tableWidth);
						}
                    }
                    if (this.gridInstance.model.allowResizing && this.gridInstance.getHeaderTable().find(".e-columnheader").css('cursor') == 'default') {
                        var cellIndex = this._getCellIndex(this);
                        var newWidth = _oldWidth + _extra;
                        var args = { columnIndex: cellIndex, column: this.gridInstance.model.columns[cellIndex], oldWidth: _oldWidth, newWidth: newWidth };
                        this.gridInstance._trigger("resized", args);
                    }
                }

            }
			this.gridInstance.model.allowScrolling && this.gridInstance.getScrollObject().refresh();
            this._target = null;
            this._$visualElement.remove();
            this._expand = false;
            this._currentCell = -1;
            this._allowStart = false;

        },
        _getFrozenResizeWidth: function () {
            var $frozenColumnsCol = this.gridInstance.getHeaderTable().find('colgroup').find("col").slice(0, this.gridInstance.model.scrollSettings ? this.gridInstance.model.scrollSettings.frozenColumn : 0), width = 0;
            for (var i = 0; i < $frozenColumnsCol.length; i++) {
                if ($frozenColumnsCol.eq(i).css("display") != "none")
                    width += parseInt($frozenColumnsCol[i].style.width.replace("px", ""));
            }
            return width;
        },
        _diaplayFinder: function () {
            return $(this).css('display') != 'none';
        },
        _resizeColumnUsingDiff: function (_oldWidth, _extra) {
            var proxy = this;
            var currentIndex = this._currntCe = this._currentCell, _extraVal;
            if ($(this._target).parent('tr').hasClass('e-stackedHeaderRow')) {
                var preCol = 0, currentTh = $(this._target), currentSpan = $(currentTh).attr('colspan'), tr = $(currentTh).parent('tr');
                while (currentIndex > 0) {
                    currentIndex--
                    var th = $(tr).children('th')[currentIndex];
                    preCol += parseInt($(th).attr('colspan'))
                }
                this._currentCell = preCol;
            }
            if (this.gridInstance.model.showStackedHeader && !$(this._target).parent('tr').hasClass('e-stackedHeaderRow'))
                this._currentCell = this._currentCell - this.gridInstance.getHeaderTable().find(".e-stackedHeaderCell").length;            
			var $headerCols = this.gridInstance.getHeaderTable().find('colgroup').find("col");
            var $ContentCols = this.gridInstance.getContentTable().find('colgroup').find("col");
            if (!ej.isNullOrUndefined(this.gridInstance.model.detailsTemplate)) {
                this.gridInstance._detailColsRefresh();
                $headerCols = this.gridInstance._$headerCols;
                $ContentCols = this.gridInstance._$contentCols;
            }
            var $headerCol = $headerCols.filter(this._diaplayFinder).eq(!this.gridInstance.model.allowGrouping || !ej.isNullOrUndefined(this.gridInstance.model.detailsTemplate) ? this._currentCell : this._currentCell + this.gridInstance.model.groupSettings.groupedColumns.length)
                    , $ContentCol, $footerCol, $frozenCols = $headerCols.slice(0, this.gridInstance.model.scrollSettings ? this.gridInstance.model.scrollSettings.frozenColumns : 0);
            var _inlineWidth = $headerCol[0].style.width;
            var indent = _oldWidth / parseInt(_inlineWidth);
            _extraVal = _extra = _extra / indent
            var _newWidth = parseInt(_extra) + parseInt(_inlineWidth);
            if (_newWidth > 0 && _extra != 0) {
                if (_newWidth < this._colMinWidth)
                    _newWidth = this._colMinWidth;
                var _extra = _newWidth - _oldWidth;
                if (this.gridInstance.model.scrollSettings && this.gridInstance.model.scrollSettings.frozenColumns) {
                    if (this._currentCell >= 0 && this._currentCell < this.gridInstance.model.scrollSettings.frozenColumns && this._getFrozenResizeWidth() + _extra > this.gridInstance.element.find(".e-headercontent").first().width())
                        return;
                    $ContentCol = $ContentCols.filter(this._diaplayFinder).eq(this._currentCell);
                }
                else
                    $ContentCol = $ContentCols.filter(this._diaplayFinder).eq(!this.gridInstance.model.allowGrouping || !ej.isNullOrUndefined(this.gridInstance.model.detailsTemplate) ? this._currentCell : this._currentCell + this.gridInstance.model.groupSettings.groupedColumns.length);
                if (this.gridInstance.model.showSummary) {
                    $footerCol = this.gridInstance.getFooterTable().find('colgroup').find("col").filter(this._diaplayFinder).eq(this._currentCell);
                    $footerCol.outerWidth(_newWidth);
                }
                if ($(this._target).parent('tr').hasClass('e-stackedHeaderRow')) {
                    this._resizeStackedHeaderColumn($(this._target).parent('tr'), _extraVal, this._currntCe);
                }
                else
                    $headerCol.outerWidth(_newWidth);
                if (this.gridInstance.model.isEdit) {
                    var $editCol = this.gridInstance.getContentTable().find(".e-editedrow,.e-addedrow").find("table").find("colgroup");
                    $($editCol[0].children[this._currentCell - this.gridInstance.model.groupSettings ? this.gridInstance.model.groupSettings.groupedColumns.length : 0]).width(_newWidth);
                }
                if ($(this._target).parent('tr').hasClass('e-stackedHeaderRow')) {
                    if (this.gridInstance.model.groupSettings.groupedColumns.length < 1) {

                        var length = this.gridInstance.getContentTable().find('colgroup').find("col").filter(this._diaplayFinder).length;
                        for (var i = 0; i < this._changedcell.length; i++) {
                            var $conCol = this.gridInstance.getContentTable().find('colgroup').find("col").filter(this._diaplayFinder)[this._changedcell[i]]
                            var width = parseInt((_extraVal)) + parseInt($conCol.style.width);
                            $($conCol).width(width);
                        }
                    }
                    else {
                        var $tables = this.gridInstance.getContentTable().find(".e-recordtable");
                        var $colGroup = $tables.find("colgroup");
                        for (var i = 0; i < this._changedcell.length; i++) {
                            var cellIndex = this._changedcell[i];
                            for (var i = 0 ; i < $colGroup.length; i++) {
                                var width = parseInt((_extraVal)) + parseInt($($colGroup[i].children[cellIndex]).width());
                                $($colGroup[i].children[cellIndex]).width(width);
                            }
                        }
                    }
                }
                else {
                    if (this.gridInstance.model.groupSettings && this.gridInstance.model.groupSettings.groupedColumns.length) {
                        var $tables = this.gridInstance.getContentTable().find(".e-recordtable");
                        var $colGroup = $tables.find("colgroup");
                        var cellIndex = this._currentCell + this.gridInstance._hiddenColumns.length;
                        var colCount = this.gridInstance.model.columns.length;
                        for (var i = 0 ; i < $colGroup.length; i++) {
                            var cols = $($colGroup[i]).find("col");
                            if (cols.length > colCount) cols.splice(0, (cols.length - colCount));
                            $(cols[cellIndex]).width(_newWidth);
                        }
                    }                    
                    $ContentCol.width(_newWidth);
                }
                this.gridInstance._findColumnsWidth();
                if (this.gridInstance.model.scrollSettings && this.gridInstance.model.scrollSettings.frozenColumns) {
                    var frozenColumns = this.gridInstance.getContentTable().find('colgroup').find("col").slice(0, this.gridInstance.model.scrollSettings.frozenColumns)
                        , width = 0, direction;
                    for (i = 0; i < frozenColumns.length; i++)
                        width += parseInt(frozenColumns[i].style.width.replace("px", ""));
                    this.gridInstance.getHeaderContent().find(".e-frozenheaderdiv").width(width);
                    direction = this.gridInstance.model.enableRTL ? "margin-right" : "margin-left";
                    this.gridInstance.getContent().find(".e-frozencontentdiv").width(width).next().css(direction, width + "px");
                    this.gridInstance.getHeaderContent().find(".e-frozenheaderdiv").width(width).next().css(direction, width + "px");
                    this.gridInstance.model.showSummary && this.gridInstance.getFooterContent().find(".e-frozenfooterdiv").width(width);
                }
                this.gridInstance.getHeaderTable().find(".e-columnheader").css("cursor", "default");
            }
        },
        _resizeStackedHeaderColumn: function (currentTr, extra, currentCell) {
            // var currentIndex = this._currntCe;
            this._changedcell = [];
            if (this.gridInstance.model.groupSettings.showGroupedColumn && this.gridInstance.model.groupSettings.groupedColumns.length > 0) {
                this._currentCell++;
                currentCell++;
            }
            var preCol = this._currentCell, currentTh = $(currentTr).find('th')[currentCell], currentSpan = $(currentTh).attr('colspan'), commonExtra = extra / currentSpan, tr = $(currentTh).parent('tr');
            if (currentSpan > 1) {
                var nextTr = tr.next();
                var length = preCol + parseInt(currentSpan);
                for (var i = preCol; i < length; i++) {
                    var curTh = $($(nextTr).find('th'))[i], curCol = $(curTh).attr('colspan');
                    if (curCol > 1) {
                        this._resizeStackedHeaderColumn($(curTh).parent('tr'), commonExtra, i)
                    }
                    else {
                        var $colG = this.gridInstance.getHeaderTable().find('col')[i];
                        this._changedcell.push(i)
                        var width = parseInt(extra) + parseInt($colG.style.width);
                        $($colG).outerWidth(width);
                    }
                }
            }
            else {
                var $colG = this.gridInstance.getHeaderTable().find('col')[this._currentCell];
                var width = parseInt(extra) + parseInt($colG.style.width);
                this._changedcell.push(preCol)
                $($colG).outerWidth(width);
            }
        },
        _triggerResizeEvents: function (event, _x) {
            var _rowobj = this.gridInstance.getHeaderTable().find(".e-columnheader");
            var _childTH = _rowobj.find(".e-headercell").filter(":visible");
            var _outerCell = _childTH[this._currentCell];
            var _oldWidth = _outerCell.offsetWidth;
            var cellIndex = this._getCellIndex(this);
            if (event == "resizeStart") {
                var args = { columnIndex: cellIndex, column: this.gridInstance.model.columns[cellIndex], target: $(_outerCell), oldWidth: _oldWidth };
                this.gridInstance._trigger("resizeStart", args);
            }
            else {
                var _extra = _x - this._orgX;
                var newWidth = _oldWidth + _extra;
                this.gridInstance._colgroupRefresh();
                var args = { columnIndex: cellIndex, column: this.gridInstance.model.columns[cellIndex], target: $(_outerCell), oldWidth: _oldWidth, newWidth: newWidth, extra: _extra };
                this.gridInstance._trigger("resizeEnd", args);
            }
        },
        _mouseUp: function (e) {
            if (this._expand) {
                var _x = e.clientX, _y = e.clientY;
                if (navigator.userAgent.indexOf("WebKit") != -1) {
                    _x = e.pageX;
                    _y = e.pageY;
                }
                if (this.gridInstance.model.allowResizing && this.gridInstance.getHeaderTable().find(".e-columnheader").css('cursor') == 'col-resize') {
                    this._triggerResizeEvents("resizeEnd", _x);
                }
                _x += document.documentElement.scrollLeft;
                this._reSize(_x, _y);
            }
        },
        _getResizableCell: function () {
            var row = this.gridInstance.getHeaderTable().find(".e-columnheader");
            var cell = row.find(".e-headercell").not(".e-hide,.e-detailheadercell");
            var scrollLeft = navigator.userAgent.indexOf("WebKit") != -1 ? document.body.scrollLeft : document.documentElement.scrollLeft;
            for (var i = 0; i < cell.length; i++) {
                point = cell[i].getBoundingClientRect();
                var xlimit = point.left + scrollLeft + 5;
                if (xlimit > this._orgX && $(cell[i]).height() + point.top >= this._orgY) {
                    this._currentCell = i - 1;
                    return;
                }
            }
        },
        _moveVisual: function (_x) {
            /// Used to move the visual element in mouse move
            var _bounds = this.gridInstance.getHeaderContent().find("div").first()[0].getBoundingClientRect();
            if ((_bounds.left + document.documentElement.scrollLeft + _bounds.width < _x) || (_x < _bounds.left + document.documentElement.scrollLeft))
                this._$visualElement.remove();
            else if (this._currentCell != -1)
                this._$visualElement.css({ left: _x, top: this._tableY });
        },
        _mouseDown: function (e) {
            if (this._allowStart && ($(e.target).closest("tr").css("cursor") == 'col-resize')) {
                this._target = e.target;
                var _x = e.clientX, _y = e.clientY;
                if (navigator.userAgent.indexOf("WebKit") != -1) {
                    _x = e.pageX;
                    _y = e.pageY;
                }
                if (this.gridInstance.model.allowResizing && this.gridInstance.getHeaderTable().find(".e-columnheader").css('cursor') == 'col-resize') {
                    if ($(e.target).is(".e-headercelldiv"))
                        e.target = e.target.parentNode;
                    this._target = e.target;
                    this._triggerResizeEvents("resizeStart", _x);
                }
                var gridobj = this;
                _x += document.documentElement.scrollLeft;
                if (e.button != 2)
                    if (this.gridInstance.model.allowResizing && this.gridInstance.model.allowResizeToFit) {
                        gridobj.gridInstance._click++;
                        setTimeout(function () {
                            if (gridobj.gridInstance._click == 1) {
                                gridobj._start(_x, _y);
                            }
                            else if (gridobj.gridInstance._click == 2) {
                                gridobj._columnResizeToFit(e);
                            }
                            gridobj.gridInstance._click = 0;
                        }, 400);
                    }
                    else
                        this._start(_x, _y);
                e.preventDefault();
            }
            return false;
        },
        _columnResizeToFit: function (e) {
            if (this.gridInstance.model.allowResizeToFit && this.gridInstance.getHeaderTable().find(".e-columnheader").css('cursor') == 'col-resize') {
                if ($(e.target).is(".e-headercelldiv"))
                    e.target = e.target.parentNode;
                var $target = $(e.target);
                this._target = $target;
                if ($target.hasClass("e-headercell")) {
                    var targetCell = e.target;
                    var hCellIndex = targetCell.cellIndex;
                    var cellIndex = hCellIndex;
                    this._orgX = e.pageX;
                    this._getResizableCell();
                    if (hCellIndex != this._currentCell) {
                        hCellIndex = cellIndex = this._currentCell;
                        targetCell = e.target.previousSibling;
                    }
                    var $cellDiv = $(targetCell).children('.e-headercelldiv');
                    if (this.gridInstance.model.groupSettings.groupedColumns.length) {
                        cellIndex = hCellIndex - this.gridInstance.model.groupSettings.groupedColumns.length;
                    }
                    var finalWidth = 0, headerWidth = 0, contentWidth = 0;
                    if (cellIndex != -1) {
                        contentWidth = this._getContentWidth(cellIndex);
                        headerWidth = this._getHeaderContentWidth($cellDiv);
                        finalWidth = headerWidth > contentWidth ? headerWidth : contentWidth;
                        finalWidth = finalWidth + (finalWidth * 0.2);
                        var oldWidth = this.gridInstance.getHeaderTable().find('col').eq(hCellIndex).width();
                        var args = { columnIndex: cellIndex, column: this.gridInstance.model.columns[cellIndex], target: $target, oldWidth: oldWidth };
                        this.gridInstance._trigger("resizeStart", args);
						finalWidth =  oldWidth > finalWidth ? finalWidth : (this._colMinWidth < contentWidth ? contentWidth : this._colMinWidth);
                        this.gridInstance.getHeaderTable().find('col').eq(hCellIndex).width(finalWidth);
                        if (this.gridInstance.model.groupSettings.groupedColumns.length) {
                            var $colGroups = this.gridInstance.getContentTable().find('.e-recordtable').find('colgroup');
                            $.each($colGroups, function (indx, colgroup) {
                                $(colgroup).find('col').eq(cellIndex).width(finalWidth);
                            });
                        }
                        else
                            this.gridInstance.getContentTable().find('col').eq(cellIndex).width(finalWidth);
                        var newWidth = this.gridInstance.getHeaderTable().find('col').eq(hCellIndex).width();
                        this.gridInstance._colgroupRefresh();
                        args = { columnIndex: cellIndex, column: this.gridInstance.model.columns[cellIndex], target: $target, oldWidth: oldWidth, newWidth: newWidth, extra: Math.abs(newWidth - oldWidth) };
                        this.gridInstance._trigger("resizeEnd", args);
                        this.gridInstance._columnsWidthCollection[cellIndex] = finalWidth;
                        this.gridInstance.model.columns[cellIndex]["width"] = finalWidth;
                        args = { columnIndex: cellIndex, column: this.gridInstance.model.columns[cellIndex], target: $target, oldWidth: oldWidth, newWidth: newWidth };
                        this.gridInstance._trigger("resized", args);
                    }
                }
            }
        },
        _getContentWidth: function (cellindx) {
            var contentWidth = 0;
            var $span = ej.buildTag('span', {}, {}), proxy = this.gridInstance, tdWidth;
            $.each(proxy._gridRows, function (indx, row) {
                var td = $(row).find('td.e-rowcell').eq(cellindx);
                var content = $(td).html();
                if (proxy.model.columns[cellindx]["isUnbound"])
                    $span.html($(content).children());
                else
                    $span.html(content);
                $(td).html($span);
                tdWidth = td.find('span:first').width();
                if (tdWidth > contentWidth)
                    contentWidth = tdWidth;
                $(td).html(content);
            });
            proxy._refreshUnboundTemplate(this.gridInstance.getContentTable());
            return contentWidth;
        },
        _getHeaderContentWidth: function ($cellDiv) {
            var headerWidth = 0, $span = ej.buildTag('span', {}, {});
            var content = $cellDiv.html();
            $span.html(content);
            $cellDiv.html($span);
            headerWidth = $cellDiv.find('span:first').width();
            if (this.gridInstance.model.allowFiltering && this.gridInstance.model.filterSettings.filterType == "menu")
                headerWidth = headerWidth + $cellDiv.parent().find(".e-filtericon").width() + 10;
            $cellDiv.html(content);
            return headerWidth;
        },
    };
})(jQuery, Syncfusion);;
});