/*!
*  filename: ej.treegrid.js
*  version : 12.3
*  Copyright Syncfusion Inc. 2001 - 2014. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
*/
(function (fn) {
    typeof define === 'function' && define.amd ? define(["./../common/ej.core","./../common/ej.data","./../common/ej.scroller","./ej.datepicker","./ej.checkbox","./ej.dropdownlist","./ej.editor","./ej.toolbar"], fn) : fn();
})
(function () {
	
/**
 * @fileOverview Plugin to style the Html TreeGrid elements
 * @copyright Copyright Syncfusion Inc. 2001 - 2014. All rights reserved.
 *  Use of this code is subject to the terms of our license.
 *  A copy of the current license can be obtained at any time by e-mailing
 *  licensing@syncfusion.com. Any infringement will be prosecuted under
 *  applicable laws. 
 * @version 12.1 
 * @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
 */

(function ($, ej, undefined) {
    /**
* @namespace ej
* @class ejTreeGrid
* @requires jQuery
* @requires jquery.globalize.js
* @requires jquery.easing.1.3.js
* @requires jsrender.js
* @requires ej.web.all.js
* @classdesc Custom Design for Html Tree grid control.
* @example 
* &lt;treegrid id="treegrid"&gt;treegrid&lt;/treegrid&gt; <br> 
* &lt;script&gt;
* // Create TreeGrid
* $('#treegrid').ejTreeGrid(); 	
* &lt;/script&gt;
*/
    ej.widget("ejTreeGrid", "ej.TreeGrid", {
        // widget element will be automatically set in this
        _rootCSS: "e-treegrid",

        // widget element will be automatically set in this
        element: null,

        validTags: ["div"],

        // user defined model will be automatically set in this
        model: null,

        _tags: [
        {
            tag: "columns",
            attr: ["field", "headerText", "allowSorting", "editType", "allowFiltering", "filterEditType","width"],
            content: "template"
        },
        {
            tag: "sortSettings.sortedColumns",
            attr: ["field", "direction"]
        },
        {
            tag: "sizeSettings",
            attr:["height","width"]
        }
        ],
        _columns: function (index, property, value, old){
            var $header = this.element.find(".e-headercelldiv");
            $header[index.columns].innerHTML=value;
            this._trigger("refresh");
        },
            keyConfigs: {
            focus: "e",
            editRecord: "113", //F2
            saveRequest: "13", // enter
            cancelRequest: "27", //Esc         
            firstRowSelection: "36", //"CtrlPlusHome",
            lastRowSelection: "35", //"CtrlPlusEnd",
            leftArrow:"37",//Left arrow
            upArrow: "38", //Up arrow
            rightArrow:"39",//Right arrow
            downArrow: "40", //Down arrow
            moveCellRight: "9", //tab
            moveCellLeft: "shift+9", //shifttab
            selectedRowExpand: "alt+40", //"AltPlusDownArrow",
            totalRowExpand: "ctrl+40", //"CtrlPlusDownArrow",
            selectedRowCollapse: "alt+38", //"AltPlusUpArrow",
            totalRowCollapse: "ctrl+38" //"CtrlPlusUpArrow"
        },
      
        defaults: {
            /**		
			* Enables or disables Filtering fields column wise. 
			* @default false
			* @type {boolean}
			* @example 
			* &lt;treegrid id="treegrid"&gt;treegrid&lt;/treegrid&gt; <br> 
			* &lt;script&gt;
			 * 	$("#treegrid").ejTreeGrid({  allowFiltering : true });
			* &lt;/script&gt;
			* @memberof ejTreeGrid
			* @instance
			*/
            allowFiltering: false,
            /**		
			* To change filterBarMode either immediate or onEnter. 
			* @default immediate
			* @type {enum}
			* @example 
			* &lt;treegrid id="treegrid"&gt;treegrid&lt;/treegrid&gt; <br> 
			* &lt;script&gt;
			 * 	$("#treegrid").ejTreeGrid({  filterBarMode : "onEnter" });
			* &lt;/script&gt;
			* @memberof ejTreeGrid
			* @instance
			*/
            filterBarMode:"immediate",
            /**		
			* Enables or disables sorting. When enabled, we can sort the column by clicking on the column. 
			* @default false
			* @type {boolean}
			* @example 
			* &lt;treegrid id="treegrid"&gt;treegrid&lt;/treegrid&gt; <br> 
			* &lt;script&gt;
			 * 	$("#treegrid").ejTreeGrid({  editSettings:{allowSorting : true} });
			* &lt;/script&gt;
			* @memberof ejTreeGrid
			* @instance
			*/
            allowSorting: false,
            /**		
             * Enables or disables the ability to resize column.
             * @default false
             * @type {boolean}
             * @example 
             * &lt;div id="treegrid"&gt;&lt;/div&gt; 
             * &lt;script&gt;                   
             * 	$("#treegrid").ejTreeGrid({ allowColumnResize:  true });			* 
             * &lt;/script&gt;
             * @memberof ejTreeGrid
             * @instance
             */
            allowColumnResize: false,
           
            /**		
            * Enables or disables the interactive selection of a row.
            * @default true
            * @type {boolean}
            * @example 
            * &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;   
            * 	$("#treegrid").ejTreeGrid({ allowSelection:  true });			* 
            * &lt;/script&gt;
            * @memberof ejTreeGrid
            * @instance
            */
            allowSelection: true,
           
            /**		
           * Collection of data or hierarchical data  to represent in  TreeGrid
           * @default 
           * @type {array}
           * @example 
           * &lt;div id="treegrid"&gt;&lt;/div&gt; 
           * &lt;script&gt; 		
           * 	$("#treegrid").ejTreeGrid(
           *  {
           *     dataSource:[{Id:2,TaskName:"Testing",startDate:"12/1/2000",Duration:5 }]	
           *  });		
           * &lt;/script&gt;
           * @memberof ejTreeGrid
           * @instance
           */

            dataSource: null,
           
            /**		
            * It receives query to retrieve data from the table (query is same as SQL). 
            * @default 
            * @type {object}
            * @example
            * &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;  			
            * 	$("#treegrid").ejTreeGrid(
            *  {
            *     query:ej.Query().from("Categories").select("CategoryID,CategoryName").take(3);	
            *  });		
            * &lt;/script&gt;
            * @memberof ejTreeGrid
            * @instance
            */
            query: ej.Query(),
            /**		
           * Specifies the mapping property path for child Id in self reference datasource
           * @default ""
           * @type {string}
           * @example 
           * &lt;div id="treegrid"&gt;&lt;/div&gt; 
           * &lt;script&gt;  		
           * 	$("#treegrid").ejTreeGrid({  IdMapping : "ID" });	            
           * &lt;/script&gt;
           * @memberof ejTreeGrid
           * @instance
           */
            idMapping: "",


            /**		
            * Specifies the mapping property path for parent Id in self reference datasource
            * @default ""
            * @type {string}
            * @example 
            * &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;  		
            * 	$("#treegrid").ejTreeGrid({  parentIdMapping : "ID" });	            
            * &lt;/script&gt;
            * @memberof ejTreeGrid
            * @instance
            */
            parentIdMapping: "",
            
            /**		
           * Specifies whether to show grid cell tooltip.
           * @default "true"
           * @type {boolean}
           * @example 
           * &lt;div id="treegrid"&gt;&lt;/div&gt; 
           * &lt;script&gt; 			
           * 	$("#treegrid").ejTreeGrid({  
           *			showGridCellTooltip : true});
           * &lt;/script&gt;
           * @memberof ejTreeGrid
           * @instance
           */
            showGridCellTooltip: false,

            /**		
            *Specifies whether to show grid cell tooltip over expander cell alone.
            * @default "true"
            * @type {boolean}
            * @example 
            * &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#treegrid").ejTreeGrid({  
            *			showGridExpandCellTooltip : true});
            * &lt;/script&gt;
            * @memberof ejTreeGrid
            * @instance
            */

            showGridExpandCellTooltip: false,

            /**		
           * Enables/Disables enableAltRow row effect in TreeGrid
           * @default true
           * @type {boolean}
           * @example 
           * &lt;div id="treegrid"&gt;&lt;/div&gt; 
           * &lt;script&gt;			
           * 	$("#treegrid").ejTreeGrid({ enableAltRow : false});			
           * &lt;/script&gt;
		   * @memberof ejTreeGrid
           * @instance
           */
            enableAltRow: true,
			
            /**		
           * Specifies the selected row index.
           * @default null
           * @type {numeric}
           * @example 
           * &lt;div id="treegrid"&gt;&lt;/div&gt; 
           * &lt;script&gt;			
           * 	$("#treegrid").ejTreeGrid({ selectedItem : 2});			
           * &lt;/script&gt;
		   * @memberof ejTreeGrid
           * @instance
           */
            selectedItem: null,

            /**		
           * Specifies the toolbarSettings options.
           * @type {object}
           * @memberof ejTreeGrid
           * @instance
           */
            toolbarSettings: {

                /**		
                * Specifies the state of enabling or disabling toolbar
                 * @alias ejTreeGrid#toolbarSettings->showToolBar
                * @default false
                * @type {boolean}
                * @example 
                * &lt;div id="treegrid"&gt;&lt;/div&gt; 
                * &lt;script&gt;	
                * 	$("#treegrid").ejTreeGrid({ showToolBar:  true });			 
                * &lt;/script&gt;
                * @memberof ejTreeGrid
			    * @instance
                */
                showToolbar: false,


                /**		
                * Specifies the list of toolbar items to rendered in toolbar
                * @alias ejTreeGrid#toolbarSettings->toolbarItems
                * @default []
                * @type {array}
                * @example 
                * &lt;div id="treegrid"&gt;&lt;/div&gt; 
                * &lt;script&gt;	
                * 	$("#treegrid").ejTreeGrid({ toolbarItems: [ej.TreeGrid.ToolbarItems.Add,ej.TreeGrid.ToolbarItems.Edit] });			 
                * &lt;/script&gt;
                * @memberof ejTreeGrid
			    * @instance
                */
                toolbarItems: []
            },
            /* editing API's */
            /**		
            * Specifies the editSettings options in treegrid. 
            * @type {object}
            * @memberof ejTreeGrid
            * @instance
            */
            editSettings: {
                /**		
           * specifies the option for enabling / disablig editing in treegrid part
           * @alias ejTreeGrid#editSettings->allowEditing
           * @default false
           * @type {boolean}
           * @example 
           * &lt;div id="treegrid"&gt;&lt;/div&gt; 
           * &lt;script&gt;			
           * 	$("#treegrid").ejTreeGrid({  editSettings:{allowEditing : true} });	
           * &lt;/script&gt;
           * @memberof ejTreeGrid
           * @instance
           */
                allowEditing: false,
                /**		
           * enables/disables add treegrid in toolbar
           * @alias ejTreeGrid#editSettings->allowAdding
           * @default true
           * @type {boolean}
           * @example 
           * &lt;div id="treegrid"&gt;&lt;/div&gt; 
           * &lt;script&gt; 			
           * 	$("#treegrid").ejTreeGrid({  editSettings:{allowAdding : true} });
           * &lt;/script&gt;
           * @memberof ejTreeGrid
           * @instance
           */
                allowAdding: true,
                /**		
            * enables/disables delete treegrid in toolbar
            * @alias ejTreeGrid#editSettings->allowDeleting
            * @default true
            * @type {boolean}
            * @example 
            * &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#treegrid").ejTreeGrid({  editSettings:{allowDeleting : true} });	
            * &lt;/script&gt;
			* @memberof ejTreeGrid
            * @instance
            */
                allowDeleting: true,
                /**		
            * specifies the editmode in treegrid , "normal" is for dialog editing ,"cellEditing" is for cell type editing
            * @alias ejTreeGrid#editSettings->editMode
            * @default cellEditing
            * @type {string}
            * @example 
            * &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#treegrid").ejTreeGrid({  editSettings:{editMode : "normal"} });
            * &lt;/script&gt;
			* @memberof ejTreeGrid
            * @instance
            */
                editMode: "cellEditing",

				/**  
            * Specifies the position where the newly added row want to add.
			* @alias ejTreeGrid#editSettings->rowPosition
            * @default top
            * @type {string}
            * @example 
            * &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;   
            *  $("#treegrid").ejTreeGrid({  editSettings:{rowPosition : "aboveSelectedRow"} });
            * &lt;/script&gt;
			* @memberof ejTreeGrid
            * @instance
            */
                rowPosition: "top",
            },     
                       
            /**		
            * Enables/Disables virtualization for rendering TreeGrid items.
            * @default false
            * @type {boolean}
            * @example 
            * &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#treegrid").ejTreeGrid({ enableVirtualization : true});			
            * &lt;/script&gt;
            * @memberof ejTreeGrid
            * @instance
            */
            enableVirtualization: false,
                    
            /**		
           * Specifies enabling / diabling multiple sorting for tree grid columns
           * @default false
           * @type {boolean}
           * @example 
           * &lt;div id="treegrid"&gt;&lt;/div&gt; 
           * &lt;script&gt;			
           * 	$("#treegrid").ejTreeGrid({ allowMultiSorting : true});			
           * &lt;/script&gt;
           * @memberof ejTreeGrid
           * @instance
           */
            allowMultiSorting: false,
          
            /**		
            *  Specifes the sorting options for Treegrid.
            * @type {object}
            * @memberof ejTreeGrid
            * @instance
            */
            sortSettings: {
                /**		
           * Specifes the sorted columns for Tree grid
           * @alias ejTreeGrid#sortSettings->sortedColumns
           * @default []
           * @type {array}
           * @example 
           * &lt;div id="treegrid"&gt;&lt;/div&gt; 
           * &lt;script&gt;		
           * 	$("#treegrid").ejTreeGrid({ sortSettings{sortedColumns : []}});	           
           * &lt;/script&gt;
           * @instance
            */
                sortedColumns: []
            },

           

            /**		
           * Specifes the single or multiple row selection           
           * @default "single"
           * @type {string}
           * @example 
           * &lt;div id="treegrid"&gt;&lt;/div&gt; 
           * &lt;script&gt;		
           * 	$("#treegrid").ejTreeGrid({ selectionType:"multiple" });	           
           * &lt;/script&gt;
           * @memberof ejTreeGrid
           * @instance
            */

            selectionType: "single",
           
            /**		
          * Specifies the selected row Index in Treegrid , the row with given index is highlighted
          * @default  "-1"
          * @type {number}
          * @example 
          * &lt;div id="treegrid"&gt;&lt;/div&gt; 
          * &lt;script&gt;			
          * 	$("#treegrid").ejTreeGrid(
          *  {
          *     selectedRowIndex:2
          *  });		
          * &lt;/script&gt;
          * @memberof ejTreeGrid
          * @instance
          */
            selectedRowIndex: -1,
          
            /**		
            * Enables/Disables Keyboard navigation in treegrid
            * @default true
            * @type {boolean}
            * @example 
            * &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt; 			
            * 	$("#treegrid").ejTreeGrid({ allowKeyboardNavigation : true});			
            * &lt;/script&gt;
            * @memberof ejTreeGrid
            * @instance
            */
            
            allowKeyboardNavigation: true,

           
            /**		
             * Specify the CSS class to tree grid to achieve custom theme.
             * @default ""
             * @type {string}
             * @example 
             * &lt;div id="treegrid"&gt;&lt;/div&gt; 
             * &lt;script&gt;		
             * 	$("#treegrid").ejTreeGrid({  cssClass : "gradient-lime" });
             * &lt;/script&gt;
             * @memberof ejTreeGrid
             * @instance
            */
            cssClass: "",
           
            locale: "en-US",

            isEdit: false,

            allowScrolling: false,
            groupSettings: {
                groupedColumns:[]
            },
            /**		
            *  Specifes the size options for Treegrid.
            * @type {object}
            * @memberof ejTreeGrid
            * @instance
            */
            sizeSettings: {
                /**		
             * Specify the height to tree grid.
			 * @alias ejTreeGrid#sizeSettings->height
             * @default "null"
             * @type {string}
             * @example 
             * &lt;div id="treegrid"&gt;&lt;/div&gt; 
             * &lt;script&gt;		
             * 	$("#treegrid").ejTreeGrid({sizeSettings{height:'450px'}});
             * &lt;/script&gt;
             * @memberof ejTreeGrid
             * @instance
            */
                height:null,
                /**		
                * Specify the width to tree grid.
				 * @alias ejTreeGrid#sizeSettings->width
                * @default "null"
                * @type {string}
                * @example 
                * &lt;div id="treegrid"&gt;&lt;/div&gt; 
                * &lt;script&gt;		
                * 	$("#treegrid").ejTreeGrid({sizeSettings{width:'500px'}});
                * &lt;/script&gt;
                * @memberof ejTreeGrid
                * @instance
                */
                width: null,
            },

            /**		
            * Specify the enableResize to tree grid.
            * @default "false"
            * @type {boolean}
            * @example 
            * &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;		
            * 	$("#treegrid").ejTreeGrid({enableResize:true});
            * &lt;/script&gt;
            * @memberof ejTreeGrid
            * @instance
            */
            enableResize:false,
            /* event function */
            /**    
            * Triggered while rendering each row
            * @event
            * @name ejTreeGrid#rowDataBound 
            * @param {Object} argument Arguments when rowDataBound event is triggered.  
            * @param {boolean} argument.cancel Returns the cancel option value.
            * @param {object} argument.rowElement Returns the row element of editing cell.
            * @param {object} argument.data Returns the data of edited cell record..
            * @example 
            * &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#treegrid").ejTreeGrid({
            *    rowDataBound: function (args) {}
            * });
            * &lt;/script&gt;
            * @instance
            */
            rowDataBound: null,

            /**    
            * Triggered while Treegrid is loaded
            * @event
            * @name ejTreeGrid#load 
            * @param {Object} argument Arguments when load event is triggered.             
            * @param {boolean} argument.cancel Returns the cancel option value.
			* @param {object}  argument.model Returns the treegrid model
            * @param {string}  argument.type Returns the name of the event. 
            * @example 
            * &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#treegrid").ejTreeGrid({
            *    load: function (args) {}
            * });
            * &lt;/script&gt;
            * @memberof ejTreeGrid
			   * @instance
            */
            load: null,

            /**    
            * Triggered while rendering each cell in the grid tree
            * @event
            * @name ejTreeGrid#queryCellInfo 
            * @param {Object} argument Arguments when queryCellInfo event is triggered.  
            * @param {boolean} argument.cancel Returns the cancel option value.
            * @param {object} argument.rowElement Returns the selecting row element.
            * @param {string} argument.cellValue Returns the value of cell.
            * @param {object} argument.data Returns the data of current cell record.
            * @param {object} argument.column Returns the column of cell belongs.
            * @example 
            * &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#treegrid").ejTreeGrid({
            *    queryCellInfo: function (args) {}
            * });
            * &lt;/script&gt;
            * @instance
            */
            queryCellInfo: null,

            /**    
			* Triggered before the row is going to be selected.
			* @event
			* @name ejTreeGrid#rowSelecting 
			* @param {Object} argument Arguments when rowSelecting event is triggered.  
			* @param {boolean} argument.cancel Returns the cancel option value.
			* @param {object} argument.rowElement Returns the selecting row element.
			* @param {string} argument.recordIndex Returns the index of selecting row record.
			* @param {object} argument.data Returns the data selecting record.
			* @example 
			* &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;
			* $("#treegrid").ejTreeGrid({
			*    rowSelecting: function (args) {}
			* });
			* &lt;/script&gt;
            * @memberof ejTreeGrid
			   * @instance
            */
            rowSelecting: null,
            /**    
			* Triggered after the row is selected.
			* @event
			* @name ejTreeGrid#rowSelected 
			* @param {Object} argument Arguments when rowSelected event is triggered.  
			* @param {boolean} argument.cancel Returns the cancel option value.
			* @param {object} argument.rowElement Returns the selecting row element.
			* @param {string} argument.recordIndex Returns the index of selecting row record.
			* @param {object} argument.data Returns the data of selected record.
			* @example 
			* &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;
			* $("#treegrid").ejTreeGrid({
			*    rowSelected: function (args) {}
			* });
			* &lt;/script&gt;
            * @memberof ejTreeGrid
			   * @instance
            */
            rowSelected: null,
            /**    
           * Triggered while enter the edit mode in the grid tree cell
           * @event
           * @name ejTreeGrid#beginEdit 
           * @param {Object} argument Arguments when beginEdit event is triggered.  
           * @param {boolean} argument.cancel Returns the cancel option value.
           * @param {object} argument.rowElement Returns the row element of editing cell.
           * @param {object} argument.cellElement Returns the Element of editing cell.
           * @param {object} argument.data Returns the data of current cell record.
           * @param {number} argument.columnIndex Returns the column Index of cell belongs.
           * @example 
           * &lt;div id="treegrid"&gt;&lt;/div&gt; 
           * &lt;script&gt;
           * $("#treegrid").ejTreeGrid({
           *    beginEdit: function (args) {}
           * });
           * &lt;/script&gt;
           * @memberof ejTreeGrid
              * @instance
           */
            beginEdit: null,

            /**    
            * Triggered after the save the modified cellValue in treegrid
            * @event
            * @name ejTreeGrid#endEdit 
            * @param {Object} argument Arguments when endEdit event is triggered.  
            * @param {boolean} argument.cancel Returns the cancel option value.
            * @param {object} argument.rowElement Returns the row element of editing cell.
            * @param {object} argument.cellElement Returns the Element of editing cell.
            * @param {object} argument.data Returns the data of edited cell record.
            * @param {string} argument.columnName Returns the column name of edited cell belongs.
            * @param {object} argument.columnObject Returns the column object of edited cell belongs.
            * @example 
            * &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#treegrid").ejTreeGrid({
            *    endEdit: function (args) {}
            * });
            * &lt;/script&gt;
            * @memberof ejTreeGrid
			   * @instance
            */
            endEdit: null,

            /**    
            * Triggered  while expanding the TreeGrid record
            * @event
            * @name ejTreeGrid#expanding 
            * @param {Object} argument Arguments when expanding event is triggered.  
            * @param {boolean} argument.cancel Returns the cancel option value.
            * @param {object} argument.recordIndex Returns the row index of record.
            * @param {object} argument.data Returns the data of edited cell record..
            * @example 
            * &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#treegrid").ejTreeGrid({
            *    expanding: function (args) {}
            * });
            * &lt;/script&gt;
            * @memberof ejTreeGrid
			   * @instance
            */
            expanding: null,

            /**    
            * Triggered  after expand the record
            * @event
            * @name ejTreeGrid#expanded 
            * @param {Object} argument Arguments when expanded event is triggered.  
            * @param {boolean} argument.cancel Returns the cancel option value.
            * @param {object} argument.recordIndex Returns the row index of record.
            * @param {object} argument.data Returns the data of edited cell record..
            * @example 
            * &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#treegrid").ejTreeGrid({
            *    expanded: function (args) {}
            * });
            * &lt;/script&gt;
            * @memberof ejTreeGrid
			   * @instance
            */
            expanded: null,
            /**    
            * Triggered while collapsing the TreeGrid record
            * @event
            * @name ejTreeGrid#collapsing 
            * @param {Object} argument Arguments when collapsing event is triggered.  
            * @param {boolean} argument.cancel Returns the cancel option value.
            * @param {object} argument.recordIndex Returns the row index of collapsing record.
            * @param {object} argument.data Returns the data of edited cell record..
            * @example 
            * &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#TreeGrid").ejTreeGrid({
            *    collapsing: function (args) {}
            * });
            * &lt;/script&gt;
            * @memberof ejTreeGrid
			   * @instance
            */
            collapsing: null,
            /**    
            * Triggered after collapsed the TreeGrid record
            * @event
            * @name ejTreeGrid#collapsed 
            * @param {Object} argument Arguments when collapsed event is triggered.  
            * @param {boolean} argument.cancel Returns the cancel option value.
            * @param {object} argument.recordIndex Returns the row index of collapsed record.
            * @param {object} argument.data Returns the data of edited cell record..
            * @example 
            * &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#treegrid").ejTreeGrid({
            *    collapsed: function (args) {}
            * });
            * &lt;/script&gt;
            * @memberof ejTreeGrid
			   * @instance
            */
            collapsed: null,

            currentViewData: [],
            flatRecords: [],
            parentRecords: [],
            records: [],

          
            /**		
            * It is to specify data values to the field. 
            * @default 
            * @type {array}
            * @example
            * &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;  			
            * 	$("#treegrid").ejTreeGrid(
            *  {
            *     columns: [{ field: "Name", headerText: "Name", isTemplateColumn: true, templateID: "customColumnTemplate" },
                          { field: "Type", headerText: "Type" },
                          { field: "DateCreated", headerText: "Date Created" },
                          { field: "DateModified", headerText: "Date Modified" }]	
            *  });		
            * &lt;/script&gt;
            * @memberof ejTreeGrid
            * @instance
            */

            columns: [],
            commonWidth: 150,

            

            dateFormat: "MM/dd/yyyy",

          
            /**		
           * Specifies the height of a single row in gantt. Also, we need to set same height in the CSS style with class name e-rowcell. 
           * @default "30"
           * @type {number}
           * @example 
           * &lt;div id="treegrid"&gt;&lt;/div&gt; 
           * &lt;script&gt;				
           * 	$("#treegrid").ejTreeGrid({  
           *			rowHeight : 30,
           * 			});
           * &lt;/script&gt;
		   * @memberof ejTreeGrid
           * @instance
           */
            rowHeight: 30,

            emptyRecordText: "No Records To Display",
            /**		
           * Specifies the tree expander column in tree grid
           * @default  0
           * @type {number}
           * @example 
           * &lt;div id="treegrid"&gt;&lt;/div&gt; 
           * &lt;script&gt;		
           * 	$("#treegrid").ejTreeGrid(
           *  {
           *     treeColumnIndex: 1
           *  });		
           * &lt;/script&gt;
           * @memberof ejTreeGrid
           * @instance
           */
            treeColumnIndex: 0,

            //API for toggle between datepicker and datetimepicker
            workingTimeScale: 'TimeScale8Hours',

            /**		
            * Specifies the mapping property path for sub tasks in datasource 
            * @default ""
            * @type {string}
            * @example 
            * &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;				
            * 	$("#treegrid").ejTreeGrid({  childMapping : "Children" });
            * &lt;/script&gt;
            * @instance
            */
            childMapping: "",           
                      
           
            /**		
             * Enables or disables the collapse all menus for tree grid , when enabled all sub menus will disappears in tree grid
             * @default  "false"
             * @type {boolean}
             * @example 
             * &lt;div id="treegrid"&gt;&lt;/div&gt; 
             * &lt;script&gt;			
             * 	$("#treegrid").ejTreeGrid(
             *  {
             *     enableCollapseAll: false
             *  });		
             * &lt;/script&gt;
             * @memberof ejTreeGrid
                * @instance
             */
            enableCollapseAll:false,

            /**		
            * Specifies the row template for each TreeGrid row
            * @default  ""
            * @type {string}
            * @example 
            * &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#treegrid").ejTreeGrid(
            *  {
            *     rowTemplateID: "customTemplate"
            *  });		
            * &lt;/script&gt;
            * @memberof ejTreeGrid
            * @instance
            */
            rowTemplateID: "",

            /**		
            * Specifies the alternate row template for each alternate TreeGrid row
            * @default  ""
            * @type {string}
            * @example 
            * &lt;div id="treegrid"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#treegrid").ejTreeGrid(
            *  {
            *     altRowTemplateID: "altRowCustomTemplate"
            *  });		
            * &lt;/script&gt;
            * @memberof ejTreeGrid
            * @instance
            */
            altRowTemplateID: "",
            /**		
            * Specifies the contextMenuSettings options.
            * @type {object}
            * @memberof ejTreeGrid
            * @instance
            */
            contextMenuSettings: {
                /**		
               * Specifies the state of enabling or disabling context menu
               * @alias ejTreeGrid#contextMenuSettings->showContextMenu
               * @default false
               * @type {boolean}
               * @example 
               * &lt;div id="treegrid"&gt;&lt;/div&gt; 
               * &lt;script&gt;	
               * 	$("#treegrid").ejTreeGrid(contextMenuSettings :{ showContextMenu:  true });			 
               * &lt;/script&gt;
               * @memberof ejTreeGrid
               * @instance
               */
                showContextMenu: false,
                /**		
                * Specifies the list of context menu items to rendered in context menu
                * @alias ejTreeGrid#contextMenuSettings->contextMenuItems
                * @default []
                * @type {array}
                * @example 
                * &lt;div id="treegrid"&gt;&lt;/div&gt; 
                * &lt;script&gt;	
                * 	$("#treegrid").ejTreeGrid({ contextMenuItems: [ej.TreeGrid.ContextMenuItems.Add,ej.TreeGrid.ContextMenuItems.Edit] });			 
                * &lt;/script&gt;
                * @memberof ejTreeGrid
			    * @instance
                */
                contextMenuItems: []
        },
            /**    
           * Triggered while Context Menu is rendered in TreeGrid control
           * @event
           * @name ejTreeGrid#contextMenuOpen 
           * @param {Object} argument Arguments when context menu is rendered.  
           * @param {boolean} argument.cancel Returns the cancel option value.
           * @param {boolean} argument.contextMenuItems Returns the default context menu items to which we add custom items.
           * @param {object}  argument.model Returns the treegrid model.
           * @param {string}  argument.requestType Returns request type.
           * @param {string}  argument.type Returns the name of the event. 
           * @example 
           * &lt;div id="treegrid"&gt;&lt;/div&gt; 
           * &lt;script&gt;
           * $("#treegrid").ejTreeGrid({
           *    contextMenuOpen: function (args) {}
           * });
           * &lt;/script&gt;
           * @memberof ejTreeGrid
              * @instance
           */
            contextMenuOpen:null,
        },

        dataTypes: {
            columns: "array",
            sortSettings: {
                sortedColumns: "array"
            },
            dataSource: "data",
            currentViewData: "array",
            flatRecords: "array",
            parentRecords: "array",
            records: "array",
            contextMenuSettings: {
                contextMenuItems: "array"
            },
            toolbarSettings: {
                toolbarItems: "array"
            },
            selectedItem: "data",

        },

        observables: ["selectedRowIndex", "dataSource"],
        selectedItem: ej.util.valueFunction("selectedItem"),
        selectedRowIndex: ej.util.valueFunction("selectedRowIndex"),
        dataSource: ej.util.valueFunction("dataSource"),
        //GET THE GRID HEADER TABLE FOR COLUMNRESIZE
        getHeaderTable: function () {
            return this._$gridHeaderTable;
        },

        //SET THE GRID HEADER TABLE
        setGridHeaderTable: function (value) {
            this._$gridHeaderTable = value;
        },

        //GET THE GRIDHEADERCONTENT
        getHeaderContent: function () {
            return this._$gridHeaderContent;
        },

        //SET THE GRIDHEADERCONTENT
        setGridHeaderContent: function (value) {
            this._$gridHeaderContent = value;
        },

        //GET THE GRID CONTENT TABLE
        getContentTable: function () {
            return this._$gridContentTable;
        },

        getContent: function () {
            return this._$gridContent;
        },
        
        //SET THE GRID CONTENT TABLE
        setGridContentTable: function (value) {
            this._$gridContentTable = value;
        },

        //GET TREEGRID ROWS
        getRows: function () {
            return this._$gridRows;
        },

        //SET TREEGRID ROWS
        setGridRows: function (value) {
            this._$gridRows = value;
        },

        //GET CURRENTVIEWPORT DATA
        getCurrentViewData: function () {
            return this.model.currentViewData;
        },

        //GET UPDATED CURRENT VIEW DATA
        getUpdatedCurrentViewData: function () {
            this._updateCurrentViewData();
            return this.model.currentViewData;
        },

        //GET FLAT RECORDS
        getFlatRecords: function () {
            return this.model.records;
        },

        //SET THE HEIGHT BASED ON THE RECORD COUNT
        setHeight: function (value) {
            this._totalHeight = value;
        },

        //GET THE UPDATEDRECORDS[SORTED,FILTERED,EXPANDCOLLAPSED]
        getUpdatedRecords: function () {
            return this._updatedRecords;
        },

        //GET THE UPDATED DATASOURCE
        getDataSource: function () {
            return this.dataSource();
        },

        //get the ids collection after perform the addition/delete operation
        //GET THE IDS COLLECTION AFTER PERFORM THE ADDITION/DELETE OPERATION
        getUpdatedIds: function () {
            return this.model.ids;
        },

        //GET THE RECORDS COUNT
        getRecordsCount: function () {
            return this._recordsCount;
        },

        //SET THE RECORDS COUNT
        setRecordsCount: function (value) {
            this._recordsCount = value;
        },

        //GET THE EXPANDCOLLAPSE RECORDS COUNT
        getExpandCollapseRecordsCount: function () {
            return this._expandCollapseRecordCount;
        },
        setCollapsedRecordCount:function(value){
            this._totalCollapseRecordCount=value; 
        },
        getCollapsedRecordCount: function () {
            return this._totalCollapseRecordCount;
        },
        
        _colgroupRefresh: function () {
            var gridheaderCol = $(this.getHeaderTable()).find('colgroup')[0];
            var gridcontentCol = $(this.getContentTable()).find('colgroup')[0];
            var headerColClone = $(gridheaderCol).clone();
            var contentColClone = $(gridcontentCol).clone();
            $(gridcontentCol).remove();
            $(gridheaderCol).remove();
            $(headerColClone).prependTo(this.getHeaderTable());
            $(contentColClone).prependTo(this.getContentTable());
        },
		
        /*CONSTRUCTOR FUNCTION*/
        _init: function () {

            var proxy = this;

            proxy._trigger("load");
            proxy._initPrivateProperties();
            
            if (proxy.model.isdesignMode) {

                proxy.element.css({ "height": "250px" });
                if (proxy.model.columns.length === 0) {
                    proxy.model.columns = [
                        { "field": "Column1", "HeaderText": "Column1" },
                        { "field": "Column2", "HeaderText": "Column2" },
                        { "field": "Column3", "HeaderText": "Column3" }
                    ];

                }
                if (proxy.model.childMapping.length == 0) {
                    proxy.model.childMapping = "Children";
                }
            }

            proxy._processEditing();
            proxy._initDatasource();

            proxy._createTooltipTemplate();
       
            //Render Records in collapsed state
            if (!proxy.model.isFromGantt && proxy.model.enableCollapseAll)
            {
                proxy.collapseAll();
            }
            var isSafari = /Safari/.test(navigator.userAgent) && /Apple Computer/.test(navigator.vendor);
            if (isSafari && !proxy.model.isFromGantt) {
                treeGridHeader = proxy._$gridHeaderContent;
                treeGridContent = $("#" + proxy._id + "e-gridcontent");
               sizeSettingsWidth = proxy.model.sizeSettings.width;
                elementStyleWidth = proxy.element[0].style.width;
                var width, height;
                //Width calculation
                if ((sizeSettingsWidth && sizeSettingsWidth.indexOf("%") != -1) || elementStyleWidth.indexOf("%") != -1) {

                    var ganttWidth = sizeSettingsWidth ? sizeSettingsWidth : elementStyleWidth;
                    var containerWidth = $(proxy.element).parent().width() ? $(proxy.element).parent().width() : $(proxy.element).width();
                    var tempWidth = (containerWidth / 100) * parseInt(ganttWidth);
                    width = tempWidth;
                }
                else {
                    width = $(proxy.element).width();
                }
                width = width - proxy._totalBorderWidth;
                proxy._updateScrollCss();
                if ($(treeGridHeader).hasClass("e-scrollcss") && proxy._$gridContent.children(".e-vscrollbar").length > 0) {
                    $(treeGridHeader).width(width - 18);
                }
                else {
                    $(treeGridHeader).width(width);
                }
            }

        },
        //#region RUNTIME UPDATE METHOD FOR TREEGRID
        //METHOD FOR UPDATE THE TREEGRID IN RUN TIME
        _setModel: function (options) {

            var proxy = this,
                model = proxy.model;

            for (var prop in options) {

                switch (prop) {

                    case "enableAltRow":
                        model.enableAltRow = options[prop];
                        proxy._addInitTemplate();
                        proxy.refreshContent();
                        break;

                    case "enableVirtualization":
                        model.enableVirtualization = options[prop];
                        proxy.refreshContent();
                        break;

                    case "allowColumnResize":
                        model.allowColumnResize = options[prop];
                        proxy._enableColumnResizeEvents();
                        break;

                    case "allowSorting":
                        model.allowSorting = options[prop];
                        break;

                    case "sortSettings":
                        $.extend(model.sortSettings, options[prop]);
                        proxy.refreshContent();
                        break;

                    case "allowSelection":
                        proxy.clearSelection();
                        model.allowSelection = options[prop];
                        break;

                    case "selectionType":
                        proxy.clearSelection();
                        model.selectionType = options[prop];
                        break;

                    case "selectedRowIndex":
                        if (this.selectedRowIndex() != -1 && $.inArray(this.selectedRowIndex(), proxy._selctedRowsIndexes == -1) && !ej.isNullOrUndefined(this.selectedRowIndex()))
                            proxy.selectRows(this.selectedRowIndex());
                        break;

                    case "editSettings":
                        $.extend(model.editSettings, options[prop]);
                        proxy._processEditing();
                        proxy._enableEditingEvents();
                        break;

                    case "allowKeyboardNavigation":
                        model.allowKeyboardNavigation = options[prop];
                        break;

                    case "dataSource":
                        proxy._refreshDataSource();
                        break;

                    case "columns":
                        $.extend(model.columns, options[prop]);
                        proxy._addInitTemplate();
                        proxy.refreshContent();
                        proxy._processEditing();
                        //Rerendering the column header with new columns.;
                        proxy._$gridHeaderContent.replaceWith(proxy._renderGridHeader());
                        var args = {};
                        args.requestType = ej.TreeGrid.Actions.Refresh;
                        //Rerendering the content of the tree grid
                        proxy.sendDataRenderingRequest(args);
                        proxy.setWidthToColumns();
                        // Update the scrollbar
                        proxy._$gridContent.ejScroller("refresh");
                        proxy._updateScrollCss();
                        break;
                    
                    case "rowHeight":
                        model.rowHeight = options[prop];
                        proxy._addInitTemplate();
                        proxy.refreshContent();
                        break;

                    case "treeColumnIndex":
                        model.treeColumnIndex = options[prop];
                        proxy._addInitTemplate();
                        proxy.refreshContent();
                        break;

                }

            }

        },
         //refresh data source on set model     
        _refreshDataSource:function()
        {
            var proxy = this,model=this.model;
            proxy.resetModelCollections();
            proxy._createdAt = "load";
            if (this.dataSource() instanceof ej.DataManager) {
                var queryPromise = this.dataSource().executeQuery(model.query);
                queryPromise.done(ej.proxy(function (e) {
                    if (proxy.dataSource().dataSource.offline) {
                        proxy._retrivedData = proxy.dataSource().dataSource.json;
                    } else {
                        proxy._retrivedData = e.result;
                    }
                    if (model.idMapping && model.parentIdMapping) {
                        //cloning the datasource
                        var dataArray = e.result.slice(0);
                        var data = [];
                        $.each(dataArray, function (indx, value) {
                            data.push(jQuery.extend(true, {}, value));
                        });
                        proxy._reconstructDatasource(data);
                    } else {
                        proxy._reconstructDatasource(e.result);
                    }
                    proxy._createRecords(proxy.secondaryDatasource);

                    args = {};
                    args["requestType"] = ej.TreeGrid.Actions.RefreshDataSource;
                    proxy._ensureDataSource(args);
                    if (proxy.selectedRowIndex() !== -1 && proxy.selectedRowIndex() < proxy.model.currentViewData.length) {
                        proxy.selectRows(proxy.selectedRowIndex());
                    }
                    if (this._$gridContent.hasClass("e-scroller"))
                        proxy._$gridContent.ejScroller("refresh");
                    proxy._createdAt = null;
                }));
            }
            else if (this.dataSource()) {
                if (model.idMapping && model.parentIdMapping) {
                    if ((model.idMapping.length > 0) && (model.parentIdMapping.length > 0)) {
                        var dataArray = this.dataSource().slice(0);
                        proxy._reconstructDatasource(dataArray);
                        proxy._createRecords(proxy.secondaryDatasource);
                    }
                }
                else if (model.flatRecords.length === 0 && this.dataSource() !== null) {
                    proxy._createRecords(this.dataSource());
                }
                args = {};
                args["requestType"] = ej.TreeGrid.Actions.RefreshDataSource;
                proxy._ensureDataSource(args);
                if (this.selectedRowIndex() !== -1 && this.selectedRowIndex() < proxy.model.currentViewData.length) {
                    proxy.selectRows(this.selectedRowIndex());
                }
                if (this._$gridContent.hasClass("e-scroller"))
                    proxy._$gridContent.ejScroller("refresh");
                proxy._createdAt = null;
            }
        
            $(".e-tooltiptable").remove();

        },
        //REFRESH THE TREEGRIDCONTENT
       
        refreshContent: function () {

            var proxy = this,
                args = {};     
            args.requestType = ej.TreeGrid.Actions.Refresh;
            proxy.processBindings(args);
        },


        //RESET THE COLLECTIONS WHILE CHANGING THE DATASOURCE
       
        resetModelCollections: function () {

            var proxy = this,
            model = proxy.model;

            // model.sortSettings.sortedColumns = [];
            model.currentViewData = [];
            model.flatRecords = [];
            model.parentRecords = [];
            model.records = [];
            proxy.secondaryDatasource = [];

        },        

        //#endregion

        //DECLARE THE PRIVATE VARIABLES
        _initPrivateProperties: function () {

            var proxy = this;

            proxy._id = proxy.element.attr("id"),
            proxy._columnsWidthCollection = [],
            proxy._cSortedColumn = null,
            proxy._cSortedDirection = null,
            proxy._dataManager = null,
            proxy._disabledSortableColumns = [],
            proxy._filteredRecords = [],
            proxy._disabledToolItems = [],
            proxy._filteredColumns = [],
            proxy_currentFilterColumn = [];
            proxy._fieldColumnNames = [],
            proxy._multiSortRequest = null,
            proxy._$gridContainer = null,
            proxy._$gridContent = null,
            proxy._$gridContentTable = null,
            proxy._$gridHeaderTable = null,
            proxy._$gridHeaderContainer = null,
            proxy._recordsCount = null,
            proxy._$gridRows = null,
            proxy._gridRows = null,
            proxy._calculateDimensions(),
            proxy._headerColumnNames = [],
            proxy._hiddenColumns = [],
            proxy._multiSelectCtrlRequest = false,
            proxy._multiSelectShiftRequest = false,
            proxy._offset = 0,
            proxy._previousIndex = -1,
            proxy._prevRBottom = 0,
            proxy._prevRTop = 0,
            proxy._prevScrollTop = 0,
            proxy._prevScrollLeft = 0,
            proxy._prevVBottom = 0,
            proxy._resizer = null,
            proxy._scrollTop = 0,
            proxy._searchString = "",
            proxy._fieldName="",
            proxy._selectedRowsIndexes = [],
            proxy._sortedRecords = [],
            proxy._storedIndex = -1,
            proxy._$tableContent = null,
            proxy._tempsortedrecords = [],
            proxy._totalHeight = 0,
            proxy._viewPortHeight = 0,
            proxy._recordIndexCount = 0,
            proxy._visibleColumns = [],
            proxy._visibleRange = null,
            proxy._vScrollDir = 1,
            proxy._vScrollDist = 0,
            proxy._cellEditTemplate = $(),
            proxy._totalBorderWidth = 2;//left and right border width
            proxy._totalBorderHeight = 1;
            proxy._cellEditingDetails = {
                cellValue: null,
                rowIndex: -1,
                columnIndex: -1,
                fieldName: null,
                _data: null,
                cellEditType: "",
                cancelSave: false,
                defaultData: null,
                insertedTrCollection: [],
                data: null
            },
            proxy._tdsOffsetWidth = [],
            proxy._isEnterKeyPressed = false,
            proxy._updatedRecords = [],
            proxy._scrollBarHeight = 18,
            proxy._expandCollapseRecordCount = 0,
            proxy._removedCount = 0,
            proxy._$gridHeaderContent = null,
            proxy._expandedRecordsCount = 0,
            proxy._totalCollapseRecordCount = 0,
            proxy._collapsedRecordCount = 0,
            proxy.secondaryDatasource = [],
            //variables for context menu items
            proxy._contextMenuItems = proxy._getContextMenuItems();
            proxy._subContextMenuItems = proxy._getsubContextMenuItems();
            proxy._dropDownTemplate = proxy._compiledDropDownTemplate(),
            proxy._createSubContextMenuTemplate();
            proxy._createContextMenuTemplate();
            proxy._retrivedData = this.dataSource();
            proxy._createdAt = "load";
            proxy._dataManager = proxy.dataSource() instanceof ej.DataManager ? proxy.dataSource() :
                proxy.dataSource() != null ? ej.DataManager(proxy.dataSource()) : null;
        },
        //set size to treegrid core by user values
        _calculateDimensions: function ()
        {
            var proxy = this, model = this.model;

            if (!model.isFromGantt) {
                if (model.sizeSettings.width)
                    proxy.element.css("width", model.sizeSettings.width);

                if (model.sizeSettings.height)
                    proxy.element.css("height", model.sizeSettings.height);
                else
                {
                    if (!proxy.element[0].style.height) {
                        proxy.element.height(350);
                    }
                }
            }
            proxy._gridHeight = proxy.element.height();
            proxy._gridWidth = proxy.element.width();

        },
        //DATASOURCE CHECKING
        _checkDataBinding: function () {

            var proxy = this,
                model = proxy.model;
            proxy._createdAt = null;
            proxy.element.addClass('e-treegrid-core');
            proxy.element.attr("tabindex", "0");
            proxy._renderToolbar();
            proxy._renderAfterColumnInitialize();
            proxy._viewPortHeight = proxy._getViewPortHeight(); 
            proxy._ensureDataSource();
            proxy._initGridRender();
            proxy._$gridContent = $("#" + proxy._id + "e-gridcontent");
            proxy._$gridContainer = $("#" + proxy._id + "e-gridcontainer");
            proxy._$tableContent = $("#" + proxy._id + "e-table");            
            proxy._wireEvents();            
            
            proxy.setWidthToColumns();
            
            proxy._renderScroller();
            proxy._resizeFilteringElements();
            
            if (model.isFromGantt) {
                proxy._addEmptyColumntoGrid();
            }
           
        },

        _initDatasource: function () {
            var proxy = this,
                model = proxy.model,retriveData;
            if (!model.isFromGantt) {
            if (this.dataSource() instanceof ej.DataManager) {

                var queryPromise = this.dataSource().executeQuery(model.query);
                queryPromise.done(ej.proxy(function (e) {
                    if (proxy.dataSource().dataSource.offline) {
                        proxy._retrivedData = proxy.dataSource().dataSource.json;
                    } else {
                        proxy._retrivedData = e.result;
                    }
                    if (model.idMapping && model.parentIdMapping) {
                        //cloning the datasource
                        var dataArray = e.result.slice(0);
                        var data = [];
                        $.each(dataArray, function (indx, value) {
                            data.push(jQuery.extend(true, {}, value));
                        });
                        proxy._reconstructDatasource(data);
                    } else {
                        proxy._reconstructDatasource(e.result);
                    }
                    proxy._createRecords(proxy.secondaryDatasource);
                    proxy._checkDataBinding();
                }));
            }

            else if (this.dataSource()) {
                if (model.idMapping && model.parentIdMapping) {
                        //cloning the datasource
                        var dataArray = this.dataSource().slice(0);
                        var data = [];
                        $.each(dataArray, function (indx, value) {
                            data.push(jQuery.extend(true, {}, value));
                        });
                        proxy._reconstructDatasource(data);
                        proxy._createRecords(proxy.secondaryDatasource);
                }
                else if (model.flatRecords.length === 0 && this.dataSource() !== null) {
                    proxy._createRecords(this.dataSource());
                }
                proxy._checkDataBinding();
            }
             else {
                    proxy._checkDataBinding();
            }
            } else {
                proxy._checkDataBinding();
            }
            
        },

        _reconstructDatasource: function (datasource) {
            var proxy = this, model = proxy.model,
                childItems, data, tempRecord = [];

            for (var i = 0; i < datasource.length; i++) {
                var data = {};
                data = ej.DataManager(datasource).executeLocal(ej.Query().where(model.parentIdMapping,
                    ej.FilterOperators.equal,
                    datasource[i][model.idMapping]));


                if ((ej.isNullOrUndefined(datasource[i][model.parentIdMapping]) || datasource[i][model.parentIdMapping] == 0)
                    && data.length > 0) {
                    datasource[i][model.childMapping] = data;
                    proxy.secondaryDatasource.push(datasource[i]);
                }
                else if (ej.isNullOrUndefined(datasource[i][model.parentIdMapping]) && !(data && data.length > 0)) {
                    proxy.secondaryDatasource.push(datasource[i]);
                }

                else if (data && data.length > 0 && !(ej.isNullOrUndefined(data[0][model.parentIdMapping]))){
                    proxy._appendChildDataItems(proxy.secondaryDatasource, data);
                }
                else if ((ej.isNullOrUndefined(datasource[i][model.parentIdMapping]) || datasource[i][model.parentIdMapping] == 0)
                    && data.length == 0) {
                    proxy.secondaryDatasource.push(datasource[i]);
                }

                if (data && data.length > 0) {

                    proxy._datasourceChildItems = proxy._reconstructDatasource(data);
                    if (ej.isNullOrUndefined(datasource[i][model.childMapping])) {
                        datasource[i][model.childMapping] = proxy._datasourceChildItems;
                        proxy._getParentIndex(datasource);
                    }
                    proxy._datasourceChildItems = [];

                }

                else if (!(ej.isNullOrUndefined(datasource[i][model.parentIdMapping]))) {
                    tempRecord.push(datasource[i]);
                }
            }

            if (tempRecord && tempRecord.length > 0) {
                return tempRecord;
            }
        },

        _appendChildDataItems: function (parentDatasource,data) {
            var proxy = this,
                model = proxy.model;
            
            for (var count = 0; count < parentDatasource.length; count++) {
                
                if (parentDatasource[count][model.idMapping] === data[0][model.parentIdMapping]) {
                    parentDatasource[count][model.childMapping] = data;
                }
                else if (!(ej.isNullOrUndefined(parentDatasource[count][model.childMapping])) &&
                    parentDatasource[count][model.childMapping].length > 0) {
                    proxy._appendChildDataItems(parentDatasource[count], data);
                }
            }

            if ((ej.isNullOrUndefined(parentDatasource.length)) && parentDatasource) {
                if (parentDatasource[model.idMapping] === data[0][model.parentIdMapping]) {
                    parentDatasource[model.childMapping] = data;
                }
                else if (!(ej.isNullOrUndefined(parentDatasource[model.childMapping])) &&
                    parentDatasource[model.childMapping].length > 0) {
                    proxy._appendChildDataItems(parentDatasource[model.childMapping], data);
                }
            }

        },
        
        _getParentIndex: function (datasource) {
            var proxy = this, model = proxy.model,
                dataArr = proxy.secondaryDatasource, parentIndex = 0;

            if (datasource.length > 0) {
                parentIndex = datasource[0][model.parentIdMapping];
            }
            for (var i = 0; i < dataArr.length; i++) {
                if (dataArr[i][model.idMapping] == parentIndex && ej.isNullOrUndefined(dataArr[i][model.childMapping])) {
                    dataArr[i][model.childMapping] = (datasource);
                    return true;
                }
                else {
                    var childItems = dataArr[i][model.childMapping];
                    if (childItems) {
                        for (var i = 0; i < childItems.length; i++) {
                            if (childItems[i][model.idMapping] == parentIndex && ej.isNullOrUndefined(childItems[i][model.childMapping])) {
                                childItems[i][model.childMapping] = (datasource);
                                return true;
                            }
                        }
                    }
                }
            }

        },
        //Window resize event
        _windowResize:function(e)
        {
            var proxy = this,
               treeGridHeader = proxy._$gridHeaderContent,
               treeGridContent = $("#" + proxy._id + "e-gridcontent"),
               treegridToolbar = $("#" + proxy._id + "_toolbarItems"),
               sizeSettingsHeight = proxy.model.sizeSettings.height,
               sizeSettingsWidth = proxy.model.sizeSettings.width,
               elementStyleWidth = proxy.element[0].style.width,
               elementStyleHeight = proxy.element[0].style.height,
               width, height;
            //Width calculation
            if ((sizeSettingsWidth && sizeSettingsWidth.indexOf("%") != -1) || elementStyleWidth.indexOf("%") != -1) {

                var ganttWidth = sizeSettingsWidth ? sizeSettingsWidth : elementStyleWidth;
                var containerWidth = $(proxy.element).parent().width() ? $(proxy.element).parent().width() : $(proxy.element).width();
                var tempWidth = (containerWidth / 100) * parseInt(ganttWidth);
                width = tempWidth;
            }
            else
                width = $(proxy.element).width();
            //height calculation
            if ((sizeSettingsHeight && sizeSettingsHeight.indexOf("%") != -1) || elementStyleHeight.indexOf("%") != -1) {
                var ganttHeight = sizeSettingsHeight ? sizeSettingsHeight : elementStyleHeight;
                var containerHeight = $(proxy.element).parent().height() ? $(proxy.element).parent().height() : $(proxy.element).height();
                var tempHeight;
                if ($(proxy.element).parent().height())
                    tempHeight = (containerHeight / 100) * parseInt(ganttHeight);
                else
                    tempHeight = $(proxy.element).height();
                height = tempHeight;
            }
            else
                height = $(proxy.element).height();

            //excludes border 
            height = height - proxy._totalBorderHeight;
            width = Math.round(width - proxy._totalBorderWidth);
            var treeGridWidth,headerHeight,headerWidth, top, left;
            top = proxy._$gridContent.ejScroller("option", "scrollTop");
            left = proxy._$gridContent.ejScroller("option", "scrollLeft");
            proxy._$gridContent.ejScroller({
                width: width,
                height: height - $(treeGridHeader).outerHeight() - treegridToolbar.outerHeight(),//for border-width of gridcontent
            });
            proxy._updateScrollCss();
            if ($(treeGridHeader).hasClass("e-scrollcss") && proxy._$gridContent.children(".e-vscrollbar").length > 0) {
                $(treeGridHeader).width(width - 18);
            }
            else {
                $(treeGridHeader).width(width);
            }
            if (proxy.model.toolbarSettings.showToolbar && treegridToolbar.length > 0) {
                treegridToolbar.width(width);
                treegridToolbar.children(".e-ul:first-child").width(width);
            }

            proxy._$gridContent.ejScroller("refresh");
            proxy.updateViewPortHeight();
            proxy._$gridContent.ejScroller("option", "scrollTop",top);
            proxy._$gridContent.ejScroller("option", "scrollLeft", left);
            proxy._$gridHeaderContainer.scrollLeft(left);
            if (proxy.model.enableVirtualization) {
                proxy.processBindings();
                var tempArgs = {};
                tempArgs.requestType = ej.TreeGrid.Actions.Refresh;
                proxy.sendDataRenderingRequest(tempArgs);
                if ((proxy.model.currentViewData.length * proxy.model.rowHeight) < proxy._viewPortHeight) {
                    var currentPosition = top - (proxy._viewPortHeight - proxy.model.currentViewData.length * proxy.model.rowHeight);
                    if (currentPosition < 0)
                        currentPosition = 0;
                    proxy._$gridContent.ejScroller("scrollY",currentPosition, true);
                }
            }
            proxy._resizeFilteringElements();
            
        },

        //PROCESSBINDING
        processBindings: function (args) {

            var proxy = this,
                model = proxy.model;

            model.query = new ej.Query();

            if (proxy._trigger("actionBegin", args)) {
                return true;
            }

            proxy._ensureDataSource(args);

        },

        _ensureDataSource: function (args) {

            var proxy = this,
                model = proxy.model,
                sortcolumns = model.sortSettings.sortedColumns,
                isupdatedHeight = false,
                index,
                childIndex;

            //if (model.dataSource == null) {
            //    return;
            //}

            model.query.requiresCount();
            proxy._queryManagar = model.query;

            if ((model.editSettings.allowEditing || model.editSettings.allowAdding) &&
                args && args.requestType == ej.TreeGrid.Actions.Save &&
                (!ej.isNullOrUndefined(args._cModifiedData) || !ej.isNullOrUndefined(args._cAddedRecord))) {

                if (ej.isNullOrUndefined(args._cAddedRecord)) {
                    $.extend(model.flatRecords[$.inArray(model.selectedItem, model.flatRecords)],
                        args._cModifiedData);
                } else {

                    var parentItem;

                    if (this.selectedRowIndex() === -1) {

                        args._cAddedRecord.hasChildRecords = false;
                        model.flatRecords.unshift(args._cAddedRecord);
                        model.records.unshift(args._cAddedRecord);
                        this.dataSource().unshift(args._cAddedRecord.item);

                        if (model.isFromGantt) {
                            model.ids.unshift(args._cAddedRecord.taskId);
                        }
                        args.recordIndex = 0;

                    } else {

                        args._cAddedRecord.level = model.selectedItem.level;
                        index = model.selectedItem ? model.flatRecords.indexOf(model.selectedItem) : 0;

                        if (args._cAddedRecord.level === 0) {
                            index = index > 0 ? index - 1 : index;
                        }

                        if (args.actionRequestType != ej.TreeGrid.Actions.ContextMenuAdd) {
                            args.recordIndex = index > 0 ? index - 1 : 0;
                        }

                        model.flatRecords.splice(index, 0, args._cAddedRecord);

                        var rowIndex = model.records.indexOf(model.selectedItem);
                        model.records.splice(rowIndex, 0, args._cAddedRecord);

                        if (model.isFromGantt) {
                            model.ids.splice(rowIndex, 0, args._cAddedRecord.taskId.toString());
                        }

                        if (args._cAddedRecord.level > 0) {

                            parentItem = model.selectedItem.parentItem;

                            if (parentItem) {

                                childIndex = parentItem.childRecords ?
                                    parentItem.childRecords.indexOf(model.selectedItem) : -1;

                                if (childIndex !== -1) {
                                    childIndex = childIndex === 0 ? 0 : childIndex - 1;
                                }

                                parentItem.childRecords.splice(childIndex, 0, args._cAddedRecord);

                            }
                        }

                        proxy.setRecordsCount(model.flatRecords.length);
                        proxy.setHeight(model.flatRecords.length * model.rowHeight);
                        proxy.updateHeight();
                        isupdatedHeight = true;

                    }
                    proxy._queryManagar.queries = [];
                    model.isEdit = false;
                    proxy._updatedGanttRecords = model.flatRecords;

                }
            }

            if (args && args.requestType === ej.TreeGrid.Actions.ExpandCollapse) {

                isupdatedHeight = true;
                // proxy.clearSelection(proxy.selectedRowIndex());
                proxy._filteredRecords = [];
                proxy._expandCollapseRecordCount = 0;
                proxy.updateExpandCollapseRecords(args.data, args.expanded);
                proxy.setRecordsCount(model.flatRecords.length);
                proxy.setHeight(model.flatRecords.length * model.rowHeight);
                proxy._updatedRecords = model.flatRecords;

                if (!model.enableVirtualization) {
                    if (model.allowSearching && proxy._searchString.length) {
                        proxy._updateFilteredRecords(proxy._tempfilteredrecords);
                        proxy.setRecordsCount(proxy._filteredRecords.length);
                        proxy.setHeight(proxy._filteredRecords * model.rowHeight);
                        proxy._updatedRecords = proxy._filteredRecords;
                    }

                    if (model.allowSorting && model.sortSettings.sortedColumns.length) {
                        proxy._updateExpandCollapseForSortedRecords(args.data, args.expanded);
                        proxy.setHeight(proxy._sortedRecords * model.rowHeight);
                        proxy._updatedRecords = proxy._sortedRecords;
                    }

                }
                proxy.updateHeight();

                if (model.enableAltRow) {
                    proxy._updateAltRow();
                }

            }

            if (model.editSettings.allowDeleting && args && args.requestType === ej.TreeGrid.Actions.Delete) {

                var deletedRow = args.data,
                    recordIndex,
                    rowindex;
                proxy._removedCount = 0;
                var childRecordsCount = proxy._getFilteredChildRecordsCount(deletedRow);
                childRecordsCount += 1;
                proxy._removedCount = 0;

                if (deletedRow.parentItem) {

                    var childRecords = deletedRow.parentItem.childRecords;
                    childIndex = childRecords.indexOf(deletedRow);

                    deletedRow.parentItem.childRecords.splice(childIndex, 1);
                    if(!model.parentIdMapping)
                        deletedRow.parentItem.item[proxy.model.childMapping].splice(childIndex, 1);
                }
                //Delete from parent collection if item is parent
                var parentIndex=model.parentRecords.indexOf(deletedRow);
                if (parentIndex!== -1)
                {
                    model.parentRecords.splice(parentIndex, 1);
                }
                recordIndex = proxy.model.flatRecords.indexOf(deletedRow);
                if (recordIndex!==-1)
                    proxy.model.flatRecords.splice(recordIndex, childRecordsCount);
                proxy.setRecordsCount(model.flatRecords.length);
                proxy.setHeight((model.flatRecords.length - proxy._totalCollapseRecordCount )* model.rowHeight);
                isupdatedHeight = false;
                index = model.records.indexOf(deletedRow);
                var deletedRecordCount = proxy.getChildCount(deletedRow, 0);
                model.records.splice(index, deletedRecordCount + 1);
                model.ids && model.ids.splice(index, deletedRecordCount + 1);
                proxy._updatedRecords = model.flatRecords;
                if(!model.parentIdMapping)
                {
                    if (this.dataSource() instanceof ej.DataManager) {
                        if (this.dataSource().dataSource.offline && this.dataSource().dataSource.json) {
                            rowindex = this.dataSource().dataSource.json.indexOf(deletedRow.item);
                            if (rowindex !== -1)
                                proxy.dataSource().dataSource.json.splice(rowindex, 1);
                        }
                    } else {
                        rowindex = this.dataSource().indexOf(deletedRow.item);
                        if (rowindex !== -1)
                            proxy.dataSource().splice(rowindex, 1);
                    }
                }
                else
                {
                    //remove child item
                    if (deletedRow.hasChildRecords && deletedRow.childRecords.length > 0)
                    {
                        proxy._removeChildItem(deletedRow);
                    }
                    //remove deleting item

                    if (this.dataSource() instanceof ej.DataManager) {
                        if (this.dataSource().dataSource.offline && this.dataSource().dataSource.json) {
                            var idx = this.dataSource().dataSource.json.indexOf(deletedRow.item);
                            if (idx !== -1)
                                this.dataSource().dataSource.json.splice(idx, 1);
                        }
                    }
                    else
                    {
                        var idx = this.dataSource().indexOf(deletedRow.item);
                        if (idx !== -1)
                            this.dataSource().splice(idx, 1);
                    }
                }
                model.selectedItem = null;
                this.selectedRowIndex(-1);
                if (!model.isFromGantt && deletedRow.parentItem)
                    if (deletedRow.parentItem.childRecords.length == 0) {
                        deletedRow.parentItem.expanded = false;
                        deletedRow.parentItem.hasChildRecords = false;
                    }
            }
            // Condition for filtering columns.
            if (model.allowFiltering && !model.isFromGantt && this._filteredColumns.length)
            {
                var predicate, firstFilterCondition = this._filteredColumns[0];
                // Condition to collect the details of filtering column.
                if (!firstFilterCondition.isComplex)
                    predicate = ej.Predicate(firstFilterCondition.field, firstFilterCondition.operator, firstFilterCondition.value, !firstFilterCondition.matchcase);
                else
                    predicate = firstFilterCondition;
                for (var i = 1; i < this._filteredColumns.length; i++) {
                    //Loop to gather all the column condition as array.
                    if (!this._filteredColumns[i].isComplex)
                        predicate = predicate[this._filteredColumns[i].predicate](this._filteredColumns[i].field, this._filteredColumns[i].operator, this._filteredColumns[i].value, !this._filteredColumns[i].matchcase);
                    else
                        predicate = predicate["and"](this._filteredColumns[i]);
                }
                proxy._queryManagar.where(predicate);
                proxy._filteredRecords = model.records.filter(function (record) {
                    return record.hasChildRecords === false;
                });
                var dataManager = new ej.DataManager(proxy._filteredRecords);
                proxy._tempfilteredrecords = dataManager.executeLocal(proxy._queryManagar).result;
                proxy._updateFilteredRecords(proxy._tempfilteredrecords);
                proxy.setRecordsCount(proxy._filteredRecords.length);
                proxy._updatedRecords = proxy._filteredRecords;
                if (model.allowSorting && model.sortSettings.sortedColumns.length > 0) {
                    proxy._sortingRecords();
                }
                proxy.setHeight(proxy._updatedRecords.length * model.rowHeight);
                proxy.updateHeight();
                isupdatedHeight = true;
                if (model.enableAltRow) {

                    proxy._updateAltRow();
                }
            }

            if ((model.allowSearching && proxy._searchString.length) || (args && args.requestType==="searching")) {

                proxy._queryManagar.search(proxy._searchString, proxy.getColumnFieldNames(),
                    ej.FilterOperators.contains, true);

                proxy._filteredRecords = model.records.filter(function (record) {
                    return record.hasChildRecords === false;
                });

                var dataManager = new ej.DataManager(proxy._filteredRecords);
                proxy._tempfilteredrecords = dataManager.executeLocal(proxy._queryManagar).result;
                proxy._updateFilteredRecords(proxy._tempfilteredrecords);
                proxy.setRecordsCount(proxy._filteredRecords.length);
                proxy._updatedRecords = proxy._filteredRecords;

                if (model.allowSorting && model.sortSettings.sortedColumns.length > 0) {
                    proxy._sortingRecords();
                }
                proxy.setHeight(proxy._updatedRecords.length * model.rowHeight);
                proxy.updateHeight();
                isupdatedHeight = true;

                if (model.enableAltRow) {

                    proxy._updateAltRow();
                }

            } else if (model.allowSorting && sortcolumns.length > 0) {

                isupdatedHeight = proxy._sortingRecords();
            }

            if ( args && args.requestType === "outdent") {
                args = {};
                args.requestType = ej.TreeGrid.Actions.Refresh;
                isupdatedHeight = true;
            }

            if (!isupdatedHeight) {

                proxy.setRecordsCount(model.flatRecords.length);
                proxy.setHeight((model.flatRecords.length - proxy._totalCollapseRecordCount) * model.rowHeight);
                proxy._updatedRecords = model.flatRecords;
                proxy.updateHeight();

            }

            if (!args) {
                args = {};
                args.requestType = ej.TreeGrid.Actions.Refresh;
            }

            proxy._updateCurrentViewData();

            if ((!model.isFromGantt && args.requestType === "save") || args.requestType === "sorting" || args.requestType === "searching" || args.requestType === "delete" || args.requestType === "refreshDataSource" ||args.requestType=="filtering") {
                proxy.renderRecords(args);
                proxy._setScrollTop();
                proxy._$gridContent.ejScroller("refresh");
                proxy._updateScrollCss();
            }

        },
        //remove child record in data source on self reference
        _removeChildItem: function (record) {
            var currentRecord, proxy = this;
            for (var i = 0; i < record.childRecords.length; i++) {
                currentRecord = record.childRecords[i];
                if (this.dataSource() instanceof ej.DataManager) {
                    if (this.dataSource().dataSource.offline && this.dataSource().dataSource.json) {
                        var idx = this.dataSource().dataSource.json.indexOf(currentRecord.item);
                        if(idx!==-1)
                            this.dataSource().dataSource.json.splice(idx, 1);

                        if (currentRecord.hasChildRecords) {
                            proxy._removeChildItem(currentRecord);
                        }
                    }
                } else {
                    var idx = this.dataSource().indexOf(currentRecord.item);
                    if (idx !== -1)
                        this.dataSource().splice(idx, 1);

                    if (currentRecord.hasChildRecords) {
                        proxy._removeChildItem(currentRecord);
                    }
                }
            }
        },

        //CHECK EDITING OPTIONS 
        _processEditing:function(){

            var proxy = this,
                model = proxy.model;

            if (model.editSettings.allowEditing || model.editSettings.allowAdding) {
                if (model.editSettings.editMode.toLowerCase() === "cellediting" || model.editSettings.editMode.toLowerCase() === "rowediting") {
                    proxy._addCellEditTemplate();
                }
            }

        },

        _toolBarClick: function (sender) {           
            var proxy = this,
               model = proxy.model,
               $gridEle = $(this.itemsContainer).closest(".e-treegrid"),
               gridInstance = $gridEle.ejTreeGrid("instance"),
               gridId = $gridEle.attr('id');
            
            if (sender.event == undefined && sender.target.tagName == "INPUT" && sender.currentTarget.id == gridId + "_search")
                return false;

            if (gridInstance.model.dateFormat.indexOf("hh") != -1)
                $.isFunction($.fn.ejDateTimePicker) && $("#" + gridId + "EditForm").find(".e-datepicker").ejDateTimePicker("hide");
            else
                $.isFunction($.fn.ejDatePicker) && $("#" + gridId + "EditForm").find(".e-datepicker").ejDatePicker("hide");


            if ($gridEle.ejTreeGrid("instance")._trigger("toolBarClick", sender))
                return false;

            switch (sender.currentTarget.id) {

                case gridId + "_add":
                    gridInstance._toolbarOperation(gridId + "_add", sender);
                    break;

                case gridId + "_edit":
                    gridInstance._toolbarOperation(gridId + "_edit", sender);
                    break;

                case gridId + "_delete":
                    gridInstance._toolbarOperation(gridId + "_delete", sender);
                    break;

                case gridId + "_update":
                    gridInstance._toolbarOperation(gridId + "_update", sender);
                    break;

                case gridId + "_cancel":
                    gridInstance._toolbarOperation(gridId + "_cancel", sender);
                    break;

                case gridId + "_expandAll":
                    gridInstance._toolbarOperation(gridId + "_expandAll", sender);
                    break;

                case gridId + "_collapseAll":
                    gridInstance._toolbarOperation(gridId + "_collapseAll", sender);
                    break;

            }
            return false;
        },
        _toolbarOperation: function (operation, searchEle) {
            var $gridEle = this.element, gridObject = $gridEle.ejTreeGrid("instance"), gridId = $gridEle.attr('id'), proxy = this;
            var selectedrow = this.selectedItem();
            var parentEle = searchEle.target
            var index = this.selectedRowIndex();
            switch (operation) {

                case gridId + "_add":
                    proxy._startAdd(parentEle,null);
                    break;
                    
                case gridId + "_edit":
                    proxy._editRow(index);
                    break;

                case gridId + "_delete":
                    proxy.deleteRow();
                    proxy._cancelSaveTools();
                    break;

                case gridId + "_update":
                    proxy._endEdit();
                    proxy._cancelSaveTools();

                    break;

                case gridId + "_cancel":
                    proxy.cancelRowEditCell();
                    proxy._cancelSaveTools();
                    break;

                case gridId + "_expandAll":
                    proxy._expandAll();
                    break;

                case gridId + "_collapseAll":
                    proxy.collapseAll();
                    break;

            }
            proxy._refreshToolBar();
            return false;
        },
        //Create the instances for newly added row.
        _createNewRowInstance: function (obj) {
            var keys = [];
            for (var key in obj) {
                keys.push(key);
            }
            return keys;
        },

         /* Public method for appending a new row in Treegrid
         *  arguments rowPosition for providing the position of newly added row
         */
        addRow:function(rowPosition){
            var proxy = this, model = proxy.model;
            if (model.selectedItem) {
                proxy._startAdd(null, rowPosition);
            }

        },

        _startAdd: function (parentEle, rowPos) {
            var proxy = this;            
            var rowIndex = this.selectedRowIndex();          
            var rowPosition = rowPos ? rowPos : proxy.model.editSettings.rowPosition;
            var length = proxy.model.currentViewData.length;
            var refindex;

            var headerColumn = proxy._headerColumnNames,
                    item = {};
            var columnitems = proxy._createNewRowInstance(headerColumn);
            for (var column = 0; column < columnitems.length; column++) {
                item[columnitems[column]] = null;
            }

            if (length>0) {                
                if (rowIndex == -1 && rowPosition != "bottom")
                    rowPosition = "top";
                //GET INDEX AND REFERENCE INDEX TO ADD A NEW ROW.
                if (rowPosition == "bottom") {
                    index = length;
                    refindex = length - 1;
                }
                else if (rowIndex != -1 && rowPosition == "aboveSelectedRow") {
                    index = rowIndex;
                    refindex = rowIndex;
                }
                else if (rowIndex != -1 && rowPosition == "belowSelectedRow") {
                    index = rowIndex + 1;
                    refindex = rowIndex;
                }
                else {
                    index = 0;
                    refindex = 0;
                }

                var ref = proxy.model.currentViewData[refindex];
                var getKeys = proxy._createNewRowInstance(ref);
                var addrow = {};                
                //TO EXPANDS AND COLLAPSES THE NEW ADDED ROW
                if (ref.parentItem || rowPosition=="bottom") {                   
                    var addrow = proxy._createRecord(item);                   
                    addrow.parentItem = ref.parentItem;
                    addrow.level = ref.level;
                    addrow.isAltRow = ref.isAltRow;
                    addrow.index = length + 1;
                    if (ref.fromEmpty)
                        addrow.fromEmpty = true;
                    //TO SORT NEWLY ADDED ROW IN CHILDRECORDS OF THE PARENTITEM.
                    if (ref.hasChildRecords) {
                        if (rowPosition == "belowSelectedRow") {
                            addrow.parentItem = ref;
                            addrow.level = ref.level + 1;
                            ref.childRecords.splice(0, 0, addrow);
                        }
                        else if (rowPosition == "aboveSelectedRow") {
                            var refabove = proxy.model.currentViewData[refindex - 1];
                            if (refabove.hasChildRecords) {
                                addrow.parentItem = ref.parentItem;
                                addrow.level = ref.level;
                                refabove.childRecords.splice(0, 0, addrow);
                            }
                            else {
                                addrow.parentItem = refabove.parentItem;
                                addrow.level = refabove.level;
                               refabove.parentItem.childRecords.splice(index, 0, addrow);
                            }
                        }                                               
                    }
                    else {
                        if (!ref.fromEmpty) {
                            ref.parentItem.childRecords.splice(index, 0, addrow);
                            ref.parentItem[proxy.model.childMapping].splice(index, 0, addrow.item);
                        }
                    }

                }
                if (!ref.parentItem) {
                    if (refindex != 0 && rowPosition == "aboveSelectedRow") {
                        var addrow = proxy._createRecord(item);                        
                        refabove = proxy.model.currentViewData[refindex - 1];
                        if (ref.fromEmpty) {
                            addrow.fromEmpty = true;
                            refabove = proxy.model.currentViewData[0];
                        }
                        addrow.parentItem = refabove.parentItem;
                        addrow.level = refabove.level;
                        if (!ref.fromEmpty) {
                            if (refabove.parentItem) {
                                refabove.parentItem.childRecords.splice(index, 0, addrow);
                                refabove.parentItem[proxy.model.childMapping].splice(index, 0, addrow.item);
                            }
                            else
                                //To sort the top most records.
                                proxy.model.parentRecords.splice(index, 0, addrow);
                        }
                    }
                    if (rowPosition == "belowSelectedRow") {
                        var addrow = proxy._createRecord(item);                        
                        refbelow = proxy.model.currentViewData[refindex + 1];
                        if (ref.fromEmpty) {
                            addrow.fromEmpty = true;
                            refbelow = proxy.model.currentViewData[0];
                        }
                        addrow.parentItem = refbelow.parentItem;
                        addrow.level = refbelow.level;
                        if (!ref.fromEmpty && refbelow.parentItem) {
                            refbelow.parentItem.childRecords.splice(index, 0, addrow);
                            refbelow.parentItem[proxy.model.childMapping].splice(index, 0, addrow.item);
                        }
                       
                    }
                   
                    //TO SORT TOP MOST ADDED ROW.
                    if (refindex == 0 && (rowPosition == "top" || rowPosition == "aboveSelectedRow")) {
                        var addrow = proxy._createRecord(item);                        
                        addrow.parentItem = ref.parentItem;
                        addrow.childRecords = undefined;
                        addrow.level = 0;
                        addrow.index = 0;
                        proxy.model.parentRecords.splice(index, 0, addrow);
                    }
                   
                }
                                            
                var previousIndex = proxy._previousIndex;              
                proxy.clearSelection(previousIndex);
                if (previousIndex != -1)
                proxy._updatedRecords[previousIndex].isSelected = false;                              

                proxy.model.currentViewData.splice(index, 0, addrow);                
            }
            else
            {                               
                var addrow = proxy._createRecord(item);
                addrow.parentItem = null;
                addrow.level = 0;
                addrow.index = 0;                
                addrow.fromEmpty = true;
                var index = addrow.index;
                proxy.model.currentViewData.push(addrow);
               
            }
            if (addrow.fromEmpty) {                
                proxy.model.parentRecords.splice(index, 0, addrow);
                var disableToolItems = [];
                if (!$($('.e-expandall')[0]).parent("li").hasClass("e-disable"))
                    disableToolItems.push($($('.e-expandall')[0]).parent()[0]);
                if (!$($('.e-collapseall')[0]).parent("li").hasClass("e-disable"))
                    disableToolItems.push($($('.e-collapseall')[0]).parent()[0]);
                $('.e-treegridtoolbar').ejToolbar('disableItem', disableToolItems);
            }            
           proxy.selectRows(index);
            proxy.renderRecords();           
            proxy._editRow(index, addrow);                      
        },
        //ENABLE AND DISABLE THE CORRESPONDING TOOLS WHILE ADDING AND EDITING THE ROW RECORD.
        _editAddTools: function () {
            var proxy = this;
            var editSettings = proxy.model.editSettings;
            var disableToolItems = [];
            if (editSettings.allowAdding)
                disableToolItems.push($($('.e-addnew')[0]).parent()[0]);
            if (editSettings.allowEditing && !$($('.e-edit')[0]).parent("li").hasClass("e-disable"))
                disableToolItems.push($($('.e-edit')[0]).parent()[0]);
            if (editSettings.allowDeleting && !$($('.e-delete')[0]).parent("li").hasClass("e-disable"))
                disableToolItems.push($($('.e-delete')[0]).parent()[0]);
            $('.e-treegridtoolbar').ejToolbar('disableItem', disableToolItems);

            var enabledToolItems = [];
            enabledToolItems.push($($('.e-cancel')[0]).parent()[0]);
            enabledToolItems.push($($('.e-save')[0]).parent()[0]);
            $('.e-treegridtoolbar').ejToolbar('enableItem', enabledToolItems);

        },
        //ENABLE AND DISABLE THE CORRESPONDING TOOLS WHILE CANCEL AND SAVING THE ROW RECORD.
        _cancelSaveTools: function () {
            var proxy = this;
            var model = proxy.model;
            var editSettings = proxy.model.editSettings;
            if (!model.isFromGantt) {
                var enabledToolItems = [];
                var disableToolItems = [];
                if (editSettings.allowAdding) {
                    if (proxy.model.toolbarSettings.toolbarItems.indexOf("add") !== -1)
                        enabledToolItems.push($($('.e-addnew')[0]).parent()[0]);
                }
                
                if (editSettings.allowEditing && proxy.model.toolbarSettings.toolbarItems.indexOf("edit") !== -1) {
                    if (proxy.model.selectedRowIndex != -1)
                        enabledToolItems.push($($('.e-edit')[0]).parent()[0]);
                   else if (!$($('.e-delete')[0]).parent("li").hasClass("e-disable"))
                        disableToolItems.push($($('.e-edit')[0]).parent()[0]);
                }
                if (editSettings.allowDeleting && proxy.model.toolbarSettings.toolbarItems.indexOf("delete") !== -1) {                   
                        if (proxy.model.selectedRowIndex != -1)
                            enabledToolItems.push($($('.e-delete')[0]).parent()[0]);
                       else if (!$($('.e-delete')[0]).parent("li").hasClass("e-disable"))
                            disableToolItems.push($($('.e-delete')[0]).parent()[0]);
                }
                
               

                if (!$($('.e-cancel')[0]).parent("li").hasClass("e-disable"))
                    disableToolItems.push($($('.e-cancel')[0]).parent()[0]);               
                if (!$($('.e-save')[0]).parent("li").hasClass("e-disable"))
                    disableToolItems.push($($('.e-save')[0]).parent()[0]);               

                $('.e-treegridtoolbar').ejToolbar('disableItem', disableToolItems);
                $('.e-treegridtoolbar').ejToolbar('enableItem', enabledToolItems);
            }
            else {
                var enabledToolItems = [];
                if (editSettings.allowAdding && proxy.model.toolbarSettings.toolbarItems.indexOf("add") !== -1)
                        enabledToolItems.push($($('.e-addnewitem')[0]).parent()[0]);
                
                if (editSettings.allowEditing && proxy.model.toolbarSettings.toolbarItems.indexOf("edit") !== -1) {
                    if (proxy.model.selectedRowIndex != -1)
                        enabledToolItems.push($($('.e-edititem')[0]).parent()[0]);
                }
                if (editSettings.allowDeleting && proxy.model.toolbarSettings.toolbarItems.indexOf("delete") !== -1) {
                    if (proxy.model.selectedRowIndex != -1)
                    enabledToolItems.push($($('.e-deleteitem')[0]).parent()[0]);
                }
                $('.e-gantttoolbar').ejToolbar('enableItem', enabledToolItems);

                var disableToolItems = [];
                if (proxy.model.toolbarSettings.toolbarItems.indexOf("cancel") !== -1)
                    disableToolItems.push($($('.e-cancel')[0]).parent()[0]);
                if (proxy.model.toolbarSettings.toolbarItems.indexOf("update") !== -1)
                    disableToolItems.push($($('.e-saveitem')[0]).parent()[0]);

                $('.e-gantttoolbar').ejToolbar('disableItem', disableToolItems);
            }

        },

        
        _checkIsEmptyRow:function(item){
            for (var key in item) {
                var val = item[key];
                if (val == " " || val == null || val == "")
                    continue;
                    return false;                
            }
            return true;
        },
              
        _beginEdit: function () {
            var proxy = this;
            proxy._trigger("beginEdit", args);
            proxy._isinBeginEdit = true;           
        },
        _endEdit: function () {
            var proxy = this;

            proxy._isinBeginEdit = false;
            proxy._trigger("endEdit");
            var index = this.selectedRowIndex();
            var tr = proxy._$gridRows[index];
            if ($('tr').hasClass("e-addedrow") || $('tr').hasClass("e-rowedit"))
                proxy._saveRow();
            else
                proxy.saveCell();
           // proxy.selectedRowIndex(index);
            proxy.getUpdatedRecords(index);
            
        },

        //Expand the child records from parent.
        _expandAll: function () {

            var proxy = this,
                model = proxy.model,
                count = 0,
                treegridRecord,
                args = {},
                enableVirtualization = model.enableVirtualization;

            proxy._isInExpandCollapse = true;

            //loop excecute for iterate the GanttRecords preseent in the Gantt Control

            for (count = 0; count < proxy._updatedRecords.length; count++) {
                treegridRecord = proxy._updatedRecords[count];
                args.data = treegridRecord;
                args.recordIndex = count;
                args.expanded = true;

                if (enableVirtualization) {
                    if (treegridRecord.hasChildRecords && !treegridRecord.expanded) {
                        ej.TreeGrid.sendExpandCollapseRequest(proxy, args);
                    }
                } else {
                    if (treegridRecord.hasChildRecords && !treegridRecord.expanded) {
                        ej.TreeGrid.sendExpandCollapseRequest(proxy, args);
                    }
                }
            }

            proxy._isInExpandCollapse = false;
            //To cancel the cell edit or row edit mode when expand the all record.
            if (proxy._isRowEdit || proxy.model.isEdit) {
                proxy.cancelRowEditCell();               
                proxy._cancelSaveTools();
            }
        },

           

        _refreshToolBar: function () {
            var $toolbar = $("#" + this._id + "_toolbarItems");
            $toolbar.find("li").removeClass("e-hover");
        },

        //RENDER TOOL BAR
        _renderToolbar: function () {
            var proxy = this,
            model = proxy.model;
            if (!model.isFromGantt) {
                var proxy = this, element = proxy.element, model = proxy.model;
                if (proxy.model.toolbarSettings.showToolbar) {
                    if (proxy.model.toolbarSettings.toolbarItems.length == 0)
                        proxy.model.toolbarSettings.toolbarItems = [ej.TreeGrid.ToolbarItems.Add,
                        ej.TreeGrid.ToolbarItems.Edit, ];
                    element.append(proxy._renderToolbarTemplate());
                }
            }
        },

        //RENDER TOOLBAR TEMPLATE
        _renderToolbarTemplate: function () {
            var proxy = this,
                model = proxy.model,
                $div = ej.buildTag("div.e-treegridtoolbar#" + proxy._id + "_toolbarItems", "", { 'height': '36px', 'border': '1px solid' }, {}),
                $ul = ej.buildTag("ul", "", { 'width': proxy._gridWidth, 'box-sizing': ' ' }, {});
            (!ej.isNullOrUndefined(model.toolbarSettings.toolbarItems) && model.toolbarSettings.toolbarItems.length) && proxy._renderLi($ul);
            $div.append($ul);
            var $customUl = ej.buildTag("ul");
            $div.append($customUl);
            var helper = {};
            helper.click = proxy._toolBarClick;
            helper.cssClass = "";
            helper.rtl = false;
            helper.itemSeparator = false;
            helper.itemLeave = proxy._toolbarItemLeave;
            helper.width= proxy._gridWidth,
            helper.fields = {
                id: "",
                tooltipText: "",
                imageUrl: "",
                text: "",
                imageAttributes: "",
                spriteCSS: "",
                htmlAttributes: "",
            };
            $div.ejToolbar(helper);
            $div.ejToolbar("disableItem", proxy._disabledToolItems);
            proxy._disabledToolItems = $();
            return $div;
        },
        //Render list to display the tools in toolbar.
        _renderLi: function ($ul) {
            var proxy = this,
                toolBarItems = proxy.model.toolbarSettings.toolbarItems,
                length = toolBarItems.length,
                i = 0,
                $li;
            for (i; i < length; i++) {

                $li = ej.buildTag("li", "", {}, {
                    id: proxy._id + "_" + toolBarItems[i],
                    "tabindex": "0"
                });

                if (toolBarItems[i] !== "search")
                    $li.css({ 'width': '30px', 'height': '24px', });

                proxy._renderLiContent($li, toolBarItems[i]);
                $ul.append($li);
            }
        },

        //RENDER TOOLBAR ICONS
        _renderLiContent: function ($li, item) {
            var $a, $input;
            var selectedRowIndex = this.model.selectedRowIndex;
            var editSetting = this.model.editSettings;
            switch (item) {

                case "add":
                    $a = ej.buildTag("span.e-addnew e-toolbaricons e-icon e-treegrid-add", "", {});                   
                    $li.attr("title", "Add");
                    if (!this.model.editSettings.allowAdding)
                        this._disabledToolItems.push($li.get(0));
                    break;

                case "edit":
                    $a = ej.buildTag("span.e-edit e-toolbaricons e-icon e-treegrid-edit", "", {});
                    $li.attr("title", "Edit");
                    if (!this.model.editSettings.allowEditing || selectedRowIndex == -1) {
                        this._disabledToolItems.push($li.get(0));
                    }

                    break;

                case "delete":
                    $li.attr("title", "Delete");
                    $a = ej.buildTag("span.e-delete e-toolbaricons e-icon e-treegrid-delete", "", {});

                    if (!this.model.editSettings.allowDeleting || selectedRowIndex == -1) {
                        this._disabledToolItems.push($li.get(0));
                    }

                    break;

                case "update":
                    $li.attr("title", "Update");
                    $a = ej.buildTag("span.e-save e-toolbaricons e-icon e-treegrid-save e-disabletool", "", {});
                    this._disabledToolItems.push($li.get(0));
                    break;

                case "cancel":
                    $li.attr("title", "Cancel");
                    $a = ej.buildTag("span.e-cancel e-toolbaricons e-icon e-treegrid-cancel e-disabletool", "", {});
                    this._disabledToolItems.push($li.get(0));
                    break;

                case "expandAll":
                    $li.attr("title", "ExpandAll");
                    $input = ej.buildTag("span.e-expandall e-toolbaricons e-icon e-treegrid-expandall", "", {}, {});
                    $li.append($input);
                    break;

                case "collapseAll":
                    $li.attr("title", "CollapseAll");
                    $input = ej.buildTag("span.e-collapseall e-toolbaricons e-icon e-treegrid-collapseall", "", {}, {});
                    $li.append($input);
                    break;
            }

            $li.append($a);
        },



        //#region TREEGRIDHEADER RENDERIGN

        //TREEGRID HEADER RENDER INITIALIZATION
        _renderAfterColumnInitialize:function(){
            var proxy = this;
            proxy.element.append(proxy._renderGridHeader());
        },

        //TO CHECK FILTER FORM ELEMENTS EDIT TYPE
        filterEditType: function (column, element, j) {

            var proxy = this,
                model = proxy.model;
               
            if (ej.isNullOrUndefined(column["filterEditType"]))
                column["filterEditType"] = "stringedit";

            switch (column["filterEditType"]) {
                case "stringedit":
                    element.html(ej.buildTag('input.e-ejinputtext e-filtertext e-field e-filterwidth', "", {}, { id: column.field + "_filterbarcell", name: column.field }));
                    break;
                case "booleanedit":
                    element.html('<input class="e-field e-checkbox e-filtertext" type ="checkbox" id=' + column.field + "_filterbarcell" + ' name=' + column.field + ' />');
                    break;
                case "numericedit":
                    var $numericText = ej.buildTag('input.e-numerictextbox e-field', "", { "width": column.width - 15 }, { type: "text", id: column.field + "_filterbarcell", name: column.field });
                    element.append($numericText);
                    break;
                case "datepicker":
                case "datetimepicker":
                    var $datePicker = ej.buildTag('input.e-' + column["filterEditType"] + ' e-field', "", {}, { type: "text", id: column.field + "_filterbarcell", name: column.field });
                    element.append($datePicker);
                    break;
                case "dropdownedit":
                    var $dropDownList = ej.buildTag('input.e-field .e-dropdownlist' + ' e-field', "", {}, { type: "text", id: column.field + "_filterbarcell", name: column.field });
                    element.append($dropDownList);
                    break;
            }
        },


        //RENDER FILTER BAR ELEMENTS ACCORDING TO ITS TYPE
        _filteringElements: function (args) {
            var proxy = this,
                model=proxy.model,
                elementFocused = false,
                $formElement,
                i = 0, form, length,
                $element,
                width,
                params = {},
                value,
                column,
                customParams,
                toformat,
                formatVal;
            selectedItem = model.selectedItem;

            if (args.requestType == "filtering") {
                form = document.getElementById(proxy._id + "_filterBar" + args.fieldname);
            }
            
            var column = customParams = ej.TreeGrid.getColumnByField(model.columns,args.fieldname)
            $formElement = $(form).find("input,select");
            length = $formElement.length;
            for (i; i < length; i++) {
                $element = $formElement.eq(i);
                params = {};
                //inputWidth = column.width ? column.width - 2 : proxy.model.commonWidth - 2;
                inputWidth = $element.closest("div").width()-2;
                if ($element.hasClass("e-numerictextbox")) {
                    width = inputWidth;
                    value = $element.val();
                    params.width = width;                    
                    params.showSpinButton = true;
                    params.cssClass = model.cssClass;
                    params.height = 28;
                    //for parent editing 
                    var tempId = $element[0].id;
                    tempId=tempId.replace(proxy._id, '');
                    if (model.filterBarMode=="immediate")
                        params.change = $.proxy(proxy._filterBarHandler, proxy, $element);

                    if (value.length)
                        params.value = parseFloat(value);
                    else
                        params.value = null;
                    customParams = ej.TreeGrid.getColumnByField(proxy.model.columns, $element.prop("name"));
                    if (!ej.isNullOrUndefined(customParams) && !ej.isNullOrUndefined(customParams["editParams"]))
                        $.extend(params, customParams["editParams"]);
                    $element.ejNumericTextbox(params);
                    $element.prop("name", $element.prop("name").replace(proxy._id, ""));
                }
                else if ($element.hasClass("e-datepicker")) {
                    width = inputWidth;
                    params.width = width;                    
                    params.cssClass = model.cssClass;
                    params.dateFormat = model.dateFormat;
                    params.locale = model.locale;
                    params.displayDefaultDate = true;
                    params.height = 28;
                    var tempId = $element[0].id;
                    tempId = tempId.replace(proxy._id, '');
                    //To filter the records once the date seleted.
                    if (model.filterBarMode == "immediate")
                    params.select = $.proxy(proxy._filterBarHandler, proxy, $element);
                    column = ej.TreeGrid.getColumnByField(proxy.model.columns, $element.prop("name"));
                    if (column["format"] !== undefined && column.format.length > 0) {
                        toformat = new RegExp("\\{0(:([^\\}]+))?\\}", "gm");
                        formatVal = toformat.exec(column.format);
                        params.dateFormat = formatVal[2];
                    }
                    if (!ej.isNullOrUndefined(column["editParams"]))
                        $.extend(params, column["editParams"]);

                    if (model.dateFormat.indexOf("hh") != -1)
                        $element.ejDateTimePicker(params);
                    else
                        $element.ejDatePicker(params);
                }
                else if ($element.hasClass("e-datetimepicker")) {
                    width = inputWidth;
                    params = {
                        width: width,
                        rtl: model.rtl,
                        locale:model.locale,
                        cssClass: model.cssClass,
                        showButton: false,

                    };
                    params.height = 28;
                    column = ej.TreeGrid.getColumnByField(proxy.model.columns, $element.prop("name"));
                    if (column["format"] !== undefined && column.format.length > 0) {
                        toformat = new RegExp("\\{0(:([^\\}]+))?\\}", "gm");
                        formatVal = toformat.exec(column.format);
                        params.dateTimeFormat = formatVal[2];
                    }
                    if (!ej.isNullOrUndefined(column["editParams"]))
                        $.extend(params, column["editParams"]);

                    if (model.dateFormat.indexOf("hh") != -1)
                        $element.ejDateTimePicker(params);
                    else
                        $element.ejDatePicker(params);

                }
                else if ($element.hasClass("e-dropdownlist")) {
                    column = ej.TreeGrid.getColumnByField(proxy.model.columns, $element.prop("name"));
                    var dataSource = column.dropdownData;
                    var checkReadonly=false;
                    if (selectedItem !== null && selectedItem.hasChildRecords && args.requestType !== "add")
                    {
                        checkReadonly=true;
                    }

                    $element.ejDropDownList({
                        width:inputWidth,
                        showCheckbox: true,
                        dataSource: dataSource,
                        readOnly: checkReadonly,
                        height : 28,
                        fields: { id: model.resourceIdMapping, text: model.resourceNameMapping, value: model.resourceNameMapping },
                        selectedItems: proxy.getIndexofresourceInfo(dataSource,args.data)
                    });
                    $element.ejDropDownList("setSelectedValue", $element.val());
                } else {
                    switch ($element.prop('tagName')) {
                        case "INPUT":
                            $element.width(inputWidth-4);
                            break;

                        case "SELECT":
                            $element.width(inputWidth).height(15);
                            break;
                    }
                }
                if (!$element.is(":disabled") && !elementFocused && (!$element.is(":hidden") || typeof $element.data("ejDropDownList") == "object")) {
                    if (!proxy._isEnterKeyPressed) {
                        elementFocused = true;
                    }
                }
            }
        },

        // METHOD TO RENDER FILDERING ELEMENTS
        _renderFiltering: function () {
            var proxy = this,
            columns = this.model.columns;
            var $tr = ej.buildTag('tr.e-filterbar', "", {}, {});
            for (var column = 0; column < this.model.columns.length; column++) {

                if (proxy.model.allowFiltering) {
                    var $th = ej.buildTag('th.e-filterbarcell .e-editValue', "", {}, {});
                    $div = ej.buildTag('div.e-filterdiv', "", {}, { id: proxy._id + "_filterBar" + columns[column].field });
                    $tr.append($th.append($div));
                    //Condition to check whether allow filtering enabled for the individual column before rendering filtering elements
                    if (columns[column].allowFiltering==false)
                        continue;
                    else {                        
                       
                        this.filterEditType(columns[column], $div, column);
                        var $span = ej.buildTag('span.e-cancel e-icon e-hide e-spanstyle');
                        this.model.columns[column]["visible"] === false && $th.addClass("e-hide");
                        $div.append($span);
                    }                   
                }          
            }
            return $tr;
        },

        //METHOD FOR RENDERING TREEGRID HEADER
        _renderGridHeader: function () {

            var proxy = this,
                model = proxy.model,
                doc = document,
                $innerDiv = ej.buildTag('div.e-gridheadercontainer', "", { "overflow": "hidden" }, {}),
                $table = ej.buildTag('table.e-table', "", {}, { "cellspacing": "0px", "border-spacing": "0px" }),
                $thead = ej.buildTag('thead'),
                $tbody = ej.buildTag('tbody.e-hide'),
                $columnHeader = ej.buildTag('tr.e-columnheader'),
                $colGroup = $(doc.createElement('colgroup')),
                $rowBody = $(doc.createElement('tr')),
                columnCount = 0,
                columns = model.columns,
                length = columns.length,
                $headerCell,
                bodyCell,
                $headerCellDiv,
                col,
                $div = model.isFromGantt ? ej.buildTag('div.e-gridheader#' + proxy._id + "e-gridheader", "", {}, "") :
                    ej.buildTag('div.e-gridheader#' + proxy._id + "e-gridheader", "",
                {
                    "border-top-style": "solid",
                    "border-left-style": "solid",
                    "border-right-style": "solid",
                    "border-top-width": "1px",
                    "border-left-width": "1px",
                    "border-right-width": "1px",
                    "width": proxy._gridWidth,
                }, "");
            

            proxy.setGridHeaderContent($div);
            proxy._$gridHeaderContainer = $innerDiv;
            proxy._hiddenColumns = [];

            //CHECK SORTING ENABLED OR NOT
            if (model.allowSorting) {
                $columnHeader.css({ 'cursor': 'pointer' });
            }

            for (columnCount; columnCount < length; columnCount++) {
                if (columns[columnCount]) {
                    $headerCell = ej.buildTag('th.e-headercell', "", { "height": "45px" }, {});
                    bodyCell = doc.createElement('td');

                    $headerCellDiv = ej.buildTag(
                        'div.e-headercelldiv',
                        columns[columnCount]["headerText"] == undefined ?
                        columns[columnCount]["headerText"] = columns[columnCount]["field"] :
                        columns[columnCount]["headerText"], {}, { 'unselectable': "on" }
                    );

                    $headerCell.append($headerCellDiv);

                    col = doc.createElement('col');

                    $rowBody.append(bodyCell);
                    $columnHeader.append($headerCell);
                    $colGroup.append(col);


                    //CHECK VISIBLE PROPERTY OF THE COLUMN
                    if (columns[columnCount]["visible"] === false) {
                        $headerCell.addClass("e-hide") && $(col).css("display", "none") &&
                        proxy._hiddenColumns.push(columns[columnCount].headerText);

                    } else {
                        proxy._visibleColumns.push(columns[columnCount].headerText);
                        columns[columnCount]["visible"] = true;
                    }

                    if (columns[columnCount]["allowSorting"] === false) {
                        proxy._disabledSortableColumns.push(columns[columnCount].headerText);
                        $headerCell.css({ 'cursor': 'normal' });
                    }

                    if (!ej.isNullOrUndefined(columns[columnCount]["headerTemplateID"])) {
                        $headerCellDiv.html($(columns[columnCount]["headerTemplateID"]).hide().html()).parent().addClass("headertemplate");
                    }

                    if (columns[columnCount]["width"] == undefined && model.commonWidth !== undefined) {
                        proxy._columnsWidthCollection[columnCount] = model.commonWidth;
                    } else {
                        proxy._columnsWidthCollection.push(columns[columnCount]["width"]);
                    }

                    proxy._fieldColumnNames[columns[columnCount].headerText] = columns[columnCount].field;
                    proxy._headerColumnNames[columns[columnCount].field] = columns[columnCount].headerText;
                }
            }
            // Condition to check whether filtering enabled to render filter elements.
            $filterHeader = ej.buildTag('tr.e-filterbar');
            if (this.model.allowFiltering && !proxy.model.isFromGantt)
            {
                $filterHeader = this._renderFiltering();
            }

            $thead.append($columnHeader).append($filterHeader);
            $table.append($colGroup).append($thead);

            $innerDiv.html($table);
            $div.html($innerDiv);

            proxy.setGridHeaderTable($table);

            return $div;
        },

        //#endregion

        //#region TREEGRIDCONTENT RENDERING
        //TREEGRID CONTENT RENDER INITIALIZATION
        _initGridRender: function () {

            var proxy = this;
            proxy._addInitTemplate();
            proxy._renderGrid();

            //CHECK COLUMN RESIZE IS ENABLED OR NOT AND INITIALIZE THE RESIZER
            if (proxy.model.allowColumnResize) {
                proxy._resizer = new ej.Grid.gridResize(proxy);
            }

        },


        //ADD GRIDCONTENT TO THE TREEGRID
        _renderGrid: function () {
            
            var proxy = this;
            proxy._renderGridContent().insertAfter(proxy.element.children(".e-gridheader"));
            proxy._initialEndRendering();

        },


        //RENDER THE GRIDCONTENT
        _renderGridContent:function(){
            
            var proxy = this,
                doc = document,
                model = proxy.model,
                $tbody = $(doc.createElement('tbody')),
                $div = ej.buildTag("div.e-gridcontent#" + proxy._id + "e-gridcontent", "",
                {                    
                    "height": proxy._viewPortHeight
                },
                {"unselectable":"on"}),
                $innderDiv = ej.buildTag('div.e-gridcontainer#' + proxy._id + "e-gridcontainer", "", {}, {});

            //CHECK VIRTUALIZATION ENABLED OR NOT
            if (model.enableVirtualization) {
                $innderDiv.css({ 'height': proxy._totalHeight });
            }

            var $table = ej.buildTag('table.e-table#' + proxy._id + "e-table", "",
                {top: "0px" }, { 'cellspacing': '0px' });

            $table.append(proxy.getHeaderTable().find('colgroup').clone()).append($tbody);
            $innderDiv.html($table);
            $div.html($innderDiv);
            proxy.setGridContentTable($table);

            //CHECK DATASOURCE IS DEFINED OR NOT
            if (this.dataSource() === null) {
                var $emptyTd = ej.buildTag('td', model.emptyRecordText, {}, { colSpan: model.columns.length });
                $tbody.append($(doc.createElement("tr")).append($emptyTd));
                $innderDiv.css('height', model.rowHeight);
            } else
            {
                proxy.renderRecords();
            }

            if (!model.isFromGantt) {
                $div.css({
                    "border-bottom-style": "solid",
                    "border-bottom-width": "1px",
                    "border-left-style": "solid",
                    "border-left-width": "1px",
                    "border-right-style": "solid",
                    "border-right-width": "1px",
                    "width": "auto",
                    "height":"auto"
                });
            }

            $table.css({ 'position': 'relative' });
            return $div;

        },


        //AFTER INITIALIZATION END RENDERING
        _initialEndRendering: function () {

            var proxy = this,
                index = proxy.selectedRowIndex();

            if (index != -1 && proxy.model.allowSelection) {

                if (!proxy._rowSelectingEventTrigger()) {

                    proxy.selectRows(index);
                    proxy._rowSelectedEventTrigger(index);

                }
            }
        },

        //#endregion
        
        //#region TEMPLATE

        //ADD CELLEDITING TEMPLATE
        _addCellEditTemplate: function () {

            var proxy = this,
                model = proxy.model,
                columns = model.columns,
                columnCount = 0,
                $outerDiv = ej.buildTag('div', "", { display: 'none' }, { id: proxy._id + "_CellEditTemplate" }),
                $innerDiv,
                length =columns&& columns.length;

            for (columnCount = 0; columnCount < length; columnCount++) {
                if (columns[columnCount]) {
                    $innerDiv = ej.buildTag('div', "", {}, { id: columns[columnCount].field + "_CellEdit" });
                    ej.TreeGrid._initCellEditType(proxy, $innerDiv, proxy._id, columnCount);
                    $outerDiv.append($innerDiv);
                }
            }

            if ($outerDiv.children().length) {
                proxy._cellEditTemplate = $outerDiv;
            }

        },


        //ADD TEMPLATE FOR RENDERING GRIDCONTENT
        _addInitTemplate:function(){

            var proxy = this,
                model = proxy.model,
                columns = model.columns,
                columnCount = 0,
                length = columns.length,
                columnName,
                tdCell,
                helpers = {};

            //CHECK THE COLUMNS ARRAY CONTAIN THE COLUMN OBJECT
            if (columns.length === 0) {
                return false;
            }

            helpers["_" + proxy._id + "rowClassName"] = ej.TreeGrid._getrowClassName;
            helpers["_" + proxy._id + "expandStatus"] = $.proxy(proxy._getExpandStatusRecord, proxy);         
            helpers["_" + proxy._id + "cellValue"] = proxy._getCellValue;
            helpers["_" + proxy._id + "getIndentWidth"] = $.proxy(proxy._getIndentWidth, proxy);
            helpers["_" + proxy._id + "checkColumn"] = $.proxy(proxy._getCellColumn, proxy);

            helpers["_treeGridTemplating"] = ej.proxy(proxy._gridTemplate, null, proxy);
            helpers["_" + proxy._id + "itemDetails"] = $.proxy(proxy._convertItemToString, proxy);

            $.views.helpers(helpers);

            
            if (model.rowTemplateID.length > 0) {
                
                var altRowTemplateElement = ej.buildTag("tbody", "", {}, {});
                var rowTemplateElement = ej.buildTag("tbody", "", {}, {});
                var rowTemplateHTML = "";
                var altRowTemplateHTML = "";


                var altRowTemplate = model.altRowTemplateID.length > 0 ? $("#" + model.altRowTemplateID)[0].innerHTML : $("#" + model.rowTemplateID)[0].innerHTML;

                $(altRowTemplateElement[0]).html(altRowTemplate);
                $(rowTemplateElement[0]).html($("#" + model.rowTemplateID)[0].innerHTML);

                if (rowTemplateElement[0].childNodes.length > 0) {
                    for (var i = 0; i < rowTemplateElement[0].childNodes.length; i++) {
                        if (rowTemplateElement[0].childNodes[i].nodeName == 'TR') {

                            rowTemplateElement[0].className = rowTemplateElement[0].childNodes[i].className;
                            rowTemplateElement[0].style.cssText = rowTemplateElement[0].childNodes[i].style.cssText;

                            if (rowTemplateElement[0].childNodes[i].childNodes.length > 0) {
                                var tdCount = 0;
                                for (var j = 0; j < rowTemplateElement[0].childNodes[i].childNodes.length; j++) {

                                    var childNode = rowTemplateElement[0].childNodes[i].childNodes[j];

                                    if (childNode.nodeName == 'TD') {
                                        var innerHtml = childNode.innerHTML;

                                        $("#" + proxy._id + "RowTemplateElement" + tdCount).remove();
                                        var scriptElement = this._createRowTemplateElement(innerHtml, tdCount);
                                        childNode.innerHTML = "{{:~_treeGridTemplating('" + scriptElement.id + "')}}";


                                        childNode.className += " e-rowcell e-templatecell";
                                        if (tdCount == model.treeColumnIndex) {
                                            var indentDiv = "<div  style='height:20px;' unselectable='on'>" +
                                            "<div class='intend' style='height:1px; float:left;width:{{:~_" + proxy._id + "getIndentWidth(#data)}}; display:inline-block;'></div>" +
                                            "<div class='{{if expanded}}e-treegridexpand e-icon{{else hasChildRecords}}e-treegridcollapse e-icon{{/if}}' " +
                                            "style='height:20px;width:30px;margin:auto;float:left;margin-left:10px;style='float: left;display:inline-block; unselectable='on'></div>"+
                                             "<div class='e-cell' style='display:inline-block;width:100%' unselectable='on'>";

                                            rowTemplateHTML += "<td class='" + childNode.className + "{{if isSelected}}e-selectionbackground{{/if}}' style='"
                                                + childNode.style.cssText + "'>" + indentDiv +
                                                childNode.innerHTML + "</div></div></td>";
                                        }
                                        else {
                                            rowTemplateHTML += childNode.outerHTML;
                                        }
                                        tdCount++;
                                    }
                                }
                            }
                        }
                    }
                }

                if (altRowTemplateElement[0].childNodes.length > 0) {
                    for (var i = 0; i < altRowTemplateElement[0].childNodes.length; i++) {
                        if (altRowTemplateElement[0].childNodes[i].nodeName == 'TR') {
                            altRowTemplateElement[0].className = altRowTemplateElement[0].childNodes[i].className;
                            altRowTemplateElement[0].style.cssText = altRowTemplateElement[0].childNodes[i].style.cssText;
                            var tdCount = 0;

                            for (var j = 0; j < altRowTemplateElement[0].childNodes[i].childNodes.length; j++) {

                                var childNode = altRowTemplateElement[0].childNodes[i].childNodes[j];

                                if (childNode.nodeName == 'TD') {

                                    var innerHtml = childNode.innerHTML;
                                    $("#" + proxy._id + "RowTemplateElement" + tdCount).remove();
                                    var scriptElement = this._createRowTemplateElement(innerHtml, tdCount);
                                    childNode.innerHTML = "{{:~_treeGridTemplating('" + scriptElement.id + "')}}";

                                    childNode.className += " e-rowcell e-templatecell";

                                    if (tdCount == model.treeColumnIndex) {
                                        var indentDiv = "<div  style='height:20px;' unselectable='on'>" +
                                        "<div class='intend' style='height:1px; float:left;width:{{:~_" + proxy._id + "getIndentWidth(#data)}}; display:inline-block;'></div>" +
                                        "<div class='{{if expanded}}e-treegridexpand e-icon{{else hasChildRecords}}e-treegridcollapse e-icon{{/if}}' " +
                                        "style='height:20px;width:30px;margin:auto;float:left;margin-left:10px;style='float: left;display:inline-block; unselectable='on'></div>" +
                                        "<div class='e-cell' style='display:inline-block;width:100%' unselectable='on'>";

                                        altRowTemplateHTML += "<td class='" + childNode.className + "{{if isSelected}}e-selectionbackground{{/if}}'" +
                                            " style='" + childNode.style.cssText + "'>" + indentDiv +
                                            childNode.innerHTML + "</div></div></td>";

                                    }
                                    else {
                                        altRowTemplateHTML += childNode.outerHTML;
                                    }
                                    tdCount++;
                                }
                            }
                        }
                    }
                }
               
                var trRow = "{{if isAltRow}}" + "<tr class='{{:~_" + proxy._id + "rowClassName()}} " +
                    "{{if expanded}}e-treegridrowexpand {{else hasChildRecords}} e-treegridrowcollapse {{/if}} e-templaterow"
                    + altRowTemplateElement[0].className + "'  style='" + altRowTemplateElement[0].style.cssText + "'>" + altRowTemplateHTML + "</tr>"

                    + "{{else}}" + "<tr class='{{:~_" + proxy._id + "rowClassName()}} " +
                    "{{if expanded}}e-treegridrowexpand {{else hasChildRecords}} e-treegridrowcollapse {{/if}} e-templaterow"
                    + rowTemplateElement[0].className + "'  style='" + rowTemplateElement[0].style.cssText + "'>" + rowTemplateHTML + "</tr>" +
                    "{{/if}}";

            }

            else {

                var trRow = "<tr class='e-treegridrows {{:~_" + proxy._id + "rowClassName()}} ";

                if (model.enableAltRow) {
                    trRow += "{{if isAltRow}}e-alt-row{{/if}} ";
                }

              
                var tdCellCollections = "";

                for (columnCount = 0; columnCount < length; columnCount++) {
                    if (columns[columnCount]) {
                        columnName = columns[columnCount].field;

                        //CHECK THE template COLUMN OR NOT
                        if (columns[columnCount]["isTemplateColumn"]) {

                            trRow += "e-templaterow "

                            var templateId = columns[columnCount]["templateID"],
                                template = columns[columnCount]["template"],
                                angularTemplate = columns[columnCount]["angularTemplate"];

                            if (angularTemplate) {
                                $("#" + proxy._id + columns[columnCount].headerText + columnCount + "_Template").remove();
                                var scriptElement = this._createTemplateElement(columns[columnCount]);

                                tdCell = "<td style=''" +
                                     "class='{{if isSelected}}e-rowcell e-selectionbackground e-intend {{else}}e-rowcell e-intend {{/if}} e-templatecell'" +
                                     "role='gridcell'" +
                                     "'tabindex='-1'>{{:~_treeGridTemplating('" + scriptElement.id + "')}}</td>";
                            }

                            else if (templateId) {

                                tdCell = "<td style=''" +
                                     "class='{{if isSelected}}e-rowcell e-selectionbackground e-intend {{else}}e-rowcell e-intend {{/if}} e-templatecell'" +
                                     "role='gridcell'" +
                                     "'tabindex='-1'" +
                                     "aria-label={{:~_" + proxy._id + "itemDetails(#data)}}>" +
                                      $("#" + templateId)[0].innerHTML +
                                     "</td>";

                            } else if (template) {

                                tdCell = "<td " +
                                     "class='{{if isSelected}}e-rowcell e-selectionbackground e-intend {{else}}" +
                                     "e-rowcell e-intend {{/if}} e-templatecell'" +
                                     "role='gridcell'" +
                                     "tabindex='-1'" +
                                     "aria-label={{:~_" + proxy._id + "itemDetails(#data)}}>" +
                                     template +
                                     "</td>";
                            }

                            //EXPAND COLLAPSE COLUMN BASED ON THE TREECOLUMNINDEX
                        } else if (columnCount === model.treeColumnIndex) {

                            tdCell = "<td " +
                                 "class='{{if isSelected}}e-rowcell e-selectionbackground e-intend {{else}}e-rowcell e-intend {{/if}}'" +
                                "style='background-color:{{if cellBackgroundColor && ~_" + proxy._id + "checkColumn('" + columnName + "',#data)=='" + columnName + "'}}{{:cellBackgroundColor}}{{else}}none{{/if}};'" +
                                 "role='gridcell'" +
                                 "tabindex='-1'" +
                                 "aria-label={{:~_" + proxy._id + "itemDetails(#data)}}>" +
                                 "<div  style='height:20px;' unselectable='on'>" +
                                 "{{if hasChildRecords}}" +
                                 "<div " +
                                 "class='intend'" +
                                 "style='height:1px; float:left; width:{{:level*20}}" + "px; display:inline-block;'>" +
                                 "</div>" +
                                 "{{else !hasChildRecords}}" +
                                 "<div " +
                                 "class='intend'" +
                                 "style='height:1px; float:left; width:{{:(level+1)*20}}" + "px; display:inline-block;'>" +
                                 "</div>" +
                                 "{{/if}}" +
                                 "<div " +
                                 "class='{{if expanded}}e-treegridexpand e-icon{{else hasChildRecords}}" +
                                 "e-treegridcollapse e-icon{{/if}}'" +
                                 "style='float: left;display:inline-block; font-size:10px; unselectable='on''>" +//unselectable on icon div
                                 "</div>" +
                                 "<div class='e-cell'" +
                                 "style='display:inline-block;width:100%;' unselectable='on'>" +//unselectable on
                                 "{{:#data['" + columnName + "']}}" +
                                 "</div>" +
                                 "</div>" +
                                 "</td>";
                            //CHECK RESOURCE COLUMN FROM GANTT OR NOT
                        } else if (model.isFromGantt && columns[columnCount].mappingName === model.resourceInfoMapping) {
                            helpers = {};
                            helpers["_" + proxy._id + "resourceName"] = proxy._getResourceName;
                            $.views.helpers(helpers);

                            tdCell = "<td  " +
                                 "class='{{if isSelected}}e-rowcell e-selectionbackground{{else}}e-rowcell {{/if}}'" +
                                "style='background-color:{{if cellBackgroundColor && ~_" + proxy._id + "checkColumn('" + columnName + "',#data)=='" + columnName + "'}}{{:cellBackgroundColor}}{{else}}none{{/if}};'" +
                                 "role='gridcell'" +
                                 "tabindex='-1'" +
                                 "aria-label={{:~_" + proxy._id + "itemDetails(#data)}}>" +
                                 "{{:~_" + proxy._id + "resourceName('" + proxy._id + "Object','"
                                 + model.resourceNameMapping + "','" + columnName + "')}}" +
                                 "</td>";
                            //CHECK PREDECESSOR COLUMN FROM GANTT OR NOT
                        } else if (model.isFromGantt && columns[columnCount].mappingName === model.predecessorMapping) {

                            helpers = {};
                            helpers["_" + proxy._id + "predecessor"] = proxy._getPredecessorsValue;
                            $.views.helpers(helpers);

                            tdCell = "<td " +
                                "class='{{if isSelected}}e-rowcell e-selectionbackground{{else}}e-rowcell {{/if}}' " +
                                "style='background-color:{{if cellBackgroundColor && ~_" + proxy._id + "checkColumn('" + columnName + "',#data)=='" + columnName + "'}}{{:cellBackgroundColor}}{{else}}none{{/if}};'" +
                                "role='gridcell'" +
                                "tabindex='-1'" +
                                "aria-label={{:~_" + proxy._id + "itemDetails(#data)}}>" +
                                "{{:~_" + proxy._id + "predecessor('" + proxy._id + "Object','"
                                + model.predecessorMapping + "','" + columnName + "')}}" +
                                "</td>";

                        }
                        else {
                            tdCell = "<td " +
                                "class='{{if isSelected}}e-rowcell e-selectionbackground{{else}}e-rowcell{{/if}}'" +
                                "style='background-color:{{if cellBackgroundColor && ~_" + proxy._id + "checkColumn('" + columnName + "',#data)=='" + columnName + "'}}{{:cellBackgroundColor}}{{else}}none{{/if}};'" +
                                "role='gridcell'" +
                                "tabindex='-1'" +
                                "aria-label={{:~_" + proxy._id + "itemDetails(#data)}} unselectable='on'>" +
                                "{{:~_" + proxy._id + "cellValue('" + columnName + "')}}" +
                                "</td>";//unselectable for 
                        }

                        tdCellCollections += tdCell;
                    }
                }

                trRow += "{{if expanded}}e-treegridrowexpand {{else hasChildRecords}} " +
                      "e-treegridrowcollapse {{/if}} '" +
                      "style='background-color:{{if rowBackgroundColor }}{{:rowBackgroundColor}}{{else}}none{{/if}}; height:" + model.rowHeight + "px;display:{{:~_" + proxy._id + "expandStatus(#data)}}'" +
                      "role='row'>";

                trRow += tdCellCollections;

                if (model.isFromGantt) {
                    trRow += "<td class='e-extendcolumn'></td></tr>";
                }
            }

            var templates = {};
                templates[proxy._id + "_Template"] = trRow;
            $.templates(templates);

            

        },
        
        //#endregion template

        //#region template METHODS

        _gridTemplate: function (self, templateId) {
            return self._renderEjTemplate("#" + templateId, this.data, this.data.index);
        },

        //method for calculating the indent width for expander column
        _getIndentWidth:function(data){
            var level = data.level;
            if (data.hasChildRecords) {
                return (level * 20) + "px";
            }
            else {
                return ((level + 1) * 20) + "px";
            }
        },

        //creating template element for angulartemplate in row template
        _createRowTemplateElement: function (innerHtml, cellCount) {
            var scriptElement = document.createElement("script");
            scriptElement.id = ("treeGridRowTemplateElement" + cellCount).split("").join("");
            scriptElement.type = "text/x-template";
            scriptElement.text = innerHtml;

            $("body").append(scriptElement);
            return scriptElement;
        },

        //creating a template element for angularjs template
        _createTemplateElement: function (column) {
            var scriptElement = document.createElement("script");
            scriptElement.id = ("treeGrid" + column.headerText + $.inArray(column, this.model.columns) + "_Template").split(" ").join("");
            scriptElement.type = "text/x-template";
            scriptElement.text = $(column["angularTemplate"]).html();



            $("body").append(scriptElement);
            return scriptElement;
        },

        //CONVERT RECORD OBJECT TO STRING
        _convertItemToString: function (data) {

            var str = '',
                labelObject = {},
                columns = this.model.columns;

            for (var i = 0; i < columns.length; i++) {
                if (columns[i]) {
                    labelObject[columns[i].field] = data.item[columns[i].field];
                }
            }

            for (var p in labelObject) {
                if (labelObject.hasOwnProperty(p)) {
                    str += p + '' + labelObject[p] + '\n';
                }
            }

            return str;
        },

        _getCellValue: function (columnName) {

            var cellValue = this.data[columnName];

            if (cellValue || cellValue===0) {
                return cellValue;
            } else {
                return this.data.item && this.data.item[columnName];
            }


        },

        _getCellColumn: function (columnName,data) {
            var proxy = this;

            if (data.treeMappingName.indexOf(columnName) !== -1) {
                return columnName;
            }
            else {
                return "none"
            }


        },

        //GET RESOURCE NAME FOR RESOURCE COLUMN IN THE GANTT CONTROL
        _getResourceName: function (gridObject, mappingName, columnName) {

            var proxy = this,
                data = proxy.data[columnName],
                count = 0,
                length = data && data.length,
                resourceName = [];

            if (data && data.length > 0) {
                for (count; count < length; count++) {
                    resourceName.push(data[count][mappingName]);
                }
            }
            return resourceName;
        },


        //GET PREDECESSOR VALUE FOR PREDECESSOR COLUMN IN THE GANTT CONTROL
        _getPredecessorsValue: function (gridObject, mappingName) {

            return this.data.item[mappingName];

        },


        //GET THE EXPAND COLLAPSE STATUS OF TABLE ROW
        _getExpandStatusRecord: function (data) {

            var proxy = this;

            if (proxy.getExpandStatus(data)) {

                return 'table-row';

            }

            return 'none';
        },

        //#endregion TEMPLATE METHODS

        //#region CONVERT HIERARCHICAL RECORDS TO FLAT RECORDS
        //CREATE FLATRECORDS FROM HIERARCHICAL DATASOURCE
        _createRecords: function (dataSource) {

            var proxy = this,
                model = proxy.model,
                flatRecords = model.flatRecords,
                length = dataSource.length,
                count = 0,
                parentRecord,
                parentRecords = model.parentRecords,
                rows = model.records;                

            for (count; count < length; count++) {

                parentRecord = proxy._createRecord(dataSource[count], 0, null);
                proxy._storedIndex++;

                //CHECK ALTROW ENABLED OR NOT
                //if (enableAltRow) {     //  DYNAMICALY CHANGE THE ALTROW 
                parentRecord.isAltRow = proxy._storedIndex % 2 == 0 ? false : true;
                //}

                //CHECK SORTING ENABLED OR NOT
                //if (enableSorting) {//  DYNAMICALY CHANGE THE ALTROW 
                parentRecords.push(parentRecord);
                //}

                parentRecord.index = proxy._storedIndex;
                rows[proxy._storedIndex] = parentRecord;
                flatRecords.push(parentRecord);
                parentRecord.childRecords && proxy._addNestedRecords(parentRecord.childRecords);

            }
        },


        //CREATE RECORD OBJECT
        _createRecord: function (data, level, parentItem, expanded) {

            var proxy = this,
                record,
                childDataSource = data[proxy.model.childMapping],model=this.model;

            //CLONE THE DATA OBJECT
            record = $.extend({}, data);
            var tempData;
            if (model.parentIdMapping && proxy._createdAt==="load") {
                tempData = ej.DataManager(proxy._retrivedData).executeLocal(ej.Query().where(model.idMapping,
                ej.FilterOperators.equal,
                record[model.idMapping]));
                record.item = tempData[0];
            }
            else {

                if (this.dataSource() instanceof ej.DataManager && this.dataSource().dataSource.json && this.dataSource().dataSource.offline && proxy._createdAt === "load") {
                    var tempData = ej.DataManager(proxy._retrivedData).executeLocal(ej.Query().where(model.idMapping,
                    ej.FilterOperators.equal,
                    record[model.idMapping]));
                    if (tempData.length > 0) {
                        record.item = tempData[0];
                    } else {
                        record.item = data;
                    }
                }
                else {
                    record.item = data;
                }
            }
            record.parentItem = parentItem;
            record.childRecords = childDataSource && proxy._createChildRecords(childDataSource, level + 1, record);
            record.hasChildRecords = childDataSource ? true : false;
            record.expanded = expanded !== undefined ? expanded : childDataSource ? childDataSource.length > 0 : false;
            record.isSelected = false;
            record.level = level;
            record.cellBackgroundColor = null;
            record.rowBackgroundColor = null;
            record.treeMappingName = [];

            return record;
        },


        //CREATE CHILD GANTT RECORDS
        _createChildRecords: function (childDataSource, level, parentItem) {

            var proxy = this,
                records = [],
                count = 0,
                length = childDataSource.length,
                record = null,
                childRecord;

            for (count = 0; count < length; count++) {

                record = childDataSource[count];

                if (record) {
                    childRecord = proxy._createRecord(record, level, parentItem);
                    records.push(childRecord);
                }
            }

            return records;

        },


        //ADD NESTED RECORDS TO FLATRECORDS
        _addNestedRecords: function (childDataSource) {

            var proxy = this,
                model = proxy.model,
                flatRecords = model.flatRecords,
                count = 0,
                length = childDataSource.length,
                rows = model.records,
                records = [],
                record;
                

            for (count = 0; count < length; count++) {

                record = childDataSource[count];
                proxy._storedIndex++;

                //CHECK ALTROW ENABLED OR NOT
                //if (enableAltRow) {//DYNAMICALLY CHANGE THE ALT ROW
                record.isAltRow = proxy._storedIndex % 2 == 0 ? false : true;
                //}

                record.index = proxy._storedIndex;
                rows[proxy._storedIndex] = record;
                flatRecords.push(record);
                records = record.childRecords;

                if (records) {

                    var j = 0,
                        recordlength = records.length,
                        childRecord = null;

                    for (j = 0; j < recordlength; j++) {

                        childRecord = records[j];
                        proxy._storedIndex++;
                        childRecord.index=proxy._storedIndex;
                        //CHECK ALTROW ENABLED OR NOT
                        //if (enableAltRow) {  //DYNAMICALLY CHANGE THE ALT ROW
                        childRecord.isAltRow = proxy._storedIndex % 2 == 0 ? false : true;
                        //}

                        rows[proxy._storedIndex] = childRecord;
                        flatRecords.push(childRecord);
                        childRecord.childRecords && proxy._addNestedRecords(childRecord.childRecords);
                    }
                }
            }
        },

        //#endregion CONVERT HIERARCHICAL RECORDS TO FLAT RECORDS

        //#region METHOD FOR EVENTS

        //INITIALIZE THE EVENTS
        _wireEvents: function () {

            var proxy = this,
                model = proxy.model;

            proxy._$gridContent.bind("scroll", $.proxy(proxy._onScroll, proxy));
            proxy._on(proxy.element, "click", proxy._onClick);
            proxy._on(proxy.element, "click", "#" + proxy._id + "e-gridheader", proxy._onHeaderClick);
            proxy._on(proxy.element, "mousedown", "#" + proxy._id + "e-gridheader", proxy._headerMouseDown);
            //Method binding for filtering data.
            if (model.filterBarMode == "immediate") {
                this._on(this.element, "keyup", ".e-filterbarcell input", this._filterBarHandler);
                this._off(this.element, "click", ".e-checkbox")._on(this.element, "click", ".e-checkbox", this._filterBarHandler);
            }
            this._on(this.element, "focus click", ".e-filterbarcell input", this._filterBarClose);
            this._on(this.element, "click", ".e-filterbarcell .e-cancel", this._filterBarClose);
            if (proxy.model.showGridCellTooltip && !proxy.model.showGridExpandCellTooltip) {

                if (ej.browserInfo().name == "msie") {
                    proxy._on(proxy.element, "mouseenter", ".e-rowcell", proxy._mouseHover);
                }
                else {
                    proxy._on(proxy.element, "mousemove", ".e-rowcell", proxy._mouseHover);
                }
            }
            else {
                proxy._on(proxy.element, "mouseenter", ".e-rowcell", proxy._mouseHover);
            }
            proxy._on(proxy.element, "mouseleave", ".e-rowcell", proxy._cellMouseLeave);
            proxy._enableColumnResizeEvents();

            //MOUSE WHEEL EVENT FOR GANTT CONTROL
            if (model.isFromGantt) {
                proxy._on(proxy.element, "mousewheel DOMMouseScroll", proxy._mouseWheel);
            }

            if (model.enableResize && !model.isFromGantt) {
                proxy._on($(window), "resize", proxy._windowResize);
            }
            proxy._enableEditingEvents();
            //Mouse right click event for tree grid
            if (!proxy.model.isFromGantt && model.contextMenuSettings.showContextMenu)
                proxy._on(proxy.element, "contextmenu", proxy._rightClick);
        },
   
        //To renter cancel icon in filtering elements.
        _filterBarClose: function (e) {
            var $target = $(e.target);
            if (e.type == "click" && $target.hasClass("e-cancel")) {
                var $targetText = $target.prev();
                    $targetText.focus().val("");
                $targetText.prop('checked', false);
                $targetText.trigger("keyup");
                e.stopPropagation();
            }
            if (e.type == "focusin") { 
                $target = $(e.target).next();
                this.getHeaderTable().find(".e-cancel").addClass("e-hide");
                $target.removeClass("e-hide");
            }
        },

        //To wireup method while user enter text to the filter textbox.
        _filterBarHandler: function (e) {
            var proxy = this;
            proxy.clearSelection(proxy.selectedRowIndex);
            if (e.target == undefined)
                var $target =$(e);
            else
                var $target = $(e.target);
            
            if (this.model.allowFiltering ) {
                var cols=proxy.model.columns;
                var matchcase;
                matchcase = proxy._cellEditingDetails;
                var key = proxy._queryManagar.queries[0];
                if ($target.hasClass("e-checkbox"))
                    proxy._searchString = $target[0].checked;
                else
                    proxy._searchString = $target.closest("input").val();
                    var splits = $target[0].id.split('_');
                proxy._fieldName = splits[0];
                this._currentFilterColumn = cols[j];                        
                for (var j = 0; j < cols.length; j++) {
                    if (cols[j].field == splits[0]) {                               
                        this._currentFilterColumn = cols[j];
                        break;
                    }                            
                }
                proxy._validateFilterValue(proxy._searchString);
                proxy.filterColumn(proxy._fieldName, this._operator, proxy._searchString, this._predicate);
                if (proxy.model.currentViewData.length > 0)
                    ej.TreeGrid.updateAltRow(proxy, proxy.model.currentViewData[0], 0, 0);                
            }
        },
        //Method to validate search string type and assign operators accordingly.
        _validateFilterValue: function (_value) {
            var proxy = this;
            this._predicate = "and";
            switch (this._currentFilterColumn.filterEditType) {
                case "numericedit":
                    this._operator = ej.FilterOperators.equal;
                    break;
                case "datepicker":
                    this._operator = ej.FilterOperators.equal;
                    
                    var _format;
                    if (this._currentFilterColumn.format == "" || this._currentFilterColumn.format == undefined)
                        _format = Globalize.culture().calendar.patterns.d; //System Date format
                    else
                        _format = this._currentFilterColumn.format.split(':')[1].replace('}', "");
                    if (this._currentFilterbarValue != "")
                        this._currentFilterbarValue = Globalize.format(_value, _format);
                    break;
                case "datetimepicker":
                    this._operator = ej.FilterOperators.equal;
                  
                    var _format;
                    if (this._currentFilterColumn.format == "")
                        _format = Globalize.culture().calendar.patterns.f; //System DateTime format
                    else
                        _format = this._currentFilterColumn.format.split(':')[1].replace('}', "");
                    if (this._searchstring != "")
                        this._searchstring = Globalize.format(_value, _format);
                    break;
                case "stringedit":
                    this._operator = ej.FilterOperators.startsWith;
                    break;
                case "booleanedit":
                    if (proxy._searchString == true || proxy._searchString == "1")
                        proxy._searchString = true;
                    else if (proxy._searchString == "false" || proxy._searchString == "0")
                        proxy._searchString = false;
                    this._operator = ej.FilterOperators.equal;
                    break;
                default:
                    this._operator = ej.FilterOperators.equal;
            }
        },
        
        _mouseHover: function (e) {
            e.preventDefault();
            var $target = $(e.target), proxy = this,
                posx = 0,
                posy = 0,
                $ganttGridRows = proxy.getRows(),
                row = $target.closest('tr'),
                div = $target[0].parentNode,
                progressHandler,
                recordIndexr = $ganttGridRows.index(row),
                item = proxy.model.currentViewData[recordIndexr],
                tooltipElement, tooltiptable, tooltipbody;

            

            proxy._cellMouseLeave();

            if (!e) e = window.event;
            if (e.originalEvent.pageX || e.originalEvent.pageY) {
                posx = e.originalEvent.pageX;
                posy = e.originalEvent.pageY;
            }
            else if (e.originalEvent.clientX || e.originalEvent.clientY) {
                posx = e.originalEvent.clientX + document.body.scrollLeft
                    + document.documentElement.scrollLeft;
                posy = e.originalEvent.clientY + document.body.scrollTop
                    + document.documentElement.scrollTop;
            }

            if ((posx + 200) > proxy._windowWidth) {
                posx -= (posx + 200) - proxy._windowWidth;
            }

            if ((posy + 150) > proxy._windowHeight) {
                posy -= (posy + 150) - proxy._windowHeight;
            }

            if (item) {

                tooltipElement = {
                    ttiptaskname: item.taskName
                };


                tooltiptable = ej.buildTag("table.e-tooltiptable", "", { 'padding': '0' }, { 'cellspacing': '1' });
                if (proxy.model.showGridExpandCellTooltip == false) {
                    if ($target[0].firstChild && $target[0].firstChild.textContent) {
                        tooltipbody = ej.buildTag("tbody", $target[0].firstChild.textContent, {}, {});
                    }
                    else if ((div.childNodes.length > 0 && div.childNodes[1] && div.childNodes[1].textContent)) {
                        tooltipbody = ej.buildTag("tbody", div.childNodes[1].textContent, {}, {});

                    }
                }
                else if (proxy.model.showGridExpandCellTooltip == true) {
                    if (($target[0].firstChild && $target[0].firstChild.childNodes.length > 0)
                        && ($target[0].firstChild && $target[0].firstChild.textContent)) {
                        tooltipbody = ej.buildTag("tbody", $target[0].firstChild.textContent, {}, {});

                    }
                }

                tooltiptable.append(tooltipbody);
                if (tooltipbody) {
                    if (!(proxy.model.showGridExpandCellTooltip) && proxy.model.showGridCellTooltip == true && $target[0].firstChild
                        || (proxy.model.showGridExpandCellTooltip && proxy.model.showGridCellTooltip == true)) {

                        proxy._mouseOverTooltip = ej.buildTag("div.e-tooltipgantt#tooltipgantt" + proxy._id + "", tooltiptable,
                            {
                                "top": (posy + 10) + "px", "left": (posx + 15) + "px",
                                'position': 'absolute',
                                'z-index': '5',
                                'padding': '0',
                                'border-radius': '3px'
                            }, {});

                        $(document.body).append(proxy._mouseOverTooltip);
                    }
                }
            }
        },

        _cellMouseLeave: function () {

            var proxy = this;
            $("#tooltipgantt").remove();
            $(proxy._mouseOverTooltip).remove();
        },

        disableTooltip: function () {
            this._cellMouseLeave();
        },

        _createTooltipTemplate: function () {

            var proxy = this,
                td,
                columnHeaderTexts = proxy.model.columnHeaderTexts,
                helpers = {
                    _getTaskName: proxy._tooltipTaskName
                };

            $.views.helpers(helpers);
            var parentTr = "<tr class='e-tooltip_rowcell'>";

            td = "{{if ~_getTaskName()}}" +
                "<td class='e-tooltiptaskname' style='height:auto;width:auto;font-weight:normal;'>{{:ttiptaskname}}</td>{{/if}}";

            parentTr += td;
            parentTr += "</tr>";

            var templates = {};
            templates[proxy._id + "tooltipTemplate"] = parentTr;
            $.templates(templates);
        },

        _tooltipTaskName: function () {
            return this.data.ttiptaskname;
        },

        //SCROLL EVENT FOR VIRTUALIZATION
        _onScroll: function (args) {

            var proxy = this,
                hScrollDist;
            proxy._popupHide();
                     
            if (proxy.model.showGridCellTooltip) {
                proxy._cellMouseLeave();
            }

            if (!proxy.isVScroll() && !proxy.model.isFromGantt && args.source === "wheel") {
                args.cancel = true;
                return;
            }

            if (args.scrollLeft != undefined) {
                proxy._scrollLeft = args.scrollLeft;
                hScrollDist = Math.abs(proxy._scrollLeft - proxy._prevScrollLeft);
            }

            

            if (hScrollDist) {

                //CHANGE SCROLL LEFT VALUE OF HEADER  BASED ON THE SCROLLING OF CONTENT DIV
                proxy._$gridHeaderContainer.scrollLeft(proxy._scrollLeft);
                proxy._prevScrollLeft = proxy._scrollLeft;
            }
            
            if (args.scrollTop != undefined) {

                

                //CHECK VIRTUALIZATION IS ENABLED OR NOT
                if (proxy.model.enableVirtualization) {

                    proxy._scrollTop = args.scrollTop; //proxy._$gridContent.scrollTop();
                    proxy._vScrollDir = proxy._prevScrollTop <= proxy._scrollTop ? 1 : -1;
                    proxy._vScrollDist = Math.abs(proxy._scrollTop - proxy._prevScrollTop);
                    //console.log("VScrollDist:" + proxy._vScrollDist);
               
                    if (proxy._vScrollDist) {
                        proxy._updateCurrentViewData();
                        proxy._prevScrollTop = proxy._scrollTop;
                    }
                }
            }
        },

        _saveRow:function()
        {
            proxy=this;
            form = $(document.getElementById(proxy._id + "EditForm"));
            formElement = $(form).find("td");
            var index = proxy.selectedRowIndex();
            if (form.closest("tr").hasClass('e-addedrow'))
                index = form.closest("tr").index();
            proxy._currentViewData = proxy.getCurrentViewData();
            for (i = 0; i < this.model.columns.length; i++) {
                column = this.model.columns[i];
                value = proxy.getCurrentEditCellDataForRowEdit(column["field"], column["editType"],i);
                proxy._currentViewData[index][column["field"]] = proxy._currentViewData[index].item[column["field"]] = value;
            }
            var item = proxy._currentViewData[index].item;
            var isEmpty = proxy._checkIsEmptyRow(item);
            if (isEmpty)
                proxy.cancelRowEditCell();

            // Save the edited row           
            proxy.refreshRow(index);
            proxy._isRowEdit = false;            
            if (proxy.model.currentViewData.length > 0)
                ej.TreeGrid.updateAltRow(proxy, proxy._currentViewData[0], 0, 0);           
            proxy._cancelSaveTools();
            if (!isEmpty)
            proxy.selectRows(index);
           proxy.refreshContent();          
            
        },
        //CLICK HANDLER FOR PERFORM ROWSELECTION AND EXPANDCOLLAPSE THE RECORD
        _onClick: function (e) {

            var proxy = this,
                model = proxy.model,
                $target = $(e.target);
                proxy._popupHide();
            if ($target.hasClass('e-icon') && $target.hasClass('e-down-arrow')) {
                //To render back the dropdown list in gantt.
                column = proxy.model.columns,
                object = null;
                for (i = 0; i < column.length; i++) {
                    if (column[i].editType == "dropdownedit") {
                        var dropdownobject = $("#" + proxy._id + column[i].field).data("ejDropDownList");
                        if (dropdownobject)
                            object = dropdownobject.popupList;
                        if (object && object.hide()) {
                            $(object.show());
                            topposition = e.clientY + 15;
                            $(object).css({ 'top': topposition })
                        }
                    }
                }
            }            
            var dateobject = "";
            var col = proxy.model.columns;
            if ($("#" + proxy._id + "EditForm").length == 0) {
            proxy.element[0].focus();
            }
            proxy._clearContextMenu();
            for (i = 0; i < col.length; i++) {
                if (col[i]) {
                    if (col[i].filterEditType == "datepicker" || col[i].filterEditType == "datetimepicker") {
                        dateobj = $("#" + col[i].field + "_filterbarcell").data("ejDatePicker");
                        if (dateobj)
                            dateobj.hide();
                    }
                }
            }
            this.getHeaderTable().find(".e-cancel").addClass("e-hide");
         
            if ($target.hasClass('e-treegridexpand') || $target.hasClass("e-treegridcollapse")) {

                var $tr = $target.closest('tr'),
                    $gridRows = proxy.getRows(),
                    rowIndex = $gridRows.index($tr),
                    record = model.currentViewData && model.currentViewData[rowIndex],
                    recordIndex = proxy._updatedRecords.indexOf(record),
                    args = {},
                    isExpandCollapseEnabeled;

                args.data = record;
                args.recordIndex = recordIndex;
                args.expanded = $tr.hasClass("e-treegridrowexpand") ? false : true;

                if (args.expanded) {

                    isExpandCollapseEnabeled = proxy._trigger("expanding", args);

                } else {

                    isExpandCollapseEnabeled = proxy._trigger("collapsing", args);
                    
                }

                if (!isExpandCollapseEnabeled&&!model.isFromGantt) {
                    ej.TreeGrid.sendExpandCollapseRequest(proxy,args);
                  
                }
                
            } else if ($target.hasClass("e-rowcell") || $target.parent().hasClass("e-rowcell") || ($target.closest("tr").hasClass("e-templaterow"))
                || ($target.closest("td").hasClass("e-rowcell")) && $target.hasClass("e-cell")) {

                if (!model.allowSelection) return;
                
                if (model.selectionType == ej.TreeGrid.SelectionType.Multiple ) {

                    if (e.ctrlKey) proxy._multiSelectCtrlRequest = true;
                    
                    if (e.shiftKey) {

                        proxy._multiSelectShiftRequest = true;
                        if (proxy.getRows()) {
                            proxy.selectRows(proxy._previousIndex, proxy.getRows().index($target.closest('tr')));
                        }
                    }
                }
                
                if (!proxy._multiSelectShiftRequest && $("#" + proxy._id + "EditForm").length == 0) {

                    recordIndex = proxy.getRows()?proxy.getRows().index($target.closest('tr')):-1;

                    if (recordIndex != -1) {
                        
                        record = model.currentViewData[recordIndex];                      
                        var args = { rowElement: $tr, recordIndex: this.selectedRowIndex() };

                        if (!proxy._trigger('rowSelecting', args)) {

                            model.selectedItem = record;
                            this.selectedRowIndex(proxy._updatedRecords.indexOf(record));
                            proxy.selectRows(this.selectedRowIndex());
                            args = {
                                rowElement: $tr,
                                data: proxy.model.selectedItem,
                                target: "ejTreeGrid",
                                recordIndex: this.selectedRowIndex(),
                            };
                           

                                proxy._cancelSaveTools();
                   
                            proxy._trigger("rowSelected", args);
                }
                    }
                }
                
                proxy._multiSelectShiftRequest = false;
                if (proxy._isRowEdit) {
                    $target.focus();
                    if ($target.parents("form").length == 0)
                        proxy._saveRow();
            }
            }
            if (proxy._isRowEdit)
                $target.focus();
        },


        //CLICK HANDLER FOR PERFORM THE SORTING ACTION
        _onHeaderClick: function (e) {

            var proxy = this,
                model = proxy.model;
            proxy._cellMouseLeave();
            proxy._clearContextMenu();
            if ($(e.target).is(".e-ascending, .e-descending")) e.target = e.target.parentNode;

            var $target = $(e.target),
                columnName,
                columnSortDirection;

            proxy.getHeaderTable().find(".e-columnheader").find(".e-headercellactive").removeClass("e-headercellactive");

            if ($target.hasClass("e-headercelldiv")) {

                if (!model.allowSorting) return false;
                proxy._isRowEdit = false;
                columnName = $.trim($target.text());

                if ($target.find('span').hasClass("e-ascending")) {
                    columnSortDirection = ej.sortOrder.Descending;
                } else {
                    columnSortDirection = ej.sortOrder.Ascending;
                }

                if (model.allowMultiSorting && e.ctrlKey) {
                    proxy._multiSortRequest = true;
                }

                proxy.sortColumn(columnName, columnSortDirection);
                var index = proxy.selectedRowIndex();
                proxy.selectRows(index);
                if (proxy.model.isFromGantt && this.selectedRowIndex()>=0) {
                    var args = {};
                    args.data = proxy.model.selectedItem;
                    args.target = "ejTreeGrid";
                    args.recordIndex = this.selectedRowIndex();
                    proxy._trigger("rowSelected", args);
                }
            }
            if ($target.hasClass("e-checkbox"))
                return true
            else
                return false;
        },


        //HEADER MOUSE DOWN EVENT FOR COLUMN RESIZING
        _headerMouseDown: function (e) {

            var proxy = this,
                model = proxy.model;
            proxy._cellMouseLeave();

            if (model.allowColumnResize) proxy._resizer._mouseDown(e);

            if (($(e.target).hasClass("headercelldiv") && $(e.target).hasClass("headercell"))) {

                var $headercell = $(e.target).hasClass("headercelldiv") ? $(e.target).parent() : $(e.target);
                model.headerEffects && $headercell.addClass("headercellactive");

            }
        },


        //EVENT FOR COLUMN RESIZE
        _enableColumnResizeEvents: function () {

            var proxy = this;

            if (proxy.model.allowColumnResize) {
                proxy._on(proxy.element, "mousemove", proxy._mouseMove);
                proxy._on(proxy.element, "mouseup", proxy._mouseUp);
            } else {
                proxy._off(proxy.element, "mousemove", proxy._mouseMove);
                proxy._off(proxy.element, "mouseup", proxy._mouseUp);
            }
        },


        _mouseMove: function (e) {

            var proxy = this;

            if (proxy.model.allowColumnResize) {
                proxy._resizer._mouseMove(e);
                proxy._$gridHeaderContainer.scrollLeft(proxy._$gridContent.ejScroller("option", "scrollLeft"));
            }
        },


        _mouseUp: function (e) {

            var proxy = this;

            if (proxy.model.allowColumnResize) {

                if ($(e.target).hasClass('e-headercelldiv') || $(e.target).hasClass('e-reSizeColbg')) {
                    if (proxy.model.isEdit)
                        proxy.saveCell();
                    else if (proxy._isRowEdit)
                        proxy._saveRow();
                    (proxy.element).focus();
                    
                }
                proxy._resizer._mouseUp(e);
                proxy._$gridContent.ejScroller("refresh");
                proxy._updateScrollCss();
                proxy._$gridHeaderContainer.scrollLeft(proxy._$gridContent.ejScroller("option", "scrollLeft"));
                proxy._resizeFilteringElements();
            }

        },
        // resize the filtering elements after column resized.
        _resizeFilteringElements:function()
        {
            var proxy = this;
            if (proxy.model.allowFiltering) {
                var args = {};
                ej.TreeGrid.Actions.Filter = "filtering";
                args.requestType = ej.TreeGrid.Actions.Filter;
                for (i = 0; i < proxy.model.columns.length; i++) {
                    proxy.model.columns[i].width = proxy._columnsWidthCollection[i];
                    args.fieldname = proxy.model.columns[i].field;
                    this._filteringElements(args);
                }
            }
        },




        //ENABLE THE EDITING EVENTS
        _enableEditingEvents: function () {

            var proxy = this,
                model = proxy.model;

            if (model.editSettings.allowEditing) {

                if (model.editSettings.editMode.toLowerCase() == "cellediting" || model.editSettings.editMode.toLowerCase() == "rowediting") {
                    proxy._on(proxy.element, "mousedown", ".e-gridcontent", proxy._saveCellHandler);
                }

                proxy._on(this.element, "dblclick", ".e-gridcontent", proxy._editdblClickHandler);
            } else {

                if (model.editSettings.editMode.toLowerCase() == "cellediting" || model.editSettings.editMode.toLowerCase() == "rowediting") {
                    proxy._off(proxy.element, "mousedown", ".e-gridcontent", proxy._saveCellHandler);
                }

                proxy._off(this.element, "dblclick", ".e-gridcontent", proxy._editdblClickHandler);
            }
        },


        //ENABLE THE MOUSEDOWNEVENT HANDLER FOR SAVE CELL
        _saveCellHandler: function (e) {

            var $target = $(e.target),
                proxy = this;
            //SKIP THE SCROLL BAR CLICK IN TREE GRID.
            if ($target.hasClass("e-vhandle") || $target.hasClass("e-vscrollbar") || $target.hasClass("e-vup") || $target.hasClass("e-vdown") || $target.hasClass("e-vhandlespace"))
                return;
            if ($target.hasClass("e-hhandle") || $target.hasClass("e-hscrollbar") || $target.hasClass("e-hup") || $target.hasClass("e-hdown") || $target.hasClass("e-hhandlespace"))
                return;
           e.stopPropagation();
           if (proxy._isRowEdit) {
               if ($target.closest("form#" + proxy._id + "EditForm").length == 0)
                   proxy._saveRow();
           }else if ($target.closest(".e-popup").length == 0 &&
                $target.closest(".e-rowcell").find("#" + proxy._id + "EditForm").length == 0) {
                proxy.saveCell();
            }
        },
        //Mouse right click (Context Menu) handler
        _rightClick: function (e) {
            var proxy = this,
               $target = $(e.target),
               div = $target[0].parentNode,
               $ganttGridRows,
               row,
               recordIndexr,
               item, selectIndex,
               args = {};
            proxy._clearContextMenu();
            proxy.disableTooltip();
            if ($target.hasClass("e-cell") || $target.hasClass("e-treegridexpand"))
                div = $target.closest('tr');
            if ($(div).hasClass("e-treegridrows") || $(div).hasClass("e-rowcell"))
                $ganttGridRows = proxy.getRows();
            else
                $ganttGridRows = $(proxy.getRows());
            row = $target.closest('tr');
            recordIndexr = $ganttGridRows.index(row);
            proxy._currentViewData = proxy.getCurrentViewData();
            item = proxy._currentViewData[recordIndexr];
            recordIndexr = proxy._updatedRecords.indexOf(item);
            args.data = item;
            args.recordIndex = recordIndexr;
            //Context menu for edited row or empty records
            if ((proxy.dataSource() == null || proxy.dataSource().length == 0 || $target.closest("form#" + proxy._id + "EditForm").length > 0)) {
                proxy._contextMenuItems = [];
                proxy._contextMenuItems = proxy._getContextMenuItems();
                proxy._subContextMenuItems = [];
                proxy._updateContextmenuOption(recordIndexr, item);
                proxy._clearContextMenu();
                if (proxy._contextMenuItems.length > 0)
                    proxy._renderContextMenu(e, recordIndexr, item);
                //proxy.selectRows(recordIndexr);
            } else if (item) {
                e.preventDefault();
                proxy._contextMenuItems = [];
                proxy._contextMenuItems = proxy._getContextMenuItems();
                proxy._subContextMenuItems = [];
                proxy._subContextMenuItems = proxy._getsubContextMenuItems();
                proxy._updateContextmenuOption(recordIndexr, item);
                proxy._clearContextMenu();
                if (proxy._contextMenuItems.length > 0)
                    proxy._renderContextMenu(e, recordIndexr, item);
                proxy.selectRows(recordIndexr);
            }
        },
        //DOUBLE CLICK EVENT HANDLER FOR DIALOG EDITING
        _editdblClickHandler: function (e) {

            var proxy = this,
                model = proxy.model,
                $form = $("#" + proxy._id + "EditForm"),
                args = {},
                $target = $(e.target);
            if ($target.hasClass("e-vhandle") || $target.hasClass("e-vscrollbar") || $target.hasClass("e-vup") || $target.hasClass("e-vdown") || $target.hasClass("e-vhandlespace"))
                return;
            if ($target.hasClass("e-hhandle") || $target.hasClass("e-hscrollbar") || $target.hasClass("e-hup") || $target.hasClass("e-hdown") || $target.hasClass("e-hhandlespace"))
                return;
                
            if (model.editSettings.editMode === "normal") {
                args.requestType = ej.TreeGrid.Actions.BeginEdit;
                proxy._trigger("actionBegin", args);
            }

            if (proxy._cellEditingDetails.cancelSave) {

                proxy._cellEditingDetails.cancelSave = false;
                return;

            }

            if ($form.length === 0 && proxy.getRows() !== null) {

                if (model.editSettings.editMode.toLowerCase() == "cellediting") {
                proxy.element.focus();
                proxy._cellEditingDetails.columnIndex = proxy.getCellIndex(e);
                proxy._cellEditingDetails.rowIndex = proxy.getRowIndex(e);
                fieldName = proxy._cellEditingDetails.columnIndex >= 0 && model.columns[proxy._cellEditingDetails.columnIndex].field;
                if (fieldName) {
                    model.editSettings.allowEditing &&
                        model.editSettings.editMode.toLowerCase() == ej.TreeGrid.EditMode.CellEditing.toLowerCase() &&
                        proxy.cellEdit(proxy._cellEditingDetails.rowIndex, fieldName);
                }
            }
                else if (model.editSettings.editMode.toLowerCase() == "rowediting") {
                    proxy._currentViewData = proxy.getCurrentViewData();
                    if (proxy.getCellIndex(e) != -1 && proxy.getRowIndex(e)!=-1)
                    proxy._editRow(proxy.getRowIndex(e));
                }
                $form = $("#" + proxy._id + "EditForm");
                if ($form.length > 0)
                    proxy._editAddTools();
            }
            proxy._clearContextMenu();
        },

        //To hide the datepicker and dropdown list.
        _popupHide: function () {
            var proxy = this,
             column = proxy.model.columns,
             object = null;

            for (i = 0; i < column.length; i++) {
                if (column[i]) {
                    if (column[i].editType == "datepicker" || column[i].editType == "datetimepicker")
                        object = $("#" + proxy._id + column[i].field).data("ejDatePicker");
                    else if (column[i].editType == "dropdownedit") {
                        var dropdownobject = $("#" + proxy._id + column[i].field).data("ejDropDownList");
                        if (dropdownobject)
                            object = dropdownobject.popupList;
                    }
                    if (object)
                        object.hide();
                }
            }
        },
        //PERFORM SCROLLING IN TREEGRID
        _mouseWheel: function (e) {

            var proxy = this,
                delta = null,
                ori = e;            
            proxy._popupHide();
            
            e = e.originalEvent;

            try {
                e.preventDefault ? e.preventDefault() : ori.preventDefault();
            }
            catch (err) {
            }
			
			 if (proxy._$gridContent.height() > proxy._$gridContainer.height()) { 
                proxy._$gridContent.ejScroller("scrollY", 0, true);
                return;
            }

            if (e.wheelDelta) {
                delta = -e.wheelDelta / 120;
                if (window.opera) {
                    if (parseFloat(window.opera.version, 10) < 10)
                        delta = -delta;
                }
            } else if (e.detail) {
                delta = e.detail / 3;
            }
	
            if (!delta) return false;

            var scrollTop = proxy._$gridContent.ejScroller("option", "scrollTop"),

                change = scrollTop + (delta * 57);  

            var h = parseInt(proxy._updatedRecords.length * 30) - (proxy._viewPortHeight-18);

            //console.log("TreeGrid ScrollTop:" + scrollTop + "Height :" + h);
            
            if (change> h) {
                change = h;                
            }

            if (change < 0) {
                change = 0;
            }
            
                proxy._updateScrollTop(change);
           
            return true;

        },
        _getCollapsedParentItem:function(record)
        {
            var parentRecord = record.parentItem;
            if (parentRecord) {
                if (parentRecord.expanded === false) {
                    return parentRecord;
                } else {
                    return this._getCollapsedParentItem(parentRecord)
                }
            }
            else {
                return null;
            }
        },
        //KEY PRESSED EVENT FOR KEY BOARD INTERACTION IN TREEGRID CONTROL
        _keyPressed: function (action, target, e) {

                var proxy = this,
                $treegridEle = proxy.element,
                gridObject = $treegridEle.ejTreeGrid("instance"),
                model = gridObject.model;
            //CHECK THE ALLOWKEYBOARDNAVIGATION
            if (!model.allowKeyboardNavigation){
                return false;
            }

            var returnValue = false,
                $target = $(target);
            $form = $("#" + proxy._id + "EditForm");
            switch (action) {

                //save the current edited cellValue on Enter key press
                case "saveRequest":
                    if (proxy._isRowEdit)
                        proxy._saveRow();
                    else if (model.editSettings.editMode.toLowerCase() == "cellediting" && $form.length > 0) {
                        gridObject._moveCurrentCell("down");
                    }
                    if (model.filterBarMode == "onEnter" && model.allowFiltering)
                        proxy._filterBarHandler(target);
                    break;

                    //cancel the cell editing in the current cell Esc key press
                case "cancelRequest":
                    if ($form.length > 0) {
                        if (model.editSettings.editMode.toLowerCase() == "cellediting") {
                            if (proxy._isRowEdit)
                                proxy.cancelRowEditCell();
                            else
                        gridObject.cancelEditCell();
                           
                    }
                    else if (model.editSettings.editMode.toLowerCase() == "rowediting") {
                        proxy.refreshRow(proxy._editedRowIndex);
                        proxy._isRowEdit = false;
                    }
                    }
                    break;

                    //edit the cell in treegrid by F2 key press
                case "editRecord":

                    if (model.editSettings.allowEditing && model.editSettings.editMode.toLowerCase() == "cellediting") {

                        gridObject._cellEditingDetails.rowIndex = this.selectedRowIndex();
                        gridObject._cellEditingDetails.columnIndex = proxy.getCellIndex(e, target);

                        if (gridObject._cellEditingDetails.columnIndex !== -1) {
                            fieldName = gridObject.model.columns[gridObject._cellEditingDetails.columnIndex].field;
                            fieldName && gridObject.cellEdit(gridObject._cellEditingDetails.rowIndex, fieldName);
                        }

                    }

                    break;

                    //select the first row while press the Home key
                case "firstRowSelection":
                    if (proxy._isRowEdit || proxy.model.isEdit) return true;
                    if (!proxy._rowSelectingEventTrigger()) {
                        proxy.selectRows(0);
                        recordIndex = proxy._updatedRecords.indexOf(model.selectedItem);
                        rowTop = recordIndex !== -1 && recordIndex * model.rowHeight;// - (proxy.getCollapsedRecordCount() * model.rowHeight);
                        var currentHeight = proxy._$gridContainer.height();
                        if (currentHeight > proxy._viewPortHeight) {
                            args = {
                                requestType: "scroll",
                                delta: rowTop
                            }
                            proxy._scrollTop = rowTop;
                            proxy._completeAction(args);
                            proxy._$gridContent.children(".e-content").scrollTop(rowTop);
                        }
                        if (model.enableVirtualization) {
                            proxy.selectRows(0);
                            proxy.element[0].focus();
                        }
                        proxy._rowSelectedEventTrigger(0);
                    }
                    break;

                case "lastRowSelection":
                    if (proxy._isRowEdit || proxy.model.isEdit) return true;
                    if (!proxy._rowSelectedEventTrigger()) {
                        lastRowIndex = proxy._updatedRecords.length - 1;
                        var previousItem = proxy._updatedRecords[lastRowIndex],
                               parentItem,
                               rowClassName, length;
                        if (!model.enableVirtualization && previousItem.parentItem) {
                            parentItem = proxy._getCollapsedParentItem(previousItem);
                            if (parentItem) {
                                length = proxy.getChildCount(parentItem, 0);
                                proxy.selectRows(lastRowIndex - length);
                            }
                            else {
                                proxy.selectRows(lastRowIndex);
                            }
                        }
                        else {
                            proxy.selectRows(lastRowIndex);
                        }

                        recordIndex = model.selectedItem && proxy._updatedRecords.indexOf(model.selectedItem);
                        rowTop = lastRowIndex !== -1 && recordIndex * model.rowHeight;

                        if (rowTop + proxy.model.rowHeight >= proxy._viewPortHeight) {
                            scrollTop = rowTop + proxy.model.rowHeight - (proxy._viewPortHeight - proxy._scrollBarHeight) - (proxy.getCollapsedRecordCount() * model.rowHeight);
                            if (scrollTop >= 0) {
                                args = {
                                    requestType: "scroll",
                                    delta: scrollTop
                                };
                            proxy._scrollTop = scrollTop;
                            proxy._completeAction(args); //actionComplete event trigger for perform the scrolling gantt chartcontrol.
                        }
                            if (model.enableVirtualization) {
                                proxy.selectRows(recordIndex);
                                proxy.element[0].focus();
                               
                            }
                        }
                        proxy._rowSelectedEventTrigger(recordIndex);
                    }
                    break;
                    //set the edit mode to previous cell by press shift +tab key
                case "moveCellLeft":
                    //Row edit Element focusing for Shift + tab key press
                    if (proxy._isRowEdit) {
                        previousElement = $target.closest("td").prev("td");
                        if (previousElement.length)
                            proxy._focusElementsForRowEdit(previousElement);
                    } else if (model.editSettings.allowEditing && model.editSettings.editMode.toLowerCase() == "cellediting" && $form.length > 0) {
                        returnValue = proxy._moveCurrentCell("left");
                    }

                    break;

                    //set the edit mode to next cell by tab key
                case "moveCellRight":
                    if (proxy._isRowEdit) {
                        nextElement = $target.closest("td").next("td");
                        if (nextElement.length)
                            proxy._focusElementsForRowEdit(nextElement);
                    } else if (model.editSettings.allowEditing && model.editSettings.editMode.toLowerCase() == "cellediting" && $target && $form.length > 0) {
                        returnValue = proxy._moveCurrentCell("right");
                    }

                    break;

                    //select the next row by press down arrow key
                case "downArrow":
                    if (proxy._isRowEdit || proxy.model.isEdit) return false;
                    else if (!proxy._rowSelectingEventTrigger()) {
                        // debugger;
                        //get the last row index of the ganttchart control
                        var lastRowIndex = proxy._updatedRecords.length - 1;

                        if (proxy.selectedRowIndex() != lastRowIndex) {

                            if (!model.enableVirtualization && !model.selectedItem.expanded) {
                                var child = proxy.getChildCount(model.selectedItem, 0);
                                var index = proxy.selectedRowIndex() + child + 1;
                                if (lastRowIndex >= index)
                                    proxy.selectRows(proxy.selectedRowIndex() + child + 1);

                            }
                            else {
                                proxy.selectRows(proxy.selectedRowIndex() + 1);
                            }
                            model.selectedItem.isSelected = true;
                            var recordIndex = model.selectedItem && proxy._updatedRecords.indexOf(model.selectedItem),
                                rowTop = lastRowIndex !== -1 && recordIndex * model.rowHeight,
                                scrollTop,
                                containerWidth,
                                scrollerExist = proxy._$gridContent.children(".e-content").length;
                            if (scrollerExist)
                                scrollTop = proxy._$gridContent.children(".e-content").scrollTop();
                            else
                                scrollTop = proxy._$gridContent.scrollTop();

                            containerWidth = scrollTop + proxy._viewPortHeight - proxy._scrollBarHeight - model.rowHeight + (proxy.getCollapsedRecordCount() * model.rowHeight);

                            if (containerWidth < rowTop) {
                                args = {
                                    requestType: "scroll",
                                    delta: (scrollTop+model.rowHeight),
                                };
                                proxy._completeAction(args);
                                if (scrollerExist)
                                    proxy._$gridContent.children(".e-content").scrollTop((scrollTop + model.rowHeight));
                                else
                                    proxy._$gridContent.scrollTop((scrollTop + model.rowHeight));

                                if (model.enableVirtualization) {
                                    proxy.element[0].focus();
                                }
                            }
                            proxy._rowSelectedEventTrigger(proxy.selectedRowIndex()); //for diasable completeaction
                        }
                    }
                    break;
                // expand the child task by press right arrow
                case "rightArrow":
                    if (proxy._isRowEdit || proxy.model.isEdit) return true;
                    var rowIndex = proxy.selectedRowIndex(),
                    record = proxy._updatedRecords[rowIndex],
                    args = {},
                    isExpandCollapseEnabeled;
                    args.data = record;
                    args.recordIndex = rowIndex;
                    args.expanded = true;
                    if (!proxy._rowSelectingEventTrigger() && record.hasChildRecords && !record.expanded) {
                        if (proxy.selectedRowIndex() >= 0) {
                            isExpandCollapseEnabeled = proxy._trigger("expanding", args);
                            if (!isExpandCollapseEnabeled && !model.isFromGantt) {
                                ej.TreeGrid.sendExpandCollapseRequest(proxy, args);
                            }
                        }
                    }
                    break;
                //collapse the child task by press left arrow 
                case "leftArrow":
                    if (proxy._isRowEdit || proxy.model.isEdit) return true;
                    var rowIndex = proxy.selectedRowIndex(),
                    record = proxy._updatedRecords[rowIndex],
                    args = {},
                    isExpandCollapseEnabeled;
                    args.data = record;
                    args.recordIndex = rowIndex;
                    args.expanded = false;
                    if (!proxy._rowSelectingEventTrigger()&&record.hasChildRecords && record.expanded) {
                        if (proxy.selectedRowIndex()>=0) {
                                    isExpandCollapseEnabeled = proxy._trigger("collapsing", args); 
                            if (!isExpandCollapseEnabeled&&!model.isFromGantt) {
                                ej.TreeGrid.sendExpandCollapseRequest(proxy,args);
                            }
                         }
                     }
                    break;
                    //select the previous row by press down arrow key
                case "upArrow":
                    if (proxy._isRowEdit || proxy.model.isEdit) return false;
                    if (!proxy._rowSelectingEventTrigger()) {
                        if (proxy.selectedRowIndex() !== 0) {
                            var previousItem = proxy._updatedRecords[proxy.selectedRowIndex() - 1],
                                parentItem,
                                rowClassName, length;
                            if (!model.enableVirtualization && previousItem.parentItem) {
                                parentItem = proxy._getCollapsedParentItem(previousItem);
                                if (parentItem) {
                                    length = proxy.getChildCount(parentItem, 0);
                                    proxy.selectRows(proxy.selectedRowIndex() - length - 1);
                                }
                                else {
                                    proxy.selectRows(proxy.selectedRowIndex() - 1);
                                }
                            }
                            else {
                                proxy.selectRows(proxy.selectedRowIndex() - 1);
                            }

                            model.selectedItem.isSelected = true;
                            recordIndex = proxy._updatedRecords.indexOf(model.selectedItem);
                            rowTop = recordIndex !== -1 && (recordIndex * model.rowHeight) - (proxy.getCollapsedRecordCount() * model.rowHeight);
                            var scrollerExist = proxy._$gridContent.children(".e-content").length, scrollTop;
                            if (scrollerExist)
                                scrollTop = proxy._$gridContent.children(".e-content").scrollTop();
                            else
                                scrollTop = proxy._$gridContent.scrollTop();
                            if (scrollTop) {
                                if (scrollTop > rowTop) {
                                    if (rowTop >= 0) {
                                        args = {
                                            requestType: "scroll",
                                            delta: rowTop
                                        };
                                    }
                                    else
                                    {
                                        args = {
                                            requestType: "scroll",
                                            delta: 0
                                        };
                                    }
                                    if (scrollerExist)
                                        proxy._$gridContent.children(".e-content").scrollTop(args.delta);
                                    else
                                        proxy._$gridContent.scrollTop(args.delta);

                                    proxy._completeAction(args);
                                    if (model.enableVirtualization) {
                                        proxy.selectRows(proxy.selectedRowIndex());
                                        proxy.element[0].focus();
                                    }
                                }
                            }
                            proxy._rowSelectedEventTrigger(proxy.model.selectedRowIndex);
                        }
                    }
                    break;

                default:
                    returnValue = true;
            }

            return returnValue;
        },

        //Method to bind all the filter condition and splice the over writed condition.
        filterColumn: function (fieldName, filterOperator, filterValue, predicate, matchcase, actualFilterValue) {
           
            if (!this.model.allowFiltering)
                return;
            var args = {};
            ej.TreeGrid.Actions.Filter = "filtering";
            args.requestType = ej.TreeGrid.Actions.Filter;
            args.currentFilterObject = [];           
            if (!$.isArray(filterOperator))
                filterOperator = $.makeArray(filterOperator);
            if (!$.isArray(filterValue))
                filterValue = $.makeArray(filterValue);
            var firstLoop = false;
            var filterCol = this._filterCollection;
            if (ej.util.isNullOrUndefined(this._currentFilterColumn))
                this._currentFilterColumn = this.getColumnByField(fieldName);
            for (var index = 0; index < filterOperator.length; index++) {
                var filterObject = {
                    field: fieldName,
                    operator: filterOperator[index],
                    value: filterValue[index],
                    matchcase: matchcase,
                    predicate: predicate,
                    actualFilterValue: actualFilterValue
                };
                this._$colType = "string";
                if (this._filteredColumns.length == 0 && filterObject.value !== "") {
                    if (this._$colType == "date" && (filterOperator == "equal" || filterOperator == "notequal") && typeof (filterObject.value) !== "string")
                        this._setDateFilters(filterObject);
                    else
                        this._filteredColumns.push(filterObject);
                } else {
                    var proxy = this;
                    if (!firstLoop) {
                        var dataManger = ej.DataManager(this._filteredColumns);
                        var query = new ej.Query().where("field", ej.FilterOperators.equal, filterObject.field);
                        var object = dataManger.executeLocal(query);
                        for (var i = 0; i < object.length; i++) {
                            var objectIndex = $.inArray(object[i], this._filteredColumns)
                            if (objectIndex != -1)
                                this._filteredColumns.splice(objectIndex, 1);
                        }
                    }
                    if (filterObject.value !== "") {
                        if (this._$colType == "date" && (filterOperator == "equal" || filterOperator == "notequal") && typeof (filterObject.value) !== "string")
                            this._setDateFilters(filterObject);
                        else
                            this._filteredColumns.push(filterObject);
                    }
                }
                firstLoop = true;
                args.currentFilterObject.push(filterObject);
            }
            args.filterCollection = this._filteredColumns;
            args.currentFilteringColumn = fieldName;
            args.fieldName = fieldName;
            var returnValue = this.processBindings(args);
            if (returnValue) {
                this._filteredColumns.reverse().splice(0, filterOperator.length);
                this._filteredColumns.reverse();
            }
        },
        //ROWSELECTING EVENT METHOD
        _rowSelectingEventTrigger: function () {

            var proxy = this,
                model = proxy.model,
                args = {},
                selectedItem,
                $gridRows;

            if (model.currentViewData.length <= 0) {
                this.selectedRowIndex(-1);
            }
            if (this.selectedRowIndex() !== -1 && model.currentViewData.length > 0) {

                $gridRows = proxy.getRows();
                selectedItem = model.currentViewData[this.selectedRowIndex()];
                model.selectedItem = selectedItem;
                args = {
                    rowElement: $gridRows.eq(this.selectedRowIndex()),
                    data: selectedItem,
                    recordIndex: this.selectedRowIndex(),
                };

            }
            return proxy._trigger('rowSelecting', args);
        },


        //ROWSELECTED EVENT METHOD
        _rowSelectedEventTrigger: function (index) {

            var proxy = this,model=proxy.model,
                args = {},
                $gridRows = proxy.getRows();

            if (model.currentViewData.length > 0) {
                args = {
                    rowElement: $gridRows.eq(index),
                    data: proxy.model.selectedItem,
                    target: "ejTreeGrid",
                    recordIndex: index
                };
                proxy._trigger("rowSelected", args);
            }

        },


        //QUERYCELLINFO,ROWDATABOUND EVENT BINDING FOR TREEGRID
        _eventBindings: function () {

            var proxy = this,
                model = proxy.model,
                count = 0,
                gridRows = proxy._gridRows,
                length = gridRows.length;

            
            if (model.queryCellInfo != null || model.rowDataBound != null) {

                for (count; count < length; count++) {
                    proxy._rowEventTrigger(gridRows[count], model.currentViewData[count]);
                }
            }
        },

        //ROWDATABOUND EVENT TRIGGER
        _rowEventTrigger: function (row, data) {

            var proxy = this;

            proxy._trigger("rowDataBound", {
                rowElement: row,
                data: data
            });

            var tdCells = row.cells,
                $tdRowcells = $(row).find(".e-rowcell"),
                cellIndex = 0,
                length = tdCells.length,
                column=null,
                columns = proxy.model.columns;

            for (cellIndex; cellIndex < length; cellIndex++) {

                if ($(tdCells[cellIndex]).hasClass("e-rowcell")) {

                    column = columns[$tdRowcells.index(tdCells[cellIndex])];

                }

                if (column) {

                    proxy._cellEventTrigger(tdCells[cellIndex], data, column);

                }
            }
        },


        //QUERYCELLINFO EVENT TRIGGER
        _cellEventTrigger: function (cell, data, column) {

            var args = {
                cellElement: cell,
                data: data,
                column: column,

            };

            args.cellValue = args.column && data[args.column.field];
            this._trigger("queryCellInfo", args);
        },


        //ACTION COMPLETE EVENT TRIGGER
        _completeAction: function (args) {

            var proxy = this,
                model = proxy.model,
                sortcolumns = model.sortSettings.sortedColumns;

            model.isEdit = false;

            if ((ej.TreeGrid.Actions.Sorting == args.requestType && model.allowSorting)
                || (ej.TreeGrid.Actions.Refresh == args.requestType)) {

                if (model.allowSorting) {

                    if (!proxy._multiSortRequest) {
                        proxy.getHeaderTable().find(".e-columnheader").
                            find(".e-headercelldiv").find(".e-ascending,.e-descending").remove();

                        proxy.getHeaderTable().find("[aria-sort]").removeAttr("aria-sort");
                    }

                    for (var i = 0; i < sortcolumns.length; i++) {
                        proxy._addSortElementToColumn(sortcolumns[i].field, sortcolumns[i].direction);
                    }

                }

                proxy._multiSortRequest = false;
            } else if (ej.TreeGrid.Actions.BeginEdit == args.requestType || ej.TreeGrid.Actions.Add == args.requestType) {

                var $form = $("#" + proxy._id + "EditForm");

                proxy.model.isEdit = true;
                proxy.setWidthToColumns();

                if (ej.TreeGrid.Actions.Add == args.requestType) {

                    $form.find(".e-field:disabled").not(".e-identity").removeAttr("disabled").removeClass("e-disable");

                }

            }
            else if (args.requestType === "scroll")
            {
                proxy._updateCurrentViewData();

                if (!proxy.model.isFromGantt && args.delta>=0 && proxy.isVScroll() && proxy.model.enableVirtualization)
                {
                    if (!proxy._$gridContent.ejScroller("isHScroll") && args.delta>=18) {
                        args.delta -= proxy._scrollBarHeight;
                        proxy._scrollTop = args.delta;
                    }
                    proxy._$gridContent.ejScroller("scrollY", args.delta, true);
                }
            }
            proxy._trigger("actionComplete", args);
        },


        //#endregion

        //#region METHOD FOR DATA PROCESSING

        //RENDERING THE DATA
        sendDataRenderingRequest: function (args) {

            var proxy = this,
                temp;
            if (proxy.model.currentViewData.length) {

                switch (args.requestType) {

                    case ej.TreeGrid.Actions.Delete:
                    case ej.TreeGrid.Actions.Refresh:
                    case ej.TreeGrid.Actions.Save:
                    case ej.TreeGrid.Actions.Filter:
                    case ej.TreeGrid.Actions.Sorting:
                    case ej.TreeGrid.Actions.Searching:
                    case ej.TreeGrid.Actions.ExpandCollapse:
                    case ej.TreeGrid.Actions.RefreshDataSource:
                        temp = document.createElement('div');
                        proxy.getContentTable().find("colgroup").first().replaceWith(proxy._getMetaColGroup());
                        var $tbody = proxy.getContentTable().children('tbody');
                        $tbody.empty();                        
                        temp.innerHTML = ['<table>', $.render[proxy._id + "_Template"](proxy.model.currentViewData),
                            '</table>'].join("");
                        proxy.getContentTable().get(0).replaceChild(temp.firstChild.firstChild,
                            proxy.getContentTable().get(0).lastChild);
                        proxy._gridRows = proxy.getContentTable().get(0).rows;
                        proxy.setGridRows($(proxy.getContentTable().get(0).rows));
                        proxy._eventBindings();
                        break;
                }

            } else {

                proxy.getContentTable().find('tbody').empty().append(proxy._getEmptyTbody());
                proxy._gridRows = null;
                proxy.setGridRows(null);

            }
            proxy._completeAction(args);

        },


        //SORTING THE DATA BASED ON THE PARTICULAR FIELDS
        /**
      * To sorting the data based on the particular fields
      * @return jQuery
      * @example 
      * &lt;treegrid id="treegrid"&gt;treegrid&lt;/treegrid&gt; <br> 
      * &lt;script&gt;
      * // Create Tree Grid
      * var treegridObj = $("#treegrid").data("ejTreeGrid");
      * treegridObj.ejTreeGrid("sortColumn"); // To sort the data
      * &lt;/script&gt;
      * @example 
      *  &lt;treegrid id="treegrid"&gt;treegrid&lt;/treegrid&gt; <br> 
      * &lt;script&gt;
      * // refresh the content
      * $("#treegrid").ejTreeGrid("sortColumn");	
      * &lt;/script&gt;
      * @memberof ejTreeGrid
      * @instance
       */
        sortColumn: function (columnName, columnSortDirection) {

            var proxy = this,
                model = proxy.model,
                sortColumns = model.sortSettings.sortedColumns,
                args = {},
                count = 0,
                length = sortColumns.length;

            if (!model.allowSorting || $.inArray(columnName, proxy._disabledSortableColumns) != -1
                || columnName.length == 0) {
                return;
            }

            if (!proxy._multiSortRequest) {
                model.sortSettings.sortedColumns = [];
            }

            args.requestType = ej.TreeGrid.Actions.Sorting;
            args.columnName = columnName;

            proxy._cSortedColumn = proxy.getFieldNameByHeaderText(columnName);
            proxy._cSortedDirection = args.columnSortDirection = columnSortDirection === undefined ?
                ej.sortOrder.Ascending : columnSortDirection;

            for (count; count < length; count++) {
                
                if (sortColumns[count].field == proxy._cSortedColumn) {
                    sortColumns.splice(count, 1);
                    break;
                }

            }

            model.sortSettings.sortedColumns.push({
                field: proxy._cSortedColumn,
                direction: proxy._cSortedDirection
            });

            var returnValue = proxy.processBindings(args);

            if (returnValue) {

                proxy._cSortedDirection = proxy._cSortedColumn = null;

            }
        },


        //DELETE THE PARTICULAR RECORD AND MULTIPLE RECORD
        deleteRow: function ($tr) {

            var proxy = this,
                deletedRowIndex,
                deletedRow,
                args = {},
                eveArgs = {};
            length = proxy._selectedRowsIndexes.length;
            proxy._selectedRowsIndexes.sort();
            var deletedrowCount = 0;
            for (var del = 0; del < length; del++) {

                if (ej.isNullOrUndefined($tr))
                    $tr = proxy.getRowByIndex(proxy._selectedRowsIndexes[del]);
                else
                    $tr = proxy.getRowByIndex(proxy._selectedRowsIndexes[del] - deletedrowCount);

            deletedRowIndex = proxy.getRows().index($tr);
            deletedRow = proxy.model.currentViewData[deletedRowIndex];

            args.tr = $tr;
            args.data = deletedRow;
            args.requestType = ej.TreeGrid.Actions.Delete;   

            if (proxy._trigger("actionBegin", args)) {
                return true;
            }

            proxy.processBindings(args);
            deletedrowCount++;
            if (proxy.model.currentViewData.length > 0)
                ej.TreeGrid.updateAltRow(proxy, proxy.model.currentViewData[0], 0, 0);
            }
            proxy._selectedRowsIndexes = [];
            proxy._previousIndex = -1;
        },


        //SEARCH THE TASK FROM TREE GRID CONTROL
        /**
        * To search an item with search string provided at the run time
        * @return jQuery
        * @example 
        * &lt;treegrid id="treegrid"&gt;TreeGrid&lt;/treegrid&gt; <br> 
        * &lt;script&gt;
        * // Create treegrid
        * var treegridObj = $("#treegrid").data("ejTreeGrid");
        * treegridObj.ejTreeGrid("searchItem",$("#text").val()); // To search a task
        * &lt;/script&gt;
        * @example 
        *  &lt;treegrid id="treegrid"&gt;TreeGrid&lt;/treegrid&gt; <br> 
        * &lt;script&gt;
        * // To search a task
        * $("#treegrid").ejTreeGrid("searchItem",$("#text").val());	
        * &lt;/script&gt;
        * @memberof ejTreeGrid
        * @instance
         */
        search: function (searchString) {

            var proxy = this,
                args = {};

            args.requestType = ej.TreeGrid.Actions.Searching;
            args.keyValue = searchString;

            proxy._searchString = searchString;

            proxy.processBindings(args);
        },

        //SEND SAVE REQUEST
        endEdit: function () {

            var proxy = this;

            if (proxy.model.editSettings.editMode.toLowerCase() == "cellediting" && !proxy._isRowEdit)
                return proxy.saveCell();

            return true;

        },

        //#endregion

        //#region PUBLIC METHODS

        //CALCULATE THE VISIBLE RANGE OF RECORDS TO DISPLAYED IN CURRENT VIEWPORT
        getVisibleRange: function () {

            var proxy = this,
                top = proxy._scrollTop / proxy.model.rowHeight,
                coeff = top - Math.floor(top),
                topIndex, bottomIndex,
                model = proxy.model;

            //console.log("TreeGrid ScrollTop:" + proxy._scrollTop);

            proxy._offset = coeff * model.rowHeight;
            topIndex = Math.floor(top);
            bottomIndex = proxy._getRowPosition(proxy._scrollTop + proxy._viewPortHeight);
            topIndex = Math.max(0, topIndex);
            bottomIndex = Math.min(proxy.getRecordsCount(), bottomIndex);

            proxy._visibleRange = {
                top: topIndex,
                bottom: bottomIndex
            };

            return proxy._visibleRange;

        },


        //SET THE COLUMNWIDTH TO EACH COLUMN IN TREEGRID
        setWidthToColumns: function () {

            var proxy = this,
                model = proxy.model,
                $cols1 = proxy.getContentTable().children("colgroup").find("col"),
                $cols2 = proxy.getHeaderTable().children("colgroup").find("col"),
                width = proxy._gridWidth,
                colCount = model.columns.length;

            if ($cols1.length > colCount) $cols1.splice(0, ($cols1.length - colCount));
            if ($cols2.length > colCount) $cols2.splice(0, ($cols2.length - colCount));

            for (var i = 0; i < $cols2.length; i++) {

                if (!ej.isNullOrUndefined(proxy._columnsWidthCollection[i])) {

                    $cols1.eq(i).width(proxy._columnsWidthCollection[i]);
                    $cols2.eq(i).width(proxy._columnsWidthCollection[i]);

                } else {
                    var colWidth = (width / colCount).toFixed(2) + "px";
                    $cols1.eq(i).css("width", colWidth);
                    $cols2.eq(i).css("width", colWidth);
                    proxy._columnsWidthCollection[i] = (width / colCount).toFixed(2);
                }
            }
        },


        //ENTER EDIT MODE INTO THE TREEGRID CELL
        cellEdit: function (index, fieldName) {

            var proxy = this,
                $form,
                model = proxy.model;

            if (proxy.model.showGridCellTooltip) {
                proxy._cellMouseLeave();
            }

            proxy.model.isEdit && proxy.saveCell();

            $form = $("#" + proxy._id + "EditForm");

            if ($form.length > 0) return true;

            if (!proxy.model.selectedItem) return false;

            if (model.isFromGantt && ((fieldName === "status" ||
                fieldName === "startDate" ||
                fieldName === "endDate" ||
                fieldName === "duration" ||
                fieldName === "predecessor") &&
                proxy.model.selectedItem.hasChildRecords) ||
                (fieldName === "baselineStartDate" ||
                    fieldName === "baselineEndDate") || (fieldName==="taskId")) {

                return false;

            }

            if (proxy.getRows()[index]) {
                var $targetTr = $(proxy.getRows()[index]);
                columnIndex = proxy.getColumnIndexByField(fieldName),
                $targetTd = $targetTr.find(".e-rowcell").eq(columnIndex),
                column = proxy.model.columns[columnIndex],
                data = proxy.model.selectedItem,
                beginEditArgs = {},
                args = {
                    validationRules: ej.isNullOrUndefined(column.validationRules) ? {} : $.extend(true, {},
                        column.validationRules),
                    columnName: column.field,
                    value: !ej.isNullOrUndefined(data[fieldName]) ? data[fieldName] : data.item && data.item[fieldName],
                    data: data,
                    columnObject: column,
                    cell: $targetTd
                },
                isEditable = true;

            if (model.isFromGantt && args.columnName === "predecessor") {

                var predecessor = args.data.item[proxy.model.predecessorMapping];
                args.value = predecessor ? predecessor : "";

            }

            beginEditArgs.data = data;
            beginEditArgs.columnIndex = columnIndex;
            beginEditArgs.rowElement = $targetTr;
            beginEditArgs.cellElement = $targetTd;

          

                proxy._cellEventTrigger($targetTr[0].cells[proxy._cellEditingDetails.columnIndex], data, args.columnObject);

                if (proxy._trigger("beginEdit", beginEditArgs)) return false;

                if ($.inArray(fieldName, proxy._primaryKeys) != -1 ||
                    args.columnObject.allowEditing === false) {

                    $.extend(proxy._cellEditingDetails, {
                        cellValue: args.value,
                        rowIndex: index,
                        fieldName: fieldName,
                        data: args.data,
                        columnIndex: columnIndex
                    });

                    isEditable = false;
                }

                if ($targetTr.hasClass("e-insertedrow") && (!args.columnObject.isTemplateColumn)) isEditable = true;

                if (isEditable) {

                    $.extend(proxy._cellEditingDetails, {
                        rowIndex: index,
                        cellValue: args.value,
                        columnIndex: columnIndex,
                        fieldName: fieldName,
                        cellEditType: args.columnObject.editType,
                        data: data
                    });
                }

                proxy._renderCellEditObject(args, $targetTd);
                if (!$targetTr.hasClass("e-templaterow")) {
                    $targetTr.addClass("e-editedrow");
                    args.cell && args.cell.addClass("e-editedcell");
                }

                return true;
            }
        },

        //validate predecessor string

        _validatePredecessorString: function (string) {
            var proxy = this, result;
            if (string.length > 0) {
                string.split(',').forEach(function (el) {
                    values = el.split('+');
                    offsetvalue = '+';
                    if (el.indexOf('-') >= 0) {
                        values = el.split('-');
                        offsetvalue = '-';
                    }
                    match = values[0].match(/(\d+|[A-z]+)/g);
                    if (proxy.model.ids.indexOf(match[0]) != -1) {
                        if (match[1]) {
                            if (match[1].toUpperCase() == 'FS' || match[1].toUpperCase() == 'FF' || match[1].toUpperCase() == 'SF' || match[1].toUpperCase() == 'SS') {
                            }
                            else {
                                result = false;
                            }
                        }
                    } else {
                        result = false;
                    }
                });
            } else {
                return true;
            }
            if (result === undefined || result)
                return true;
            else
                return false;
        },

        //SAVE THE EDITED CELL
        saveCell: function () {

            var proxy = this,
                model = proxy.model;

            if ($("#" + proxy._id + "EditForm").length > 0) {

                if (!proxy.editFormValidate()) return true;

                if (proxy._cellEditingDetails.columnIndex >= 0) {

                    var $form = $("#" + proxy._id + "EditForm"),
                        $targetTr = $form.closest("tr"),
                        $targetTd = $form.closest("td"),
                        formattedValue, args = {},
                        column = model.columns[proxy._cellEditingDetails.columnIndex],
                        $element = $("#" + proxy._id + proxy._cellEditingDetails.fieldName),
                        cellElement;

                    args = {
                        columnName: column.field,
                        value: proxy.getCurrentEditCellData(),
                        data: proxy._cellEditingDetails.data,
                        previousValue: proxy._cellEditingDetails.cellValue,
                        columnObject: column,
                        cellElement: $targetTd,
                        rowElement: $targetTr,
                    };

                    if (proxy._cellEditingDetails.cellEditType == "datetimepicker" ||
                        proxy._cellEditingDetails.cellEditType == "dropdownedit" ||
                        proxy._cellEditingDetails.cellEditType == "datepicker") {

                        $element.data("ejWidgets") && $element[$element.data("ejWidgets")[0]]("destroy");                        

                    }

                    if (proxy._cellEditingDetails.cellEditType === "datepicker")
                        args.value = proxy.getFormatedDate(args.value);

                    if (!ej.isNullOrUndefined(column.format)) {

                        formattedValue = proxy.formatting(column.format, args.value);
                        args.cellElement.empty().html(formattedValue);

                    } else {

                        if (args.columnObject.type == "boolean") {

                            var cellData = {};
                            cellData[args.columnObject.field] = args.value;
                            args.cellElement.empty().html(
                                $($.templates.Grid_JSONTemplate.render(cellData))[0].cells[proxy._cellEditingDetails.columnIndex].innerHTML
                            );

                        } else args.cellElement.empty().html(args.value);
                    }

                    var isValueModified = ((proxy._cellEditingDetails.cellEditType == "datepicker" ||
                            proxy._cellEditingDetails.cellEditType == "datetimepicker") &&
                        args.value instanceof Date && args.previousValue instanceof Date) ?
                        (args.value.getTime() !== args.previousValue.getTime()) :
                        (args.value !== args.previousValue);

                    model.isEdit = false;

                    var fieldName = proxy._cellEditingDetails["fieldName"];

                    if (model.isFromGantt && fieldName === "predecessor") {

                        var eventArg = {},stringResult,logicResult;
                        stringResult = proxy._validatePredecessorString(args.value);
                        if (stringResult) {
                            eventArg.predecessorString = args.value.split(',');
                            eventArg.data = {};
                            eventArg.data[model.taskIdMapping] = args.data.taskId;
                            eventArg.requestType = "validatePredecessor";
                            proxy._trigger("actionComplete", eventArg);
                            logicResult = eventArg.result;
                            if (!logicResult) {
                                args.value = args.previousValue;
                            }
                        }
                        else {
                            args.value = args.previousValue;
                        }
                        args.value = args.value.toUpperCase();
                        var ganttPredecessor = [],
                        prevPredecessors = [],
                        modifiedPredecessors = [],
                        count = 0,
                        length, predecessor;
                        args.previousValue = args.data.predecessor;
                        prevPredecessors = args.previousValue;
                        if (args.value.length > 0) {
                            modifiedPredecessors = args.data._calculatePredecessor(args.value);
                        }
                        length = modifiedPredecessors.length;
                        var index = 0,
                            prevPrdecessorlength = args.previousValue && args.previousValue.length;
                        for (index = 0; index < prevPrdecessorlength; index++) {
                            predecessor = prevPredecessors[index];
                            if (predecessor.from === args.data.taskId.toString()) {
                                ganttPredecessor.push(predecessor);
                            }
                        }
                        for (count = 0; count < length; count++) {
                            ganttPredecessor.push(modifiedPredecessors[count]);
                        }
                        args.data[proxy._cellEditingDetails["fieldName"]] = ganttPredecessor;
                        args.data.item[model.predecessorMapping] = args.value;

                    } else if (isValueModified) {
                        if (model.isFromGantt) {

                            switch (fieldName) {

                                case "taskId":
                                    args.data.item[model.taskIdMapping] = args.value;
                                    break;
                                case "taskName":
                                    args.data.item[model.taskNameMapping] = args.value;
                                    break;
                                case "startDate":
                                    args.data.item[model.startDateMapping] = args.value;
                                    break;
                                case "endDate":
                                    args.data.item[model.endDateMapping] = args.value;
                                    break;
                                case "resourceInfo":
                                    args.data.item[model.resourceInfoMapping] = proxy._getResourceId( args.value);                                    
                                    break;
                                case "duration":
                                    args.data.item[model.durationMapping] = args.value;
                                    break;
                                case "status":
                                    args.data.item[model.progressMapping] = args.value;
                                    break;
                                default:
                                    args.data.item[proxy._cellEditingDetails[fieldName]] = args.value;
                                    break;
                            }

                        } else {
                            args.data.item[proxy._cellEditingDetails.fieldName] = args.value;
                        }
                        
                        args.data[proxy._cellEditingDetails.fieldName] = args.value;
                        
                    }

                    if (model.isFromGantt && (args.columnName === "startDate" ||
                        args.columnName === "endDate" ||
                        args.columnName === "duration" ||
                        args.columnName === "predecessor" ||
                        args.columnName == "status")) {

                        args.isModified = true;

                    }
                    cellElement = $($.render[proxy._id + "_Template"](args.data))[0].cells[proxy._cellEditingDetails.columnIndex];
                    args.cellElement.removeClass("e-editedcell").replaceWith(cellElement);

                    proxy._trigger("refresh");
                    if (!args.data.treeMappingName)
                        args.data.treeMappingName = [];
                    args.data.treeMappingName.push(args.columnName);
                    if (proxy._trigger("endEdit", args)) {
                        args.data[args.columnName] = args.previousValue;
                        args.data.item[args.columnObject.field] = args.previousValue;
                        proxy.selectRows(this.selectedRowIndex());
                        proxy.refreshRow(this.selectedRowIndex());
                    }
                    
                    proxy._cellEventTrigger(args.rowElement[0].cells[proxy._cellEditingDetails.columnIndex], args.data, args.columnObject);
                    $targetTr.removeClass("e-editedrow");                    
                }
            }
            proxy._cancelSaveTools();
            return false;
        },

        //VALIDATE THE MODIFIED CELLVALUE
        editFormValidate: function () {

            if ($.isFunction($.validator))
                return $("#" + this._id + "EditForm").validate({
                    onsubmit: false
                }).form();

            return true;
        },


        //GET THE CURRENT CELL DATA
        getCurrentEditCellData: function () {

            var proxy = this,
                model = proxy.model;

            if ($("#" + proxy._id + "EditForm").length) {

                var $element = $("#" + proxy._id + proxy._cellEditingDetails.fieldName),
                    cellValue;

                switch (proxy._cellEditingDetails.cellEditType) {

                    case ej.TreeGrid.EditingType.String:
                        cellValue = $element.val();
                        break;

                    case ej.TreeGrid.EditingType.Numeric:
                        cellValue = $element.ejNumericTextbox("getValue");
                        $element.ejNumericTextbox("getValue");
                        break;

                    case ej.TreeGrid.EditingType.Dropdown:
                        if (model.isFromGantt) {
                            cellValue = proxy._getSelectedItem($element.ejDropDownList("model.selectedItems"));
                        } else
                            cellValue = $element.ejDropDownList("model.value");
                        break;

                    case ej.TreeGrid.EditingType.Boolean:
                        cellValue = $element.is(':checked');
                        break;

                    case ej.TreeGrid.EditingType.DatePicker:
                        if (model.dateFormat.indexOf("hh") == -1)
                            cellValue = $element.ejDatePicker("model.value");
                        else
                            cellValue = $element.ejDateTimePicker("model.value");

                        break;

                    case ej.TreeGrid.EditingType.DateTimePicker:
                        cellValue = Globalize.format($element.ejDateTimePicker("model.value"), "MM/dd/yyyy hh:mm tt");
                        break;

                }
                if (typeof cellValue == "string" && cellValue.length &&
                    model.columns[proxy._cellEditingDetails.columnIndex].type == "number") {

                    cellValue = parseFloat(cellValue);

                }

                return cellValue;
            }

            return null;
        },
        //Get the value from edited row
        getCurrentEditCellDataForRowEdit: function (field,type,cellIndex) {

            var proxy = this,
                model = proxy.model;

            if ($("#" + proxy._id + "EditForm").length) {

                var $element = $("#" + proxy._id + field),
                    cellValue;

                switch (type) {

                    case ej.TreeGrid.EditingType.String:
                        cellValue = $element.val();
                        break;

                    case ej.TreeGrid.EditingType.Numeric:
                        cellValue = $element.ejNumericTextbox("getValue");
                        $element.ejNumericTextbox("getValue");
                        break;

                    case ej.TreeGrid.EditingType.Dropdown:
                        cellValue = $element.ejDropDownList("model.value");
                        $element.data("ejWidgets") && $element[$element.data("ejWidgets")[0]]("destroy");
                        break;

                    case ej.TreeGrid.EditingType.Boolean:
                        cellValue = $element.is(':checked');
                        break;

                    case ej.TreeGrid.EditingType.DatePicker:
                        cellValue = Globalize.format($element.ejDatePicker("model.value"), this.model.dateFormat)
                        $element.data("ejWidgets") && $element[$element.data("ejWidgets")[0]]("destroy");
                        break;

                    case ej.TreeGrid.EditingType.DateTimePicker:
                        cellValue = Globalize.format($element.ejDateTimePicker("model.value"), "MM/dd/yyyy hh:mm tt");
                        $element.data("ejWidgets") && $element[$element.data("ejWidgets")[0]]("destroy");
                        break;

                }
                if (typeof cellValue == "string" && cellValue.length &&
                    model.columns[cellIndex].type == "number") {
                    cellValue = parseFloat(cellValue);
                }

                return cellValue;
            }

            return null;
        },

        _getResourceId:function(dataSource){

            var resourceIds = [],
                count = 0, length = dataSource.length;

            for (count = 0; count < length; count++) {
                resourceIds.push(dataSource[count][this.model.resourceIdMapping]);
            }
            return resourceIds;
        },

        _getSelectedItem: function (indexArray) {

            var proxy = this,
                count = 0,
                length = indexArray.length,
                dropDownData = proxy.model.columns[proxy._cellEditingDetails.columnIndex].dropdownData,
                selectedItems = [];

            if (dropDownData) {

                for (count = 0; count < length; count++) {

                    $.each(dropDownData, function (index, resourceInfo) {
                        if (indexArray[count] === index) {
                            selectedItems.push(resourceInfo);
                        }
                    });

                }
            }

            return selectedItems;
        },

        //GET THE FORMATED DATE 
        getFormatedDate: function (date) {
            return Globalize.format(date, this.model.dateFormat);
        },


        //GET THE FORMATTED TEXT
        formatting: function (formatstring, str) {

            formatstring = formatstring.replace(/%280/g, "\"").replace(/&lt;/g, "<").replace(/&gt;/g, ">");

            var proxy = this,
                s = formatstring,
                frontHtmlidx, frontHtml, rearHtml, lastidxval;

            frontHtmlidx = formatstring.split("{0:");
            lastidxval = formatstring.split("}");
            frontHtml = frontHtmlidx[0];
            rearHtml = lastidxval[1];

            if (formatstring.indexOf("{0:") != -1) {

                var toformat = new RegExp("\\{0(:([^\\}]+))?\\}", "gm"),
                    formatVal = toformat.exec(formatstring);

                if (formatVal != null && str != null) {

                    if (frontHtml != null && rearHtml != null) str = frontHtml + Globalize.format(str, formatVal[2]) + rearHtml;
                    else str = Globalize.format(str, formatVal[2]);

                } else if (str != null) str = str;
                else str = "";

                return str;
            } else if (proxy.data != null && proxy.data.Value == null) {

                $.each(proxy.data, function (dataIndex, dataValue) {
                    s = s.replace(new RegExp('\\{' + dataIndex + '\\}', 'gm'), dataValue);
                });

                return s;

            } else return proxy.data.Value;

        },


        //GET THE COLUMNINDEX BY USIGN THE FIELD NAME
        getColumnIndexByField: function (field) {

            var proxy = this,
                columns = proxy.model.columns,
                length = columns.length,
                column = 0;

            for (column; column < length; column++) {
                if (columns[column]["field"] == field)
                    break;
            }

            return column;
        },

        //GET THE BROWSER DETAILS
        getBrowserDetails: function () {
            var b = navigator.userAgent.match(/(firefox|chrome|opera|msie|safari)\s?\/?(\d+(.\d+)*)/i);
            if (!!navigator.userAgent.match(/Trident\/7\./))
                return { browser: "msie", version: jQuery.uaMatch(navigator.userAgent).version };
            return { browser: b[1].toLowerCase(), version: b[2] };
        },


        setValidation: function () {

            var proxy = this,
                columns = proxy.model.columns,
                length = columns.length,
                count = 0;

            proxy._initValidator();

            for (count; count < length; count++) {

                if (!ej.isNullOrUndefined(columns[count]["validationRules"])) {

                    proxy.setValidationToField(columns[count].field, columns[count].validationRules);

                }
            }
        },

        //SET THE VALIDATION TO THE PARTICULAR FIELD
        setValidationToField: function (name, rules) {

            var proxy = this,
                ele = $("#" + proxy._id + name).length > 0 ? $("#" + proxy._id + name) : $("#" + name);
            ele.rules("add", rules);

            var validator = $("#" + proxy._id + "EditForm").validate({
                onsubmit: false

            });

            if (!ej.isNullOrUndefined(rules["required"])) {

                validator.settings.messages[name] = {};
                validator.settings.messages[name]["required"] = ej.TreeGrid.getColumnByField(proxy.model.columns, name).headerText + " is required";

            }
        },


        //GET THE FIELDNAME OF COLUMN BY USING THE HEADERTEXT
        getFieldNameByHeaderText: function (headerText) {

            var proxy = this;

            if (ej.isNullOrUndefined(proxy._fieldColumnNames[headerText])) return null;

            return proxy._fieldColumnNames[headerText];
        },


        //CLEAR THE SELECTION

        clearSelection: function (index) {

            var proxy = this,
                model = proxy.model;

            if (this.selectedRowIndex() != -1) {

                var $gridRows = proxy.getRows(),
                    index;

                if (!ej.isNullOrUndefined(index)) {
                    for (i = 0; i < this._selectedRowsIndexes.length; i++)
                        proxy.getRowByIndex(this._selectedRowsIndexes[i]).removeAttr("aria-selected").find(".e-selectionbackground").removeClass("e-selectionbackground").removeClass("e-active");                   
                    var record=model.flatRecords[index];
                    if (record){   // For delete all records
                        record.isSelected = false;
                    }
                    else {

                        if ($gridRows) {
                            $gridRows.removeAttr("aria-selected").find(".e-rowcell").removeClass("e-selectionbackground").removeClass("e-active");
                        }
                        var dataManager = new ej.DataManager(model.flatRecords);

                        var query = new ej.Query();
                        query.search(true, ['isSelected'], ej.FilterOperators.Equals, true);

                        var records = dataManager.executeLocal(query);
                        var length = records && records.length;

                        if (length > 0) {

                            var count = 0;

                            for (count = 0; count < length; count++) {
                                records[count].isSelected = false;
                            }

                        }

                    }
                    if (!proxy._selectedRowsIndexes.length) {
                        proxy.selectedRowIndex(-1);
                        proxy.model.selectedItem = null;//For single selection only
                    }
                }

            }
        },


        //UPDATE EXPAND COLLAPSE RECORDS
        updateExpandCollapseRecords: function (record, expand) {

            var proxy = this;

            record.expanded = expand;
            proxy._removedCount = 0;
            proxy._expandCollapseRecordCount = proxy.getChildRecordsCount(record);
            index = proxy.model.flatRecords.indexOf(record);
            if (expand) {

                proxy._tempRecordIndex = proxy.model.records.indexOf(record);

                if (record.hasChildRecords) {
                    proxy._addNestedExpandCollapseRecords(record.childRecords, record.level, record, index);
                }

            } else {

                proxy.model.flatRecords.splice(index + 1, proxy._expandCollapseRecordCount);

            }
        },

        //COUNT THE CHILDRECORDS COUNT
        getChildRecordsCount: function (record) {

            var proxy = this,
                childRecords = record.childRecords,
                count = 0,
                length = childRecords ? childRecords.length : 0;

            for (count; count < length; count++) {

                if (proxy._filteredRecords.length > 0) {

                    var recordIndex = proxy._filteredRecords.indexOf(childRecords[count]);

                    if (recordIndex != -1) {

                        ++proxy._removedCount;

                        if (childRecords[count].hasChildRecords && childRecords[count].expanded) {
                            proxy.getChildRecordsCount(childRecords[count]);
                        }

                    }
                } else {

                    ++proxy._removedCount;

                    if (childRecords[count].hasChildRecords && childRecords[count].expanded) {
                        proxy.getChildRecordsCount(childRecords[count]);
                    }

                }
            }

            return proxy._removedCount;
        },


        //GET THE EXPAND STATUS OF RECORD
        getExpandStatus: function (record) {

            var parentRecord = record.parentItem;

            if (parentRecord != null) {

                if (parentRecord.expanded === false) {
                    return false;
                } else if (parentRecord.parentItem) {

                    if (parentRecord.parentItem.expanded === false) {
                        return false;
                    } else {
                        return this.getExpandStatus(parentRecord.parentItem);
                    }

                } else return true;
            } else return true;
        },


        //RETURN THE COLUMN FIELD NAMES
        getColumnFieldNames: function () {

            var columnNames = [],
                columns = this.model.columns,
                count = 0,
                length = columns.length;

            for (count; count < length; count++) {

                if (columns[count]["field"] && (columns[count]["field"] != "resourceInfo") && (columns[count]["field"] != "predecessor")) { //&& (columns[count]["field"] != "resourceInfo")
                    columnNames.push(columns[count]["field"]);
                }
                else if (columns[count]["field"] == "resourceInfo") {
                    //columns[count]["field"] = "resourceNames";
                    columnNames.push("resourceNames");
                }
                else if (columns[count]["field"] == "predecessor")
                {
                    //columns[count]["field"] = "predecessorsName";
                    columnNames.push("predecessorsName");
                }

            }

            return columnNames;
        },


        //RENDERED  RECORDS
        renderRecords: function (args) {

            var proxy = this;

            if (!args) {

                args = {};
                args.requestType = ej.TreeGrid.Actions.Refresh;

            }

            this.sendDataRenderingRequest(args);
        },       


        //SELECT THE ROW IN TREEGRID
        selectRows: function (rowIndex, toIndex) {

            var proxy = this,
                model = proxy.model;

            var $gridRows = proxy.getRows(),
            selectedItem;
            
            if ((model.editSettings.allowEditing || model.editSettings.allowAdding) && !proxy._isRowEdit ) {
                if ($("#" + proxy._id + "EditForm").length > 0 && proxy.endEdit()) {
                    $gridRows = proxy.getRows();
                    return;
                }
            }

            if (ej.isNullOrUndefined(toIndex) || ej.isNullOrUndefined(rowIndex)) {

                rowIndex = ej.isNullOrUndefined(rowIndex) ? toIndex : rowIndex;        

                    switch (model.selectionType) {

                        case ej.TreeGrid.SelectionType.Multiple:

                            if (proxy._multiSelectCtrlRequest) {
                                var selectedRowIndex = $.inArray(rowIndex, proxy._selectedRowsIndexes);
                                selectedRowIndex != -1 && proxy.clearSelection(rowIndex) && proxy._selectedRowsIndexes.splice(selectedRowIndex, 0);

                                if (selectedRowIndex == -1) {
                                    proxy._selectedRowsIndexes.push(rowIndex);                                   
                                    proxy.getRowByIndex(rowIndex).attr("aria-selected", "true").find('.e-rowcell').addClass("e-selectionbackground e-active").attr("tabindex", "0");                                    
                                }
                                break;
                            }
                            

                        case ej.TreeGrid.SelectionType.Single:
                            proxy.clearSelection(proxy._previousIndex);
                            model.selectedItem = null;
                            if (rowIndex <= proxy._updatedRecords.length - 1) {
                                proxy._selectedRowsIndexes = [];
                                proxy._selectedRowsIndexes.push(rowIndex);
                                proxy.getRowByIndex(rowIndex).attr("aria-selected", "true").find('.e-rowcell').addClass("e-selectionbackground e-active").attr("tabindex", 0);
                                if (proxy._updatedRecords[rowIndex]) {
                                    proxy._updatedRecords[rowIndex].isSelected = true;  //Selection issue Changes
                                    model.selectedItem = proxy._updatedRecords[rowIndex];
                                }
                                
                                if (proxy._updatedRecords[proxy._previousIndex] && rowIndex != proxy._previousIndex) {
                                    proxy._updatedRecords[proxy._previousIndex].isSelected = false;
                                }

                            }
                            break;
                    }
              
            } else {

                if (model.selectionType == ej.TreeGrid.SelectionType.Multiple)
                {
                proxy.clearSelection();
                proxy._selectedRowsIndexes = [];
                var rows = rowIndex - toIndex < 0 ? $gridRows.slice(rowIndex, toIndex + 1) : $gridRows.slice(toIndex, rowIndex + 1),
                    count = 0,
                    length = rows.length;

                for (count; count < length; count++) {
                    proxy._selectedRowsIndexes.push(rows[count].rowIndex);
                    model.flatRecords[rows[count].rowIndex].isSelected = true;
                }
                    $(rows).attr("aria-selected", "true").find('.e-rowcell').addClass("e-selectionbackground e-active").attr("tabindex", "0");                                       
            }
            }
            proxy._previousIndex = proxy._selectedRowsIndexes.length ? rowIndex : undefined;

            if (this.selectedRowIndex() != rowIndex)
            this.selectedRowIndex(rowIndex);

            proxy._multiSelectCtrlRequest = false;
            return false;
        },


        //GET THE CURRENTCELLINDEX
        getCellIndex: function (e, target) {

            var $target = $(e.target);

            if (target) $target = $(target);

            if ($target.prop("tagName") == "TD") {
                return $target.index();
            } else if ($target.prop('tagName') == "DIV" && $target.hasClass('e-cell')) {

                var $td = $target.closest('td');
                return $td.index();

            } else if ($target.prop('tagName') == "DIV" && $($target.closest('td')[0]).hasClass("e-templatecell")) {

                var $td = $target.closest('td');
                return $td.index();
            }
            else if ($($target.closest('td')[0]).hasClass("e-templatecell") && $($target.closest("tr")[0]).hasClass("e-templaterow")) {

                var $td = $target.closest('td');
                return $td.index();
            }
            return -1;
        },


        //GET THE CURRENT ROW INDEX
        getRowIndex: function (e) {

            var proxy = this,
                $target = $(e.target),
                $gridRows = proxy.getRows(),
                index = $gridRows.index($target.parent());

            if (index == -1) {

                var row = $target.closest('tr');
                index = $gridRows.index(row);

            }

            return index;
        },


        //GET THE ROW ELEMENT BY INDEX
        getRowByIndex: function (from, to) {
            try {
                var proxy = this;

                var $gridRows = proxy.getRows(),
                    gridRows=proxy._gridRows,
                    $row = $();

                if (proxy.model.enableVirtualization) {
                    var recordstart = proxy._updatedRecords[from];
                    from = proxy.model.currentViewData.indexOf(recordstart);            
                }

                if (ej.isNullOrUndefined(to)) {
                    if (proxy.model.enableVirtualization) {
                        var recordend = proxy._updatedRecords[to];
                        to = proxy.model.currentViewData.indexOf(recordend);
                    }
                    return $(gridRows[from]);
                } else {                    
                    return $($gridRows.slice(from, to));
                }
            } catch (e) {
                return $();
            }
        },

        //cancel the editMode of the cell
        cancelEditCell: function (e) {

            var proxy = this,
                tr = proxy._gridRows[proxy.selectedRowIndex()],//proxy._cellEditingDetails.rowIndex
                cellData = {},
                cell;

            cellData[proxy._cellEditingDetails.fieldName] = proxy._cellEditingDetails.cellValue,
            data = proxy.model.selectedItem;

            if ($(tr).hasClass("e-insertedrow")) cell = tr.cells[proxy._cellEditingDetails.columnIndex];
            else cell = tr.cells[proxy._cellEditingDetails.columnIndex];

            $(cell).removeClass("e-editedcell").empty().html(
                $($.render[proxy._id + "_Template"](data))[0].cells[proxy._cellEditingDetails.columnIndex].innerHTML
            );

            proxy.element.focus();          
            proxy.model.isEdit = false;
            proxy._cancelSaveTools();
        },

        //Cancel row edit.
        cancelRowEditCell: function (e) {

            
            var proxy = this;
            
            //  To delete the empty added row when allowDeleting is false.
            var temp = proxy.model.editSettings.allowDeleting;
            form = $(document.getElementById(proxy._id + "EditForm"));
            if (form.closest("tr").hasClass('e-addedrow')) {
                var index = form.closest("tr").index();
                proxy._currentViewData = proxy.getCurrentViewData();
                var item = proxy._currentViewData[index].item;
                var isEmpty = proxy._checkIsEmptyRow(item);                
                if (isEmpty) {
                    if (!proxy.model.editSettings.allowDeleting)
                        proxy.model.editSettings.allowDeleting = true;
                }
            }

            var rowIndex = this.selectedRowIndex();
            if (form.closest("tr").hasClass('e-addedrow'))
                rowIndex = index;
            tr = proxy._gridRows[rowIndex];
            data = proxy.model.selectedItem;
            //Cancel the edited row.
            if ($(tr).hasClass('e-editedrow')) {
                $(tr).removeClass("e-editedrow").empty().html(
                    $($.render[proxy._id + "_Template"](data))[0].innerHTML);
                index = rowIndex;
            }
            else if ($(tr).hasClass('e-rowedit')) {
                $(tr).removeClass("e-rowedit").empty().html(
                    $($.render[proxy._id + "_Template"](data))[0].innerHTML);
                index = rowIndex;
            }               
                //Cancel the newly added row.
            else {
                var length = proxy._$gridRows.length;
                var rowPosition = proxy.model.editSettings.rowPosition;
                if (rowPosition == "bottom")
                    index = length - 1;
                    
                else if (rowPosition == "top")
                    index = 0;
                else
                    index = rowIndex;

                tr = proxy._gridRows[index];
                proxy.deleteRow($(tr));
            }
            proxy.model.isEdit = proxy._isRowEdit = false;
            if (rowPosition == "bottom" || rowPosition == "belowSelectedRow")
                index = index - 1;
            proxy.selectRows(index);
            proxy.model.editSettings.allowDeleting = temp;
            //Change the index of selected row when cancel the first empty row in empty content.
            if (proxy._$gridRows == null) 
                proxy.selectRows(-1);               
        },

        //RERENDERED THE EDITED RECORD
        refreshRow: function (index) {
            var proxy = this,
                data = proxy.model.currentViewData[index],eventArgs={};
            if (data) {
                $(proxy._gridRows[index]).replaceWith($($.render[proxy._id + "_Template"](data)));
                proxy.setGridRows($(proxy.getContentTable().get(0).rows));
                eventArgs.rowElement=proxy._gridRows[index];
                eventArgs.data=data;
                proxy._refreshedCellEventTrigger(eventArgs);
            }
        },
        //Trigger rowDataBound and queryCellInfo event when row is refreshed
        _refreshedCellEventTrigger:function(eventArgs)
        {
            var proxy = this, model = this.model;
            if (model.queryCellInfo != null || model.rowDataBound != null) {
                proxy._trigger("rowDataBound", {
                    rowElement: eventArgs.rowElement,
                    data: eventArgs.data
                });

                var tdCells = eventArgs.rowElement.cells,
                $tdRowcells = $(eventArgs.rowElement).find(".e-rowcell"),
                cellIndex = 0,
                length = tdCells.length,
                column = null,
                columns = proxy.model.columns;

                for (cellIndex; cellIndex < length; cellIndex++) {
                    if ($(tdCells[cellIndex]).hasClass("e-rowcell")) {
                        column = columns[$tdRowcells.index(tdCells[cellIndex])];
                    }
                    if (column) {
                        proxy._cellEventTrigger(tdCells[cellIndex], eventArgs.data, column);
                    }
                }
            }
        },

        //removeRecord: function (args) {
        //    var proxy = this,
        //    deletedRow = args.data, childIndex;
        //    var childRecordsCount = proxy._getFilteredChildRecordsCount(deletedRow);
        //    childRecordsCount += 1;var count=0;
        //    for (var i = 0; i < childRecordsCount; i++) {
        //        proxy.getRows().eq(args.recordIndex).remove();
        //        proxy.setGridRows($(proxy.getContentTable().get(0).rows));
        //    }
        //},

        //RENDERE THE ADDED NEW RECORD
        renderRecord: function (args) {
            var proxy = this,
                addedGridRow = $.render[this._id + "_Template"](args._cAddedRecord),
                model = proxy.model, spliceIndex, spliceIndexRecords;

            if (proxy._gridRows != null && proxy._gridRows.length > 0) {
                var insertIndex = model.currentViewData.indexOf(model.selectedItem);
                if (args.position) {
                    if (args.position == "Above") {
                        proxy.getRows().eq(insertIndex).before(addedGridRow);
                    }
                    else if (args.position == "Below") {
                        proxy.getRows().eq(insertIndex).after(addedGridRow);
                    }
                }
                else {
                    if (insertIndex === -1) {
                        args._cAddedRecord.index = 0;
                        proxy.getRows().eq(0).before(addedGridRow);
                    } else {
                        proxy.getRows().eq(insertIndex).after(addedGridRow);
                    }
                }

                proxy.setGridRows($(proxy.getContentTable().get(0).rows));

                args._cAddedRecord.hasChildRecords = false;
                args._cAddedRecord.expanded = false;

                //For update selfreference datasource
                if (model.parentIdMapping) {
                    if (args._cAddedRecord.parentItem)
                        args._cAddedRecord.item[model.parentIdMapping] = args._cAddedRecord.parentItem.taskId;
                    else
                        delete args._cAddedRecord.item[model.parentIdMapping];

                    if (this.dataSource() instanceof ej.DataManager) {
                        if (this.dataSource().dataSource.offline && this.dataSource().dataSource.json) {
                            this.dataSource().dataSource.json.push(args._cAddedRecord.item);
                        }
                    } else {
                        this.dataSource().push(args._cAddedRecord.item);
                    }
                }
                //update child record in parent item
                if (args._cAddedRecord.parentItem && model.selectedItem) {

                    if (args._cAddedRecord.parentItem.hasChildRecords && (args.position == "Below" || !args.position)) {

                        var tempIndex = model.flatRecords.indexOf(args._cAddedRecord.parentItem);
                        var childIndex = model.flatRecords[tempIndex].childRecords.indexOf(model.selectedItem);
                        if (childIndex === -1) {
                            model.flatRecords[tempIndex].childRecords.splice(0, 0, args._cAddedRecord);
                            if (!model.parentIdMapping)
                                model.flatRecords[tempIndex].item[model.childMapping].splice(0, 0, args._cAddedRecord.item);
                        }
                        else {
                            model.flatRecords[tempIndex].childRecords.splice(childIndex + 1, 0, args._cAddedRecord);
                            if (!model.parentIdMapping)
                                model.flatRecords[tempIndex].item[model.childMapping].splice(childIndex + 1, 0, args._cAddedRecord.item);
                        }
                    }
                    else if (args._cAddedRecord.parentItem.hasChildRecords && args.position == "Above") {

                        var tempIndex = model.flatRecords.indexOf(args._cAddedRecord.parentItem);
                        var childIndex = model.flatRecords[tempIndex].childRecords.indexOf(model.selectedItem);

                        if (childIndex === -1) {
                            model.flatRecords[tempIndex].childRecords.push(args._cAddedRecord);
                            if (!model.parentIdMapping)
                                model.flatRecords[tempIndex].item[model.childMapping].push(args._cAddedRecord.item);
                        }
                        else {
                            model.flatRecords[tempIndex].childRecords.splice(childIndex, 0, args._cAddedRecord);
                            if (!model.parentIdMapping)
                                model.flatRecords[tempIndex].item[model.childMapping].splice(childIndex, 0, args._cAddedRecord.item);
                        }
                    }
                }
                else if (!args._cAddedRecord.parentItem && model.selectedItem) {
                    model.parentRecords.splice(args._cAddedRecord.index, 0, args._cAddedRecord);
                    var tempDataSource;

                    if (this.dataSource() instanceof ej.DataManager) {
                        if (this.dataSource().dataSource.offline && this.dataSource().dataSource.json) {
                            tempDataSource = this.dataSource().dataSource.json;
                        }
                    }
                    else {
                        tempDataSource = this.dataSource();
                    }

                    if (tempDataSource) {
                        var idx = tempDataSource.indexOf(model.selectedItem.item);
                        if (args.position == "Above") {
                            if (!model.parentIdMapping)
                                tempDataSource.splice(idx, 0, args._cAddedRecord.item);
                        }
                        else if (args.position == "Below" || !args.position) {
                            if (!model.parentIdMapping)
                                tempDataSource.splice(idx + 1, 0, args._cAddedRecord.item);
                        }
                    }
                }
                else if (!model.selectedItem && args._cAddedRecord) {
                    if (this.dataSource() instanceof ej.DataManager) {
                        if (this.dataSource().dataSource.offline && this.dataSource().dataSource.json) {
                            if (!model.parentIdMapping)
                                this.dataSource().dataSource.json.splice(0, 0, args._cAddedRecord.item);
                        }
                    }
                    else {
                        if (!model.parentIdMapping)
                            this.dataSource().splice(0, 0, args._cAddedRecord.item);
                    }
                }

                //splice index for records and id
                if (model.selectedItem) {
                    var selectedIndex = model.records.indexOf(model.selectedItem);
                    var flatIndex = model.flatRecords.indexOf(model.selectedItem);
                    if (args.position == "Above") {
                        spliceIndexRecords = selectedIndex;
                        spliceIndex = flatIndex;
                    }
                    else {
                        spliceIndexRecords = selectedIndex + 1;
                        spliceIndex = flatIndex + 1;
                    }
                }
                else {
                    spliceIndexRecords = 0;
                    spliceIndex = 0;
                }

                if (proxy.getExpandStatus(args._cAddedRecord) && model.enableVirtualization) {
                    if (spliceIndex === model.flatRecords.length) {
                        model.flatRecords.push(args._cAddedRecord);
                    }
                    else {
                        proxy._recordIndexCount = 0;
                        model.flatRecords.splice(spliceIndex, 0, args._cAddedRecord);
                    }
                } else if (!model.enableVirtualization) {

                    if (spliceIndex === model.flatRecords.length) {
                        model.flatRecords.push(args._cAddedRecord);
                    }
                    else {
                        proxy._recordIndexCount = 0;
                        model.flatRecords.splice(spliceIndex, 0, args._cAddedRecord);
                    }
                }
                if (spliceIndexRecords === model.records.length) {
                    model.records.push(args._cAddedRecord);
                    if (model.isFromGantt)
                        model.ids.push(args._cAddedRecord.taskId.toString());
                }
                else {
                    model.records.splice(spliceIndexRecords, 0, args._cAddedRecord);
                    if (model.isFromGantt)
                        model.ids.splice(spliceIndexRecords, 0, args._cAddedRecord.taskId.toString());
                }
                proxy.setRecordsCount(model.flatRecords.length);
                proxy.setHeight(model.flatRecords.length * model.rowHeight);
                if (!(model.allowSorting && model.sortSettings.sortedColumns.length > 0)) {
                    proxy._updatedRecords = model.flatRecords;
                    proxy._updateCurrentViewData();
                }
            }
            else if (proxy._gridRows == null || proxy._gridRows.length == 0) {
                //model.ids = [];
                if (this.selectedRowIndex() === -1) {

                    args._cAddedRecord.hasChildRecords = false;
                    args.recordIndex = 0;
                }

                model.flatRecords.push(args._cAddedRecord);
                if (this.dataSource() == null) {
                    this.dataSource([]);
                }

                if (this.dataSource() instanceof ej.DataManager) {
                    if (this.dataSource().dataSource.offline && this.dataSource().dataSource.json) {
                        this.dataSource().dataSource.json.push(args._cAddedRecord.item);
                    }
                } else {
                    this.dataSource().push(args._cAddedRecord.item);
                }
                model.records.push(args._cAddedRecord);
                if (model.isFromGantt)
                    model.ids.push(args._cAddedRecord.taskId.toString());
                proxy._updatedGanttRecords = model.flatRecords;

                proxy._updatedRecords = model.flatRecords;
                proxy.setRecordsCount(model.flatRecords.length);
                proxy.setHeight(model.flatRecords.length * model.rowHeight);

                proxy._updateCurrentViewData();
                model.parentRecords.push(args._cAddedRecord);
                proxy.getContentTable().find('tbody').empty().append(proxy._getEmptyTbody());
                var temp = document.createElement('div');
                proxy.getContentTable().find("colgroup").first().replaceWith(proxy._getMetaColGroup());
                var $tbody = proxy.getContentTable().children('tbody');
                $tbody.empty();
                temp.innerHTML = ['<table>', $.render[proxy._id + "_Template"](proxy.model.currentViewData),
                    '</table>'].join("");
                proxy.getContentTable().get(0).replaceChild(temp.firstChild.firstChild,
                    proxy.getContentTable().get(0).lastChild);

                proxy._gridRows = proxy.getContentTable().get(0).rows;
                proxy.setGridRows($(proxy.getContentTable().get(0).rows));
                proxy._eventBindings();

            }

        },


        
        onScrollHelper: function (scrolltop) {
            var proxy = this;            
            proxy._$gridContent.ejScroller("scrollY", scrolltop, true);
            var isHorizontalScroll = proxy._$gridContent.ejScroller("isHScroll");
            if (!isHorizontalScroll)
                proxy._$gridContent.scrollTop(scrolltop);
        },

        isVScroll: function () {
            if (this._$gridContent.hasClass("e-scroller")) {
                return this._$gridContent.ejScroller("isVScroll");
            }
            else
            {
                return false;
            }
        },

        //REFRESH THE SCROLLER FOR TREEGRIDCONTENT
        refreshScroller:function(panSize){
            
            var proxy = this;                       
            proxy._$gridContent.removeClass("e-borderbox");
            //proxy._$gridContent.css({ 'width': panSize + "px" });
            var scrollTop = proxy._$gridContent.ejScroller("option", "scrollTop");
            var scrollLeft = proxy._$gridContent.ejScroller("option", "scrollLeft");

            proxy._$gridContent.ejScroller("option", { "persist": true });
            proxy._$gridContent.ejScroller("option", { "width": panSize });
            
            var maxScrollWidth = proxy.getMaxScrollWidth();
            if (scrollLeft > maxScrollWidth)
                scrollLeft = maxScrollWidth > 0 ? maxScrollWidth : 0;

            proxy._$gridContent.css("height", proxy._viewPortHeight);
            proxy._$gridContent.ejScroller("refresh");
            var isHorizontalScroll = proxy._$gridContent.ejScroller("isHScroll");

            if (proxy.model.isFromGantt)
                if (!isHorizontalScroll) {
                    proxy._$gridContent.addClass("e-borderbox");
                }
                else {
                    proxy._$gridContent.removeClass("e-borderbox");
                }
            proxy._$gridContent.ejScroller("option", { "scrollTop": scrollTop });
            proxy._$gridContent.ejScroller("option", { "scrollLeft": scrollLeft });
            proxy._$gridHeaderContainer.scrollLeft(scrollLeft);

            if (!isHorizontalScroll)
            proxy._$gridContent.scrollTop(scrollTop);
            //else {
            //    proxy._$gridContent.scrollTop(0)
            //}
        },
        getMaxScrollWidth:function()
        {
            var proxy=this;
            return proxy._$gridContent.children(".e-content").children(".e-gridcontainer").children(".e-table").width() - proxy._$gridContent.children(".e-content").width();
        },
        refreshHeight:function(){

            var proxy = this;
            proxy._$gridContent.ejScroller("refresh");            

        },

        //#endregion

        //#region PRIVATE METHODS

        //CALCULATE THE VIEWPORTHEIGHT
        _getViewPortHeight: function () {

            var proxy = this,
                height = 0,borderTopWidth=0;
                borderTopWidth = proxy.model.isFromGantt ? 0 : 1;
                height = proxy.element.height() -
                proxy._$gridHeaderContent.height() -
                parseFloat(borderTopWidth) -
                parseFloat(proxy._$gridHeaderContent.css("border-bottom-width"));
                if (proxy.model.toolbarSettings.showToolbar) {
                    height -= $("#" + proxy._id + "_toolbarItems").outerHeight();
                }

            if (!proxy.model.isFromGantt)
                height -= 1;//in gantt gridcontent does't contain border-width but have in treeGrid
            return height;

        },

        updateViewPortHeight: function () {
            var proxy = this;
            proxy._viewPortHeight = proxy._getViewPortHeight();
        },

        _updateScrollCss: function () {
            var proxy = this;
            if (!proxy.model.isFromGantt) {
                var isVscroll = proxy.isVScroll();
                if (isVscroll) {
                        proxy._$gridHeaderContent.addClass("e-scrollcss");
                } else {
                    proxy._$gridHeaderContent.removeClass("e-scrollcss");
                }
                proxy._resizeFilteringElements();
            }
        },



        //UPDATE CURRENT VIEWPORT DATA FROM FLATRECORDS/UPDATED RECORDS
        _updateCurrentViewData: function () {

            var proxy = this,
                model = proxy.model,
                args = {},
                tMargin,
                isRangeModified = false;

            //CHECK VIRTUALIZATION IS ENABLED OR NOT 
            if (model.enableVirtualization) {

                proxy.getVisibleRange();
                model.currentViewData = proxy._updatedRecords.slice(proxy._visibleRange.top,
                    proxy._visibleRange.bottom);



                if (proxy._vScrollDist !== 0) {

                    tMargin = proxy._scrollTop - proxy._offset;

                    //console.log("Margin :" + tMargin);

                    if ((proxy._prevRTop - proxy._visibleRange.top !== 0) ||
                        (proxy._prevRBottom - proxy._visibleRange.bottom !== 0)) {

                        args.requestType = ej.TreeGrid.Actions.Refresh;
                        proxy.sendDataRenderingRequest(args);
                        isRangeModified = true;

                    }

                        proxy._$tableContent.css({
                            "top": tMargin
                        });

                    proxy._prevRTop = proxy._visibleRange.top;
                    proxy._prevRBottom = proxy._visibleRange.bottom;

                }

            } else {

                model.currentViewData = proxy._updatedRecords;

            }

            if (proxy._isEnterKeyPressed) {

                proxy._isEnterKeyPressed = false;
                if (model.allowSelection && model.editSettings.allowEditing) {

                    if (!isRangeModified) proxy._cellEditingDetails.rowIndex += 1;

                    if (!proxy._rowSelectingEventTrigger()) {

                        proxy.selectRows(proxy._cellEditingDetails.rowIndex);
                        proxy._rowSelectedEventTrigger(proxy._cellEditingDetails.rowIndex);

                    }

                    proxy.cellEdit(proxy._cellEditingDetails.rowIndex, proxy.model.columns[proxy._cellEditingDetails.columnIndex].field);

                }
            }
        },


        //GET THE TABLE ROW POSITION
        _getRowPosition: function (y) {
            return Math.ceil((y) / this.model.rowHeight);
        },


        //GET THE COLUMNGROUP FOR HEADER TABLE
        _getMetaColGroup: function () {

            var $colgroup = this.getHeaderTable().find('colgroup').clone();
            return $colgroup;

        },


        //CREATE EMPTY ROW WHILE DATASOURCE OBJECT AS NULL
        _getEmptyTbody: function () {

            var proxy = this,
                $emptyTd = ej.buildTag('td', proxy.model.emptyRecordText, {}, { colSpan: proxy.model.columns.length });
            return $(document.createElement("tr")).append($emptyTd);

        },


        //ADD SORTICON TO THE COLUMN HEADER
        _addSortElementToColumn: function (field, direction) {

            var proxy = this,
                column = ej.TreeGrid.getColumnByField(proxy.model.columns, field),
                index = $.inArray(column, proxy.model.columns),
                $headerCellDiv = proxy.getHeaderTable().find("thead").
                find(".e-headercell").eq(index).find(".e-headercelldiv");
            $headerCellDiv.find(".e-ascending,.e-descending").remove();
            $headerCellDiv.append(proxy._createSortElement().addClass("e-" + direction).addClass("e-icon"));
            $headerCellDiv.parent().attr("aria-sort", direction);
        },


        //CREATE SORT ELEMENT        
        _createSortElement: function () {
            return ej.buildTag('span', "&nbsp;");
        },


        //RENDERED EDITED CELL
        _renderCellEditObject: function (cellEditArgs, $td) {

            var proxy = this,
                $form = ej.buildTag("form.#" + proxy._id + "EditForm", "", {}, {}),
                $cellEditTemplate = proxy._cellEditTemplate,
                $element,
                htmlString,
                cellData = {};

            cellData[cellEditArgs.columnObject.field] = cellEditArgs.value,
            columnIndex = proxy.getColumnIndexByField(cellEditArgs.columnObject.field);

            if (columnIndex===proxy.model.treeColumnIndex) {
                $td.find('.e-cell').empty();
            } else $td.empty();

            htmlString = $cellEditTemplate.find("#" + cellEditArgs.columnObject.field + "_CellEdit").html();
            if (cellEditArgs.columnObject.field === "predecessor")
                $element = $($.templates(htmlString).render(cellEditArgs.data));
            else
                 $element = $($.templates(htmlString).render(cellData));

            if ($element.get(0).tagName == "SELECT") {

                $element.val(cellData[cellEditArgs.columnObject.field]);
                $element.val() == null && $element.val($element.find("option").first().val());

            }

            $form.append($element);

           if (columnIndex===proxy.model.treeColumnIndex) {
                $td.find('.e-cell').append($form);
            } else $td.append($form);

            proxy._setoffsetWidth();
            proxy._refreshEditForm();

            if ($.isFunction($.validator) && !$.isEmptyObject(cellEditArgs.validationRules)) {

                proxy._initValidator();
                proxy.setValidationToField(cellEditArgs.columnObject.field, cellEditArgs.validationRules);

            }
            proxy.model.isEdit = true;

        },


        //SET WIDTH FOR EDITING ELEMENTS
        _setoffsetWidth: function () {

            var proxy = this,
                tds, $form = $("#" + proxy._id + "EditForm"),
                i = 0,
                length, child;

            if (proxy.model.editSettings.editMode.toLowerCase() == "cellediting" && !proxy._isRowEdit) {
                tds = $form.closest("td");
            } else {
                tds = $form.find("tr").find(".e-rowcell");
            }

            length = tds.length;

            for (i; i < length; i++) {

                child = $(tds.children()[0]).children();

                if (child.length > 1) {
                    proxy._tdsOffsetWidth[i] = tds.get(i).offsetWidth - child[0].offsetWidth - child[1].offsetWidth;
                } else {
                    proxy._tdsOffsetWidth[i] = tds.get(i).offsetWidth;
                }
            }

        },


        //get Index of resourceInfo
        getIndexofresourceInfo: function (dataSource) {

            var proxy = this,
                data = proxy._cellEditingDetails.data,
                resourceInfo = data.resourceInfo,
                count = 0,
                length = resourceInfo && resourceInfo.length,
                resourceIndex = [];

            for (count; count < length; count++)
                resourceIndex.push(dataSource.indexOf(resourceInfo[count]));

            return resourceIndex;

        },

        //REFRESH THE EDITED FORM
        _refreshEditForm: function () {

            var proxy = this,
                form = document.getElementById(proxy._id + "EditForm"),
                elementFocused = false,
                $formElement = $(form).find("input,select"),
                percent = 86,
                i = 0,
                length = $formElement.length,
                $element, inputWidth,
                model = proxy.model,
                width,
                params = {},
                value,
                column,
                customParams,
                toformat,
                formatVal,
                rowHeight = proxy.model.rowHeight;

            for (i; i < length; i++) {

                $element = $formElement.eq(i);

                if (model.editSettings.editMode.toLowerCase() == "cellediting")
                    percent = 95;
                if (proxy._isRowEdit && $element.attr("type") != "checkbox")
                    inputWidth = "100%";
               else
                inputWidth = proxy._tdsOffsetWidth[i] * (percent / 100);
                if ($element.hasClass("e-numerictextbox")) {

                    width = inputWidth;
                    value = $element.val();
                    params.width = width;
                    params.height = rowHeight - 5;
                    params.showSpinButton = true;
                    params.cssClass = model.cssClass;
                  
                    if (value.length) params.value = parseFloat(value);

                    customParams = ej.TreeGrid.getColumnByField(model.columns, $element.prop("name"));

                    if (model.isFromGantt && (customParams.field === "duration" || customParams.field === "status"))
                    {
                        params.minValue = 0;
                        if (customParams.field == "status")
                            params.maxValue = 100;
                    }

                    if (!ej.isNullOrUndefined(customParams["editParams"])) $.extend(params, customParams["editParams"]);

                    $element.ejNumericTextbox(params);
                    $element.prop("name", $element.prop("name").replace(proxy._id, ""));

                } else if ($element.hasClass("e-datepicker")) {

                    //inputWidth = proxy._tdsOffsetWidth[i] * (90 / 100);
                    width = inputWidth;
                    params.width = width;
                    params.height = rowHeight - 5;
                    params.locale = model.locale;
                    params.cssClass = model.cssClass;
                    params.displayDefaultDate = true;
                    params.dateFormat = model.dateFormat;

                    if ($element.val().length) params.value = new Date($element.val());

                    column = ej.TreeGrid.getColumnByField(model.columns, $element.prop("name"));

                    if (column["format"] !== undefined && column.format.length > 0) {

                        toformat = new RegExp("\\{0(:([^\\}]+))?\\}", "gm");
                        formatVal = toformat.exec(column.format);
                        params.dateFormat = formatVal[2];
                    }

                    if (!ej.isNullOrUndefined(column["editParams"])) $.extend(params, column["editParams"]);

                    if (model.dateFormat.indexOf("hh") == -1)
                        $element.ejDatePicker(params);
                    else {
                        $element.ejDateTimePicker(params);
                    }
                } else if ($element.hasClass("e-datetimepicker")) {

                    width = inputWidth;
                    params = {
                        width: width,
                        height: rowHeight - 5,
                        locale:model.locale,
                        cssClass: model.cssClass,
                        showButton: false
                    };

                    if ($element.val().length) params.value = new Date($element.val());

                    column = ej.TreeGrid.getColumnByField(model.columns, $element.prop("name"));

                    if (column["format"] !== undefined && column.format.length > 0) {

                        toformat = new RegExp("\\{0(:([^\\}]+))?\\}", "gm");
                        formatVal = toformat.exec(column.format);
                        params.dateTimeFormat = formatVal[2];

                    }

                    if (!ej.isNullOrUndefined(column["editParams"])) $.extend(params, column["editParams"]);
                    if (proxy.model.isFromGantt)
                        {
                    if (model.dateFormat.indexOf("hh") == -1)
                        $element.ejDatePicker(params);
                    else
                        $element.ejDateTimePicker(params);
                    }
                    else
                        $element.ejDateTimePicker(params);

                } else if ($element.hasClass("e-dropdownlist")) {
                    if (proxy._isRowEdit)
                        {
                        var dataSource = model.columns[i].dropdownData;
                        var fieldName = model.columns[i].field;
                    }
                    else{
                    var dataSource = model.columns[proxy._cellEditingDetails.columnIndex].dropdownData;
                        var fieldName = model.columns[proxy._cellEditingDetails.columnIndex].field;
                    }

                    if(model.isFromGantt){
                        $element.ejDropDownList({
                            width: inputWidth + "px",
                            height: rowHeight - 5,
                            showCheckbox: true,
                            dataSource: dataSource,
                            popupWidth:"auto",
                            fields: {
                                id: model.resourceIdMapping,
                                text: model.resourceNameMapping,
                                value: model.resourceNameMapping
                            },
                            selectedItems: proxy.getIndexofresourceInfo(dataSource)
                        });
                        
                    } else {
                        $element.css({ 'position': 'absolute', 'margin-top': '-13px' });
                        $element.ejDropDownList({
                            width: inputWidth,
                            height: rowHeight - 5,                            
                            dataSource: dataSource,
                        });                        
                    }
                    $element.ejDropDownList("setSelectedValue", $element.val());
                    $("#" + proxy._id + fieldName + "_list").hide();

                } else {

                    switch ($element.prop('tagName')) {
                        case "INPUT":

                            if ($element.attr("type") != "checkbox") {

                                $element.css("text-align", $element.attr("name") != null &&
                                    ej.TreeGrid.getColumnByField(model.columns, $element.attr("name")) != null ?
                                    ej.TreeGrid.getColumnByField(model.columns, $element.attr("name")).textAlign :
                                    "center");

                                $element.outerWidth(inputWidth).height(model.rowHeight-9);

                            } else $element.width(inputWidth > 0 ? ($element.width() > inputWidth ? inputWidth : $element.width()) : 1);

                            break;

                        case "SELECT":
                            $element.width(inputWidth).height(20);
                            break;
                    }
                }

                if (!$element.is(":disabled") && !elementFocused &&
                    (!$element.is(":hidden") || typeof $element.data("ejDropDownList") == "object")) {

                    if (!proxy._isEnterKeyPressed) {

                        proxy._focusElements($element.closest('td'));
                        elementFocused = true;

                    }
                }
            }
        },


        //INITIALIZE THE VALIDATOR
        _initValidator: function() {

            var proxy = this;

            $("#" + proxy._id + "EditForm").validate({
                onclick: false,
                onfocusout: false,
                errorClass: 'e-field-validation-error',
                errorElement: 'div',
                wrapper: "div",

                errorPlacement: function(error, element) {
                    var $td = element.closest("td"),
                        $container = $(error).addClass("e-error"),
                        $tail = ej.buildTag("div.e-errortail e-toparrow");

                    $td.find(".e-error").remove();
                    element.hasClass("e-numerictextbox") ? $container.insertAfter(element.closest(".e-numeric")) :
                                                          $container.insertAfter(element);
                    $container.prepend($tail);
                    proxy.model.editSettings.editMode != "normal" && $container.offset({
                        left: element.offset().left
                    });

                    $container.fadeIn("slow");
                }
            });
        },


        //SET FOCUS TO EDITED ELEMENT
        _focusElements: function ($currentCell) {
            var proxy = this;

            if ($currentCell.length) {

                $currentCell.focus();
                var $childElem = $currentCell.children();

                if ($childElem[0]) {

                    if ($childElem[0].tagName.toLowerCase() == "select" || 
                        $childElem[0].tagName.toLowerCase() == "input") {

                        $childElem.focus().select();
                        $childElem[0].focus();

                    } else if ($childElem.find(".e-field.e-dropdownlist").length) {

                        $childElem.find(".e-ddl").focus();

                    } else if ($childElem.find(".e-datewidget.e-widget").length) {

                        $childElem.find(".e-datewidget.e-widget").focus();
                    }
                    else {

                        $childElem.find('input,select').select().focus();
                    }
                }
            }
			   proxy._$gridHeaderContainer.scrollLeft(proxy._$gridContent.children('.e-content').scrollLeft());
        },
        //Set the focus for edit row elements
        _focusElementsForRowEdit: function ($currentCell) {
            if ($currentCell.length) {
                var $childElem = $currentCell.children();
                if ($childElem[0].tagName.toLowerCase() == "select" || $childElem[0].tagName.toLowerCase() == "input") {
                    $childElem.focus().select();
                    $childElem[0].focus();
                }
                else if ($childElem.find(".e-field.e-dropdownlist").length)
                    $childElem[0].focus();
                else
                    $childElem.find('input:visible,select').first().select().focus();
            }
        },
        //UPDATE THE GRID CONTAINER HEIGHT
        updateHeight: function (height) {

            var proxy = this;
            if (proxy._$gridContainer && proxy._$gridContent) {
                if (height) {
                    proxy._$gridContainer.css({
                        "height": height + "px",
                        "width": "auto"
                    });
                    proxy._$gridContent.ejScroller("refresh");
                } else {
                    proxy._$gridContainer.css({
                        "height": proxy._totalHeight + "px"
                    });
                }                
                if (proxy._$gridContent.hasClass("e-scroller")) {
                    proxy._$gridContent.ejScroller("refresh");
                    proxy._updateScrollCss();
                }
            }
        },
        //check scroller position in virtualization
        _setScrollTop: function () {

            var proxy = this,
            model = this.model,
            top = proxy._scrollTop;

            if (model.enableVirtualization && top !== 0 && !model.isFromGantt) {
                if ((proxy.model.currentViewData.length * proxy.model.rowHeight) < proxy._viewPortHeight) {
                    var currentPosition = top - (proxy._viewPortHeight - proxy.model.currentViewData.length * proxy.model.rowHeight);
                    if (currentPosition < 0)
                        currentPosition = 0;
                    proxy._$gridContent.ejScroller("scrollY", currentPosition, true);
                }
            }
        },

        //ADD EXPANDED CHILDRECORDS TO FLAT RECORDS
        _addNestedExpandCollapseRecords: function (data, level, parentItem, index) {

            var proxy = this,
                model = proxy.model,
                records = model.flatRecords,
                rows = model.records,
                count = 0,
                length = data.length,
                parentRecord;


            for (count; count < length; count++) {
                
                index++;
                proxy._tempRecordIndex++;
                parentRecord = rows[proxy._tempRecordIndex];

                if ($.inArray(parentRecord, records) === -1) {
                    records.splice(index, 0, parentRecord);
                }

                if (parentRecord && parentRecord.isExpanded === false) {
                    parentRecord.isExpanded = true;
                }

                if (parentRecord.hasChildRecords) {

                    if (parentRecord.expanded) {

                        var len = parentRecord.childRecords.length,
                            k = 0,
                            childRecord;

                        for (k; k < len; k++) {

                            index++;
                            proxy._tempRecordIndex++;
                            childRecord = rows[proxy._tempRecordIndex];
                            records.splice(index, 0, childRecord);

                            if (childRecord.hasChildRecords) {

                                if (childRecord.expanded) {
                                    index = proxy._addNestedExpandCollapseRecords(childRecord.childRecords, level + 1, childRecord, index);
                                } else proxy._tempRecordIndex += proxy.getChildCount(childRecord, 0);//childRecord.childRecords.length;

                            }
                        }
                    } else {

                        proxy._tempRecordIndex += proxy.getChildCount(parentRecord,0);  //parentRecord.childRecords.length;// here inner task are not counted
                    }
                }
            }
            return index;
        },

        getChildCount:function(record,count)
        {
            var currentRecord, proxy = this;
            if (!record.hasChildRecords)
                return 0;
            for (var i = 0; i < record.childRecords.length;i++)
            {
                currentRecord= record.childRecords[i];
                count++;
                if(currentRecord.hasChildRecords)
                {
                    count=proxy.getChildCount(currentRecord, count);
                }
            }
            return count;
        },
        //UPDATE THE FILTERED RECORDS FOR ADDING PARENTRECORDS
        _updateFilteredRecords: function (data) {

            var proxy = this,
                count = 0,
                length = data.length,
                record,virtualization=proxy.model.enableVirtualization;

            proxy._filteredRecords = [];
            proxy._filteredGanttRecords = [];

            for (count; count < length; count++) {

                record = data[count];

                if (record.parentItem != null) {

                    proxy._addParentRecord(record.parentItem);

                    if ($.inArray(record, proxy._filteredRecords) === -1) {
                        if (virtualization)
                        {
                            if (proxy.getExpandStatus(record))
                            {
                                proxy._filteredRecords.push(record);
                            }
                        }
                        else
                        {
                            proxy._filteredRecords.push(record);
                        }
                           
                    }

                } else {

                    if ($.inArray(record, proxy._filteredRecords) === -1) {
                        if (virtualization) {
                            if (proxy.getExpandStatus(record)) {
                                proxy._filteredRecords.push(record);
                            }
                        }
                        else {
                            proxy._filteredRecords.push(record);
                        }
                    }
                }
            }
        },

                
        //ADD PARENTRECORD FOR FILTERED OTH LEVEL ITEMS
        _addParentRecord: function (record) {

            var proxy = this,
            virtualization = proxy.model.enableVirtualization;

            if (record.parentItem) {
                proxy._addParentRecord(record.parentItem);

                if ($.inArray(record, proxy._filteredRecords) === -1) {

                    if (virtualization) {
                        if (proxy.getExpandStatus(record)) {
                            proxy._filteredRecords.push(record);
                        }
                    }
                    else {
                        proxy._filteredRecords.push(record);
                    }
                     

                }
            } else {

                if ($.inArray(record, proxy._filteredRecords) === -1) {

                    if (virtualization) {
                        if (proxy.getExpandStatus(record)) {
                            proxy._filteredRecords.push(record);
                        }
                    }
                    else {
                        proxy._filteredRecords.push(record);
                    }

                }
            }
        },


        //UPDATEEXPANDCOLLAPSE FOR SORTED RECORDS
        _updateExpandCollapseForSortedRecords: function (Record, expanded) {

            var proxy = this,
                count = 0,
                length = proxy._sortedRecords.length,
                record,
                index = proxy._sortedRecords.indexOf(Record);

            if (expanded) {

                proxy._addNestedSortRecords(Record, index);

            } else {

                var removedCount = 0;

                for (count = index + 1; count < length; count++) {

                    record = proxy._sortedRecords[count];

                    if (record.level === Record.level) {
                        break;
                    } else if (!proxy.getExpandStatus(record)) {
                        removedCount++;
                    }

                }

                proxy._sortedRecords.splice(index + 1, removedCount);

            }
        },


        //ADD NESTEDSORTRECORDS
        _addNestedSortRecords: function (record, index) {

            var proxy = this,
                childRecords,
                sortColumns = proxy.model.sortSettings.sortedColumns,
                length;

            if (sortColumns.length) {

                length = sortColumns.length - 1;
                proxy._queryManagar.queries = [];

                for (var i = length; i >= 0; i--) {

                    proxy._queryManagar.sortBy(sortColumns[i].field, sortColumns[i].direction);

                }

            }
            if (record.hasChildRecords) {

                var dataManager = ej.DataManager(record.childRecords),
                    count,
                    childrecord;

                childRecords = dataManager.executeLocal(proxy._queryManagar).result;
                length = childRecords.length;

                for (count = 0; count < length; count++) {

                    childrecord = childRecords[count];

                    if (proxy._filteredRecords.length) {

                        if ($.inArray(childrecord, proxy._filteredRecords) !== -1) {
                            proxy._sortedRecords.splice(++index, 0, childrecord);
                        }

                    } else {
                        proxy._sortedRecords.splice(++index, 0, childrecord);
                    }

                    if (childrecord.hasChildRecords && childrecord.expanded) {
                        proxy._addNestedSortRecords(childrecord, index);
                    }
                }
            }
        },

        //UPDATE Edit Settings
        updateEditSettings: function (edit) {

            var proxy = this;

            if (edit) {
                if (edit.editMode)
                    proxy.model.editSettings.editMode = edit.editMode;
                if (edit.allowAdding)
                    proxy.model.editSettings.allowAdding = edit.allowAdding;
                if (edit.allowEditing)
                    proxy.model.editSettings.allowEditing = edit.allowEditing;
                if (edit.allowDeleting)
                    proxy.model.editSettings.allowDeleting = edit.allowDeleting;
            }
        },

        //UPDATE ALTROW
        _updateAltRow: function () {

            var proxy = this,
                count = 0,
                currentViewData = proxy._updatedRecords,
                length = currentViewData.length,
                record;

            for (count = 0; count < length; count++) {
                record = currentViewData[count];
                record.isAltRow = count % 2 == 0 ? true : false;
            }

        },


        
        //COUNT THE NUMBER OF CHILD RECORDS PRESENT IN THE GANTTRECORD
        _getFilteredChildRecordsCount: function (Record) {

            var proxy = this,
                model=proxy.model,
                length = Record&&Record.childRecords && Record.childRecords.length,
                i = 0,
                record;

            for (i = 0; i < length; i++) {

                record = Record.childRecords[i];
                if (model.enableVirtualization)
                {
                    if(proxy.getExpandStatus(record))
                    {
                        proxy._removedCount++;
                    }
                }
                else
                {
                    proxy._removedCount++;
                }
                   
                if (record.childRecords) {
                    proxy._getFilteredChildRecordsCount(record);
                }
            }

            return proxy._removedCount;
        },


        //SORTING THE RECORDS
        _sortingRecords: function () {

            var proxy = this,
                model = proxy.model,
                sortcolumns = model.sortSettings.sortedColumns;

            proxy._queryManagar.queries = [];

            if (sortcolumns.length) {

                var length = sortcolumns.length - 1;

                for (var i = length; i >= 0; i--) {

                    var column;
                    if(model.isFromGantt)
                        column = ej.TreeGrid.getColumnByMappingName(model.columns, sortcolumns[i].field);
                    if (column) {
                        proxy._queryManagar.sortBy(column.field, sortcolumns[i].direction);
                        sortcolumns[i].field = column.field;
                    }
                    else
                        proxy._queryManagar.sortBy(sortcolumns[i].field, sortcolumns[i].direction);
                }

            }

            var dataManager = new ej.DataManager(model.parentRecords),
                records = dataManager.executeLocal(proxy._queryManagar).result;

            proxy._sortedRecords = [];
            proxy._storedIndex = -1;

            proxy._createSortedRecords(records);
            proxy._tempsortedrecords = proxy._sortedRecords;
           // proxy._updateSortedRecords(proxy._tempsortedrecords);
            proxy.setRecordsCount(proxy._sortedRecords.length);
            if (proxy.model.selectedRowIndex >= 0) {
                var previousIndex = proxy._selectedRowsIndexes.indexOf(proxy.model.selectedRowIndex);
                var selectedRecord = proxy._updatedRecords[proxy.model.selectedRowIndex];
                proxy._previousIndex = proxy.model.selectedRowIndex = proxy._sortedRecords.indexOf(selectedRecord);
                proxy._selectedRowsIndexes[previousIndex] = proxy._previousIndex;
            }
            proxy._updatedRecords = proxy._sortedRecords;

            return true;
        },


        //CREATE SORTED GANTT RECORDS
        _createSortedRecords: function (data) {

            var proxy = this,
                sortedRecords = proxy._sortedRecords,
                dataManager,
                enableAltRow = proxy.model.enableAltRow,model=this.model;

            $.each(data, function (index, record) {

                if (proxy._searchString.length > 0) {

                    if (proxy._filteredRecords.length > 0 && proxy._filteredRecords.indexOf(record) !== -1) {

                        proxy._storedIndex++;

                        if (enableAltRow) {

                            record.isAltRow = proxy._storedIndex % 2 == 0 ? false : true;

                        }

                        sortedRecords[proxy._storedIndex] = record;

                    }
                } else {

                    proxy._storedIndex++;

                    if (enableAltRow) {

                        record.isAltRow = proxy._storedIndex % 2 == 0 ? false : true;

                    }

                    sortedRecords[proxy._storedIndex] = record;

                }

                if (record.hasChildRecords && record.expanded) {

                    dataManager = ej.DataManager(record.childRecords);
                    var childRecords = dataManager.executeLocal(proxy._queryManagar).result;
                    proxy._createSortedRecords(childRecords);

                }
                else if (record.hasChildRecords && !record.expanded && !model.enableVirtualization)
                {
                    proxy._setChildRecords(record, sortedRecords);
                }
            });
        },

        _setChildRecords:function(record,sortedRecords)
        {
            var proxy = this,
            enableAltRow = proxy.model.enableAltRow;
            var length = record.childRecords.length;

            dataManager = ej.DataManager(record.childRecords);
            var childRecords = dataManager.executeLocal(proxy._queryManagar).result;
            for(var count=0;count<length;count++)
            {
                if (proxy._filteredRecords.length > 0) {
                    if (proxy._filteredRecords.length > 0 && proxy._filteredRecords.indexOf(childRecords[count]) !== -1) {
                        proxy._storedIndex++;
                        if (enableAltRow) {
                            childRecords[count].isAltRow = proxy._storedIndex % 2 == 0 ? false : true;
                        }
                        sortedRecords[proxy._storedIndex] = childRecords[count];
                        if (childRecords[count].hasChildRecords) {
                            this._setChildRecords(childRecords[count], sortedRecords);
                        }
                    }
                }else
                {
                    proxy._storedIndex++;
                    if (enableAltRow) {
                        childRecords[count].isAltRow = proxy._storedIndex % 2 == 0 ? false : true;
                    }
                    sortedRecords[proxy._storedIndex] = childRecords[count];
                    if (childRecords[count].hasChildRecords) {
                        this._setChildRecords(childRecords[count], sortedRecords);
                    }
                }
            }
        },    
        //UPDAT THE SORTED RECORDS
        _updateSortedRecords: function (data) {

            var proxy = this,
                count = 0,
                length = data.length,
                record,model=this.model;

            for (count; count < length; count++) {

                record = data[count];

                if (!model.enableVirtualization) {

                    if (proxy._filteredRecords.length > 0) {

                        if ($.inArray(record, proxy._filteredRecords) !== -1 && $.inArray(record, proxy._sortedRecords) === -1) {
                            proxy._sortedRecords.push(record);
                        }

                    } else {

                        if ($.inArray(record, proxy._sortedRecords) === -1) {
                            proxy._sortedRecords.push(record);
                        }

                    }

                    if (record.hasChildRecords && record.childRecords.length > 0) {

                        var dataManager = ej.DataManager(record.childRecords),
                            sortedChildRecords = dataManager.executeLocal(proxy._queryManagar).result;
                        proxy._updateSortedRecords(sortedChildRecords);

                    }
                }
            }
        },


        //REMOVE SORT ICON FORM COLUMN HEADER
        _removeSortElementFromColumn: function (field) {

            var proxy = this,
                column = ej.TreeGrid.getColumnByField(proxy.model.columns, field),
                index = $.inArray(column, proxy.model.columns),
                $headerCellDiv = proxy.getHeaderTable().find("thead").find(".e-headercell").eq(index).find(".e-headercelldiv");

            $headerCellDiv.find(".ascending,.descending").remove();
            $headerCellDiv.parent().removeAttr("aria-sort");
        },


        //ADD EMPTYCOLUMN TO THE TREEGRID
        _addEmptyColumntoGrid: function () {

            $('.e-gridheadercontainer table colgroup').append(ej.buildTag('col', "", {
                "width": "auto"
            },
            {}));

            $('.e-gridheadercontainer table thead tr').append(ej.buildTag('th.e-headercell'));
        },


        //UPDATE THE SCROLLTOP OF THE GRIDCONTAINER
        _updateScrollTop: function (y) {

            var args = {},
                proxy = this;

            args.requestType = "scroll";
            args.delta = y;

            var isHorizontalScroll = proxy._$gridContent.ejScroller("isHScroll");

            if (!isHorizontalScroll) {
                proxy._$gridContent.scrollTop(y);//grid container
            }
            else
            {
                proxy._$gridContent.scrollTop(0)
            }
            proxy._$gridContent.ejScroller("scrollY", y, true);
            proxy._completeAction(args);
            
        },


        //MOVE CURRENT CELL FOR KEYBOARD INTERACTION
        _moveCurrentCell: function (direction) {

            var proxy = this,
                rowIndex = proxy._cellEditingDetails.rowIndex,
                columnIndex = proxy._cellEditingDetails.columnIndex,
                model = proxy.model;

            if (rowIndex == -1 && columnIndex == -1) return false;

            if (proxy.model.isEdit) {

                proxy.saveCell();
                proxy.model.isEdit = false;

            }

            switch (direction) {
                

                case "right":
                    if (!proxy._rowSelectingEventTrigger()) {

                        if (!proxy.selectRows(proxy._cellEditingDetails.rowIndex)) {

                            if (rowIndex == proxy._gridRows.length - 1 && columnIndex == model.columns.length - 1) {
                                return true;
                            }

                            if (columnIndex == model.columns.length - 1) {

                                proxy._cellEditingDetails.columnIndex = 0;
                                proxy._cellEditingDetails.rowIndex = rowIndex + 1;

                            } else proxy._cellEditingDetails.columnIndex = columnIndex + 1;

                            proxy.selectRows(proxy._cellEditingDetails.rowIndex);
                            proxy.cellEdit(proxy._cellEditingDetails.rowIndex,
                                model.columns[proxy._cellEditingDetails.columnIndex].field);
                        }
                    }

                    break;

                case "left":

                    if ((rowIndex == 0 && columnIndex == 0)) return true;

                    if (columnIndex == 0) {

                        proxy._cellEditingDetails.columnIndex = model.columns.length - 1;
                        proxy._cellEditingDetails.rowIndex = rowIndex - 1;

                    } else {
                        proxy._cellEditingDetails.columnIndex = columnIndex - 1;
                    }

                    proxy.selectRows(proxy._cellEditingDetails.rowIndex);
                    proxy.cellEdit(proxy._cellEditingDetails.rowIndex, model.columns[proxy._cellEditingDetails.columnIndex].field);

                    break;

                case "up":

                    if (rowIndex == 0) return true;

                    proxy._cellEditingDetails.rowIndex = rowIndex - 1;
                    proxy.selectRows(proxy._cellEditingDetails.rowIndex);
                    proxy._rowSelectedEventTrigger(proxy._cellEditingDetails.rowIndex);
                    proxy.cellEdit(proxy._cellEditingDetails.rowIndex, model.columns[proxy._cellEditingDetails.columnIndex].field);

                    break;

                case "down":

                    if (rowIndex + 1 == proxy.getRows().length - 1) {

                        if (proxy.model.enableVirtualization) {

                            proxy._isEnterKeyPressed = true;
                            proxy._updateScrollTop(proxy._$gridContent.scrollTop() + model.rowHeight - proxy._offset);
                        }
                    }

                    if (!proxy._isEnterKeyPressed) {

                        if (proxy._updatedRecords.length > (rowIndex + 1))
                        if (!proxy.selectRows(rowIndex + 1)) {

                            proxy._rowSelectedEventTrigger(proxy._cellEditingDetails.rowIndex+1);
                            proxy._cellEditingDetails.rowIndex = rowIndex + 1;
                            proxy.cellEdit(proxy._cellEditingDetails.rowIndex, model.columns[proxy._cellEditingDetails.columnIndex].field);
                            args = {};
                            args.requestType = "scroll";
                            args.delta = proxy._$gridContent.children('.e-content').scrollTop();
                            proxy._trigger("actionComplete", args);
                            //$(".e-ganttviewerbodyContianer").children('.e-content').scrollTop((proxy._$gridContent.children('.e-content').scrollTop()));
                        }

                    }

                    break;
            }

            return false;

        },

        //FIND THE COLUMNWIDTH OF THE TREEGRID COLUMN
        _findColumnsWidth: function (extra) {

            var proxy = this,
                length = proxy.model.columns.length,
                j = proxy.getHeaderTable().find("colgroup").find("col");
            
            for (var i = 0; i < length; i++)
                proxy._columnsWidthCollection[i] = j.eq(i).width();

        },

        //CALCULATE THE TOTAL WIDTH OF THE COLUMNS
        _calculateWidth: function () {

            var j = this.getHeaderTable().find("colgroup").find("col"),
                width = 0;

            for (var i = 0; i < j.length; i++)
                width += j.eq(i).width();

            return width;
        },


        //TEMPLATE FOR DROP DOWNLIST
        _compiledDropDownTemplate: function () {

            var $select = ej.buildTag('select'),
                $option = ej.buildTag("option", "{{:text}}", {},
                {
                    value: "{{:value}}"
               });

            $select.append($option);

            return $.templates($select.html());
        },
        //update element height when viewport height is <0
        _updateElementHeight:function()
        {
            var proxy = this;
            proxy.element.height(450);
            proxy._calculateDimensions();
            proxy.updateViewPortHeight();
        },
        _renderScroller: function () {

            var proxy = this,
            model = proxy.model;
            var containerHeight = model.flatRecords.length * model.rowHeight;
            if (!model.isFromGantt && proxy._viewPortHeight < 0) {
                proxy._updateElementHeight();
            }
            var contentHeight = proxy._viewPortHeight;
            proxy._$gridContent.css({ "height": contentHeight + "px" });
            proxy._$gridContainer.css({ "height": containerHeight + "px" });
            
            if (!proxy._$gridContent.hasClass("e-scroller")) {
                $div = ej.buildTag('div', {}, { "width": "auto", "height": "auto" });
                $div.append(proxy._$gridContainer);
                proxy._$gridContent.append($div);
                var height = proxy._gridHeight ? contentHeight : "auto";
                var width = proxy.element.width();

                proxy._$gridContent.ejScroller({
                    height:proxy.model.isFromGantt ? 0 :height,
                    width: proxy.model.isFromGantt ? width : width - proxy._totalBorderWidth,
                    scroll: $.proxy(proxy._onScroll, proxy)
                });
                proxy._$gridContent.ejScroller("refresh");

            }
            else {
                proxy._$gridContent.ejScroller("refresh");
          }
            proxy._$gridContent.ejScroller("model.keyConfigs", { up: "", down: "" });
            proxy._updateScrollCss();
            var isHorizontalScroll = proxy._$gridContent.ejScroller("isHScroll");
            if (proxy.model.isFromGantt)
                if (!isHorizontalScroll) {
                    proxy._$gridContent.addClass("e-borderbox");
                }
                else {
                    proxy._$gridContent.removeClass("e-borderbox");
                }

        },
        

        
        //ALL EVENTS BOUND USING THIS._ON WILL BE UNBIND AUTOMATICALLY
        _destroy: function () {

            var proxy = this;
            proxy.element.empty().removeClass("e-treegrid-core e-treegrid " + proxy.model.cssClass);
            
        },

        /**
          * To collapse all the parent items in tree grid
          * @return jQuery
          * @example 
          * &lt;treegrid id="treegrid"&gt;Treegrid&lt;/treegrid&gt; <br> 
          * &lt;script&gt;
          * // Create treegrid
          * var treegridObj = $("#treegrid").data("ejTreeGrid");
          * treegridObj.ejTreeGrid("collapseAll"); // To collapse all parent items in tree grid
          * &lt;/script&gt;
          * @example 
          *  &lt;treegrid id="treegrid"&gt;Treegrid&lt;/treegrid&gt; <br> 
          * &lt;script&gt;
          * // To expand all items
          * $("#treegrid").ejTreeGrid("collapseAll");	
          * &lt;/script&gt;
          * @memberof ejTreeGrid
          * @instance
           */

        collapseAll: function () {
            var proxy = this,
                model = proxy.model,
                count = 0,
                ganttRecord,
                args = {},
                enableVirtualization = model.enableVirtualization,
                $gridRows = proxy.getRows(),
                $rowElement = null;

            proxy._gridRows = $gridRows;
            //To cancel the cell edit or row edit mode when collapse the all record.
            if (proxy._isRowEdit || proxy.model.isEdit) {                
                proxy.cancelRowEditCell();
                proxy.selectRows(-1);
                proxy._cancelSaveTools();                              
            }
            
            //loop excecute for iterate the GanttRecords preseent in the Gantt Control

            for (count = 0; count < proxy.model.parentRecords.length; count++) {
                ganttRecord = proxy.model.parentRecords[count];
                args.data = ganttRecord;
                args.recordIndex = count;
                args.expanded = false;

                if (enableVirtualization) {
                    if (ganttRecord.hasChildRecords && ganttRecord.expanded) {
                        ej.TreeGrid.sendExpandCollapseRequest(proxy, args);
                    }
                } else {
                    if (ganttRecord.hasChildRecords && ganttRecord.expanded) {
                        ej.TreeGrid.sendExpandCollapseRequest(proxy, args);
                    }
                }
            }
        },
        //populate the context menu with items
        _getContextMenuItems: function () {
            var contextMenuItems = [];

            contextMenuItems = [ {
                headerText: "Add Row",
                eventHandler: null,
                isDefault: true,
                disable:false,
            },
             {
                 iconClass: "e-edit",
                 headerText: "Edit",
                 eventHandler: null,
                 isDefault: true,
                 isEdit: true,
                 disable: false,
             },
            {
                headerText: "Delete",
                eventHandler: null,
                isDefault: true,
                disable: false,
            },
            {
                iconClass: "e-save",
                headerText: "Save",
                eventHandler: null,
                isDefault: true,
                isEdit: true,
                disable: false,
            },
             {
                 iconClass: "e-cancel",
                 headerText: "Cancel",
                 eventHandler: null,
                 isDefault: true,
                 isEdit: true,
                 disable: false,
             },
            ];
            return contextMenuItems;
        },

        //populate sub context menu items
        _getsubContextMenuItems: function () {
            var contextMenuItems = [];

            contextMenuItems = [{
                iconPath: null,
                headerText: "Above",
                eventHandler: null
            }, {
                iconPath: null,
                headerText: "Below",
                eventHandler: null
            }
            ];
            return contextMenuItems;
        },
        _clearContextMenu: function () {
            //remove context menu items
            $('.e-contextmenu').remove();
            $('.e-innerContextmenu').remove();
        },
        // create and append a context menu and also bind the events for context menu option
        _renderContextMenu: function (e, index, item) {

            var proxy = this,
            model = proxy.model,
                eventArgs = {},
                args = {},
                posx,
				subposx,
                posy,
                subposx,
                contextMenu,
                contextMenuUList,
                subContextMenu,
                subContextMenuUList;
            if (!e) e = window.event;
            if (e.pageX || e.pageY) {
               subposx = posx = e.pageX;
                posy = e.pageY;
            } else if (e.clientX || e.clientY) {
                subposx = posx = e.clientX + document.body.scrollLeft
                    + document.documentElement.scrollLeft;
                posy = e.clientY + document.body.scrollTop
                    + document.documentElement.scrollTop;
            }
            if ($(window).width() < posx + 130) {
                posx = posx - 130;
                subposx = posx - 102;
            }
            else
                subposx = subposx + 132;
            if ($(window).height() < posy + (25*proxy._contextMenuItems.length))
                posy = posy - (25 * proxy._contextMenuItems.length);
            args.targetElement = e;
            args.item = item;
            args.index = index;
            args.requestType = "ContextMenuOpen";
            args.contextMenuItems = proxy._contextMenuItems;
            args.innerContextMenuItems = proxy._subContextMenuItems;
            proxy._trigger("contextMenuOpen", args);
            contextMenu = ej.buildTag("div.e-contextmenu", "", {
                'height': 'auto',
                'width': '130px',
                'position': 'absolute',
                'left': posx + 'px',
                'top': posy + 'px',
                'background-color': '#F0F0F0',
                'border': '1px solid #99bce8',
                'z-index': '10033',
            }, {});

            contextMenuUList = ej.buildTag("ul", $.render[proxy._id + "contextMenuTemplate"](args.contextMenuItems), {
                'height': 'auto',
                'width': 'auto',
                'top': '0px',
                'display': 'inline'
            }, {
                'data-icon': false,
                'type': 'none',
                'data-role': 'list-divider'
            });
            //var addIndex = proxy._contextMenuItems.indexOf("add");
            subContextMenu = ej.buildTag("div.e-innerContextmenu", "", {
                'height': 'auto',
                'width': '100px',
                'position': 'absolute',
                'left': subposx + 'px',
                'top': posy + (proxy._contextAddMenuIndex * 30) + 'px',
                'background-color': '#F0F0F0',
                'border': '1px solid #99bce8',
                'z-index': '10',
                'visibility': 'hidden',
            }, {});

            subContextMenuUList = ej.buildTag("ul", $.render[proxy._id + "subContextMenuTemplate"](args.innerContextMenuItems), {
                'height': 'auto',
                'width': 'auto',
                'top': '0px',
                'display': 'inline'
            }, {
                'data-icon': false,
                'type': 'none',
                'data-role': 'list-divider'
            });
            contextMenu.append(contextMenuUList);
            $(document.body).append(contextMenu);

            if (args.innerContextMenuItems.length > 0) {
                subContextMenu.append(subContextMenuUList);
                $(document.body).append(subContextMenu);
            }



            $(contextMenu).css({ 'height': 'auto' });
            proxy._on(contextMenu, "contextmenu", function (argsE) {
                argsE.preventDefault();
            });
            //click event handlers for contextmenu items and subcontextmenu items
            $('.e-menuitem').click(function () {
                var choice = $(this).attr('id');
                if(!$(this).hasClass("e-disable")){
                switch (choice) {
                    case "Delete": eventArgs.requestType = "contextMenuDelete";
                        proxy.deleteRow();
                        proxy._clearContextMenu();
                        break;
                    case "Above":
                        proxy._subContextMenuAction(item, index, "Above");
                        $(proxy.element).focus();
                        break;
                    case "Below":
                        proxy._subContextMenuAction(item, index, "Below");
                        $(proxy.element).focus();
                        break;
                    case "Add":
                        proxy._setInitialData();
                        proxy._clearContextMenu();
                        
                        break;
                    case "Edit":
                        if (model.editSettings.editMode.toLowerCase() == "cellediting") {

                            proxy.element.focus();
                            proxy._cellEditingDetails.columnIndex = proxy.getCellIndex(e);
                            proxy._editedRowIndex=proxy._cellEditingDetails.rowIndex = proxy.getRowIndex(e);
                            fieldName = proxy._cellEditingDetails.columnIndex >= 0 && model.columns[proxy._cellEditingDetails.columnIndex].field;
                            if (fieldName) {
                                model.editSettings.allowEditing &&
                                    model.editSettings.editMode == ej.TreeGrid.EditMode.CellEditing &&
                                    proxy.cellEdit(proxy._cellEditingDetails.rowIndex, fieldName);
                                    proxy._editAddTools();
                            }
                        }
                        else if (model.editSettings.editMode.toLowerCase() == "rowediting") 
                            proxy._editRow(index);
                        proxy._clearContextMenu();
                        break;
                    case "Save":
                        if (model.editSettings.editMode.toLowerCase() == "cellediting") {
                             if (proxy._isRowEdit)
                                   proxy._endEdit();
                                   else proxy.saveCell();
                            }
                        else if (model.editSettings.editMode.toLowerCase() == "rowediting")
                            proxy._saveRow();
                        proxy._cancelSaveTools();
                        proxy._clearContextMenu();
                        $(proxy.element).focus();
                        break;
                    case "Cancel":
                        proxy.cancelRowEditCell();
                        proxy._cancelSaveTools();
                        proxy._clearContextMenu();
                        $(proxy.element).focus();
                        break;
                    default:
                        $.each(proxy._contextMenuItems, function (idx, val) {
                            if (val.headerText === choice) {
                                proxy.model["customEvent"] = val.eventHandler;
                                proxy._trigger("customEvent", args);
                            }
                        });
                        proxy._clearContextMenu();
                        break;
                }
                if (proxy.model.enableAltRow && proxy._currentViewData[0])
                    ej.TreeGrid.updateAltRow(proxy, proxy._currentViewData[0], 0, 0);
                proxy.updateHeight();
                    
                }
            });
            //Mouseenter and mouse leave handler for contextmenu items and Subcontextmenuitems
            $(".e-menuitem").mouseenter(function () {
                if (!$(this).hasClass("e-disable")) {
                    $(".e-contextmenu-mouseover").removeClass("e-contextmenu-mouseover");
                $(this).addClass("e-contextmenu-mouseover");
                if ($(this).attr('id') == "Add" || $(this).attr('id') == "Above" || $(this).attr('id') == "Below") {
                    $('.e-innerContextmenu').css({ 'visibility': 'visible' });
                    $('#Add').addClass("e-contextmenu-mouseover");
                }
                else {
                    $('.e-innerContextmenu').css({ 'visibility': 'hidden' });
                }
                }
            });
            $(".e-menuitem").mouseleave(function () {
                $(this).removeClass("e-contextmenu-mouseover");
            });
            e.preventDefault();
        },
        _createContextMenuTemplate: function () {
            var proxy = this;
            helpers = {
                getHeaderName: $.proxy(proxy._getHeaderName, proxy),
            };
            $.views.helpers(helpers);
            var menuItemList = "<li style='list-style-type:none;width:92px;height:25px;display:inline-block;'>";
            var listChild = "<div class='e-menuitem {{if disable}}e-disable{{/if}}' id={{:headerText}}  style='left:0px;padding-top:3px;height:25px;width:130px;cursor:{{if disable}}default{{else}}pointer{{/if}};display:block;position:absolute;'  {{if !isDefault}}onClick='{{:eventHandler}}'{{/if}}>" +
                            "{{if !isEdit}}" +
                            "<div class='e-icon' style='left:10px;top:4px;height:20px;position:absolute;" +
                            "background-image:{{:iconPath}};background-repeat:no-repeat;'/> " + 
                            "{{else}}" +
                            "<span class='e-icon {{:iconClass}}' style='left:10px;top:7px;height:20px;position:absolute;opacity:0.5'/>" +
                            "{{/if}}" +
                            "<div style='left:35px;position:absolute;'>" +
                            "<span style='font-family:Segoe UI;font-size:12px;padding-left:5px;'>{{:headerText}}</span></div>" +
                            "{{if ~getHeaderName(#data)}}<span class='e-icon e-expander' style='height:16px;width:16px;right:5px;top:7px;position:absolute;'></span>{{/if}}";

            menuItemList += listChild;
            menuItemList += "</div></li>";
            var templates = {};
            templates[proxy._id + "contextMenuTemplate"] = menuItemList;
            $.templates(templates);
        },
        _createSubContextMenuTemplate: function () {
            var proxy = this,
                helpers = {
                    getHeaderName: proxy._getHeaderName
                };
            $.views.helpers(helpers);

            var menuItemList = "<li style='list-style-type:none;width:100px;height:25px;display:inline-block;'>";
            var listChild = "<div class='e-menuitem' id={{:headerText}} style='left:0px;padding-top:3px;" +
                "height:25px;width:100px;cursor: pointer;display:block;position:absolute;'>" +
                "<div style='left:10px;height:20px;width:16px;position:absolute;padding-top:5px;" +
                "background-image:{{:iconPath}};background-repeat:no-repeat;'/>" +
               "<div style='left:10px;position:absolute;'>" +
                "<span style='font-family:Segoe UI;font-size:12px;padding-left:5px;'>{{:headerText}}" +
                "</span></div></div>";


            menuItemList += listChild;
            menuItemList += "</li>";

            var templates = {};
            templates[proxy._id + "subContextMenuTemplate"] = menuItemList;
            $.templates(templates);
        },
        _getHeaderName: function (data) {
            if (data.headerText == "Add Row" && this._subContextMenuItems.length > 0) {
                return true;
            }
            return false;
        },
        //Change the context menu based on context menu item list.
        _updateContextmenuOption: function (recordIndex) {
            //removing empty string and undefined from contextmenu items.
            Array.prototype.clean = function (deleteValue) {
                for (var i = 0; i < this.length; i++) {
                    if (this[i] == deleteValue) {
                        this.splice(i, 1);
                        i--;
                    }
                }
                return this;
            };
            var proxy = this;
            
            if(proxy._isRowEdit || proxy.model.isEdit)
            {
                //Remove add, delete and edit context menu when row in edit mode.
                proxy._contextMenuItems.splice(0, 3);
            }
            else
            {
                proxy._contextMenuItems.splice(3, 2); //Remove save and cancel when row not in edit mode
                var editSetting = proxy.model.editSettings
                var contextMenuItems = $.extend(true, [], proxy._contextMenuItems);
                var contextMenuList = proxy.model.contextMenuSettings.contextMenuItems.clean("").clean(undefined);
                var contextMenuItemList = [];
                //removing duplicate conetxt menu items
                $.each(contextMenuList, function (i, el) {
                    if ($.inArray(el.toLowerCase(), contextMenuItemList) === -1) contextMenuItemList.push(el.toLowerCase());
                });
                proxy._contextMenuItems = [];
                if (recordIndex == -1) {
                    if (contextMenuItemList.indexOf("add") != -1 || contextMenuItemList.length==0)
                        proxy._contextMenuItems[0] = contextMenuItems[0];
                    if (!editSetting.allowAdding)
                        proxy._contextMenuItems[0].disable = true;
                    proxy._contextAddMenuIndex = 0;
                }
                //Adding default context menu when user not specify the context menu items.
                else if (contextMenuItemList.length == 0)
                {
                    proxy._contextMenuItems[0] = contextMenuItems[0];
                    if (!editSetting.allowAdding)
                        proxy._contextMenuItems[0].disable = true;
                    proxy._contextAddMenuIndex = 0;
                    proxy._contextMenuItems[1] = contextMenuItems[2];
                    if (!editSetting.allowDeleting)
                        proxy._contextMenuItems[1].disable = true;
                }
                //Change the context menu order based on context menu items order
                else {
                for(i=0;i<contextMenuItemList.length;i++)
                {
                    var item=contextMenuItemList[i];
                    switch(item.toLowerCase())
                    {
                        case "add":
                            proxy._contextMenuItems[i] = contextMenuItems[0];
                            proxy._contextAddMenuIndex = i;
                            if (!editSetting.allowAdding)
                                proxy._contextMenuItems[i].disable = true;
                            break;
                        case "delete":
                            proxy._contextMenuItems[i] = contextMenuItems[2];
                            if (!editSetting.allowDeleting)
                                proxy._contextMenuItems[i].disable = true;
                            break;
                        case "edit":
                            proxy._contextMenuItems[i] = contextMenuItems[1];
                            if (!editSetting.allowEditing)
                                proxy._contextMenuItems[i].disable = true;
                            break;
                    }
                }
                }
            }
        },
        //Assign default value to columns based on column edit type
        _setInitialData:function()
        {
            var eventArgs = {}, proxy = this,
               model = proxy.model, data = [], item, initialData = {};
            for (i = 0; i < model.columns.length; i++)
            {
                var column = model.columns[i];
                switch(column.editType)
                {
                    case "booleanedit":
                        initialData[column.field] = false;
                        break;
                    case "stringedit":
                        initialData[column.field] = null;
                        break;
                    case "datepicker":
                        initialData[column.field] = Globalize.format(new Date(), this.model.dateFormat);
                        break;
                    case "datetimepicker":
                        today = new Date();
                        initialData[column.field] = Globalize.format(new Date(), "MM/dd/yyyy hh:mm tt");
                        break;
                    case "numericedit":
                        initialData[column.field] = 0;
                        break;
                    default:
                        initialData[column.field] = null;

            }
            }
            data.push(initialData);
            if (proxy.dataSource() == null || proxy.dataSource().length == 0) {
                //proxy._createGanttRecords(data);
                item = proxy._createRecord(data[0], 0, null);
                item.index = 0;
                eventArgs._cAddedRecord = jQuery.extend(true, {}, item);
                eventArgs.data = eventArgs._cAddedRecord.item;
                eventArgs.requestType = "save";
                eventArgs.actionRequestType = "contextMenuAdd";
                proxy.renderRecord(eventArgs);
                proxy._clearContextMenu();
            }
        },
        _subContextMenuAction:function(item,index,position)
        {
            proxy = this;
            eventArgs = {};
            eventArgs.requestType = "save";
            newItem = jQuery.extend(true, {}, item.item);
            newItem[proxy.model.childMapping] = null;
            eventArgs._cAddedRecord = jQuery.extend({}, item);
            eventArgs._cAddedRecord.isSelected = false;
            if (eventArgs._cAddedRecord.hasChildRecords && position == "Below") {
                eventArgs._cAddedRecord.parentItem = item;
                eventArgs._cAddedRecord.level += 1;
            }
            eventArgs._cAddedRecord.hasChildRecords = false;
            eventArgs._cAddedRecord.expanded = false;
            eventArgs._cAddedRecord.childRecords = null;
            eventArgs._cAddedRecord.item = newItem;
            eventArgs.recordIndex = index == 0 ? 0 : index;
            eventArgs.position = position;
            eventArgs.data = eventArgs._cAddedRecord.item;
            eventArgs.actionRequestType = "contextMenuAdd";
            eventArgs.selectedItem = proxy.model.selectedItem;
            proxy.renderRecord(eventArgs);
            proxy._clearContextMenu();
            selectionIndex = proxy._currentViewData.indexOf(proxy.model.selectedItem);
            proxy.selectRows(selectionIndex);
            if(proxy.model.enableAltRow)
                ej.TreeGrid.updateAltRow(proxy, proxy._currentViewData[0], 0, 0);
            proxy.refreshRow(proxy._currentViewData.indexOf(eventArgs._cAddedRecord));
        },
        //Create editable row with specific edit type.
        _editRow: function (index, addrow) {
            proxy = this;
            proxy._editedRowIndex = index;
            var rowHeight=proxy.model.rowHeight;
            $form = ej.buildTag("form.#" + proxy._id + "EditForm", "", {"margin":"-1px"}, {})
            $table = ej.buildTag('table.e-table', "", {}, { "cellspacing": "0px","cellpadding":"0"});
            $table.append(proxy.getHeaderTable().find('colgroup').clone());
            var $targetTr = $(proxy.getRows()[index])
            $targetTr.empty();
            if (addrow)
                $targetTr.addClass('e-addedrow');
            else
                $targetTr.addClass('e-rowedit');
            $mainTd = ej.buildTag("td", "", {}, { "colspan": proxy.model.columns.length });
            var $headerTable = proxy.getHeaderTable();
            var $tr = ej.buildTag('tr.e-treegridrows e-selectionbackground e-active', { "height": rowHeight }, {}), $trClone;
            $tbody = ej.buildTag('tbody');
            $cellEditTemplate = proxy._cellEditTemplate
            for (var column = 0; column < proxy.model.columns.length; column++) {
                var data = {};
                //Create a html string for column field with specific edit type using cellEditTemplate
                htmlString = $cellEditTemplate.find("#" + proxy.model.columns[column].field + "_CellEdit").html();
                data[proxy.model.columns[column]["field"]] = proxy._updatedRecords[index][proxy.model.columns[column]["field"]];
                $element = $($.templates(htmlString).render(data));
                var $td = ej.buildTag('td.e-rowcell', "", { "height": rowHeight, "vertical-align": "middle;", "overflow": "hidden" }, {});
                if ($element.get(0).tagName == "SELECT") {

                    $element.val(data[proxy.model.columns[column]["field"]]);
                    $element.val() == null && $element.val($element.find("option").first().val());
                }
                $tr.append($td.append($element));
                $tbody.append($tr);
            }
            $table.append($tbody);
            $form.append($table)
            $mainTd.append($form);
            $targetTr.append($mainTd);
            proxy._isRowEdit = true;
            proxy._setoffsetWidth();
            proxy._editAddTools();
            proxy._refreshEditForm();
        },
        //#endregion       

    });

    //ENUM FOR EACH ACTION IN TREEGRID
    ej.TreeGrid.Actions = {
        Sorting: "sorting",
        BeginEdit: "beginedit",
        Save: "save",
        Add: "add",
        Delete: "delete",
        Cancel: "cancel",
        Refresh: "refresh",
        Searching: "searching",
        ExpandCollapse: "expandcollapse",
        Selection: "selection",
        rowHover: "rowHover",
        Scroll: "scroll",
        ContextMenuAdd: "contextMenuAdd",
        RefreshDataSource:"refreshDataSource"
    };

    //ENUM FOR SELECTION MODE IN TREEGRID
    ej.TreeGrid.SelectionType = {
        Single: "single",
        Multiple: "multiple"
    };

    //ENUM FOR DIFFERENT EDIT MODE IN TREEGRID
    ej.TreeGrid.EditMode = {
        Normal: "normal",
        CellEditing: "cellEditing",
        RowEditing:"rowEditing",
    };

    //Enum for position of new added row.
    ej.TreeGrid.RowPosition = {
        Top: "top",
        Bottom: "bottom",
        Above: "aboveSelectedRow",
        Below: "belowSelectedRow"
    }
    /* enum for six different columnEditType for treegrid */
    ej.TreeGrid.EditingType = {
        String: "stringedit",
        Boolean: "booleanedit",
        Numeric: "numericedit",
        Dropdown: "dropdownedit",
        DatePicker: "datepicker",
        DateTimePicker: "datetimepicker",
        
    };
    /* enum for different context menu in treegrid */
    ej.TreeGrid.ContextMenuItems = {
        Add: "add",
        Edit: "edit",
        Delete: "delete",
    };
    
    ej.TreeGrid = ej.TreeGrid || {};


    //INITIALIZE THE CELLEDIT ELEMENT FOR DIFFERENT TYPES OF EDITORS
    ej.TreeGrid._initCellEditType = function (instance, $element, id, columnCount) {

        var proxy=instance,
            model=proxy.model,
            columns=model.columns,
            column=columns[columnCount];

        if (ej.isNullOrUndefined(columns[columnCount]["editType"])) {
            column["editType"] = "stringedit";
        }

        switch (column["editType"]) {
            
            case "stringedit":

                if(model.isFromGantt){
                    
                    var helpers={};
                    
                    helpers["_" + id + "cellValue"] = ej.TreeGrid._getCellValue;
                    
                    if(column.field==="predecessor"){
                        helpers["_" + id + "predecessorCell"] = ej.Gantt._getPredecessorsValue;
                    }
                    
                    $.views.helpers(helpers);


                    if(column.field==="predecessor"){ //get the predecessor value from item of GanttRecord
                     
                        var $input=ej.buildTag('input.e-field e-ejinputtext',
                                       "",{},
                                       {
                                           value:"{{:~_" + id + "predecessorCell('"+model.predecessorMapping+"')}}",
                                           id: id + column.field, 
                                           name: column.field
                                       }
                                       );
                    }else { /*get the cellValue if the column does not exist in the GanttRecord object and
                           present in the item of GanttRecord*/
                        $input= ej.buildTag('input.e-field e-ejinputtext', 
                                            "",
                                            {},
                                            {
                                                value: "{{:~_" + proxy._id + "cellValue('" + columns[columnCount].field + "')}}",
                                                id: proxy._id + model.columns[columnCount].field,
                                                name: model.columns[columnCount].field
                                            });
                       
                    }

                }else { /*Get the cellvalue of the normal gridcell*/
                    $input=ej.buildTag('input.e-field e-ejinputtext',
                                          "",
                                          {}, 
                                          {
                                              value: "{{:#data['" + column.field + "']}}", 
                                              id: id + column.field, 
                                              name: column.field
                                          });
                }    
                $element.html($input);
            
                break;

            case "booleanedit":
                
                $element.html('{{if ' + columns[columnCount].field + '}} ' +
                        '<input class="e-field e-checkbox" type ="checkbox" ' +
                        'id=' + proxy._id + columns[columnCount].field +
                        ' name=' + columns[columnCount].field +
                        ' checked="checked"></input>' +
                        ' {{else}} ' +
                        ' <input class="e-field e-checkbox"' +
                        ' type ="checkbox" ' +
                        ' id=' + proxy._id + columns[columnCount].field +
                        ' name=' + columns[columnCount].field + ' > ' +
                        ' {{/if}}');

                break;
            
            case "numericedit":

                var $numericText = ej.buildTag('input.e-numerictextbox e-field', "", {}, {
                    type: "text",
                    value: "{{:#data['" + columns[columnCount].field + "']}}",
                    id: proxy._id + columns[columnCount].field,
                    name: columns[columnCount].field
                });
                $element.append($numericText);

                break;

            case "datepicker":
            case "datetimepicker":
                
                var $datePicker = ej.buildTag('input.e-' + columns[columnCount]["editType"] + ' e-field', "",
                                             {}, 
                                             {
                                                 type: "text",
                                                 value: "{{:#data['" + columns[columnCount].field + "']}}",
                                                 id: id + columns[columnCount].field,
                                                 name: columns[columnCount].field
                                             });
                $element.append($datePicker);

                break;

            case "dropdownedit":

                if(model.isFromGantt){
                    var $dropDownList = ej.buildTag('input.e-field e-dropdownlist' + ' e-field',
                        "", 
                        {}, 
                        {
                            type: "text",
                            value: "{{:#data['" + columns[columnCount].field + "']}}",
                            id: id + columns[columnCount].field,
                            name: columns[columnCount].field
                        });
                    $element.append($dropDownList);
                }else {
                    if (!ej.isNullOrUndefined(column.dropdownData)) {
                        var selectedItems = column.dropdownData;
                        var dropDownTemplate = proxy._compiledDropDownTemplate();
                        $element.get(0).innerHTML = ["<select>", dropDownTemplate.render(selectedItems), "</select>"].join("");
                        $element.find("select").prop({ id: proxy._id + column.field, name: column.field }).addClass("e-field e-dropdownlist");
                    }
                }

                break;
        }
    };
    
    ej.TreeGrid._getCellValue= function (columnName) {

        var cellValue = this.data[columnName];

        if (cellValue) {
            return cellValue;
        } else {
            return this.data.item && this.data.item[columnName];
        }


    };
    //Initialize tree grid toolbar item.
    ej.TreeGrid.ToolbarItems = {
        Add: "add",
        Edit: "edit",
        Delete: "delete",
        Update: "update",
        Cancel: "cancel",
        ExpandAll: "expandAll",
        CollapseAll: "collapseAll"
    };
    //GET ROW CLASS NAME FOR EXPAND COLLAPSE ACTION
    ej.TreeGrid._getrowClassName = function () {

        var rowClass = "gridrowIndex",
            proxy = this;

        if (proxy.data.parentItem) {// && proxy.data.parentItem.index

            rowClass += proxy.data.parentItem.index.toString();

        }

        rowClass += "level";
        rowClass += proxy.data.level.toString();

        return rowClass;
    };

    //GET COLUMN BY FIELD NAME
    ej.TreeGrid.getColumnByField = function (columns, field) {

        var column = 0;

        for (column; column < columns.length; column++) {

            if (columns[column]["field"] == field) break;

        }

        return column == columns.length ? null : columns[column];
    };


    ej.TreeGrid.getColumnByMappingName = function (columns, field) {
        var column = 0;
        for (column; column < columns.length; column++) {
            if (columns[column]["mappingName"] == field) break;
        }
        return column == columns.length ? null : columns[column];
    };

    //EXPAND COLLAPSE THE PARTICULAR RECORD OBJECT
    ej.TreeGrid.sendExpandCollapseRequest = function (element, args) {

        var proxy = element,
            model = proxy.model;

        args.requestType = ej.TreeGrid.Actions.ExpandCollapse;
        //To cancel the cell edit or row edit mode when expand the all record.
        if (proxy._isRowEdit || proxy.model.isEdit) {
            proxy.cancelRowEditCell();
            proxy._cancelSaveTools();
        }
        if (model.enableVirtualization) {

            if (proxy._isFromGantt) {
                proxy._$treegridHelper.ejTreeGrid("processBindings", args);
            } else {
                proxy.processBindings(args);
            }

            if (args.expanded) {

                proxy._trigger("expanded", args);

            } else {

                proxy._trigger("collapsed", args);

            }

            if (proxy._isFromGantt) {
                proxy._$treegridHelper.ejTreeGrid("sendDataRenderingRequest", args);
                proxy._updatedGanttRecords = proxy.getUpdatedRecords();
                proxy._currentViewData = proxy.getCurrentViewData();
                if (proxy.model.enableVirtualization) {
                    if (proxy.model.predecessorMapping) {
                        proxy._isValidationEnabled = false;
                        proxy._connectorlineIds = [];
                        proxy._connectorLinesCollection = [];
                        proxy._$ganttchartHelper.ejGanttChart("clearConnectorLines");
                        proxy._createConnectorLinesCollection();
                    }
                   proxy._$ganttchartHelper.ejGanttChart("refreshHelper", proxy._currentViewData, proxy._updatedGanttRecords);
                   proxy._$treegridHelper.ejTreeGrid("refreshHeight");                    
                }
                
            } else {
                proxy.sendDataRenderingRequest(args);
                proxy._setScrollTop();
                proxy._$gridContent.ejScroller("refresh");
                proxy._updateScrollCss();
            }
            

        } else {

            var record = args.data,
                index,
                $row,
                height = 0,
                isModified = record.expanded !== args.expanded;

            if (proxy._isFromGantt) {
                index = proxy._currentViewData.indexOf(record)
            } else {
                index = proxy.model.currentViewData.indexOf(record);
            }

            $row = $(proxy.getRows()[index]);

            if (args.expanded) {//expand event 
                record.expanded = args.expanded;
                proxy._expandedRecordsCount = 0;
                ej.TreeGrid.expandRecord(proxy, record, args.expanded, args);

                if (isModified) {
                    proxy._totalCollapseRecordCount -= proxy._expandedRecordsCount;
                }

                $row.find(".e-treegridcollapse").removeClass('e-treegridcollapse').addClass('e-treegridexpand');
                $row.removeClass('e-treegridrowcollapse').addClass('e-treegridrowexpand');                

                if (model.enableAltRow) {
                    ej.TreeGrid.updateAltRow(proxy, record, index, 1);
                }
            } else {

                proxy._collapsedRecordCount = 0;
                ej.TreeGrid.collapseRecord(proxy, record, args.expanded);
                
                if (isModified)
                    proxy._totalCollapseRecordCount += proxy._collapsedRecordCount;

                record.expanded = args.expanded;
                $row.find(".e-treegridexpand").removeClass('e-treegridexpand').addClass('e-treegridcollapse');
                $row.removeClass('e-treegridrowexpand').addClass('e-treegridrowcollapse');               
                    
                if (model.enableAltRow)
                    ej.TreeGrid.updateAltRow(proxy, record, index, proxy._collapsedRecordCount + 1);
            }


            var filteredCollapseCount = 0;
            if (proxy._searchString) {
                filteredCollapseCount = proxy.getUpdatedRecords().filter(function (record) {
                    return (proxy.getExpandStatus(record) === false);
                });
                height = (proxy.getUpdatedRecords().length - filteredCollapseCount.length) * model.rowHeight;
            } else
                height = (proxy.getUpdatedRecords().length - proxy._totalCollapseRecordCount) * model.rowHeight;
            if (proxy._isFromGantt) {
                proxy._$treegridHelper.ejTreeGrid("updateHeight", height);
                proxy._$ganttchart.ejGanttChart("updateHeight", height);
                proxy._$ganttchart.ejGanttChart("setCollapsedRecordCount", proxy._totalCollapseRecordCount);
                proxy._$treegridHelper.ejTreeGrid("setCollapsedRecordCount", proxy._totalCollapseRecordCount);
                
            } else {
                proxy.updateHeight(height);
            }

            

            if (args.expanded)
                proxy._trigger("expanded", args);
            else
                proxy._trigger("collapsed", args);
        }
        if (proxy._isFromGantt) {
            var treeGrid = proxy._$treegridHelper.ejTreeGrid("instance");
            var chart = proxy._$ganttchart.ejGanttChart("instance");
            var top = treeGrid._$gridContent.ejScroller("option", "scrollTop");
            chart._$bodyContainer.ejScroller("option", "scrollTop", top);
        }
        var selectItem = proxy.selectedItem();
        if (!proxy._isFromGantt && !args.expanded && selectItem) {            
            var expanded = proxy.getExpandStatus(selectItem);
            if (!expanded) {
                proxy.selectRows(-1);
                proxy.selectedRowIndex(-1);
                selectItem.isSelected = false;
                model.selectedItem = null;
                var editSettings = proxy.model.editSettings;
                var disableToolItems = [];
                if (editSettings.allowEditing && !$($('.e-edit')[0]).parent("li").hasClass("e-disable"))
                    disableToolItems.push($($('.e-edit')[0]).parent()[0]);
                if (editSettings.allowDeleting && !$($('.e-delete')[0]).parent("li").hasClass("e-disable"))
                    disableToolItems.push($($('.e-delete')[0]).parent()[0]);
                if (editSettings.allowDeleting && !$($('.e-cancel')[0]).parent("li").hasClass("e-disable"))
                    disableToolItems.push($($('.e-cancel')[0]).parent()[0]);
                if (editSettings.allowDeleting && !$($('.e-save')[0]).parent("li").hasClass("e-disable"))
                    disableToolItems.push($($('.e-save')[0]).parent()[0]);
                $('.e-treegridtoolbar').ejToolbar('disableItem', disableToolItems);
            }
        }
    };

    //EXPAND THE RECORD
    ej.TreeGrid.expandRecord = function (controlObject, Record, expanded, args) {
  
        var proxy = controlObject,
            rowClassName = ".gridrowIndex" + Record.index.toString() + "level" + (Record.level + 1).toString(),
            $rows = $(rowClassName),
            count = 0,
            length = $rows.length,
            row,
            index,
            record,
            model = proxy.model,
            $expandedRows = $(rowClassName),
            index,
            $gridRows = proxy.getRows(),
            $row = $($gridRows[index]);

        if (proxy._isFromGantt) {
            index = proxy._currentViewData.indexOf(Record);


        } else {
            index = model.currentViewData.indexOf(Record);
        }

        if (Record.hasChildRecords && Record.childRecords.length > 0) {
            $row.find(".e-treegridcollapse").removeClass('e-treegridcollapse').addClass('e-treegridexpand');
            $row.removeClass('e-treegridrowcollapse').addClass('e-treegridrowexpand');
        }

        proxy._expandedRecordsCount += proxy._isFromGantt ? $expandedRows.length / 2 : $expandedRows.length;

        if ($expandedRows.length === 0) {
            if (proxy.model.allowSearching && proxy._searchString && proxy._searchString.length > 0) {
                args && ej.TreeGrid.sendExpandCollapseRequest(proxy, args);
            }
        }

        $expandedRows.css({ 'display': 'table-row' });

        if (proxy._isFromGantt) {
         
            length = length / 2;
        }

        for (count; count < length; count++) {
            row = $rows[count];
            index = $gridRows.index(row);
            if (index !== -1) {
                record = proxy._isFromGantt ? proxy._updatedGanttRecords[index] : proxy._updatedRecords[index];
                record.isExpanded = true;
                if (record.expanded)
                    ej.TreeGrid.expandRecord(proxy,record, expanded);
            }
        }

        if (proxy._isFromGantt)
        proxy.updateConnectorLines($expandedRows, expanded);
    },
    
    //COLLAPSE THE RECORD
    ej.TreeGrid.collapseRecord = function (controlObject, Record, expanded) {

        var proxy = controlObject,
            model = proxy.model,
            rowClassName = ".gridrowIndex" + Record.index.toString() + "level" + (Record.level + 1).toString(),
            $rows = $(rowClassName),
            count = 0,
            length = $rows.length,
            row,
            index,
            record,
            $collapsedRows = $(rowClassName),
        $gridRows = proxy.getRows();

        proxy._collapsedRecordCount += proxy._isFromGantt ? $collapsedRows.length / 2 : $collapsedRows.length;
        $collapsedRows.css({ 'display': 'none' });

        if (proxy._isFromGantt) {

            proxy.updateConnectorLines($collapsedRows, expanded);
            length = length / 2;

        }

        for (count; count < length; count++) {

            row = $rows[count];
            var nn = proxy.getRows();
            index = proxy.getRows().index(row);


            if (index !== -1) {
                record = proxy.getUpdatedRecords()[index];

                if (record.expanded)
                    ej.TreeGrid.collapseRecord(proxy,record, expanded);
            }
        }
    },

    //UPDATE THE ALT ROW FUNCTION
    ej.TreeGrid.updateAltRow = function (controlObject, Record, recordIndex, offset) {

        var proxy = controlObject,
            count = 0,
            model = proxy.model,
            currentViewData = proxy._isFromGantt ? proxy._currentViewData : model.currentViewData,
            length = currentViewData.length,
            isAltRow = Record.isAltRow,
            record,
            $gridRows = proxy.getRows();

        for (count = recordIndex + offset; count < length; count++) {

            if ($($gridRows[count]).css('display') === "none")
                continue;

            record = currentViewData[count];
            if(count!=0)
            record.isAltRow = !isAltRow;
            isAltRow = record.isAltRow;

            if (isAltRow)
                $($gridRows[count]).addClass('e-alt-row');
            else
                $($gridRows[count]).removeClass('e-alt-row');

        }
    };     

    jQuery.uaMatch = function (ua) {
        ua = ua.toLowerCase();

        var match = /(chrome)[ \/]([\w.]+)/.exec(ua) ||
            /(webkit)[ \/]([\w.]+)/.exec(ua) ||
            /(opera)(?:.*version|)[ \/]([\w.]+)/.exec(ua) ||
            /(msie) ([\w.]+)/.exec(ua) ||
            ua.indexOf("compatible") < 0 && /(mozilla)(?:.*? rv:([\w.]+)|)/.exec(ua) ||
            [];

        return {
            browser: match[1] || "",
            version: match[2] || "0"
        };
    };

})(jQuery, Syncfusion);;;;
(function ($, ej, undefined) {
    ej.Grid = ej.Grid || {};
    ej.Grid.gridResize = function (instance) {
        this.$headerTable = instance.getHeaderTable();
        this.gridInstance = instance;
        this._colMinWidth = 15;
        this._$visualElement = $();
        this._currentCell = -1;
        this._allowStart = false;
        this._oldWidth = null;
        this._orgX = null;
        this._orgY = null;
        this._extra = null;
        this._expand = false;
        this._target = null;
    }

    ej.Grid.gridResize.prototype = {
        _mouseHover: function (e) {
            if (this._$visualElement.is(":visible"))
                return;
            if ($(e.target).is(".e-headercelldiv"))
                e.target = e.target.parentNode;
            var $target = $(e.target);
            if ($target.hasClass("e-headercell")) {
                var _resizableCell = e.target;
                var location = _resizableCell.getBoundingClientRect(), _x = 0, _y = 0;
                if (e.type = "mousemove") {
                    _x = e.clientX;
                    _y = e.clientY;
                }
                else if (e.type = "touchmove") {
                    _x = evt.originalEvent.changedTouches[0].clientX;
                    _y = evt.originalEvent.changedTouches[0].clientY;
                }
                else if (e.type = "MSPointerMove") {
                    _x = e.originalEvent.clientX;
                    _y = e.originalEvent.clientY;
                }
                if (this.gridInstance.model.scrollSettings && this.gridInstance.model.scrollSettings.frozenColumns)
                    var _nlx = this.gridInstance.getHeaderContent().width() + this.gridInstance.element.children(".e-gridheader").find(".e-columnheader").offset().left;
                else
                    var _nlx = this.gridInstance.getHeaderTable().width() + this.gridInstance.element.children(".e-gridheader").find(".e-columnheader").offset().left;
                if (((_x >= (location.left + document.documentElement.scrollLeft + _resizableCell.offsetWidth - 5)) || ((_x <= (location.left + 3)))) && (_x < _nlx) && (_x >= location.left) && (_y <= location.top + document.documentElement.scrollTop + e.target.offsetHeight)) {
                    this.gridInstance.model.showStackedHeader && $($target.parents('thead')).find('tr').css("cursor", "col-resize");
                    !this.gridInstance.model.showStackedHeader && $target.parent().css("cursor", "col-resize");
                    if ($(e.target).hasClass('e-stackedHeaderCell'))
                        this._currentCell = this.gridInstance.getHeaderContent().find(".e-headercell:visible").index(_resizableCell);
                    else
                        this._currentCell = this.gridInstance.getHeaderContent().find(".e-headercell:visible").not(".e-stackedHeaderCell").index(_resizableCell);
                    this._allowStart = true;
                }
                else {
                    $target.parent().css("cursor", "pointer");
                    this._allowStart = false;
                    this._currentCell = -1;
                }
            }
        },
        _start: function (_x, _y) {
            var _myrow = this.gridInstance.getHeaderTable().find(".e-columnheader");
            var _cells, _mycel;
            if ($(this._target).hasClass('e-stackedHeaderCell'))
                _cells = _myrow.find(".e-headercell")
            else
                _cells = _myrow.find(".e-headercell").not(".e-stackedHeaderCell");
            if (this._currentCell != -1 && this._currentCell < _cells.length)
                _mycel = _cells[this._currentCell];
            if (typeof (_mycel) == 'undefined')
                return;
            var _j = _mycel.getBoundingClientRect();
            this._tableY = _j.top + parseInt(navigator.userAgent.indexOf("WebKit") != -1 ? document.body.scrollTop : document.documentElement.scrollTop);
            if (this._allowStart) {
                this._$visualElement = $(document.createElement('div'));
                _height = this.gridInstance.element.find(".e-gridcontent").first().height() + this.gridInstance.element.find(".e-gridheader").height();
                if (this.gridInstance.model.showStackedHeader && this.gridInstance.model.stackedHeaderRows.length > 0) {
                    var headerRow = this.gridInstance.getHeaderTable().find('tr.e-columnheader')
                    var lenght = headerRow.length;
                    var currentIndex = $(this._target).parent('tr')[0].rowIndex;
                    for (var i = 0; i < currentIndex; i++) {
                        _height = _height - $(headerRow[i]).height();
                    }
                    // _height = _height - $(".e-stackedHeaderRow").height();
                }
                this._$visualElement.addClass("e-reSizeColbg").appendTo(this.gridInstance.element).css({ height: _height + 'px', cursor: 'col-resize' });
                this._$visualElement.css({ left: _x, top: this._tableY });
                this._oldWidth = _mycel.offsetWidth;
                this._orgX = _x;
                this._orgY = _y;
                this._extra = _x - this._orgX;
                this._expand = true;
            }
            else {
                this._currentCell = -1;
            }
        },
        _mouseMove: function (e) {
            if (this._expand) {
                var _x = 0, _y = 0;
                if (e.type = "mousemove") {
                    _x = e.clientX;
                    _y = e.clientY;
                }
                else if (e.type = "touchmove") {
                    _x = evt.originalEvent.changedTouches[0].clientX;
                    _y = evt.originalEvent.changedTouches[0].clientY;
                }
                else if (e.type = "MSPointerMove") {
                    _x = e.originalEvent.clientX;
                    _y = e.originalEvent.clientY;
                }
                if (navigator.userAgent.indexOf("WebKit") != -1) {
                    _x = e.pageX;
                    _y = e.pageY;
                }
                _x += document.documentElement.scrollLeft;
                e.preventDefault();
                this._moveVisual(_x);
            }
            else
                this._mouseHover(e);
        },
        _getCellIndex: function (e) {
            var $target = $(e._target);
            var targetCell = e._target;
            var hCellIndex = targetCell.cellIndex;
            var cellIndex = hCellIndex;
            if (e.gridInstance.model.groupSettings.groupedColumns.length) {
                cellIndex = hCellIndex - e.gridInstance.model.groupSettings.groupedColumns.length;
            }
            return cellIndex;
        },
        _reSize: function (_x, _y) {
            // Function used for Resizing the column
            var proxy = this;
            var resized = false, $content;
            if (this.gridInstance.model.scrollSettings && this.gridInstance.model.scrollSettings.frozenColumns)
                this._initialTableWidth = this.gridInstance.getHeaderTable().first().parent().width() + this.gridInstance.getHeaderTable().last().parent().width();
            else
                this._initialTableWidth = this.gridInstance.getHeaderTable().parent().width();
            !this.gridInstance.model.enableRTL && this._getResizableCell();
            var _rowobj = $(this._target).parents('thead');
            if (this._currentCell != -1 && this._expand) {
                this._expand = false;
                var _childTH = _rowobj.find(".e-headercell").filter(":visible");
                var _outerCell = _childTH[this._currentCell];
                var _oldWidth = _outerCell.offsetWidth;
                var _extra = _x - this._orgX;
                //Check whether the column minimum width reached
                if (parseInt(_extra) + parseInt(_oldWidth) > this._colMinWidth) {
                    if (_extra != 0)
                        _rowobj.css("cursor", 'default');
                    this._resizeColumnUsingDiff(_oldWidth, _extra);
                    $content = this.gridInstance.element.find(".e-gridcontent").first();
                    this.gridInstance.model.allowScrolling && $content.ejScroller("refresh");
                    var browser = this.gridInstance.getBrowserDetails();
                    if (browser.browser == "msie" && this.gridInstance.model.allowScrolling) {
                        var oldWidth = this.gridInstance.getContentTable().width(), newwidth = this.gridInstance._calculateWidth();
                        if (this.gridInstance.model.scrollSettings && this.gridInstance.model.scrollSettings.frozenColumns > 0) {
                            this.gridInstance.getHeaderTable().last().width(newwidth - this.gridInstance.getHeaderContent().find(".e-frozenheaderdiv").width());
                            this.gridInstance.getContentTable().last().width(newwidth - this.gridInstance.getContent().find(".e-frozencontentdiv").width());
                            this.gridInstance.model.showSummary && this.gridInstance.getFooterTable().last().width(newwidth - this.gridInstance.getFooterContent().find(".e-frozenfootertdiv").width());
                        }
                        else {
							if (newwidth > oldWidth) {
								this.gridInstance.getHeaderTable().width(newwidth);
								this.gridInstance.getContentTable().width(newwidth);
								this.gridInstance.model.showSummary && this.gridInstance.getFooterTable().width(newwidth);
							}
                        }
                        if (parseInt(browser.version, 10) > 8 && this.gridInstance.model.groupSettings && this.gridInstance.model.groupSettings.groupedColumns.length) {
                            if (newwidth > oldWidth) {
                                this.gridInstance.getContentTable().width(newwidth);
                                this.gridInstance.getContentTable().children("colgroup").find("col").first().css("width", (20 / $content.find("table").first().width()) * 100 + "%");
                            }
                            else {
                                this.gridInstance.getContentTable().css("width", "100%");
                                this.gridInstance._groupingAction();
                                this.gridInstance.getContentTable().children("colgroup").find("col").first().css("width", ((this.gridInstance.getHeaderTable().find("colgroup").find("col").first().width() / $content.find("table").first().width()) * 100).toFixed(2) + "%");
                            }
                        }
                        this.gridInstance.getHeaderTable().parent().scrollLeft($content.find(".e-content").scrollLeft() - 1);
                    }
                    this.gridInstance._colgroupRefresh();
                    if (this.gridInstance.model.groupSettings.groupedColumns.length && this.gridInstance.model.groupSettings.showGroupedColumn)
                        this.gridInstance._recalculateIndentWidth();
                    if (!(browser.browser == "msie") && this.gridInstance.model.allowScrolling && this.gridInstance.model.scrollSettings.frozenColumns == 0) {
                        var tableWidth = this.gridInstance._calculateWidth();
						if(tableWidth > this.gridInstance.getContentTable().width() || this.gridInstance.getHeaderTable().width() > this.gridInstance.getContentTable().width()){
							this.gridInstance.getHeaderTable().width(tableWidth);
							this.gridInstance.getContentTable().width(tableWidth);
						}
                    }
                    if (this.gridInstance.model.allowResizing && this.gridInstance.getHeaderTable().find(".e-columnheader").css('cursor') == 'default') {
                        var cellIndex = this._getCellIndex(this);
                        var newWidth = _oldWidth + _extra;
                        var args = { columnIndex: cellIndex, column: this.gridInstance.model.columns[cellIndex], oldWidth: _oldWidth, newWidth: newWidth };
                        this.gridInstance._trigger("resized", args);
                    }
                }

            }
			this.gridInstance.model.allowScrolling && this.gridInstance.getScrollObject().refresh();
            this._target = null;
            this._$visualElement.remove();
            this._expand = false;
            this._currentCell = -1;
            this._allowStart = false;

        },
        _getFrozenResizeWidth: function () {
            var $frozenColumnsCol = this.gridInstance.getHeaderTable().find('colgroup').find("col").slice(0, this.gridInstance.model.scrollSettings ? this.gridInstance.model.scrollSettings.frozenColumn : 0), width = 0;
            for (var i = 0; i < $frozenColumnsCol.length; i++) {
                if ($frozenColumnsCol.eq(i).css("display") != "none")
                    width += parseInt($frozenColumnsCol[i].style.width.replace("px", ""));
            }
            return width;
        },
        _diaplayFinder: function () {
            return $(this).css('display') != 'none';
        },
        _resizeColumnUsingDiff: function (_oldWidth, _extra) {
            var proxy = this;
            var currentIndex = this._currntCe = this._currentCell, _extraVal;
            if ($(this._target).parent('tr').hasClass('e-stackedHeaderRow')) {
                var preCol = 0, currentTh = $(this._target), currentSpan = $(currentTh).attr('colspan'), tr = $(currentTh).parent('tr');
                while (currentIndex > 0) {
                    currentIndex--
                    var th = $(tr).children('th')[currentIndex];
                    preCol += parseInt($(th).attr('colspan'))
                }
                this._currentCell = preCol;
            }
            if (this.gridInstance.model.showStackedHeader && !$(this._target).parent('tr').hasClass('e-stackedHeaderRow'))
                this._currentCell = this._currentCell - this.gridInstance.getHeaderTable().find(".e-stackedHeaderCell").length;            
			var $headerCols = this.gridInstance.getHeaderTable().find('colgroup').find("col");
            var $ContentCols = this.gridInstance.getContentTable().find('colgroup').find("col");
            if (!ej.isNullOrUndefined(this.gridInstance.model.detailsTemplate)) {
                this.gridInstance._detailColsRefresh();
                $headerCols = this.gridInstance._$headerCols;
                $ContentCols = this.gridInstance._$contentCols;
            }
            var $headerCol = $headerCols.filter(this._diaplayFinder).eq(!this.gridInstance.model.allowGrouping || !ej.isNullOrUndefined(this.gridInstance.model.detailsTemplate) ? this._currentCell : this._currentCell + this.gridInstance.model.groupSettings.groupedColumns.length)
                    , $ContentCol, $footerCol, $frozenCols = $headerCols.slice(0, this.gridInstance.model.scrollSettings ? this.gridInstance.model.scrollSettings.frozenColumns : 0);
            var _inlineWidth = $headerCol[0].style.width;
            var indent = _oldWidth / parseInt(_inlineWidth);
            _extraVal = _extra = _extra / indent
            var _newWidth = parseInt(_extra) + parseInt(_inlineWidth);
            if (_newWidth > 0 && _extra != 0) {
                if (_newWidth < this._colMinWidth)
                    _newWidth = this._colMinWidth;
                var _extra = _newWidth - _oldWidth;
                if (this.gridInstance.model.scrollSettings && this.gridInstance.model.scrollSettings.frozenColumns) {
                    if (this._currentCell >= 0 && this._currentCell < this.gridInstance.model.scrollSettings.frozenColumns && this._getFrozenResizeWidth() + _extra > this.gridInstance.element.find(".e-headercontent").first().width())
                        return;
                    $ContentCol = $ContentCols.filter(this._diaplayFinder).eq(this._currentCell);
                }
                else
                    $ContentCol = $ContentCols.filter(this._diaplayFinder).eq(!this.gridInstance.model.allowGrouping || !ej.isNullOrUndefined(this.gridInstance.model.detailsTemplate) ? this._currentCell : this._currentCell + this.gridInstance.model.groupSettings.groupedColumns.length);
                if (this.gridInstance.model.showSummary) {
                    $footerCol = this.gridInstance.getFooterTable().find('colgroup').find("col").filter(this._diaplayFinder).eq(this._currentCell);
                    $footerCol.outerWidth(_newWidth);
                }
                if ($(this._target).parent('tr').hasClass('e-stackedHeaderRow')) {
                    this._resizeStackedHeaderColumn($(this._target).parent('tr'), _extraVal, this._currntCe);
                }
                else
                    $headerCol.outerWidth(_newWidth);
                if (this.gridInstance.model.isEdit) {
                    var $editCol = this.gridInstance.getContentTable().find(".e-editedrow,.e-addedrow").find("table").find("colgroup");
                    $($editCol[0].children[this._currentCell - this.gridInstance.model.groupSettings ? this.gridInstance.model.groupSettings.groupedColumns.length : 0]).width(_newWidth);
                }
                if ($(this._target).parent('tr').hasClass('e-stackedHeaderRow')) {
                    if (this.gridInstance.model.groupSettings.groupedColumns.length < 1) {

                        var length = this.gridInstance.getContentTable().find('colgroup').find("col").filter(this._diaplayFinder).length;
                        for (var i = 0; i < this._changedcell.length; i++) {
                            var $conCol = this.gridInstance.getContentTable().find('colgroup').find("col").filter(this._diaplayFinder)[this._changedcell[i]]
                            var width = parseInt((_extraVal)) + parseInt($conCol.style.width);
                            $($conCol).width(width);
                        }
                    }
                    else {
                        var $tables = this.gridInstance.getContentTable().find(".e-recordtable");
                        var $colGroup = $tables.find("colgroup");
                        for (var i = 0; i < this._changedcell.length; i++) {
                            var cellIndex = this._changedcell[i];
                            for (var i = 0 ; i < $colGroup.length; i++) {
                                var width = parseInt((_extraVal)) + parseInt($($colGroup[i].children[cellIndex]).width());
                                $($colGroup[i].children[cellIndex]).width(width);
                            }
                        }
                    }
                }
                else {
                    if (this.gridInstance.model.groupSettings && this.gridInstance.model.groupSettings.groupedColumns.length) {
                        var $tables = this.gridInstance.getContentTable().find(".e-recordtable");
                        var $colGroup = $tables.find("colgroup");
                        var cellIndex = this._currentCell + this.gridInstance._hiddenColumns.length;
                        var colCount = this.gridInstance.model.columns.length;
                        for (var i = 0 ; i < $colGroup.length; i++) {
                            var cols = $($colGroup[i]).find("col");
                            if (cols.length > colCount) cols.splice(0, (cols.length - colCount));
                            $(cols[cellIndex]).width(_newWidth);
                        }
                    }                    
                    $ContentCol.width(_newWidth);
                }
                this.gridInstance._findColumnsWidth();
                if (this.gridInstance.model.scrollSettings && this.gridInstance.model.scrollSettings.frozenColumns) {
                    var frozenColumns = this.gridInstance.getContentTable().find('colgroup').find("col").slice(0, this.gridInstance.model.scrollSettings.frozenColumns)
                        , width = 0, direction;
                    for (i = 0; i < frozenColumns.length; i++)
                        width += parseInt(frozenColumns[i].style.width.replace("px", ""));
                    this.gridInstance.getHeaderContent().find(".e-frozenheaderdiv").width(width);
                    direction = this.gridInstance.model.enableRTL ? "margin-right" : "margin-left";
                    this.gridInstance.getContent().find(".e-frozencontentdiv").width(width).next().css(direction, width + "px");
                    this.gridInstance.getHeaderContent().find(".e-frozenheaderdiv").width(width).next().css(direction, width + "px");
                    this.gridInstance.model.showSummary && this.gridInstance.getFooterContent().find(".e-frozenfooterdiv").width(width);
                }
                this.gridInstance.getHeaderTable().find(".e-columnheader").css("cursor", "default");
            }
        },
        _resizeStackedHeaderColumn: function (currentTr, extra, currentCell) {
            // var currentIndex = this._currntCe;
            this._changedcell = [];
            if (this.gridInstance.model.groupSettings.showGroupedColumn && this.gridInstance.model.groupSettings.groupedColumns.length > 0) {
                this._currentCell++;
                currentCell++;
            }
            var preCol = this._currentCell, currentTh = $(currentTr).find('th')[currentCell], currentSpan = $(currentTh).attr('colspan'), commonExtra = extra / currentSpan, tr = $(currentTh).parent('tr');
            if (currentSpan > 1) {
                var nextTr = tr.next();
                var length = preCol + parseInt(currentSpan);
                for (var i = preCol; i < length; i++) {
                    var curTh = $($(nextTr).find('th'))[i], curCol = $(curTh).attr('colspan');
                    if (curCol > 1) {
                        this._resizeStackedHeaderColumn($(curTh).parent('tr'), commonExtra, i)
                    }
                    else {
                        var $colG = this.gridInstance.getHeaderTable().find('col')[i];
                        this._changedcell.push(i)
                        var width = parseInt(extra) + parseInt($colG.style.width);
                        $($colG).outerWidth(width);
                    }
                }
            }
            else {
                var $colG = this.gridInstance.getHeaderTable().find('col')[this._currentCell];
                var width = parseInt(extra) + parseInt($colG.style.width);
                this._changedcell.push(preCol)
                $($colG).outerWidth(width);
            }
        },
        _triggerResizeEvents: function (event, _x) {
            var _rowobj = this.gridInstance.getHeaderTable().find(".e-columnheader");
            var _childTH = _rowobj.find(".e-headercell").filter(":visible");
            var _outerCell = _childTH[this._currentCell];
            var _oldWidth = _outerCell.offsetWidth;
            var cellIndex = this._getCellIndex(this);
            if (event == "resizeStart") {
                var args = { columnIndex: cellIndex, column: this.gridInstance.model.columns[cellIndex], target: $(_outerCell), oldWidth: _oldWidth };
                this.gridInstance._trigger("resizeStart", args);
            }
            else {
                var _extra = _x - this._orgX;
                var newWidth = _oldWidth + _extra;
                this.gridInstance._colgroupRefresh();
                var args = { columnIndex: cellIndex, column: this.gridInstance.model.columns[cellIndex], target: $(_outerCell), oldWidth: _oldWidth, newWidth: newWidth, extra: _extra };
                this.gridInstance._trigger("resizeEnd", args);
            }
        },
        _mouseUp: function (e) {
            if (this._expand) {
                var _x = e.clientX, _y = e.clientY;
                if (navigator.userAgent.indexOf("WebKit") != -1) {
                    _x = e.pageX;
                    _y = e.pageY;
                }
                if (this.gridInstance.model.allowResizing && this.gridInstance.getHeaderTable().find(".e-columnheader").css('cursor') == 'col-resize') {
                    this._triggerResizeEvents("resizeEnd", _x);
                }
                _x += document.documentElement.scrollLeft;
                this._reSize(_x, _y);
            }
        },
        _getResizableCell: function () {
            var row = this.gridInstance.getHeaderTable().find(".e-columnheader");
            var cell = row.find(".e-headercell").not(".e-hide,.e-detailheadercell");
            var scrollLeft = navigator.userAgent.indexOf("WebKit") != -1 ? document.body.scrollLeft : document.documentElement.scrollLeft;
            for (var i = 0; i < cell.length; i++) {
                point = cell[i].getBoundingClientRect();
                var xlimit = point.left + scrollLeft + 5;
                if (xlimit > this._orgX && $(cell[i]).height() + point.top >= this._orgY) {
                    this._currentCell = i - 1;
                    return;
                }
            }
        },
        _moveVisual: function (_x) {
            /// Used to move the visual element in mouse move
            var _bounds = this.gridInstance.getHeaderContent().find("div").first()[0].getBoundingClientRect();
            if ((_bounds.left + document.documentElement.scrollLeft + _bounds.width < _x) || (_x < _bounds.left + document.documentElement.scrollLeft))
                this._$visualElement.remove();
            else if (this._currentCell != -1)
                this._$visualElement.css({ left: _x, top: this._tableY });
        },
        _mouseDown: function (e) {
            if (this._allowStart && ($(e.target).closest("tr").css("cursor") == 'col-resize')) {
                this._target = e.target;
                var _x = e.clientX, _y = e.clientY;
                if (navigator.userAgent.indexOf("WebKit") != -1) {
                    _x = e.pageX;
                    _y = e.pageY;
                }
                if (this.gridInstance.model.allowResizing && this.gridInstance.getHeaderTable().find(".e-columnheader").css('cursor') == 'col-resize') {
                    if ($(e.target).is(".e-headercelldiv"))
                        e.target = e.target.parentNode;
                    this._target = e.target;
                    this._triggerResizeEvents("resizeStart", _x);
                }
                var gridobj = this;
                _x += document.documentElement.scrollLeft;
                if (e.button != 2)
                    if (this.gridInstance.model.allowResizing && this.gridInstance.model.allowResizeToFit) {
                        gridobj.gridInstance._click++;
                        setTimeout(function () {
                            if (gridobj.gridInstance._click == 1) {
                                gridobj._start(_x, _y);
                            }
                            else if (gridobj.gridInstance._click == 2) {
                                gridobj._columnResizeToFit(e);
                            }
                            gridobj.gridInstance._click = 0;
                        }, 400);
                    }
                    else
                        this._start(_x, _y);
                e.preventDefault();
            }
            return false;
        },
        _columnResizeToFit: function (e) {
            if (this.gridInstance.model.allowResizeToFit && this.gridInstance.getHeaderTable().find(".e-columnheader").css('cursor') == 'col-resize') {
                if ($(e.target).is(".e-headercelldiv"))
                    e.target = e.target.parentNode;
                var $target = $(e.target);
                this._target = $target;
                if ($target.hasClass("e-headercell")) {
                    var targetCell = e.target;
                    var hCellIndex = targetCell.cellIndex;
                    var cellIndex = hCellIndex;
                    this._orgX = e.pageX;
                    this._getResizableCell();
                    if (hCellIndex != this._currentCell) {
                        hCellIndex = cellIndex = this._currentCell;
                        targetCell = e.target.previousSibling;
                    }
                    var $cellDiv = $(targetCell).children('.e-headercelldiv');
                    if (this.gridInstance.model.groupSettings.groupedColumns.length) {
                        cellIndex = hCellIndex - this.gridInstance.model.groupSettings.groupedColumns.length;
                    }
                    var finalWidth = 0, headerWidth = 0, contentWidth = 0;
                    if (cellIndex != -1) {
                        contentWidth = this._getContentWidth(cellIndex);
                        headerWidth = this._getHeaderContentWidth($cellDiv);
                        finalWidth = headerWidth > contentWidth ? headerWidth : contentWidth;
                        finalWidth = finalWidth + (finalWidth * 0.2);
                        var oldWidth = this.gridInstance.getHeaderTable().find('col').eq(hCellIndex).width();
                        var args = { columnIndex: cellIndex, column: this.gridInstance.model.columns[cellIndex], target: $target, oldWidth: oldWidth };
                        this.gridInstance._trigger("resizeStart", args);
						finalWidth =  oldWidth > finalWidth ? finalWidth : (this._colMinWidth < contentWidth ? contentWidth : this._colMinWidth);
                        this.gridInstance.getHeaderTable().find('col').eq(hCellIndex).width(finalWidth);
                        if (this.gridInstance.model.groupSettings.groupedColumns.length) {
                            var $colGroups = this.gridInstance.getContentTable().find('.e-recordtable').find('colgroup');
                            $.each($colGroups, function (indx, colgroup) {
                                $(colgroup).find('col').eq(cellIndex).width(finalWidth);
                            });
                        }
                        else
                            this.gridInstance.getContentTable().find('col').eq(cellIndex).width(finalWidth);
                        var newWidth = this.gridInstance.getHeaderTable().find('col').eq(hCellIndex).width();
                        this.gridInstance._colgroupRefresh();
                        args = { columnIndex: cellIndex, column: this.gridInstance.model.columns[cellIndex], target: $target, oldWidth: oldWidth, newWidth: newWidth, extra: Math.abs(newWidth - oldWidth) };
                        this.gridInstance._trigger("resizeEnd", args);
                        this.gridInstance._columnsWidthCollection[cellIndex] = finalWidth;
                        this.gridInstance.model.columns[cellIndex]["width"] = finalWidth;
                        args = { columnIndex: cellIndex, column: this.gridInstance.model.columns[cellIndex], target: $target, oldWidth: oldWidth, newWidth: newWidth };
                        this.gridInstance._trigger("resized", args);
                    }
                }
            }
        },
        _getContentWidth: function (cellindx) {
            var contentWidth = 0;
            var $span = ej.buildTag('span', {}, {}), proxy = this.gridInstance, tdWidth;
            $.each(proxy._gridRows, function (indx, row) {
                var td = $(row).find('td.e-rowcell').eq(cellindx);
                var content = $(td).html();
                if (proxy.model.columns[cellindx]["isUnbound"])
                    $span.html($(content).children());
                else
                    $span.html(content);
                $(td).html($span);
                tdWidth = td.find('span:first').width();
                if (tdWidth > contentWidth)
                    contentWidth = tdWidth;
                $(td).html(content);
            });
            proxy._refreshUnboundTemplate(this.gridInstance.getContentTable());
            return contentWidth;
        },
        _getHeaderContentWidth: function ($cellDiv) {
            var headerWidth = 0, $span = ej.buildTag('span', {}, {});
            var content = $cellDiv.html();
            $span.html(content);
            $cellDiv.html($span);
            headerWidth = $cellDiv.find('span:first').width();
            if (this.gridInstance.model.allowFiltering && this.gridInstance.model.filterSettings.filterType == "menu")
                headerWidth = headerWidth + $cellDiv.parent().find(".e-filtericon").width() + 10;
            $cellDiv.html(content);
            return headerWidth;
        },
    };
})(jQuery, Syncfusion);;
});