/**
* @fileOverview Plugin to style the Html ListView elements
* @copyright Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/

(function ($, ej, undefined) {



    ej.widget("ejListViewBase", "ej.ListViewBase", {


        defaults: {
            // Web
            /**		
            * Specifies the height.
            * @default undefined
            * @member height {object}
            * @type {number}
            * @example 
            * //Set the height property in obtrusive way.
            * &lt;div id="lb" data-ej-allowScrolling=true &gt;
            *	 &lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * // Set height on initialization. 
            * //To set height API value 
            * $("#lb").ejListView ({ height: 300 });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set  height, after initialization:<br>
            * // Get the height API value.		
            *  $("#lb").ejListView ("option", "height");			
            * // Set the height API
            * $("#lb").ejListView ("option", "height", 300);
            * &lt;/script&gt;
            * @memberof ejListView
            * @instance
            */
            //Mobile
            /**		
            * Specifies the height of the ListView.
            * @default undefined
            * @member height {object}
            * @type {number}
            * @example 
            * //Set the height property in Unobtrusive way.
            * &lt;div id="lb" data-role="ejmlistview" data-ej-height="300"&gt;
            *	 &lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * //Set the height property in Obtrusive way.
            * &lt;div id="lb" &gt;
            *	 &lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * // Set ListView height on initialization. 
            * //To set height API value 
            * $("#lb").ejmListView ({ height: 300 });
            * //Get or set the ListView height, after initialization:<br>
            * // Gets the height API value.		
            *  $("#lb").ejmListView ("option", "height");			
            * // Sets the height API
            * $("#lb").ejmListView ("option", "height", 300);
            * @memberof ejmListView
            * @instance
            */
            height: null,
            /**		
            * Specifies the width.
            * @default undefined
            * @member width {object}
            * @type {number}
            * @example 
            * //Set the width property in obtrusive way.
            * &lt;div id="lb"&gt;
            *	 &lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * // Set width on initialization. 
            * //To set width API value 
            * $("#lb").ejListView ({ width: 200 });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set  width, after initialization:<br>
            * // Get the width API value.		
            *  $("#lb").ejListView ("option", "width");			
            * // Set the width API
            * $("#lb").ejListView ("option", "width", 200);
            * &lt;/script&gt;
            * @memberof ejListView
            * @instance
            */
            //Mobile
            /**		
            * Specifies the width of the ListView.
            * @default undefined
            * @member width {object}
            * @type {number}
            * @example 
            * //Set the width property in Unobtrusive way.
            * &lt;div id="lb" data-role="ejmlistview" data-ej-width="200"&gt;
            *	 &lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * //Set the width property in Obtrusive way.
            * &lt;div id="lb" &gt;
            *	 &lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * // Set ListView width on initialization. 
            * //To set width API value 
            * $("#lb").ejmListView ({ width: 200 });
            * //Get or set the ListView width, after initialization:<br>
            * // Gets the width API value.		
            *  $("#lb").ejmListView ("option", "width");			
            * // Sets the width API
            * $("#lb").ejmListView ("option", "width", 200);
            * @memberof ejmListView
            * @instance
            */
            width: null,
            /**		
            * Specifies the index of item which need to be in selected state initially while loading.
            * @default 0
            * @member selectedItemIndex {object}
            * @type {number}
            * @example 
            * //Set the selectedItemIndex property in obtrusive way.
            * &lt;div id="lb"&gt;
            *	 &lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * // Set selectedItemIndex on initialization. 
            * //To set selectedItemIndex API value 
            * $("#lb").ejListView ({ selectedItemIndex: 2 });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set  selectedItemIndex, after initialization:<br>
            * // Get the selectedItemIndex API value.		
            *  $("#lb").ejListView ("option", "selectedItemIndex");			
            * // Set the selectedItemIndex API
            * $("#lb").ejListView ("option", "selectedItemIndex", 2);
            * &lt;/script&gt;
            * @memberof ejListView
            * @instance
            */
            //Mobile
            /**		
            * Specifies the selectedItemIndex of the ListView.
            * @default 0
            * @member selectedItemIndex {object}
            * @type {number}
            * @example 
            * //Set the selectedItemIndex property in Unobtrusive way.
            * &lt;div id="lb" data-role="ejmlistview" data-ej-selectedItemIndex="2"&gt;
            *	 &lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * //Set the selectedItemIndex property in Obtrusive way.
            * &lt;div id="lb" &gt;
            *	 &lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * // Set ListView selectedItemIndex on initialization. 
            * //To set selectedItemIndex API value 
            * $("#lb").ejmListView ({ selectedItemIndex: 2 });
            * //Get or set the ListView selectedItemIndex, after initialization:<br>
            * // Gets the selectedItemIndex API value.		
            *  $("#lb").ejmListView ("option", "selectedItemIndex");			
            * // Sets the selectedItemIndex API
            * $("#lb").ejmListView ("option", "selectedItemIndex", 2);
            * @memberof ejmListView
            * @instance
            */
            selectedItemIndex: -1,
            /**		
            * Specifies whether to group the list item.
            * @default false
            * @member enableGroupList {object}
            * @type {boolean}
            * @example 
            * //Set the enableGroupList property in obtrusive way.
            * &lt;div id="lb"&gt;
            * 	&lt;ul data-ej-grouplisttitle="Network"&gt;
            *		&lt;li data-ej-text="Airplane Mode"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Wi-Fi"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Notifications"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Location Services"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * 	&lt;ul data-ej-grouplisttitle="Apps"&gt;
            *		&lt;li data-ej-text="Sound"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Brightness"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Wallpaper"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * 	&lt;ul data-ej-grouplisttitle="Settings"&gt;
            *		&lt;li data-ej-text="General"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Brightness"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Wallpaper"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * // Set enableGroupList on initialization. 
            * //To set enableGroupList API value 
            * $("#lb").ejListView ({ enableGroupList: true });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set  enableGroupList, after initialization:<br>
            * // Get the enableGroupList API value.		
            *  $("#lb").ejListView ("option", "enableGroupList");			
            * // Set the enableGroupList API
            * $("#lb").ejListView ("option", "enableGroupList", true);
            * &lt;/script&gt;
            * @memberof ejListView
            * @instance
            */
            //Mobile
            /**		
            * Specifies whether to group the list item.
            * @default false
            * @member enableGroupList {object}
            * @type {boolean}
            * @example 
            * //Set the enableGroupList property in unobtrusive way.
            * &lt;div id="lb" data-role="ejmlistview" data-ej-enableGroupList="true"&gt;
            * 	&lt;ul data-ej-grouplisttitle="Network"&gt;
            *		&lt;li data-ej-text="Airplane Mode"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Wi-Fi"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Notifications"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Location Services"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * 	&lt;ul data-ej-grouplisttitle="Apps"&gt;
            *		&lt;li data-ej-text="Sound"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Brightness"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Wallpaper"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * 	&lt;ul data-ej-grouplisttitle="Settings"&gt;
            *		&lt;li data-ej-text="General"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Brightness"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Wallpaper"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * //Set the enableGroupList property in obtrusive way.
            * &lt;div id="lb"&gt;
            * 	&lt;ul data-ej-grouplisttitle="Network"&gt;
            *		&lt;li data-ej-text="Airplane Mode"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Wi-Fi"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Notifications"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Location Services"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * 	&lt;ul data-ej-grouplisttitle="Apps"&gt;
            *		&lt;li data-ej-text="Sound"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Brightness"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Wallpaper"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * 	&lt;ul data-ej-grouplisttitle="Settings"&gt;
            *		&lt;li data-ej-text="General"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Brightness"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Wallpaper"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * // Set enableGroupList on initialization. 
            * //To set enableGroupList API value 
            * $("#lb").ejmListView ({ enableGroupList: true });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set  enableGroupList, after initialization:<br>
            * // Get the enableGroupList API value.		
            *  $("#lb").ejmListView ("option", "enableGroupList");			
            * // Set the enableGroupList API
            * $("#lb").ejmListView ("option", "enableGroupList", true);
            * &lt;/script&gt;
            * @memberof ejmListView
            * @instance
            */
            enableGroupList: false,
            /**		
            * Specifies whether to load ajax content while selecting item.
            * @default false
            * @member enableAjax {object}
            * @type {boolean}          
            * @example  
            * //Set the enableAjax property in obtrusive way.
            * &lt;div id="lb"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Man of Steel" data-ej-href="load1.html" &gt;&lt;/li&gt;
            *		&lt;li data-ej-text="World War Z" data-ej-href="load2.html" &gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Monsters University" data-ej-href="load3.html" &gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * // Set enableAjax on initialization. 
            * //To set enableAjax API value
            * $("#lb").ejListView ({ enableAjax: true });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set  enableAjax, after initialization:<br>
            * // Get the enableAjax API value.		
            * $("#lb").ejListView ("option", "enableAjax");			
            * // Set the enableAjax API
            * $("#lb").ejListView ("option", "enableAjax", true);
            * &lt;/script&gt;
            * @memberof ejListView
            * @instance
            */
            //Mobile
            /**		
            * Specifies whether to load ajax content while selecting item.
            * @default false
            * @member enableAjax {object}
            * @type {boolean}
            * @example 
            * //Set the enableAjax property in unobtrusive way.
            * &lt;div id="lb" data-role="ejmlistview"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Man of Steel" data-ej-href="load1.html" data-ej-enableajax="true"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="World War Z" data-ej-href="load2.html" data-ej-enableajax="true"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Monsters University" data-ej-href="load3.html" data-ej-enableajax="true"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example  
            * //Set the enableAjax property in obtrusive way.
            * &lt;div id="lb"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Man of Steel" data-ej-href="load1.html" &gt;&lt;/li&gt;
            *		&lt;li data-ej-text="World War Z" data-ej-href="load2.html" &gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Monsters University" data-ej-href="load3.html" &gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * // Set enableAjax on initialization. 
            * //To set enableAjax API value
            * $("#lb").ejmListView ({ enableAjax: true });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set  enableAjax, after initialization:<br>
            * // Get the enableAjax API value.		
            * $("#lb").ejmListView ("option", "enableAjax");			
            * // Set the enableAjax API
            * $("#lb").ejmListView ("option", "enableAjax", true);
            * &lt;/script&gt;
            * @memberof ejmListView
            * @instance
            */
            enableAjax: false,
            /**		
            * Specifies whether to enable caching the content.
            * @default false
            * @member enableCache {object}
            * @type {boolean}
            * @example 
            * //Set the enableCache property in obtrusive way.
            * &lt;div id="lb" &gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Man of Steel" data-ej-href="load1.html" &gt;&lt;/li&gt;
            *		&lt;li data-ej-text="World War Z" data-ej-href="load2.html" &gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Monsters University" data-ej-href="load3.html" &gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * // Set enableCache on initialization. 
            * //To set enableCache API value             
            * $("#lb").ejListView ({ enableAjax: true,enableCache: true });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set  enableCache, after initialization:<br>
            * // Get the enableCache API value.		
            * $("#lb").ejListView ("option", "enableCache");			
            * // Set the enableCache API
            * $("#lb").ejListView ("option", "enableCache", true);
            * &lt;/script&gt;
            * @memberof ejListView
            * @instance
            */
            //Mobile
            /**		
            * Specifies whether to enable caching the content.
            * @default false
            * @member enableCache {object}
            * @type {boolean}
            * @example 
            * //Set the enableCache property in unobtrusive way.
            * &lt;div id="lb" data-role="ejmlistview" data-ej-enableCache="true"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Man of Steel" data-ej-href="load1.html" data-ej-enableajax="true" data-ej-enableCache="true"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="World War Z" data-ej-href="load2.html" data-ej-enableajax="true" data-ej-enableCache="true"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Monsters University" data-ej-href="load3.html" data-ej-enableajax="true" data-ej-enableCache="true"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * //Set the enableCache property in obtrusive way.
            * &lt;div id="lb" &gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Man of Steel" data-ej-href="load1.html" data-ej-enableajax="true" &gt;&lt;/li&gt;
            *		&lt;li data-ej-text="World War Z" data-ej-href="load2.html" data-ej-enableajax="true" &gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Monsters University" data-ej-href="load3.html" data-ej-enableajax="true" &gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * // Set enableCache on initialization. 
            * //To set enableCache API value 
            * $("#lb").ejmListView ({ enableCache: true });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set  enableCache, after initialization:<br>
            * // Get the enableCache API value.		
            * $("#lb").ejmListView ("option", "enableCache");			
            * // Set the enableCache API
            * $("#lb").ejmListView ("option", "enableCache", true);
            * &lt;/script&gt;
            * @memberof ejmListView
            * @instance
            */
            enableCache: false,
            /**		
            * Specifies to maintain the current model value to browser cookies for state maintenance. While refresh the page, the model value will get apply to the control from browser cookies.
            * @default false
            * @member enablePersistence {object}
            * @type {boolean}
            * @example 
            * //Set the enablePersistence property in obtrusive way.
            * &lt;div id="lb"&gt;
            *	 &lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * // Set enablePersistence on initialization. 
            * //To set enablePersistence API value 
            * $("#lb").ejListView ({ enablePersistence: true });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set  enablePersistence, after initialization:<br>
            * // Get the enablePersistence API value.		
            *  $("#lb").ejListView ("option", "enablePersistence");			
            * // Set the enablePersistence API
            * $("#lb").ejListView ("option", "enablePersistence", true);
            * &lt;/script&gt;
            * @memberof ejListView
            * @instance
            */
            //Mobile
            /**		
            * Specifies to maintain the current model value to browser cookies for state maintenance. While refresh the page, the model value will get apply to the control from browser cookies.
            * @default false
            * @member enablePersistence {object}
            * @type {boolean}
            * @example 
            * //Set the enablePersistence property in unobtrusive way.
            * &lt;div id="lb" data-role="ejmlistview" data-ej-enablepersistence=true &gt;
            *	 &lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * //Set the enablePersistence property in obtrusive way.
            * &lt;div id="lb"&gt;
            *	 &lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * // Set enablePersistence on initialization. 
            * //To set enablePersistence API value 
            * $("#lb").ejmListView ({ enablePersistence: true });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set  enablePersistence, after initialization:<br>
            * // Get the enablePersistence API value.		
            *  $("#lb").ejmListView ("option", "enablePersistence");			
            * // Set the enablePersistence API
            * $("#lb").ejmListView ("option", "enablePersistence", true);
            * &lt;/script&gt;
            * @memberof ejmListView
            * @instance
            */
            enablePersistence: false,
            //Events
            /**    
            * Event triggers before the items loaded.
            * @event
            * @name ejListView#load	
            * @param {Object} argument Event parameters from listview.
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @example 
            * //load event for ListView
            * &lt;div id="lb" &gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(document).ready(function(){
            * $("#lb").ejListView({
            *   	load: function (args) { //handle the event 
            * }
            *	});         
            * });
            * &lt;/script&gt;
            * @memberof ejListView
            * @instance
            */
            //Mobile
            /**    
            * Event triggers before the items loaded.
            * @event
            * @name ejmListView#load	
            * @param {Object} argument Event parameters from listview.
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @example 
            * //Set the load property in unobtrusive way.
            * &lt;div id="lb" data-role="ejmlistview" data-ej-load="load"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * //load event for ListView
            * &lt;div id="lb" data-role="ejmlistview"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(document).ready(function(){
            * $("#lb").ejmListView({
            *   	load: function (args) { //handle the event 
            * }
            *	});         
            * });
            * &lt;/script&gt;
            * @memberof ejmListView
            * @instance
            */
            load: null,
            /**    
            * Event triggers after the items loaded.
            * @event
            * @name ejListView#loadComplete	
            * @param {Object} argument Event parameters from listview.
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @example 
            * //loadComplete event for ListView
            * &lt;div id="lb" &gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(document).ready(function(){
            * $("#lb").ejListView({
            *   	loadComplete: function (args) { //handle the event 
            * }
            *	});         
            * });
            * &lt;/script&gt;
            * @memberof ejListView
            * @instance
            */
            //Mobile
            /**    
            * Event triggers after the items loaded.
            * @event
            * @name ejmListView#loadComplete	
            * @param {Object} argument Event parameters from listview.
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @example 
            * //Set the loadComplete property in unobtrusive way.
            * &lt;div id="lb" data-role="ejmlistview" data-ej-loadComplete="loadComplete"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * //loadComplete event for ListView
            * &lt;div id="lb" data-role="ejmlistview"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(document).ready(function(){
            * $("#lb").ejmListView({
            *   	loadComplete: function (args) { //handle the event 
            * }
            *	});         
            * });
            * &lt;/script&gt;
            * @memberof ejmListView
            * @instance
            */
            loadComplete: null,
            /**    
            * Event triggers before the ajax request happens.
            * @event
            * @name ejListView#ajaxBeforeLoad	
            * @param {Object} argument Event parameters from listview.
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @param {Object} argument.ajaxData returns the ajax settings.
            * @example 
            * //ajaxBeforeLoad event for ListView
            * &lt;div id="lb" &gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Man of Steel" data-ej-href="load1.html" &gt;&lt;/li&gt;
            *		&lt;li data-ej-text="World War Z" data-ej-href="load2.html" &gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Monsters University" data-ej-href="load3.html" &gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(document).ready(function(){            
            * $("#lb").ejListView({enableAjax: true,
            *   	ajaxBeforeLoad: function (args) { //handle the event 
            * }
            *	});           
            * });
            * &lt;/script&gt;
            * @memberof ejListView
            * @instance
            */
            //Mobile
            /**    
            * Event triggers before the ajax request happens.
            * @event
            * @name ejmListView#ajaxBeforeLoad	
            * @param {Object} argument Event parameters from listview.
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @param {Object} argument.ajaxData returns the ajax settings.
            * @example 
            * //Set the ajaxBeforeLoad property in unobtrusive way.
            * &lt;div id="lb" data-role="ejmlistview" data-ej-ajaxBeforeLoad="ajaxBeforeLoad"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Man of Steel" data-ej-href="load1.html" data-ej-enableajax="true"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="World War Z" data-ej-href="load2.html" data-ej-enableajax="true"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Monsters University" data-ej-href="load3.html" data-ej-enableajax="true"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * //ajaxBeforeLoad event for ListView
            * &lt;div id="lb" data-role="ejmlistview"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Man of Steel" data-ej-href="load1.html" data-ej-enableajax="true"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="World War Z" data-ej-href="load2.html" data-ej-enableajax="true"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Monsters University" data-ej-href="load3.html" data-ej-enableajax="true"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(document).ready(function(){
            * $("#lb").ejmListView({
            *   	ajaxBeforeLoad: function (args) { //handle the event 
            * }
            *	});           
            * });
            * &lt;/script&gt;
            * @memberof ejmListView
            * @instance
            */
            ajaxBeforeLoad: null,
            /**    
            * Event triggers after the ajax content loaded successfully.
            * @event
            * @name ejListView#ajaxSuccess
            * @param {Object} argument Event parameters from listview.
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @param {string}  argument.content returns the ajax current content.
            * @param {object}  argument.item returns the curent list item.
            * @param {string}  argument.text returns the current item text.
            * @param {number}  argument.index returns the current item index.
            * @param {string}  argument.url returns the current url of the ajax post.
            * @example 
            * //ajaxSuccess event for ListView
            * &lt;div id="lb" &gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Man of Steel" data-ej-href="load1.html" &gt;&lt;/li&gt;
            *		&lt;li data-ej-text="World War Z" data-ej-href="load2.html" &gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Monsters University" data-ej-href="load3.html" &gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(document).ready(function(){            
            * $("#lb").ejListView({enableAjax: true,
            *   	ajaxSuccess: function (args) { //handle the event 
            * }
            *	});         
            * });
            * &lt;/script&gt;
            * @memberof ejListView
            * @instance
            */
            //Mobile
            /**    
            * Event triggers after the ajax content loaded successfully.
            * @event
            * @name ejmListView#ajaxSuccess
            * @param {Object} argument Event parameters from listview.
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @param {string}  argument.content returns the ajax current content.
            * @param {object}  argument.item returns the curent list item.
            * @param {string}  argument.text returns the current item text.
            * @param {number}  argument.index returns the current item index.
            * @param {string}  argument.url returns the current url of the ajax post.
            * @example 
            * //Set the ajaxSuccess property in unobtrusive way.
            * &lt;div id="lb" data-role="ejmlistview" data-ej-ajaxSuccess="ajaxSuccess"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Man of Steel" data-ej-href="load1.html" data-ej-enableajax="true"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="World War Z" data-ej-href="load2.html" data-ej-enableajax="true"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Monsters University" data-ej-href="load3.html" data-ej-enableajax="true"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * //ajaxSuccess event for ListView
            * &lt;div id="lb" data-role="ejmlistview"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Man of Steel" data-ej-href="load1.html" data-ej-enableajax="true"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="World War Z" data-ej-href="load2.html" data-ej-enableajax="true"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Monsters University" data-ej-href="load3.html" data-ej-enableajax="true"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(document).ready(function(){
            * $("#lb").ejmListView({
            *   	ajaxSuccess: function (args) { //handle the event 
            * }
            *	});         
            * });
            * &lt;/script&gt;
            * @memberof ejmListView
            * @instance
            */
            ajaxSuccess: null,
            /**    
            * Event triggers when the ajax request failed.
            * @event
            * @name ejListView#ajaxError	
            * @param {Object} argument Event parameters from listview.
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @param {Object} argument.errorThrown returns the error thrown in the ajax post.
            * @param {Object} argument.textStatus returns the status.
            * @param {object} argument.item returns the curent list item.
            * @param {string} argument.text returns the current item text.
            * @param {number} argument.index returns the current item index.            
            * @example 
            * //ajaxError event for ListView
            * &lt;div id="lb" &gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Man of Steel" data-ej-href="load1.html" &gt;&lt;/li&gt;
            *		&lt;li data-ej-text="World War Z" data-ej-href="load2.html" &gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Monsters University" data-ej-href="load3.html" &gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(document).ready(function(){            
            * $("#lb").ejListView({enableAjax: true,
            *   	ajaxError: function (args) { //handle the event 
            * }
            *	});         
            * });
            * &lt;/script&gt;
            * @memberof ejListView
            * @instance
            */
            //Mobile
            /**    
            * Event triggers when the ajax request failed.
            * @event
            * @name ejmListView#ajaxError	
            * @param {Object} argument Event parameters from listview.
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @param {Object} argument.errorThrown returns the error thrown in the ajax post.
            * @param {Object} argument.textStatus returns the status.
            * @param {object} argument.item returns the curent list item.
            * @param {string} argument.text returns the current item text.
            * @param {number} argument.index returns the current item index.
            * @example 
            * //Set the ajaxError property in unobtrusive way.
            * &lt;div id="lb" data-role="ejmlistview" data-ej-ajaxError="ajaxError"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Man of Steel" data-ej-href="load1.html" data-ej-enableajax="true"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="World War Z" data-ej-href="load2.html" data-ej-enableajax="true"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Monsters University" data-ej-href="load3.html" data-ej-enableajax="true"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * //ajaxError event for ListView
            * &lt;div id="lb" data-role="ejmlistview"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Man of Steel" data-ej-href="load1.html" data-ej-enableajax="true"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="World War Z" data-ej-href="load2.html" data-ej-enableajax="true"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Monsters University" data-ej-href="load3.html" data-ej-enableajax="true"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(document).ready(function(){
            * $("#lb").ejmListView({
            *   	ajaxError: function (args) { //handle the event 
            * }
            *	});         
            * });
            * &lt;/script&gt;
            * @memberof ejmListView
            * @instance
            */
            ajaxError: null,
            /**    
            * Event triggers after the ajax content loaded completely.
            * @event
            * @name ejListView#ajaxComplete	
            * @param {Object} argument Event parameters from listview.
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.           
            * @example 
            * //ajaxComplete event for ListView
            * &lt;div id="lb" &gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Man of Steel" data-ej-href="load1.html" &gt;&lt;/li&gt;
            *		&lt;li data-ej-text="World War Z" data-ej-href="load2.html" &gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Monsters University" data-ej-href="load3.html" &gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(document).ready(function(){            
            * $("#lb").ejListView({enableAjax: true,
            *   	ajaxComplete: function (args) { //handle the event 
            * }
            *	});         
            * });
            * &lt;/script&gt;
            * @memberof ejListView
            * @instance
            */
            //Mobile
            /**    
            * Event triggers after the ajax content loaded completely.
            * @event
            * @name ejmListView#ajaxComplete	
            * @param {Object} argument Event parameters from listview.
            * @param {boolean} argument.cancel returns true if the event should be cancelled; otherwise, false.
            * @param {string} argument.type returns the name of the event.
            * @param {Object} argument.model returns the model value of the control.
            * @example 
            * //Set the ajaxComplete property in unobtrusive way.
            * &lt;div id="lb" data-role="ejmlistview" data-ej-ajaxComplete="ajaxComplete"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Man of Steel" data-ej-href="load1.html" data-ej-enableajax="true"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="World War Z" data-ej-href="load2.html" data-ej-enableajax="true"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Monsters University" data-ej-href="load3.html" data-ej-enableajax="true"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * //ajaxComplete event for ListView
            * &lt;div id="lb" data-role="ejmlistview" &gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Man of Steel" data-ej-href="load1.html" data-ej-enableajax="true"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="World War Z" data-ej-href="load2.html" data-ej-enableajax="true"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Monsters University" data-ej-href="load3.html" data-ej-enableajax="true"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * $(document).ready(function(){
            * $("#lb").ejmListView({
            *   	ajaxComplete: function (args) { //handle the event 
            * }
            *	});         
            * });
            * &lt;/script&gt;
            * @memberof ejmListView
            * @instance
            */
            ajaxComplete: null,
            /**		
            * Specifies the settings option for ajax request.
            * @type {JSONObject}  
            * @example 
            * //Set ajaxSettings in obtrusive way
            * &lt;div id="lb" &gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Man of Steel" data-ej-href="load1.html" &gt;&lt;/li&gt;
            *		&lt;li data-ej-text="World War Z" data-ej-href="load2.html" &gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Monsters University" data-ej-href="load3.html" &gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * // Set Tab ajaxSettings on initialization. 
            * //To set ajaxSettings API value 
            * &lt;script&gt;            
            * $("#lb").ejListView({ enableAjax: true,ajaxSettings: { type: 'GET',
            *   cache: false,
            *   async: true,
            *   dataType: "html",
            *   contentType: "html"
            *   } });		
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set the ListView ajaxSettings, after initialization:<br>
            * // Get the ajaxSettings API value.
            * $("#lb").ejListView ("option", "ajaxSettings");			
            * // Set the ajaxSettings API
            * $("#lb").ejListView ("option", "ajaxSettings", { type: 'GET',cache: false,async: true,dataType: "html",contentType: "html",url: "",data: {}});        
            * &lt;/script&gt;    
            * @memberof ejListView
            * @instance				
            */
            //Mobile
            /**		
            * Specifies the settings option for ajax request.
            * @type {JSONObject}  
            * @example 
            * //Set ajaxSettings in unobtrusive way
            * &lt;div id="lb" data-role="ejmlistview" data-ej-ajaxsettings-type="GET" data-ej-ajaxsettings-cache=false data-ej-ajaxsettings-async=true
            * data-ej-ajaxsettings-datatype="html" data-ej-ajaxsettings-contenttype="html" &gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Man of Steel" data-ej-href="load1.html" data-ej-enableajax="true"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="World War Z" data-ej-href="load2.html" data-ej-enableajax="true"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Monsters University" data-ej-href="load3.html" data-ej-enableajax="true"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;          
            * @example 
            * //Set ajaxSettings in obtrusive way
            * &lt;div id="lb" &gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Man of Steel" data-ej-href="load1.html" data-ej-enableajax="true"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="World War Z" data-ej-href="load2.html" data-ej-enableajax="true"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Monsters University" data-ej-href="load3.html" data-ej-enableajax="true"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * // Set Tab ajaxSettings on initialization. 
            * //To set ajaxSettings API value 
            * &lt;script&gt;
            * $("#lb").ejmListView({ ajaxSettings: { type: 'GET',
            *   cache: false,
            *   async: true,
            *   dataType: "html",
            *   contentType: "html"
            *   } });		
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set the ListView ajaxSettings, after initialization:<br>
            * // Get the ajaxSettings API value.
            * $("#lb").ejmListView ("option", "ajaxSettings");			
            * // Set the ajaxSettings API
            * $("#lb").ejmListView ("option", "ajaxSettings", { type: 'GET',cache: false,async: true,dataType: "html",contentType: "html",url: "",data: {}});        
            * &lt;/script&gt;    
            * @memberof ejmListView
            * @instance				
            */
            ajaxSettings: {
                type: 'GET',
                cache: false,
                async: true,
                dataType: "html",
                contentType: "html",
                url: "",
                data: {}
            },
            /**		
            * Specifies whether need to render the control with the template contents.
            * @default false
            * @member renderTemplate {object}
            * @type {boolean}
            * @example 
            * //Set the renderTemplate property in obtrusive way.
            * &lt;div id="lb"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-templateid="target1"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-templateid="target2"&gt;&lt;/li&gt;
            *		&lt;li data-ej-templateid="target3"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;div id="target1"&gt;
            *	&lt;div&gt Template1 &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="target2"&gt;
            *	&lt;div&gt Template2 &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="target3"&gt;
            *	&lt;div&gt Template3 &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * // Set renderTemplate on initialization. 
            * //To set renderTemplate API value 
            * $("#lb").ejListView ({ renderTemplate: true });
            * &lt;/script&gt;
            * @memberof ejListView
            * @instance
            */
            //Mobile
            /**		
            * Specifies whether need to render the control with the template contents.
            * @default false
            * @member renderTemplate {object}
            * @type {boolean}
            * @example 
            * //Set the renderTemplate property in unobtrusive way.
            * &lt;div id="lb" data-role="ejmlistview"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-rendertemplate=true data-ej-templateid="target1"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-rendertemplate=true data-ej-templateid="target2"&gt;&lt;/li&gt;
            *		&lt;li data-ej-rendertemplate=true data-ej-templateid="target3"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;div id="target1"&gt;
            *	&lt;div&gt Template1 &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="target2"&gt;
            *	&lt;div&gt Template2 &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="target3"&gt;
            *	&lt;div&gt Template3 &lt;/div&gt;
            * &lt;/div&gt;            
            * @memberof ejmListView
            * @instance
            */
            renderTemplate: false,
            /**		
            * Specifies ID of the element contains template contents.
            * @default false
            * @member templateId {object}
            * @type {boolean}
            * @example 
            * //Set the templateId property in unobtrusive way.
            * &lt;div id="lb" data-role="ejlistview"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-rendertemplate=true data-ej-templateid="target1"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-rendertemplate=true data-ej-templateid="target2"&gt;&lt;/li&gt;
            *		&lt;li data-ej-rendertemplate=true data-ej-templateid="target3"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;div id="target1"&gt;
            *	&lt;div&gt Template1 &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="target2"&gt;
            *	&lt;div&gt Template2 &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="target3"&gt;
            *	&lt;div&gt Template3 &lt;/div&gt;
            * &lt;/div&gt;
            * @memberof ejListView
            * @instance
            */
            //Mobile
            /**		
            * Specifies ID of the element contains template contents.
            * @default false
            * @member templateId {object}
            * @type {boolean}
            * @example 
            * //Set the templateId property in unobtrusive way.
            * &lt;div id="lb" data-role="ejmlistview"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-rendertemplate=true data-ej-templateid="target1"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-rendertemplate=true data-ej-templateid="target2"&gt;&lt;/li&gt;
            *		&lt;li data-ej-rendertemplate=true data-ej-templateid="target3"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;div id="target1"&gt;
            *	&lt;div&gt Template1 &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="target2"&gt;
            *	&lt;div&gt Template2 &lt;/div&gt;
            * &lt;/div&gt;
            * &lt;div id="target3"&gt;
            *	&lt;div&gt Template3 &lt;/div&gt;
            * &lt;/div&gt;
            * @memberof ejmListView
            * @instance
            */
            templateId: null,
            /**		
            * Specifies whether to retain the selection of the item.
            * @default false
            * @member persistSelection {object}
            * @type {boolean}           
            * @example 
            * //Set the persistSelection property in obtrusive way.
            * &lt;div id="lb"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * // Set persistSelection on initialization. 
            * //To set persistSelection API value 
            * $("#lb").ejListView ({ persistSelection: true });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set the ListView persistSelection, after initialization:<br>
            * // Get the persistSelection API value.		
            * $("#lb").ejListView ("option", "persistSelection");			
            * // Set the persistSelection API
            * $("#lb").ejListView ("option", "persistSelection", true);
            * &lt;/script&gt;
            * @memberof ejListView
            * @instance
            */
            //Mobile
            /**		
            * Specifies whether to retain the selection of the item.
            * @default false
            * @member persistSelection {object}
            * @type {boolean}
            * @example 
            * //Set the persistSelection property in unobtrusive way.
            * &lt;div id="lb" data-role="ejmlistview" data-ej-persistSelection="true"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * //Set the persistSelection property in obtrusive way.
            * &lt;div id="lb"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * // Set persistSelection on initialization. 
            * //To set persistSelection API value 
            * $("#lb").ejmListView ({ persistSelection: true });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set the ListView persistSelection, after initialization:<br>
            * // Get the persistSelection API value.		
            * $("#lb").ejmListView ("option", "persistSelection");			
            * // Set the persistSelection API
            * $("#lb").ejmListView ("option", "persistSelection", true);
            * &lt;/script&gt;
            * @memberof ejmListView
            * @instance
            */
            persistSelection: false,
            /**		
            * Specifies whether to prevent the selection of the item.
            * @default false
            * @member preventSelection {object}
            * @type {boolean}
            * @example 
            * //Set the preventSelection property in obtrusive way.
            * &lt;div id="lb"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * // Set preventSelection on initialization. 
            * //To set preventSelection API value 
            * $("#lb").ejListView ({ preventSelection: true });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set the ListView preventSelection, after initialization:<br>
            * // Get the preventSelection API value.		
            * $("#lb").ejListView ("option", "preventSelection");			
            * // Set the preventSelection API
            * $("#lb").ejListView ("option", "preventSelection", true);
            * &lt;/script&gt;
            * @memberof ejListView
            * @instance
            */
            //Mobile
            /**		
            * Specifies whether to prevent the selection of the item.
            * @default false
            * @member preventSelection {object}
            * @type {boolean}
            * @example 
            * //Set the preventSelection property in unobtrusive way.
            * &lt;div id="lb" data-role="ejmlistview" data-ej-preventSelection="true"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * //Set the preventSelection property in obtrusive way.
            * &lt;div id="lb"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * // Set preventSelection on initialization. 
            * //To set preventSelection API value 
            * $("#lb").ejmListView ({ preventSelection: true });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set the ListView preventSelection, after initialization:<br>
            * // Get the preventSelection API value.		
            * $("#lb").ejmListView ("option", "preventSelection");			
            * // Set the preventSelection API
            * $("#lb").ejmListView ("option", "preventSelection", true);
            * &lt;/script&gt;
            * @memberof ejmListView
            * @instance
            */
            preventSelection: false,
            /**		
            * Specifies the datasource is enabled.
            * @default []
            * @member dataSource {object}
            * @type {JSONArray}
            * @example 
            * //Set the dataSource property in obtrusive way.
            * &lt;div id="lb" &gt;
            * &lt;/div&gt;           
            * &lt;script&gt;
            * $(function(){
            * $("#lb").ejListView({dataSource:window.dbitem});
            * });
            * window.dbitem =
            * [   { "text": "Hot Singles"},
            *     { "text": "Rising Artists"},
            *     { "text": "Live Music" },
            *     { "text": "Best of 2013 So Far"},
            *     { "text": "100 Albums - $5 Each"},
            *     { "text": "Hip-Hop and R&B Sale"},
            *     { "text": "CD Deals"}];
            * &lt;/script&gt;  
            * @example       
            * &lt;script&gt;
            * //Get or set  dataSource, after initialization:<br>
            * // Get the dataSource API value.		
            * $("#lb").ejListView ("option", "dataSource");			
            * // Set the dataSource API
            * $("#lb").ejListView ("option", "dataSource", true);   
            * &lt;/script&gt;                     
            * @memberof ejListView
            * @instance
            */
            //Mobile
            /**		
            * Specifies the datasource is enabled.
            * @default []
            * @member dataSource {object}
            * @type {JSONArray}
            * @example 
            * //Set the dataSource property in unobtrusive way.
            * &lt;div id="lb" data-role="ejmlistview" data-ej-datasource="window.dbitem"&gt;
            * &lt;/div&gt;           
            * &lt;script&gt;
            * window.dbitem =
            * [   { "text": "Hot Singles"},
            *     { "text": "Rising Artists"},
            *     { "text": "Live Music" },
            *     { "text": "Best of 2013 So Far"},
            *     { "text": "100 Albums - $5 Each"},
            *     { "text": "Hip-Hop and R&B Sale"},
            *     { "text": "CD Deals"}];
            * &lt;/script&gt; 
            * @example 
            * //Set the dataSource property in obtrusive way.
            * &lt;div id="lb" &gt;
            * &lt;/div&gt;           
            * &lt;script&gt;
            * $(function(){
            * $("#lb").ejmListView({dataSource:window.dbitem});
            * });
            * window.dbitem =
            * [   { "text": "Hot Singles"},
            *     { "text": "Rising Artists"},
            *     { "text": "Live Music" },
            *     { "text": "Best of 2013 So Far"},
            *     { "text": "100 Albums - $5 Each"},
            *     { "text": "Hip-Hop and R&B Sale"},
            *     { "text": "CD Deals"}];
            * &lt;/script&gt;  
            * @example       
            * &lt;script&gt;
            * //Get or set  dataSource, after initialization:<br>
            * // Get the dataSource API value.		
            * $("#lb").ejmListView ("option", "dataSource");			
            * // Set the dataSource API
            * $("#lb").ejmListView ("option", "dataSource", true);   
            * &lt;/script&gt;                     
            * @memberof ejmListView
            * @instance
            */
            dataSource: [],
            /**		
            * Specifies the query to execute with the datasource.
            * @default null
            * @member query {object}
            * @type {ej.Query}
            * @example 
            * //Set the query property in obtrusive way.
            * &lt;div id="lb" &gt;
            * &lt;/div&gt;            
            * &lt;script&gt;            
            *		// DataManager creation
            *		window.datasource = ej.DataManager({
            *   	url: "http://mvc.syncfusion.com/Services/Northwnd.svc/"
            *		});
            *		window.dbitem = { "text": "ShipCity" };   
            * $(function(){
            * $("#lb").ejListView({fieldSettings:"window.dbitem",dataSource:"window.datasource",query:"ej.Query().from('Orders').select('ShipCity').take(5)"});
            * });         
            * &lt;/script&gt;
            * @example        
            * &lt;script&gt;  
            * //Get or set  query, after initialization:<br>
            * // Get the query API value.		
            * $("#lb").ejListView ("option", "query");			
            * // Set the query API
            * $("#lb").ejListView ("option", "query", true);  
            * &lt;/script&gt;
            * @memberof ejListView
            * @instance
            */
            //Mobile
            /**		
            * Specifies the query to execute with the datasource.
            * @default null
            * @member query {object}
            * @type {ej.Query}
            * @example 
            * //Set the query property in unobtrusive way.
            * &lt;div id="lb" data-role="ejmlistview" data-ej-fieldSettings="window.dbitem" data-ej-datasource="window.datasource" 
            * data-ej-query="ej.Query().from('Orders').select('ShipCity').take(5)"&gt;
            * &lt;/div&gt;            
            * &lt;script&gt;            
            *		// DataManager creation
            *		window.datasource = ej.DataManager({
            *   	url: "http://mvc.syncfusion.com/Services/Northwnd.svc/"
            *		});
            *		window.dbitem = { "text": "ShipCity" };            
            * &lt;/script&gt;
            * @example 
            * //Set the query property in obtrusive way.
            * &lt;div id="lb" &gt;
            * &lt;/div&gt;            
            * &lt;script&gt;            
            *		// DataManager creation
            *		window.datasource = ej.DataManager({
            *   	url: "http://mvc.syncfusion.com/Services/Northwnd.svc/"
            *		});
            *		window.dbitem = { "text": "ShipCity" };   
            * $(function(){
            * $("#lb").ejmListView({fieldSettings:"window.dbitem",dataSource:"window.datasource",query:"ej.Query().from('Orders').select('ShipCity').take(5)"});
            * });         
            * &lt;/script&gt;
            * @example        
            * &lt;script&gt;  
            * //Get or set  query, after initialization:<br>
            * // Get the query API value.		
            * $("#lb").ejmListView ("option", "query");			
            * // Set the query API
            * $("#lb").ejmListView ("option", "query", true);  
            * &lt;/script&gt;
            * @memberof ejmListView
            * @instance
            */
            query: null,
            /**		
            * Specifies whether to show the header.
            * @default true
            * @member showHeader {object}
            * @type {boolean}
            * @example 
            * //Set the showHeader property in obtrusive way.
            * &lt;div id="lb"&gt;
            *	 &lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * // Set showHeader on initialization. 
            * //To set showHeader API value 
            * $("#lb").ejListView ({ showHeader: true });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set  showHeader, after initialization:<br>
            * // Get the showHeader API value.		
            *  $("#lb").ejListView ("option", "showHeader");			
            * // Set the showHeader API
            * $("#lb").ejListView ("option", "showHeader", true);  
            * &lt;/script&gt;          
            * @memberof ejListView
            * @instance
            */
            //Mobile
            /**		
            * Specifies whether to show the header.
            * @default false
            * @member showHeader {object}
            * @type {boolean}
            * @example 
            * //Set the showHeader property in unobtrusive way.
            * &lt;div id="lb" data-role="ejmlistview" data-ej-showHeader="true"&gt;
            *	 &lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * //Set the showHeader property in obtrusive way.
            * &lt;div id="lb"&gt;
            *	 &lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * // Set showHeader on initialization. 
            * //To set showHeader API value 
            * $("#lb").ejmListView ({ showHeader: true });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set  showHeader, after initialization:<br>
            * // Get the showHeader API value.		
            *  $("#lb").ejmListView ("option", "showHeader");			
            * // Set the showHeader API
            * $("#lb").ejmListView ("option", "showHeader", true);  
            * &lt;/script&gt;          
            * @memberof ejmListView
            * @instance
            */
            showHeader: false,
            /**		
            * Specifies the title of the header.
            * @default Title
            * @member headerTitle {object}
            * @type {string}
            * @example 
            * //Set the headerTitle property in obtrusive way.
            * &lt;div id="lb" &gt;
            *	 &lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * // Set headerTitle on initialization. 
            * //To set headerTitle API value 
            * $("#lb").ejListView ({ headerTitle: "Title" });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set  headerTitle, after initialization:<br>
            * // Get the headerTitle API value.		
            *  $("#lb").ejListView ("option", "headerTitle");			
            * // Set the headerTitle API
            * $("#lb").ejListView ("option", "headerTitle", "Title");
            * &lt;/script&gt;
            * @memberof ejListView
            * @instance
            */
            //Mobile
            /**		
            * Specifies the title of the header.
            * @default Title
            * @member headerTitle {object}
            * @type {string}
            * @example 
            * //Set the headerTitle property in unobtrusive way.
            * &lt;div id="lb" data-role="ejmlistview" data-ej-headerTitle="Title"&gt;
            *	 &lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * //Set the headerTitle property in obtrusive way.
            * &lt;div id="lb" &gt;
            *	 &lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * // Set headerTitle on initialization. 
            * //To set headerTitle API value 
            * $("#lb").ejmListView ({ headerTitle: "Title" });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set  headerTitle, after initialization:<br>
            * // Get the headerTitle API value.		
            *  $("#lb").ejmListView ("option", "headerTitle");			
            * // Set the headerTitle API
            * $("#lb").ejmListView ("option", "headerTitle", "Title");
            * &lt;/script&gt;
            * @memberof ejmListView
            * @instance
            */
            headerTitle: "Title",
            /**		
            * Specifies the text of the back button in the header.
            * @default null
            * @member headerBackButtonText {object}
            * @type {string}
            * @example 
            * //Set the headerBackButtonText property in obtrusive way.
            * &lt;div id="lb" &gt;
            *	 &lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * // Set headerBackButtonText on initialization. 
            * //To set headerBackButtonText API value 
            * $("#lb").ejListView ({showHeader: true,showHeaderBackButton:true, headerBackButtonText: "Back" });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set  headerBackButtonText, after initialization:<br>
            * // Get the headerBackButtonText API value.		
            *  $("#lb").ejListView ("option", "headerBackButtonText");			
            * // Set the headerBackButtonText API
            * $("#lb").ejListView ("option", "headerBackButtonText", "Back");
            * &lt;/script&gt;
            * @memberof ejListView
            * @instance
            */
            //Mobile
            /**		
            * Specifies the text of the back button in the header.
            * @default undefined
            * @member headerBackButtonText {object}
            * @type {string}
            * @example 
            * //Set the headerBackButtonText property in unobtrusive way.
            * &lt;div id="lb" data-role="ejmlistview" data-ej-showHeaderBackButton="true" data-ej-headerBackButtonText="Back"&gt;
            *	 &lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * //Set the headerBackButtonText property in obtrusive way.
            * &lt;div id="lb" &gt;
            *	 &lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            * 	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * // Set headerBackButtonText on initialization. 
            * //To set headerBackButtonText API value 
            * $("#lb").ejmListView ({ showHeader: true,showHeaderBackButton:true,headerBackButtonText: "Back" });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set  headerBackButtonText, after initialization:<br>
            * // Get the headerBackButtonText API value.		
            *  $("#lb").ejmListView ("option", "headerBackButtonText");			
            * // Set the headerBackButtonText API
            * $("#lb").ejmListView ("option", "headerBackButtonText", "Back");
            * &lt;/script&gt;
            * @memberof ejmListView
            * @instance
            */
            headerBackButtonText: null,
            /**		
            * Specifies the field settings to map the datasource.
            * @type {JSONArray}
            * @member fieldSettings {object}
            * @example 
            * //Set the fieldSettings property in obtrusive way.
            * &lt;div id="lb" &gt;
            * &lt;/div&gt;           
            * &lt;script&gt;
            * window.dbitem =
            * [{ "Texts": "Discover Music", "PrimaryKeys": "1" },
            *     { "Texts": "Hot Singles", "ParentPrimaryKeyss": "1" },
            *     { "Texts": "Rising Artists", "PrimaryKeyss": null, "ParentPrimaryKeyss": "1" },
            *     { "Texts": "Live Music", "ParentPrimaryKeyss": "1" },
            *     { "Texts": "Best of 2013 So Far", "ParentPrimaryKeyss": "1" },
            *{ "Texts": "Sales and Events", "PrimaryKeys": "2" },
            *     { "Texts": "100 Albums - $5 Each", "ParentPrimaryKeyss": "2" },
            *     { "Texts": "Hip-Hop and R&B Sale", "ParentPrimaryKeyss": "2" },
            *     { "Texts": "CD Deals", "ParentPrimaryKeyss": "2" }];
            * window.musicFields = {
            * "href": "Hrefs",
            * "text": "Texts",
            * "primaryKey": "PrimaryKeys",
            * "parentPrimaryKey": "ParentPrimaryKeyss"
            * };
            * $(function(){
            * $("#lb").ejListView({fieldSettings:"window.musicFields",dataSource:"window.dbitem"});
            * });
            * &lt;/script&gt;
            * @example         
            * &lt;script&gt;
            * //Get or set  fieldSettings, after initialization:<br>
            * // Get the fieldSettings API value.		
            * $("#lb").ejListView ("option", "fieldSettings");			
            * // Set the fieldSettings API
            * $("#lb").ejListView ("option", "fieldSettings", true); 
            * &lt;/script&gt; 
            * @memberof ejListView
            * @instance
            */
            //Mobile
            /**		
            * Specifies the field settings to map the datasource.
            * @member fieldSettings {object}
            * @type {JSONArray}
            * @example 
            * //Set the fieldSettings property in unobtrusive way.
            * &lt;div id="lb" data-role="ejmlistview" data-ej-fieldSettings="window.musicFields" data-ej-datasource="window.dbitem" &gt;
            * &lt;/div&gt;           
            * &lt;script&gt;
            * window.dbitem =
            * [{ "Texts": "Discover Music", "PrimaryKeys": "1" },
            *     { "Texts": "Hot Singles", "ParentPrimaryKeyss": "1" },
            *     { "Texts": "Rising Artists", "PrimaryKeyss": null, "ParentPrimaryKeyss": "1" },
            *     { "Texts": "Live Music", "ParentPrimaryKeyss": "1" },
            *     { "Texts": "Best of 2013 So Far", "ParentPrimaryKeyss": "1" },
            *{ "Texts": "Sales and Events", "PrimaryKeys": "2" },
            *     { "Texts": "100 Albums - $5 Each", "ParentPrimaryKeyss": "2" },
            *     { "Texts": "Hip-Hop and R&B Sale", "ParentPrimaryKeyss": "2" },
            *     { "Texts": "CD Deals", "ParentPrimaryKeyss": "2" }];
            * window.musicFields = {
            * "href": "Hrefs",
            * "text": "Texts",
            * "primaryKey": "PrimaryKeys",
            * "parentPrimaryKey": "ParentPrimaryKeyss"
            * };
            * &lt;/script&gt;
            * @example 
            * //Set the fieldSettings property in obtrusive way.
            * &lt;div id="lb" &gt;
            * &lt;/div&gt;           
            * &lt;script&gt;
            * window.dbitem =
            * [{ "Texts": "Discover Music", "PrimaryKeys": "1" },
            *     { "Texts": "Hot Singles", "ParentPrimaryKeyss": "1" },
            *     { "Texts": "Rising Artists", "PrimaryKeyss": null, "ParentPrimaryKeyss": "1" },
            *     { "Texts": "Live Music", "ParentPrimaryKeyss": "1" },
            *     { "Texts": "Best of 2013 So Far", "ParentPrimaryKeyss": "1" },
            *{ "Texts": "Sales and Events", "PrimaryKeys": "2" },
            *     { "Texts": "100 Albums - $5 Each", "ParentPrimaryKeyss": "2" },
            *     { "Texts": "Hip-Hop and R&B Sale", "ParentPrimaryKeyss": "2" },
            *     { "Texts": "CD Deals", "ParentPrimaryKeyss": "2" }];
            * window.musicFields = {
            * "href": "Hrefs",
            * "text": "Texts",
            * "primaryKey": "PrimaryKeys",
            * "parentPrimaryKey": "ParentPrimaryKeyss"
            * };
            * $(function(){
            * $("#lb").ejmListView({fieldSettings:"window.musicFields",dataSource:"window.dbitem"});
            * });
            * &lt;/script&gt;
            * @example         
            * &lt;script&gt;
            * //Get or set  fieldSettings, after initialization:<br>
            * // Get the fieldSettings API value.		
            * $("#lb").ejmListView ("option", "fieldSettings");			
            * // Set the fieldSettings API
            * $("#lb").ejmListView ("option", "fieldSettings", true); 
            * &lt;/script&gt; 
            * @memberof ejmListView
            * @instance
            */
            fieldSettings: {
                "navigateUrl": "navigateUrl",
                "href": "href",
                "enableAjax": "enableAjax",
                "preventSelection": "preventSelection",
                "persistSelection": "persistSelection",
                "text": "text",
                "enableCheckMark": "enableCheckMark",
                "checked": "checked",
                "primaryKey": "primaryKey",
                "parentPrimaryKey": "parentPrimaryKey",
                "imageClass": "imageClass",
                "imageUrl": "imageUrl",
                "childHeaderTitle": "childHeaderTitle",
                "childId": "childId",
                "childHeaderBackButtonText": "childHeaderBackButtonText",
                "renderTemplate": "renderTemplate",
                "templateId": "templateId",
                "touchStart": "touchStart",
                "touchEnd": "touchEnd",
                "attributes": "attributes"
            },
            /**		
            * Specifies whether to enable the filtering feature to filter the item.
            * @default false
            * @member enableFiltering {object}
            * @type {boolean}
            * @example 
            * //Set the enableFiltering property in obtrusive way.
            * &lt;div id="lb"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * // Set enableFiltering on initialization. 
            * //To set enableFiltering API value 
            * $("#lb").ejListView ({ enableFiltering: true });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set the ListView enableFiltering, after initialization:<br>
            * // Get the enableFiltering API value.		
            * $("#lb").ejListView ("option", "enableFiltering");			
            * // Set the enableFiltering API
            * $("#lb").ejListView ("option", "enableFiltering", true);    
            * &lt;/script&gt;        
            * @memberof ejListView
            * @instance
            */
            //Mobile
            /**		
            * Specifies whether to enable the filtering feature to filter the item.
            * @default false
            * @member enableFiltering {object}
            * @type {boolean}
            * @example 
            * //Set the enableFiltering property in unobtrusive way.
            * &lt;div id="lb" data-role="ejmlistview" data-ej-enableFiltering="true"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * //Set the enableFiltering property in obtrusive way.
            * &lt;div id="lb"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * // Set enableFiltering on initialization. 
            * //To set enableFiltering API value 
            * $("#lb").ejmListView ({ enableFiltering: true });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set the ListView enableFiltering, after initialization:<br>
            * // Get the enableFiltering API value.		
            * $("#lb").ejmListView ("option", "enableFiltering");			
            * // Set the enableFiltering API
            * $("#lb").ejmListView ("option", "enableFiltering", true);    
            * &lt;/script&gt;        
            * @memberof ejmListView
            * @instance
            */
            enableFiltering: false,
            /**		
            * Specifies whether to enable check mark for the item.
            * @default false
            * @member enableCheckMark {object}
            * @type {boolean}
            * @example 
            * //Set the enableCheckMark property in obtrusive way.
            * &lt;div id="lb"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * // Set enableCheckMark on initialization. 
            * //To set enableCheckMark API value 
            * $("#lb").ejListView ({ enableCheckMark: true });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set the ListView enableCheckMark, after initialization:<br>
            * // Get the enableCheckMark API value.		
            * $("#lb").ejListView ("option", "enableCheckMark");			
            * // Set the enableCheckMark API
            * $("#lb").ejListView ("option", "enableCheckMark", true);    
            * &lt;/script&gt;        
            * @memberof ejListView
            * @instance
            */
            /**		
            * Specifies whether to enable check mark for the item.
            * @default false
            * @member enableCheckMark {object}
            * @type {boolean}
            * @example 
            * //Set the enableCheckMark property in unobtrusive way.
            * &lt;div id="lb" data-role="ejmlistview" data-ej-enablecheckmark="true"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * @example 
            * //Set the enableCheckMark property in obtrusive way.
            * &lt;div id="lb"&gt;
            * 	&lt;ul&gt;
            *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
            * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
            *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
            *	&lt;/ul&gt;
            * &lt;/div&gt;
            * &lt;script&gt;
            * // Set enableCheckMark on initialization. 
            * //To set enableCheckMark API value 
            * $("#lb").ejmListView ({ enableCheckMark: true });
            * &lt;/script&gt;
            * @example 
            * &lt;script&gt;
            * //Get or set the ListView enableCheckMark, after initialization:<br>
            * // Get the enableCheckMark API value.		
            * $("#lb").ejmListView ("option", "enableCheckMark");			
            * // Set the enableCheckMark API
            * $("#lb").ejmListView ("option", "enableCheckMark", true);    
            * &lt;/script&gt;        
            * @memberof ejmListView
            * @instance
            */
            enableCheckMark: false


        },

        observables: ["selectedItemIndex", "dataSource"],
        selectedItemIndex: ej.util.valueFunction("selectedItemIndex"),
        dataSource: ej.util.valueFunction("dataSource"),

        //Before loading the list
        /**
        * Section for ListView control before load
        * @private
        */
        _load: function () {
            this._orgEle = this.element.clone();
            this._index = 0;
            this._items = [];
            this._indexVal = 0;
            this.model.id = this.element[0].id;
            if (this.model.load)
                this._trigger("load");
            this.model.fieldSettings = eval(this.model.fieldSettings);
            if (this.model.fieldSettings && this.model.query != null) {
                var proxy = this;
                if (proxy._prefixClass == "e-m-")
                    App.waitingPopUp.show();
                this.dataSource().executeQuery(eval(this.model.query)).done(function (e) {
                    proxy.model.dataSource = e.result;
                    proxy._renderControl();
                    if (proxy._prefixClass == "e-m-")
                        App.waitingPopUp.hide();
                });
            }
            else
                this._renderControl();
        },
        //To render the list control
        /**
        * Render Section for ListView control	
        * @private
        */
        _renderControl: function () {
            this.element.addClass(this._prefixClass + "parentlv ");
            this._lbEle = ej.buildTag("div." + this._rootCSS);
            this._lbEle.addClass("subpage");
            if (this._prefixClass == "e-m-") {
                this._lbEle.addClass("e-m-" + this.model.renderMode + " e-m-" + this.model.theme).addClass(!ej.isMobile() ? "e-m-tablet" : "e-m-mobile");
                if (this.model.ios7.inline)
                    this._lbEle.addClass("e-m-inline")
            }
            this._lContainer = ej.buildTag("div." + this._prefixClass + "list-container#" + this.model.id + "_container");
            var ul = this.element.find(">ul");
            if (this.model.showHeader) {
                var hdr = this._renderHeader(this.model.id, this.model.showHeaderBackButton, this.model.headerTitle, this.model.headerBackButtonText);
                this._lbEle.prepend(hdr);
            }
            if (this._prefixClass == "e-m-")
                if (this.model.allowScrolling)
                    this._renderScrollPanel(this._lbEle, this.model.id + "_scroll", this.model.id + "_container");
            if (this._hasDataSource() && !this.model.renderTemplate)
                this.element.empty();
            if (this.model.renderTemplate) {
                if (this.model.templateId) {
                    if (ej.getCurrentPage().find('#' + this.model.templateId).length) {
                        this._template = ej.getCurrentPage().find('#' + this.model.templateId);
                        ej.destroyWidgets(this._template);
                        this._template.remove();
                        this._template = this._template[0].nodeName && this._template[0].nodeName.toLowerCase() == "script" ? ej.getClearString(this._template[0].innerHTML) : this._template[0].outerHTML;
                    }
                }
                else {
                    ej.destroyWidgets(this.element);
                    this._template = this.element.html();
                    this.element.empty();
                }
            }
            if (this.model.renderTemplate && !this._hasDataSource() && !this.model.enableGroupList) {
                this.element.append(this._lbEle.append(this._lContainer));
                if (this._template) {
                    this._lContainer.append(this._template);
                    if (ej.widget.init)
                        ej.widget.init(this._lContainer);
                }
            }
            else if (!this.model.renderTemplate || this.model.renderTemplate && this._hasDataSource() || this.model.renderTemplate && this.model.enableGroupList) {
                if (this.model.enableGroupList) {
                    this._lContainer.addClass(this._prefixClass + "grouped");
                    var innerDiv = ej.buildTag("div." + this._prefixClass + "grouplist");
                    ul = this.element.children();
                    if (ul.length) {
                        var length = this._hasDataSource() ? this.dataSource().length : ul.length;
                        var title;
                        for (var i = 0; i < length; i++) {
                            if (this._hasDataSource()) {
                                this._items = this.dataSource()[i].items;
                                if (!this.model.renderTemplate) {
                                    ulItem = ej.buildTag('ul');
                                    this._lbEle.append(ulItem);
                                }
                                else
                                    ulItem = ul[i];
                            }
                            else {
                                this._items = [];
                                ulItem = ul[i];
                            }
                            title = this._hasDataSource() ? this.dataSource()[i].key : ej.getAttrVal($(ulItem), 'data-ej-grouplisttitle', "GroupList" + (i + 1));
                            var groupdiv = ej.buildTag("div." + this._prefixClass + "groupdiv", ej.buildTag("div." + this._prefixClass + "grouptitle", title));
                            innerDiv.append(groupdiv.append(this._renderListItems($(ulItem).addClass(this._prefixClass + "grouped"))));
                        }
                    }
                    else if (this._template) {
                        ej.destroyWidgets(this._template);
                        innerDiv[0].innerHTML = this._template;
                    }

                    this._lContainer.append(innerDiv);
                    if (ej.widget.init)
                        ej.widget.init(innerDiv);
                }
                else {
                    if (this._hasDataSource()) {
                        var ul = ej.buildTag('ul');
                        this._items = this.dataSource();
                    }
                    if (ul.length) {
                        ej.destroyWidgets(ul);
                        this._lContainer.append(this._renderListItems(ul));
                    }
                    else if (this._template) {
                        ej.destroyWidgets(this._template);
                        this._lContainer[0].innerHTML = this._template;
                    }
                }
                this.element.prepend(this._lbEle);
                if (this.model.enableFiltering)
                    this._createFilterWrapper(this._lbEle);
                this._lbEle.append(this._lContainer);
                if (ej.widget.init)
                    ej.widget.init(this._lContainer);
                var eLi = this.element.find('li.' + this._prefixClass + 'list');
                eLi.removeEleEmptyAttrs();
                eLi.find('.' + this._prefixClass + 'list-anchor').removeEleEmptyAttrs();
                if (ej.widget.init)
                    ej.widget.init(this._lbEle);
                var ulItems = this.element.find('ul');
                ulItems.find('li:first').addClass(this._prefixClass + "firstitem");
                ulItems.find('li:last').addClass(this._prefixClass + "lastitem");
                this._liEl = this.element.find("li");
                if (this.selectedItemIndex() >= 0 && !this.model.preventSelection && this.model.persistSelection) {
                    if (!ej.getBooleanVal(ulItems[this.selectedItemIndex()], 'data-preventselection', this.model.preventSelection) && ej.getBooleanVal(ulItems[this.selectedItemIndex()], 'data-persistselection', this.model.persistSelection)) {
                        this._currentItem = $(this._liEl[this.selectedItemIndex()]);
                        this._prevItem = this._currentItem;
                        this._currentItem.removeClass(this._prefixClass + "state-default").addClass(this._prefixClass + "state-active");
                    }
                }
                $(this.element.find('.' + this._prefixClass + 'lv-check').parent()).addClass(this._prefixClass + 'lv-checkdiv');
                $(this.element.find('.' + this._prefixClass + 'lv-check').closest('li.' + this._prefixClass + 'list')).addClass(this._prefixClass + 'list-check');
                $(this.element.find('.' + this._prefixClass + 'lv-input').closest('.' + this._prefixClass + 'lv-filter')).addClass(this._prefixClass + 'lv-inputdiv');
                this._wireEvents();
            }
            this._setHeightWidth();
            if (this.model.loadComplete)
                this._trigger("loadComplete");
        },
        //To render filtering box wrapper
        /**
        * Creating Filter Wrapper for ListView control	
        * @private
        */
        _createFilterWrapper: function (element) {
            var fDiv = this._createFilterDiv();
            var fAnchor = ej.buildTag("a." + this._prefixClass + "lv-anchor", ej.buildTag('span.' + this._prefixClass + 'input-btn'), {}, { "Title": "Clear text", "data-role": "none" });
            $(fDiv).append(fAnchor);
            element.append(fDiv);
        },
        //To render list items
        /**
        * Section for Render ListItems for ListView control	
        * @private
        */
        _renderListItems: function (ul) {
            var proxy = this;
            ul.addClass(this._prefixClass + "list-hdr " + this._prefixClass + "clearall");
            this._liItems = ul.find(">li");
            if (this._liItems.length && !this._hasDataSource() || this._hasDataSource()) {
                this._renderParentChildTemplate();
                if (!this._hasDataSource()) {
                    this._liItems.each(function (index, element) {
                        proxy._generateData(element, null, ej.getAttrVal(element, 'data-ej-primarykey', null));
                    });
                }
                this._items = eval(this._items);
                var dataMgr = ej.DataManager(this._items);
                var parentItem = dataMgr.executeLocal(ej.Query().from(this._items).where(ej.Predicate(this.model.fieldSettings['parentPrimaryKey'], ej.FilterOperators.equal, null)).group(this.model.fieldSettings['parentPrimaryKey']));
                var grouped = dataMgr.executeLocal(ej.Query().from(this._items).where(ej.Predicate(this.model.fieldSettings['parentPrimaryKey'], ej.FilterOperators.notEqual, null)).group(this.model.fieldSettings['parentPrimaryKey']));
                if (parentItem[0]) {
                    ul.empty().html($(this.jsRender).render(parentItem[0].items));
                    if (grouped.length) {
                        this.element.append($(this.jsChildRender).render(grouped));
                        $.each(grouped, function (index, element) {
                            if (ej.widget.init)
                                ej.widget.init(proxy.element.find('#child' + element.key));
                            var ul = proxy.element.find('#child' + element.key).find('ul');
                            var li = ul.find('li');
                            k = 0;
                            for (var j = 0; j < li.length; j++) {
                                if (grouped[k].items[j] && grouped[k].items[j].attributes)
                                    $(li[j]).addEleAttrs(grouped[k].items[j].attributes);
                            }
                            k++;
                        });
                    }
                    var ulItems = ul.find('>li');
                    for (var j = 0; j < ulItems.length; j++) {
                        if (parentItem[0].items[j] && parentItem[0].items[j].attributes)
                            $(ulItems[j]).addEleAttrs(parentItem[0].items[j].attributes);
                    }
                }
            }
            if (this._initEJCheckBox)
                this._initEJCheckBox(ul);
            return ul;
        },


        //To render parent child template
        /**
        * Section for Render Parent Child Template for ListView control	
        * @private
        */
        _renderParentChildTemplate: function () {
            var list = this._renderLists();
            $.views.helpers({ _checkAjaxUrls: this._checkAjaxUrl, _checkImgUrls: this._checkImgUrl, _checkIsChecked: this._checkIsCheck, Object: this, ej: ej });
            //Template for parent item
            this.jsRender = ej.buildTag("script#" + this.model.id + "_Template", "", {}, { "type": "text/x-jsrender" });
            if (ej.browserInfo().name == "msie" && ej.browserInfo().version < 10)
                this.jsRender[0].text = list[0].outerHTML.replace(/&gt;/g, '>');
            else
                this.jsRender[0].text = list[0].outerHTML.replace(/&gt;/g, '>');
            //Template for child item
            this.jsChildRender = ej.buildTag("script#" + this.model.id + "_ChildTemplate", "", {}, { "type": "text/x-jsrender" });
            var ul = ej.buildTag("ul." + this._prefixClass + "childcontainer " + this._prefixClass + "list-hdr " + this._prefixClass + "clearall");
            list.addClass(this._prefixClass + "childli");
            ul[0].innerHTML = "{{for items}}" + list[0].outerHTML + "{{/for}}";
            var div = ej.buildTag("div." + this._rootCSS + " subpage " + this._prefixClass + "childitem", "", {}, { "id": "{{if key}}child{{>key}}{{else " + this.model.fieldSettings['childId'] + "}}{{>" + this.model.fieldSettings['childId'] + "}}{{else}}{{/if}}", "style": "display:none" });
            if (this._prefixClass == "e-m-")
                div.addClass(this._prefixClass + this.model.renderMode + this._prefixClass + this.model.theme + !ej.isMobile() ? " e-m-tablet" : " e-m-mobile");
            var innerdiv = ej.buildTag("div." + this._prefixClass + "list-container", "", {}, { "id": "{{if key}}child{{>key}}{{else " + this.model.fieldSettings['childId'] + "}}{{>" + this.model.fieldSettings['childId'] + "}}{{else}}{{/if}}_container" });
            if (this.model.showHeader)
                div.append(this._renderHeader("{{if key}}child{{>key}}{{else " + this.model.fieldSettings['childId'] + "}}{{>" + this.model.fieldSettings['childId'] + "}}{{else}}{{/if}}", true, "Title"));
            if (this.model.enableFiltering)
                this._createFilterWrapper(div);
            div.append(innerdiv.append(ul));
            if (this._prefixClass == "e-m-")
                if (this.model.allowScrolling)
                    this._renderScrollPanel(div, "{{if key}}child{{>key}}{{else " + this.model.fieldSettings['childId'] + "}}{{>" + this.model.fieldSettings['childId'] + "}}{{else}}{{/if}}_scroll", "{{if key}}child{{>key}}{{else " + this.model.fieldSettings['childId'] + "}}{{>" + this.model.fieldSettings['childId'] + "}}{{else}}{{/if}}_container");
            if (ej.browserInfo().name == "msie" && ej.browserInfo().version < 10)
                this.jsChildRender[0].text = div[0].outerHTML.replace(/&gt;/g, '>');
            else
                this.jsChildRender[0].innerHTML = div[0].outerHTML.replace(/&gt;/g, '>');
        },
        //To render the list items
        /**
        * Section for Render Lists for ListView control	
        * @private
        */
        _renderLists: function () {
            var list = ej.buildTag("li", "", {}, {
                "class": this._prefixClass + "user-select " + this._prefixClass + "list " + this._prefixClass + "state-default{{if " + this.model.fieldSettings['primaryKey'] + " || " + this.model.fieldSettings['enableAjax'] + " || " + this.model.enableAjax + "}} " + this._prefixClass + "arrow{{/if}}{{if " + this.model.fieldSettings['imageClass'] + "}} " + this._prefixClass + "margin{{else}}{{if " + this.model.fieldSettings['imageUrl'] + "}} " + this._prefixClass + "margin{{/if}}{{/if}}",
                "data-childid": "{{if " + this.model.fieldSettings['primaryKey'] + "}}child{{>" + this.model.fieldSettings['primaryKey'] + "}}{{else " + this.model.fieldSettings['childId'] + "}}{{>" + this.model.fieldSettings['childId'] + "}}{{else}}{{/if}}",
                "data-childtitle": "{{>" + this.model.fieldSettings['childHeaderTitle'] + "}}",
                "data-childbackbutton": "{{>" + this.model.fieldSettings['childHeaderBackButtonText'] + "}}",
                "data-preventSelection": "{{>" + this.model.fieldSettings['preventSelection'] + "}}",
                "data-persistSelection": "{{>" + this.model.fieldSettings['persistSelection'] + "}}",
                "data-navigateUrl": "{{>" + this.model.fieldSettings['navigateUrl'] + "}}",
                "data-loadajax": "{{>" + this.model.fieldSettings['enableAjax'] + "}}",
                "data-href": '{{>' + this.model.fieldSettings['href'] + '}}{{:~_checkAjaxUrls()}}',
                "data-check": '{{>' + this.model.fieldSettings['enableCheckMark'] + '}}',
                "data-templateid": "{{>" + this.model.fieldSettings['renderTemplate'] + "}}",
                "data-touchstart": "{{>" + this.model.fieldSettings['touchStart'] + "}}",
                "data-touchend": "{{>" + this.model.fieldSettings['touchEnd'] + "}}"
            });
            if (this.model.renderTemplate) {
                if (this._hasDataSource() && this._template)
                    list[0].innerHTML = this._template;
            }
            else {
                var linkTag = ej.buildTag("a", "", {}, { "class": this._prefixClass + "list-anchor " + this._prefixClass + "remove-shadow{{if " + this.model.fieldSettings['imageClass'] + "}} " + this._prefixClass + "margin{{else}}{{if " + this.model.fieldSettings['imageUrl'] + "}} " + this._prefixClass + "margin{{/if}}{{/if}}{{if " + this.model.fieldSettings['primaryKey'] + " || " + this.model.fieldSettings['enableAjax'] + " || " + this.model.enableAjax + "}} " + this._prefixClass + "fontimage{{/if}}", "href": (ej.browserInfo().name == "msie" && ej.browserInfo().version < 9 ? "{{if " + this.model.fieldSettings['navigateUrl'] + " == '' || " + this.model.fieldSettings['navigateUrl'] + " == undefined }}#{{else}}{{:" + this.model.fieldSettings['navigateUrl'] + "}}{{/if}}" : "") });
                var span = ej.buildTag("span", "{{>" + this.model.fieldSettings['text'] + "}}", {}, { "class": this._prefixClass + "list-text " + this._prefixClass + "rel " + this._prefixClass + "user-select{{if " + this.model.fieldSettings['imageClass'] + "}} " + this._prefixClass + "text{{else}}{{if " + this.model.fieldSettings['imageUrl'] + "}} " + this._prefixClass + "text{{/if}}{{/if}}" });
                var imgClass = ej.buildTag("div", "", {}, { 'class': this._prefixClass + "list-img " + this._prefixClass + "rel " + this._prefixClass + "user-select {{>" + this.model.fieldSettings['imageClass'] + "}}" });
                var check = this._createCheckBox();
                if (this.model.renderMode == "windows" && ej.isMobile())
                    linkTag[0].innerHTML = "{{if !" + this.model.fieldSettings['primaryKey'] + "}}{{if " + this.model.fieldSettings['enableAjax'] + " == undefined || " + this.model.fieldSettings['enableAjax'] + ".toString() == 'false'}}{{if !" + this.model.fieldSettings['navigateUrl'] + "}}{{if " + this.model.fieldSettings['enableCheckMark'] + " !== undefined}}{{if " + this.model.fieldSettings['enableCheckMark'] + ".toString() == 'false' ? " + this.model.fieldSettings['enableCheckMark'] + " : " + this.model.enableCheckMark + "}}" + check[0].outerHTML + "{{/if}}{{else}}{{if " + this.model.enableCheckMark + "}}" + check[0].outerHTML + "{{/if}}{{/if}}{{/if}}{{/if}}{{/if}}" + "{{if " + this.model.fieldSettings['imageClass'] + "}}" + imgClass[0].outerHTML + "{{else}}{{if " + this.model.fieldSettings['imageUrl'] + "}}{{:~_checkImgUrls()}}{{/if}}{{/if}}" + span[0].outerHTML;
                else
                    linkTag[0].innerHTML = "{{if " + this.model.fieldSettings['imageClass'] + "}}" + imgClass[0].outerHTML + "{{else}}{{if " + this.model.fieldSettings['imageUrl'] + "}}{{:~_checkImgUrls()}}{{/if}}{{/if}}" + span[0].outerHTML + "{{if !" + this.model.fieldSettings['primaryKey'] + "}}{{if " + this.model.fieldSettings['enableAjax'] + " == undefined || " + this.model.fieldSettings['enableAjax'] + ".toString() == 'false'}}{{if !" + this.model.fieldSettings['navigateUrl'] + "}}{{if " + this.model.fieldSettings['enableCheckMark'] + " !== undefined}}{{if " + this.model.fieldSettings['enableCheckMark'] + ".toString() == 'false' ? " + this.model.fieldSettings['enableCheckMark'] + " : " + this.model.enableCheckMark + "}}" + check[0].outerHTML + "{{/if}}{{else}}{{if " + this.model.enableCheckMark + "}}" + check[0].outerHTML + "{{/if}}{{/if}}{{/if}}{{/if}}{{/if}}";

                list[0].innerHTML = "{{if " + this.model.fieldSettings['renderTemplate'] + " == undefined || " + this.model.fieldSettings['renderTemplate'] + ".toString() == 'false'}}" + linkTag[0].outerHTML + "{{else}}{{:templateId}}{{/if}}";
            }
            if (this.model.renderMode == "ios7") {
                var innerDiv = ej.buildTag("div." + this._prefixClass + "list-div");
                innerDiv[0].innerHTML = list[0].innerHTML;
                list.empty().append(innerDiv);
            }
            return list;
        },
        //To render child wrapper
        /**
        * Section for Render Child Items for ListView control	
        * @private
        */
        _renderChild: function (childId) {
            this._currentItem.attr('data-childid', childId);
            if (!this._currentItem.attr('data-childtitle'))
                this._currentItem.attr('data-childtitle', this._currentItem.text());
            this._createListDiv(childId);
            this._div.hide();
            if (this._prefixClass == "e-m-")
                this._div.addClass(!ej.isMobile() ? this._prefixClass + "m-tablet" : this._prefixClass + "m-mobile");
            this._container = ej.buildTag("div." + this._prefixClass + "list-container#" + childId + "_container");
            this.element.append(this._div);
            if (this.model.allowScrolling)
                this._renderScrollPanel(this._div, childId + "_scroll", childId + "_container");
        },
        //To check the url while jsrender
        /**
        * Section for check Ajax Url for ListView control	
        * @private
        */
        _checkAjaxUrl: function () {
            var href = this.data.href;
            var listObj = this.getRsc("helpers", "Object");
            var ej = this.getRsc("helpers", "ej");
            if (href && href.indexOf("#") != -1 && href != "#") {
                if (!listObj._storedContent[this.index]) {
                    var ele = ej.getCurrentPage().find(href).remove();
                    listObj._storedContent[this.index] = ele[0].nodeName && ele[0].nodeName.toLowerCase() == "script" ? ej.getClearString(ele[0].innerHTML) : ele[0].outerHTML;
                }
                else if (listObj._storedContent[this.index] && ej.getCurrentPage().find(href).length) {
                    var ele = ej.getCurrentPage().find(href).remove();
                    ele = ele[0].nodeName && ele[0].nodeName.toLowerCase() == "script" ? ej.getClearString(ele[0].innerHTML) : ele[0].outerHTML;
                    listObj._storedContent = ej._pushValue(listObj._storedContent, ele, this.index);
                }
            }
            else {
                if (listObj._storedContent[this.index])
                    listObj._storedContent = ej._pushValue(listObj._storedContent, "", this.index);
            }
        },
        /**
        * Section for check Image URL for ListView control	
        * @private
        */
        _checkImgUrl: function (item) {
            var obj = this.getRsc("helpers", "Object");
            var img = this.data[obj.model.fieldSettings.imageUrl];
            if (!$.support.pushstate)
                img = typeof App == "object" ? App.route.makeUrlAbsolute(img, true) : img;
            return "<img src = " + img + " class='" + obj._prefixClass + "list-img " + obj._prefixClass + "rel " + obj._prefixClass + "user-select'/>";
        },
        /**
        * Section for check isChecked for ListView control	
        * @private
        */
        _checkIsCheck: function (item) {
            return this.data[this.getRsc("helpers", "Object").model.fieldSettings.checked] ? true : false;
        },
        //To generate data to pass in jsrender
        /**
        * Section for Generate Data for ListView control	
        * @private
        */
        _generateData: function (element, parentKey, primaryKey) {
            var childId = null, text = ej.getAttrVal(element, 'data-ej-text', $(element).text());
            var headerTitle = null, $ele = $(element), backButton = ej.getAttrVal(element, 'data-ej-childbuttontext', '');
            var renderTemp = ej.getBooleanVal(element, 'data-ej-rendertemplate', false);
            if (renderTemp) {
                if (ej.getCurrentPage().find('#' + ej.getAttrVal(element, 'data-ej-templateid')).length) {
                    var ele = ej.getCurrentPage().find('#' + ej.getAttrVal(element, 'data-ej-templateid')).remove();
                    this._storedTemplate[this._indexVal] = ele[0].nodeName && ele[0].nodeName.toLowerCase() == "script" ? ej.getClearString(ele[0].innerHTML) : ele[0].outerHTML;
                }
                else if (!this._storedTemplate[this._indexVal])
                    this._storedTemplate[this._indexVal] = element.innerHTML;
                else if (this._storedTemplate[this._indexVal] && ej.getCurrentPage().find('#' + ej.getAttrVal(element, 'data-ej-templateid')).length) {
                    var ele = ej.getCurrentPage().find('#' + ej.getAttrVal(element, 'data-ej-templateid')).remove();
                    ele = ele[0].nodeName && ele[0].nodeName.toLowerCase() == "script" ? ej.getClearString(ele[0].innerHTML) : ele[0].outerHTML;
                    this._storedTemplate = ej._pushValue(this._storedTemplate, ele, this._indexVal);
                }
                this._indexVal++;
            }
            if ($ele.find(">ul").length) {
                var proxy = this;
                headerTitle = ej.getAttrVal(element, 'data-ej-childtitle', text);
                if (!$(element).attr("data-ej-primarykey")) {
                    $(element).attr('data-ej-primarykey', Math.round(Math.random() * 100));
                    primaryKey = ej.getAttrVal(element, 'data-ej-primarykey');
                }
                var li = $ele.find(">ul").find('>li');
                li.each(function (index, element) {
                    proxy._generateData(element, ej.getAttrVal(element, 'data-ej-parentkey', primaryKey), ej.getAttrVal(element, 'data-ej-primarykey', null));
                });
            }
            this._items[this._index] = {
                "navigateUrl": ej.getAttrVal(element, 'data-ej-navigateUrl', ""),
                "href": ej.getAttrVal(element, 'data-ej-href', ""),
                "enableAjax": ej.getBooleanVal(element, 'data-ej-enableAjax', this.model.enableAjax),
                "preventSelection": ej.getBooleanVal(element, 'data-ej-preventSelection', this.model.preventSelection),
                "persistSelection": ej.getBooleanVal(element, 'data-ej-persistSelection', this.model.persistSelection),
                "text": text,
                "enableCheckMark": ej.getBooleanVal(element, 'data-ej-enableCheckMark', this.model.enableCheckMark),
                "checked": ej.getBooleanVal(element, 'data-ej-checked', false),
                "primaryKey": primaryKey,
                "parentPrimaryKey": parentKey,
                "imageClass": ej.getAttrVal(element, 'data-ej-imageclass', ""),
                "imageUrl": ej.getAttrVal(element, 'data-ej-imageurl', ""),
                "childHeaderTitle": headerTitle,
                "childId": ej.getAttrVal(element, 'data-ej-childid', "page_" + parseInt(Math.random().toFixed(3) * 1000)),
                "childHeaderBackButtonText": backButton,
                "renderTemplate": renderTemp,
                "templateId": this._storedTemplate[this._indexVal - 1],
                "touchStart": ej.getAttrVal(element, 'data-ej-touchstart', null),
                "touchEnd": ej.getAttrVal(element, 'data-ej-touchend', null),
                "attributes": $ele.removeEleAttrs(/^data-ej-/)[0].attributes
            };
            this._index += 1;
        },
        //Touch Start event handler for list item
        /**
        * To handle Touch Start Handler Event for list Items.
        * @private
        */
        _onTouchStartHandler: function (evt) {
            if (!ej.isDevice() && !ej._preventDefaultException(evt.target, this._preventDefaultException))
                evt.preventDefault && evt.preventDefault();
            if (ej.isWindows && ej.isWindows())
                ej._touchStartPoints(evt, this);
            this._currentItem = $(evt.currentTarget);
            this._scroll = false;
            if (!ej.getBooleanVal(this._currentItem, 'data-preventSelection', this.model.preventSelection))
                this._addSelection();
            if (this.model.renderMode == "windows" && !this.model.windows.preventSkew)
                this._currentItem.addClass(ej.isMobile() ? ej._getSkewClass($(this._currentItem), evt.pageX, evt.pageY) : this._prefixClass + "m-skew-center");
            this._triggerStartEvent(this._returnData());
            ej.listenEvents([this._liEl, this._liEl],
                           [ej.endEvent(), ej.moveEvent(), ej.cancelEvent()],
                           [this._touchEndDelegate, this._touchMoveDelegate, this._touchMoveDelegate], false, this);
            $(window).bind(ej.endEvent(), this._docClickDelegate);
        },
        //Touch Move event handler for list item to prevent selection while scrolling
        /**
        * To handle Touch move handler for list items to prevent selection while scrolling.
        * @private
        */
        _onTouchMoveHandler: function (evt) {
            if (!ej.isWindows || (ej.isWindows && !ej.isWindows()) || (ej.isWindows && ej.isWindows() && ej._isTouchMoved(evt, this))) {
                this._scroll = true;
                if (!ej.getBooleanVal(this._currentItem, 'data-persistSelection', this.model.persistSelection))
                    this._removeSelection();
                else if (this._prevItem && this._prevItem[0] != this._currentItem[0])
                    this._removeSelection();
                if (this.model.renderMode == "windows" && !this.model.windows.preventSkew)
                    ej._removeSkewClass(this._currentItem);
                else if (this.model.renderMode != "windows" && !ej.getBooleanVal(this._currentItem, 'data-preventselection', this.model.preventSelection) && this._prevItem && ej.getBooleanVal(this._currentItem, 'data-persistSelection', this.model.persistSelection))
                    this._prevItem.removeClass(this._prefixClass + "state-default").addClass(this._prefixClass + "state-active");
            }
        },
        //Touch End event handler for list item
        /**
        * To Handle Touch End Handler for List Item.
        * @private
        */
        _onTouchEndHandler: function (evt) {
            this._isFromAjax = false;
            if (!ej.getBooleanVal(this._currentItem, 'data-persistSelection', this.model.persistSelection))
                this._removeSelection();
            if (this.model.renderMode == "windows" && !this.model.windows.preventSkew)
                ej._removeSkewClass(this._currentItem);
            if (this._scroll) {
                this._setCurrent();
                this._unbindEvents(evt);
                return false;
            }
            else if (!this._scroll) {
                if (this._currentItem.find('.' + this._prefixClass + 'lv-check').length) {
                    var lbCheck = this._currentItem.find('.' + this._prefixClass + 'lv-check');
                    if (this._prefixClass == "e-m-" || (this._prefixClass == "e-" && !$(evt.target).closest('.e-lv-checkdiv').length))
                        this._toggleCheckboxValue(lbCheck);
                }
                if (this._prefixClass == "e-m-")
                    var backButton = this._currentItem.attr('data-childbackbutton') == undefined ? this._currentItem.closest('.' + this._rootCSS + '').find('.' + this._prefixClass + 'header').length ? this._currentItem.closest('.' + this._rootCSS + '').find('.' + this._prefixClass + 'header').ejmHeader('getTitle') : "Back" : ej.getAttrVal(this._currentItem, 'data-childbackbutton');
                else
                    var backButton = this._currentItem.attr('data-childbackbutton') == undefined ? this._currentItem.closest('.' + this._rootCSS + '').find('.' + this._prefixClass + 'header').length ? this._currentItem.closest('.' + this._rootCSS + '').find('.' + this._prefixClass + 'header .' + this._prefixClass + 'htitle').text() : "Back" : ej.getAttrVal(this._currentItem, 'data-childbackbutton');
                var urlVal = this._currentItem.attr('data-href');
                if (!this._currentItem.attr('data-navigateUrl')) {
                    var page = this.element.find("[data-ajaxurl='" + this._convertToRelativeUrl(urlVal) + "']");
                    if (ej.getBooleanVal(this._currentItem, 'data-loadajax', this.model.enableAjax) && (!this.model.enableCache || page.length == 0)) {
                        if (page.length)
                            page.remove();
                        this.loadAjaxContent(urlVal, backButton);
                        this._unbindEvents(evt);
                        return;
                    }
                    else if (urlVal && urlVal.indexOf("#") != -1) {
                        if (!$('#' + urlVal.replace('#', '')).length) {
                            this._renderChild(ej.getAttrVal(this._currentItem, 'data-childid', "page_" + parseInt(Math.random().toFixed(3) * 1000)));
                            var content = ej.buildTag("div." + this._prefixClass + "content", this._storedContent[this._currentItem.index()]);
                            this._div.append(this._container.append(content));
                            if (ej.widget.init)
                                ej.widget.init(this._div);
                        }
                    }
                    this._updateContent(this._currentItem, backButton);
                    this._touchEndEventHandler();
                }
                else
                    this._touchEndEventHandler();
                this._prevItem = this._currentItem;
            }
            else if (this.model.renderMode == "windows" && !ej.isMobile())
                this._touchEndEventHandler();
            this._unbindEvents(evt);
        },
        /**
        * Section for Set Current List Item.	
        * @private
        */
        _setCurrent: function (e) {
            if (this._prevItem && ej.getBooleanVal(this._currentItem, 'data-persistSelection', this.model.persistSelection)) {
                this._currentItem = this._prevItem;
                this._currentItem.removeClass(this._prefixClass + "state-default").addClass(this._prefixClass + "state-active");
            }
        },
        /**
        * Section for to UnBind the Events.
        * @private
        */
        _unbindEvents: function (e) {
            if (e && e.target.nodeName && e.target.nodeName.toLowerCase() != "a") {
                //   ej.blockDefaultActions(e);
                this._scroll = false;
            }
            ej.listenEvents([this._liEl, this._liEl],
                           [ej.endEvent(), ej.moveEvent(), ej.cancelEvent()],
                           [this._touchEndDelegate, this._touchMoveDelegate, this._touchMoveDelegate], true, this);
        },
        //To make the list as selected
        /**
        * Section for to make the list as selected.
        * @private
        */
        _addSelection: function () {
            if (!this._scroll) {
                this._currentItem.closest('.' + this._prefixClass + 'list-container').find('.' + this._prefixClass + 'state-active').removeClass(this._prefixClass + "state-active").addClass(this._prefixClass + "state-default");
                this._currentItem.removeClass(this._prefixClass + "state-default").addClass(this._prefixClass + "state-active");
            }
        },
        //To make the list as unselected
        /**
        * Section for to remove the selected list.
        * @private
        */
        _removeSelection: function () {
            var proxy = this;
            proxy._currentItem.removeClass(this._prefixClass + "state-active").addClass(this._prefixClass + "state-default");
        },

        /**
        * Section for to set Height Width for ListView Control.
        * @private
        */
        _setHeightWidth: function () {
            if (this.model.autoAdjustHeight)
                this.element.height(window.innerHeight);
            else if (this.model.height)
                this.element.height(this.model.height);
            else {
                var hgt = this.element[0].scrollHeight ? this.element[0].scrollHeight : ej.getDimension(this._lbEle.find('.' + this._prefixClass + 'list-container'), 'outerHeight');
                if (this.model.showHeader)
                    hgt = hgt + ej.getDimension(this._lbEle.find('.' + this._prefixClass + 'header'), 'outerHeight');
                if (this.model.enableFiltering)
                    hgt = hgt + ej.getDimension(this._lbEle.find('.' + this._prefixClass + 'lv-inputdiv'), 'outerHeight');
                this.element.height(hgt);
            }
            if (this.model.width)
                this.element.width(this.model.width);
        },
        //Touch end event handler
        /**
        * To handle Touch End event handler.
        * @private
        */
        _touchEndEventHandler: function () {
            this._triggerEndEvent(this._returnData());
        },

        //Doc Click
        /**
        * To handle Doc Click.
        * @private
        */
        _docClick: function (evt) {
            if (this._scroll)
                this._setCurrent();
            $(window).unbind(ej.endEvent(), this._docClickDelegate);
            ej.listenEvents([this._liEl, this._liEl],
                           [ej.endEvent(), ej.moveEvent()],
                           [this._touchEndDelegate, this._touchMoveDelegate], true, this);
        },
        //Pop State Navigation
        /**
        * To handle pop state navigation.
        * @private
        */
        _popStateNavigation: function (evt, data) {
            if (data.pageUrl && this.model.enableFiltering)
                this._initializeFiltering($("div[data-url='" + data.pageUrl.replace('#', '') + "']"));
        },
        //Anchor tag click handler
        /**
        * To handle anchor click handler.
        * @private
        */
        _anchorClickHandler: function (e) {
            if (this._scroll) {
                ej.blockDefaultActions(e);
                return false;
            }
        },
        /**
        * Section for to resize handler.
        * @private
        */
        _onResize: function () {
            var proxy = this;
            setTimeout(function () {
                proxy._setHeightWidth();
            }, ej.isAndroid() ? 200 : 0);
        },
        _onScrollStop: function (e) {
            ej.blockDefaultActions(e);
        },
        //To create delegates for event handling
        /**
        * Section for to create delegates for Event handling.
        * @private
        */
        _createDelegates: function () {
            this._anchorClickDelegate = $.proxy(this._anchorClickHandler, this);
            this._keyup = $.proxy(this._onKeyUp, this);
            this._touchStartDelegate = $.proxy(this._onTouchStartHandler, this);
            this._touchEndDelegate = $.proxy(this._onTouchEndHandler, this);
            this._touchMoveDelegate = $.proxy(this._onTouchMoveHandler, this);
            this._resizeDelegate = $.proxy(this._onResize, this);
            this._popStateDelegate = $.proxy(this._popStateNavigation, this);
            this._docClickDelegate = $.proxy(this._docClick, this);
        },
        //To wire events for the list
        /**
        * Section for to wire events for the list.
        * @private
        */
        _wireEvents: function (remove) {
            this._createDelegates();
            var eventType = remove ? "unbind" : "bind";
            if (this.model.autoAdjustHeight) {
                var evt = !ej.isDevice() && !ej.isTouchDevice() ? "resize" : "orientationchange";
                ej.listenEvents([window], [evt], [this._resizeDelegate], remove, this);
            }
            ej.listenEvents([this._liEl.find('a'), this.element.find('.' + this._prefixClass + 'lv-input'), this._liEl, this._liEl],
                ["click", "keyup", ej.startEvent(), ej.cancelEvent()],
                [this._anchorClickDelegate, this._keyup, this._touchStartDelegate, this._touchMoveDelegate], remove, this);
            this._lContainer.on("scrollstop", $.proxy(this._onScrollStop, this));
            $('body')[eventType]('viewpopstate', this._popStateDelegate);
            if (this.model.enableFiltering)
                this._initializeFiltering(this._lbEle);
        },
        //To initialize filtering
        /**
        * Section for to initialize filtering.
        * @private
        */
        _initializeFiltering: function (element) {
            this._searchItems = $(element).find("." + this._prefixClass + "list");
            this._emptyFilterTextValue(element);
            element.find('.' + this._prefixClass + 'list[style*="display: none"]').show();
            var selector = "a";
            this._elementText = [];
            for (var i = 0; i < this._searchItems.length; i++) {
                if ($(this._searchItems[i]).find(selector))
                    this._elementText.push($.trim($(this._searchItems[i]).find(selector).html().replace(new RegExp('<[^<]+\>', 'g'), "").toLowerCase()));
                else
                    this._elementText.push("");
            }
        },
        //To perform filtering in keyup event
        /**
        * Section for to perform Key Up filtering.
        * @private
        */
        _onKeyUp: function (evt) {
            for (var i = 0; i < this._searchItems.length; i++) {
                if (this._elementText[i].indexOf(evt.target.value) == -1)
                    $(this._searchItems[i]).css("display", "none");
                else
                    $(this._searchItems[i]).css("display", "");
            }
        },
        //To set the model values
        /**
        * To configure the properties at runtime using SetModel		
        * @private
        */
        _setModel: function (options) {
            var refresh = false;
            for (var prop in options) {
                var setModel = "_set" + prop.charAt(0).toUpperCase() + prop.slice(1);
                if (this[setModel])
                    this[setModel](options[prop]);
                else
                    refresh = true;
            }
            if (refresh)
                this._refresh();
        },
        //To change the Theme property
        /**
        * Section for to change the theme property.
        * @private
        */
        _setTheme: function (value) {
            if (value) {
                this.model.theme = value;
                this._lbEle.removeClass("e-m-dark e-m-light e-default").addClass("e-m-" + this.model.theme);
                if (this.model.enableFiltering)
                    this.element.find('.' + this._prefixClass + 'text-input').ejmTextBox('model.theme', this.model.theme);
                if (this.model.showHeader)
                    this._lbEle.find('#' + this.model.id + "_header").ejmHeader('model.theme', this.model.theme);
                if (this.element.find('.' + this._prefixClass + 'childitem').length) {
                    $(this.element.find('.' + this._prefixClass + 'childitem')).removeClass("e-m-dark e-m-light e-default").addClass("e-m-" + this.model.theme);
                    var header = this.element.find('.' + this._prefixClass + 'childitem .' + this._prefixClass + 'header');
                    var proxy = this;
                    header.each(function (index, element) {
                        $(element).ejmHeader('model.theme', proxy.model.theme);
                    });
                }
            }
        },
        //To update the data source
        /**
        * Section for to update the data source.
        * @private
        */
        _setDataSource: function (dataSource, fieldSettings) {
            if (this._hasDataSource() && dataSource) {
                if (fieldSettings)
                    this.model.fieldSettings = fieldSettings;
                this._refresh();
            }
        },
        //To check the data source
        /**
        * Section for to check the data source.
        * @private
        */
        _hasDataSource: function () {
            return this.dataSource() && this.dataSource().length;
        },
        //To get the element
        /**
        * Section for to get the element.	
        * @private
        */
        _getElement: function (childId) {
            return childId ? this.element.find('#' + childId) : this._lbEle;
        },
        //To check the element is disabled
        /**
        * Section for to check the element is disabled.	
        * @private
        */
        _isEnable: function (item) {
            return item.hasClass(this._prefixClass + 'state-disabled') ? false : true;
        },
        //To refresh the control
        _refresh: function () {
            this._destroy();
            this.element.addClass(this._rootCSS);
            this._load();
        },
        //To clear the element
        _clearElement: function () {
            this.element.removeAttr("class").removeAttr("style");
            this.element.empty().html(this._orgEle.html());
        },
        // all events bound using this._on will be unbind automatically
        _destroy: function () {
            this._wireEvents(true);
            this._clearElement();
        },

        /*-------------------------------Public Methods--------------------*/
        //To load Ajax content while clicking list item
        /**
        * To load the ajax content while selecting the item.
        * @method loadAjaxContent
        * @return jQuery
        * @example 
        * &lt;div id="lb" &gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Man of Steel" data-ej-href="load1.html" &gt;&lt;/li&gt;
        *		&lt;li data-ej-text="World War Z" data-ej-href="load2.html" &gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Monsters University" data-ej-href="load3.html" &gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call enableAjax method.
        * $(document).ready(function(){
        * $("#lb").ejListView ({ enableAjax: true });
        * $("#lb").ejListView("loadAjaxContent","load1.html");
        * });
        * &lt;/script&gt;
        * @memberof ejListView
        * @instance
        */
        //Mobile
        /**
        * To load the ajax content while selecting the item.
        * @method loadAjaxContent
        * @return jQuery
        * @example 
        * &lt;div id="lb" data-role="ejmlistview"&gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Man of Steel" data-ej-href="load1.html" data-ej-enableAjax="true"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="World War Z" data-ej-href="load2.html" data-ej-enableAjax="true"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Monsters University" data-ej-href="load3.html" data-ej-enableAjax="true"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call enableAjax method.
        * $(document).ready(function(){
        * $("#lb").ejmListView("loadAjaxContent","load1.html");
        * });
        * &lt;/script&gt;
        * @memberof ejmListView
        * @instance
        */
        loadAjaxContent: function (urlVal, backButton) {
            var proxy = this;
            this._isFromAjax = true;
            this._renderChild(ej.getAttrVal(this._currentItem, 'data-childid', "page_" + parseInt(Math.random().toFixed(3) * 1000)));
            if (!$.support.pushstate || ej.isWindowsWebView())
                urlVal = App.route.makeUrlAbsolute(urlVal);
            var loadData = { content: proxy._div, item: proxy._currentItem, index: $(proxy._currentItem).index(), text: $(proxy._currentItem).text(), url: proxy.model.ajaxSettings.url ? proxy.model.ajaxSettings.url : urlVal };
            if (this.model.ajaxBeforeLoad)
                this._trigger("ajaxBeforeLoad", loadData);
            var ajaxSettings = {
                cache: proxy.model.ajaxSettings.cache,
                async: proxy.model.ajaxSettings.async,
                type: proxy.model.ajaxSettings.type,
                contentType: proxy.model.ajaxSettings.contentType,
                url: ej.isWindowsWebView() ? urlVal : proxy.model.ajaxSettings.url ? proxy.model.ajaxSettings.url : urlVal,
                dataType: proxy.model.ajaxSettings.dataType,
                data: proxy.model.ajaxSettings.data,
                "successHandler": function (data) { //Ajax post success event handler
                    var content = ej.buildTag("div." + this._prefixClass + "content", (/<\/?body[^>]*>/gmi).test(data) ? data.split(/<\/?body[^>]*>/gmi)[1] : data || "");
                    proxy._div.append(proxy._container.append(content));
                    proxy._div.attr("data-ajaxurl", App.route.convertToRelativeUrl(urlVal));
                    proxy._updateContent(proxy._currentItem, backButton);
                    var successData = { content: proxy._div, item: proxy._currentItem, index: $(proxy._currentItem).index(), text: $(proxy._currentItem).text(), url: proxy.model.ajaxSettings.url ? proxy.model.ajaxSettings.url : urlVal };
                    if (proxy.model.ajaxSuccess)
                        proxy._trigger("ajaxSuccess", successData);
                },
                "errorHandler": function (xhr, textStatus, errorThrown) {
                    var errorData = { "xhr": xhr, "textStatus": textStatus, "errorThrown": errorThrown, item: proxy._currentItem, index: $(proxy._currentItem).index(), text: $(proxy._currentItem).text(), url: proxy.model.ajaxSettings.url ? proxy.model.ajaxSettings.url : urlVal };
                    if (proxy.model.ajaxError)
                        proxy._trigger("ajaxError", errorData);
                },
                "completeHandler": function (data) {
                    var completeData = { content: proxy._div, item: proxy._currentItem, index: $(proxy._currentItem).index(), text: $(proxy._currentItem).text(), url: proxy.model.ajaxSettings.url ? proxy.model.ajaxSettings.url : urlVal };
                    if (proxy.model.ajaxComplete)
                        proxy._trigger("ajaxComplete", completeData);
                }
            };
            ej.sendAjaxRequest(ajaxSettings);
        },
        //To select the list item
        /**
        * To select item in the given index.
        * @method selectItem
        * @return jQuery
        * @example 
        * &lt;div id="lb" &gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call selectItem method.
        * $(document).ready(function(){
		* $("#lb").ejListView();
        * $("#lb").ejListView("selectItem",2);
        * });
        * &lt;/script&gt;
        * @memberof ejListView
        * @instance
        */
        //Mobile
        /**
        * To select item in the given index.
        * @method selectItem
        * @return jQuery
        * @example 
        * &lt;div id="lb" data-role="ejmlistview"&gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call selectItem method.
        * $(document).ready(function(){
        * $("#lb").ejListView({enableCheckMark:true});
        * $("#lb").ejmListView("selectItem",2);
        * });
        * &lt;/script&gt;
        * @memberof ejmListView
        * @instance
        */
        selectItem: function (index, childId) {
            if (index >= 0 && this._isEnable($(this._getElement(childId).find('li.' + this._prefixClass + 'list')[index]))) {
                this._currentItem = $(this._getElement(childId).find('li.' + this._prefixClass + 'list')[index]);
                this._prevItem = this._currentItem;
                this._onTouchEndHandler();
            }
        },
        //To make the List item to be active
        /**
        * To make the item in the given index to be active state.
        * @method setActive
        * @return jQuery
        * @example 
        * &lt;div id="lb"&gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call setActive method.
        * $(document).ready(function(){
		* $("#lb").ejListView({persistSelection:true});
        * $("#lb").ejListView("setActive",2);
        * });
        * &lt;/script&gt;
        * @memberof ejListView
        * @instance
        */
        //Mobile
        /**
        * To make the item in the given index to be active state.
        * @method setActive
        * @return jQuery
        * @example 
        * &lt;div id="lb" data-role="ejmlistview"&gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call setActive method.
        * $(document).ready(function(){
		* $("#lb").ejmListView({persistSelection:true});
        * $("#lb").ejmListView("setActive",2);
        * });
        * &lt;/script&gt;
        * @memberof ejmListView
        * @instance
        */
        setActive: function (index, childId) {
            if (index >= 0) {
                element = this._getElement(childId);
                if (this._isEnable($(element.find('li.' + this._prefixClass + 'list')[index])) && ej.getBooleanVal($(element.find('li.' + this._prefixClass + 'list')[index]), 'data-persistSelection', this.model.persistSelection)) {
                    element.find('li.' + this._prefixClass + 'list.' + this._prefixClass + 'state-active').removeClass(this._prefixClass + 'state-active').addClass(this._prefixClass + 'state-default');
                    this._currentItem = $(element.find('li.' + this._prefixClass + 'list')[index]);
                    this._prevItem = this._currentItem;
                    this._currentItem.removeClass(this._prefixClass + 'state-default').addClass(this._prefixClass + 'state-active');
                }
            }
        },
        //To un set the List item to be active
        /**
        * To make the item in the given index to be default state.
        * @method deActive
        * @return jQuery
        * @example 
        * &lt;div id="lb" &gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call deActive method.
        * $(document).ready(function(){
		* $("#lb").ejListView({persistSelection:true});
        * $("#lb").ejListView("deActive",2);
        * });
        * &lt;/script&gt;
        * @memberof ejListView
        * @instance
        */
        //Mobile
        /**
        * To make the item in the given index to be default state.
        * @method deActive
        * @return jQuery
        * @example 
        * &lt;div id="lb" data-role="ejmlistview"&gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call deActive method.
        * $(document).ready(function(){
		* $("#lb").ejListView({persistSelection:true});
        * $("#lb").ejmListView("deActive",2);
        * });
        * &lt;/script&gt;
        * @memberof ejmListView
        * @instance
        */
        deActive: function (index, childId) {
            if (index >= 0 && this._isEnable($(this._getElement(childId).find('li.' + this._prefixClass + 'list')[index])))
                $(this._getElement(childId).find('li.' + this._prefixClass + 'list')[index]).removeClass(this._prefixClass + 'state-active').addClass(this._prefixClass + 'state-default');
        },
        //To enable the List item
        /**
        * To enable item in the given index.
        * @method enableItem
        * @return jQuery
        * @example 
        * &lt;div id="lb"&gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call enableItem method.
        * $(document).ready(function(){
		* $("#lb").ejListView();
        * $("#lb").ejListView("enableItem",2);
        * });
        * &lt;/script&gt;
        * @memberof ejListView
        * @instance
        */
        //Mobile
        /**
        * To enable item in the given index.
        * @method enableItem
        * @return jQuery
        * @example 
        * &lt;div id="lb" data-role="ejmlistview"&gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call enableItem method.
        * $(document).ready(function(){
        * $("#lb").ejmListView("enableItem",2);
        * });
        * &lt;/script&gt;
        * @memberof ejmListView
        * @instance
        */
        enableItem: function (index, childId) {
            if (index >= 0)
                $(this._getElement(childId).find('li.' + this._prefixClass + 'list')[index]).removeClass(this._prefixClass + 'state-disabled');
        },
        //To disable the List item
        /**
        * To disable item in the given index.
        * @method disableItem
        * @return jQuery
        * @example 
        * &lt;div id="lb" &gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call disableItem method.
        * $(document).ready(function(){
		* $("#lb").ejListView();
        * $("#lb").ejListView("disableItem",2);
        * });
        * &lt;/script&gt;
        * @memberof ejListView
        * @instance
        */
        //Mobile
        /**
        * To disable item in the given index.
        * @method disableItem
        * @return jQuery
        * @example 
        * &lt;div id="lb" data-role="ejmlistview"&gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call disableItem method.
        * $(document).ready(function(){
        * $("#lb").ejmListView("disableItem",2);
        * });
        * &lt;/script&gt;
        * @memberof ejmListView
        * @instance
        */
        disableItem: function (index, childId) {
            if (index >= 0)
                $(this._getElement(childId).find('li.' + this._prefixClass + 'list')[index]).addClass(this._prefixClass + 'state-disabled');
        },
        //To remove check mark to the list
        /**
        * To remove the check mark either for specific item in the given index or for all items.
        * @method removeCheckMark
        * @return jQuery
        * @example 
        * &lt;div id="lb" &gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call removeCheckMark method.
        * $(document).ready(function(){
        * $("#lb").ejListView({enableCheckMark:true});
        * $("#lb").ejListView("removeCheckMark",2);
        * });
        * &lt;/script&gt;
        * @memberof ejListView
        * @instance
        */
        //Mobile
        //To remove check mark to the list
        /**
        * To remove the check mark either for specific item in the given index or for all items.
        * @method removeCheckMark
        * @return jQuery
        * @example 
        * &lt;div id="lb" data-role="ejmlistview" data-ej-enablecheckmark="true"&gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call removeCheckMark method.
        * $(document).ready(function(){
		* $("#lb").ejListView({enableCheckMark:true});
        * $("#lb").ejmListView("removeCheckMark",2);
        * });
        * &lt;/script&gt;
        * @memberof ejmListView
        * @instance
        */
        removeCheckMark: function (index, childId) {
            element = this._getElement(childId);
            if (index >= 0 && this._isEnable($(element.find('li.' + this._prefixClass + 'list')[index])))
                $(element.find('li.' + this._prefixClass + 'list')[index]).find('.' + this._prefixClass + 'lv-checkdiv').remove();
            else
                element.find('.' + this._prefixClass + 'lv-checkdiv').remove();
        },
        //To check selected item in the list
        /**
        * To check item in the given index.
        * @method checkItem
        * @return jQuery
        * @example 
        * &lt;div id="lb" &gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call checkItem method.
        * $(document).ready(function(){
		* $("#lb").ejListView({enableCheckMark:true});
        * $("#lb").ejListView("checkItem",2);
        * });
        * &lt;/script&gt;
        * @memberof ejListView
        * @instance
        */
        //Mobile
        /**
        * To check item in the given index.
        * @method checkItem
        * @return jQuery
        * @example 
        * &lt;div id="lb" data-role="ejmlistview" data-ej-enablecheckmark="true"&gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call checkItem method.
        * $(document).ready(function(){
        * $("#lb").ejmListView("checkItem",2);
        * });
        * &lt;/script&gt;
        * @memberof ejmListView
        * @instance
        */
        checkItem: function (index, childId) {
            if (index >= 0 && this._isEnable($(this._getElement(childId).find('li.' + this._prefixClass + 'list')[index])))
                this._setCheckboxValue($(this._getElement(childId).find('.' + this._prefixClass + 'lv-check')[index]), true);
        },
        //To uncheck selected item in the list
        /**
        * To uncheck item in the given index.
        * @method unCheckItem
        * @return jQuery
        * @example 
        * &lt;div id="lb" &gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call unCheckItem method.
        * $(document).ready(function(){
		* $("#lb").ejListView({enableCheckMark:true});
        * $("#lb").ejListView("unCheckItem",2);
        * });
        * &lt;/script&gt;
        * @memberof ejListView
        * @instance
        */
        //Mobile
        /**
        * To uncheck item in the given index.
        * @method unCheckItem
        * @return jQuery
        * @example 
        * &lt;div id="lb" data-role="ejmlistview"&gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call unCheckItem method.
        * $(document).ready(function(){
        * $("#lb").ejmListView("unCheckItem",2);
        * });
        * &lt;/script&gt;
        * @memberof ejmListView
        * @instance
        */
        unCheckItem: function (index, childId) {
            if (index >= 0 && this._isEnable($(this._getElement(childId).find('li.' + this._prefixClass + 'list')[index])))
                this._setCheckboxValue($(this._getElement(childId).find('.' + this._prefixClass + 'lv-check')[index]), false);
        },
        //To check all the items in the list
        /**
        * To check all the items.
        * @method checkAllItem
        * @return jQuery
        * @example 
        * &lt;div id="lb"&gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call checkAllItem method.
        * $(document).ready(function(){
        * $("#lb").ejListView({enableCheckMark:true});
        * $("#lb").ejListView("checkAllItem");
        * });
        * &lt;/script&gt;
        * @memberof ejListView
        * @instance
        */
        //Mobile
        /**
        * To check all the items.
        * @method checkAllItem
        * @return jQuery
        * @example 
        * &lt;div id="lb" data-role="ejmlistview" data-ej-enablecheckmark="true"&gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call checkAllItem method.
        * $(document).ready(function(){
        * $("#lb").ejmListView("checkAllItem");
        * });
        * &lt;/script&gt;
        * @memberof ejmListView
        * @instance
        */
        checkAllItem: function (childId) {
            var proxy = this;
            this._getElement(childId).find('.' + this._prefixClass + 'lv-check').each(function (index, check) {
                if (proxy._isEnable($(proxy._getElement(childId).find('li.' + proxy._prefixClass + 'list')[index])))
                    proxy._setCheckboxValue($(check), true);
            });
        },
        //To uncheck all the items in the list
        /**
        * To uncheck all the items.
        * @method unCheckAllItem
        * @return jQuery
        * @example 
        * &lt;div id="lb" &gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call unCheckAllItem method.
        * $(document).ready(function(){
		* $("#lb").ejListView({enableCheckMark:true});
        * $("#lb").ejListView("unCheckAllItem");
        * });
        * &lt;/script&gt;
        * @memberof ejListView
        * @instance
        */
        //Mobile
        /**
        * To uncheck all the items.
        * @method unCheckAllItem
        * @return jQuery
        * @example 
        * &lt;div id="lb" data-role="ejmlistview" data-ej-enablecheckmark="true"&gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call unCheckAllItem method.
        * $(document).ready(function(){
        * $("#lb").ejmListView("unCheckAllItem");
        * });
        * &lt;/script&gt;
        * @memberof ejmListView
        * @instance
        */
        unCheckAllItem: function (childId) {
            var proxy = this;
            this._getElement(childId).find('.' + this._prefixClass + 'lv-check').each(function (index, check) {
                if (proxy._isEnable($(proxy._getElement(childId).find('li.' + proxy._prefixClass + 'list')[index])))
                    proxy._setCheckboxValue($(check), false);
            });
        },
        //To get active list item
        /**
        * To get the active item.
        * @method getActiveItem
        * @return jQuery
        * @example 
        * &lt;div id="lb"&gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call getActiveItem method.
        * $(document).ready(function(){
		* $("#lb").ejListView({persistSelection:true});
        * $("#lb").ejListView("getActiveItem");
        * });
        * &lt;/script&gt;
        * @memberof ejListView
        * @instance
        */
        //Mobile
        /**
        * To get the active item.
        * @method getActiveItem
        * @return jQuery
        * @example 
        * &lt;div id="lb" data-role="ejmlistview"&gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call getActiveItem method.
        * $(document).ready(function(){
        * $("#lb").ejmListView("getActiveItem");
        * });
        * &lt;/script&gt;
        * @memberof ejmListView
        * @instance
        */
        getActiveItem: function (childId) {
            return this._getElement(childId).find('li.' + this._prefixClass + 'list.' + this._prefixClass + 'state-active');
        },
        /**
        * To get the text of the active item.
        * @method getActiveItemText
        * @return jQuery
        * @example 
        * &lt;div id="lb"&gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call getActiveItemText method.
        * $(document).ready(function(){
		* $("#lb").ejListView({persistSelection:true});
        * $("#lb").ejListView("getActiveItemText");
        * });
        * &lt;/script&gt;
        * @memberof ejListView
        * @instance
        */
        //Mobile
        /**
        * To get the text of the active item.
        * @method getActiveItemText
        * @return jQuery
        * @example 
        * &lt;div id="lb" data-role="ejmlistview"&gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call getActiveItemText method.
        * $(document).ready(function(){
        * $("#lb").ejmListView("getActiveItemText");
        * });
        * &lt;/script&gt;
        * @memberof ejmListView
        * @instance
        */
        getActiveItemText: function (childId) {
            return this._getElement(childId).find('li.' + this._prefixClass + 'list.' + this._prefixClass + 'state-active').text();
        },
        //To get text of the list item
        /**
        * To get the text of the item in the given index.
        * @method getItemText
        * @return jQuery
        * @example 
        * &lt;div id="lb"&gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call getItemText method.
        * $(document).ready(function(){
		* $("#lb").ejListView();
        * $("#lb").ejListView("getItemText",2);
        * });
        * &lt;/script&gt;
        * @memberof ejListView
        * @instance
        */
        //Mobile
        /**
        * To get the text of the item in the given index.
        * @method getItemText
        * @return jQuery
        * @example 
        * &lt;div id="lb" data-role="ejmlistview"&gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call getItemText method.
        * $(document).ready(function(){
        * $("#lb").ejmListView("getItemText",2);
        * });
        * &lt;/script&gt;
        * @memberof ejmListView
        * @instance
        */
        getItemText: function (index, childId) {
            if (index >= 0)
                return $(this._getElement(childId).find('li.' + this._prefixClass + 'list')[index]).text();
        },
        //To get all checked list items
        /**
        * To get all the checked items.
        * @method getCheckedItems
        * @return jQuery
        * @example 
        * &lt;div id="lb" &gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call getCheckedItems method.
        * $(document).ready(function(){
		* $("#lb").ejListView({enableCheckMark:true})
        * $("#lb").ejListView("getCheckedItems");
        * });
        * &lt;/script&gt;
        * @memberof ejListView
        * @instance
        */
        /**
        * To get all the checked items.
        * @method getCheckedItems
        * @return jQuery
        * @example 
        * &lt;div id="lb" data-role="ejmlistview" data-ej-enablecheckmark="true"&gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call getCheckedItems method.
        * $(document).ready(function(){
        * $("#lb").ejmListView("getCheckedItems");
        * });
        * &lt;/script&gt;
        * @memberof ejmListView
        * @instance
        */
        getCheckedItems: function (childId) {
            return this._getElement(childId).find('input.' + this._prefixClass + 'lv-check:checked').closest('li.' + this._prefixClass + 'list');
        },
        //To get all checked list item's text
        /**
        * To get the text of all the checked items.
        * @method getCheckedItemsText
        * @return jQuery
        * @example 
        * &lt;div id="lb" &gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call getCheckedItemsText method.
        * $(document).ready(function(){
		* $("#lb").ejListView({enableCheckMark:true})
        * $("#lb").ejListView("getCheckedItemsText");
        * });
        * &lt;/script&gt;
        * @memberof ejListView
        * @instance
        */
        //Mobile
        /**
        * To get the text of all the checked items.
        * @method getCheckedItemsText
        * @return jQuery
        * @example 
        * &lt;div id="lb" data-role="ejmlistview" data-ej-enablecheckmark="true"&gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call getCheckedItemsText method.
        * $(document).ready(function(){
        * $("#lb").ejmListView("getCheckedItemsText");
        * });
        * &lt;/script&gt;
        * @memberof ejmListView
        * @instance
        */
        getCheckedItemsText: function (childId) {
            return $(this.getCheckedItems(childId)).map(function () { return $(this).text(); }).get();
        },
        //To check whether the list item has child or not
        /**
        * To check whether the item in the given index has child item.
        * @method hasChild
        * @return jQuery
        * @example 
        * &lt;div id="lb"&gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call hasChild method.
        * $(document).ready(function(){
		* $("#lb").ejListView();
        * $("#lb").ejListView("hasChild",2);
        * });
        * &lt;/script&gt;
        * @memberof ejListView
        * @instance
        */
        //Mobile
        /**
        * To check whether the item in the given index has child item.
        * @method hasChild
        * @return jQuery
        * @example 
        * &lt;div id="lb" data-role="ejmlistview"&gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call hasChild method.
        * $(document).ready(function(){
        * $("#lb").ejmListView("hasChild",2);
        * });
        * &lt;/script&gt;
        * @memberof ejmListView
        * @instance
        */
        hasChild: function (index, childId) {
            if (index >= 0)
                return this.element.find('#' + $(this._getElement(childId).find('li.' + this._prefixClass + 'list')[index]).attr('data-childid')).length ? true : false;
        },
        //To check whether the list item is checked or not
        /**
        * To check whether item in the given index is checked.
        * @method isChecked
        * @return jQuery
        * @example 
        * &lt;div id="lb" &gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call isChecked method.
        * $(document).ready(function(){
		* $("#lb").ejListView({enableCheckMark:true});
        * $("#lb").ejListView("isChecked",2);
        * });
        * &lt;/script&gt;
        * @memberof ejListView
        * @instance
        */
        //Mobile
        /**
        * To check whether item in the given index is checked.
        * @method isChecked
        * @return jQuery
        * @example 
        * &lt;div id="lb" data-role="ejmlistview" data-ej-enablecheckmark="true"&gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call isChecked method.
        * $(document).ready(function(){
        * $("#lb").ejmListView("isChecked",2);
        * });
        * &lt;/script&gt;
        * @memberof ejmListView
        * @instance
        */
        isChecked: function (index, childId) {
            if (index >= 0)
                return $(this._getElement(childId).find('li.' + this._prefixClass + 'list')[index]).find('input.' + this._prefixClass + 'lv-check').prop('checked');
        },
        //To show the list item
        /**
        * To show item in the given index.
        * @method showItem
        * @return jQuery
        * @example 
        * &lt;div id="lb" &gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call showItem method.
        * $(document).ready(function(){
		* $("#lb").ejListView();
        * $("#lb").ejListView("showItem",2);
        * });
        * &lt;/script&gt;
        * @memberof ejListView
        * @instance
        */
        //Mobile
        /**
        * To show item in the given index.
        * @method showItem
        * @return jQuery
        * @example 
        * &lt;div id="lb" data-role="ejmlistview"&gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call showItem method.
        * $(document).ready(function(){
        * $("#lb").ejmListView("showItem",2);
        * });
        * &lt;/script&gt;
        * @memberof ejmListView
        * @instance
        */
        showItem: function (index, childId) {
            if (index >= 0)
                $(this._getElement(childId).find('li.' + this._prefixClass + 'list')[index]).css('visibility', '');
        },
        //To hide the list item
        /**
        * To hide item in the given index.
        * @method hideItem
        * @return jQuery
        * @example 
        * &lt;div id="lb" &gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call hideItem method.
        * $(document).ready(function(){
		* $("#lb").ejListView();
        * $("#lb").ejListView("hideItem",2);
        * });
        * &lt;/script&gt;
        * @memberof ejListView
        * @instance
        */
        //Mobile
        /**
        * To hide item in the given index.
        * @method hideItem
        * @return jQuery
        * @example 
        * &lt;div id="lb" data-role="ejmlistview"&gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call hideItem method.
        * $(document).ready(function(){
        * $("#lb").ejmListView("hideItem",2);
        * });
        * &lt;/script&gt;
        * @memberof ejmListView
        * @instance
        */
        hideItem: function (index, childId) {
            if (index >= 0)
                $(this._getElement(childId).find('li.' + this._prefixClass + 'list')[index]).css('visibility', 'hidden');
        },
        //To show the list
        /**
        * To show the list.
        * @method show
        * @return jQuery
        * @example 
        * &lt;div id="lb"&gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call show method.
        * $(document).ready(function(){
		* $("#lb").ejListView();
        * $("#lb").ejListView("show");
        * });
        * &lt;/script&gt;
        * @memberof ejListView
        * @instance
        */
        //Mobile
        /**
        * To show the list.
        * @method show
        * @return jQuery
        * @example 
        * &lt;div id="lb" data-role="ejmlistview"&gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call show method.
        * $(document).ready(function(){
        * $("#lb").ejmListView("show");
        * });
        * &lt;/script&gt;
        * @memberof ejmListView
        * @instance
        */
        show: function (childId) {
            this._getElement(childId).css('visibility', '');
        },
        //To hide the list
        /**
        * To hide the list.
        * @method hide
        * @return jQuery
        * @example 
        * &lt;div id="lb"&gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call hide method.
        * $(document).ready(function(){
		* $("#lb").ejListView();
        * $("#lb").ejListView("hide");
        * });
        * &lt;/script&gt;
        * @memberof ejListView
        * @instance
        */
        //Mobile
        /**
        * To hide the list.
        * @method hide
        * @return jQuery
        * @example 
        * &lt;div id="lb" data-role="ejmlistview"&gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call hide method.
        * $(document).ready(function(){
        * $("#lb").ejmListView("hide");
        * });
        * &lt;/script&gt;
        * @memberof ejmListView
        * @instance
        */

        hide: function (childId) {
            this._getElement(childId).css('visibility', 'hidden');
        },
        //To add list item
        /**
        * To add item in the given index.
        * @method addItem
        * @return jQuery
        * @example 
        * &lt;div id="lb" &gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call addItem method.
        * $(document).ready(function(){
		* $("#lb").ejListView();
        * $("#lb").ejListView("addItem",$("&ltli data-ej-text='Comic / Cartoon'&gt&lt/li&gt"),2);
        * });
        * &lt;/script&gt;
        * @memberof ejListView
        * @instance
        */
        //Mobile
        /**
        * To add item in the given index.
        * @method addItem
        * @return jQuery
        * @example 
        * &lt;div id="lb" data-role="ejmlistview"&gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call addItem method.
        * $(document).ready(function(){
        * $("#lb").ejmListView("addItem",$("&ltli data-ej-text='Comic / Cartoon'&gt&lt/li&gt"),2);
        * });
        * &lt;/script&gt;
        * @memberof ejmListView
        * @instance
        */
        addItem: function (list, index) {
            if (index >= 0)
                list.insertBefore($(this._orgEle.children().children()[index]));
            else
                this._orgEle.children().append(list);
            this._refresh();
        },
        //To remove list item
        /**
        * To remove item in the given index.
        * @method removeItem
        * @return jQuery
        * @example 
        * &lt;div id="lb" &gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call removeItem method.
        * $(document).ready(function(){
		* $("#lb").ejListView();
        * $("#lb").ejListView("removeItem",3);
        * });
        * &lt;/script&gt;
        * @memberof ejListView
        * @instance
        */
        //Mobile
        /**
        * To remove item in the given index.
        * @method removeItem
        * @return jQuery
        * @example 
        * &lt;div id="lb" data-role="ejmlistview"&gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call removeItem method.
        * $(document).ready(function(){
        * $("#lb").ejmListView("removeItem",3);
        * });
        * &lt;/script&gt;
        * @memberof ejmListView
        * @instance
        */
        removeItem: function (index, childId) {
            if (index >= 0) {
                element = this._getElement(childId);
                var child = $(element.find('li.' + this._prefixClass + 'list')[index]).attr('data-childid');
                if (this.element.find($('#' + child).length))
                    this.element.find($('#' + child)).remove();
                $(element.find('li.' + this._prefixClass + 'list')[index]).remove();
            }
        },
        //To clear the control before updating with new datasource
        /**
        * To clear all the list item in the control before updating with new datasource.
        * @method clear
        * @return jQuery
        * @example 
        * &lt;div id="lb" &gt;
        * &lt;/div&gt;  
        * &lt;input id="button" /&gt;<br>         
        * &lt;script&gt;
        * $(document).ready(function(){
        * $("#button").ejButton();
        * $("#button").ejButton({ text: "Clear" });
		* $("#lb").ejListView();
        * $("#lb").ejListView({dataSource:"window.dbitem1"});
        * $("#button").ejButton({	
  	    * click: function (args) { 
	    * $('#lb').ejListView("clear");
        * $("#lb").ejListView({dataSource:"window.dbitem2"});
        * }
        * });
        * });
        * window.dbitem1 =
        * [   { "text": "Hot Singles"},
        *     { "text": "Rising Artists"},
        *     { "text": "Live Music" },
        *     { "text": "Best of 2013 So Far"},
        *     { "text": "100 Albums - $5 Each"},
        *     { "text": "Hip-Hop and R&B Sale"},
        *     { "text": "CD Deals"}];
        * window.dbitem2 =
        * [   { "text": "Music"},
        *     { "text": "Videos"},
        *     { "text": "Games" },
        *     { "text": "Chat"},
        *     { "text": "Others"}];      
        * &lt;/script&gt;  
        * @memberof ejListView
        * @instance
        */
        //Mobile
        /**
        * To clear all the list item in the control before updating with new datasource.
        * @method clear
        * @return jQuery
        * @example 
        * &lt;div id="lb" data-role="ejmlistview" data-ej-datasource="window.dbitem1" &gt;
        * &lt;/div&gt;  
        * &lt;input id="button" type="button" data-role="ejmbutton" data-ej-text="Clear" data-ej-touchend="touchend" /&gt;<br>         
        * &lt;script&gt;
        * window.dbitem1 =
        * [   { "text": "Hot Singles"},
        *     { "text": "Rising Artists"},
        *     { "text": "Live Music" },
        *     { "text": "Best of 2013 So Far"},
        *     { "text": "100 Albums - $5 Each"},
        *     { "text": "Hip-Hop and R&B Sale"},
        *     { "text": "CD Deals"}];
        * window.dbitem2 =
        * [   { "text": "Music"},
        *     { "text": "Videos"},
        *     { "text": "Games" },
        *     { "text": "Chat"},
        *     { "text": "Others"}];
        * function touchend(){
        *     $('#lb').ejmListView("clear");
        *     $("#lb").ejmListView({dataSource:"window.dbitem2"});
        * }
        * &lt;/script&gt;  
        * @memberof ejmListView
        * @instance
        */
        clear: function () {
            this.element.empty().html();
            this._liEl = this.element.find('li.' + this._prefixClass + 'list');
        },
        //To return the list item count
        /**
        * To get the total item count.
        * @method getItemsCount
        * @example 
        * &lt;div id="lb" &gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call getItemsCount method.
        * $(document).ready(function(){
		* $("#lb").ejListView();
        * $("#lb").ejListView("getItemsCount");
        * });
        * &lt;/script&gt;
        * @memberof ejListView
        * @instance
        */
        //Mobile
        /**
        * To get the total item count.
        * @method getItemsCount
        * @example 
        * &lt;div id="lb" data-role="ejmlistview"&gt;
        * 	&lt;ul&gt;
        *		&lt;li data-ej-text="Artwork"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Abstract"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="2 Acrylic Mediums"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Creative Acrylic"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Modern Painting"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Canvas Art"&gt;&lt;/li&gt;
        * 		&lt;li data-ej-text="Black white"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Children"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="Preschool Crafts"&gt;&lt;/li&gt;
        *		&lt;li data-ej-text="School-age Crafts"&gt;&lt;/li&gt;
        *	&lt;/ul&gt;
        * &lt;/div&gt;
        * &lt;script&gt;
        * // Call getItemsCount method.
        * $(document).ready(function(){
        * $("#lb").ejmListView("getItemsCount");
        * });
        * &lt;/script&gt;
        * @memberof ejmListView
        * @instance
        */
        getItemsCount: function (childId) {
            return this._getElement(childId).find('li.' + this._prefixClass + 'list').length;
        }
    });
})(jQuery, Syncfusion);