﻿/**
* @fileOverview Plugin to style the Html Button elements
* @copyright Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
* Use of this code is subject to the terms of our license.
* A copy of the current license can be obtained at any time by e-mailing
* licensing@syncfusion.com. Any infringement will be prosecuted under
* applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/
(function ($, ej, undefined) {
    /**
    * @namespace ej
    * @class ejDiagram
    * @requires jquery.js
    * @requires jquery.easing.min.js
    * @requires jsrender.min.js
    * @requires ej.core.js
    * @requires ej.draggable.js
    * @requires ej.scrollbar.js
    * @requires ej.touch.js
    * @requires ej.diagram.js
    * @requires ej.diagramcommon.js
    * @requires ej.diagraminteraction.js
    * @requires ej.diagramsvg.js
    * @requires ej.diagramtools.js
    * @requires ej.diagramlayout.js
    * @requires ej.matrix.js
    * @classdesc The diagram control provides 2D surface to visualize the data as shapes, lines, text and images. It can be configured to DOM element such as DIV.
    * @example 
    * &lt;div id="diagram"&gt;&lt;/div&gt;<br>
    * &lt;script&gt;
    * //Create Diagram
    $("#diagram").ejDiagram();
    * &lt;/script&gt
    */

    "use strict";
    //#region ej.Diagram widget
    ej.widget("ejDiagram", "ej.datavisualization.Diagram", {
        // widget element will be automatically set in this
        element: null,

        // user defined model will be automatically set in this
        model: null,
        validTags: ["div"],

        //#region defaults
        defaults: {
            /**Specifies the width of the diagram. 
            * @default null
            * @type {string}
            * @example
            * &lt;div id="diagram"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * $("#diagram").ejDiagram({ width:"100%" });
            * &lt;/script&gt
              * @memberof ejDiagram
              * @instance
            */
            width: null,
            /**Specifies the height of the diagram.
            * @default null
            * @type {string}
            * @example
            * &lt;div id="diagram"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * $("#diagram").ejDiagram({ height:"100%" });
            * &lt;/script&gt
              * @memberof ejDiagram
              * @instance
            */
            height: null,
            /**Array of node objects where each object has definition/properties of node.
            * @default []
            * @type {array}
            * @example
            * &lt;div id="diagram"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * var nodes = [{ name: "node", width: 175, height: 60}];
            * $("#diagram").ejDiagram({ nodes:nodes });
            * &lt;/script&gt
              * @memberof ejDiagram
              * @instance
            */
            nodes: [],
            /**Array of connector objects where each object has definition/properties of connector.
            * @default []
            * @type {array}
            * @example
            * &lt;div id="diagram"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * var connectors = [{ name: "connector" sourceNode: "node1", targetNode: "node2"}];
            * $("#diagram").ejDiagram({ connectors:connectors });
            * &lt;/script&gt
              * @memberof ejDiagram
              * @instance
            */
            connectors: [],

            /** To set the default properties for nodes and connectors.
        * @default {}
        * @type {object}
        * @example
        * &lt;div id="diagram"&gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * $("#diagram").ejDiagram({ defaultSettings: { node:  {width: 110, height: 40, fillColor:"skyblue"}}});
        * &lt;/script&gt
        * @memberof ejDiagram
        * @instance
       */
            defaultSettings: {
                /** To set the default properties of connector.
                * @default null
                * @type {object}
                * @example
                * &lt;div id="diagram"&gt;&lt;/div&gt;<br>
                * &lt;script&gt;
                * $("#diagram").ejDiagram({ defaultSettings:{ connector:{ lineColor: "gray", lineWidth: 2 }}});
                * &lt;/script&gt
                 * @alias  ejDiagram#defaultSettings->connector
                  * @memberof ejDiagram
                  * @instance
                */
                connector: null,
                /**To set the default properties of node.
                * @default null
                * @type {object}
                * @example
                * &lt;div id="diagram"&gt;&lt;/div&gt;<br>
                * &lt;script&gt;
                * $("#diagram").ejDiagram({ defaultSettings:{node: { fillColor: "#83A93F", borderColor: "#000000" }}});
                * &lt;/script&gt
                * @alias  ejDiagram#defaultSettings->node
                  * @memberof ejDiagram
                  * @instance
                */
                node: null
            },


            /**To customize the node properties before rendering the node.
               * @default null
               * @type {object}
               * @example
               * &lt;div id="diagram"&gt;&lt;/div&gt;<br>
               * &lt;script&gt;
               *function nodeTemplate(diagram, node) {node.labels[0].text = node.Name};
               * $("#diagram").ejDiagram({ nodeTemplate:nodeTemplate});
               * &lt;/script&gt
                 * @memberof ejDiagram
                 * @instance
               */

            nodeTemplate: null,
            /** To customize the connector properties before rendering the connector.
               * @default null
               * @type {object}
               * @example
               * &lt;div id="diagram"&gt;&lt;/div&gt;<br>
               * &lt;script&gt;
               *function connectorTemplate(diagram, connector, data) {connector.labels[0].text = data.Name};
               * $("#diagram").ejDiagram({ connectorTemplate:connectorTemplate});
               * &lt;/script&gt
                 * @memberof ejDiagram
                 * @instance
               */
            connectorTemplate: null,
            /** Configures the datasource for diagram.
      * @default {id: "Id", parent: "ReportingPerson",dataSource: data  }
      * @type {object}
      * @example
      * &lt;div id="diagram"&gt;&lt;/div&gt;<br>
      * &lt;script&gt;
      * $("#diagram").ejDiagram({ dataSourceSettings: {id: "Id", parent: "ReportingPerson",dataSource: data  }});
      * &lt;/script&gt
         * @memberof ejDiagram
        * @instance
      */
            dataSourceSettings: {
                /** Describes the datasource for diagram. 
            * @default null
            * @type {object}
            * @example
            * &lt;div id="diagram"&gt;&lt;/div&gt;<br>
            * &lt;script&gt;
            * $("#diagram").ejDiagram({ dataSourceSettings: {dataSource: localData}});
            * &lt;/script&gt
            * @alias ejDiagram#dataSourceSettings->dataSource
            */

                dataSource: null,
                /**Describes query to retrieve data from the datasource.
        * @default null
        * @type {object}
        * @example
        * &lt;div id="diagram"&gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        *query: ej.Query().from("Categories").select("CategoryID,CategoryName").take(3);
        * &lt;/script&gt
        * @alias ejDiagram#dataSourceSettings->query
        */
                query: null,
                /**Describes table name to execute query on the corresponding table.
     * @default null
     * @type {String}
     * @example
     * &lt;div id="diagram"&gt;&lt;/div&gt;<br>
     * &lt;script&gt;
     * $("#diagram").ejDiagram({ dataSourceSettings:{tableName: "Categories"}});
     * &lt;/script&gt
     * @alias ejDiagram#dataSourceSettings->tablename
     */
                tableName: null,
                /** Describes the unique id of datasource items.
        * @default null
        * @type {String}
        * @example
        * &lt;div id="diagram"&gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * $("#diagram").ejDiagram({ dataSourceSettings: {id: "CategoryID"}});
        * &lt;/script&gt
        * @alias ejDiagram#dataSourceSettings->id
        */
                id: "",

                /**Describes the parent id of datasource items.
        * @default null
        * @type {String}
        * @example
        * &lt;div id="diagram"&gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        * $("#diagram").ejDiagram({ dataSourceSettings: { parent: "reportingPerson"}});
        * &lt;/script&gt
        * @alias ejDiagram#dataSourceSettings->parent
        */
                parent: "",

                nodes: null,

                connectors: null,
                //nodeBinding: null,
                //connectorBinding: null,
                /**Describes the root node.
      * @default null
      * @type {String}
      * @example
      * &lt;div id="diagram"&gt;&lt;/div&gt;<br>
      * &lt;script&gt;
      * $("#diagram").ejDiagram({ dataSourceSettings: { root: "1"}});
      * &lt;/script&gt
      * @alias ejDiagram#dataSourceSettings->root
     */
                root: "",
            },
            /**Specifies the snap settings of the diagram.
            * @type {object}
               * @memberof ejDiagram
              * @instance
            */
            snapSettings: /** @lends ejDiagram# */ {
                /**Specifies the settings of horizontal grid lines.
                * @type {object}
                * @alias ejDiagram#snapSettings->horizontalGridLines
                */
                horizontalGridLines: {
                    /**Specifies the space between horizontal grid lines
                    * @default [1.25, 18.75, 0.25, 19.75, 0.25, 19.75, 0.25, 19.75, 0.25, 19.75]
                    * @type {array}
                    * @example
                    * &lt;div id="diagram"&gt;&lt;/div&gt;<br>
                    * &lt;script&gt;
                    * $("#diagram").ejDiagram({ snapSettings: { 
                    *     horizontalGridLines: { linesInterval: [1, 14, 0.25, 15, 0.25, 15, 0.25, 15, 0.25, 15] }
                    * }}); 
                    * &lt;/script&gt
                    * @alias ejDiagram#snapSettings->horizontalGridLines->linesInterval
                    */
                    linesInterval: [1.25, 18.75, 0.25, 19.75, 0.25, 19.75, 0.25, 19.75, 0.25, 19.75],
                    /**Specifies the snap intervals for horizontal grid lines.
                    * @default [20]
                    * @type {array}
                    * @example 
                    * &lt;div id="diagram"&gt;&lt;/div&gt;<br>
                    * &lt;script&gt;
                    * $("#diagram").ejDiagram({ snapSettings: { horizontalGridLines: { snapInterval: [10] }}}); 
                    * &lt;/script&gt
                   * @alias ejDiagram#snapSettings->horizontalGridLines->snapInterval
                    */
                    snapInterval: [20],
                    /**Specifies the pattern of dashes and gaps used to stroke horizontal grid lines
                    * @default "0"
                    * @type {string}
                    * @example 
                    * &lt;div id="diagram"&gt;&lt;/div&gt;<br>
                    * &lt;/script&gt
                    * $("#diagram").ejDiagram({ snapSettings: { horizontalGridLines: { lineDashArray: "2 2"}}}); 
                    * &lt;/script&gt
                     * @alias ejDiagram#snapSettings->horizontalGridLines->lineDashArray
                    */
                    lineDashArray: "0",
                    /**		
                    * Line color for horizontal gridlines
                    * @default "lightgray"
                    * @type {string}
                    * @example 
                    * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
                    * &lt;/script&gt
                    * var gridline = { "snapConstraints":"lineColor": "blue" };
                    * //Linecolor of the horizontal gridlines
                    * $("#diagramContent").ejDiagram({snapSettings: { horizontalGridLines: gridline} }); 
                    * &lt;/script&gt
                   * @alias ejDiagram#snapSettings->horizontalGridLines->lineColor
                    */
                    lineColor: "lightgray"
                },
                /**Specifies the settings of vertical grid lines.
                * @type {object}
                * @alias ejDiagram#snapSettings->verticalGridLines
                */
                verticalGridLines: {
                    /**Specifies the space between vertical grid lines
                    * @default [1.25, 18.75, 0.25, 19.75, 0.25, 19.75, 0.25, 19.75, 0.25, 19.75]
                    * @type {array}
                    * @example
                    * &lt;div id="diagram"&gt;&lt;/div&gt;<br>
                    * &lt;script&gt;
                    * $("#diagram").ejDiagram({ snapSettings: { 
                    *     verticalGridLines: { linesInterval: [1, 14, 0.25, 15, 0.25, 15, 0.25, 15, 0.25, 15] }
                    * }}); 
                    * &lt;/script&gt
                    * @alias ejDiagram#snapSettings->verticalGridLines->linesInterval
                    */
                    linesInterval: [1.25, 18.75, 0.25, 19.75, 0.25, 19.75, 0.25, 19.75, 0.25, 19.75],
                    /**Specifies the snap intervals for vertical grid lines.
                    * @default [20]
                    * @type {array}
                    * @example 
                    * &lt;div id="diagram"&gt;&lt;/div&gt;<br>
                    * &lt;script&gt;
                    * $("#diagram").ejDiagram({ snapSettings: { verticalGridLines: { snapInterval: [10] }}}); 
                    * &lt;/script&gt
                  * @alias ejDiagram#snapSettings->verticalGridLines->snapInterval
                    */
                    snapInterval: [20],
                    /**Specifies the pattern of dashes and gaps used to stroke vertical grid lines
                    * @default "0"
                    * @type {string}
                    * @example 
                    * &lt;div id="diagram"&gt;&lt;/div&gt;<br>
                    * &lt;/script&gt
                    * $("#diagram").ejDiagram({ snapSettings: { verticalGridLines: { lineDashArray: "2 2"}}}); 
                    * &lt;/script&gt
                   * @alias ejDiagram#snapSettings->verticalGridLines->lineDashArray
                    */
                    lineDashArray: "0",
                    /**		
               * Line Color of vertical grid lines
               * @default "lightgray"
               * @type {string}
               * @example 
               * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
               * &lt;/script&gt
               * var gridline = { "snapConstraints":"lineColor": "blue" };
               * //Linecolor of the vertical gridlines
               * $("#diagramContent").ejDiagram({snapSettings: { verticalGridLines: gridline} });
               * &lt;/script&gt
              * @alias ejDiagram#snapSettings->verticalGridLines->lineColor
               */
                    lineColor: "lightgray"
                },
                /**		
           * Enables or disables the snapconstraints of gridlines see{@link snapConstraints}
           * @name SnapConstraints
           * @default SnapConstraints.ShowLines 
           * @type {enum}
           * @example 
           * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
           * &lt;/script&gt
           * var gridline = { "snapConstraints": ej.datavisualization.Diagram.SnapConstraints.ShowLines};
           * //snap constraints of gridlines
           * $("#diagramContent").ejDiagram({snapSettings: gridline} });
           * &lt;/script&gt
           * @alias ejDiagram#snapSettings->snapConstraints
           */
                snapConstraints: 1 | 2 | 4 | 8,
                /**		
            * Enables or disables the snap object 
            * @default true
            * @type {Boolean}
            * @example 
            *var snap = {"enableSnapToObject":true};
            * //enableSnapToObject: 
            * $("#diagramContent").ejDiagram({snapSettings: snap}); 
            * @alias ejDiagram#snapSettings->enableSnapToObject
            */
                enableSnapToObject: true,
                /**		
         * The Angle to which the object to be snapped
         * @default 5
         * @type {Number}
         * @example 
         *var snap = {"snapAngle":5};
         * //enableSnapToObject: 
         *$("#diagramContent").ejDiagram({snapSettings: snap}); 
         * @alias ejDiagram#snapSettings->snapAngle
         */
                snapAngle: 5,
                /**		
            * Relative distance between the nearer object and selected object
            * @default 5
            * @type {Number}
            * @example 
            *var snap = {"snapObjectDistance":5};
            * //snapObjectDistance
            *$("#diagramContent").ejDiagram({snapSettings: snap}); 
            * @alias ejDiagram#snapSettings->snapObjectDistance
            */
                snapObjectDistance: 5
            },
            /**		
            * The pageSetting of the diagram
               * @memberof ejDiagram
              * @instance*/
            pageSettings: /** @lends ejDiagram# */ {
                /**		
         * This is used to set the width of the page 
         * @default null
         * @type {Number}
         * @example 
         * //pageWidth
         *$("#diagramContent").ejDiagram({pageSettings: {pageWidth: 4500}}); 
         * @alias ejDiagram#pageSettings->pageWidth
         */
                pageWidth: null,
                /**		
         * This is used to set the height of the page 
         * @default null
         * @type {Number}
         * @example 
         * //pageHeight of the diagram
         *$("#diagramContent").ejDiagram({pageSettings: {pageHeight: 4500}}); 
         * @alias ejDiagram#pageSettings->pageHeight
         */
                pageHeight: null,
                /**		
         * Enables or disables the multiple page
         * @default false
         * @type {Boolean}
         * @example 
         * //multiplePage of the diagram
         *$("#diagramContent").ejDiagram({pageSettings: {multiplePage: false}}); 
         * @alias ejDiagram#pageSettings->multiplePage
         */
                multiplePage: false,
                /**		
         *This is used to set the width of the page border 
         * @default 0
         * @type {Number}
         * @example 
         * //pageBorderWidth of the diagram
         *$("#diagramContent").ejDiagram({pageSettings: {pageBorderWidth: 3}}); 
         * @alias ejDiagram#pageSettings->pageBorderWidth
         */

                pageBorderWidth: 0,
                /**		
          * Used set the background color of the page 
          * @default "#ffffff"
          * @type {String}
          * @example 
          * //pageBackgroundColor of the diagram
          * $("#diagramContent").ejDiagram({pageSettings: {pageBackgroundColor: "#ffffff"}}); 
          * @alias ejDiagram#pageSettings->pageBackgroundColor
          */
                pageBackgroundColor: "#ffffff",
                /**		
         * Used to set the border color of the page
         * @default "#565656"
         * @type {String}
         * @example 
         * //pageBorderColor of the diagram
         *$("#diagramContent").ejDiagram({pageSettings: {pageBorderColor: "#565656"}}); 
         * @alias ejDiagram#pageSettings->pageBorderColor
         */
                pageBorderColor: "#565656",
                /**		
         * Margin of the page
         * @default 24
         * @type {Number}
         * @example 
         * //pageMargin of the diagram
         *$("#diagramContent").ejDiagram({pageSettings: {pageMargin: 24}}); 
         * @alias ejDiagram#pageSettings->pageMargin
         */
                pageMargin: 24,
                /**		
         * Enables or disables the page breaks in diagram
         * @default false
         * @type {Boolean}
         * @example 
         * //showPageBreak of the diagram
         *$("#diagramContent").ejDiagram({pageSettings: {showPageBreak: false}}); 
         * @alias ejDiagram#pageSettings->showPageBreak
         */
                showPageBreak: false,
                /**		
          * Orientation allows placement of element on a page that set through page set up see{@link PageOrientations}
          * @name pageOrientation
          * @default "portrait"
          * @type {enum}
          * @example 
          * //pageOrientation of the diagram
          *$("#diagramContent").ejDiagram({pageSettings: {pageOrientation: "portrait"}}); 
          * @alias ejDiagram#pageSettings->pageOrientation
          */
                pageOrientation: "portrait",

                /**		
      * scrollLimit used to set the scroll limit on the diagram that set through page set up see{@link ScrollLimit}
      * @name scrollLimit
      * @default "infinity"
      * @type {enum}
      * @example 
      * //scrollLimit of the diagram
      *$("#diagramContent").ejDiagram({pageSettings: {scrollLimit: "infinity"}}); 
      * @alias ejDiagram#pageSettings->scrollLimit
      */
                scrollLimit: "infinity",

                /**		
     * scrollableArea used to set the scroll area on the diagram.
     * @name scrollableArea
     * @default {scrollableArea: { x: Infinity, y: Infinity, width: Infinity, height: Infinity }}
     * @type {object}
     * @example 
     * //scrollableArea of the diagram
     *$("#diagramContent").ejDiagram({pageSettings: {scrollableArea: { x: 0, y: 0, width: 0, height: 0 }}}); 
     * @alias ejDiagram#pageSettings->scrollableArea
     */
                scrollableArea: { x: Infinity, y: Infinity, width: Infinity, height: Infinity },

                /**
     * Specifics the auto scroll starting point of diagram control.
     * @name autoScrollBorder
     * @default { autoScrollBorder: { left: 15, top: 15, right: 15, bottom: 15 }}
     * @type {object}
     * @example
     * //scrollableArea of the diagram
     *$("#diagramContent").ejDiagram({pageSettings: {autoScrollBorder: { left: 15, top: 15, right: 15, bottom: 15 }}}); 
     * @alias ejDiagram#pageSettings->autoScrollBorder
     */
                autoScrollBorder: { left: 15, top: 15, right: 15, bottom: 15 },
            },

            locale: "en-US",
            /**		
           *The contextmenu of the diagram
              * @memberof ejDiagram
              * @instance*/
            contextMenu: {
                /**		
      * Collection of items of Contextmenu
      * @default []
      * @type {Object}                          
      * @example 
	  * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
      * &lt;script&gt;
      * //Collection of  items
      *var menucollection = [{ "name": "hyperLink", "text": "Hyperlink", "image": "", "style": "" }];
	  *var contextMenu = { items: menucollection};
      *$("#diagramContent").ejDiagram({contextMenu: contextMenu}); 
      * &lt;/script&gt
      * @alias ejDiagram#contextMenu->items
       * @memberof ejDiagram
         * @instance
        */
                items: [],
                /**To display or hide items of contextmenu
                          * @default true
                          * @type {Boolean}
                          * @example
                          * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
                          * &lt;script&gt;
                          * $("#diagramcontent").ejDiagram({showCustomMenuItemsOnly: true});
                          * &lt;/script&gt
						    * @alias ejDiagram#contextMenu->showCustomMenuItemsOnly
                             * @memberof ejDiagram
                             * @instance
                          */

                showCustomMenuItemsOnly: false
            },
            enableContextMenu: true,
            /** Enables or disables Auto scroll in diagram
           * @default true
           * @type {Boolean}
           * @example
           * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
           * &lt;script&gt;
           * $("#diagramcontent").ejDiagram({enableAutoScroll: true});
           * &lt;/script&gt
              * @memberof ejDiagram
              * @instance
           */
            enableAutoScroll: true,
            /** Enables or disables tooltip of diagram
         * @default true
         * @type {Boolean}
         * @example
         * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
         * &lt;script&gt;
         * $("#diagramcontent").ejDiagram({showTooltip: true});
         * &lt;/script&gt
            * @memberof ejDiagram
              * @instance
         */
            showTooltip: true,
            /** To set custom style for tool tip of diagram
         * @default ""
         * @type {String}
         * @example
         * &lt;script type="text/x-jsrender" id="toolTipId"&gt;
         * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
         *&lt;span &gt;{{:offsetX}}{{:x}}{{:offsetY}}{{:y}}
         * &lt;/script&gt
         *&lt;/span&gt;
         * &lt;script&gt;
         * $("#diagramcontent").ejDiagram({ tooltipTemplateId: "toolTipId"});
         * &lt;/script&gt
            * @memberof ejDiagram
              * @instance
         */
            tooltipTemplateId: "",
            /** To arrange elements on the page in diagram
               * @memberof ejDiagram
              * @instance*/
            layout: /** @lends ejDiagram# */{
                /**		
          * Type of the layout on the page
          * @default "none"
          * @type {String}
          * @example 
          * //type of the layout
          * $("#diagramContent").ejDiagram({layout: {type: "none"}}); 
          * @alias ejDiagram#layout->type
          */
                type: "none",
                /**		
          * Alignment of elements based on some specific direction see {@link LayoutOrientations}
          * @default "topToBottom"
          * @type {String}
          * @example 
          * //orientation of the layout
          *$("#diagramContent").ejDiagram({layout: {orientation: "topToBottom"}}); 
          * @alias ejDiagram#layout->orientation
          */
                orientation: "toptobottom",
                /**		
          * Horizontal Spacing between the nodes in layout
          * @default 30
          * @type {Number}
          * @example 
          * //horizontalSpacing of the layout
          *$("#diagramContent").ejDiagram({layout: {horizontalSpacing: 30}}); 
          * @alias ejDiagram#layout->horizontalSpacing
          */
                horizontalSpacing: 30,
                /**		
          * Vertical Spacing between the nodes in layout
          * @default 30
          * @type {Number}
          * @example 
          * //verticalSpacing of the layout
          *$("#diagramContent").ejDiagram({layout: {verticalSpacing: 30}}); 
          * @alias ejDiagram#layout->verticalSpacing
          */
                verticalSpacing: 30,
                /**		
         * Margin value along X -Axis 
         * @default 0
         * @type {Number}
         * @example 
         * //marginX of the layout
         *$("#diagramContent").ejDiagram({layout: {marginX: 0}}); 
         * @alias ejDiagram#layout->marginX
         */
                marginX: 0,
                /**		
          * Margin value along y -Axis
          * @default 0
          * @type {Number}
          * @example 
          * // marginY of the layout
          *$("#diagramContent").ejDiagram({layout: { marginY: 0}}); 
          * @alias ejDiagram#layout-> marginY
          */
                marginY: 0,
                /**	 Nodes position is set as fixed and draw all node based on the fixed node
             * @default ""
             * @type {String}
             * @example 
             * //fixedNode of the layout
             *$("#diagramContent").ejDiagram({layout: { fixedNode: "nodename"}}); 
             * @alias ejDiagram#layout-> fixedNode
             */
                fixedNode: "",
            },
            /** Enables to choose which interactive feature to be performed
         * @default ""
         * @type {Object}
         * @example
         * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
         * &lt;script&gt;
         * $("#diagramcontent").ejDiagram({ drawingTools: {textTool: ej.datavisualization.Diagram.TextTool()}});
         * &lt;/script&gt
            * @memberof ejDiagram
              * @instance
         */
            drawingTools: {},
            /** Image to be used as an background of the elements
         * @default null
         * @type {String}
         * @example
         * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
         * &lt;script&gt;
         * $("#diagramcontent").ejDiagram({ backgroundImage: "Syncfusion.png"});
         * &lt;/script&gt
            * @memberof ejDiagram
              * @instance
         */
            backgroundImage: null,
            /** color to be used as an background of the elements
     * @default null
     * @type {String}
     * @example
     * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
     * &lt;script&gt;
     * $("#diagramcontent").ejDiagram({ backgroundColor: "red"});
     * &lt;/script&gt
        * @memberof ejDiagram
          * @instance
     */
            backgroundColor: "transparent",

            /** Sets the bridge direction of connectors
       * @default "top" 
       * @type {String}
       * @example 
       * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
       * &lt;script&gt;
       *$("#diagramContent").ejDiagram({bridgeDirection: "top"} }); 
       * &lt;/script&gt
          * @memberof ejDiagram
       * @instance
       */
            bridgeDirection: "top",
            /** Sets the version of the diagram
         * @default "13.1"
         * @type {String}
         * @example
         * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
         * &lt;script&gt;
         * $("#diagramcontent").ejDiagram("instance");
         * &lt;/script&gt
            * @memberof ejDiagram
              * @instance
         */
            version: "13.1",

            /** Sets the default behaviour of the diagram see{@link DiagramConstraints}
           * @default constraints.All 
           * @type {enum}
           * @example 
           * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
           * &lt;script&gt;
           *$("#diagramContent").ejDiagram({constraints: ej.datavisualization.Diagram.DiagramConstraints.Default} }); 
           * &lt;/script&gt
              * @memberof ejDiagram
           * @instance
           */

            constraints: 1 << 1 | 1 << 3 | 1 << 4 | 1 << 5 | 1 << 6,

            /** Sets the default behaviour of the diagram see{@link Tool}
       * @default Tool.All 
       * @type {enum}
       * @example 
       * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
       * &lt;script&gt;
       *$("#diagramContent").ejDiagram({tool: ej.datavisualization.Diagram.Tool.Default} }); 
       * &lt;/script&gt
          * @memberof ejDiagram
       * @instance
       */


            tool: 1 << 1 | 1 << 2,
            /**		
   * Type of the Connector to be drawn through drawing tool see {@link ConnectorType}
   * @default 1
   * @type {String}
   * @example 
   * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
   * &lt;script&gt;
    *$("#diagramContent").ejDiagram({connectorType: ej.datavisualization.Diagram.ConnectorType.straightLine} }); 
   * &lt;/script&gt
   * @memberof ejDiagram
         * @instance
   */

            connectorType: "orthogonalLine",

            /*The selectedItems of the diagram
              * @memberof ejDiagram
              * @instance*/
            selectedItems: {
                /**		
             * Align selected items position along X-axis
             * @default 0
             * @type {Number}
             * @example 
             *$("#diagramContent").ejDiagram({selectedItems: {offsetX: 50}}); 
             * @alias ejDiagram#selectedItems->offsetX
                */
                offsetX: 0,
                /**		
             * Align selected items position along Y-axis
             * @default 0
             * @type {Number}
             * @example 
             *$("#diagramContent").ejDiagram({selectedItems: {offsetY: 50}}); 
             * @alias ejDiagram#selectedItems->offsetY
                */
                offsetY: 0,
                /**		
             * set the width of the selected items.
             * @default 0
             * @type {Number}
             * @example 
             *$("#diagramContent").ejDiagram({selectedItems: {width: 50}}); 
             * @alias ejDiagram#selectedItems->width
                */
                width: 0,
                /**		
             * set the height of the selected items.
             * @default 0
             * @type {Number}
             * @example 
             *$("#diagramContent").ejDiagram({selectedItems: {height: 50}}); 
             * @alias ejDiagram#selectedItems->height
                */
                height: 0,
                /**		
             * set the rotation angle of the selected items.
             * @default 0
             * @type {Number}
             * @example 
             *$("#diagramContent").ejDiagram({selectedItems: {rotateAngle: 50}}); 
             * @alias ejDiagram#selectedItems->offsetX
                */
                rotateAngle: 0,

                children: [],

                /**		
              * Enables or disables the selector constraints see{@link SelectorConstraints}
              * @default SelectorConstraints.All 
              * @type {enum}
              * @example 
              * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
              * &lt;script&gt;
              *$("#diagramContent").ejDiagram({selectedItems:{constraints: ej.datavisualization.Diagram.SelectorConstraints.None} }}); 
              * &lt;/script&gt
                 * @memberof ejDiagram
              * @instance
              */
                constraints: 1 << 1 | 1 << 2 | 1 << 3,

                /** To add frequently using commands around selector
         * @default ""
         * @type {string}
         * @example
         * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
         * &lt;script&gt;
         * var userHandle= [];
         * function createUserHandles() {
         * var cloneHandle = ej.datavisualization.Diagram.UserHandle();
         * userhandle.push(cloneHandles);
         * }
         * $("#diagramcontent").ejDiagram({selectedItems:{userHandles:userHandle}});
         * &lt;/script&gt
            * @memberof ejDiagram
              * @instance
         */
                userHandles: [],
            },


            /**		
        * Allow to set the factor by which we can zoom in or zoom out
        * @default 1
        * @type {Number}
        * @example 
        * &lt;div id="diagramcontent"&gt;&lt;/div&gt;<br>
        * &lt;script&gt;
        *$("#diagramContent").ejDiagram({zoomFactor: 1}); 
        * &lt;/script&gt
        * @memberof ejDiagram
              * @instance
        */
            zoomFactor: 0.2,
            /**
        *Triggers When node collection get change
        * @event
        * @name ejDiagram#nodeCollectionChange
        * @param {Object} argument args parameter from diagram              
        * @param {String} argument.changetype return should be insert or remove
        * @param {Object} argument.element parameter returns node which to be added or deleted
        * @example
        * // nodeCollectionChange event for diagram
        * $("#diagramcontent").ejDiagram({
        * nodeCollectionChange:function (args)  {}
        *  });
        */
            nodeCollectionChange: null,
            /**
       *Triggers When auto scroll get change
       * @event
       * @name ejDiagram#autoScrollChange             
       * @param {String} argument.delay return should be insert or remove
       * @param {Object} argument.distanceFromDiagram parameter returns node which to be added or deleted
       * @example
       * // nodeCollectionChange event for diagram
       * $("#diagramcontent").ejDiagram({
       * autoScrollChange:function (args)  {}
       *  });
       */
            autoScrollChange: null,
            /**
        *Triggers the selected object changed in the diagram model
        * @event
        * @name ejDiagram#itemClick
        * @param {object} argument args.cancel  if the event should be cancelled ,otherwise fasle             
        * @param {String} argument.type return event name
        * @param {Object} argument.actualObject node was clicked
        * @param {Object} argument.selectedObject actual selected object
        * @param {Object} argument.model contains holds the reference of diagram
        
        * @example
        * // connectorCollectionChange event for diagram
        * $("#diagramcontent").ejDiagram({
        * connectorCollectionChange:function (args) {}
        });
        */
            itemClick: null,
            /**
        *Triggers When connector collection get change
        * @event
        * @name ejDiagram#connectorCollectionChange
        * @param {Object} argument args parameter from diagram              
        * @param {String} argument.changetype return should be insert or remove
        * @param {Object} argument.element parameter returns connector which to be added or deleted
        * @example
        * // connectorCollectionChange event for diagram
        * $("#diagramcontent").ejDiagram({
        * connectorCollectionChange:function (args) {}
        });
        */
            connectorCollectionChange: null,
            /**
        *Triggers When selection get change
        * @event
        * @name ejDiagram#selectionChanged
        * @param {Object} argument args parameter from diagram 
        * @param {String} argument.changetype return should be inserted or removed
        * @param {Object} argument.element parameter returns node or connector which to be added or deleted
        * @example
        * //  selectionChange event for diagram
        * $("#diagramcontent").ejDiagram({
        * selectionChange:function (args)  {}
        });
        */
            selectionChange: null,
            /**
        *Triggers When mouse leaves node/connector
        * @event
        * @name ejDiagram#mouseLeave
        * @param {Object} argument args parameter from diagram 
        * @param {Object} argument.element parameter returns node or connector 
            * @param {Object} argument.source the object dragged from this container 
            * @param {Object} argument.target the object is going to be dropped.  
            * @example
            * //  mouseLeave event for diagram
            * $("#diagramcontent").ejDiagram({
            * mouseLeave:function (args)  {}
               });
            */
            mouseLeave: null,
            /**
        *Triggers When mouse enter node/connector
        * @event
        * @name ejDiagram#mouseEnter
        * @param {Object} argument args parameter from diagram 
        * @param {Object} argument.element parameter returns node or connector 
        * @param {Object} argument.source the object dragged from this container 
        * @param {Object} argument.target the object is going to be dropped.  
        * @example
        * //  mouseEnter event for diagram
        * $("#diagramcontent").ejDiagram({
        * mouseEnter:function (args)  {}
        });
        */
            mouseEnter: null,
            /**
        *Triggers When mouse Hover on node/connector
        * @event
        * @name ejDiagram#mouseOver
        * @param {Object} argument args parameter from diagram 
        * @param {Object} argument.diagram parameter returns node or connector 
        * @param {Object} argument.source the object dragged from this container 
        * @param {Object} argument.target the object is going to be dropped.  
        * @example
        * //  mouseOver event for diagram
        * $("#diagramcontent").ejDiagram({
        * mouseOver:function (args)  {}
        });   
        */
            mouseOver: null,
            /**
        *Triggers When click node/connector
        * @event
        * @name ejDiagram#click
        * @param {Object} argument args parameter from diagram 
        * @param {Object} argument.element parameter returns diagram
        * @example
        * //  click event for diagram
        * $("#diagramcontent").ejDiagram({
        * click:function (args)  {}
        });
        */
            click: null,
            /**
        *Triggers When doubleClick node/connector
        * @event
        * @name ejDiagram#doubleClick
        * @param {Object} argument args parameter from diagram 
        * @param {Boolean} argument.cancel if the event should be cancelled ,otherwise fasle
        * @param {Object} argument.element parameter returns selected object in list
        * @example
        * //  doubleClick event for diagram
        * $("#diagramcontent").ejDiagram({
        * doubleClick:function (args)  {}
        });
        */
            doubleClick: null,
            /**
        *Triggers When drag and drop symbols from palette to drawing area 
        * @event
        * @name ejDiagram#drop
        * @param {Object} argument args parameter from diagram 
        * @param {Object} argument.element parameter returns node or connector
        * @example
        * //  drop event for diagram
        * $("#diagramcontent").ejDiagram({
        * drop:function (args)  {}
        });
        */
            drop: null,
            /**
  *Triggers When drag and drop symbols from palette to drawing area 
  * @event
  * @name ejDiagram#drag
  * @param {Object} argument args parameter from diagram 
  * @param {Object} argument.element parameter returns node or connector
  * @example
  * //  deag event for diagram
  * $("#diagramcontent").ejDiagram({
  * drag:function (args)  {}
  });
  */
            drag: null,
            /**
        *Triggers When label edit gets ended 
        * @event
        * @name ejDiagram#textchanged
        * @param {Object} argument args parameter from diagram 
        * @param {Object} argument.element parameter returns shape
        * @param {String} argument.value parameter returns value in label edit box
        * @example
        * // textChanged event for diagram
        * $("#diagramcontent").ejDiagram({
        * textChanged:function (args)  {}
        });
        */
            textChange: null,
            /**
        *Triggers When node size has been change
        * @event
        * @name ejDiagram#nodeSizeChange
        * @param {Object} argument args parameter from diagram 
        * @param {Object} argument.element parameter returns node that was resized
        * @param {Number} argument.offset parameter returns size of the node
        * @param {Boolean} argument.cancel if the event should be cancelled ,otherwise fasle
        * @example
        * // sizeChange event for diagram
        * $("#diagramcontent").ejDiagram({
        * sizeChange:function (args)  {}
         });
        */
            sizeChange: null,
            /**
        *Triggers When connection changes has been done
        * @event
        * @name ejDiagram#connectionChange
        * @param {Object} argument args parameter from diagram 
        * @param {Object} argument.element parameter returns connector
        * @param {String} argument.connection parameter returns source or target node that was connected
        * @param {port} argument.port parameter returns source or target port that was connected
        * @example
        * // connectionChange event for diagram
        * $("#diagramcontent").ejDiagram({
        * connectionChange:function (args)  {}
        }); 
        */
            connectionChange: null,
            /**
        *Triggers When rotate node
        * @event
        * @name ejDiagram#rotationChange
        * @param {Object} argument args parameter from diagram 
        * @param {Object} argument.element parameter returns node
        * @param {Boolean} argument.cancel if the event should be cancelled ,otherwise fasle
        * @example
        * // rotationChange event for diagram
        * $("#diagramcontent").ejDiagram({
        * rotationChange:function (args)  {}
        });
        */
            rotationChange: null,
            /**
          *Triggers When context menu item clicked
          * @event
          * @name ejDiagram#contextMenuClick
          * @param {Object} argument args parameter from diagram  
          * @example
          * // contextMenuClick event for diagram
          * $("#diagramcontent").ejDiagram({
          * contextMenuClick:function (args)  {}
          });
          */
            contextMenuClick: null,
            /**
         *Triggers bofore open the context menu
         * @event
         * @name ejDiagram#contextMenuBeforeOpen
         * @param {Object} argument args parameter from diagram  
         * @example
         * // contextMenuBeforeOpen event for diagram
         * $("#diagramcontent").ejDiagram({
         * contextMenuBeforeOpen:function (args)  {}
         });
         */
            contextMenuBeforeOpen: null,
            /**
       *Triggers when the connectors source point change
       * @event
       * @name ejDiagram#connectorSourceChange
       * @param {Object} argument.point returns source point
       * @param {Object} argument.port returns source port
       * @param {Boolean} argument.cancel if the event should be cancelled ,otherwise fasle
       * @example
       * // connectorSourceChange event for diagram
       * $("#diagramcontent").ejDiagram({
       * connectorSourceChange:function (args)  {}
       });
       */
            connectorSourceChange: null,
            /**
      *Triggers when the connectors target point change
      * @event
      * @name ejDiagram#connectorTargetChange
      * @param {Object} argument.point returns target point
      * @param {Object} argument.port returns target port
      * @param {Boolean} argument.cancel if the event should be cancelled ,otherwise fasle
      * @example
      * // connectorTargetChange event for diagram
      * $("#diagramcontent").ejDiagram({
      * connectorTargetChange:function (args)  {}
      });
      */
            connectorTargetChange: null,
        },

        observables: [
            "nodes",
            "connectors",
            "locale",
            "enableContextMenu",
            "enableAutoScroll",
            "showTooltip",
            "bridgeDirection",
            "tool",
            "zoomFactor",
            "pageSettings.pageHeight",
            "pageSettings.pageWidth",
            "pageSettings.multiplePage",
            "pageSettings.pageBorderWidth",
            "pageSettings.pageBackgroundColor",
            "pageSettings.pageBorderColor",
            "pageSettings.pageMargin",
            "pageSettings.showPageBreak",
            "pageSettings.pageOrientation",
			"pageSettings.scrollLimit",
            "snapSettings.enableSnapToObject",
            "snapSettings.snapAngle",
            "snapSettings.snapObjectDistance",
            "selector.offsetX",
            "selector.offsetY",
            "selector.width",
            "selector.height",
            "selector.rotateAngle",
        ],

        nodes: ej.util.valueFunction("nodes"),
        connectors: ej.util.valueFunction("connectors"),
        locale: ej.util.valueFunction("locale"),
        enableContextMenu: ej.util.valueFunction("enableContextMenu"),
        enableAutoScroll: ej.util.valueFunction("enableAutoScroll"),
        showTooltip: ej.util.valueFunction("showTooltip"),
        bridgeDirection: ej.util.valueFunction("bridgeDirection"),
        tool: ej.util.valueFunction("tool"),
        zoomFactor: ej.util.valueFunction("zoomFactor"),
        _pageHeight: ej.util.valueFunction("pageSettings.pageHeight"),
        _pageWidth: ej.util.valueFunction("pageSettings.pageWidth"),
        _multiplePage: ej.util.valueFunction("pageSettings.multiplePage"),
        _pageBorderWidth: ej.util.valueFunction("pageSettings.pageBorderWidth"),
        _pageBackgroundColor: ej.util.valueFunction("pageSettings.pageBackgroundColor"),
        _pageBorderColor: ej.util.valueFunction("pageSettings.pageBorderColor"),
        _pageMargin: ej.util.valueFunction("pageSettings.pageMargin"),
        _showPageBreak: ej.util.valueFunction("pageSettings.showPageBreak"),
        _pageOrientation: ej.util.valueFunction("pageSettings.pageOrientation"),
        _scrollLimit: ej.util.valueFunction("pageSettings.scrollLimit"),
        _enableSnapToObject: ej.util.valueFunction("snapSettings.enableSnapToObject"),
        _snapAngle: ej.util.valueFunction("snapSettings.snapAngle"),
        _snapObjectDistance: ej.util.valueFunction("snapSettings.snapObjectDistance"),
        _selectorOffsetX: ej.util.valueFunction("selector.offsetX"),
        _selectorOffsetY: ej.util.valueFunction("selector.offsetY"),
        _selectorWidth: ej.util.valueFunction("selector.width"),
        _selectorHeight: ej.util.valueFunction("selector.height"),
        _selectorRotateAngle: ej.util.valueFunction("selector.rotateAngle"),

        dataTypes: {
            contextMenu: {
                items: "array",
                showCustomMenuItemsOnly: "boolean"
            },
            layout: {
                type: "enum",
                orientation: "enum",
                horizontalSpacing: "number",
                verticalSpacing: "number",
                marginX: "number",
                marginY: "number"
            },
        },

        //#endregion

        //#region Local members
        _canvas: null,
        _svg: null,
        _toolToActivate: null,
        _inAction: false,
        _isPinching: false,
        _isEditing: false,
        _nodeToHit: null,
        _currentCursor: null,
        _pasteIndex: null,
        _page: null,
        _view: null,
        _currentLabel: null,
        _zOrder: 0,
        _clipboardData: null,
        _currZoom: 1,
        _selectedItem: "",
        _historyList: {
            currentEntry: {
                next: null,
                previous: null
            },
            canUndo: false,
            canRedo: false
        },

        _defaultContextMenuItems: [
            { name: "cut", text: "Cut" },
            { name: "copy", text: "Copy" },
            { name: "paste", text: "Paste" },
            { name: "undo", text: "Undo" },
            { name: "redo", text: "Redo" },
            { name: "selectAll", text: "Select All" },
            {
                name: "grouping",
                text: "Grouping",
                subItems: [
                            { name: "group", text: "Group" },
                            { name: "ungroup", text: "Ungroup" }
                ]
            },
            {
                name: "order",
                text: "Order",
                subItems: [
                            { name: "bringToFront", text: "Bring To Front" },
                            { name: "moveForward", text: "Move Forward" },
                            { name: "sendToBack", text: "Send To Back" },
                            { name: "sendBackward", text: "Send Backward" }
                ]
            }
        ],

        _hScrollOffset: 0,
        _vScrollOffset: 0,
        _hScrollbar: null,
        _vScrollbar: null,
        _scrollPixel: 30,
        //#endregion

        //#region public members
        activeTool: null,
        selectionList: [],
        tools: null,
        nameTable: {},
        //#endregion

        //#region Initialization
        _updateScrollOffset: function (hScrollOffset, vScrollOffset, canScale) {
            this._hScrollOffset = hScrollOffset;
            this._vScrollOffset = vScrollOffset;
            ej.datavisualization.Diagram.ScrollUtil._transform(this, hScrollOffset, vScrollOffset, canScale);
            var diagram = this;
            this._views.forEach(function (viewid) {
                var view = diagram._views[viewid];
                if (view.type == "overview") {
                    var ovw = $("#" + viewid).ejOverview("instance");
                    if (ovw)
                        ovw._scrollOverviewRect(hScrollOffset, vScrollOffset, diagram._currZoom);
                }
            });
        },

        _init: function () {
            var svgSupport = (window.SVGSVGElement) ? true : false;
            if (svgSupport) {
                this._spatialSearch = ej.datavisualization.Diagram.SpatialSearch();
                this._initDefaults();
                this._initViews();
                this._initData();
                this._doLayout();
                this._initCanvas();
                this._initDiagramTool();
                this._initVisualGuide();
                this._wireEvents();
                this._initHandles();
                this._initContextMenu();
                this._drawingTool = false;
                this._isDropped = false;
            }
        },

        _setModel: function (options) {
            for (var option in options) {
                switch (option) {
                    case "height": 
                    case "width":
                        this._initViews(true);
                        this._initCanvas(true);
                        break;
                    case "nodes":
                        this.nodes(typeof option.nodes === 'function' ? option.nodes() : option.nodes);
                        this._initNodeCollection(true);
                        $(this.element).find(".ej-d-node").remove();
                        $(this.element).find(".ej-d-group").remove();
                        if (this._hasSelection())
                            this._clearSelection();
                        var diagram = this;
                        this._views.forEach(function (viewid) {
                            var view = diagram._views[viewid];
                            diagram._setNodeZOrder(view);
                            diagram._renderNodes(view, true);
                        });
                        break;
                    case "connectors":
                        this.connectors(typeof option.connectors === 'function' ? option.connectors() : option.connectors);
                        this._initConnectorCollection();
                        $(this.element).find(".ej-d-connector").remove();
                        if (this._hasSelection())
                            this._clearSelection();
                        var diagram = this;
                        this._views.forEach(function (viewid) {
                            var view = diagram._views[viewid];
                            diagram._renderConnectors(view);
                        });
                        break;
                    case "phases":
                        this.element.remove(".ej-d-node");
                        this.element.remove(".ej-d-group");
                        var diagram = this;
                        this._views.forEach(function (viewid) {
                            var view = diagram._views[viewid];
                            diagram._renderphases(view);
                        });
                        break;
                    case "enableContextMenu":
                    case "contextMenu":
                        this.model.contextMenu = options[option];
                        this._initContextMenu(true);
                        break;
                    case "snapSettings":
                        var object = options[option];
                        if (object && Object.keys(object).length > 0) {
                            this._updateSnapSettings(options[option]);
                            ej.datavisualization.Diagram.SvgContext._renderGrid(this._canvas, this._svg, this._page, this);
                        }
                        break;
                    case "selectorConstraints":
                        this._setSelectorConstraints(options[option]);
                        break;
                    case "constraints":
                        if (this._hasSelection())
                            this._clearSelection();
                        break;
                    case "drawingTools":
                        this.model.drawingTools = options[option];
                        this._registerDrawingTools();
                        break;
                    case "backgroundImage":
                        this.model.backgroundImage = options[option];
                        ej.datavisualization.Diagram.SvgContext._renderBackground(this._canvas, this._svg, this._page, this.model);
                        break;
                    case "enableAutoScroll":
                        this.enableAutoScroll(options[option]);
                        break;
                    case "autoScrollMargin":
                        this.model.autoScrollMargin = options[option];
                        break;
                    case "layout":
                        this.model.layout = $.extend(true, {}, this.model.layout, options[option]);
                        this._setLayout(options[option]);
                        break;
                    case "selectedItems":
                        this.updateSelector(options[option]);
                        break;
                    case "pageSettings":
                        this.updatePageSettings(options[option]);
                        break;
                    case "locale":
                        this.locale(options[option]);
                        var contextmenu = document.getElementById(this.element[0].id + "_contextMenu");
                        contextmenu.parentNode.removeChild(contextmenu);
                        if (this.model.contextMenu && this.model.contextMenu.items && this.model.contextMenu.items.length > 0)
                            this.model.contextMenu.items = [];
                        this._renderContextMenu();
                        break;
                    case "nodeTemplate":
                        this.clear();
                        this._initData();
                        var diagram = this;
                        this._views.forEach(function (viewid) {
                            var view = diagram._views[viewid];
                            diagram._renderNodes(view);
                            diagram._renderConnectors(view);
                        });
                        this.layout();
                        break;
                    case "bridgeDirection":
                    case "tool":
                        this.update(options);
                        break;
                    case "connectorTemplate":
                        this._updateConnectors();
                        break;
                    case "dataSourceSettings":
                        var object = options[option];
                        if (object && Object.keys(object).length > 0) {
                            this.clear();
                            $.extend(true, this.model.dataSourceSettings, {}, options[option]);
                            this._initData();
                            var diagram = this;
                            this._views.forEach(function (viewid) {
                                var view = diagram._views[viewid];
                                diagram._renderNodes(view);
                                diagram._renderConnectors(view);
                            });
                            this.layout();
                        }
                        break;
                }
            }
        },

        _initData: function () {
            if (this.model.dataSourceSettings)
                var dataSource = this.model.dataSourceSettings.dataSource || this.model.dataSourceSettings.nodes || this.model.dataSourceSettings.connectors;
            if (dataSource) {
                var nodes = [];
                var connectors = [];
                var dataSourceApplied;
                if (this.model.dataSourceSettings.nodes || this.model.dataSourceSettings.connectors) {
                    if (this.model.dataSourceSettings.nodes) {
                        dataSource = this.model.dataSourceSettings.nodes.dataSource || this.model.dataSourceSettings.dataSource;
                        if (dataSource) {
                            if (dataSource instanceof ej.DataManager) {
                                $.ajaxSetup({
                                    async: false
                                });
                                var query = this._findQuery(this.model.dataSourceSettings.nodes, this.model.dataSourceSettings.nodeBinding);
                                var queryPromise = dataSource.executeQuery(eval(query));
                                var diagram = this;
                                queryPromise.done(function (e) {
                                    diagram.retriveData = e.result;
                                    diagram._applyTemplate(diagram.model.dataSourceSettings, e.result, nodes, "nodes");
                                });
                            } else
                                this._applyTemplate(this.model.dataSourceSettings, dataSource, nodes, "nodes");
                        }
                        if (this.model.dataSourceSettings.connectors) {
                            dataSource = this.model.dataSourceSettings.connectors.dataSource || this.model.dataSourceSettings.dataSource;
                            if (dataSource) {
                                if (dataSource instanceof ej.DataManager) {
                                    $.ajaxSetup({
                                        async: false
                                    });
                                    query = this._findQuery(this.model.dataSourceSettings.connectors, this.model.dataSourceSettings.connectorBinding);
                                    queryPromise = dataSource.executeQuery(eval(query));
                                    queryPromise.done(function (e) {
                                        diagram.retriveData = e.result;
                                        diagram._applyTemplate(diagram.model.dataSourceSettings, e.result, connectors, "connectors");
                                    });
                                } else {
                                    this._applyTemplate(this.model.dataSourceSettings, dataSource, connectors, "connectors");
                                }
                            }
                        }
                    }
                } else if (dataSource instanceof ej.DataManager)
                    this._initDataSource(dataSource, nodes, connectors);
                else if (dataSource.length) {
                    this._applyDataSource(this.model.dataSourceSettings, dataSource, nodes, connectors);
                    dataSourceApplied = true;
                }
                var tempNodes = [], tempconnectors = [];
                if (this.nodes().length > 0)
                    tempNodes = this.nodes();
                if (this.connectors().length > 0)
                    tempconnectors = this.connectors();
                this.nodes(nodes);
                this.connectors(connectors);

                for (var i = 0; i < tempNodes.length; i++) {
                    this.nodes().push(tempNodes[i]);
                }
                for (var i = 0; i < tempconnectors.length; i++) {
                    this.connectors().push(tempconnectors[i]);
                }

            }
            var collapsedNodes = this._initNodeCollection(false, dataSourceApplied);
            this._initConnectorCollection(dataSourceApplied);
            if (collapsedNodes.length > 0) {
                this._collapseNodes(collapsedNodes);
            }
        },

        _initDataSource: function (dataSource, nodes, connectors) {
            var diagram = this;
            if (!dataSource.dataSource.table) {
                var mapper = this.model.dataSourceSettings;
                if (dataSource instanceof ej.DataManager) {
                    $.ajaxSetup({
                        async: false
                    });
                    var query = this._findQuery(mapper, this.model.dataSourceSettings.nodeBinding);
                    var queryPromise = this.model.dataSourceSettings["dataSource"].executeQuery(eval(query));
                    queryPromise.done(function (e) {
                        diagram.retriveData = e.result;
                        diagram._applyDataSource(diagram.model.dataSourceSettings, e.result, nodes, connectors);
                    });
                }
            }
            else {
                diagram._applyDataSource(diagram.model.dataSourceSettings, dataSource.dataSource.json, nodes, connectors);
            }
        },

        _findQuery: function (mapper, binding) {
            var column = [], queryManager = ej.Query();
            var query = mapper.query || this.model.dataSourceSettings.query;

            if (ej.isNullOrUndefined(query)) {
                var dataSource = mapper.dataSource || this.model.dataSourceSettings.dataSource;
                var tableName = mapper.tableName || this.model.dataSourceSettings.tableName;;
                for (var col in mapper) {
                    if (col !== "tableName" && col !== "dataSource" && col !== "designTemplate" && !col.match("Binding"))
                        if (mapper[col]) column.push(mapper[col]);
                }
                for (var tempcol in binding) {
                    if (tempcol === "labels") {
                        var labels = binding[tempcol];
                        for (var i = 0; i < labels.length; i++) {
                            if (labels[i].text) column.push(labels[i].text);
                        }
                    } else if (tempcol == "shape" || tempcol == "line") {
                        if (binding[tempcol][type]) col.push(binding[tempcol][type]);
                    } else
                        if (binding[tempcol]) column.push(binding[tempcol]);
                }

                if (column.length > 0)
                    queryManager.select(column);
                if (!dataSource["dataSource"].url.match(tableName + "$"))
                    !ej.isNullOrUndefined(tableName) && queryManager.from(tableName);

            } else
                queryManager = query;
            return queryManager;
        },

        _applyDataSource: function (mapper, data, nodes, connectors, ancestor) {
            var rootNodes = ej.DataManager(data).executeLocal(ej.Query().group(mapper.parent));
            if (mapper.parent) {
                var firstLvel = [];
                if (mapper.root != "") {
                    var rootNode = ej.DataManager(data).executeLocal(ej.Query().where(mapper.id, ej.FilterOperators.equal, mapper.root))
                    if (rootNode.length > 0) {
                        if (mapper.root === rootNode[0][mapper.id]) {
                            firstLvel.push({ items: [rootNode[0]] });
                        }
                    }
                }
                else {
                    for (var i = 0; i < rootNodes.length; i++) {
                        if ((!rootNodes[i].key && rootNodes[i].key !== 0) || rootNodes[i].key == "undefined" || rootNodes[i].key == "\"\"" || rootNodes[i].key == "null") {
                            firstLvel.push(rootNodes[i]);
                        }
                    }
                }
            }
            else firstLvel = rootNodes;
            var nodeBinding = this.model.dataSourceSettings.nodeBinding || {};
            var nodeDefaults = this.model.defaultSettings.node || {};
            var connectorDefaults = this.model.defaultSettings.connector || {};
            var connectorBinding = this.model.dataSourceSettings.connectorBinding || {};
            for (var i = 0; i < firstLvel.length; i++) {
                for (var j = 0; j < firstLvel[i].items.length; j++) {
                    var item = firstLvel[i].items[j];
                    var node = this._applyNodeTemplate(mapper, item, nodeBinding, nodeDefaults);
                    nodes.push(node);
                    var nextLevel = ej.DataManager(rootNodes).executeLocal(ej.Query().where("key", ej.FilterOperators.equal, item[mapper.id]));
                    if (nextLevel[0] && nextLevel[0].items)
                        this._renderChildNodes(mapper, nextLevel[0], node.name, nodes, connectors, rootNodes);
                }
            }
        },

        _renderChildNodes: function (mapper, parent, ancestor, nodes, connectors, rootNodes) {
            var nodeBinding = this.model.dataSourceSettings.nodeBinding || {};
            var nodeDefaults = this.model.defaultSettings.node || {};
            var connectorDefaults = this.model.defaultSettings.connector || {};
            var connectorBinding = this.model.dataSourceSettings.connectorBinding || {};
            for (var j = 0; j < parent.items.length; j++) {
                var child = parent.items[j];
                var node = this._applyNodeTemplate(mapper, child, nodeBinding, nodeDefaults);
                nodes.push(node);
                connectors.push(this._applyConnectorTemplate(mapper, null, connectorBinding, connectorDefaults, ancestor, node.name));
                var nextLevel = ej.DataManager(rootNodes).executeLocal(ej.Query().where("key", ej.FilterOperators.equal, child[mapper.id]));
                if (nextLevel[0] && nextLevel[0].items)
                    this._renderChildNodes(mapper, nextLevel[0], node.name, nodes, connectors, rootNodes);
            }
        },

        _applyTemplate: function (mapper, data, collection, collname) {
            if (collname == "nodes") {
                var template = this.model.dataSourceSettings.nodeBinding || {};
                var defaults = this.model.defaultSettings.node || {};
                for (var i = 0; i < data.length; i++) {
                    var node = this._applyNodeTemplate(mapper, data[i], template, defaults);
                    collection.push(node);
                }
            }
            if (collname == "connectors") {
                var template = this.model.dataSourceSettings.connectorBinding || {};
                var defaults = this.model.defaultSettings.connector || {};
                for (var i = 0; i < data.length; i++) {
                    var conn = this._applyConnectorTemplate(mapper, data[i], template, defaults);
                    collection.push(conn);
                }
            }
        },

        _applyNodeTemplate: function (mapper, item, nodeBinding, nodeDefaults) {
            var root = jQuery.extend(true, {}, nodeDefaults, item);
            if (root.name === "" || !root.name)
                root.name = ej.datavisualization.Diagram.Util.randomId();
            if (nodeBinding) {
                for (var prop in nodeBinding) {
                    if (prop != "labels")
                        root[prop] = item[nodeBinding[prop]];
                }
                if (nodeBinding.labels) {
                    if (!root.labels) {
                        root.labels = [];
                    }
                    for (var i = 0; i < nodeBinding.labels.length; i++) {
                        var label = nodeDefaults && nodeDefaults.labels && nodeDefaults.labels.length ? nodeDefaults.labels[i % nodeDefaults.labels.length] : {};
                        label.name = ej.datavisualization.Diagram.Util.randomId();
                        label.text = item[nodeBinding.labels[i].text];
                        root.labels[i] = label;
                    }
                }
                if (nodeBinding.shape) {
                    var shape = nodeDefaults && nodeDefaults.shape ? nodeDefaults.shape : {};
                    shape.type = item[nodeBinding.shape.type];
                    root.shape = shape;
                }
            }
            root = ej.datavisualization.Diagram.Node(root);
            if (root)
                root = this._getNewNode(root);
            if (this.model.nodeTemplate) {
                if (typeof this.model.nodeTemplate === "string") {
                    this.model.nodeTemplate = ej.util.getObject(this.model.nodeTemplate, window);
                }
                if ($.isFunction(this.model.nodeTemplate)) {
                    this.model.nodeTemplate(this, root);
                }
            }

            if (root.type == "group") {
                root = this._getNewGroup(root);
                this._initGroupNode(root);
            }
            else if (root.type == "node") {
                root = this._getNewNode(root)
            }

            return root;
        },

        _applyConnectorTemplate: function (mapper, item, connectorBinding, connectorDefaults, sourceNode, targetNode) {
            var connector = jQuery.extend(true, {}, connectorDefaults);
            connector.name = ej.datavisualization.Diagram.Util.randomId();
            connector.sourceNode = sourceNode;
            connector.targetNode = targetNode;
            if (connectorBinding) {
                for (var prop in connectorBinding) {
                    if (prop != "labels")
                        connector[prop] = item[connectorBinding[prop]];
                }
                if (connectorBinding.labels) {
                    if (!connector.labels) {
                        connector.labels = [];
                    }
                    for (var i = 0; i < connectorBinding.labels.length; i++) {
                        var label = connectorDefaults && connectorDefaults.labels && connectorDefaults.labels.length ? connectorDefaults.labels[i % connectorDefaults.labels.length] : {};
                        label.name = ej.datavisualization.Diagram.Util.randomId();
                        label.text = item[connectorBinding.labels[i].text];
                        connector.labels[i] = label;
                    }
                }
                //if (connectorBinding.segments) {
                //    var line = {};
                //    line.type = item[connectorBinding.line.type];
                //    connector.line = line;
                //}
            }
            var connector = ej.datavisualization.Diagram.Connector(connector);
            if (this.model.connectorTemplate) {
                this.model.connectorTemplate(this, connector, item);
            }
            return connector;
        },

        _collapseNodes: function (nodes) {
            for (var i = 0; i < nodes.length; i++) {
                var node = nodes[i];
                this._collapseChildren(node);
            }
        },

        _initViews: function (isLoad) {
            if (!isLoad) {
                this._views = [];
                this._views.push(this._id);
            }
            this._views[this._id] = {
                "type": "mainview",
                "context": ej.datavisualization.Diagram.SvgContext,
                "style": "position:relative; height:" + this.model.height + "; width:" + this.model.width + ";"
            };
        },
        _setOverview: function (overview, id) {
            if (overview) {
                this._overview = overview;
                if (!this._views[overview._id]) {
                    this._views.push(overview._id);
                    this._views[overview._id] = { "context": ej.datavisualization.Diagram.SvgContext, "type": "overview" };
                    overview._renderDocument(this._views[overview._id]);
                    this._setNodeZOrder(this._views[overview._id]);
                    this._renderNodes(this._views[overview._id], null, true);
                    this._renderConnectors(this._views[overview._id]);
                    overview._updateOverview(this._views[overview._id]);
                }
            } else {
                var overview = $("#" + id).ejOverview("instance");
                overview._removeDocument(this._views[id]);
                this._views[id] = undefined;
                var index = this._views.indexOf(id);
                this._views.splice(index, 1);
                //this._overview = null;
            }

        },

        _getChild: function (child) {
            if (child) {
                if (typeof (child) == "object") {
                    return child.name;
                }
                else {
                    return child;
                }
            }
        },

        _getChildren: function (children) {
            if (children) {
                var children1 = [];
                for (var i = 0; i < children.length; i++) {
                    var child = children[i];
                    if (child) {
                        if (typeof (child) == "object") {
                            children1.push(child.name);
                        }
                        else {
                            children1.push(child);
                        }
                    }
                }
                return children1;
            }
        },
        _initGroupNode: function (group) {
            var child = null;
            for (var i = 0; i < group.children.length; i++) {
                child = group.children[i];
                if (child && typeof (child) == "object") {
                    if (child.type != "group" && !child.children && !child.segments && child.type != "connector") {
                        group.children[i] = child = this._getNewNode(child);
                        if (child.name == "") {
                            child.name = ej.datavisualization.Diagram.Util.randomId();
                        }
                    }
                    else if (child.segments || child.type == "connector") {
                        group.children[i] = child = this._getNewConnector(child);
                        if (child.name == "") {
                            child.name = ej.datavisualization.Diagram.Util.randomId();
                        }
                    }
                    else {
                        group.children[i] = child = this._getNewGroup(child);
                        if (child.name == "") {
                            child.name = ej.datavisualization.Diagram.Util.randomId();
                        }
                        this._initGroupNode(child);
                    }
                    child.parent = group.name;
                    this.nameTable[child.name] = child;
                    this.nodes()[this.nodes().length] = this.nameTable[child.name];
                }
            }
        },
        _initNodeCollection: function (isLoad, dataSourceApplied) {
            var collapsedNodes = [];
            var nodes = this.nodes();
            var length = this.nodes().length;
            for (var i = 0; i < length; i++) {
                if (nodes[i].name == "") {
                    nodes[i].name == ej.datavisualization.Diagram.Util.randomId();
                }
                if (nodes[i].type == "swimlane" || nodes[i].isSwimlane) {
                    if (isLoad)
                        nodes[i] = nodes[i];
                    else
                        nodes[i] = ej.datavisualization.Diagram.SwimLaneHelper._initSwimLane(nodes[i], this);
                    this.nameTable[nodes[i].name] = ej.datavisualization.Diagram.Group(nodes[i]);

                }
                else if (nodes[i].type == "group" || (nodes[i].children && nodes[i].children.length > 0)) {
                    nodes[i] = ej.datavisualization.Diagram.Group(nodes[i]);
                    this.nameTable[nodes[i].name] = nodes[i];
                    this._initGroupNode(nodes[i]);
                }
                else {
                    if (!dataSourceApplied)
                        nodes[i] = this._getNewNode(nodes[i]); //ej.datavisualization.Diagram.Node(nodes[i]);
                    this.nameTable[nodes[i].name] = nodes[i];
                    ej.datavisualization.Diagram.SpatialUtil._updateQuad(this, this._spatialSearch, nodes[i]);
                }
                if (nodes[i].type == "node" && nodes[i].labels.length && (nodes[i].width == 0 || nodes[i].height == 0))
                    this._getNodeDimension(nodes[i], nodes[i].labels[0]);
                this.nameTable[nodes[i].name] = nodes[i];
                if (!nodes[i].isExpanded) {
                    collapsedNodes.push(nodes[i]);
                }
            }
            return collapsedNodes;
        },
        _getNodeDimension: function (node, label, labelText) {
            var text = document.createElement("span");
            ej.datavisualization.Diagram.Util.attr(text, { "id": node.name + "_" + label.name, "class": "ej-d-label", "style": "display: inline-block; position: absolute; pointer-events: all; line-height: normal; " });
            if (label.bold) text.style.fontWeight = "bold";
            if (label.italic) text.style.fontStyle = "italic";
            text.style.textDecoration = label.textDecoration;
            text.style.fontFamily = label.fontFamily;
            text.style.fontSize = label.fontSize + "px";
            text.style.color = label.fontColor;
            text.style.backgroundColor = label.fillColor;
            text.style.borderColor = label.borderColor;
            text.style.borderWidth = label.borderWidth;
            text.textContent = labelText ? labelText : label.text;
            text.style.wordWrap = "normal";
            text.style.whiteSpace = "pre-wrap";
            this.element[0].appendChild(text)
            node._width = text.offsetWidth + label.margin.left + label.margin.right;
            node._height = text.offsetHeight + label.margin.top + label.margin.bottom;
            this.element[0].removeChild(text);
        },
        _getNewNode: function (options) {
            return ej.datavisualization.Diagram.Node($.extend(true, {}, this.model.defaultSettings.node, options));
        },

        _getNewGroup: function (options) {
            var child = null;
            if (options.children && options.children.length > 0) {
                for (var i in options.children) {
                    child = this.nameTable[this._getChild(options.children[i])];
                    if (child) {
                        if (child.segments) {
                            if (this.nameTable[child.name])
                                delete this.nameTable[child.name];
                            this.nameTable[child.name] = this._getNewConnector(child);
                            this._dock(this.nameTable[child.name], this.nameTable);
                            ej.datavisualization.Diagram.Util.updateBridging(this.nameTable[child.name], this);
                            this._updateQuad(this, this.nameTable[child.name]);
                        }
                        else if (child.type == "node") {
                            if (this.nameTable[child.name])
                                delete this.nameTable[child.name];
                            this.nameTable[child.name] = this._getNewNode(child);
                        }
                        else if (child.type == "group") {
                            if (this.nameTable[child.name])
                                delete this.nameTable[child.name];
                            this.nameTable[child.name] = this._getNewGroup(child);
                        }
                    }
                }
            }
            return ej.datavisualization.Diagram.Group($.extend(true, {}, this.model.defaultSettings.node, options));

        },
        _getNewConnector: function (options) {
            var obj = $.extend(true, {}, this.model.defaultSettings.connector, options);
            if (this.model.defaultSettings.connector && (this.model.defaultSettings.connector.segments && this.model.defaultSettings.connector.segments[0])) {
                obj.defaultType = this.model.defaultSettings.connector.segments[0].type;
            }
            ej.datavisualization.Diagram.Util._initConnectionEnds(obj, this);
            return ej.datavisualization.Diagram.Connector(obj);
        },
        _getTightChildrenBounds: function (node) {
            var children = this._getChildren(node.children), rect, bounds = null, child;
            for (var i = 0, len = children.length; i < len; i++) {
                child = this.nameTable[children[i]];
                if (child) {
                    var rect1 = ej.datavisualization.Diagram.Util.bounds(child);
                    rect = ej.datavisualization.Diagram.Geometry.rect([rect1.topLeft, rect1.topRight, rect1.bottomRight, rect1.bottomLeft]);
                    if (child.verticalAlign == "stretch") {
                        rect.height = 0;
                    } else if (child.horizontalAlign == "stretch") {
                        rect.width = 0;
                    }
                }
                if (bounds)
                    bounds = this._union(rect, bounds);
                else
                    bounds = rect;
            }
            return bounds;
        },
        _getBoundsWithoutStretch: function (node, vertical, horizontal) {
            var children = this._getChildren(node.children), rect, rect1, bounds = null, child;
            for (var i = 0, len = children.length; i < len; i++) {
                child = this.nameTable[children[i]];
                rect1 = ej.datavisualization.Diagram.Util.bounds(child);
                rect = ej.datavisualization.Diagram.Geometry.rect([rect1.topLeft, rect1.topRight, rect1.bottomRight, rect1.bottomLeft]);
                if (vertical) {
                    if (child.verticalAlign == "stretch" && !(child.verticalAlign == "stretch" && child.horizontalAlign == "stretch")) {
                        rect.height = 0;
                    }
                } else if (horizontal) {
                    if (child.horizontalAlign == "stretch" && !(child.verticalAlign == "stretch" && child.horizontalAlign == "stretch")) {
                        rect.width = 0;
                    }
                }

                if (bounds)
                    bounds = this._union(rect, bounds);
                else
                    bounds = rect;
            }

            bounds.width += node.paddingLeft + node.paddingRight;
            bounds.height += node.paddingTop + node.paddingBottom;
            return bounds;
        },
        _getMinMaxSize: function (node, width, height, stretch) {
            var nw = null, nh = null;
            if (width >= node.minWidth && width <= node.maxWidth) {
                nw = width;
            } else {
                if (node.horizontalAlign == "stretch" && node.parent && !stretch) {
                    var group = this.nameTable[node.parent];
                    if (group) {
                        var rSize = ej.datavisualization.Diagram.Util.bounds(group);// ej.datavisualization.Diagram.SvgContext._measureCanvasSize(group, this);
                        if (rSize.width == 0 && rSize.height == 0) {
                            rSize.width = width;
                            rSize.height = height;
                        }
                        var newSize = this._getMinMaxSize(group, rSize.width, rSize.height);
                        newSize.width -= (group.paddingLeft + group.paddingRight + group.marginLeft + group.marginRight);
                        newSize.height -= (group.paddingTop + group.paddingBottom + group.marginTop + group.marginBottom);
                        nw = newSize.width ? newSize.width : width;
                    }
                } else if (width < node.minWidth && node.minWidth != 0)
                    nw = node.minWidth;
                else if (width > node.maxWidth && node.maxWidth != 0)
                    nw = node.maxWidth;
                else
                    nw = width;
            }

            if (height >= node.minHeight && height <= node.maxHeight) {
                nh = height;
            } else {
                if (node.verticalAlign == "stretch" && node.parent && !stretch) {
                    var group = this.nameTable[node.parent];
                    var rSize = ej.datavisualization.Diagram.Util.bounds(group);
                    if (rSize.width == 0 && rSize.height == 0) {
                        //rSize.width = width;
                        //rSize.height = height;
                        var status = null;
                        var state = false;
                        rSize.width = node.minWidth;
                        rSize.height = node.minHeight;
                        if (node.minWidth == 0 && node.minHeight == 0) {
                            rSize.width = width;
                            rSize.height = height;
                            status = false;
                            state = true;
                        }
                        if (!state)
                            status = true;
                    }
                    var newSize = this._getMinMaxSize(group, rSize.width, rSize.height);
                    newSize.width -= (group.paddingLeft + group.paddingRight + group.marginLeft + group.marginRight);
                    newSize.height -= (group.paddingTop + group.paddingBottom + group.marginTop + group.marginBottom);
                    if (status) {
                        newSize.height -= node.marginTop;

                    }
                    nh = newSize.height ? newSize.height : height;
                } else if (height < node.minHeight && node.minHeight != 0)
                    nh = node.minHeight;
                else if (height > node.maxHeight && node.maxHeight != 0)
                    nh = node.maxHeight;
                else
                    nh = height;
            }
            return { width: nw, height: nh };
        },
        _initConnectorCollection: function (dataSourceApplied) {
            var connectors = this.connectors();
            var connector;
            for (var i = 0, len = connectors.length; i < len; i++) {
                connector = this._getNewConnector(connectors[i]);
                this.nameTable[connector.name] = connector;
                this._dock(connector, this.nameTable);
                this._updateEdges(connector);
                connectors[i] = connector;
            }
        },

        _initDefaults: function () {
            this._initTools();
        },

        _initCanvas: function (isload) {
            this._renderCanvas(isload); 
            if (this.model.selectorConstraints && this.model.selectedItems) {
                this.model.selectedItems.constraints = this.model.selectorConstraints;
            }
        },

        _updateConnectorBridging: function (baseConnector) {
            var childBounds = ej.datavisualization.Diagram.Util.bounds(baseConnector);
            var quads = ej.datavisualization.Diagram.SpatialUtil.findQuads(this._spatialSearch, childBounds);
            for (var item = 0; item < quads.length; item++) {
                var quad = quads[item];
                if (quad.objects.length > 0) {
                    for (var q = 0; q < quad.objects.length; q++) {
                        var connector = quad.objects[q];
                        if (connector.segments) {
                            if (connector != baseConnector) {
                                ej.datavisualization.Diagram.Util.updateBridging(connector, this);
                                ej.datavisualization.Diagram.DiagramContext.update(connector, this);
                            }
                        }
                    }
                }
            }
        },

        _initVisualGuide: function () {
            if (this.showTooltip() && !this.model.tooltipTemplateId) {
                var script = document.createElement("script");
                var attr = {
                    "id": this.element[0].id + "_defaultTooltip",
                    "type": "text/x-jsrender"
                };
                ej.datavisualization.Diagram.Util.attr(script, attr);
                script.innerHTML = "<span class=\"e-diagram-tooltipLabel-default\"> {{:type}}{{:x}}{{:type1}}{{:y}}</span>";
                this._canvas.appendChild(script);
            } else {
                this.element.remove("#" + this.element[0].id + "_defaultTooltip");
            }
        },

        _initTools: function () {
            this.tools = {
                "select": new ej.datavisualization.Diagram.SelectTool(this),
                "move": new ej.datavisualization.Diagram.MoveTool(this),
                "resize": new ej.datavisualization.Diagram.ResizeTool(this),
                "rotate": new ej.datavisualization.Diagram.RotateTool(this),
                //"pivot": new ej.datavisualization.Diagram.PivotTool(this),
                "endPoint": new ej.datavisualization.Diagram.ConnectionEditTool(this),
                "panTool": new ej.datavisualization.Diagram.PanTool(this),
                "straightLine": new ej.datavisualization.Diagram.StraightLineTool(this),
                "orthogonalLine": new ej.datavisualization.Diagram.OrthogonalLineTool(this),
                "phase": new ej.datavisualization.Diagram.PhaseTool(this)
            };
            this._toolToActivate = "select";
            this.activeTool = this.tools[this._toolToActivate];
            this._registerDrawingTools();
        },

        _initDiagramTool: function () {
            var tool = this.tool();
            if (tool & ej.datavisualization.Diagram.Tool.ContinuesDraw) {
                this.activateTool(this.model.connectorType, false);
            }
            else if (tool & ej.datavisualization.Diagram.Tool.DrawOnce) {
                this.activateTool(this.model.connectorType, true);
            }
            else if (tool & ej.datavisualization.Diagram.Tool.ZoomPan) {
                if (ej.datavisualization.Diagram.Util.canPanning(this)) {
                    this._toolToActivate = "panTool";
                    this.activeTool = this.tools[this._toolToActivate];
                    this.activeTool._isMouseDown = false;
                    this._currentCursor = "pointer";
                }
            }
            else if (tool & ej.datavisualization.Diagram.Tool.MultipleSelect) {
                this.activateTool("select");
            }
        },

        _initHandles: function () {
            var userHandles = this.model.selectedItems.userHandles;
            if (userHandles) {
                for (var i = 0; i < userHandles.length; i++) {
                    userHandles[i] = ej.datavisualization.Diagram.UserHandle(userHandles[i]);
                    if (userHandles[i].tool) {
                        userHandles[i].tool.diagram = this;
                        this.tools[userHandles[i].name] = userHandles[i].tool;
                    }
                }
            }
        },

        _destroy: function () {
            this.element.empty().removeClass("e-datavisualization-diagram");
        },
        //#endregion       

        updatePageSettings: function (option) {
            if (option) {
                if (option.pageHeight) {
                    this._pageHeight(Number(typeof option.pageHeight === 'function' ? option.pageHeight() : option.pageHeight));
                }
                if (option.pageWidth) {
                    this._pageWidth(Number(typeof option.pageWidth === 'function' ? option.pageWidth() : option.pageWidth));
                }
                if (option.pageBorderWidth) {
                    this._pageBorderWidth(Number(typeof option.pageBorderWidth === 'function' ? option.pageBorderWidth() : option.pageBorderWidth));
                }
                if (option.pageMargin) {
                    this._pageMargin(Number(typeof option.pageMargin === 'function' ? option.pageMargin() : option.pageMargin));
                }
                if (option.pageBackgroundColor) {
                    this._pageBackgroundColor(typeof option.pageBackgroundColor === 'function' ? option.pageBackgroundColor() : option.pageBackgroundColor);
                }
                if (option.scrollLimit) {
                    this._scrollLimit(typeof option.scrollLimit === 'function' ? option.scrollLimit() : option.scrollLimit);
                }
                if (option.scrollableArea) {
                    this.model.pageSettings.scrollableArea = option.scrollableArea;
                }

                ej.datavisualization.Diagram.PageUtil._updatePageSize(this);
                ej.datavisualization.Diagram.SvgContext._updateBackground(this._hScrollOffset, this._vScrollOffset, this._currZoom, this);
                ej.datavisualization.Diagram.SvgContext._updateGrid(this._hScrollOffset, this._vScrollOffset, this._currZoom, this);
            }
        },

        _updateSnapSettings: function (option) {
            if (option) {
                if (option.snapAngle) {
                    this._snapAngle(Number(typeof option.snapAngle === 'function' ? option.snapAngle() : option.snapAngle));
                }
                if (option.snapObjectDistance) {
                    this._snapObjectDistance(Number(typeof option.snapObjectDistance === 'function' ? option.snapObjectDistance() : option.snapObjectDistance));
                }
            }
        },

        /**
     *update Node with their specific properties
     *@return jQuery
     *@param {String} name  to identify the Node from the model
     *@param {String} options to specify which property of the Node to be update
     *@example
     *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
     *&lt;script&gt;
     *var diagram=$("#diagramcontent").ejDiagram("instance");
     *var value = ej.datavisualization.Diagram.NodeConstraints.Default & ~ej.datavisualization.Diagram.NodeConstraints.Connect;
     *diagram.updateNode(node.name, { constraints: value });
     *&lt;/script&gt;
     *@memberof ejDiagram
     *@instance
     */
        //#region Public methods

        updateNode: function (name, options) {

            if (name) {
                var node = this._findNode(name);
                if (node) {
                    if (options.offsetX | options.offsetX === 0) {
                        this._translate(node, options.offsetX - node.offsetX, 0, this.nameTable);
                    }
                    if (options.offsetY | options.offsetY === 0) {
                        this._translate(node, 0, options.offsetY - node.offsetY, this.nameTable);
                    }
                    if (options.rotateAngle | options.rotateAngle === 0) {
                        this._rotate(node, options.rotateAngle - node.rotateAngle, this.nameTable);
                    }
                    if (options.width) {
                        node.width = node.width ? node.width : 1;
                        this.scale(node, options.width / node.width, 1, new ej.datavisualization.Diagram.Point(node.offsetX, node.offsetY), this.nameTable);
                    }
                    if (options.height) {
                        node.height = node.height ? node.height : 1;
                        this.scale(node, 1, options.height / node.height, new ej.datavisualization.Diagram.Point(node.offsetX, node.offsetY), this.nameTable);
                    }
                    if (options.connectorPadding != undefined) {
                        node.connectorPadding = options.connectorPadding;
                        this.scale(node, 1, 1, new ej.datavisualization.Diagram.Point(node.offsetX, node.offsetY), this.nameTable);
                    }
                    if (options.visible != undefined) {
                        node.visible = options.visible;
                        if (!options.visible)
                            this._clearSelection();
                    }
                    if (options.constraints) {
                        if (node.type != "group") {
                            if (!(node.constraints & ej.datavisualization.Diagram.NodeConstraints.Shadow)) {
                                node.constraints = options.constraints;
                                ej.datavisualization.Diagram.DiagramContext.renderShadow(node, this);
                            }
                            else if (node.constraints != options.constraints) {
                                node.constraints = options.constraints;
                                ej.datavisualization.Diagram.DiagramContext.removeShadow(node, this);
                            }
                        }
                        node.constraints = options.constraints;
                        if (this.selectionList[0] && this.selectionList[0].name === node.name) {
                            ej.datavisualization.Diagram.SvgContext.clearSelector(this._svg, this._adornerLayer);
                            ej.datavisualization.Diagram.SvgContext.renderSelector(this.selectionList[0], this._svg, this._adornerLayer, this._currZoom, this.model.selectedItems.constraints);
                            if (this.model.selectedItems.constraints & ej.datavisualization.Diagram.SelectorConstraints.UserHandles)
                                ej.datavisualization.Diagram.SvgContext.renderUserHandles(this.model.selectedItems.userHandles, this.selectionList[0], this._svg, this.selectionList[0].type == "pseudoGroup",
                                    this._currZoom, this._adornerLayer);
                        }
                    }
                    if (node.type != "group") {
                        if (options.fillColor) {
                            node.fillColor = options.fillColor;
                        }
                        if (options.opacity) {
                            node.opacity = options.opacity;
                        }
                        if (options.borderColor) {
                            node.borderColor = options.borderColor;
                        }
                        if (options.borderWidth) {
                            node.borderWidth = options.borderWidth;
                        }
                        if (options.borderDashArray) {
                            node.borderDashArray = options.borderDashArray;
                        }
                        if (options.gradient !== undefined)
                            node.gradient = options.gradient;
                    }
                    if (options.shape) {
                        if (ej.browserInfo().name === "msie") {
                            if (node.shape && node.shape.html) {
                                var htmlelement = document.getElementById(node.name + "_parentdiv");
                                htmlelement.parentNode.removeChild(htmlelement);
                            }
                        }
                        node.shape = ej.datavisualization.Diagram.Shape(options.shape);
                        ej.datavisualization.Diagram.DiagramContext.setNodeShape(node, this);
                    }
                    ej.datavisualization.Diagram.DiagramContext.update(node, this);
                    ej.datavisualization.Diagram.DiagramContext.updateNodeStyle(node, this);
                    if (this.selectionList[0] && this.selectionList[0].name === node.name)
                        ej.datavisualization.Diagram.SvgContext.updateSelector(node, this._svg, this._currZoom, this, this.model.selectedItems.constraints);

                    if (options.isExpanded !== undefined) {
                        if (this.model.layout && this.model.layout.type !== ej.datavisualization.Diagram.LayoutTypes.None) {
                            if (options.isExpanded) {
                                node.isExpanded = true;
                                this._expandChildren(node);
                            }
                            else {
                                node.isExpanded = false;
                                this._collapseChildren(node);
                            }
                            this.layout();
                        }
                    }
                }
            }
            if (name) {
                var node = this._findNode(name);
                if (node && node.type == "node" && options && options.type && options.type == "group" && options.children && options.children.length > 0) {
                    var isRendered = false;
                    if (this._svg.document.getElementById(node.name))
                        isRendered = true;
                    this.remove(node);
                    node.borderColor = "transparent";
                    node.borderDashArray = "";
                    node.borderWidth = 1;
                    node.fillColor = "#1BA0E2";
                    node.labels = [];
                    node.fillColor = "";
                    node.type = options.type;
                    node.children = options.children;
                    node = ej.datavisualization.Diagram.Group(node);
                    this._initGroupNode(node);
                    if (isRendered) {
                        ej.datavisualization.Diagram.Util._updateGroupBounds(node, this);
                        this.add(node);
                        this._clearSelection();
                        this._addSelection(node);
                    }
                }
            }
        },

        /**
       *update Connector with their specific properties
       *@return jQuery
       *@param {String} name  to identify the connector from the model
       *@param {object} options to specify which property of the Connector to be update
       *@example
       *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
       *&lt;script&gt;
       *var diagram=$("#diagramcontent").ejDiagram("instance");
       *var value = ej.datavisualization.Diagram.ConnectorConstraints.Default;
       *diagram.updateConnector(connector.name, { constraints: value });      
       *&lt;/script&gt;
       *@memberof ejDiagram
       *@instance
       */
        updateConnector: function (name, options) {
            if (name) {
                var connector = this._findConnector(name);
                if (connector) {
                    if (options.constraints) {
                        connector.constraints = options.constraints;
                    }
                    if (options.lineColor) {
                        connector.lineColor = options.lineColor;
                    }
                    if (options.lineWidth) {
                        connector.lineWidth = options.lineWidth;
                    }
                    if (options.lineDashArray) {
                        connector.lineDashArray = options.lineDashArray;
                    }
                    if (options.sourcePadding != undefined) {
                        connector.sourcePadding = options.sourcePadding;
                        this._dock(connector, this.nameTable);
                    }
                    if (options.targetPadding != undefined) {
                        connector.targetPadding = options.targetPadding;
                        this._dock(connector, this.nameTable);
                    }
                    if (options.visible != undefined) {
                        node.visible = options.visible;
                        if (!options.visible)
                            this._clearSelection();
                    }
                    if (options.segments) {
                        connector.segments = options.segments;
                        ej.datavisualization.Diagram.Util._initConnectionEnds(connector, this);
                        if (this.model.defaultSettings.connector && this.model.defaultSettings.connector.segments[0]) {
                            var defaultType = this.model.defaultSettings.connector.segments[0].type;
                        }
                        ej.datavisualization.Diagram.Util._initializeSegments(connector, defaultType);
                        this._dock(connector, this.nameTable);
                        ej.datavisualization.Diagram.Util.updateBridging(connector, this);
                        this._updateQuad(this, connector);
                        if (connector == this.selectionList[0]) {
                            this._clearSelection();
                            this._addSelection(connector);
                        }
                    }

                    var decorator;
                    if (options.targetDecorator) {
                        if (connector.targetDecorator) {
                            decorator = $.extend(true, {}, connector.targetDecorator, options.targetDecorator);
                        } else {
                            decorator = ej.datavisualization.Diagram.Decorator(options.targetDecorator);
                        }
                        connector.targetDecorator = decorator;
                    }
                    if (options.sourceDecorator) {
                        if (connector.sourceDecorator) {
                            decorator = $.extend(true, {}, connector.sourceDecorator, options.sourceDecorator);
                        } else {
                            decorator = ej.datavisualization.Diagram.Decorator(options.sourceDecorator);
                        }
                        connector.sourceDecorator = decorator;
                    }
                    if (options.sourceDecorator || options.targetDecorator) {
                        ej.datavisualization.Diagram.DiagramContext.clearDecorators(connector, this);
                        ej.datavisualization.Diagram.DiagramContext.renderDecorators(connector, this);
                    }
                    if (this._svg) {
                        ej.datavisualization.Diagram.DiagramContext.update(connector, this);
                        ej.datavisualization.Diagram.DiagramContext.updateConnectorStyle(connector, this);
                    }
                    if (this.selectionList[0] && this.selectionList[0].name === connector.name)
                        ej.datavisualization.Diagram.SvgContext.updateSelector(connector, this._svg, this._currZoom, this, this.model.selectedItems.constraints);
                }
            }
        },

        /**
      *update Diagram with its specific properties
      *@return jQuery
      *@param {String} name  to identify the diagram from the model
      *@param {object} options to specify which properties of the diagram to be updated
      *@example
      *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
      *&lt;script&gt;
      *var diagram=$("#diagramcontent").ejDiagram("instance");
      *var value = ej.datavisualization.Diagram.DiagramConstraints.Default;
      *diagram.updateDiagram(diagram.name, { constraints: value });      
      *&lt;/script&gt;
      *@memberof ejDiagram
      *@instance
      */

        update: function (option) {
            if (option.tool) {
                this.activeTool._showAllPorts(true);
                var tool = option.tool;
                this.tool(tool);
                if (tool & ej.datavisualization.Diagram.Tool.ContinuesDraw) {
                    this.activateTool(this.model.connectorType, false);
                }
                else if (tool & ej.datavisualization.Diagram.Tool.DrawOnce) {
                    this.activateTool(this.model.connectorType, true);
                }
                else if (tool & ej.datavisualization.Diagram.Tool.ZoomPan) {
                    if (ej.datavisualization.Diagram.Util.canPanning(this)) {
                        this._toolToActivate = "panTool";
                        this.activeTool = this.tools[this._toolToActivate];
                        this.activeTool._isMouseDown = false;
                        this._currentCursor = "pointer";
                    }
                }
                else if (tool & ej.datavisualization.Diagram.Tool.MultipleSelect) {
                    this.activateTool("select");
                }
            }
            if (option.bridgeDirection) {
                this.bridgeDirection(option.bridgeDirection);
                var connectors = this.connectors();
                for (var i = 0, len = connectors.length; i < len; i++) {
                    var connector = connectors[i];
                    ej.datavisualization.Diagram.Util.updateBridging(connector, this);
                    ej.datavisualization.Diagram.DiagramContext.update(connector, this);
                }
            }
        },
        /**
       *To bring the specified portion of the diagram content to center of the diagram viewport
       *@return jQuery
       *@param {Object} rect pass bounds value (x,y,height,width)
       *@example
       
       *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
       *&lt;script&gt;
       *var diagram=$("#diagramcontent").ejDiagram("instance");
       *diagram.bringToCenter(ej.datavisualization.Diagram.Rectangle(700, 500, 80, 80));
       *&lt;/script&gt;
       *@memberof ejDiagram
        *@instance
       */
        bringToCenter: function (rect) {
            var scale = this._currZoom;
            var viewPort = ej.datavisualization.Diagram.ScrollUtil._viewPort(this);
            var hoffset = rect.x + (rect.width) / 2 - viewPort.width / 2;
            var voffset = rect.y + (rect.height) / 2 - viewPort.height / 2;
            hoffset = Math.max(0, hoffset) * scale;
            voffset = Math.max(0, voffset) * scale;
            ej.datavisualization.Diagram.ZoomUtil._applyTransform(this, scale, ej.datavisualization.Diagram.Point(-hoffset, -voffset), null);
        },
        /**
        *To bring the specified portion of the diagram content to the diagram viewport
        *@return jQuery
        *@param {Object} bounds pass bounds value (x,y,height,width)
        *@example
        
        *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
        *&lt;script&gt;
        *var diagram=$("#diagramcontent").ejDiagram("instance");
        *diagram.bringIntoView(ej.datavisualization.Diagram.Rectangle(700, 500, 80, 80));
        *&lt;/script&gt;
        *@memberof ejDiagram
        *@instance
        */
        bringIntoView: function (bounds) {
            var x = 0, y = 0;
            bounds.right = bounds.right ? bounds.right : bounds.x + bounds.width;
            bounds.bottom = bounds.bottom ? bounds.bottom : bounds.y + bounds.height;
            var hoffset = this._hScrollOffset;
            var voffset = this._vScrollOffset;
            var viewPort = ej.datavisualization.Diagram.ScrollUtil._viewPort(this);
            if (bounds.right > (-hoffset + viewPort.width)) {
                x = bounds.right - viewPort.width;
            }
            if (bounds.x < -hoffset) {
                x = bounds.x;
            }
            if (bounds.bottom > (-voffset + viewPort.height)) {
                y = bounds.bottom - viewPort.height;
            }
            if (bounds.y < -voffset) {
                y = bounds.y;
            }
            ej.datavisualization.Diagram.ZoomUtil._applyTransform(this, this._currZoom, ej.datavisualization.Diagram.Point(-x, -y), null);

        },
        getBridgeSegment: function (startPt, endPt, angle, bridgeSpace, sweep) {
            var path = "A " + bridgeSpace / 2 + " " + bridgeSpace / 2 + "  " + angle + " , 1 " + sweep + " " + endPt.x + "," + endPt.y;
            return path;
        },


        /**
      
          *To fit the diagram content into diagram viewport       
          *@return jQuery
          *@param {Object} type to specify diagramcontent either by width or height or both of the viewport    
          *@param {Object} region to set fit whether to diagramcontent and pagesettings
          *@param {Object} margin to set the required margin viewport
          *@example         
          *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
          *&lt;script&gt;
          *var diagram=$("#diagramcontent").ejDiagram("instance");
          *diagram.fitToPage(type,region,margin);
          *&lt;/script&gt;
          *@memberof ejDiagram
          *@instance
          */

        fitToPage: function (type, region, margin) {
            var zoomFactor, factor, scale = {}, bounds;
            if (this.nodes().length > 0 || this.connectors().length > 0) {
                var viewPort = ej.datavisualization.Diagram.ScrollUtil._viewPort(this);
                if (!margin)
                    margin = ej.datavisualization.Diagram.Margin();
                if (region != "custom") {
                    if (region == "content") {
                        bounds = new ej.datavisualization.Diagram.Rectangle();
                        bounds.x = this._spatialSearch.pageLeft;
                        bounds.y = this._spatialSearch.pageTop;
                        bounds.width = this._spatialSearch.pageRight;
                        bounds.height = this._spatialSearch.pageBottom;
                    }
                    else
                        bounds = this._getDigramBounds();
                }
                var width = region != "custom" ? bounds.width - bounds.x : bounds.width;
                var height = region != "custom" ? bounds.height - bounds.y : bounds.height;
                scale.x = (viewPort.width - (margin.left + margin.right)) / width;
                scale.y = (viewPort.height - (margin.top + margin.bottom)) / height;
                var deltaX = this._hScrollOffset;
                var deltaY = this._vScrollOffset;

                switch (type) {
                    case "width":
                        zoomFactor = scale.x;
                        factor = zoomFactor / this._getCurrentZoom();
                        deltaX -= bounds.x * zoomFactor;
                        deltaY -= this._vScrollOffset * factor;
                        deltaY = region != "custom" ? deltaY : deltaY + this._vScrollOffset * factor;
                        break;
                    case "height":
                        zoomFactor = scale.y;
                        factor = zoomFactor / this._getCurrentZoom();
                        //var centerX = (viewPort.width - (bounds.x > 0 ? bounds.width : width) * zoomFactor - bounds.x * zoomFactor) / 2;
                        //deltaX += centerX - (bounds.x * zoomFactor) / 4 + margin.left;
                        //deltaY -= bounds.y * zoomFactor - margin.top;
                        var centerX = (viewPort.width - (region != "content" ? bounds.width : width) * zoomFactor) / 2 - bounds.x * zoomFactor;
                        var centerY = (viewPort.height - (region != "content" ? bounds.height : height) * zoomFactor) / 2 - bounds.y * zoomFactor;
                        deltaX += centerX + (margin.left - margin.right) / 2 * zoomFactor;
                        deltaY += centerY + (margin.top - margin.bottom) / 2 * zoomFactor;
                        break;
                    case "page":
                        zoomFactor = Math.min(scale.x, scale.y);
                        factor = zoomFactor / this._getCurrentZoom();
                        if (Math.min(scale.x, scale.y) == scale.x) {
                            deltaX -= bounds.x * zoomFactor;
                            deltaY -= this._vScrollOffset * factor;
                            deltaY = region != "custom" ? deltaY : deltaY + this._vScrollOffset * factor;
                        }
                        else {
                            var centerX = (viewPort.width - (region != "content" ? bounds.width : width) * zoomFactor) / 2 - bounds.x * zoomFactor;
                            var centerY = (viewPort.height - (region != "content" ? bounds.height : height) * zoomFactor) / 2 - bounds.y * zoomFactor;
                            deltaX += centerX + (margin.left - margin.right) / 2 * zoomFactor;
                            deltaY += centerY + (margin.top - margin.bottom) / 2 * zoomFactor;
                        }
                        break;
                }
                ej.datavisualization.Diagram.ZoomUtil.zoomPan(this, factor, deltaX, deltaY, new ej.datavisualization.Diagram.Point(0, 0), true);
            }
            else {
                factor = 1 / this._getCurrentZoom();
                ej.datavisualization.Diagram.ZoomUtil.zoomPan(this, factor, this._hScrollOffset, this._vScrollOffset, new ej.datavisualization.Diagram.Point(0, 0), true);
            }
        },



        /**
    *To export the diagram as image .
    *@return jQuery
    *@example
 
    *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
    *&lt;script&gt;
    *var diagram=$("#diagramcontent").ejDiagram("instance");
    *diagram.exportAsImage();
    *&lt;/script&gt;
    *@memberof ejDiagram
    *@instance
 */
        exportAsImage: function () {
            var bounds = this._getDigramBounds();
            var bounds = {
                x: this._spatialSearch.pageLeft || bounds.x,
                y: this._spatialSearch.pageTop || bounds.y,
                width: this._spatialSearch.pageRight - this._spatialSearch.pageLeft || bounds.width,
                height: this._spatialSearch.pageBottom - this._spatialSearch.pageTop || bounds.height
            };
            var canvas = new ej.datavisualization.Diagram.Canvas({ "id": "mycanvas", "width": bounds.width + 50, "height": bounds.height + 50 });
            var context = canvas.document.getContext("2d");
            context.translate(-bounds.x + 25, -bounds.y + 25);
            context.fillStyle = this.model.pageSettings.pageBackgroundColor;
            context.fillRect(bounds.x - 25, bounds.y - 25, bounds.width + 50, bounds.height + 50);
            var elements = this.nodes().concat(this.connectors());
            elements = this._sortByZIndex(elements, true);
            for (var i = 0; i < elements.length; i++) {
                var element = elements[i];
                if (element.type == "group" && !element.parent)
                    ej.datavisualization.Diagram.CanvasContext.renderGroup(element, canvas, this);
                else if (element.shape)
                    ej.datavisualization.Diagram.CanvasContext.renderNode(element, canvas);
                else if (element.segments)
                    ej.datavisualization.Diagram.CanvasContext.renderConnector(element, canvas);
            }

            var tx = 0, ty = 0;
            if (this.model.phases) {
                for (var i = 0; i < this.model.phases.length; i++) {
                    var parNode = this.nameTable[this.model.phases[i].parent];
                    if (parNode) {
                        var children = this._getChildren(parNode.children);
                        if (children.length > 1)
                            var header = this.nameTable[children[0]];
                        var bounds = ej.datavisualization.Diagram.Util.bounds(parNode);
                        var points = [], nPoint;
                        var top = bounds.top + 50;
                        var left = bounds.left + 50;
                        if (this.model.phases[i].orientation == "vertical") {
                            points.push({ x: 0, y: 0 });
                            points.push({ x: bounds.width, y: 0 });
                            nPoint = this._convertToSVGPoints(points);
                            tx = bounds.x;
                            ty = bounds.y + this.model.phases[i].offset;
                            if (header)
                                top += header.height;
                            if (!(ty < bounds.bottom && ty > top)) {
                                visibility = "hidden";
                            }
                        } else {
                            points.push({ x: 0, y: header.height ? header.height : 0 });
                            points.push({ x: 0, y: bounds.height });
                            tx = bounds.x + this.model.phases[i].offset;
                            ty = bounds.y;
                            for (var j = 0, len = points.length; j < len; ++j) {
                                var point = ej.datavisualization.Diagram.Geometry.translate(points[j], tx, ty);
                                points[j] = point;
                            }
                        }
                    }
                    ej.datavisualization.Diagram.CanvasContext.renderPhases(this.model.phases[i], canvas, points);
                }
            }
            var url = canvas.document.toDataURL('image/png');
            return url;
        },
        /**
     *To print the diagram as image .
     *@return jQuery
     *@example
  
     *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
     *&lt;script&gt;
     *var diagram=$("#diagramcontent").ejDiagram("instance");
     *diagram.print();
     *&lt;/script&gt;
     *@memberof ejDiagram
     *@instance
  */
        print: function () {
            var url = this.exportAsImage();
            var img = document.createElement('img');
            var attr = {
                "id": this.element[0].id + "_printImage",
                "src": url,
            };
            ej.datavisualization.Diagram.Util.attr(img, attr);
            var div = document.createElement("div");
            div.appendChild(img);

            // specify window parameters
            var PrintWind = window.open('');
            if (PrintWind != null) {
                PrintWind.document.write('<html><head><title></title></head>');
                PrintWind.document.write('<BODY onload="window.print()">');
                PrintWind.document.write("<center>" + div.innerHTML + "</center>");
                PrintWind.document.close();
            }
        },

        /**
*To save the diagram .
*@return jQuery
*@param {Object} 
*@example

*&lt;div id="diagramcontent"&gt;&lt;/div&gt;
*&lt;script&gt;
*var diagram=$("#diagramcontent").ejDiagram("instance");
*diagram.save();
*&lt;/script&gt;
*@memberof ejDiagram
*@instance
*/
        save: function () {
            var drawingTools = this.model.drawingTools;
            var userHandles = this.model.selectedItems.userHandles;
            this.model.drawingTools = null;
            this.model.selectedItems.userHandles = null;
            if (this.nameTable["multipleSelection"]) {
                ej.datavisualization.Diagram.Util.removeItem(this.nodes(), this.nameTable["multipleSelection"]);
            }
            this._updateTableNodes();
            var model = jQuery.extend(true, {}, this.model);
            this.model.drawingTools = drawingTools;
            this.model.selectedItems.userHandles = userHandles;
            return model;
        },

        _updateTableNodes: function () {
            var i = 0, node, connector;
            for (i; i < this.nodes().length; i++) {
                node = this.nameTable[this.nodes()[i].name];
                if (node) {
                    this.nodes()[i] = node;
                    if (node.type == "group") {
                        this._updateTableGroup(node);
                    }
                }
            }
            for (i; i < this.connectors().length; i++) {
                connector = this.nameTable[this.connectors()[i].name];
                if (connector) {
                    this.connectors()[i] = connector;
                }
            }
        },
        _updateTableGroup: function (group) {
            var children = group.children;
            for (var i = 0; i < group.children.length; i++) {
                group.children[i] = this.nameTable[this._getChild(group.children[i])];
                if (group.children[i] && group.children[i].type == "group") {
                    this._updateTableGroup(group.children[i]);
                }
            }
        },

        /**
*To Upgrade the diagram from old version .
*@return jQuery 
*@param {Object} 
*@example

*&lt;div id="diagramcontent"&gt;&lt;/div&gt;
*&lt;script&gt;
*var diagram=$("#diagramcontent").ejDiagram("instance");
*diagram.upgrade(jsonData);
*diagram.load(jsonData);
*&lt;/script&gt;
*@memberof ejDiagram
*@instance
*/
        upgrade: function (data) {
            //Support to upgrade diagram JSON data from 12.1

            if (!data.version) {

                //CommonAPIChanges
                this.commonAPIChanges(data);

                //Node and Connector constraints set to default
                if (data.nodes) {
                    for (var i = 0 ; i < data.nodes.length; i++) {
                        if (!data.nodes[i].inEdges) {
                            data.nodes[i].inEdges = [];
                            data.nodes[i].outEdges = [];
                        }
                        data.nodes[i].constraints = ej.datavisualization.Diagram.NodeConstraints.Default;
                    }
                }
            }
            else if (data.version == "13.1") {
                //No Code Changes
            }
        },

        commonAPIChanges: function (data) {
            // defaultSettings API Added
            data.defaultSettings = { node: data.nodeDefaults, connectors: data.connectorDefaults };

            // line is changed to segments; Inserting segments
            if (data.connectors) {
                for (var i = 0 ; i < data.connectors.length; i++) {

                    //Setting the Connector's constraints to Default
                    data.connectors[i].constraints = ej.datavisualization.Diagram.ConnectorConstraints.Default;

                    if (data.connectors[i].line) {
                        if (data.connectors[i].line.type == "straight") {
                            var segments = [{
                                type: "straight",
                                startPoint: data.connectors[i].line.startPoint,
                                endPoint: data.connectors[i].line.endPoint
                            }];
                            this.commonSourceTargetChanges(data.connectors[i]);
                        }
                        else if (data.connectors[i].line.type == "orthogonal") {
                            var segments = [{
                                type: "orthogonal",
                                startPoint: data.connectors[i].line.startPoint,
                                endPoint: data.connectors[i].line.endPoint,
                            }];
                            this.commonSourceTargetChanges(data.connectors[i]);
                        }
                        else if (data.connectors[i].line.type == "bezier") {
                            var segments = [{
                                type: "bezier",
                                startPoint: data.connectors[i].line.startPoint,
                                endPoint: data.connectors[i].line.endPoint,
                                point1: data.connectors[i].line.point1,
                                point2: data.connectors[i].line.point2
                            }];
                            this.commonSourceTargetChanges(data.connectors[i]);
                        }
                        data.connectors[i].sourcePoint = data.connectors[i].line.startPoint;
                        data.connectors[i].targetPoint = data.connectors[i].line.endPoint;
                        data.connectors[i].segments = segments;
                    }
                }
            }
        },

        commonSourceTargetChanges: function (data) {
            if (data.sourceNodeName)
                data.sourceNode = data.sourceNodeName;
            if (data.sourceNodePort)
                data.sourcePort = data.sourceNodePort;
            if (data.targetNodeName)
                data.targetNode = data.targetNodeName;
            if (data.targetPortName)
                data.targetPort = data.targetPortName;
        },

        /**
*To load the diagram .
*@return jQuery 
*@param {Object} 
*@example

*&lt;div id="diagramcontent"&gt;&lt;/div&gt;
*&lt;script&gt;
*var diagram=$("#diagramcontent").ejDiagram("instance");
*diagram.load(data);
*&lt;/script&gt;
*@memberof ejDiagram
*@instance
*/
        load: function (data) {
            this.clear();
            var contextmenu = document.getElementById(this.element[0].id + "_contextMenu");
            if (contextmenu)
                contextmenu.parentNode.removeChild(contextmenu);
            var load = {
                nodes: data.nodes ? data.nodes : [],
                connectors: data.connectors ? data.connectors : [],
                contextMenu: data.contextMenu ? data.contextMenu : {},
                snapSettings: data.snapSettings ? data.snapSettings : {},
                backgroundImage: data.backgroundImage ? data.backgroundImage : null,
                enableAutoScroll: data.enableAutoScroll ? data.enableAutoScroll : true,
                autoScrollMargin: data.autoScrollMargin ? data.autoScrollMargin : 20,
                layout: data.layout ? data.layout : {},
                pageSettings: data.pageSettings ? data.pageSettings : {},
                click: data.click ? data.click : null,
                connectionChange: data.connectionChange ? data.connectionChange : null,
                defaultSettings: data.defaultSettings ? data.defaultSettings : null,
                dataSource: data.dataSource ? data.dataSource : null,
                dataSourceSchema: data.dataSourceSettings ? data.dataSourceSettings : null,
                doubleClick: data.doubleClick ? data.doubleClick : null,
                enableContextMenu: data.enableContextMenu ? data.enableContextMenu : true,
                showTooltip: data.showTooltip ? data.showTooltip : true,
                height: data.height ? data.height : null,
                mouseEnter: data.mouseEnter ? data.mouseEnter : null,
                mouseOver: data.mouseOver ? data.mouseOver : null,
                mouseLeave: data.mouseLeave ? data.mouseLeave : null,
                nodeTemplate: data.nodeTemplate ? data.nodeTemplate : null,
                rotationChange: data.rotationChange ? data.rotationChange : null,
                selectorConstraints: data.selectorConstraints ? data.selectorConstraints : ej.datavisualization.Diagram.SelectorConstraints.All,
                tooltipTemplateId: data.tooltipTemplateId ? data.tooltipTemplateId : null,
                width: data.width ? data.width : null,
                constraints: data.constraints,
                zoomFactor: data.zoomFactor ? data.zoomFactor : 1,
                phases: data.phases ? data.phases : [],
            };
            $("#" + this._id).ejDiagram(load);
        },

        /**
*To arrange the elements on the page in the diagram .
*@return jQuery
*@param {String} 
*@example

*&lt;div id="diagramcontent"&gt;&lt;/div&gt;
*&lt;script&gt;
*var diagram=$("#diagramcontent").ejDiagram("instance");
*diagram.layout();
*&lt;/script&gt;
*@memberof ejDiagram
*@instance
*/

        layout: function () {
            this._setLayout();
        },

        _setLayout: function () {
            //this.model.layout = new ej.datavisualization.Diagram.HierarchicalLayout(this.model.layout);
            this._doLayout();
            ej.datavisualization.Diagram.PageUtil._updatePageSize(this);
            this._clearSelection();
            //this._updateNodes();
            //this._updateConnectors();
        },
        /**
               *Select the target node
               *@return jQuery
               *@param {Object} node pass target node to be updated
               *@example
               *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
               *&lt;script&gt;
               *var diagram=$("#diagramcontent").ejDiagram("instance");
               *var node=diagram.model.nodes[0];
               *diagram.addSelection(node);
               *&lt;/script&gt;
               *@memberof ejDiagram
*@instance
               */
        addSelection: function (node) {
            this._addSelection(node);
        },

        /**
     *update specified node as selected object.
     *@return jQuery
     *@param {String} name  to identify the object from the model 
     *@example
     *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
     *&lt;script&gt;
     *var diagram=$("#diagramcontent").ejDiagram("instance"); 
     *diagram.updateSelectedObject(name);    
     *&lt;/script&gt;
     *@memberof ejDiagram
     *@instance
     */
        updateSelectedObject: function (nodeName) {
            var node = this.nameTable[nodeName];
            if (node) {
                this.activeTool.selectedObject = node;

            }
        },
        /**
        *Update the selection of target node/connector
        *@return jQuery
        *@param {Boolean} isDragging pass true/false whether to drag or not
        *@example
        *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
        *&lt;script&gt;
        *var diagram=$("#diagramcontent").ejDiagram("instance");
        *diagram.updateSelection(true);
        *&lt;/script&gt;
        *@memberof ejDiagram
        *@instance
        */

        updateSelection: function (isDragging) {
            if (ej.datavisualization.Diagram.Util.isPageEditable(this)) {
                this._updateSelectionHandle(isDragging);
            }
        },
        /**
        *To activate registered tool 
        *@return jQuery
        *@param {String} toolName name of the tool to be activated
        *@param {Boolean} singleAction default value set to true tool action to be performed only once
        *@example
        *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
        *&lt;script&gt;
        *var diagram=$("#diagramcontent").ejDiagram("instance");
        *diagram.activateTool("panTool");
                 *&lt;/script&gt;

          *@example
            *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
                 *&lt;script&gt;
                 *var diagram=$("#diagramcontent").ejDiagram("instance");                 
                 *diagram.activateTool("orthogonalTool",false);
                 *&lt;/script&gt;
                 *@memberof ejDiagram
                 *@instance
        */
        activateTool: function (toolName, singleAction) {

            if (this.tools[toolName]) {
                if (this.activeTool instanceof ej.datavisualization.Diagram.LineTool) {
                    this.activeTool._showAllPorts(true);
                }
                this._toolToActivate = toolName;
                this.activeTool = this.tools[this._toolToActivate];
                if (singleAction != undefined)
                    this.activeTool.singleAction = singleAction;
            }
            if (this.activeTool instanceof ej.datavisualization.Diagram.ImageTool && this.activeTool.autoOpenUpload) {
                this.activeTool._showPopup();
            }
            if (this.activeTool instanceof ej.datavisualization.Diagram.PanTool) {
                this._currentCursor = "pointer";
            }
            if (this.activeTool instanceof ej.datavisualization.Diagram.LineTool) {
                if (this.activeTool.singleAction)
                    this.tool(this.tool() | ej.datavisualization.Diagram.Tool.DrawOnce);
                else
                    this.tool(this.tool() | ej.datavisualization.Diagram.Tool.ContinuesDraw);
                this.activeTool._showAllPorts();
            }
            this._drawingTool = true;
        },
        /**
       *Deactivate the current activated tool
       *@return jQuery
       *@example
       *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
       *&lt;script&gt;
       *var diagram=$("#diagramcontent").ejDiagram("instance");
       *diagram.deactivateTool();
       *&lt;/script&gt;
       *@memberof ejDiagram
       *@instance
       */
        deactivateTool: function () {
            if (this.activeTool instanceof ej.datavisualization.Diagram.LineTool) {
                this.activeTool._showAllPorts(true);
            }
            if (this.tool() & ej.datavisualization.Diagram.Tool.DrawOnce)
                this.tool(this.tool() ^ ej.datavisualization.Diagram.Tool.DrawOnce);
            if (this.tool() & ej.datavisualization.Diagram.Tool.ContinuesDraw)
                this.tool(this.tool() ^ ej.datavisualization.Diagram.Tool.ContinuesDraw);
            if (this.tool() & ej.datavisualization.Diagram.Tool.ZoomPan) {
                this._toolToActivate = "panTool";
                this.activeTool = this.tools[this._toolToActivate];
                this.activeTool._mousedown = false;
                this._currentCursor = "pointer";
            }
            else {
                this._toolToActivate = "select";
                this.activeTool = this.tools[this._toolToActivate];
            }
        },

        /**
                    *Update the given label style
                    *@return jQuery
                    *@param {String} nodeName pass the name of node/connector
                    *@param {Object} label pass the label to be modified
                    *@param {Object} obj pass the new porperties of the label
                    *@example
                    
                    *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
                    *&lt;script&gt;
                    *var diagram=$("#diagramcontent").ejDiagram("instance");
                    *var node=diagram.selectionList[0];
                    *var label = [];
                    *label =[{"name":"node1" "text": "node", "bold": true, "italic": true}]
                    *diagram.updateLabel(node.name,node.labels[0],label);
                    *&lt;/script&gt;
                    *@memberof ejDiagram
*@instance
                    */
        updateLabel: function (nodeName, label, obj) {
            if (nodeName && ej.datavisualization.Diagram.Util.isPageEditable(this)) {
                var mNode = this._findNode(nodeName);
                if (!mNode)
                    mNode = this._findConnector(nodeName);
                if (obj && label && !obj.name || label.name == obj.name) {
                    if (mNode) {
                        for (var prop in obj)
                            if (label.hasOwnProperty(prop)) {
                                label[prop] = obj[prop];
                            }
                        if (mNode.segments || (mNode.shape && mNode.shape.type !== "text")) {
                            ej.datavisualization.Diagram.DiagramContext.updateLabelStyle(mNode, label, this);
                            ej.datavisualization.Diagram.DiagramContext.updateLabel(mNode, label, this);
                        } else if (mNode.shape && mNode.shape.type === "text") {
                            ej.datavisualization.Diagram.DiagramContext.updateTextBlock(mNode, label, this);
                        }
                    }
                    if (obj.mode === ej.datavisualization.Diagram.LabelEditMode.Edit) {
                        this.startLabelEdit(mNode, label);
                    }
                }
            }
        },
        /**
                    *Starts the editing of the specified label in the given node
                    *@return jQuery
                    *@param {Object} node pass the node/connector to which label to be edited
                      *@param {Object} label pass the label to be edited
                    *@example
                    
                    *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
                    *&lt;script&gt;
                    *var diagram=$("#diagramcontent").ejDiagram("instance");
                    *var node=diagram.selectionList[0];
                    *diagram.startLabelEdit(node,node.labels[0]);
                    *&lt;/script&gt;
                    *@memberof ejDiagram
                    *@instance
                    */
        startLabelEdit: function (node, label) {
            if (node) {
                //Disables the edit mode of labels in the selectionList
                for (var i = 0; i < this.selectionList.length; i++) {
                    var mNode = this.selectionList[i];
                    if (mNode !== node && typeof mNode.labels.length != "undefined") {
                        for (var j = 0; j < mNode.labels.length; j++)
                            mNode.labels[j].mode = ej.datavisualization.Diagram.LabelEditMode.View;
                    }
                }
                if (!label && node.shape.type === "text")
                    label = node.shape.textBlock;
                if (this._setLabelEditing(label))
                    this._startEdit(node);
                else {
                    this._endEdit();
                }
            }
        },

        _setSelectorConstraints: function (constraints) {
            this.model.selectedItems.constraints = constraints;
            if (this.selectionList[0]) {
                ej.datavisualization.Diagram.SvgContext.clearSelector(this._svg, this._adornerLayer);
                ej.datavisualization.Diagram.SvgContext.renderSelector(this.selectionList[0], this._svg, this._adornerLayer, this._currZoom, constraints);
                if (this.model.selectedItems.constraints & ej.datavisualization.Diagram.SelectorConstraints.UserHandles)
                    ej.datavisualization.Diagram.SvgContext.renderUserHandles(this.model.selectedItems.userHandles, this.selectionList[0], this._svg, this.selectionList[0].type == "pseudoGroup",
                        this._currZoom, this._adornerLayer);
            }
        },
        /**
        *Group the selected node and connector
        *@return jQuery
        *@example
       
        *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
        *&lt;script&gt;
        *var diagram=$("#diagramcontent").ejDiagram("instance");
        *diagram.group(); 
        *&lt;/script&gt;
        *@memberof ejDiagram
        *@instance
        */
        group: function () {
            if (this.selectionList[0] && this.selectionList[0].type == "pseudoGroup") {
                var selectionList = [];
                var i;
                for (i = 0; i < this.selectionList[0].children.length; i++)
                    selectionList.push(this.nameTable[this.selectionList[0].children[i]]);
                this._sortByZIndex(selectionList, true);
                var element;
                var groupName = ej.datavisualization.Diagram.Util.randomId();
                var group = new ej.datavisualization.Diagram.Group({ name: groupName, });
                this._clearSelection();
                for (i = 0; i < selectionList.length; i++) {
                    this._isUndo = true;
                    group.children.push(selectionList[i].name);
                    selectionList[i].parent = groupName;
                    ej.datavisualization.Diagram.Util.removeItem(this.selectionList, selectionList[i].name);
                    if (!selectionList[i].segments) ej.datavisualization.Diagram.Util.removeItem(this.nodes(), this.nameTable[selectionList[i].name]);
                    else ej.datavisualization.Diagram.Util.removeItem(this.connectors(), this.nameTable[selectionList[i].name]);
                    ej.datavisualization.Diagram.SpatialUtil._removeFromaQuad(this._spatialSearch, this._spatialSearch.quadTable[selectionList[i].name], selectionList[i]);
                    if (ej.browserInfo().name === "msie") {
                        if (selectionList[i].shape && selectionList[i].shape.type == "html") {
                            element = document.getElementById(selectionList[i].name + "_parentdiv");
                            element.parentNode.removeChild(element);
                        }
                        else {
                            if (selectionList[i].type == "group")
                                this._checkForHtmlNode(selectionList[i]);
                        }
                    }
                    // $("#" + selectionList[i].name)[0].parentNode.removeChild($("#" + selectionList[i].name)[0]);
                    element = this._svg.document.getElementById(selectionList[i].name);
                    element.parentNode.removeChild(element);
                }
                ej.datavisualization.Diagram.Util.clear(this.selectionList);
                group = this._getNewGroup(group);
                this.add(group);
                this._addSelection(group);
                var entry = { type: "groupchanged", object: group, actionType: "group" };
                this.addHistoryEntry(entry);
                //var entry = new ej.datavisualization.Diagram.HistoryEntry(new ej.datavisualization.Diagram.GroupHandleCmd(group, "group"));
                //this.historyManager.addHistoryEntry(entry);
                this._isUndo = false;
            }
        },

        _checkForHtmlNode: function (group) {
            var children = this._getChildren(group.children);
            for (var i = 0; i < children.length; i++) {
                var child = this.nameTable[children[i]];
                if (child) {
                    if (child.type == "group") {
                        this._checkForHtmlNode(child);
                    } else {
                        if (child.shape && child.shape.type == "html") {
                            var element = document.getElementById(child.name + "_parentdiv");
                            element.parentNode.removeChild(element);
                        }
                    }
                }
            }
        },
        _removeChildren: function (group, args) {
            var children = this._getChildren(group.children);
            for (var i = 0; i < children.length; i++) {
                var child = this.nameTable[children[i]];
                if (child) {
                    if (group.isLane) {
                        this._disConnect(child, args);
                        this._removeConnector(child, args);
                    }
                    else
                        this._disConnect(child, args, true);
                    ej.datavisualization.Diagram.Util.removeItem(this.nodes(), child);
                    if (child.type == "group") {
                        this._removeChildren(child, args);
                    } else {
                        ej.datavisualization.Diagram.SpatialUtil._removeFromaQuad(this._spatialSearch, this._spatialSearch.quadTable[child.name], child);
                        ej.datavisualization.Diagram.SpatialUtil._updateBounds(this, this._spatialSearch, child);
                        delete this.nameTable[child.name];
                    }
                    this._removeElement(child);
                }
            }
        },
        /**
*Ungroup the selected group
*@return jQuery
*@example

*&lt;div id="diagramcontent"&gt;&lt;/div&gt;
*&lt;script&gt;
*var diagram=$("#diagramcontent").ejDiagram("instance");
*diagram.ungroup(); 
*&lt;/script&gt;
*@memberof ejDiagram
*@instance
*/
        ungroup: function () {
            if (this.selectionList[0] && this.selectionList[0].type == "group" && !(this.selectionList[0].isSwimlane || this.selectionList[0].isLane)) {
                this._isUndo = true;
                var selectionList = this.selectionList[0].children;
                var i, node;
                node = this.selectionList[0];
                $("#" + this.selectionList[0].name)[0].parentNode.removeChild($("#" + this.selectionList[0].name)[0]);
                if ($("#" + this.selectionList[0].name)[0])
                    $("#" + this.selectionList[0].name)[0].parentNode.removeChild($("#" + this.selectionList[0].name)[0]);
                if (ej.browserInfo().name === "msie")
                    this._checkForHtmlNode(this.selectionList[0]);
                this._clearSelection();
                var object;
                ej.datavisualization.Diagram.Util.clear(this.selectionList);
                for (i = 0; i < selectionList.length; i++) {
                    var item = this.nameTable[selectionList[i]];
                    if (item) {
                        if (item.parent)
                            item.parent = null;
                        if (item.segments) {
                            object = item;
                            object.parent = "";
                            this._updateEdges(object);
                            this._dock(object, this.nameTable);
                            ej.datavisualization.Diagram.DiagramContext.renderConnector(object, this);
                            this.connectors().push(object);
                        }
                        else {
                            object = item;
                            object.parent = "";
                            if (object.type == "group") {
                                this._updateChildrenEdges(object);
                                if (object.isLane || object.isSwimlane) {
                                    object.width = 0;
                                    object.height = 0;
                                }
                                ej.datavisualization.Diagram.DiagramContext.renderGroup(object, this);
                            }
                            else
                                ej.datavisualization.Diagram.DiagramContext.renderNode(object, this);
                            this.nodes().push(object);
                        }
                    }

                }
                //this._clearSelection();
                ej.datavisualization.Diagram.Util.removeItem(this.nodes(), this._findNode(node.name));

                var entry = { type: "groupchanged", object: node, actionType: "ungroup" };
                this.addHistoryEntry(entry);

                //var entry = new ej.datavisualization.Diagram.HistoryEntry(new ej.datavisualization.Diagram.GroupHandleCmd(node, "ungroup"));
                //this.historyManager.addHistoryEntry(entry);
                this._isUndo = false;

            }
        },


        /**
       *Executes nudge command tp move selected node/connector one pixel 
       *@return jQuery
       *@param {String} direction  specify the driection to move the selected objects ("left","right",top","bottom")
       *@example
       *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
       *&lt;script&gt;
       *var diagram=$("#diagramcontent").ejDiagram("instance");
       *diagram.nudge("direction"); 
       *&lt;/script&gt;
       *@memberof ejDiagram
       *@instance
       */

        nudge: function (direction, nudgeDelta) {
            nudgeDelta = !nudgeDelta ? 1 : nudgeDelta;
            var dir = { up: { x: 0, y: -nudgeDelta }, down: { x: 0, y: nudgeDelta }, left: { x: -nudgeDelta, y: 0 }, right: { x: nudgeDelta, y: 0 } };
            var nudge = dir[direction];
            if (nudge && this.selectionList[0]) {
                this._nudge(this.selectionList[0], nudge.x, nudge.y);
            }
        },

        /**
              *Select all nodes and connector in diagram
              *@return jQuery
              *@example
             
              *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
              *&lt;script&gt;
              *var diagram=$("#diagramcontent").ejDiagram("instance");
              *diagram.selectAll(); 
              *&lt;/script&gt;
              *@memberof ejDiagram
              *@instance
              */
        selectAll: function () {
            var collection, nodes, i, len, item = null;
            this._clearSelection();
            collection = ej.datavisualization.Diagram.Group({ type: "pseudoGroup", name: "multipleSelection" });
            nodes = this.nodes();
            for (i = 0, len = nodes.length; i < len; i++) {
                if (ej.datavisualization.Diagram.Util.canSelect(nodes[i])) {
                    item = this.nameTable[nodes[i].name];
                    if (item && item.parent == "") {
                        collection.children.push(item.name);
                    }
                }
            }
            var connectors = this.connectors();
            for (i = 0, len = connectors.length; i < len; i++) {
                if (ej.datavisualization.Diagram.Util.canSelect(connectors[i])) {
                    if (connectors[i].parent == "") {
                        collection.children.push(connectors[i].name);
                    }
                }
            }
            ej.datavisualization.Diagram.Util._updateGroupBounds(collection, this);
            //ej.datavisualization.Diagram.Util.clear(this.selectionList);
            this.nodes().push(collection);
            this.nameTable[collection.name] = collection;
            if (collection.children.length > 0)
                this._addSelection(collection);
        },
        /**
        *Align selected object based on reference object and direction
        *@return jQuery
        *@param {String} direction To specify the driection for alignment ("left","right",top","bottom")
        *@example
        *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
        *&lt;script&gt;
        *var diagram=$("#diagramcontent").ejDiagram("instance");
        *diagram.align("left"); 
        *&lt;/script&gt;
        *@memberof ejDiagram
        *@instance
        */
        align: function (direction) {
            if (this.selectionList[0] && this.selectionList[0].type == "pseudoGroup" && this.selectionList[0].children && this.selectionList[0].children.length > 0) {
                var list = this.nameTable[this.selectionList[0].name].children;
                var cNode;
                if (direction === "left")
                    cNode = this._findCornerNodes().left;
                else if (direction === "right")
                    cNode = this._findCornerNodes().right;
                else if (direction === "top")
                    cNode = this._findCornerNodes().top;
                else if (direction === "bottom")
                    cNode = this._findCornerNodes().bottom;
                var cNodeBounds;
                if (cNode)
                    cNodeBounds = ej.datavisualization.Diagram.Util.bounds(cNode);
                else if (direction === "center" || direction === "middle") {
                    cNodeBounds = ej.datavisualization.Diagram.Util.bounds(this.selectionList[0]);
                }
                if (cNodeBounds) {
                    var i, bounds, node, x = 0, y = 0;
                    for (i = 0; i < list.length; i++) {
                        node = this.nameTable[list[i]];
                        bounds = ej.datavisualization.Diagram.Util.bounds(node);
                        if (direction === "left")
                            x = -(bounds.x - cNodeBounds.x);
                        else if (direction === "right")
                            x = -((bounds.x + bounds.width) - (cNodeBounds.x + cNodeBounds.width));
                        else if (direction === "top")
                            y = -(bounds.y - cNodeBounds.y);
                        else if (direction === "bottom")
                            y = -((bounds.y + bounds.height) - (cNodeBounds.y + cNodeBounds.height));
                        else if (direction === "center")
                            x = -((bounds.x + bounds.width / 2) - (cNodeBounds.x + cNodeBounds.width / 2));
                        else if (direction === "middle")
                            y = -((bounds.y + bounds.height / 2) - (cNodeBounds.y + cNodeBounds.height / 2));
                        this._moveNode(x, y, node);
                    }
                    ej.datavisualization.Diagram.Util._updateGroupBounds(this.selectionList[0], this);
                    ej.datavisualization.Diagram.SvgContext.updateSelector(this.selectionList[0], this._svg, this._currZoom, this, this.model.selectedItems.constraints);
                }
            }
        },
        /**
        *Update size of the object in the selection list to the size of first object in selction list 
        *@return jQuery
        *@example
        
        *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
        *&lt;script&gt;
        *var diagram=$("#diagramcontent").ejDiagram("instance");
        *diagram.sameSize(); 
        *&lt;/script&gt;
        *@memberof ejDiagram
        *@instance
        */
        sameSize: function () {
            if (this.selectionList[0] && this.selectionList[0].type == "pseudoGroup" && this.selectionList[0].children && this.selectionList[0].children.length > 0) {
                var list = this.nameTable[this.selectionList[0].name].children;
                var fNode = this.nameTable[this.selectionList[0].children[0]];
                var fNodeBounds = ej.datavisualization.Diagram.Util.bounds(fNode);
                for (var i = 0; i < list.length; i++) {
                    var element = this.nameTable[list[i]];
                    if (!(element.segments)) {
                        element.height = fNodeBounds.height;
                        element.width = fNodeBounds.width;
                        this._updateQuad(this, element);
                        ej.datavisualization.Diagram.DiagramContext.update(element, this);
                    }
                }
                ej.datavisualization.Diagram.Util._updateGroupBounds(this.selectionList[0], this);
                ej.datavisualization.Diagram.SvgContext.updateSelector(this.selectionList[0], this._svg, this._currZoom, this, this.model.selectedItems.constraints);
            }
        },
        /**
        *Update height of the object in the selection list to the height of first object in selection list 
        *@return jQuery
        *@example
        
        *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
        *&lt;script&gt;
        *var diagram=$("#diagramcontent").ejDiagram("instance");
        *diagram.sameHeight(); 
        *&lt;/script&gt;
        *@memberof ejDiagram
*@instance
        */
        sameHeight: function () {
            if (this.selectionList[0] && this.selectionList[0].type == "pseudoGroup" && this.selectionList[0].children && this.selectionList[0].children.length > 0) {
                var list = this.nameTable[this.selectionList[0].name].children;
                var fNode = this.nameTable[this.selectionList[0].children[0]];
                var fNodeBounds = ej.datavisualization.Diagram.Util.bounds(fNode);
                for (var i = 0; i < list.length; i++) {
                    var element = this.nameTable[list[i]];
                    if (!(element.segments)) {
                        element.height = fNodeBounds.height;
                        this._updateQuad(this, element);
                        ej.datavisualization.Diagram.DiagramContext.update(element, this);
                    }
                }
                ej.datavisualization.Diagram.Util._updateGroupBounds(this.selectionList[0], this);
                ej.datavisualization.Diagram.SvgContext.updateSelector(this.selectionList[0], this._svg, this._currZoom, this, this.model.selectedItems.constraints);
            }
        },
        /**
        *Update width of the object in the selection list to the width of first object in selection list 
        *@return jQuery
        *@example
        
        *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
        *&lt;script&gt;
        *var diagram=$("#diagramcontent").ejDiagram("instance");
        *diagram.sameWidth(); 
        *&lt;/script&gt;
        *@memberof ejDiagram
*@instance
        */
        sameWidth: function () {
            if (this.selectionList[0] && this.selectionList[0].type == "pseudoGroup" && this.selectionList[0].children && this.selectionList[0].children.length > 0) {
                var list = this.nameTable[this.selectionList[0].name].children;
                var fNode = this.nameTable[this.selectionList[0].children[0]];
                var fNodeBounds = ej.datavisualization.Diagram.Util.bounds(fNode);
                for (var i = 0; i < list.length; i++) {
                    var element = this.nameTable[list[i]];
                    if (!(element.segments)) {
                        element.width = fNodeBounds.width;
                        this._updateQuad(this, element);
                        ej.datavisualization.Diagram.DiagramContext.update(element, this);
                    }
                }
                ej.datavisualization.Diagram.Util._updateGroupBounds(this.selectionList[0], this);
                ej.datavisualization.Diagram.SvgContext.updateSelector(this.selectionList[0], this._svg, this._currZoom, this, this.model.selectedItems.constraints);
            }
        },
        /**
        *Update vertical space between the object is set with selection boundary
        *@return jQuery
        *@example
        
        *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
        *&lt;script&gt;
        *var diagram=$("#diagramcontent").ejDiagram("instance");
        *diagram.spaceDown(); 
        *&lt;/script&gt;
        *@memberof ejDiagram
*@instance
        */
        spaceDown: function () {
            if (this.selectionList[0] && this.selectionList[0].type == "pseudoGroup") {
                var lstSelections = this.selectionList[0].children;
                this._sortByYvalue(this.selectionList[0].children);
                var selectionCount = lstSelections.length, fSpacing;
                if (lstSelections && selectionCount > 2) {
                    var cornerNodes = this._findCornerNodes();
                    var firstNode = cornerNodes.top;
                    var lastNode = cornerNodes.bottom;
                    if (firstNode && lastNode) {
                        var bFirst = ej.datavisualization.Diagram.Util.bounds(firstNode);
                        var bLast = ej.datavisualization.Diagram.Util.bounds(lastNode);
                        fSpacing = (bLast.y - bFirst.y) / (selectionCount - 1);
                        var y = 1;
                        for (var i = 0; i < lstSelections.length; i++) {
                            var inode = this.nameTable[lstSelections[i]];
                            if (inode !== firstNode && inode !== lastNode) {
                                if (!inode.segments) {
                                    inode.offsetY = bFirst.y + (y * fSpacing) + (inode.height / 2);
                                }
                                else {
                                    var dify;
                                    var inodes = ej.datavisualization.Diagram.Util.bounds(inode);
                                    dify = (bFirst.y + (y * fSpacing)) - (inodes.y);
                                    this._translate(inode, 0, dify, this.nameTable);
                                }
                                this._updateQuad(this, inode);
                                y += 1;
                                this._updateNodeMargin(inode);
                                ej.datavisualization.Diagram.DiagramContext.update(inode, this);
                            }
                        }
                    }
                }
            }
        },
        /**
        *Update horizontal space between the object is set with selection boundary
        *@return jQuery
        *@example
        
        *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
        *&lt;script&gt;
        *var diagram=$("#diagramcontent").ejDiagram("instance");
        *diagram.spaceAcross(); 
        *&lt;/script&gt;
        *@memberof ejDiagram
*@instance
        */
        spaceAcross: function () {
            if (this.selectionList[0] && this.selectionList[0].type == "pseudoGroup") {
                var lstSelections = this.selectionList[0].children;
                this._sortByXvalue(this.selectionList[0].children);
                var selectionCount = lstSelections.length, fSpacing;
                if (lstSelections && selectionCount > 2) {
                    var cornerNodes = this._findCornerNodes();
                    var firstNode = cornerNodes.left;
                    var lastNode = cornerNodes.right;
                    if (firstNode && lastNode) {
                        var bFirst = ej.datavisualization.Diagram.Util.bounds(firstNode);
                        var bLast = ej.datavisualization.Diagram.Util.bounds(lastNode);
                        fSpacing = (bLast.x - bFirst.x) / (selectionCount - 1);
                        var x = 1;
                        for (var i = 0; i < lstSelections.length; i++) {
                            var inode = this.nameTable[lstSelections[i]];
                            if (inode !== firstNode && inode !== lastNode) {
                                if (!inode.segments) {
                                    inode.offsetX = bFirst.x + (x * fSpacing) + (inode.width / 2);
                                }
                                else {
                                    var difx;
                                    var inodes = ej.datavisualization.Diagram.Util.bounds(inode);
                                    difx = (bFirst.x + (x * fSpacing)) - (inodes.x);
                                    this._translate(inode, difx, 0, this.nameTable);
                                }
                                this._updateQuad(this, inode);
                                x += 1;
                                this._updateNodeMargin(inode);
                                ej.datavisualization.Diagram.DiagramContext.update(inode, this);
                            }
                        }
                    }
                }
            }
        },
        /**
        *Decrease the Z-index value of selected object by 1
        *@return jQuery
        *@example
        
        *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
        *&lt;script&gt;
        *var diagram=$("#diagramcontent").ejDiagram("instance");
        *diagram.sendBackward(); 
        *&lt;/script&gt;
        *@memberof ejDiagram
*@instance
        */
        sendBackward: function () {
            var ovarLapNodes, i;
            var prevNode;
            if (this.selectionList[0] && this.selectionList[0].type != "pseudoGroup") {
                var node = this.selectionList[0];
                if (node) {
                    ovarLapNodes = this._findOverlapNode(node);
                    this._sortByZIndex(ovarLapNodes);
                    for (var k = 0; k < ovarLapNodes.length; k++)
                        if (node.zOrder > ovarLapNodes[k].zOrder) {
                            prevNode = ovarLapNodes[k];
                            break;
                        }
                    var start = node.zOrder;
                    if (prevNode) {
                        var end = prevNode.zOrder;
                        for (i = end; i < start; i++) {
                            if (node.parent != "")
                                this._findObjectByIndex(i, true).zOrder += 1;
                            else
                                this._findObjectByIndex(i).zOrder += 1;
                        }
                        if (node.parent != "") {
                            if (node.parent) {
                                var parent = this.nameTable[node.parent];
                                this._findChildren(parent, node.name).zOrder = end;
                            }
                        } else
                            this._findObjectByName(node.name).zOrder = end;
                        this._svg.getElementById(prevNode.name).parentNode.insertBefore(this._svg.getElementById(node.name), this._svg.getElementById(prevNode.name));
                        ej.datavisualization.Diagram.SvgContext.renderSelector(node, this._svg, this._adornerLayer, this._currZoom,
                        this.model.selectedItems.constraints);
                    }
                }
            }
        },
        /**
               *Increase the Z-index value of selected object by 1
               *@return jQuery
               *@example
              
               *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
               *&lt;script&gt;
               *var diagram=$("#diagramcontent").ejDiagram("instance");
               *diagram.moveForward(); 
               *&lt;/script&gt;
               *@memberof ejDiagram
*@instance
               */
        moveForward: function () {
            var ovarLapNodes, i;
            var prevNode;
            if (this.selectionList[0] && this.selectionList[0].type != "pseudoGroup") {
                var node = this.selectionList[0];
                if (node) {
                    ovarLapNodes = this._findOverlapNode(node);
                    this._sortByZIndex(ovarLapNodes);
                    for (var k = ovarLapNodes.length - 1; k >= 0; k--)
                        if (node.zOrder < ovarLapNodes[k].zOrder) {
                            prevNode = ovarLapNodes[k];
                            break;
                        }

                    var start = node.zOrder;
                    if (prevNode) {
                        var end = prevNode.zOrder;
                        for (i = end; i > start; i--) {
                            if (node.parent != "")
                                this._findObjectByIndex(i, true).zOrder -= 1;
                            else
                                this._findObjectByIndex(i).zOrder -= 1;
                        }
                        if (node.parent != "") {
                            if (node.parent) {
                                var parent = this.nameTable[node.parent];
                                this._findChildren(parent, node.name).zOrder = end;
                            }
                        }
                        else
                            this._findObjectByName(node.name).zOrder = end;
                        this._svg.getElementById(prevNode.name).parentNode.insertBefore(this._svg.getElementById(node.name), this._svg.getElementById(prevNode.name).nextSibling);
                        ej.datavisualization.Diagram.SvgContext.renderSelector(node, this._svg, this._adornerLayer, this._currZoom,
                        this.model.selectedItems.constraints);

                    }
                }
            }
        },
        /**
        *Move the selected object behind other object
        *@return jQuery
        *@example
        
        *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
        *&lt;script&gt;
        *var diagram=$("#diagramcontent").ejDiagram("instance");
        *diagram.sendToBack(); 
        *&lt;/script&gt;
        *@memberof ejDiagram
*@instance
        */
        sendToBack: function () {
            var node = this.selectionList[0];
            var prevNode;
            if (node && node.type != "pseudoGroup") {
                var ovarLapNodes = this._findOverlapNode(node);
                var nodes = this._sortByZIndex(ovarLapNodes);
                var start = node.zOrder;
                var end = node.zOrder;
                for (var i = 0; i < nodes.length; i++) {
                    if (nodes[i].zOrder < end) {
                        end = nodes[i].zOrder;
                        prevNode = nodes[i];
                    }
                }
                if (prevNode) {
                    for (i = end; i < start; i++) {
                        if (node.parent != "")
                            this._findObjectByIndex(i, true).zOrder += 1;
                        else
                            this._findObjectByIndex(i).zOrder += 1;
                    }
                    if (node.parent != "") {
                        if (node.parent) {
                            var parent = this.nameTable[node.parent];
                            this._findChildren(parent, node.name).zOrder = end;
                        }
                    } else
                        this._findObjectByName(node.name).zOrder = end;
                    this._svg.getElementById(prevNode.name).parentNode.insertBefore(this._svg.getElementById(node.name), this._svg.getElementById(prevNode.name));
                    ej.datavisualization.Diagram.SvgContext.renderSelector(node, this._svg, this._adornerLayer, this._currZoom,
                        this.model.selectedItems.constraints);
                }
            }
        },
        /**
        *Move the selected object over other object
        *@return jQuery
        *@example
        
        *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
        *&lt;script&gt;
        *var diagram=$("#diagramcontent").ejDiagram("instance");
        *diagram.bringToFront(); 
        *&lt;/script&gt;
        *@memberof ejDiagram
*@instance
        */

        bringToFront: function () {
            var node = this.selectionList[0];
            var prevNode;
            if (node && node.type != "pseudoGroup") {
                var ovarLapNodes = this._findOverlapNode(node);
                var nodes = this._sortByZIndex(ovarLapNodes);
                var start = node.zOrder;
                var end = node.zOrder;
                for (var i = 0; i < nodes.length; i++) {
                    if (nodes[i].zOrder > end) {
                        end = nodes[i].zOrder;
                        prevNode = nodes[i];
                    }
                }
                if (prevNode) {
                    for (i = 0; i < nodes.length; i++) {
                        if (nodes[i].zOrder > start) {
                            nodes[i].zOrder -= 1;
                        }
                    }
                    if (node.parent) {
                        var parent = this.nameTable[node.parent];
                        this._findChildren(parent, node.name).zOrder = end;
                    } else
                        this._findObjectByName(node.name).zOrder = end;

                    this._svg.getElementById(prevNode.name).parentNode.insertBefore(this._svg.getElementById(node.name), this._svg.getElementById(prevNode.name).nextSibling);
                    ej.datavisualization.Diagram.SvgContext.renderSelector(node, this._svg, this._adornerLayer, this._currZoom,
                        this.model.selectedItems.constraints);
                }
            }
        },
        /**
        *Reverse the last action thta was performed
        *@return jQuery
        *@example
        
        *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
        *&lt;script&gt;
        *var diagram=$("#diagramcontent").ejDiagram("instance");
        *diagram.undo(); 
        *&lt;/script&gt;
        *@memberof ejDiagram
*@instance
        */
        undo: function () {
            if (ej.datavisualization.Diagram.Util.isPageEditable(this) && ej.datavisualization.Diagram.Util.canUndo(this)) {
                var args;
                this._isUndo = true;
                //this.historyManager.undo();
                var entryItem = this.getUndoEntry();
                switch (entryItem && entryItem.type) {
                    case "positionchanged":
                        args = { object: entryItem.undoObject, isMultipleNode: entryItem.isMultipleNode };
                        this._recordPinPointChanged(args);
                        break;
                    case "rotationchanged":
                        args = { object: entryItem.undoObject, isMultipleNode: entryItem.isMultipleNode };
                        this._recordRotationChanged(args);
                        break;
                    case "sizechanged":
                        args = { object: entryItem.undoObject, isMultipleNode: entryItem.isMultipleNode };
                        this._recordSizeChanged(args);
                        break;
                    case "endpointchanged":
                        args = { undoObject: entryItem.undoObject, redoObject: entryItem.redoObject, isMultipleNode: entryItem.isMultipleNode, _isUndo: true };
                        this._recordEndPointChanged(args);
                        break;
                    case "collectionchanged":
                        args = { changeType: entryItem.changeType, childTable: entryItem.childTable, edgeTable: entryItem.edgeTable, isUndo: true, sourcePorts: entryItem.sourcePorts, targetPorts: entryItem.targetPorts };
                        args.object = jQuery.extend(true, {}, entryItem.object);
                        this._recordCollectionChanged(args);
                        break;
                    case "labelchanged":
                        args = { object: entryItem.shape, label: entryItem.previousLabelValue };
                        this._recordLabelChanged(args);
                        break;
                    case "groupchanged":
                        args = { object: entryItem.object, isUndo: true, actionType: entryItem.actionType };
                        this._recordGroupChanged(args);
                        break;
                }

                this._isUndo = false;
            }
        },
        /**
        *Restore the last action thta was performed
        *@return jQuery
        *@example
        
        *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
        *&lt;script&gt;
        *var diagram=$("#diagramcontent").ejDiagram("instance");
        *diagram.redo(); 
        *&lt;/script&gt;
        *@memberof ejDiagram
*@instance
        */
        redo: function () {
            this._isUndo = true;
            //this.historyManager.redo();
            var entryItem = this.getRedoEntry();
            switch (entryItem && entryItem.type) {
                case "positionchanged":
                    var args = { object: entryItem.redoObject, isMultipleNode: entryItem.isMultipleNode };
                    this._recordPinPointChanged(args);
                    break;
                case "rotationchanged":
                    args = { object: entryItem.redoObject, isMultipleNode: entryItem.isMultipleNode };
                    this._recordRotationChanged(args);
                    break;
                case "sizechanged":
                    args = { object: entryItem.redoObject, isMultipleNode: entryItem.isMultipleNode };
                    this._recordSizeChanged(args);
                    break;
                case "endpointchanged":
                    args = { undoObject: entryItem.undoObject, redoObject: entryItem.redoObject, isMultipleNode: entryItem.isMultipleNode, _isUndo: false };
                    this._recordEndPointChanged(args);
                case "collectionchanged":
                    args = { changeType: entryItem.changeType, childTable: entryItem.childTable, isUndo: false };
                    args.object = jQuery.extend(true, {}, entryItem.object);
                    this._recordCollectionChanged(args);
                    break;
                case "labelchanged":
                    args = { object: entryItem.shape, label: entryItem.updatedLabelValue };
                    this._recordLabelChanged(args);
                    break;
                case "groupchanged":
                    args = { object: entryItem.object, actionType: entryItem.actionType, isUndo: false };
                    this._recordGroupChanged(args);
                    break;
            }
            this._isUndo = false;
        },

        addHistoryEntry: function (entry) {
            if (this._historyList.currentEntry != null) {
                var cEntry = this._historyList.currentEntry;
                if (cEntry.next) {
                    if (cEntry.previous) {
                        var entry1 = cEntry.next;
                        entry1.previous = null;
                        cEntry.next = entry;
                        entry.previous = cEntry;
                    }
                } else {
                    cEntry.next = entry;
                    entry.previous = cEntry;
                }
            }
            this._historyList.currentEntry = entry;
            this._historyList.canUndo = true;
            this._historyList.canRedo = false;
        },

        clearHistory: function () {
            var hList = this._historyList;
            hList.currentEntry = null;
            hList.canUndo = false;
            hList.canRedo = false;
            this._hScrollbar._scrollData = null;
            this._vScrollbar._scrollData = null;
        },

        getUndoEntry: function () {
            var undoEntry = null;
            var currentEntry;
            var hList = this._historyList;
            if (hList.canUndo) {
                undoEntry = hList.currentEntry;
                currentEntry = hList.currentEntry.previous;
                if (currentEntry) {
                    hList.currentEntry = currentEntry;
                    if (!hList.canRedo)
                        hList.canRedo = true;
                } else {
                    hList.canRedo = true;
                    hList.canUndo = false;
                }
            }
            return undoEntry;
        },

        getRedoEntry: function () {
            var redoEntry = null;
            var entryCurrent;
            var hList = this._historyList;
            if (hList.canRedo) {
                if (!hList.currentEntry.previous && !hList.canUndo) {
                    entryCurrent = hList.currentEntry;
                } else
                    entryCurrent = hList.currentEntry.next;
                if (entryCurrent) {
                    hList.currentEntry = entryCurrent;
                    if (!hList.canUndo)
                        hList.canUndo = true;
                    if (!entryCurrent.next) {
                        hList.canRedo = false;
                        hList.canUndo = true;
                    }
                }
                redoEntry = hList.currentEntry;
            }
            return redoEntry;
        },
        /**
        *cut the selected object from diagram to diagram internal clipboard
        *@return jQuery
        *@example
        
        *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
        *&lt;script&gt;
        *var diagram=$("#diagramcontent").ejDiagram("instance");
        *diagram.cut(); 
        *&lt;/script&gt;
        *@memberof ejDiagram
*@instance
        */
        cut: function () {
            this._pasteIndex = 0;
            this._setClipboard();
            this._delete();
        },


        /**
 *Add ports to the node
 *@return jQuery
 *@param {String} name  to identify the object from the model 
 *@example
 
 *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
 *&lt;script&gt;
 *var diagram = $("#diagramcontent").ejDiagram("instance");
 *var port = [{ offset: { x: 0, y: 0.5 }, name: "aport", fillColor: "yellow"}, { offset: { x: 0.5, y: 0.5 }, name: "bport", fillColor: "yellow",  }];
 *diagram.addPorts("Rect1", port);
 *&lt;/script&gt;
 *@memberof ejDiagram
 *@instance
 */
        addPorts: function (name, ports) {
            if (ej.datavisualization.Diagram.Util.isPageEditable(this)) {
                var node = this.nameTable[name];
                if (node && ports) {
                    var port;
                    for (var i = 0; i < ports.length; i++) {
                        port = ej.datavisualization.Diagram.Port(ports[i]);
                        node.ports.push(port);
                        ej.datavisualization.Diagram.DiagramContext.renderPort(node, port, this);
                    }
                }
            }
        },


        /**
        *copy the selected object from internal clipboard
        *@return jQuery
        *@example
        
        *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
        *&lt;script&gt;
        *var diagram=$("#diagramcontent").ejDiagram("instance");
        *diagram.copy(); 
        *&lt;/script&gt;
        *@memberof ejDiagram
*@instance
        */

        copy: function () {
            this._pasteIndex = 1;
            if (this.selectionList && this.selectionList.length > 0) {
                this._setClipboard();
            }
        },
        /**
        *paste the selected object from internal clipboard to diagram
        *@return jQuery
        *@example
        
        *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
        *&lt;script&gt;
        *var diagram=$("#diagramcontent").ejDiagram("instance");
        *diagram.paste(); 
        *&lt;/script&gt;
        *@memberof ejDiagram
*@instance
        */
        paste: function () {
            //this._isUndo = true; 
            this._paste();
            //this._isUndo = false;
        },

        _setClipboard: function () {
            if (this.selectionList.length > 0) {
                var data, node = this.selectionList[0];
                var childTable = {};
                if (node.type == "group" || node.type == "pseudoGroup") {
                    var temp, i, j;
                    var children = this._getChildren(node.children);
                    for (i = 0; i < children.length; i++) {
                        for (j = i + 1; j < children.length; j++) {
                            var nodei = this.nameTable[children[i]];
                            var nodej = this.nameTable[children[j]];
                            if (nodej && nodei) {
                                if (nodej.zOrder < nodei.zOrder) {
                                    temp = children[i];
                                    children[i] = children[j];
                                    children[j] = temp;
                                }
                            }
                        }
                    }
                    childTable = this._getChildTable(node, childTable);
                }
                childTable[node.name] = node;
                data = $.extend(true, {}, { "childTable": childTable, "node": node });
                if (data.node.segments) {
                    data.node.targetNode = null;
                    data.node.targetPort = null;
                    data.node.sourceNode = null;
                    data.node.sourcePort = null;
                }
                this._clipboardData = data;

            }
        },

        _getChildTable: function (group, childTable) {
            var child, names, name;
            names = this._getChildren(group.children);
            if (names) {
                for (var i = 0; i < names.length; i++) {
                    name = names[i];
                    child = this.nameTable[name];
                    if (child && (child.parent === group.name || group.type == "pseudoGroup")) {
                        var node = childTable[child.name] = $.extend(true, {}, child);
                        if (node.type == "group" || node.type == "pseudoGroup")
                            childTable = this._getChildTable(node, childTable);
                        if (node.inEdges && node.inEdges.length > 0) {
                            for (var e in node.inEdges) {
                                var cCon = this.nameTable[node.inEdges[e]];
                                if (cCon) {
                                    if (childTable[cCon.name])
                                        delete childTable[cCon.name];
                                    childTable[cCon.name] = cCon;
                                }
                            }
                        }
                        if (node.outEdges && node.outEdges.length > 0) {
                            for (var f in node.outEdges) {
                                var cCon = this.nameTable[node.outEdges[f]];
                                if (cCon) {
                                    if (childTable[cCon.name])
                                        delete childTable[cCon.name];
                                    childTable[cCon.name] = cCon;
                                }
                            }
                        }
                    }
                }
            }
            return childTable;
        },

        _paste: function () {
            if (this._clipboardData) {
                var data = this._clipboardData;
                var dx, child;
                data = $.extend(true, {}, { "childTable": data.childTable, "node": data.node });
                var node = data.node;
                if (!node.container) {
                    if (node.type == "pseudoGroup") {
                        var names = node.children;
                        var pseudoGroup = ej.datavisualization.Diagram.Group({ type: "pseudoGroup", "name": "multipleSelection" });
                        this._isUndo = true;
                        for (var i = 0; i < names.length; i++) {
                            var name = names[i];
                            child = data.childTable[name];
                            if (child && (child.isLane || child.isSwimlane)) {
                                this._pasteSwimlane(child, data, true)
                            }

                            else if (child) {
                                name = name + ej.datavisualization.Diagram.Util.randomId();
                                delete (data.childTable[child.name]);
                                child.name = name;
                                child.parent = "";
                                data.childTable[child.name] = child;
                                this._preserveConnection(data.childTable, child);
                                pseudoGroup.children.push(name);
                                if (child.type == "group") {
                                    this._pasteChildren(data.childTable, child);
                                }
                                dx = this._pasteIndex * 10;
                                this._translate(child, dx, dx, this.nameTable);
                                this.add(child);
                            }
                        }
                        this._clearSelection();
                        this.nodes().push(pseudoGroup);
                        this.nameTable[pseudoGroup.name] = pseudoGroup;
                        ej.datavisualization.Diagram.Util._updateGroupBounds(pseudoGroup, this);
                        this._addSelection(pseudoGroup);
                        var childTable = {};
                        childTable = this._getChildTable(this.selectionList[0], childTable);
                        var entry = { type: "collectionchanged", object: jQuery.extend(true, {}, this.selectionList[0]), childTable: jQuery.extend(true, {}, childTable), changeType: "insert" };
                        this.addHistoryEntry(entry);
                        this._isUndo = false;
                    }
                    else {
                        node.name = node.name + ej.datavisualization.Diagram.Util.randomId();
                        node.parent = "";
                        if (node.type == "group") {
                            this._pasteChildren(data.childTable, node);
                        } else if (node.segments) {
                            //this._disConnect(node);
                        } else if (!node.segments) {
                            //@Fix
                            //this._disConnect(node);
                            node.inEdges = [];
                            node.outEdges = [];
                        }

                        dx = this._pasteIndex * 10;
                        if (!node.segments)
                            this._translate(node, dx, dx, this.nameTable);
                        else
                            ej.datavisualization.Diagram.Util._translateLine(node, dx, dx);
                        this.add(node);
                        // ej.datavisualization.Diagram.DiagramContext.update(node, this);
                        //this._clearSelection();
                        //this._addSelection(node);
                    }
                }
                else {
                    node = this._pasteSwimlane(node, data);
                    dx = this._pasteIndex * 10;
                    this._translate(node, dx, dx, this.nameTable);
                    ej.datavisualization.Diagram.DiagramContext.update(node, this);
                    this._clearSelection();
                    this._addSelection(node);
                }
                this._pasteIndex++;
            }
        },

        _pasteSwimlane: function (node, data, mSelection) {
            var name = ej.datavisualization.Diagram.Util.randomId();
            this._cloneSwimlane(node, data, name);
            if (node.isSwimlane) {
                node.width = 0;
                node.height = 0;
                node = this._getNewGroup(node)
                this.add(node);

                ej.datavisualization.Diagram.DiagramContext.update(node, this);
                return node;
            }
            else if (node.isLane) {
                var swimlane = ej.datavisualization.Diagram.SwimLaneHelper._createSwimlane(node, this, data);
                if (swimlane) {
                    swimlane.width = 0;
                    swimlane.height = 0;
                    this.add(swimlane);
                    return swimlane;
                }
            }
        },

        _cloneNode: function (node, data, name) {
            var node = jQuery.extend(true, {}, data.childTable[node]);
            if (node.children && node.children.length > 0) {
                for (var i in node.children) {
                    this._cloneNode(node.children[i], data, name);
                    node.children[i] += name;
                }
            }
            if (node.parent != "")
                node.parent += name;
            if (node.inEdges && node.inEdges.length > 0) {
                for (var e in node.inEdges) {
                    node.inEdges[e] += name;
                }
            }
            if (node.outEdges && node.outEdges.length > 0) {
                for (var e in node.outEdges) {
                    node.outEdges[e] += name;
                }
            }
            node.name += name;
            this.nameTable[node.name] = node;
        },

        _cloneSwimlane: function (node, data, name) {
            node.name += name;
            if (node.children && node.children.length > 0) {
                for (var i in node.children) {
                    this._cloneNode(node.children[i], data, name);
                    node.children[i] += name;
                }
            }
            this.nameTable[node.name] = node;
        },

        _updateChildName: function (node, name) {
            if (node && name) {
                var children = node.children;
                for (var i = 0; i < children.length; i++) {
                    children[i] = children[i] + name;
                }
            }
        },

        _pasteChildren: function (childTable, group) {
            var child, names, name;
            var childNames = [];
            names = group.children;
            for (var i = 0; i < names.length; i++) {
                name = this._getChild(names[i]);
                child = childTable[name];
                if (child) {
                    name = name + ej.datavisualization.Diagram.Util.randomId();
                    delete (childTable[child.name]);
                    child.name = name;
                    childTable[child.name] = child;
                    this._preserveConnection(childTable, child);
                    child.parent = group.name;
                    childNames.push(name);
                    if (child.type == "group") {
                        this._pasteChildren(childTable, child);
                    }
                    this.add(child);
                }
            }
            group.children = childNames;
            this._preserveConnection(childTable, group);
        },

        _preserveConnections: function (childTable, group) {
            var child, names;
            names = this._getChildren(group.children);
            for (var i = 0; i < names.length; i++) {
                child = childTable[names[i]];
                if (child) {
                    this._preserveConnection(childTable, child);
                    if (child.type == "group")
                        this._preserveConnections(childTable, group);
                }
            }
        },

        _preserveConnection: function (childTable, child) {
            var i, connection, len;
            if (!child.segments) {
                len = child.inEdges.length;
                if (len > 0) {
                    for (i = 0; i < len; i++) {
                        connection = childTable[child.inEdges[i]];
                        if (connection) {
                            connection.targetNode = child.name;
                        }
                    }
                    child.inEdges = [];
                }
                len = child.outEdges.length;
                if (len > 0) {
                    for (i = 0; i < child.outEdges.length; i++) {
                        connection = childTable[child.outEdges[i]];
                        if (connection) {
                            connection.sourceNode = child.name;
                        }
                    }
                    child.outEdges = [];
                }
            } else {
                var node;
                if (child.targetNode) {
                    node = childTable[child.targetNode];
                    if (node)
                        node.inEdges.push(child.name);
                    //else
                    //    child.targetNode = null;
                }
                if (child.sourceNode) {
                    node = childTable[child.sourceNode];
                    if (node)
                        node.outEdges.push(child.name);
                    //else
                    //    child.sourceNode = null;
                }
            }
        },

        _expandChildren: function (node) {
            for (var i = 0; i < node.outEdges.length; i++) {
                var conn = this.nameTable[node.outEdges[i]];
                conn.visible = true;
                var target = this.nameTable[conn.targetNode];
                if (target.isExpanded)
                    this._expandChildren(target);
                target.visible = true;
                target.excludeFromLayout = false;
            }
        },

        _collapseChildren: function (node) {
            for (var i = 0; i < node.outEdges.length; i++) {
                var conn = this.nameTable[node.outEdges[i]];
                conn.visible = false;
                var target = this.nameTable[conn.targetNode];
                if (target.isExpanded)
                    this._collapseChildren(target);
                target.visible = false;
                target.excludeFromLayout = true;
            }
        },
        /**
        *Used to zoomIn/zoomOut diagram
        *@return jQuery
        *@param {Object} zoom pass zoom commands of the diagram
        *@example
        
        *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
        *&lt;script&gt;
        *var diagram=$("#diagramcontent").ejDiagram("instance");
        *var zoom =  ej.datavisualization.Diagram.Zoom();
        *zoom.zoomFactor = .1;
        *zoom.zoomCommand = ej.datavisualization.Diagram.ZoomCommand.ZoomIn;
        *diagram.zoomTo(zoom);
        *&lt;/script&gt;
        *@memberof ejDiagram
*@instance
        */
        zoomTo: function (zoom) {
            if (!zoom) {
                zoom = new ej.datavisualization.Diagram.Zoom();
            }
            if (zoom.zoomCommand & ej.datavisualization.Diagram.ZoomCommand.ZoomIn) {
                ej.datavisualization.Diagram.ZoomUtil.zoomPan(this, (1 + zoom.zoomFactor), 0, 0, zoom.focusPoint, true);
            } else {
                ej.datavisualization.Diagram.ZoomUtil.zoomPan(this, (1 / (1 + zoom.zoomFactor)), 0, 0, zoom.focusPoint, true);
            }
        },
        /**
        *Removes either given node/connector or the selected element from diagram
        *@return jQuery
        *@param {Object} node pass node/connector to be removed
        *@example
        
        *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
        *&lt;script&gt;
        *var diagram=$("#diagramcontent").ejDiagram("instance");
        *diagram.remove(); 
        *&lt;/script&gt;
        *@memberof ejDiagram
*@instance
        */
        remove: function (node) {
            if (node && this.nameTable[node.name] && ej.datavisualization.Diagram.Util.isPageEditable(this)) {
                this._remove(node);
            }
            else
                this._delete();
        },
        /**
               *Remove all the elements from diagram
               *@return jQuery
               *@example
               
               *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
               *&lt;script&gt;
               *var diagram=$("#diagramcontent").ejDiagram("instance");
               *diagram.clear(); 
               *&lt;/script&gt;
               *@memberof ejDiagram
               *@instance
               */
        clear: function () {
            this._clearSelection();
            var i;
            for (i = this.connectors().length - 1; i >= 0; i--) {
                this._remove(this.connectors()[i]);
            }
            for (i = this.nodes().length - 1; i >= 0; i--) {
                this._remove(this.nodes()[i]);
            }
            this.clearHistory();
            $("#" + this._canvas.id + "_hScrollbar").ejScrollBar({ width: 0 });
            $("#" + this._canvas.id + "_vScrollbar").ejScrollBar({ height: 0 });
        },

        _add: function (node, render, arg) {
            var success = false;
            if (node.length > 0) {
                for (var i = 0; i < node.length; i++) {
                    this.add(node[i]);
                }
            } else {
                if (node.segments) var type = "connector"; else type = "node";
                var args = { changeType: "insert", element: node, cancel: false };
                this._raiseEvent(type + "CollectionChange", args);
                if (!args.cancel) {
                    this._setZorder(node);
                    if (!(node.isLane || node.isSwimlane)) {
                        if (!node.segments) {
                            if (node.type == "group") {
                                node = ej.datavisualization.Diagram.Group(node);
                                this._initGroupNode(node);
                            }
                            else {
                                //if (!(this.activeTool && this.activeTool.name === "textTool"))
                                node = this._getNewNode(node);
                                this._getNodeDimension(node, node.labels[0]);
                            }
                            success = this.nodes().push(node);
                            this.nameTable[node.name] = node;
                            if (success) {

                                if (node.type == "group") {
                                    this._updateParent(node);
                                    if (node.offsetX == 0 && node.offsetY == 0)
                                        ej.datavisualization.Diagram.Util._updateGroupBounds(node, this);
                                    this._updateChildrenEdges(node);
                                    if (render)
                                        ej.datavisualization.Diagram.DiagramContext.renderGroup(node, this);
                                } else {
                                    ej.datavisualization.Diagram.SpatialUtil._updateQuad(this, this._spatialSearch, node);
                                    if (render) {
                                        var parent = null;
                                        if (node.parent) {
                                            var parent = this._svg.document.getElementById(node.parent)
                                            var parentObj = this.nameTable[node.parent];
                                            if (parentObj) {
                                                parentObj.children.push(node.name);
                                                ej.datavisualization.Diagram.Util._updateGroupBounds(parentObj, this);
                                                ej.datavisualization.Diagram.DiagramContext.update(parentObj, this);
                                            }
                                        }
                                        ej.datavisualization.Diagram.DiagramContext.renderNode(node, this, parent);
                                    }
                                }
                                this.nameTable[node.name] = node;
                                if (render) {
                                    this._clearSelection();
                                    this._addSelection(node);
                                }
                            }
                        }
                        else {
                            node = this._getNewConnector(node);
                            success = this.model.connectors.push(node);
                            if (success) {
                                ej.datavisualization.Diagram.SpatialUtil._updateQuad(this, this._spatialSearch, node);
                                this._updateEdges(node);
                                this._dock(node, this.nameTable);
                                ej.datavisualization.Diagram.Util.updateBridging(node, this);
                                if (!node.parent) {
                                    if (render)
                                        ej.datavisualization.Diagram.DiagramContext.renderConnector(node, this);
                                }
                                this.nameTable[node.name] = node;
                                if (render) {
                                    this._clearSelection();
                                    this._addSelection(node);
                                }
                            }
                        }
                    }
                    else {
                        success = this.nodes().push(node);
                        this.nameTable[node.name] = node;
                        if (success) {
                            if (node.type == "group") {
                                if (render) {
                                    ej.datavisualization.Diagram.DiagramContext.renderGroup(node, this);
                                    this._clearSelection();
                                    this._addSelection(node);
                                }
                            }
                        }
                    }
                }
            }
            if (!this._isUndo && !this._selectedSymbol) {
                if (node.parent == "") {
                    var childTable = {};
                    if (this.selectionList && this.selectionList.length > 0)
                        childTable = this._getChildTable(this.selectionList[0], childTable);
                    var entry = { type: "collectionchanged", object: jQuery.extend(true, {}, node), childTable: jQuery.extend(true, {}, childTable), changeType: "insert" };
                    this.addHistoryEntry(entry);
                }
            }
            return success;
        },
        /**
              *Add node/connector
              *@return jQuery
              *@param {Object} node pass node/connector to be added
              *@example
              
              *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
              *&lt;script&gt;
              *var diagram=$("#diagramcontent").ejDiagram("instance");
              *var node = [];
              *node=[{ name: "node", width: 175, height: 60, offsetX: 400, offsetY: 60, shape: { type: "Rectangle"}];
              *diagram.add(node);
              *&lt;/script&gt;
              *@memberof ejDiagram
              *@instance
              */
        add: function (node, args) {
            if (ej.datavisualization.Diagram.Util.isPageEditable(this)) {
                return this._add(node, true, args);
            }
        },
        /**
           *Update userhandles of given node
           *@return jQuery
            *@param {Object} node pass node/connector 
           *@example
          
           *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
           *&lt;script&gt;
           *var diagram=$("#diagramcontent").ejDiagram("instance");
           * var node = diagram.selectionList[0];
           * diagram.updateUSerHandles(node); 
           *&lt;/script&gt;
           *@memberof ejDiagram
*@instance
           */
        updateUserHandles: function (node) {
            ej.datavisualization.Diagram.SvgContext.updateUserHandles(this.model.selectedItems.userHandles, node, this._svg, false, false, this._currZoom);
        },
        /**
           *Update offsetX of given node
           *@return jQuery
            *@param {Object} node pass node/connector to be added
           *@example
          
           *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
           *&lt;script&gt;
           *var diagram=$("#diagramcontent").ejDiagram("instance");
           * var node = diagram.selectionList[0];
           * diagram.scrollToNode(node); 
           *&lt;/script&gt;
           *@memberof ejDiagram
*@instance
           */
        scrollToNode: function (node) {
            var nodeX, nodeY;
            var curZoomfactor = this._currZoom;
            var elementBounds = this.element[0].getBoundingClientRect();
            var nodeBounds = ej.datavisualization.Diagram.Util.bounds(node);
            nodeX = (nodeBounds.x + nodeBounds.width / 2) * curZoomfactor;
            nodeY = (nodeBounds.y + nodeBounds.height / 2) * curZoomfactor;
            var hScrollOffset = this._hScrollOffset, vScrollOffset = this._vScrollOffset;
            if (elementBounds.width + this._hScrollOffset < nodeX + nodeBounds.width / 2) {
                hScrollOffset = (nodeX + (nodeBounds.width * curZoomfactor) - elementBounds.width);
            }
            if (elementBounds.height + this._vScrollOffset < nodeY + nodeBounds.height / 2) {
                vScrollOffset = (nodeY + (nodeBounds.height * curZoomfactor) - elementBounds.height);
            }
            this._updateScrollOffset(hScrollOffset, vScrollOffset);
        },

        findNode: function (id) {
            return this._findNode(id);
        },
        //#endregion

        //#region support methods

        _getElementType: function (element) {
            if (element) {
                if (element.isSwimlane)
                    return "swimlane";
                else if (element.type == "group")
                    return "group";
                else if (element.segments)
                    return "connector";
                else if (element.shape)
                    return "node";
                else return null;
            }
            return null;
        },

        _registerDrawingTools: function () {
            for (var toolname in this.model.drawingTools) {
                var tool = this.model.drawingTools[toolname];
                tool.diagram = this;
                this.tools[tool.name] = tool;
            }
        },

        _sortByXvalue: function (nodes) {
            var temp, i, j;
            var fNode, lNode;
            for (i = 0; i < nodes.length; i++) {
                for (j = i + 1; j < nodes.length; j++) {
                    var nodei = this.nameTable[nodes[i]];
                    var nodej = this.nameTable[nodes[j]];
                    fNode = ej.datavisualization.Diagram.Util.bounds(nodei);
                    lNode = ej.datavisualization.Diagram.Util.bounds(nodej);
                    if (fNode.x > lNode.x) {
                        temp = nodes[i];
                        nodes[i] = nodes[j];
                        nodes[j] = temp;
                    }
                }
            }
            return nodes;
        },

        _sortByYvalue: function (nodes) {
            var temp, i, j;
            var fNode, lNode;
            for (i = 0; i < nodes.length; i++) {
                for (j = i + 1; j < nodes.length; j++) {
                    var nodei = this.nameTable[nodes[i]];
                    var nodej = this.nameTable[nodes[j]];
                    fNode = ej.datavisualization.Diagram.Util.bounds(nodei);
                    lNode = ej.datavisualization.Diagram.Util.bounds(nodej);
                    if (fNode.y > lNode.y) {
                        temp = nodes[i];
                        nodes[i] = nodes[j];
                        nodes[j] = temp;
                    }
                }
            }
            return nodes;
        },

        _sortByZIndex: function (nodes, asc) {
            var temp, i, j;
            if (!asc) {
                for (i = 0; i < nodes.length; i++) {
                    for (j = i + 1; j < nodes.length; j++) {
                        if (nodes[i].zOrder < nodes[j].zOrder) {
                            temp = nodes[i];
                            nodes[i] = nodes[j];
                            nodes[j] = temp;
                        }
                    }

                }
            }
            else {
                for (i = 0; i < nodes.length; i++) {
                    for (j = i + 1; j < nodes.length; j++) {
                        if (nodes[i].zOrder > nodes[j].zOrder) {
                            temp = nodes[i];
                            nodes[i] = nodes[j];
                            nodes[j] = temp;
                        }
                    }

                }
            }
            return nodes;
        },

        _findCornerNodes: function () {
            var lNode, rNode, tNode, bNode, i, nBounds;
            var list = this.selectionList[0].children;
            var fnode = this.nameTable[this.selectionList[0].children[0]];
            lNode = fnode, rNode = fnode, tNode = fnode, bNode = fnode;

            if (list.length > 1) {
                for (i = 0; i < list.length; i++) {
                    var node = this.nameTable[list[i]];
                    nBounds = ej.datavisualization.Diagram.Util.bounds(node);

                    var rNodeBounds = ej.datavisualization.Diagram.Util.bounds(rNode);    //Right Node
                    if ((nBounds.x + nBounds.width) > (rNodeBounds.x + rNodeBounds.width))
                        rNode = node;

                    var bNodeBounds = ej.datavisualization.Diagram.Util.bounds(bNode);    //Bottom Node
                    if ((nBounds.y + nBounds.height) > (bNodeBounds.y + bNodeBounds.height))
                        bNode = node;

                    var lNodeBounds = ej.datavisualization.Diagram.Util.bounds(lNode);    //Left Node
                    if (nBounds.x < lNodeBounds.x)
                        lNode = node;

                    var tNodeBounds = ej.datavisualization.Diagram.Util.bounds(tNode);    //top Node
                    if (nBounds.y < tNodeBounds.y)
                        tNode = node;

                }
            }
            return { left: lNode, right: rNode, top: tNode, bottom: bNode };
        },

        _moveNode: function (diffX, diffY, node) {
            this._translate(node, diffX, diffY, this.nameTable);
            this._updateNodeMargin(node);
            ej.datavisualization.Diagram.DiagramContext.update(node, this);
        },

        _nudge: function (node, x, y) {
            this.activateTool("move");
            this.activeTool.inAction = true;
            this._translate(node, x, y, this.nameTable);
            this._updateNodeMargin(node);
            ej.datavisualization.Diagram.DiagramContext.update(node, this);
            this._updateSelectionHandle(true);
            //ej.datavisualization.Diagram.SvgContext.updateSelector(node, this._svg, this._currZoom, this, this.model.selectedItems.constraints);
        },

        _findObjectByName: function (name) {
            var node = null;
            if (this._findNode(name))
                node = this._findNode(name);
            if (this._findConnector(name))
                node = this._findConnector(name);
            return node;
        },

        _findObjectByIndex: function (index, group) {
            var nodes, findNode = null, node, m, k;
            if (group) {
                var parent = this.nameTable[this.selectionList[0].parent];
                if (parent) {
                    nodes = this._getChildren(parent.children);
                    for (k = 0; k < nodes.length; k++) {
                        node = this.nameTable[nodes[k]];
                        if (node.zOrder === index)
                            findNode = nodes[k];
                    }
                }
            } else {
                for (m = 0; m < this.nodes().length; m++) {
                    node = this.nodes()[m];
                    if (node.zOrder === index)
                        findNode = node;
                }
                for (m = 0; m < this.connectors().length; m++) {
                    node = this.connectors()[m];
                    if (node.zOrder === index)
                        findNode = node;
                }
            }

            return findNode;
        },

        _findOverlapNode: function (node) {
            var oNodes = [], m, i, rNodes = [];
            if (!node.parent) {
                for (m = 0; m < this.nodes().length; m++) {
                    oNodes.push(this.nodes()[m]);
                }
                for (m = 0; m < this.connectors().length; m++) {
                    oNodes.push(this.connectors()[m]);
                }
                var nBound = ej.datavisualization.Diagram.Util.bounds(node);
                if (node) {
                    for (i = 0; i < oNodes.length; i++) {
                        var chBound = ej.datavisualization.Diagram.Util.bounds(oNodes[i]);
                        if (node.name !== oNodes[i].name) {
                            if (this._intersect(nBound, chBound))
                                rNodes.push(oNodes[i]);
                        }
                    }
                }
            } else {
                var parent = this.nameTable[node.parent], child;
                if (parent) {
                    var children = this._getChildren(parent.children);
                    for (m = 0; m < children.length; m++) {
                        if (children[m] !== node.name) {
                            child = this.nameTable[children[m]];
                            if (child)
                                rNodes.push(child);
                        }
                    }
                }
            }
            return rNodes;
        },

        _intersect: function (a, b) {
            return (a.x <= (b.x + b.width) &&
                b.x <= (a.x + a.width) &&
                a.y <= (b.y + b.height) &&
                b.y <= (a.y + a.height));
        },
        //#endregion 

        //#region Rendering
        _createTooltipDiv: function () {
            var div = document.createElement("div");
            var attr = {
                "id": this.element[0].id + "_tooltipDiv",
                "class": "e-diagram-tooltip-default", "style": "padding-top:3px; height: 24px;pointer-events:none;",
            };
            ej.datavisualization.Diagram.Util.attr(div, attr);
            this._canvas.appendChild(div);
            return div;
        },

        _renderTooltip: function (object) {
            if (!(object.parent && this.nameTable[object.parent] && this.nameTable[object.parent].container)) {
                if (this.showTooltip() && $.templates) {
                    var tooltipDiv = $("#" + this.element[0].id + "_tooltipDiv")[0];
                    if (!tooltipDiv) {
                        tooltipDiv = this._createTooltipDiv();
                    }
                    var template;
                    var objectValues;
                    var html;

                    var curZoomfactor = this._currZoom;
                    if (!this.model.tooltipTemplateId) {
                        template = $.templates("#" + this.element[0].id + "_defaultTooltip");
                        if (this.activeTool instanceof ej.datavisualization.Diagram.MoveTool) {
                            tooltipDiv.style.width = "150px";
                            if (!object.segments)
                                objectValues = [{ type: "X : ", type1: "Y : ", x: Math.round((object.offsetX - object.width / 2)) + "px  ", y: Math.round((object.offsetY - object.height / 2)) + "px" }];
                        } else if (this.activeTool instanceof ej.datavisualization.Diagram.ResizeTool) {
                            tooltipDiv.style.width = "150px";
                            objectValues = [{ type: "W : ", type1: "H : ", x: Math.round(object.width) + "px  ", y: Math.round(object.height) + "px" }];
                        } else if (this.activeTool instanceof ej.datavisualization.Diagram.RotateTool) {
                            tooltipDiv.style.width = "50px";
                            objectValues = [{ type: "", type1: "", x: Math.round(object.rotateAngle) + "&deg; ", y: "" }];
                        }
                        if (objectValues) {
                            tooltipDiv.style.top = -this._vScrollOffset + ((object.offsetY * curZoomfactor - (object.height / 2) * curZoomfactor) + (object.height * curZoomfactor) + 15) + "px";
                            tooltipDiv.style.left = -this._hScrollOffset + ((object.offsetX * curZoomfactor - (object.width / 2) * curZoomfactor)) + (object.width / 2 * curZoomfactor - $(tooltipDiv).width() / 2) + "px";
                            html = template.render(objectValues);
                            $(tooltipDiv).html(html);
                        } else {
                            this._removeTooltip();
                        }
                    } else {
                        if (!object.segments) {
                            tooltipDiv.style.top = -this._vScrollOffset + ((object.offsetY * curZoomfactor - (object.height / 2) * curZoomfactor) + (object.height * curZoomfactor) + 15) + "px";
                            tooltipDiv.style.left = -this._hScrollOffset + ((object.offsetX * curZoomfactor - (object.width / 2) * curZoomfactor)) + (object.width / 2 * curZoomfactor - $(tooltipDiv).width() / 2) + "px";
                            template = $.templates("#" + this.model.tooltipTemplateId);
                            objectValues = [{ name: this.activeTool.selectedObject.name, x: (object.offsetX - object.width / 2) + "px", y: (object.offsetY - object.height / 2) + "px", width: object.width + "px", height: object.height + "px", rotationAngle: object.rotateAngle }];
                            html = template.render(objectValues);
                            $(tooltipDiv).html(html);
                        }
                    }
                }
            }
        },

        _removeTooltip: function () {
            var tooltipDiv = document.getElementById(this.element[0].id + "_tooltipDiv");
            if (tooltipDiv) {
                tooltipDiv.parentNode.removeChild(tooltipDiv);
            }
        },

        _renderCanvas: function (isLoad) {
            if (!isLoad) {
                this._canvas = document.createElement("div");
                this.element.append(this._canvas);
            }
            this._canvas.setAttribute("id", this.element[0].id + "_canvas");
            this._canvas.setAttribute("class", "drawing");
            this._canvas.setAttribute("style", "position:relative; height:" + this.model.height + "; width:" + this.model.width + ";");
            this.element.css({
                overflow: "hidden", outline: "none", display: "block", height: this.model.height, width: this.model.width
            });
            this._views[this._id].canvas = this._canvas;
            this.element[0].setAttribute("tabindex", 0);

            this._renderDiagram(isLoad);
        },

        _getDigramBounds: function () {
            var left, top, right, bottom;
            left = Math.min(0, this._spatialSearch.pageLeft);
            top = Math.min(0, this._spatialSearch.pageTop);
            if (!this._pageWidth()) {
                right = this._spatialSearch.pageRight - Math.min(0, this._spatialSearch.pageLeft);
            }
            if (!this._pageHeight()) {
                bottom = this._spatialSearch.pageBottom - Math.min(0, this._spatialSearch.pageTop);
            }
            if (this.model.pageSettings && this._multiplePage()) {
                left = Math.min(0, this._spatialSearch.pageLeft);
                top = Math.min(0, this._spatialSearch.pageTop);
                if (this._pageWidth()) {
                    left = Math.floor(left / this._pageWidth()) * this._pageWidth();
                    right = Math.ceil(this._spatialSearch.pageRight / this._pageWidth()) * this._pageWidth() - left;
                }
                if (this._pageHeight()) {
                    top = Math.floor(top / this._pageHeight()) * this._pageHeight();
                    bottom = Math.ceil(this._spatialSearch.pageBottom / this._pageHeight()) * this._pageHeight() - top;
                }
                if (this._spatialSearch.pageRight === null) {
                    if (this._pageWidth() !== 0) {
                        right = this._pageWidth();
                    }
                }
                if (this._spatialSearch.pageBottom === null) {
                    if (this._pageHeight() !== 0) {
                        bottom = this._pageHeight();
                    }
                }
            }
            else {
                if (this._pageWidth()) {
                    left = Math.min(0, this._spatialSearch.pageLeft);
                    right = this._pageWidth();
                }
                if (this._pageHeight()) {
                    top = Math.min(0, this._spatialSearch.pageTop);

                    bottom = this._pageHeight();
                }
            }
            var svgBounds = new ej.datavisualization.Diagram.Rectangle();
            svgBounds.x = left;
            svgBounds.y = top;
            svgBounds.width = right;
            svgBounds.height = bottom;
            return svgBounds;
        },

        _initContextMenu: function (isLoad) {
            if (this.enableContextMenu()) {
                this._renderContextMenu(isLoad);
            }
            else {
                $("#" + this.element[0].id + "_contextMenu").remove();
            }
        },

        _renderContextMenuItem: function (item) {
            var li = document.createElement("li");
            var a = document.createElement("a");
            var menu = ej.datavisualization.Diagram.Locale[this.locale()];
            $.each(menu, function (otext, ntext) {
                if (item.name === otext) {
                    a.innerHTML = ntext;
                    item.text = ntext;
                }
            });
            li.setAttribute("id", this.element[0].id + "_contextMenu_" + item.name);

            var div = document.createElement("span");
            div.setAttribute("id", item.text + "_image");
            div.setAttribute("style", "display:table-cell; vertical-align:middle; text-align:center");
            div.setAttribute("class", "sf-d-menuitem " + item.name);
            a.appendChild(div);
            if (item.subItems && item.subItems.length > 0) {
                var subUl = document.createElement("ul");
                var i = 0, subli;
                for (i; i < item.subItems.length; i++) {
                    subli = this._renderContextMenuItem(item.subItems[i], subUl);
                    subUl.appendChild(subli);
                }
                li.appendChild(subUl);
            }
            li.appendChild(a);
            return li;
        },

        _renderContextMenu: function (isLoad) {
            if (!isLoad && !this.model.contextMenu.showCustomMenuItemsOnly) {
                for (var i = this._defaultContextMenuItems.length - 1; i >= 0; i--) {
                    this.model.contextMenu.items.splice(0, 0, this._defaultContextMenuItems[i]);
                }
            }
            var menuCollection = this.model.contextMenu.items;
            var i = 0, item, mItem;
            var ul = document.createElement("ul");
            ul.setAttribute("id", this.element[0].id + "_contextMenu");
            for (i; i < menuCollection.length; i++) {
                item = menuCollection[i];
                mItem = this._renderContextMenuItem(item, ul);
                ul.appendChild(mItem);
            }
            this._canvas.appendChild(ul);

            $("#" + this.element[0].id + "_contextMenu").ejMenu({
                menuType: ej.MenuType.ContextMenu,
                contextMenuTarget: "#" + this.element[0].id + "_canvas_svg",
                click: $.proxy(this._onMenuItemClick, this),
                beforeOpen: $.proxy(this._onContextMenuOpen, this),
                mouseover: $.proxy(this._onMenuItemMouseOver, this),
                mouseout: $.proxy(this._onMenuItemMouseOut, this),
                close: $.proxy(this._onContextMenuClose, this),
            });
        },

        _onContextMenuClose: function () {
            this.element[0].focus();
        },

        _onContextMenuOpen: function (args) {
            var _id = this.element[0].id;
            var node = this._findNodeUnderMouse(args);
            var isMulSel = false;
            if (this.selectionList[0] && (this.selectionList[0].type == "pseudoGroup" || this.selectionList[0].type == "group"))
                isMulSel = true;
            if (node && (this.selectionList.length <= 0 || (this.selectionList[0] != node)) && !isMulSel) {
                args.cancel = true;
                $("#" + this.element[0].id + "_contextMenu").ejMenu("instance")._hideContextMenu();
            }
            if (!node && this.selectionList.length > 0 && !isMulSel) {
                this._clearSelection();
            }
            if (this.enableContextMenu()) {
                if ($("#" + _id + "_contextMenu_cut")[0])
                    $("#" + _id + "_contextMenu_cut")[0].style.display = "block";
                if ($("#" + _id + "_contextMenu_copy")[0])
                    $("#" + _id + "_contextMenu_copy")[0].style.display = "block";
                if ($("#" + _id + "_contextMenu_paste")[0])
                    $("#" + _id + "_contextMenu_paste")[0].style.display = "block";
                if ($("#" + _id + "_contextMenu_undo")[0])
                    $("#" + _id + "_contextMenu_undo")[0].style.display = "block";
                if ($("#" + _id + "_contextMenu_redo")[0])
                    $("#" + _id + "_contextMenu_redo")[0].style.display = "block";
                if ($("#" + _id + "_contextMenu_selectAll")[0])
                    $("#" + _id + "_contextMenu_selectAll")[0].style.display = "block";
                if ($("#" + _id + "_contextMenu_cut")[0])
                    $("#" + _id + "_contextMenu_cut")[0].style.display = "block";
                if ($("#" + _id + "_contextMenu_grouping")[0])
                    $("#" + _id + "_contextMenu_grouping")[0].style.display = "block";
                if ($("#" + _id + "_contextMenu_order")[0])
                    $("#" + _id + "_contextMenu_order")[0].style.display = "block";
                if (this.selectionList.length == 0) {
                    if ($("#" + _id + "_contextMenu_cut")[0])
                        $("#" + _id + "_contextMenu_cut")[0].style.display = "none";
                    if ($("#" + _id + "_contextMenu_copy")[0])
                        $("#" + _id + "_contextMenu_copy")[0].style.display = "none";
                    if ($("#" + _id + "_contextMenu_cut")[0])
                        $("#" + _id + "_contextMenu_cut")[0].style.display = "none";
                    if ($("#" + _id + "_contextMenu_grouping")[0])
                        $("#" + _id + "_contextMenu_grouping")[0].style.display = "none";
                    if ($("#" + _id + "_contextMenu_order")[0])
                        $("#" + _id + "_contextMenu_order")[0].style.display = "none";
                }
            }
            var obj = ({ diagram: this, contextmenu: args });
            this._trigger("contextMenuBeforeOpen", obj);
        },

        _onMenuItemClick: function (args) {
            var menuId = args.events.ID.replace(this._id + "_" + "contextMenu_", "");
            switch (menuId) {
                case "cut":
                    this.cut();
                    break;
                case "copy":
                    this.copy();
                    break;
                case "paste":
                    this.paste();
                    break;
                case "undo":
                    this.undo();
                    break;
                case "redo":
                    this.redo();
                    break;
                case "selectAll":
                    this.selectAll();
                    break;
                case "group":
                    this.group();
                    break;
                case "ungroup":
                    this.ungroup();
                    break;
                case "bringToFront":
                    this.bringToFront();
                    break;
                case "sendToBack":
                    this.sendToBack();
                    break;
                case "moveForward":
                    this.moveForward();
                    break;
                case "sendBackward":
                    this.sendBackward();
                    break;
                default:
                    break;
            }
            this._trigger("contextMenuClick", args);
        },

        _onMenuItemMouseOver: function (args) {
            var t = args.events.element.lastChild.childNodes[1];
            $(t).addClass("hover");
        },

        _onMenuItemMouseOut: function (args) {
            var t = args.events.element.lastChild.childNodes[1];
            $(t).removeClass("hover");
        },

        _renderDiagram: function (isload) {
            var diagram = this;
            this._views.forEach(function (viewid) {
                var view = diagram._views[viewid];
                view.context._renderDocument(view, diagram, isload); if (view.type == "mainview" && view.context == ej.datavisualization.Diagram.SvgContext) {
                    diagram._createScrollbar(diagram._canvas);
                    ej.datavisualization.Diagram.ScrollUtil._initScrollbar(diagram);
                    ej.datavisualization.Diagram.PageUtil._updatePageSize(diagram);
                }
                //if (diagram.model.layout && diagram.model.layout.type !== ej.datavisualization.Diagram.LayoutTypes.None) {
                //    diagram._doLayout();
                //};
                if (!isload) {
                    diagram._setNodeZOrder(view);
                    diagram._renderNodes(view);
                    diagram._renderConnectors(view);
                    diagram._renderphases(view);
                }
            });
            $(this._svg.document).pinchDiagram(this._view, this);
        },

        _createScrollbar: function (canvas) {
            var hScrollbar = document.createElement("div");
            hScrollbar.setAttribute("id", canvas.id + "_hScrollbar");
            canvas.appendChild(hScrollbar);
            var vScrollbar = document.createElement("div");
            vScrollbar.setAttribute("id", canvas.id + "_vScrollbar");
            canvas.appendChild(vScrollbar);
        },

        _doLayout: function () {
            if (this.model.layout && this.model.layout.type !== ej.datavisualization.Diagram.LayoutTypes.None) {
                //this.model.layout = new ej.datavisualization.Diagram.HierarchicalLayout(this.model.layout);
                //this.model.layout._setModel(this);
                this._updateEdgeCollection();
                ej.datavisualization.Diagram.Layout.doLayout(this);
                //this.model.layout.doLayout(this);
            }
        },

        _updateNodes: function () {
            var nodes = this.nodes();
            for (var i = 0; i < nodes.length; i++) {
                ej.datavisualization.Diagram.DiagramContext.update(nodes[i], this);
            }
        },

        _updateConnectors: function () {
            var connections = this.connectors();
            for (var i = 0; i < connections.length; i++) {
                ej.datavisualization.Diagram.DiagramContext.update(connections[i], this);
            }
        },

        _updateEdgeCollection: function () {
            for (var i = 0; i < this.connectors().length; i++) {
                this._updateEdges(this.connectors()[i]);
            }
        },
        /**
        *To update viewport when window resize
        *@return jQuery
        *@example
        
        *&lt;div id="diagramcontent"&gt;&lt;/div&gt;
        *&lt;script&gt;
        *var diagram=$("#diagramcontent").ejDiagram("instance");
        *diagram.updateViewPort();
        *&lt;/script&gt;
        *@memberof ejDiagram
*@instance
        */

        updateViewPort: function () {
            ej.datavisualization.Diagram.DiagramContext.updateViewPort(this);
        },

        _containsSameIndex: function (index, parent) {
            if (!parent) {
                var nodes = this.nodes(), cNode;
                for (var i = 0; i < nodes.length > 0; i++) {
                    cNode = nodes[i];
                    if (cNode && cNode.zOrder === index)
                        return true;
                }
            }
            else {
                var children = parent.children, child;
                for (var i = 0; i < children.length; i++) {
                    child = this.nameTable[this._getChild(children[i])];
                    if (child && child.zOrder) {
                        if (child.zOrder === index)
                            return true;
                    }
                }
            }
            return false;
        },
        _setZorder: function (node) {
            if (node && node.zOrder) {
                if (node.zOrder == -1) {
                    if (this._containsSameIndex(this._zOrder)) {
                        do {
                            this._zOrder++;
                        } while (this._containsSameIndex(this._zOrder));
                        node.zOrder = this._zOrder;
                    }
                    else {
                        node.zOrder = this._zOrder;
                        this._zOrder++;
                    }
                }
                else {
                }
                if (node.type === "group") {
                    var children = node.children, child;
                    for (var i = 0; i < children.length; i++) {
                        child = this.nameTable[this._getChild(children[i])];
                        if (child && child.zOrder && child.zOrder === -1) {
                            var inx = i;
                            if (this._containsSameIndex(i, node)) {
                                do {
                                    inx++;
                                } while (this._containsSameIndex(inx));
                                child.zOrder = inx;
                            }
                            else {
                                child.zOrder = i;
                            }
                        }
                    }
                }
            }
        },

        _union: function (rect1, rect2) {
            var x = Math.min(rect1.x, rect2.x);
            var y = Math.min(rect1.y, rect2.y);
            var overWidth = Math.max(rect1.x + rect1.width, rect2.x + rect2.width);
            var overheight = Math.max(rect1.y + rect1.height, rect2.y + rect2.height);
            return new ej.datavisualization.Diagram.Rectangle(x, y, overWidth - x, overheight - y);
        },
        _getSeperetor: function (id) {
            var phases = this.model.phases;
            if (phases) {
                for (var i = 0, len = phases.length; i < len; i++) {
                    if (phases[i].name == id) {
                        return phases[i];
                    }
                }
            }
        },
        _renderphases: function () {
            var phases = this.model.phases;
            if (phases) {
                for (var i = 0, len = phases.length; i < len; i++) {
                    if (phases[i].type == "phase") {
                        ej.datavisualization.Diagram.SvgContext.renderphase(phases[i], this._svg, this._diagramLayer, this);
                    }
                }
            }
        },

        _setNodeZOrder: function (view) {
            var temp = null, jindex, iindex;
            if (this.nodes()) {
                var nodes = this.nodes();
                for (var f = 0; f < nodes.length; f++) {
                    if (nodes[f].parent === "")
                        this._setZorder(nodes[f]);
                }
                for (var i = 0; i < nodes.length; i++) {
                    for (var j = i + 1; j < nodes.length; j++) {
                        if (nodes[i].zOrder > nodes[j].zOrder && (nodes[i].parent === "" && nodes[j].parent === "")) {
                            jindex = nodes[j].zOrder;
                            iindex = nodes[i].zOrder;
                            temp = nodes[i];
                            nodes[i] = nodes[j];
                            nodes[j] = temp;
                        }
                    }
                    if (nodes[i].type === "group") {
                        var children = nodes[i].children;
                        for (var m = 0; m < children.length; m++) {
                            for (var n = m + 1; n < children.length; n++) {
                                if (children[m].zOrder > children[n].zOrder) {
                                    jindex = children[n].zOrder;
                                    iindex = children[m].zOrder;
                                    temp = children[m];
                                    children[m] = children[n];
                                    children[n] = temp;
                                }
                            }
                        }
                    }
                }
            }
        },
        _renderNodes: function (view, isLoad, isoverView) {
            if (this.nodes()) {
                var nodes = this.nodes();
                for (var i = 0, len = nodes.length; i < len; ++i) {
                    var node = this.nameTable[nodes[i].name];
                    var panel = view.svg || view._canvas;
                    if (node.type == "group" && !node.parent) {
                        if (!node.container) {
                            ej.datavisualization.Diagram.Util._updateGroupBounds(node, this, true);
                        }
                        view.context.renderGroup(node, panel, view.diagramLayer, this.nameTable, this, isLoad, isoverView);
                        ej.datavisualization.Diagram.Util._updateGroupBounds(node, this);
                        ej.datavisualization.Diagram.DiagramContext.update(node, this);
                    }
                    else {
                        if (!node.parent)
                            view.context.renderNode(node, panel, view.diagramLayer, this);
                    }
                }
            }
        },

        _renderConnectors: function (view) {
            if (this.connectors()) {
                var connectors = this.connectors();
                var panel = view.svg || view._canvas;
                var connector;
                for (var i = 0, len = connectors.length; i < len; ++i) {
                    connector = connectors[i];
                    this._setZorder(connector);
                }
                for (var i = 0, len = connectors.length; i < len; ++i) {
                    connector = connectors[i];
                    ej.datavisualization.Diagram.Util.updateBridging(connector, this);
                    if (connector.parent && connector.parent != "") {
                        var parent = this._svg.document.getElementById(connector.parent)
                        if (parent)
                            view.context.renderConnector(connector, panel, parent, this);
                    }
                    else
                        view.context.renderConnector(connector, panel, view.diagramLayer, this);
                }
            }
        },

        //#endregion

        //#region Events
        _wireEvents: function () {
            //svg document events
            var svgDocument = $(this._canvas);
            this._on(svgDocument, ej.eventType.mouseDown, this._mousedown);
            this._on(svgDocument, ej.eventType.mouseMove, this._mousemove);
            this._on(svgDocument, ej.eventType.mouseUp, this._mouseup);
            this._on(svgDocument, ej.eventType.mouseLeave, this._documentmouseup);
            this._on(svgDocument, "dblclick", this._doubleclick);
            this._on(svgDocument, "doubletap", this._doubleclick);

            this._on(this.element, "keydown", this._keydown);
            this._on(this.element, "keyup", this._keyup);
            //this._on(this.element, "contextmenu", this._contextmenu);
            this._on(svgDocument, "pinchin", this._pinchin);
            this._on(svgDocument, "pinchout", this._pinchout);
            this._on(this.element, "touchstart", this._handleTouchStart);
            if (ej.browserInfo().name === "mozilla") {
                this._on(this.element, "DOMMouseScroll", this._handleMouseWheel);
            }
            else
                this._on(this.element, "mousewheel", this._handleMouseWheel);
            //window document event
            this._on($(document), "mouseup", this._documentmouseup);

            if (window) {
                this._on($(window), "resize", this.updateViewPort);
            }
            var obj = this;
            $(svgDocument).ejDroppable({
                drop: function (event, ui) {
                    obj._svgdrop(event, ui);
                    obj._isDropped = true;
                }
            });
        },

        _mousePosition: function (evt, exOffset) {
            var e = this._isTouchEvent(evt);
            var scrollLeft = this._canvas.scrollLeft;
            var scrollTop = this._canvas.scrollTop;
            var controlBBox = this._canvas.getBoundingClientRect();
            var layerx = (e.clientX + scrollLeft) - controlBBox.left;
            var layery = (scrollTop + e.clientY) - controlBBox.top;
            if (!exOffset) {
                layerx = (layerx + this._hScrollOffset) / this._currZoom;
                layery = (layery + this._vScrollOffset) / this._currZoom;
            }
            return new ej.datavisualization.Diagram.Point(Math.round(layerx * 100) / 100, Math.round(layery * 100) / 100);
        },

        _contextmenu: function (evt) {
            evt.preventDefault();
            evt.stopPropagation();
        },

        _pinchin: function (evt) {
            evt.preventDefault();
        },

        _pinchout: function (evt) {
            evt.preventDefault();
        },

        _handleTouchStart: function (evt) {
            evt.preventDefault();
        },

        _mousedown: function (evt) {
            this._isPinching = false;
            if (this._invoke(evt)) {
                if (!this._isForeignObject(evt.originalEvent.target))
                    evt.preventDefault();
                if (this.model.contextMenu && $("#" + this.element[0].id + "_contextMenu").css("display") !== "none") {
                    evt.cancel = true;
                }
                if (this._isEditing)
                    this._endEdit();
                if ((evt.which === 1 || evt.which === 3) || (evt.which === 0 && evt.originalEvent.changedTouches)) {
                    if (evt.which === 0 && evt.originalEvent.changedTouches) {
                        var node = null;
                        var point = this._mousePosition(evt);
                        var isUserHandle = this._isUserHandle(evt);
                        if ((this._isInternalTool(this.activeTool) && !this.activeTool.inAction)) {
                            if (!isUserHandle) {
                                node = this._findNodeUnderMouse(evt);
                                this._raiseMouseEvents(node);
                            }
                            if (!node && this.selectionList[0]) {
                                node = this.selectionList[0];
                            }
                            this._checkToolToActivate(evt, node, point);
                        }
                    }
                    if (evt.ctrlKey && evt.shiftKey) {
                        node = this._findNodeUnderMouse(evt);
                        if (!node && this.selectionList[0]) {
                            node = this.selectionList[0];
                        }
                        this._checkToolToActivate(evt, node, point);
                    }
                    if (this._toolToActivate === "panTool") {
                        this.activeTool = this.tools[this._toolToActivate];
                    }
                    else {
                        this.activateTool(this._toolToActivate);
                    }
                    this.activeTool.mousedown(evt);
                }
            }
        },

        _invoke: function (evt) {
            var className = evt.originalEvent.target.className;
            if (evt.originalEvent.target && (className == "edit" || className == "editBox" || className == "e-hhandle" || className == "e-hhandlespace" || className == "e-vhandle" || className == "e-vhandlespace")) {
                return false;
            }

            return true;
        },

        _handleMouseWheel: function (evt) {
            if (evt.originalEvent.preventDefault)
                evt.originalEvent.preventDefault();
            var position = new ej.datavisualization.Diagram.Point(0, 0);
            //this.deactivateTool();
            if (evt.ctrlKey) {
                position.x = (evt.originalEvent.layerX + this._hScrollOffset) / this._currZoom;
                position.y = (evt.originalEvent.layerY + this._vScrollOffset) / this._currZoom;
                if (evt.originalEvent.wheelDelta > 0 || -40 * evt.originalEvent.detail > 0) {
                    ej.datavisualization.Diagram.ZoomUtil.zoomPan(this, (1 + Number(this.zoomFactor())), 0, 0, position, true);
                }
                else {
                    ej.datavisualization.Diagram.ZoomUtil.zoomPan(this, (1 / (1 + Number(this.zoomFactor()))), 0, 0, position, true);
                }
            }
            else {
                var offsetY = 0;
                if (evt.originalEvent.wheelDelta > 0 || -40 * evt.originalEvent.detail > 0) {
                    var top = this._vScrollbar.model.minimum;
                    if ((this._vScrollOffset - this._scrollPixel) >= top || this._scrollLimit() === ej.datavisualization.Diagram.ScrollLimit.Infinity) {
                        this._updateScrollOffset(this._hScrollOffset, (this._vScrollOffset - this._scrollPixel));
                        offsetY = -this._scrollPixel;
                    }
                    else {
                        this._updateScrollOffset(this._hScrollOffset, top);
                        offsetY = 0;
                    }
                }
                else {

                    var cHeight = this._vScrollbar.model.maximum;
                    var viewPort = ej.datavisualization.Diagram.ScrollUtil._viewPort(this);
                    if ((cHeight) >= (this._vScrollOffset + this._scrollPixel) || this._scrollLimit() === ej.datavisualization.Diagram.ScrollLimit.Infinity) {
                        this._updateScrollOffset(this._hScrollOffset, (this._vScrollOffset + this._scrollPixel));
                        offsetY = this._scrollPixel;
                    }
                    else {
                        this._updateScrollOffset(this._hScrollOffset, cHeight);
                        offsetY = 0;
                    }

                }
                this._updateEditBox(0, offsetY);
            }
        },

        _mousemove: function (evt) {
            if (evt.type == "touchmove" && evt.originalEvent.touches.length > 1) {
                this._isPinching = true;
            }
            else {
                this._isPinching = false;
                var node = null;
                var point = this._mousePosition(evt);
                var isUserHandle = this._isUserHandle(evt);
                if ((this.activeTool.inAction === false) && (this._selectedSymbol)) {
                    var scale = this._currZoom;
                    var offset = $("#" + this.element[0].id).offset();
                    var coor = this._isTouchEvent(evt);
                    var pageX;
                    var pageY;
                    if (coor) {
                        pageX = coor.pageX;
                        pageY = coor.pageY;
                    }
                    else {
                        pageX = evt.pageX;
                        pageY = evt.pageY;
                    }
                    var x = pageX + this._hScrollOffset - offset.left;
                    var y = pageY + this._vScrollOffset - offset.top;

                    {
                        var paletteItem = $.extend(true, {}, this._selectedSymbol);
                        if (this._selectedSymbol) {
                            var paletteItem = $.extend(true, {}, this._selectedSymbol);
                            paletteItem.name += ej.datavisualization.Diagram.Util.randomId();
                            if (paletteItem.segments) {
                                ej.datavisualization.Diagram.Util._translateLine(paletteItem, x / scale, y / scale);
                                args = { element: paletteItem };
                                if (!args.cancel) {
                                    this.add(paletteItem);
                                }
                            }
                            else {
                                var palNameTable = this._palNameTable;
                                var args = { element: paletteItem };
                                if (!args.cancel) {
                                    var randomId = ej.datavisualization.Diagram.Util.randomId();
                                    this._cloneGroupNode(paletteItem, randomId);
                                    //paletteItem.name = randomId;
                                    if (paletteItem.type == "group") {
                                        var cBound = ej.datavisualization.Diagram.Util._getChildrenBounds(paletteItem, this);
                                        this._translate(paletteItem, (x / scale - cBound.x - cBound.height / 2), (y / scale - cBound.y - cBound.width / 2), this.nameTable);
                                    } else {
                                        paletteItem.offsetX = x / scale;
                                        paletteItem.offsetY = y / scale;
                                    }
                                    if (paletteItem.isLane) {
                                        var obj = ej.datavisualization.Diagram.SwimLaneHelper._createDiagramLane(paletteItem, this.nameTable);
                                        obj.isLane = paletteItem.isLane;
                                        obj.orientation = paletteItem.orientation;
                                        this.add(obj);
                                        ej.datavisualization.Diagram.SvgContext._hideNode(obj, this._svg);

                                    }
                                    else
                                        this.add(paletteItem);

                                }
                            }
                            // this.scrollToNode(paletteItem);
                            this.element[0].focus();
                            this._toolToActivate = "move";
                            this.activateTool("move");
                            var displays = document.getElementsByClassName("dragClone")[0];
                            if (displays) {
                                displays.style.display = "none";
                            }
                            this.activateTool("move", true);
                            this.activeTool.mousedown(evt);
                            this.activeTool.mousemove(evt);

                        }
                    }
                }
                else {
                    if ((this._isInternalTool(this.activeTool) && !this.activeTool.inAction)) {
                        if (!isUserHandle) {
                            var node = this._findNodeUnderMouse(evt);
                            if (node) {
                                if (this._nodeToHit && this._nodeToHit != node && !this._nodeToHit.segments) {
                                    this.activeTool._showPort(this._nodeToHit, true);
                                }
                                if (!node.segments) {
                                    this.activeTool._showPort(node);
                                }
                            }
                            this._raiseMouseEvents(node);
                        }
                        if (!node && this.selectionList[0]) {
                            node = this.selectionList[0];
                        }
                        if (ej.datavisualization.Diagram.Util.isPageEditable(this)) {
                            this._checkToolToActivate(evt, node, point);
                        }
                    } else {
                        if (!this.activeTool.inAction) {
                            this._toolToActivate = this.activeTool.name;
                            this._currentCursor = this.activeTool.cursor;
                        }

                        node = this._findNodeUnderMouse(evt);
                        if (node) {
                            this._raiseMouseEvents(node);
                        }

                    }
                    this._updateCursor();
                    this.activeTool.mousemove(evt);
                    if (this.activeTool.inAction && this.enableAutoScroll()) {
                        var viewPort = ej.datavisualization.Diagram.ScrollUtil._viewPort(this);
                        var pt = this._mousePosition(evt, true);
                        var autoScrollBorder = this.model.pageSettings.autoScrollBorder;
                        if (pt.x + autoScrollBorder.right >= viewPort.width - 18) {
                            this._beginAutoScroll("right", evt);
                            this._canAutoScroll = true;
                        }
                        else if (pt.x <= autoScrollBorder.left) {
                            this._beginAutoScroll("left", evt);
                            this._canAutoScroll = true;
                        }
                        else if (pt.y + autoScrollBorder.bottom >= viewPort.height - 18) {
                            this._beginAutoScroll("bottom", evt);
                            this._canAutoScroll = true;
                        }
                        else if (pt.y <= autoScrollBorder.top) {
                            this._beginAutoScroll("top", evt);
                            this._canAutoScroll = true;
                        }
                        else {
                            this._canAutoScroll = false;
                        }
                    }
                }
            }
        },

        _cloneGroupNode: function (node, id, nameTable) {
            var child = null, clnObj;
            var children = node.children = this._getChildren(node.children);
            if (node.type == "group") {
                for (var i = 0; i < children.length; i++) {
                    if (nameTable)
                        child = nameTable[children[i]];
                    else {
                        if (this._paletteTable)
                            child = this._paletteTable[children[i]];
                    }
                    if (child) {
                        child = $.extend(true, {}, child);
                        if (child.type == "group")
                            this._cloneGroupNode(child, id);
                        clnObj = $.extend(true, {}, child);
                        clnObj.name += id;
                        children[i] = clnObj.name;
                        this.nameTable[clnObj.name] = clnObj;
                    }
                }
            }
        },
        _setActiveTool: function (evt) {
            var point = this._mousePosition(evt);
            if (!this.activeTool.inAction && (this._isUserHandleActive(this.activeTool.name) || !this.model.selectedItems.userHandles || !this.model.selectedItems.userHandles.length)) {
                if (this._isInternalTool(this.activeTool) || this.activeTool.singleAction) {
                    var node;
                    var success = false;
                    //var handle = this._isHandle(evt);
                    if (this.selectionList[0]) {
                        node = this.selectionList[0];
                        success = this._checkToolToActivate(evt, node, point);
                    }
                    if (!success) {
                        node = this._findNodeUnderMouse(evt);
                        if (this._isUserHandle(evt)) {
                            var handleName = $(evt.target).parents("g").first().context.id.split("_")[0];
                            this._checkToolToActivate(evt, node, point, handleName);
                            this.activeTool = this.tools[this._toolToActivate];
                        }
                        else {
                            this._checkToolToActivate(evt, node, point);
                            this._raiseMouseEvents(node);
                            if (this._isUserHandleActive(this.activateTool.name) && !this._drawingTool)
                                this.activeTool = this.tools[this._toolToActivate];
                        }
                    }
                }
            }
        },

        _beginAutoScroll: function (option, evt) {
            var delay = 100;
            var callBack = this;
            var left = 0, top = 0;
            var viewPort = ej.datavisualization.Diagram.ScrollUtil._viewPort(this);
            var cWidth = this._hScrollbar.model.maximum + viewPort.width;
            var cHeight = this._vScrollbar.model.maximum + viewPort.height;
            if (this._canAutoScroll) {
                switch (option) {
                    case "right":
                        if ((this._hScrollOffset + viewPort.width + 10) < cWidth || this._scrollLimit() === ej.datavisualization.Diagram.ScrollLimit.Infinity) {
                            left = 10;
                        }
                        break;
                    case "left":
                        if (this._hScrollOffset - 10 > this._hScrollbar.model.minimum || this._scrollLimit() === ej.datavisualization.Diagram.ScrollLimit.Infinity) {
                            left = -10;
                        }
                        break;
                    case "bottom":
                        if (this._vScrollOffset + viewPort.height + 10 < cHeight || this._scrollLimit() === ej.datavisualization.Diagram.ScrollLimit.Infinity) {
                            top = 10;
                        }
                        break;
                    case "top":
                        if (this._vScrollOffset - 10 > this._vScrollbar.model.minimum || this._scrollLimit() === ej.datavisualization.Diagram.ScrollLimit.Infinity) {
                            top = -10;
                        }
                        break;
                }
                setTimeout(function () {
                    callBack._raiseEvent("autoScrollChange", { delay: delay })
                    callBack._updateScrollBar(left, top, option, evt);
                }, delay);
            }
        },

        _updateScrollBar: function (x, y, option, evt) {
            if (x === 0 && y === 0) {
                this._canAutoScroll = false;
            }
            else if (this.activeTool.inAction) {
                var hScrollOffset = this._hScrollOffset + (x * this._currZoom);
                var vScrollOffset = this._vScrollOffset + (y * this._currZoom);
                this._updateSelectionOnScroll(x, y);
                this._updateScrollOffset(hScrollOffset, vScrollOffset);
                this._beginAutoScroll(option, evt);
            }
        },

        _updateSelectionOnScroll: function (x, y) {
            var tool = this.activeTool;
            if (tool.name === "select") {
                tool.currentPoint = new ej.datavisualization.Diagram.Point(tool.currentPoint.x + x, tool.currentPoint.y + y);
                tool._updateHelper();
            }
            else if (tool.name === "orthogonalLine" || tool.name === "straightLine") {
                tool.currentPoint = new ej.datavisualization.Diagram.Point(tool.currentPoint.x + x, tool.currentPoint.y + y);
                tool._targetPossibleConnection = tool._currentPossibleConnection;
                tool._targetPort = tool._possibleConnectionPort;
                tool._updateHelper();
            }
            else if (this.selectionList.length > 0) {
                var node = this.selectionList[0];
                tool.currentPoint = ej.datavisualization.Diagram.Point(tool.currentPoint.x + x, tool.currentPoint.y + y);
                if (tool.name === "move") {
                    if (tool.activeLabel)
                        this._translateLabel(node, tool.activeLabel, x, y);
                    else
                        this._translate(node, x, y, this.nameTable);
                }
                else if (tool.name === "resize") {
                    ej.datavisualization.Diagram.SnapUtil._removeGuidelines(this);
                    tool._updateSize(node, tool.previousPoint, tool.currentPoint);
                }
                else if (tool.name === "endPoint") {
                    if (tool.selectedSegment && tool._endPoint == "segmentEnd") {
                        var difx = tool.currentPoint.x - tool.previousPoint.x;
                        var dify = tool.currentPoint.y - tool.previousPoint.y;
                        tool._updateAdjacentSegments(difx, dify);

                    }
                    else {
                        var updateSelection = tool._updatePoints(node);
                        tool._disconnect(node);
                        tool._updateConnection(node, updateSelection);
                    }
                }
                tool.previousPoint = ej.datavisualization.Diagram.Point(tool.currentPoint.x, tool.currentPoint.y);
                if (!tool.activeLabel) {
                    ej.datavisualization.Diagram.DiagramContext.update(node, this);
                    this._updateSelectionHandle();
                    this._renderTooltip(node);
                }
            }
        },

        _isUserHandle: function (evt) {
            if (evt.target.parentNode.className.animVal === "userHandle") {
                return true;
            }
            else {
                return false;
            }
        },

        _isUserHandleActive: function (name) {
            var userHandleActive = false;
            if (this.model.selectedItems.userHandles && this.model.selectedItems.userHandles.length > 0) {
                var i = 0;
                var length = this.model.selectedItems.userHandles.length;
                for (i; i < length; i++) {
                    if (this.model.selectedItems.userHandles[i].name === name) {
                        userHandleActive = true;
                        break;
                    }
                    else
                        userHandleActive = true;
                }
            }
            return userHandleActive;
        },

        _raiseMouseEvents: function (node) {
            if (!node && this._nodeToHit) {
                this._raiseEvent("mouseLeave", { element: this._nodeToHit });

                if (this._nodeToHit != null && (this._nodeToHit.shape) && !(this.activeTool instanceof ej.datavisualization.Diagram.LineTool)) {
                    this.activeTool._showPort(this._nodeToHit, true);

                }
            }
            if (node) {
                if (this._nodeToHit !== node) {
                    this._nodeToHit = node;
                    this._raiseEvent("mouseEnter", { element: node });
                }
            }
            else {
                this._nodeToHit = null;
            }
            if (node) {
                this._raiseEvent("mouseOver", { element: node });
            }
        },

        _isHandle: function (evt) {
            var handle = $(evt.target).parent("g.handle");
            if (handle.length > 0) {
                return true;
            }
            return false;
        },

        _findNodeUnderMouse: function (evt) {
            var node = null;
            var type;
            var parent = $(evt.target).parents(".ej-d-node,.ej-d-connector,.ej-d-group");
            if (parent) {
                type = parent.attr("class");
                if (type === "ej-d-node" || type === "ej-d-group") {
                    node = this._findNode(parent.attr("id"));
                }
                else if (type === "ej-d-connector") {
                    node = this._findConnector(parent.attr("id"));
                }
            }
            return node;
        },

        _isForeignObject: function (target) {
            var foreignObj = target.parentNode;
            if (foreignObj) {
                while (foreignObj.parentNode != null) {
                    if (foreignObj.className === "foreignObject") {
                        return foreignObj;
                    }
                    else {
                        foreignObj = foreignObj.parentNode;
                    }
                }
            }
            return null;
        },

        _mouseup: function (evt) {
            if (!this._isPinching) {
                if (this._invoke(evt)) {
                    var foreignObject = this._isForeignObject(evt.originalEvent.target);
                    if (!foreignObject)
                        evt.preventDefault();
                    if (evt.target.id === this._id + "_canvas_svg")
                        this._raiseEvent("click", { element: this });
                    this.activeTool.mouseup(evt);
                    if (this.activeTool instanceof ej.datavisualization.Diagram.PanTool) {
                        document.onmousemove = null;
                        document.onmouseup = null;
                    }

                    if (this._selectedSymbol) {
                        var args;
                        args = { element: this.selectionList[0], cancel: false };

                        if (args.cancel === true) {
                            this._remove(args.element);
                        }
                        var node = this.selectionList[0];
                        if (node) {
                            this.scrollToNode(node);
                            if ((node.labels.length > 0 && node.labels[0].mode === "edit") && !node.labels[0].readOnly) {
                                this._isEditing = true;
                                this.startLabelEdit(node, node.labels[0]);
                            }

                            else {
                                this.element[0].focus();
                            }

                            this._raiseDropEvent(args);
                            this._raiseEvent("selectionChange", args);

                        }
                        var childTable = {};
                        if (this.selectionList && this.selectionList.length > 0)
                            childTable = this._getChildTable(this.selectionList[0], childTable);
                        var entry = { type: "collectionchanged", object: jQuery.extend(true, {}, node), childTable: jQuery.extend(true, {}, childTable), changeType: "insert" };
                        this.addHistoryEntry(entry);
                        this._selectedSymbol = null;
                    }
                    if ((!(this.activeTool instanceof ej.datavisualization.Diagram.PolygonTool) && !(this.activeTool instanceof ej.datavisualization.Diagram.TextTool)) && document.activeElement && document.activeElement.id !== this.element[0].id)
                        if (!this._isEditing && !foreignObject)
                            this.element[0].focus();
                    this._currentCursor = this.activeTool.cursor;
                    this._updateCursor();
                }
            }
        },

        _doubleclick: function (evt) {
            if (this.activeTool.name != "panTool") {
                var args;
                args = { element: this._nodeToHit, cancel: false, actualObject: this.activeTool.actualObject }
                if (!this._isEditing)
                    this._raiseEvent("doubleClick", args);
                if (this._nodeToHit)
                    this.activeTool._doubleClick(this._nodeToHit);
                if (!this.activeTool.inAction && ((this.selectionList.length > 0) || this.activeTool.selectedObject) && !args.cancel) {

                    if (this.activeTool.selectedObject)
                        var obj = this.activeTool.selectedObject;
                    else
                        var obj = this.selectionList[0];
                    if (!this._isEditing && !(obj.type == "pseudoGroup") && !args.cancel) {
                        if (!this._isEditing && obj.shape && obj.shape.type === "text" && this._setLabelEditing(obj.shape.textBlock)) {
                            this.scrollToNode(obj);
                            this._startEdit(obj);
                        }
                        else if (!this._isEditing && ((obj.labels.length === 0 || typeof obj.labels.length === "undefined") || (obj.labels.length > 0 && this._setLabelEditing(obj.labels[0])))) {
                            this.scrollToNode(obj);
                            this._startEdit(obj);
                        }
                    }
                }
                else if (this.activeTool instanceof ej.datavisualization.Diagram.PolygonTool) {
                    this.activeTool.doubleclick(evt);
                }
            }
        },

        _keydown: function (evt) {
            var keycode = evt.keyCode ? evt.keyCode : evt.which;
            if (keycode === 113) {
                if (this.selectionList.length > 0) {
                    var shape = this.selectionList[0];
                    if (!(shape.type == "pseudoGroup")) {
                        if (shape.shape.type === "text" && this._setLabelEditing(shape.shape.textBlock))
                            this._startEdit(shape);
                        else if (shape.labels.length > 0 && this._setLabelEditing(shape.labels[0]))
                            this._startEdit(shape);
                    }
                }
            }
            else if (this._isEditing && keycode === 27) {
                this._endEdit();
            }
            else if (!this._isEditing && keycode === 46) {
                this._delete();
            }
            else if (!this._isEditing && evt.ctrlKey && keycode === 88) {
                this.cut();
            }
            else if (!this._isEditing && evt.ctrlKey && keycode === 67) {
                this.copy();
            }
            else if (!this._isEditing && evt.ctrlKey && keycode === 86) {
                this.paste();
            }
            else if (evt.ctrlKey && keycode === 65) {
                if (this._isEditing)
                    this._endEdit();
                evt.preventDefault();
                this.selectAll();
            }
            else if (!this._isEditing && evt.ctrlKey && keycode === 89) {
                this.redo();
            }
            else if (!this._isEditing && evt.ctrlKey && keycode === 90) {
                this.undo();
            }
            if (!this._isEditing && (keycode === 37 || keycode === 38 || keycode === 39 || keycode === 40)) {
                evt.preventDefault();
                if (keycode === 37) { //left
                    !evt.shiftKey ? this.nudge("left") : this.nudge("left", 5);
                } else if (keycode === 38) { //up
                    !evt.shiftKey ? this.nudge("up") : this.nudge("up", 5);
                } else if (keycode === 39) { //right
                    !evt.shiftKey ? this.nudge("right") : this.nudge("right", 5);
                } else if (keycode === 40) { //down
                    !evt.shiftKey ? this.nudge("down") : this.nudge("down", 5);
                }
            }
            this.activeTool.keydown(evt);
        },

        _keyup: function (evt) {
            var keycode = evt.keyCode ? evt.keyCode : evt.which;
            if (!this._isEditing && (keycode === 37 || keycode === 38 || keycode === 39 || keycode === 40)) {
                evt.preventDefault();
                this.activeTool.inAction = false;
                this._updateSelectionHandle();
            }
        },

        _registerHistoryEvents: function () {
            this.historyManager.addEventHandler("collectionchanged", $.proxy(this._recordCollectionChanged, this));
            this.historyManager.addEventHandler("positionchanged", $.proxy(this._recordPinPointChanged, this));
            this.historyManager.addEventHandler("sizechanged", $.proxy(this._recordResizeChanged, this));
            this.historyManager.addEventHandler("rotationchanged", $.proxy(this._recordRotationChanged, this));
            this.historyManager.addEventHandler("endpointchanged", $.proxy(this._recordEndPointChanged, this));
            this.historyManager.addEventHandler("labelchanged", $.proxy(this._recordLabelChanged, this));
            this.historyManager.addEventHandler("groupingchanged", $.proxy(this._recordGroupChanged, this));
        },

        _updatePoints: function (helper, startPoint, endPoint, isTarget) {
            var offset = new ej.datavisualization.Diagram.Point(endPoint.x - startPoint.x, endPoint.y - startPoint.y);
            if (!ej.datavisualization.Diagram.Geometry.isEmptyPoint(offset)) {
                helper._updateEndPoint(offset.x, offset.y, isTarget);
            }
        },

        _recordCollectionChanged: function (args) {
            this._clearSelection();
            this._isUndo = true;
            var i;
            var changeType = args.changeType;
            if (args.isUndo) {
                if (args.changeType == "insert")
                    changeType = "remove";
                else
                    changeType = "insert";
            }
            if (changeType == "insert") {
                if (!args.object.container) {
                    if (args.object.type != "pseudoGroup") {
                        if (!args.object.segments) {
                            var port = null;
                            if (args.object.inEdges.length > 0) {
                                for (i = 0; i < args.object.inEdges.length; i++) {
                                    if (this.nameTable[args.object.inEdges[i]])
                                        this.nameTable[args.object.inEdges[i]].targetNode = args.object.name;
                                    port = args.targetPorts[args.object.inEdges[i]];
                                    if (port)
                                        if (this.nameTable[args.object.inEdges[i]])
                                            this.nameTable[args.object.inEdges[i]].targetPort = port;
                                }
                            }
                            if (args.object.outEdges.length > 0) {
                                for (i = 0; i < args.object.outEdges.length; i++) {
                                    if (this.nameTable[args.object.outEdges[i]])
                                        this.nameTable[args.object.outEdges[i]].sourceNode = args.object.name;
                                    port = args.sourcePorts[args.object.outEdges[i]];
                                    if (port)
                                        if (this.nameTable[args.object.outEdges[i]])
                                            this.nameTable[args.object.outEdges[i]].sourcePort = port;
                                }
                            }
                        }
                        if (args.object.type == "group")
                            this._addChildren(args.object, args.childTable);
                        this.add(args.object, args);
                        if (args.object.type == "group") {
                            this._addConnector(args.object, args);
                            this._addGroupConnector(args.object, args)
                        }
                        else {
                            this._addConnector(args.object, args);
                        }
                        this._clearSelection();
                        this.addSelection(this.nameTable[args.object.name]);
                    } else {
                        delete this.nameTable["multipleSelection"];
                        var node, j;
                        var pseudoGroup = ej.datavisualization.Diagram.Group({ "name": "multipleSelection", type: "pseudoGroup" });
                        for (i = 0; i < args.object.children.length; i++) {
                            pseudoGroup.children.push(args.object.children[i]);
                            node = args.childTable[args.object.children[i]];
                            node.parent = "";
                            if (node.type == "group")
                                this._addChildren(node, args.childTable);
                            this.add(args.childTable[args.object.children[i]], args);
                        }
                        this._addGroupConnector(args.object, args);
                        for (i = 0; i < pseudoGroup.children.length; i++) {
                            node = this.nameTable[pseudoGroup.children[i]];
                            if (!node.segments) {
                                if (node.inEdges.length > 0) {
                                    for (j = 0; j < node.inEdges.length; j++)
                                        this.nameTable[node.inEdges[j]].targetNode = node.name;
                                }
                                if (node.outEdges.length > 0) {
                                    for (j = 0; j < node.outEdges.length; j++)
                                        this.nameTable[node.outEdges[j]].sourceNode = node.name;
                                }
                            }
                        }
                        this._clearSelection();
                        this.nodes().push(pseudoGroup);
                        pseudoGroup.offsetX = args.object.offsetX;
                        pseudoGroup.offsetY = args.object.offsetY;
                        pseudoGroup.height = args.object.height;
                        pseudoGroup.width = args.object.width;
                        pseudoGroup.rotateAngle = args.object.rotateAngle;
                        this.addSelection(pseudoGroup);
                        this.nameTable[pseudoGroup.name] = pseudoGroup;
                    }
                } else {
                    if (!args.object.container) {
                        var child;
                        for (var i in args.childTable) {
                            child = args.childTable[i];
                            this.nameTable[i] = child;
                        }
                        node = args.object;
                        if (node.isSwimlane) {
                            node.width = 0;
                            node.height = 0;
                            this.add(node);
                        } else if (node.isLane) {
                            var swimlane = ej.datavisualization.Diagram.SwimLaneHelper._createSwimlane(node, this);
                            if (swimlane) {
                                swimlane.width = 0;
                                swimlane.height = 0;
                                this.add(swimlane);
                            }
                        }
                    }
                }

            }
            else if (changeType == "remove") {
                if (args.object.type != "pseudoGroup") {
                    this._remove(args.object);
                }
                else {
                    for (i = 0; i < args.object.children.length; i++) {
                        this._remove(this.nameTable[args.object.children[i]]);
                    }
                }
            }
            this._isUndo = false;
        },

        _addGroupConnector: function (group, arg) {
            var edges;
            var connector;
            var k, j, len, l;
            if (!group.segments) {
                var children = this._getChildren(group.children);
                for (k = 0; k < children.length; k++) {
                    var child = this.nameTable[children[k]];
                    if (child.inEdges && child.inEdges.length > 0) {
                        edges = child.inEdges;
                        for (j = 0, len = edges.length; j < len; j++) {
                            if (arg.edgeTable)
                                connector = arg.edgeTable[edges[j]];
                            else
                                connector = arg.childTable[edges[j]];
                            if (connector)
                                this.add(connector);
                        }
                    }
                    if (child.outEdges && child.outEdges.length > 0) {
                        edges = child.outEdges;
                        for (j = 0, len = edges.length; j < len; j++) {
                            if (arg.edgeTable)
                                connector = arg.edgeTable[edges[j]];
                            else
                                connector = arg.childTable[edges[j]];
                            if (connector)
                                this.add(connector);
                        }
                    }
                }
            }
        },

        _addConnector: function (node, arg) {
            var edges;
            var connector;
            var k, j, len, l;
            if (!node.segments) {
                if (node.inEdges && node.inEdges.length > 0) {
                    edges = node.inEdges;
                    for (j = 0, len = edges.length; j < len; j++) {
                        connector = arg.edgeTable[edges[j]];
                        this.add(connector);
                    }
                }
                if (node.outEdges && node.outEdges.length > 0) {
                    edges = node.outEdges;
                    for (j = 0, len = edges.length; j < len; j++) {
                        connector = arg.edgeTable[edges[j]];
                        this.add(connector);
                    }
                }
            }
        },

        _addChildren: function (group, childTable) {
            var children = this._getChildren(group.children);
            for (var i = 0; i < children.length; i++) {
                var node = childTable[children[i]];
                if (node.type == "group")
                    this._addChildren(node, childTable);
                else
                    this.nameTable[children[i]] = node;
            }
        },

        _updateRecordPinPoint: function (node, childTable, isMultipleSelection) {
            var object, i, item, objNode;
            // this._clearSelection();
            if (node.type == "pseudoGroup") {
                var undoObj = node;
                var children = this._getChildren(node.children);
                for (i = 0; i < children.length; i++) {
                    item = this.nameTable[children[i]];
                    objNode = childTable[children[i]];
                    if (objNode) {
                        if (!item.segments) {
                            this._translate(item, objNode.offsetX - item.offsetX, objNode.offsetY - item.offsetY, this.nameTable);
                        } else {
                            var objLine = childTable[item.name];
                            item.sourcePoint = objLine.sourcePoint;
                            item.targetPoint = objLine.targetPoint;
                            item.segments = objLine.segments;
                        }
                        ej.datavisualization.Diagram.DiagramContext.update(item, this);
                    }
                }
                if (this.selectionList[0]) {
                    if (this.selectionList[0].name === undoObj.name) {
                        this.selectionList[0].offsetX = undoObj.offsetX;
                        this.selectionList[0].offsetY = undoObj.offsetY;
                    }
                }
                ej.datavisualization.Diagram.SvgContext.updateSelector(undoObj, this._svg, this._currZoom, this, this.model.selectedItems.constraints);
            } else {
                if (node.segments) {
                    if (isMultipleSelection) {
                        object = childTable[node.name];
                        node.sourcePoint = object.sourcePoint;
                        node.targetPoint = object.targetPoint;
                        node.segments = object.segments;
                        ej.datavisualization.Diagram.DiagramContext.update(node, this);
                    } else {
                        this._clearSelection();
                        object = this._findConnector(node.name);
                        var obj;

                        if (node.targetNode) {
                            obj = this.nameTable[node.targetNode];
                            ej.datavisualization.Diagram.Util.removeItem(obj.inEdges, node);
                        }
                        if (node.sourceNode) {
                            obj = this.nameTable[node.sourceNode];
                            ej.datavisualization.Diagram.Util.removeItem(obj.outEdges, node);
                        }
                        if (node.targetNode) {
                            obj = this.nameTable[node.targetNode];
                            obj.inEdges.push(node.name);
                        }
                        if (node.sourceNode) {
                            obj = this.nameTable[node.sourceNode];
                            obj.outEdges.push(node.name);
                        }
                        object.targetNode = node.targetNode;
                        object.sourceNode = node.sourceNode;
                        object.targetPort = node.targetPort;
                        object.sourcePort = node.sourcePort;

                        object.sourcePoint = node.sourcePoint;
                        object.targetPoint = node.targetPoint;
                        object.segments = node.segments;
                        this._updateLabels(object, node.labels);
                        ej.datavisualization.Diagram.DiagramContext.update(object, this);
                        ej.datavisualization.Diagram.SvgContext.updateSelector(node, this._svg, this._currZoom, this, this.model.selectedItems.constraints);
                        this.addSelection(node);
                    }
                } else {
                    if (isMultipleSelection) {
                        object = childTable[node.name];
                        this._translate(node, object.offsetX - node.offsetX, object.offsetY - node.offsetY, childTable);
                        ej.datavisualization.Diagram.DiagramContext.update(object, this);
                    } else {
                        this._clearSelection();
                        object = this._findNode(node.name);
                        this._translate(object, node.offsetX - object.offsetX, node.offsetY - object.offsetY, this.nameTable);
                        this._updateLabels(object, node.labels);
                        if (node.parent) {
                            ej.datavisualization.Diagram.Util._updateGroupBounds(this.nameTable[object.parent], this);
                        }
                        if (object.parent) {
                            var parent = this.nameTable[object.parent];
                            if (parent && parent.container) {
                                if (parent.container.type == "canvas") {
                                    ej.datavisualization.Diagram.SvgContext._alignOnCanvas1(parent, this);
                                }
                                else if (parent.container.type == "stack") {

                                    ej.datavisualization.Diagram.SvgContext._alignOnStack(parent, this);
                                }

                            }
                        }
                        ej.datavisualization.Diagram.DiagramContext.update(object, this);
                        this.addSelection(object);
                    }
                }
            }
        },
        _updateLabels: function (node, labels) {
            node.labels = labels;
            for (var i = 0; i < node.labels.length; i++)
                ej.datavisualization.Diagram.DiagramContext.updateLabel(node, node.labels[i], this);
        },
        _recordPinPointChanged: function (args) {
            var node = args.object.node;
            var childTable = args.object.childTable;
            if (!node.container)
                this._updateRecordPinPoint(node, childTable);
        },
        _updateRecordRotation: function (object, childTable) {
            var node, i, item, objNodeChild;
            if (object.type == "pseudoGroup") {
                node = this.nameTable[object.name];
                var children = object.children;
                for (i = 0; i < children.length; i++) {
                    item = this.nameTable[children[i]];
                    objNodeChild = childTable[children[i]];
                    if (item) {
                        if (!item.segments) {
                            if (objNodeChild) {
                                this._translate(item, objNodeChild.offsetX - item.offsetX, objNodeChild.offsetY - item.offsetY, this.nameTable);
                                this._rotate(item, objNodeChild.rotateAngle - item.rotateAngle, this.nameTable);
                            }
                        } else {
                            var objLine = childTable[item.name];
                            item.sourcePoint = objLine.sourcePoint;
                            item.targetPoint = objLine.targetPoint;
                            item.segments = objLine.segments;
                        }
                        ej.datavisualization.Diagram.DiagramContext.update(item, this);
                    }
                }
                if (node) {
                    var newangle = object.rotateAngle - node.rotateAngle;
                    node.rotateAngle += newangle;
                    if (this.selectionList[0])
                        this.selectionList[0].rotateAngle = node.rotateAngle;
                }
                ej.datavisualization.Diagram.SvgContext.updateSelector(object, this._svg, this._currZoom, this, this.model.selectedItems.constraints);
            }
            else {
                var parent = null;
                if (object.parent) {
                    parent = this.nameTable[object.parent];
                }
                if (parent && parent.container) {
                    if (parent.container.type == "canvas") {
                        ej.datavisualization.Diagram.SvgContext._alignOnCanvas1(parent, this);
                    }
                    else if (parent.container.type == "stack") {

                        ej.datavisualization.Diagram.SvgContext._alignOnStack(parent, this);
                    }

                }
                else if (object) {
                    this._clearSelection();
                    node = this._findNode(object.name);
                    this._rotate(node, object.rotateAngle - node.rotateAngle, this.nameTable);
                    ej.datavisualization.Diagram.DiagramContext.update(node, this);
                    this.addSelection(node);
                }
            }
        },
        _recordSizeChanged: function (args) {
            var node = args.object.node;
            var childTable = args.object.childTable;
            if (!node.container)
                this._updateRecordSize(node, childTable);
        },
        _updateRecordSize: function (object, childTable) {
            var node, i, childObj;
            if (object.type == "group" || object.type == "pseudoGroup") {
                if (object.type == "pseudoGroup")
                    this.nameTable[object.name] = object;
                node = this._findNode(object.name);
                var nodeChildren = this._getChildren(node.children);
                var objChildren = this._getChildren(object.children);
                for (i = 0; i < nodeChildren.length; i++) {
                    var item = this.nameTable[objChildren[i]];
                    childObj = childTable[objChildren[i]];
                    if (childObj) {
                        if (!item.segments) {
                            this._translate(item, childObj.offsetX - item.offsetX, childObj.offsetY - item.offsetY, this.nameTable);
                            this.scale(item, (childObj.width / item.width), (childObj.height / item.height), ej.datavisualization.Diagram.Point(item.offsetX, item.offsetY), this.nameTable);
                            ej.datavisualization.Diagram.DiagramContext.update(item, this);
                        } else {
                            var kk = childTable[item.name];
                            item.sourcePoint = kk.sourcePoint;
                            item.targetPoint = kk.targetPoint;
                            item.segments = kk.segments;
                            ej.datavisualization.Diagram.DiagramContext.update(item, this);
                        }
                    }
                }
                //if (node.name === object.name) {
                node.offsetX = object.offsetX;
                node.offsetY = object.offsetY;
                node.width = object.width;
                node.height = object.height;
                //}
                ej.datavisualization.Diagram.SvgContext.updateSelector(node, this._svg, this._currZoom, this, this.model.selectedItems.constraints);
            }
            else {
                var parent = null;
                if (object.parent) {
                    parent = this.nameTable[object.parent];
                }
                if (parent && parent.container) {
                    if (parent.container.type == "canvas") {
                        ej.datavisualization.Diagram.SvgContext._alignOnCanvas1(parent, this);
                    }
                    else if (parent.container.type == "stack") {

                        ej.datavisualization.Diagram.SvgContext._alignOnStack(parent, this);
                    }

                }
                else if (!object.segments) {
                    node = this._findNode(object.name);
                    this._translate(node, object.offsetX - node.offsetX, object.offsetY - node.offsetY, this.nameTable);
                    this.scale(node, object.width / node.width, object.height / node.height, ej.datavisualization.Diagram.Point(node.offsetX, node.offsetY), this.nameTable);
                    ej.datavisualization.Diagram.DiagramContext.update(node, this);
                    ej.datavisualization.Diagram.SvgContext.updateSelector(node, this._svg, this._currZoom, this, this.model.selectedItems.constraints);
                }
                else {

                }
            }

        },
        _recordRotationChanged: function (args) {
            var node = args.object.node;
            var childTable = args.object.childTable;
            if (!node.container)
                this._updateRecordRotation(node, childTable);
        },
        _recordEndPointChanged: function (args) {

            var connector, currentObject, previousObject, obj;
            if (args._isUndo) {
                connector = currentObject = args.undoObject;
                previousObject = args.redoObject;
            }
            else {
                connector = currentObject = args.redoObject;
                previousObject = args.undoObject;
            }
            if (connector.parent) {

                connector = this._findChildren(connector.parent, connector.name);
            }
            else
                connector = this._findConnector(connector.name);

            if (previousObject.targetNode) {
                obj = this.nameTable[previousObject.targetNode];
                ej.datavisualization.Diagram.Util.removeItem(obj.inEdges, previousObject);
            }
            if (previousObject.sourceNode) {
                obj = this.nameTable[previousObject.sourceNode];
                ej.datavisualization.Diagram.Util.removeItem(obj.outEdges, previousObject);
            }
            if (currentObject.targetNode) {
                obj = this.nameTable[currentObject.targetNode];
                obj.inEdges.push(currentObject.name);
            }
            if (currentObject.sourceNode) {
                obj = this.nameTable[currentObject.sourceNode];
                obj.outEdges.push(currentObject.name);
            }
            connector.targetNode = currentObject.targetNode;
            connector.sourceNode = currentObject.sourceNode;
            connector.targetPort = currentObject.targetPort;
            connector.sourcePort = currentObject.sourcePort;
            connector.sourcePoint = currentObject.sourcePoint;
            connector.targetPoint = currentObject.targetPoint;
            connector.segments = currentObject.segments;
            this._updateEdges(connector);
            this._dock(connector, this.nameTable);
            ej.datavisualization.Diagram.Util._updateConnectorSegments(connector, connector.sourcePort, connector.targetPort, this);
            ej.datavisualization.Diagram.DiagramContext._refreshSegments(connector, this);
            ej.datavisualization.Diagram.Util.updateBridging(connector, this);
            ej.datavisualization.Diagram.DiagramContext.update(connector, this);
            this._updateConnectorBridging(connector);
            this._updateSelectionHandle();
            if (this.selectionList[0])
                ej.datavisualization.Diagram.SvgContext._refreshEndPointHandles(this.selectionList[0], this._svg, this.model.zoomFactor);
            ej.datavisualization.Diagram.SvgContext.updateSelector(connector, this._svg, this._currZoom, this, this.model.selectedItems.constraints);
        },

        _recordLabelChanged: function (args) {
            var node = this.nameTable[args.object.name];
            if (args.object.shape && args.object.shape.type === "text") {
                node.shape.textBlock.text = args.label;
                ej.datavisualization.Diagram.DiagramContext.updateTextBlock(node, node.shape.textBlock, this);
            } else {
                node.labels[0].text = args.label;
                ej.datavisualization.Diagram.DiagramContext.updateLabel(node, node.labels[0], this);
            }
        },

        _recordGroupChanged: function (args) {
            this._clearSelection();
            var actionType = args.actionType;
            if (args.isUndo) {
                if (args.actionType === "group")
                    actionType = "ungroup";
                if (args.actionType === "ungroup")
                    actionType = "group";
            }
            var selectionList = this._getChildren(args.object.children);
            if (actionType === "group") {
                var group = new ej.datavisualization.Diagram.Group({ name: args.object.name });
                for (i = 0; i < selectionList.length; i++) {
                    group.children.push(selectionList[i]);
                    this.nameTable[selectionList[i]].parent = group.name;
                    var groupElement = this._svg.document.getElementById(selectionList[i]);
                    if (groupElement)
                        groupElement.parentNode.removeChild(groupElement);
                }
                //group.name = args.object.name;
                this.add(group);
                this._addSelection(group);
            }
            else {
                var i, node;
                node = args.object;
                var groupElement = this._svg.document.getElementById(node.name);
                if (groupElement)
                    groupElement.parentNode.removeChild(groupElement);
                var nodeChildren = this._getChildren(node.children);
                for (i = 0; i < nodeChildren.length; i++) {
                    var childNode = this.nameTable[nodeChildren[i]];
                    childNode.parent = "";
                    this._isUndo = true;
                    if (childNode.segments) {
                        ej.datavisualization.Diagram.DiagramContext.renderConnector(childNode, this);
                    }
                    else if (childNode.type != "group") {
                        ej.datavisualization.Diagram.DiagramContext.renderNode(childNode, this);
                    }
                    else {
                        ej.datavisualization.Diagram.DiagramContext.renderGroup(childNode, this);
                    }
                    this._isUndo = false;
                }
                ej.datavisualization.Diagram.Util.removeItem(this.nodes(), this._findNode(node.name));
            }
        },

        _svgdrop: function (evt, ui) {
            var args = {};
            var e = evt.originalEvent;
            if (e.preventDefault)
                e.preventDefault();
            else
                e.returnValue = false;
            var scale = this._currZoom;
            var offset = $("#" + this.element[0].id).offset();
            var coor = this._isTouchEvent(evt);
            var pageX;
            var pageY;
            if (coor) {
                pageX = coor.pageX;
                pageY = coor.pageY;
            }
            else {
                pageX = evt.pageX;
                pageY = evt.pageY;
            }
            var x = pageX + this._hScrollOffset - offset.left;
            var y = pageY + this._vScrollOffset - offset.top;
            var symbolPaletteId = ui.helper[0].getAttribute("paletteId");
            var symbolPalette = $("#" + symbolPaletteId).ejSymbolPalette("instance");
            if (symbolPaletteId) {
                var paletteItem = $.extend(true, {}, this._selectedSymbol);
                this._selectedSymbol = null;
                paletteItem.name += ej.datavisualization.Diagram.Util.randomId();
                if (paletteItem.segments) {
                    if (paletteItem.segments) {
                        ej.datavisualization.Diagram.Util._translateLine(paletteItem, x, y);
                    }
                    args = { element: paletteItem };
                    this._raiseDropEvent(args);
                    if (!args.cancel) {
                        this.add(paletteItem);
                    }
                    paletteItem = this.selectionList[0];
                }
                else {

                    var palNameTable = $.extend(true, {}, symbolPalette.nameTable);
                    paletteItem.offsetX = x / scale;
                    paletteItem.offsetY = y / scale;
                    if (paletteItem.type == "group") {
                        var children = this._getChildren(paletteItem.children);
                        for (var j = 0; j < children.length; j++) {
                            var newObj = $.extend(true, {}, palNameTable[children[j]]);
                            newObj.parent = paletteItem.name;
                            newObj.name = paletteItem.name + newObj.name;
                            children[j] = newObj.name;
                            this.nameTable[newObj.name] = newObj;
                            this.nodes().push(newObj);
                            ej.datavisualization.Diagram.SpatialUtil._updateQuad(this, this._spatialSearch, newObj);
                        }
                        paletteItem.height = paletteItem.width = 0;
                        this._updateChildBounds(paletteItem, this.nameTable);
                    }
                    args = { element: paletteItem };
                    this._raiseDropEvent(args);
                    if (!args.cancel) {
                        this.add(paletteItem);
                    }
                    paletteItem = this.selectionList[0];
                }
                this.scrollToNode(paletteItem);
                if (paletteItem.labels.length > 0 && paletteItem.labels[0].mode === "edit") {
                    this._isEditing = true;
                    this.startLabelEdit(paletteItem, paletteItem.labels[0]);
                }
                else
                    this.element[0].focus();

            }
            else {
                var node = null;
                node = this._findNodeUnderMouse(evt);
                args = { element: ui.helper, e: evt, draggable: ui.draggable, targetNode: node };
                this._raiseDropEvent(args);
            }
        },

        _isTouchEvent: function (evt) {
            if (evt.type == "touchmove" || evt.type == "touchstart" || evt.type == "touchend") {
                return evt.originalEvent ? evt.originalEvent.changedTouches[0] : evt.changedTouches[0];
            }
            return evt;
        },

        _raiseDropEvent: function (args) {
            this._raiseEvent("drop", args);
        },

        _documentmouseup: function (evt) {
            if (this.activeTool && this.activeTool.inAction && !(this.activeTool instanceof ej.datavisualization.Diagram.PolygonTool) && !(this.activeTool instanceof ej.datavisualization.Diagram.TextTool)) {
                this.activeTool.mouseup(evt, true);
            }

            if (this._selectedSymbol) {
                var displays = document.getElementsByClassName("dragClone")[0];
                if (displays != null) {
                    displays.style.display = "block";
                }
                this._remove(this.selectionList[0]);

            }

        },
        //#endregion

        //#region Helper methods
        _updateEdges: function (connector) {
            var node;
            if (ej.datavisualization.Diagram.Util.isTargetConnected(connector)) {
                node = this.nameTable[connector.targetNode];
                if (node && node.inEdges.indexOf(connector.name) == -1)
                    node.inEdges.push(connector.name);
            }
            if (ej.datavisualization.Diagram.Util.isSourceConnected(connector)) {
                node = this.nameTable[connector.sourceNode];
                if (node && node.outEdges.indexOf(connector.name) == -1)
                    node.outEdges.push(connector.name);
            }
        },

        _updateChildrenEdges: function (object) {
            var children = this._getChildren(object.children);
            for (var i = 0; i < children.length; i++) {
                var child = children[i];
                if (child.segments) {
                    this._updateEdges(child);
                    this._dock(child, this.nameTable);
                }
                else if (child.type == "group") {
                    this._updateChildrenEdges(child);
                }
            }
        },
        _updateParent: function (object) {
            var children = this._getChildren(object.children);
            for (var i = 0; i < children.length; i++) {
                var index = this.nodes().indexOf(this.nameTable[children[i]]);
                var child = this._getNewNode(this.nameTable[children[i]]);
                if (child && child.type == "group") {
                    this._updateParent(child);
                }
                else if (child) {
                    child.parent = object.name;
                    this.nameTable[child.name] = child;
                    if (index != -1) {
                        this.nodes()[index] = child;
                    }
                }
            }
        },
        _findPortAtPoint: function (point, node) {
            var ports;
            var port;
            var location;
            var size, pt, x, y;
            var bounds;
            if (node) {
                bounds = ej.datavisualization.Diagram.Util.bounds(node, true);
                ports = node.ports;
                var matrix;
                for (var i = 0, len = ports.length; i < len; ++i) {
                    port = ports[i];
                    size = ej.datavisualization.Diagram.Size(port.size, port.size);
                    pt = ej.datavisualization.Diagram.Util._getPortPosition(port, bounds);
                    matrix = ej.Matrix.identity();
                    ej.Matrix.rotate(matrix, node.rotateAngle, node.offsetX, node.offsetY);
                    pt = ej.Matrix.transform(matrix, pt);
                    x = pt.x - port.size / 2;
                    y = pt.y - port.size / 2;
                    location = ej.datavisualization.Diagram.Rectangle(x, y, size.width, size.height);
                    if (ej.datavisualization.Diagram.Geometry.containsPoint(location, point)) {
                        return port;
                    }
                }

            }
            return null;
        },

        _findLabelAtPoint: function (point, node) {
            var labels, label = null;
            var location;
            var size, pt, x, y, width, height;
            var bounds, textElement, matrix;
            var htmlLayer = this._svg.document.parentNode.getElementsByClassName("htmlLayer")[0];
            if (node) {
                bounds = ej.datavisualization.Diagram.Util.bounds(node);
                labels = node.labels;
                if (labels.length > 0) {
                    label = labels[0];
                    for (var i = 0, len = labels.length; i < len; i++) {
                        label = labels[i];
                        textElement = $(htmlLayer).find("#" + node.name + "_" + label.name)[0];
                        width = textElement.offsetWidth;
                        height = textElement.offsetHeight;
                        if (!width) width = bounds.width;
                        if (!height) height = label.fontSize;
                        size = ej.datavisualization.Diagram.Size(width, height);
                        pt = ej.datavisualization.Diagram.Util._getLabelPosition(label, bounds);
                        pt.x = bounds.x + pt.x;
                        pt.y = bounds.y + pt.y;
                        matrix = ej.Matrix.identity();
                        if (!node.segments)
                            ej.Matrix.rotate(matrix, node.rotateAngle, node.offsetX, node.offsetY);
                        else
                            ej.Matrix.rotate(matrix, 0, bounds.x + bounds.width / 2, bounds.y + bounds.height / 2);
                        pt = ej.Matrix.transform(matrix, pt);
                        x = pt.x - size.width / 2;
                        y = pt.y - size.height / 2;
                        location = ej.datavisualization.Diagram.Rectangle(x, y, size.width, size.height);
                        if (ej.datavisualization.Diagram.Geometry.containsPoint(location, point)) {
                            break;
                        }
                    }
                }
            }
            return label;
        },

        _getCurrentZoom: function () {
            return this._currZoom;
        },

        _findNode: function (id) {
            return this.nameTable[id];
        },
        _findPort: function (node, portId) {
            var ports = node.ports;
            for (var i = 0, len = ports.length; i < len; i++) {
                if (ports[i].name === portId) {
                    return ports[i];
                }
            }
            return null;
        },

        _findConnector: function (id) {
            return this.nameTable[id];
        },

        _findChildren: function (group, name) {
            var child, innerchild;
            var children = this._getChildren(group.children);
            for (var i = 0; i < children.length; i++) {
                child = this.nameTable[children[i]];
                if (child) {
                    if (name == child.name) {
                        return child;
                    }
                    if (child.type == "group") {
                        innerchild = this._findChildren(child, name);
                        if (innerchild) return innerchild;
                    }
                }
            }
            return null;
        },

        _delete: function () {
            if (this.selectionList[0]) {
                var childTable = {};
                var edgeTable = {};
                childTable = this._getChildTable(this.selectionList[0], childTable);
                edgeTable = this._getEdgeTable(this.selectionList[0], edgeTable);
                if (!this._isUndo) {
                    var sourcePorts = {}, targetPorts = {}, connector, count, i;
                    if (!this.selectionList[0].segments) {
                        if (this.selectionList[0].outEdges.length > 0) {
                            count = this.selectionList[0].outEdges.length;
                            for (i = 0; i < count; i++) {
                                connector = this.nameTable[this.selectionList[0].outEdges[i]];
                                if (connector.sourcePort)
                                    sourcePorts[connector.name] = connector.sourcePort;
                            }

                        }
                        if (this.selectionList[0].inEdges.length > 0) {
                            count = this.selectionList[0].inEdges.length;
                            for (i = 0; i < count; i++) {
                                connector = this.nameTable[this.selectionList[0].inEdges[i]];
                                if (connector.targetPort)
                                    targetPorts[connector.name] = connector.targetPort;
                            }

                        }
                    }
                    var entry = { type: "collectionchanged", object: jQuery.extend(true, {}, this.selectionList[0]), childTable: jQuery.extend(true, {}, childTable), edgeTable: jQuery.extend(true, {}, edgeTable), sourcePorts: sourcePorts, targetPorts: targetPorts, changeType: "remove" };
                    this.addHistoryEntry(entry);
                }
                if (this.selectionList.length > 0) {
                    var obj = this.selectionList[0];
                    if (obj.type == "pseudoGroup") {
                        var children = this._getChildren(obj.children);
                        for (var i = children.length - 1; i >= 0; i--) {
                            this._remove(this.nameTable[children[i]]);
                            this._isUndo = true;
                        }
                        this._isUndo = false;
                    }
                    else {
                        if (this._nodeToHit === obj)
                            this._nodeToHit = null;
                        this._remove(obj);
                        if (obj.container && obj.parent) {
                            var parent = this.nameTable[obj.parent];
                            if (parent && parent.container) {
                                if (parent.container.type == "stack") {
                                    if (this._getChild(parent.children[0])) {
                                        this.tools.move._updateContainer(this.nameTable[this._getChild(parent.children[0])]);
                                        ej.datavisualization.Diagram.DiagramContext.update(parent, this);
                                    } else {
                                        var prePar = this.nameTable[parent.parent];
                                        if (prePar) {
                                            this._remove(prePar);
                                        }
                                    }
                                }

                            }
                        }
                    }
                }
                this._clearSelection();
            }
        },
        _getEdgeTable: function (group, edgeTable) {
            var edges, len, i, j, depend;
            if (!group.segments) {
                if (group.type == "group") {
                    var children = this._getChildren(group.children);
                    for (i = 0; i < children.length; i++) {
                        var node = this.nameTable[children[i]];
                        if (node.inEdges && node.inEdges.length > 0) {
                            edges = node.inEdges;
                            for (j = 0, len = edges.length; j < len; j++) {
                                depend = this.nameTable[edges[j]];
                                var table = edgeTable[depend.name] = $.extend(true, {}, depend);
                            }
                        }
                        if (node.outEdges && node.outEdges.length > 0) {
                            edges = node.outEdges;
                            for (j = 0, len = edges.length; j < len; j++) {
                                depend = this.nameTable[edges[j]];
                                var table = edgeTable[depend.name] = $.extend(true, {}, depend);
                            }
                        }
                    }
                }
                if (group.inEdges && group.inEdges.length > 0) {
                    edges = group.inEdges;
                    for (j = 0, len = edges.length; j < len; j++) {
                        depend = this.nameTable[edges[j]];
                        var table = edgeTable[depend.name] = $.extend(true, {}, depend);
                    }
                }
                if (group.outEdges && group.outEdges.length > 0) {
                    edges = group.outEdges;
                    for (j = 0, len = edges.length; j < len; j++) {
                        depend = this.nameTable[edges[j]];
                        var table = edgeTable[depend.name] = $.extend(true, {}, depend);
                    }
                }
            }
            return edgeTable;
        },
        _remove: function (obj, dependent) {
            if (obj) {
                if (obj.segments) var type = "connector";
                else type = "node";
                var dependent = dependent ? ej.datavisualization.Diagram.dependentconnector.dependent : ej.datavisualization.Diagram.dependentconnector.independent;
                var args = { changeType: "remove", element: obj, cancel: false, dependent: dependent };
                if (!obj.segments) { args.adjustDependent = true; args.deleteDependent = true; }
                this._raiseEvent(type + "CollectionChange", args);
                if (!args.cancel) {
                    if (ej.datavisualization.Diagram.Util.canDelete(obj)) {
                        var name = obj.name;
                        if (obj.type == "group" && obj.type != "pseudoGroup") {
                            var children = this._getChildren(obj.children);
                            for (var i = 0; i < children.length; i++) {
                                var child = this.nameTable[children[i]];
                                if (child && !ej.datavisualization.Diagram.Util.canDelete(child)) return;
                            }
                        }
                        if (!obj.segments) {
                            this._disConnect(obj, args);

                            //if (obj.type != "group")
                            this._removeConnector(obj, args);
                            ej.datavisualization.Diagram.Util.removeItem(this.nodes(), this.nameTable[obj.name]);
                        } else {
                            this._removeEdges(obj);
                            obj.sourceNode = obj.sourcePort = obj.targetNode = obj.targetPort = null;
                            ej.datavisualization.Diagram.Util.removeItem(this.connectors(), this.nameTable[obj.name]);
                        }
                        if (obj.shape || obj.segments) {
                            ej.datavisualization.Diagram.SpatialUtil._removeFromaQuad(this._spatialSearch, this._spatialSearch.quadTable[obj.name], obj);
                            ej.datavisualization.Diagram.SpatialUtil._updateBounds(this, this._spatialSearch, obj);
                            if (obj.segments)
                                this._updateConnectorBridging(obj);
                        }
                        if (obj.parent) {
                            var parent = this.nameTable[obj.parent];
                            if (parent && parent.type == "group") {
                                ej.datavisualization.Diagram.Util.removeItem(parent.children, obj.name);
                                ej.datavisualization.Diagram.Util._updateGroupBounds(parent, this);
                            }
                        }
                        delete this.nameTable[name];
                        var element = this._svg.getElementById(obj.name);
                        if (ej.browserInfo().name === "msie") {
                            if (obj.shape && obj.shape.html && element) {
                                var htmlelement = document.getElementById(obj.name + "_parentdiv");
                                htmlelement.parentNode.removeChild(htmlelement);
                            } else if (obj.type == "group")
                                this._checkForHtmlNode(obj);
                        }
                        if (obj.type == "group" && obj.type != "pseudoGroup") {
                            this._removeChildren(obj, args);
                        }
                        this._removeElement(obj);
                        if (obj.type == "group" && obj.container) {
                            ej.datavisualization.Diagram.SvgContext._removephases(obj, this);
                        }
                        if (element && element.parentNode)
                            element.parentNode.removeChild(element);
                        if (this.selectionList[0]) {
                            this._clearSelection();
                        }
                    }
                }
            }
        },

        _removeConnector: function (node, args) {
            var edges;
            var connector;
            var i, len;
            if (!node.segments) {
                //If adjustDependent is false all connector associated with Nodes get deleted.
                if (args.deleteDependent && !(args.adjustDependent)) {
                    if (node.inEdges && node.inEdges.length > 0) {
                        edges = node.inEdges;
                        for (i = edges.length - 1 ; i >= 0; i--) {
                            //Remove the Connector
                            this._updateConnection(this.nameTable[edges[i]], true);
                        }
                    }
                    if (node.outEdges && node.outEdges.length > 0) {
                        edges = node.outEdges;
                        for (i = 0, len = edges.length; i < len; i++) {
                            //Remove the Connector
                            this._updateConnection(this.nameTable[edges[i]], true);
                        }
                    }
                }
                //If both deleteDependent & adjustDependent are true changes to Visio behaviour
                if (args.deleteDependent && args.adjustDependent) {
                    if (node.inEdges && node.inEdges.length == 0 && node.outEdges.length > 0) {
                        edges = node.outEdges;
                        for (i = edges.length - 1 ; i >= 0; i--) {
                            //Remove the Connector
                            this._updateConnection(this.nameTable[edges[i]], true);
                        }
                    }
                    else if (node.outEdges && node.outEdges.length == 0 && node.inEdges.length > 0) {
                        edges = node.inEdges;
                        for (i = edges.length - 1 ; i >= 0; i--) {
                            //Remove the Connector
                            if (this.nameTable[edges[i]])
                                this._updateConnection(this.nameTable[edges[i]], true);
                        }
                    }
                    else if ((node.inEdges && node.inEdges.length == 1 || node.inEdges.length > 1) && (node.outEdges.length == 1)) {
                        edges = node.outEdges;
                        for (i = 0, len = edges.length; i < len; i++) {
                            //Remove the Connector
                            this._updateConnection(this.nameTable[edges[i]], true);
                        }
                    }
                    else if (!(node.inEdges && node.inEdges.length > 1 && node.outEdges.length > 1)) {
                        edges = node.inEdges;
                        for (i = 0, len = edges.length; i < len; i++) {
                            //Remove the Connector
                            this._updateConnection(this.nameTable[edges[i]], true);
                        }
                    }
                }
            }
        },

        _updateConnection: function (connector, args) {
            if (connector) {
                this._remove(connector, args);
                this.updateConnector(connector.name);
            }
        },
        _removeElement: function (element) {
            for (var i = 0; i < this._views.length; i++) {
                var view = this._views[i];
                this._views[view].context.removeChild(element, this._views[view]);
            }

        },
        _disConnect: function (node, args, isChild) {
            var edgesIn, edgesOut, connector, parentNode, targetNode, data;
            var i, j, leni, lenj;
            if (args.deleteDependent && args.adjustDependent && !isChild) {
                if (node.inEdges && node.inEdges.length > 0 && node.outEdges.length > 0) {
                    edgesIn = node.inEdges;
                    edgesOut = node.outEdges;
                    if ((node.inEdges.length > 1 || node.inEdges.length == 1) && node.outEdges.length == 1) {
                        for (i = 0, leni = edgesIn.length; i < leni; i++) {
                            if (this.nameTable[edgesIn[i]] && this.nameTable[edgesOut[0]]) {
                                if ((this.nameTable[edgesIn[i]].targetNode == this.nameTable[edgesOut[0]].sourceNode)) {
                                    targetNode = this.nameTable[this.nameTable[edgesOut[0]].targetNode];
                                    if (targetNode) {
                                        data = $.extend(true, {}, targetNode);
                                        this.nameTable[edgesIn[i]].targetNode = this.nameTable[edgesOut[0]].targetNode;
                                        this.nameTable[edgesIn[i]].targetPort = this.nameTable[edgesOut[0]].targetPort;
                                        targetNode.inEdges[i] = this.nameTable[edgesIn[i]].name;
                                    }
                                    //Updating the Connector Dock and Connector
                                    ej.datavisualization.Diagram.Util.dock(this.nameTable[edgesIn[i]], this.nameTable);
                                    ej.datavisualization.Diagram.DiagramContext.update(this.nameTable[edgesIn[i]], this);
                                }
                            }
                        }
                        if (this.nameTable[edgesOut[0]]) {
                            this.nameTable[edgesOut[0]].sourceNode = null;
                            this.nameTable[edgesOut[0]].sourcePort = null;
                        }
                    }
                    else if (!(node.inEdges.length > 1 && node.outEdges.length > 1)) {
                        // Need to code when many in and only one out 
                        for (i = 0, leni = edgesIn.length; i < leni; i++) {
                            if (node.outEdges.length > 0) {
                                parentNode = this.nameTable[this.nameTable[edgesIn[i]].sourceNode];
                                data = $.extend(true, {}, parentNode);
                                for (j = 0, lenj = edgesOut.length; j < lenj; j++) {
                                    if ((this.nameTable[edgesIn[i]].targetNode == this.nameTable[edgesOut[j]].sourceNode)) {
                                        this.nameTable[edgesOut[j]].sourceNode = this.nameTable[edgesIn[i]].sourceNode;
                                        this.nameTable[edgesOut[j]].sourcePort = this.nameTable[edgesIn[i]].sourcePort;
                                        parentNode.outEdges[data.outEdges.length + j] = this.nameTable[edgesOut[j]].name;
                                        //Updating the Connector Dock and Connector
                                        ej.datavisualization.Diagram.Util.dock(this.nameTable[edgesOut[j]], this.nameTable);
                                        ej.datavisualization.Diagram.DiagramContext.update(this.nameTable[edgesOut[j]], this);
                                    }
                                }
                                this.nameTable[edgesIn[i]].targetNode = null;
                                this.nameTable[edgesIn[i]].targetPort = null;
                            }
                        }
                    }
                } return;
            }
            if (node.inEdges && node.inEdges.length > 0) {
                edgesIn = node.inEdges;
                for (i = 0, leni = edgesIn.length; i < leni; i++) {
                    connector = this.nameTable[edgesIn[i]];
                    connector.targetNode = null;
                    connector.targetPort = null;
                }
            }
            if (node.outEdges && node.outEdges.length > 0) {
                edgesOut = node.outEdges;
                for (i = 0, leni = edgesOut.length; i < leni; i++) {
                    connector = this.nameTable[edgesOut[i]];
                    connector.sourceNode = null;
                    connector.sourcePort = null;
                }
            }
        },

        _removeEdges: function (connector) {
            if (connector.targetNode) {
                if (this.nameTable[connector.targetNode] && this.nameTable[connector.targetNode].inEdges)
                    ej.datavisualization.Diagram.Util.removeItem(this.nameTable[connector.targetNode].inEdges, connector.name);
            }
            if (connector.sourceNode) {
                if (this.nameTable[connector.sourceNode] && this.nameTable[connector.sourceNode].outEdges)
                    ej.datavisualization.Diagram.Util.removeItem(this.nameTable[connector.sourceNode].outEdges, connector.name);
            }
        },

        _selectionContains: function (node) {
            if (this._hasSelection() && node)
                for (var i = 0; i < this.selectionList.length; i++) {
                    if (node.name === this.selectionList[i].name)
                        return true;
                }
            return false;
        },

        _addSelection: function (selectedShape) {

            if (selectedShape && ej.datavisualization.Diagram.Util.canSelect(selectedShape)) {
                if (!this._selectionContains(selectedShape)) {
                    this.selectionList.push(selectedShape);
                    var args = { changeType: "insert", element: selectedShape, cancel: false };
                    if (!this._selectedSymbol)
                        this._raiseEvent("selectionChange", args);

                    if (!args.cancel) {
                        this._updateSelectorObject(selectedShape);
                        ej.datavisualization.Diagram.SvgContext.renderSelector(selectedShape, this._svg, this._adornerLayer, this._currZoom,
                            this.model.selectedItems.constraints);
                        if ((this.model.selectedItems.userHandles != null && this.model.selectedItems.userHandles.length > 0)) {
                            var isMultipleSelection = false;
                            if (selectedShape.type == "pseudoGroup")
                                isMultipleSelection = true;
                            if (this.model.selectedItems.constraints & ej.datavisualization.Diagram.SelectorConstraints.UserHandles)
                                ej.datavisualization.Diagram.SvgContext.renderUserHandles(this.model.selectedItems.userHandles, selectedShape, this._svg, isMultipleSelection, this._currZoom, this._adornerLayer);
                        }
                    }
                    else {
                        ej.datavisualization.Diagram.Util.removeItem(this.selectionList, selectedShape);
                    }
                }
            }
        },

        updateSelector: function (option) {
            if (this._selectedItem != "") {
                var options = {};
                if (option.offsetX)
                    options.offsetX = Number(typeof option.offsetX === 'function' ? option.offsetX() : option.offsetX);

                if (option.offsetY)
                    options.offsetY = Number(typeof option.offsetY === 'function' ? option.offsetY() : option.offsetY);

                if (option.width)
                    options.width = Number(typeof option.width === 'function' ? option.width() : option.width);

                if (option.height)
                    options.height = Number(typeof option.height === 'function' ? option.height() : option.height);

                if (option.rotateAngle)
                    options.rotateAngle = Number(typeof option.rotateAngle === 'function' ? option.rotateAngle() : option.rotateAngle);

                this.updateNode(this._selectedItem, options);
            }
            if (option.userHandles) {
                this.model.selectedItems.userHandles = option;
                this._initHandles();
            }
        },

        _updateSelectorObject: function (selectedShape) {
            if (!selectedShape.segments) {
                this._selectorOffsetX(selectedShape.offsetX);
                this._selectorOffsetY(selectedShape.offsetY);
                this._selectorWidth(selectedShape.width);
                this._selectorHeight(selectedShape.height);
                this._selectorRotateAngle(selectedShape.rotateAngle);
                this._selectedItem = selectedShape.name;
            }
            if (selectedShape.type == "pseudoGroup") {
                for (var i = 0; i < selectedShape.children.length; i++) {
                    var child = selectedShape.children[i];
                    if (typeof (child) === "object") {
                        this.model.selectedItems.children.push(child);
                    }
                    else if (typeof (child) === "string") {
                        this.model.selectedItems.children.push(this.nameTable[child]);
                    }
                }
            }
            else {
                this.model.selectedItems.children.push(selectedShape);
            }
        },

        _clearSelectorObject: function () {
            this._selectorOffsetX(0);
            this._selectorOffsetY(0);
            this._selectorWidth(0);
            this._selectorHeight(0);
            this._selectorRotateAngle(0);
            this._selectedItem = "";
            this.model.selectedItems.children = [];
        },

        _raiseEvent: function (type, args) {
            args.elementType = this._getElementType(args.element);
            return this._trigger(type, args);

        },
        _clearSelection: function () {
            if (this._isEditing && this.selectionList.length > 0) {
                this._endEdit();
            }
            var args = { changeType: "remove", element: this.selectionList, cancel: false };
            if (!this._selectedSymbol)
                this._raiseEvent("selectionChange", args);
            if (!args.cancel) {
                this._clearSelectorObject();
                if (this.selectionList[0] && this.selectionList[0].type == "pseudoGroup") {
                    ej.datavisualization.Diagram.Util.removeItem(this.nodes(), this.selectionList[0]);
                    delete this.nameTable[this.selectionList[0].name];
                }
                ej.datavisualization.Diagram.Util.clear(this.selectionList);
                ej.datavisualization.Diagram.SvgContext.clearSelector(this._svg, this._adornerLayer);

            }
        },

        _updateSelectionHandle: function (isDragging) {
            if (this.selectionList.length > 0) {
                var shape = this.nameTable[this.selectionList[0].name];
                var constraints = this.model.selectedItems.constraints;
                if (isDragging && (this.model.selectedItems.constraints & ej.datavisualization.Diagram.SelectorConstraints.UserHandles))
                    constraints = constraints & ~ej.datavisualization.Diagram.SelectorConstraints.UserHandles;
                this._updateSelectorObject(shape);
                ej.datavisualization.Diagram.SvgContext.updateSelector(shape, this._svg, this._currZoom, this, constraints);
                if ((this.model.selectedItems.userHandles != null && this.model.selectedItems.userHandles.length > 0)) {
                    var isMultipleSelection = false;
                    if (shape.type == "pseudoGroup")
                        isMultipleSelection = true;
                    if (this.model.selectedItems.constraints & ej.datavisualization.Diagram.SelectorConstraints.UserHandles)
                        ej.datavisualization.Diagram.SvgContext.updateUserHandles(this.model.selectedItems.userHandles, shape, this._svg, isMultipleSelection, isDragging, this._currZoom);
                }
            }
        },

        _hasSelection: function () {
            return this.selectionList.length > 0;
        },

        _checkToolToActivate: function (evt, node, point) {
            var success = false;
            if (node) {
                if (node.segments && (evt.ctrlKey && evt.shiftKey) || (evt.ctrlKey && evt.altKey)) {
                    this._toolToActivate = "endPoint";
                    this._currentCursor = "move";
                    success = true;
                }
                if (!success) {
                    if (this._selectionContains(node)) {
                        if (node.segments) {
                            success = this._canActivateEndPointTool(evt, node, point);
                        }
                        else {
                            success = this._canActivateResizeTool(evt, node, point);
                            if (!success) {
                                success = this._canActivateRotateTool(evt, node, point);
                            }
                        }
                        if (!success) {
                            success = this._canActivateUserHandle(evt, node, point);
                        }
                        if (!success) {
                            success = this._canActivateMoveTool(evt, node, point);
                        }
                        if (!success) {
                            success = this._canActivatephaseTool(evt, point);
                        }
                    }
                    else {
                        success = this._canActivateMoveTool(evt, node, point);
                    }
                }
            }
            else {
                success = this._canActivatephaseTool(evt, point);
            }
            if (!success) {
                if (this.tool() & ej.datavisualization.Diagram.Tool.ZoomPan) {
                    this._toolToActivate = "panTool";
                    this._currentCursor = "pointer";
                }
                else {
                    this._toolToActivate = "select";
                    this._currentCursor = "default";
                }
            }
            if (this._toolToActivate != "rotate") {
                this._svg.document.removeAttribute("class");
            }
            return success;
        },

        _canActivatephaseTool: function (evt, point) {
            if ($(evt.target).parents("g").first()[0]) {
                var id = $(evt.target).parents("g").first()[0].id;
                var phase = this._getSeperetor(id);
                if (phase) {
                    if (phase.orientation == "horizontal")
                        this._currentCursor = "e-resize";
                    else
                        this._currentCursor = "n-resize";
                }
                else
                    this._currentCursor = "default";
                this._toolToActivate = "phase";

                return true;
            }
        },

        _canActivateUserHandle: function (evt) {
            if (this._isUserHandle(evt)) {
                var handleName = $(evt.target).parents("g").first().context.id.split("_")[0];
                this._toolToActivate = handleName;
                this._currentCursor = this.tools[this._toolToActivate].cursor;
                return true;
            }
            return false;
        },

        _canActivateEndPointTool: function (evt, connector) {
            if (connector) {
                var endPointHandle = evt.target.getAttribute("class");
                if (endPointHandle && ((endPointHandle === "targetEndPoint" && ej.datavisualization.Diagram.Util.canDragTargetEnd(connector)) ||
                    (endPointHandle === "sourceEndPoint" && ej.datavisualization.Diagram.Util.canDragSourceEnd(connector)) ||
                (endPointHandle.match("bezierpoint") && ej.datavisualization.Diagram.Util.canDragSegmentThumbs(connector)) ||
                    endPointHandle == "segmentEnd")) {
                    this._toolToActivate = "endPoint";
                    this._currentCursor = "move";
                    return true;
                }
            }
            return false;
        },

        _canActivateResizeTool: function (evt, node) {
            if (ej.datavisualization.Diagram.Util.canResize(node) && (this.model.selectedItems.constraints & ej.datavisualization.Diagram.SelectorConstraints.Resizer)) {
                var dir = evt.target.getAttribute("class");
                if (dir === "nw-resize" || dir === "n-resize" || dir === "ne-resize" || dir === "w-resize" || dir === "e-resize" || dir === "sw-resize" || dir === "s-resize" || dir === "se-resize") {
                    this._toolToActivate = "resize";
                    if ((node.rotateAngle >= 0 && node.rotateAngle < 25) || (node.rotateAngle >= 160 && node.rotateAngle <= 200) || (node.rotateAngle >= 340 && node.rotateAngle <= 360)) {
                        this._currentCursor = dir;
                    }
                    else if ((node.rotateAngle >= 25 && node.rotateAngle <= 65) || (node.rotateAngle >= 205 && node.rotateAngle <= 240)) {

                        if (dir === "n-resize" || dir === "s-resize") {
                            this._currentCursor = "ne-resize";
                        }
                        else if (dir === "nw-resize" || dir === "se-resize") {
                            this._currentCursor = "n-resize";
                        }
                        else if (dir === "e-resize" || dir === "w-resize") {
                            this._currentCursor = "nw-resize";
                        }
                        else {
                            this._currentCursor = "e-resize";
                        }
                    }
                    else if ((node.rotateAngle >= 70 && node.rotateAngle <= 110) || (node.rotateAngle >= 250 && node.rotateAngle <= 290)) {
                        if (dir === "n-resize" || dir === "s-resize") {
                            this._currentCursor = "e-resize";
                        }
                        else if (dir === "nw-resize" || dir === "se-resize") {
                            this._currentCursor = "ne-resize";
                        }
                        else if (dir === "e-resize" || dir === "w-resize") {
                            this._currentCursor = "n-resize";
                        }
                        else {
                            this._currentCursor = "nw-resize";
                        }
                    }
                    else if ((node.rotateAngle >= 115 && node.rotateAngle <= 155) || (node.rotateAngle >= 295 && node.rotateAngle <= 335)) {
                        if (dir === "n-resize" || dir === "s-resize") {
                            this._currentCursor = "nw-resize";
                        }
                        else if (dir === "nw-resize" || dir === "se-resize") {
                            this._currentCursor = "e-resize";
                        }
                        else if (dir === "e-resize" || dir === "w-resize") {
                            this._currentCursor = "ne-resize";
                        }
                        else {
                            this._currentCursor = "n-resize";
                        }
                    }
                    return true;
                }
            }
            return false;
        },

        _canActivateMoveTool: function (evt, node) {
            var findNode = this._findNodeUnderMouse(evt);
            if (findNode && findNode.name === node.name) {
                var canMove = true;
                if (node.parent) {
                    if (this.selectionList.length > 0 && this._selectionContains(node))
                        canMove = true;
                    else
                        canMove = false;
                }
                if (canMove && ej.datavisualization.Diagram.Util.canMoveLabel(node)) {
                    var id = evt.target.parentNode.id.split('_');
                    if (id[id.length - 1] == "lblbg") {
                        this._toolToActivate = "move";
                        this._currentCursor = "pointer";
                        return true;
                    }
                }

                if (ej.datavisualization.Diagram.Util.canMove(node)) {
                    this._toolToActivate = "move";
                    if (this.selectionList.length > 0 && (this._selectionContains(node) || (this.selectionList[0].children && this._findChildren(this.selectionList[0], node.name)))) {
                        this._currentCursor = "move";
                    }
                    else {
                        this._currentCursor = "default";
                    }
                    return true;
                }
            }
            return false;
        },

        _canActivateRotateTool: function (evt, node) {
            if (ej.datavisualization.Diagram.Util.canRotate(node) && (this.model.selectedItems.constraints & ej.datavisualization.Diagram.SelectorConstraints.Rotator)) {
                var rotateHandle = evt.target.getAttribute("class");
                if (rotateHandle === "rotate") {
                    this._toolToActivate = "rotate";
                    this._svg.document.setAttribute("class", "svg-rotate");
                    this._currentCursor = "";
                    return true;
                }
            }
            return false;
        },

        _canActivatePivotTool: function (evt) {
            var pivotHandle = evt.target.getAttribute("class");
            if (pivotHandle === "pivot") {
                this._toolToActivate = "pivot";
                this._currentCursor = "default";
                return true;
            }

            return false;
        },

        _updateCursor: function () {
            this._svg.document.style.cursor = this._currentCursor;
            this._svg.document.parentNode.getElementsByClassName("htmlLayer")[0].style.cursor = this._currentCursor;
        },

        _getResizeCursor: function (resizeDirection) {
            var cursor = "default";
            switch (resizeDirection) {
                case "topleft": cursor = "nw-resize";
                    break;
                case "topcenter": cursor = "n-resize";
                    break;
                case "topright": cursor = "ne-resize";
                    break;
                case "middleleft": cursor = "w-resize";
                    break;
                case "middleright": cursor = "e-resize";
                    break;
                case "bottomleft": cursor = "sw-resize";
                    break;
                case "bottomcenter": cursor = "s-resize";
                    break;
                case "bottomright": cursor = "se-resize";
                    break;
            }
            return cursor;
        },

        _startEdit: function (shape) {
            var label;
            var centerX, centerY;
            var bbox;
            var nodeBounds;
            var bounds;
            var curZoomfactor;
            var matrix = ej.Matrix.identity();
            var width = shape.width ? shape.width : shape._width;
            var height = shape.height ? shape.height : shape._height;
            ej.Matrix.rotate(matrix, shape.rotateAngle, width / 2, height / 2);
            if (shape.shape && shape.shape.type === "text") {
                if (this._svg.getElementById(shape.name + "_shape") !== null)
                    bbox = this._svg.getElementById(shape.name + "_shape").getBBox();
                else
                    bbox = { x: shape.offsetX - width / 2, y: shape.offsetY - height / 2, width: width, height: height };
                label = shape.shape.textBlock;
                if (label) {
                    nodeBounds = ej.datavisualization.Diagram.Util.bounds(shape);
                    bounds = new ej.datavisualization.Diagram.Rectangle(bbox.x - label.fontSize, bbox.y - label.fontSize, bbox.width + label.fontSize / 2, bbox.height + label.fontSize / 2);
                    curZoomfactor = this._currZoom;
                    var diff = ej.Matrix.transform(matrix, ej.datavisualization.Diagram.Util._getLabelPosition(label, nodeBounds));
                    centerX = shape.offsetX - width / 2 + diff.x;
                    centerY = shape.offsetY - height / 2 + diff.y;
                    if (label.horizontalAlignment == "left")
                        centerX += bbox.width / 2;
                    else if (label.horizontalAlignment == "right")
                        centerX -= bbox.width / 2;
                    if (label.verticalAlignment == "top")
                        centerY += bbox.height / 2;
                    else if (label.verticalAlignment == "bottom")
                        centerY -= bbox.height / 2;
                    if (bbox.width === 0 || bbox.height === 0) {
                        bbox = ej.datavisualization.Diagram.Util.bounds(shape);
                        bounds.width = bbox.width == 0 ? 50 : nodeBounds.width * curZoomfactor;
                        bounds.x = (centerX * curZoomfactor - bounds.width / 2 * curZoomfactor) - this._hScrollOffset;

                        bounds.height = label.fontSize;
                        bounds.y = (centerY * curZoomfactor - bounds.height / 2 * curZoomfactor) - this._vScrollOffset;
                    }
                    else {
                        bounds.width = 50;
                        bounds.height = label.fontSize;
                        bounds.x = (centerX * curZoomfactor - (bounds.width / 2 * curZoomfactor)) - this._hScrollOffset;
                        bounds.y = (centerY * curZoomfactor - (bounds.height / 2 * curZoomfactor)) - this._vScrollOffset;
                    }
                    this._boundingBox = bounds;
                    this._createEditBox(label, bounds.x, bounds.y, bounds.width, bounds.height, shape);
                    this._isEditing = true;
                }
            }
            else {
                if (shape.labels.length > 0) {
                    if (this.activeTool.name === "textTool") {
                        label = this.activeTool.getLabelUnderMouse();
                        if (label) label = shape.labels[0];
                    }
                    else {
                        label = shape.labels[0];
                    }
                }
                else {
                    var mNode = this._findNode(shape.name);
                    label = new ej.datavisualization.Diagram.Label({ "name": "label" + ej.datavisualization.Diagram.Util.randomId() });
                    shape.labels.push(label);
                    var parent = (mNode !== shape) ? mNode : null;
                    ej.datavisualization.Diagram.DiagramContext.addNodeLabel(shape, label, parent, this);
                    if (this.activeTool.name === "textTool")
                        this.activateTool.activeLabel = label;
                }
                if (label && !label.readOnly) {
                    var element = document.getElementById(shape.name + "_" + label.name);
                    nodeBounds = ej.datavisualization.Diagram.Util.bounds(shape);
                    bounds = new ej.datavisualization.Diagram.Rectangle(element.offsetLeft, element.offsetTop, element.offsetWidth, element.offsetHeight);
                    bbox = bounds;
                    curZoomfactor = this._currZoom;
                    var position = ej.datavisualization.Diagram.Util._getLabelPosition(label, nodeBounds);
                    if (shape.segments) {
                        centerX = nodeBounds.x + position.x;
                        centerY = nodeBounds.y + position.y;
                    }
                    else {
                        if (label.horizontalAlignment == "left")
                            position.x += bbox.width / 2;
                        else if (label.horizontalAlignment == "right")
                            position.x -= bbox.width / 2;
                        if (label.verticalAlignment == "top")
                            position.y += bbox.height / 2;
                        else if (label.verticalAlignment == "bottom")
                            position.y -= bbox.height / 2;
                        var diff = ej.Matrix.transform(matrix, position);
                        centerX = shape.offsetX - width / 2 + diff.x;
                        centerY = shape.offsetY - height / 2 + diff.y;
                    }
                    if (bbox.width === 0 || bbox.height === 0) {
                        bbox = ej.datavisualization.Diagram.Util.bounds(shape);
                        if (!shape.shape) {
                            bounds.width = bbox.width < 50 ? 50 : nodeBounds.width * curZoomfactor;
                            bounds.x = (centerX * curZoomfactor - bounds.width / 2 * curZoomfactor) - this._hScrollOffset;
                        }
                        else {
                            bounds.width = bbox.width < 50 ? 50 : (nodeBounds.width * curZoomfactor);
                            bounds.x = (centerX * curZoomfactor - bounds.width / 2) - this._hScrollOffset;
                        }
                        bounds.height = label.fontSize;
                        bounds.y = (centerY * curZoomfactor - bounds.height / 2 * curZoomfactor) - this._vScrollOffset;
                    }
                    else {
                        bounds.x = (centerX * curZoomfactor - (bounds.width / 2 * curZoomfactor)) - this._hScrollOffset;
                        bounds.y = (centerY * curZoomfactor - (bounds.height / 2 * curZoomfactor)) - this._vScrollOffset;
                    }
                    this._boundingBox = bounds;
                    this._createEditBox(label, bounds.x, bounds.y, bounds.width, bounds.height, shape);
                    this._isEditing = true;
                }
            }
        },

        _createEditBox: function (label, x, y, width, height, shape) {
            var nodeBounds = ej.datavisualization.Diagram.Util.bounds(shape);
            var div = document.createElement("div");

            var attr = {
                "id": this.element[0].id + "_editBoxDiv",
                "class": "edit",
                "style": "top:" + y + "px;left:" + x + "px;width:" + width + "px;height:" + height + "px;" +
                    "font-family:" + label.fontFamily + ";font-size:" + label.fontSize + "px;min-width: 50px;min-height:" + label.fontSize + "px;",
            };
            ej.datavisualization.Diagram.Util.attr(div, attr);
            var textBox = document.createElement("textarea");
            attr = {
                "id": this.element[0].id + "_editBox",
                "class": "editBox",
                "style": "font-size:" + label.fontSize + "px;font-family:" + label.fontFamily + ";min-height:" + label.fontSize + "px;line-height:" + label.fontSize + "px;",
                "nodeWidth": nodeBounds.width, "nodeHeight": nodeBounds.height, "fontSize": label.fontSize, "nodeOffsetX": shape.offsetX, "nodeOffsetY": shape.offsetY, "containerName": shape.name
            };
            ej.datavisualization.Diagram.Util.attr(textBox, attr);
            textBox.value = label.text;
            div.appendChild(textBox);
            $(this._canvas).append(div);

            if (label.text !== "") {
                this._updateEditor(null, div, textBox, nodeBounds.width, label.fontSize);
            }
            this._on($(textBox), "focusout", this._editboxfocusout);
            this._on($(textBox), "keyup", this._editBoxKeyUp);
            this._on($(textBox), "input", this._editBoxTextChange);
            textBox.focus();
            textBox.select();
        },

        _editBoxKeyUp: function (evt) {
            this._updateLabelPosition(evt);
        },

        _editBoxTextChange: function (evt) {
            this._updateLabelPosition(evt);
        },

        _updateEditBox: function (x, y) {
            var editBox = document.getElementById(this.element[0].id + "_editBoxDiv");
            if (editBox) {
                editBox.style.left = editBox.offsetLeft - x + "px";
                editBox.style.top = editBox.offsetTop - y + "px";
            }
        },

        _editboxfocusout: function () {
            this._endEdit();
        },

        _updateLabelPosition: function (evt) {
            var minWidth = 50;
            var curZoomfactor = this._currZoom;
            var parentBoundary = this._boundingBox;
            var fontSize = Number(evt.target.getAttribute("fontSize"));
            var nodeWidth = Number(evt.target.getAttribute("nodeWidth"));
            var conCenterX = parentBoundary.x + (parentBoundary.width / 2);
            var conCenterY = parentBoundary.y + (parentBoundary.height / 2);
            var bounds = this._textLength(evt);

            var width;
            if (bounds.width === 0) {
                width = parentBoundary.width < minWidth ? minWidth : parentBoundary.width;
                evt.target.parentNode.style.width = width + "px";
                evt.target.parentNode.style.left = conCenterX - width / 2 + "px";
            }
            else {
                if (bounds.width <= (nodeWidth * curZoomfactor))
                    width = bounds.width < minWidth ? minWidth : bounds.width;
                else
                    width = nodeWidth < minWidth ? minWidth : (nodeWidth * curZoomfactor);
                evt.target.parentNode.style.width = width + "px";
                evt.target.parentNode.style.left = conCenterX - (width / 2) + "px";
            }
            if (bounds.height === 0) {
                evt.target.style.height = fontSize + "px";
                evt.target.parentNode.style.top = conCenterY - fontSize / 2 + 'px';
            }
            else {
                this._updateEditor(evt, evt.target.parentNode, evt.target, nodeWidth, fontSize);
            }
        },

        _updateEditor: function (evt, div, textBox, nodeWidth, fontSize) {
            var offsetX, offsetY;
            var elHeight;
            var bounds = this._textLength(evt);
            var curZoomfactor = this._currZoom;
            var minWidth = 50;
            var x = this._boundingBox.x;
            var y = this._boundingBox.y;
            var width = this._boundingBox.width;
            var height = this._boundingBox.height;

            var str = textBox.value;
            var line = str.split('\n');

            var temp = (nodeWidth * curZoomfactor) < bounds.width ? (nodeWidth * curZoomfactor) : bounds.width;
            var elWidth = temp < minWidth ? minWidth : temp;
            div.style.width = elWidth + "px";
            if (evt)
                offsetX = (elWidth - width) / 2;
            else
                offsetX = (elWidth - width * curZoomfactor) / 2;
            div.style.left = x - offsetX - fontSize / 4 + "px";

            if (line.length > 1 || bounds.width >= nodeWidth) {
                if (ej.browserInfo().name === "mozilla")
                    elHeight = textBox.scrollHeight - 5;
                else
                    elHeight = textBox.scrollHeight - 4;
                textBox.style.height = 'auto';
            }
            else
                elHeight = fontSize;

            textBox.style.height = elHeight + "px";
            if (evt)
                offsetY = (elHeight - height) / 2;
            else
                offsetY = (elHeight - height * curZoomfactor) / 2;
            this._boundingBox = new ej.datavisualization.Diagram.Rectangle(x - offsetX, y - offsetY, elWidth, elHeight);
            div.style.top = y - offsetY - fontSize / 4 + "px";
        },

        _textLength: function (evt) {
            var temp = document.createElement("div");
            var textElement = document.getElementById(this.element[0].id + "_editBox");
            var attr = {
                "id": this.element[0].id + "_editBoxHiddenDiv",
                "style": "position:absolute; width:" + textElement.width + "px;height:" + textElement.height + "px;" +
                         "font-size:" + textElement.style.fontSize + "px;font-family:" + textElement.style.fontFamily + ";padding: 4px;word-wrap: break-word;white-space:pre-wrap;",
            };
            ej.datavisualization.Diagram.Util.attr(temp, attr);
            if (evt) {
                temp.innerHTML = evt.target.value;
            } else {
                temp.innerHTML = textElement.value;
            }
            document.body.appendChild(temp);
            var bounds = temp.getBoundingClientRect();
            document.body.removeChild(temp);
            return bounds;
        },

        _endEdit: function () {
            var args, entry;
            var editBox = document.getElementById(this.element[0].id + "_editBox");
            if (editBox) {
                var shape = this._findNode(editBox.getAttribute("containerName"));;
                if (this.activeTool.name === "textTool")
                    shape = this.activeTool.selectedObject;
                else if (!shape) {
                    for (var i = 0; i < this.selectionList.length; i++) {
                        var mNode = this.selectionList[i];
                        if (typeof mNode.labels.length != "undefined" && mNode.labels.length > 0 && mNode.labels[0].mode === ej.datavisualization.Diagram.LabelEditMode.Edit)
                            shape = this.selectionList[i];
                    }
                }

                if (shape) {
                    this._isEditing = false;
                    if (shape.type == "node" && (!shape.width || !shape.height))
                        this._getNodeDimension(shape, shape.labels[0], editBox.value);
                    args = this._raiseEvent("textChange", { element: shape, value: editBox.value });

                    if (!args) {
                        if (shape && shape.shape !== undefined && shape.shape.type === "text") {
                            var oldText = shape.shape.textBlock.text;
                            shape.shape.textBlock.text = editBox.value;
                            shape.shape.textBlock.mode = ej.datavisualization.Diagram.LabelEditMode.View;
                            if (!this._findNode(shape.name)) {
                                if (editBox.value !== "") {
                                    var height = Number(editBox.style.height.substring(0, editBox.style.height.length - 2));
                                    if (shape.height < height) {
                                        shape.offsetY = (shape.offsetY - (shape.height / 2)) + (height / 2);
                                        shape.height = height;
                                    }
                                    if (this.selectionList.length > 0)
                                        this._clearSelection();
                                    this.add(shape);
                                }
                                this.activeTool.selectedObject = null;
                            } else {
                                ej.datavisualization.Diagram.DiagramContext.update(shape, this);

                                entry = { type: "labelchanged", shape: shape, previousLabelValue: oldText, updatedLabelValue: editBox.value };
                                this.addHistoryEntry(entry);
                                //entry = new ej.datavisualization.Diagram.HistoryEntry(new ej.datavisualization.Diagram.TextChangeCmd(shape, shape.shape.textBlock.text, editBox.value));
                                //this.historyManager.addHistoryEntry(entry);
                            }
                        } else if (shape != undefined && !(shape.type == "pseudoGroup")) {
                            var label;
                            if (this.activeTool.name === "textTool")
                                label = this.activeTool.getLabelUnderMouse();
                            else
                                label = shape.labels[0];
                            if (label != undefined) {
                                if (label.text != editBox.value) {

                                    entry = { type: "labelchanged", shape: shape, previousLabelValue: label.text, updatedLabelValue: editBox.value };
                                    this.addHistoryEntry(entry);
                                    //entry = new ej.datavisualization.Diagram.HistoryEntry(new ej.datavisualization.Diagram.LabelChangeCmd(shape, label.text, editBox.value));
                                    //this.historyManager.addHistoryEntry(entry);
                                }
                                label.text = editBox.value;
                                label.mode = ej.datavisualization.Diagram.LabelEditMode.View;
                                ej.datavisualization.Diagram.DiagramContext.updateLabel(shape, label, this);
                            }
                            else if (shape.labels.length == 0) {
                                label = ej.datavisualization.Diagram.Label();
                                label.text = editBox.value;
                                label.mode = ej.datavisualization.Diagram.LabelEditMode.View;
                                shape.labels.push(label);
                                ej.datavisualization.Diagram.DiagramContext.addNodeLabel(shape, label, null, this);
                            }
                        }
                    }
                }

                this._off($(editBox), "focusout", this._editboxfocusout);
                this._off($(editBox), "keyup", this._editBoxKeyUp);
                this._off($(editBox), "input", this._editBoxTextChange);
                var element = $("#" + this.element[0].id + "_editBoxDiv")[0];
                if (element)
                    element.parentNode.removeChild(element);
            }
        },

        _setLabelEditing: function (label) {
            var success;
            if (label) {
                if (label.readOnly) {
                    label.mode = ej.datavisualization.Diagram.LabelEditMode.View;
                    success = false;
                }
                else {
                    if (this._currentLabel)
                        this._currentLabel.mode = ej.datavisualization.Diagram.LabelEditMode.View;
                    label.mode = ej.datavisualization.Diagram.LabelEditMode.Edit;
                    this._currentLabel = label;
                    success = true;
                }
                return success;
            }
        },

        _isInternalTool: function (tool) {
            if (tool instanceof ej.datavisualization.Diagram.SelectTool || tool instanceof ej.datavisualization.Diagram.ConnectionEditTool || tool instanceof ej.datavisualization.Diagram.MoveTool || tool instanceof ej.datavisualization.Diagram.ResizeTool
                  || tool instanceof ej.datavisualization.Diagram.PhaseTool || tool instanceof ej.datavisualization.Diagram.RotateTool || (tool instanceof ej.datavisualization.Diagram.PanTool && (this.tool() & ej.datavisualization.Diagram.Tool.SingleSelect) && (this.tool() & ej.datavisualization.Diagram.Tool.ZoomPan)))
                return true;
            else
                return false;
        },
        _updateNodeMargin: function (node) {
            if (node.parent != "") {
                var group = this.nameTable[node.parent];
                if (group && group.container && group.container.type == "canvas") {
                    var groupBounds = ej.datavisualization.Diagram.Util.bounds(group);
                    var bounds1 = ej.datavisualization.Diagram.Util.bounds(node);
                    var bounds = ej.datavisualization.Diagram.Geometry.rect([bounds1.topLeft, bounds1.topRight, bounds1.bottomRight, bounds1.bottomLeft]);
                    node.marginLeft = bounds.x - (groupBounds.x + group.paddingLeft);
                    node.marginRight = (groupBounds.x + group.width) - (bounds.x + bounds.width) - group.paddingRight;
                    node.marginTop = bounds.y - (groupBounds.y + group.paddingTop);
                    node.marginBottom = groupBounds.bottom - (bounds.y + bounds.height) - group.paddingBottom;
                }
            }
            if ((node.type == "pseudoGroup" || node.name == "multipleSelection") && node.children.length > 0) {
                var child;
                for (var i = 0; i < node.children.length; i++) {
                    child = this.nameTable[this._getChild(node.children[i])];
                    if (child) {
                        this._updateNodeMargin(child);
                    }
                }
            }
        },
        _translate: function (node, dx, dy, nameTable, isContainer, layout) {
            if (ej.datavisualization.Diagram.Util.canMove(node) || layout) {
                if ((node.type == "group" || node.type == "pseudoGroup") && !layout) {
                    var children = this._getChildren(node.children);
                    for (var i = 0; i < children.length; i++) {
                        var child = this.nameTable[children[i]];
                        if (child && !ej.datavisualization.Diagram.Util.canMove(child)) return;
                    }
                }
                if (!node.segments) {
                    node.offsetX += dx;
                    node.offsetY += dy;
                    if ((node.type == "group" || node.type == "pseudoGroup") && !isContainer) {
                        var nodes = this._getChildren(node.children);
                        var child;
                        for (var i = 0; i < nodes.length; i++) {
                            child = nameTable[nodes[i]];
                            if (child) {
                                this._translate(child, dx, dy, nameTable);
                                if (child.parent && (child.parent != node.name && node.type != "pseudoGroup"))
                                    ej.datavisualization.Diagram.Util._updateGroupBounds(nameTable[child.parent], this);
                            }
                        }
                        if (node.type != "group" && node.container)
                            ej.datavisualization.Diagram.Util._updateGroupBounds(node, this);
                    }
                    this._updateAssociatedConnectorEnds(node, nameTable);
                } else {
                    ej.datavisualization.Diagram.Util._translateLine(node, dx, dy, node);
                    this._dock(node, nameTable);
                    ej.datavisualization.Diagram.Util.updateBridging(node, this);
                    this._updateConnectorBridging(node);
                }
                this._updateQuad(node);
            }
        },
        _translateLabel: function (node, label, dx, dy) {
            label.margin["left"] += dx;
            label.margin["top"] += dy;
            label.margin["right"] -= dx;
            label.margin["bottom"] -= dy;
            if (label.horizontalAlignment == "center") label.margin["right"] = 0;
            if (label.verticalAlignment == "center") label.margin["bottom"] = 0;
            ej.datavisualization.Diagram.DiagramContext.updateLabel(node, label, this);
        },
        _rotate: function (node, angle, nameTable) {
            if (ej.datavisualization.Diagram.Util.canRotate(node)) {
                if (node.type == "group" || node.type == "pseudoGroup") {
                    var children = this._getChildren(node.children);
                    for (var i = 0; i < children.length; i++) {
                        var child = this.nameTable[children[i]];
                        if (child && !child.segments && !ej.datavisualization.Diagram.Util.canRotate(child)) return;
                    }
                }
                if (!node.segments) {
                    node.rotateAngle += angle;
                    node.rotateAngle %= 360;
                    if (node.rotateAngle < 0) node.rotateAngle += 360;
                    if ((node.type == "group" || node.type == "pseudoGroup")) {
                        var matrix = ej.Matrix.identity();
                        var child, pinx, piny;
                        ej.Matrix.rotate(matrix, angle, node.offsetX, node.offsetY);
                        var nodes = this._getChildren(node.children);
                        for (var i = 0; i < nodes.length; i++) {
                            child = nameTable[nodes[i]];
                            if (child) {
                                if (!(child.segments)) {
                                    this._rotate(child, angle, nameTable);
                                    pinx = child.offsetX;
                                    piny = child.offsetY;
                                    var actualpt = ej.Matrix.transform(matrix, ej.datavisualization.Diagram.Point(pinx, piny));
                                    this._translate(child, actualpt.x - pinx, actualpt.y - piny, nameTable);
                                    this._updateAssociatedConnectorEnds(child, nameTable);
                                } else {
                                    if (!child.sourceNode)
                                        this._setEndPoint(child, ej.Matrix.transform(matrix, child.sourcePoint), false);
                                    if (!child.targetNode)
                                        this._setEndPoint(child, ej.Matrix.transform(matrix, child.targetPoint), true);
                                }
                                if (child.parent && (child.parent != node.name && node.type != "pseudoGroup"))
                                    ej.datavisualization.Diagram.Util._updateGroupBounds(nameTable[child.parent], this);
                            }
                        }

                        ej.datavisualization.Diagram.Util._updateGroupBounds(node, this);
                    }
                    if (node.parent) {
                        this._updateParentBounds(node.parent);
                    }
                    this._updateQuad(node);
                    this._updateAssociatedConnectorEnds(node, nameTable);
                }
            }
        },

        scale: function (node, sw, sh, pivot, nameTable, skipScalOnChild, updateMinMax, isHelper) {
            if (!node.container) {
                if (ej.datavisualization.Diagram.Util.canResize(node)) {
                    if (node.type == "group" || node.type == "pseudoGroup") {
                        var children = this._getChildren(node.children);
                        for (var i = 0; i < children.length; i++) {
                            var child = this.nameTable[children[i]];
                            if (!ej.datavisualization.Diagram.Util.canResize(child)) return;
                        }
                    }
                    var matrix = ej.Matrix.identity();
                    if (!node.segments) {
                        if ((node.type == "group" || node.type == "pseudoGroup")) {
                            var nodes = this._getChildren(node.children);
                            var child;
                            for (var i = 0; i < nodes.length; i++) {
                                child = nameTable[nodes[i]];
                                if (child) {
                                    this.scale(child, sw, sh, pivot, nameTable);
                                    if (child.parent && (child.parent != node.name && node.type != "pseudoGroup"))
                                        ej.datavisualization.Diagram.Util._updateGroupBounds(nameTable[child.parent], this);
                                }
                            }

                            if (node.children.length <= 0) {
                                ej.Matrix.rotate(matrix, -node.rotateAngle, pivot.x, pivot.y);
                                ej.Matrix.scale(matrix, sw, sh, pivot.x, pivot.y);
                                ej.Matrix.rotate(matrix, node.rotateAngle, pivot.x, pivot.y);
                                var newPosition = ej.Matrix.transform(matrix, ej.datavisualization.Diagram.Point(node.offsetX, node.offsetY));
                                var width = node.width * sw;
                                var height = node.height * sh;
                                if (width > 1) {
                                    node.width = width;
                                    node.offsetX = newPosition.x;
                                }
                                if (height > 1) {
                                    node.height = height;
                                    node.offsetY = newPosition.y;
                                }
                            }
                            ej.datavisualization.Diagram.Util._updateGroupBounds(node, this);

                        } else {
                            ej.Matrix.rotate(matrix, -node.rotateAngle, pivot.x, pivot.y);
                            ej.Matrix.scale(matrix, sw, sh, pivot.x, pivot.y);
                            ej.Matrix.rotate(matrix, node.rotateAngle, pivot.x, pivot.y);
                            var newPosition = ej.Matrix.transform(matrix, ej.datavisualization.Diagram.Point(node.offsetX, node.offsetY));
                            var width = node.width * sw;
                            var height = node.height * sh;
                            if (width > 1) {
                                node.width = width;
                                node.offsetX = newPosition.x;
                            }
                            if (height > 1) {
                                node.height = height;
                                node.offsetY = newPosition.y;
                            }
                        }
                        if (node.parent) {
                            this._updateParentBounds(node.parent);
                        }
                        this._updateAssociatedConnectorEnds(node, nameTable);
                    } else {
                        ej.Matrix.scale(matrix, sw, sh, pivot.x, pivot.y);
                        for (var i = 0; i < node.segments.length; i++) {
                            var segment = node.segments[i];
                            for (var j = 0; j < segment.points.length; j++) {
                                segment.points[j] = ej.Matrix.transform(matrix, segment.points[j]);
                                if (i == 0 && j == 0 && !node.sourceNode) {
                                    segment._startPoint = segment.points[0];
                                    segment._endPoint = segment.points[segment.points.length - 1];
                                    ej.datavisualization.Diagram.Util._setLineEndPoint(node, ej.Matrix.transform(matrix, node.sourcePoint), false);
                                }
                                if (i == node.segments.length - 1 && j == segment.points.length - 1 && !node.targetNode) {
                                    segment._startPoint = segment.points[0];
                                    segment._endPoint = segment.points[segment.points.length - 1];
                                    node.targetPoint = segment._endPoint;
                                    //ej.datavisualization.Diagram.Util._setLineEndPoint(node, ej.Matrix.transform(matrix, node.targetPoint), true);
                                }
                            }
                            segment._startPoint = segment.points[0];
                            segment._endPoint = segment.points[segment.points.length - 1];
                            if (segment.type == "orthogonal") {
                                if (segment.length || segment.length === 0)
                                    segment.length = segment._length = ej.datavisualization.Diagram.Geometry.distance(segment._startPoint, segment._endPoint);
                                else
                                    ej.datavisualization.Diagram.Util._addOrthogonalPoints(segment, node.segments[i - 1], node.segments[i + 1], node.sourcePoint, node.targetPoint);
                            } else {
                                segment.point = segment._endPoint;
                            }

                        }
                        if (node.sourceNode || node.targetNode)
                            this._dock(node, nameTable);
                    }
                    this._updateQuad(node);
                }
            }
            else {
                switch (node.container.type) {
                    case "canvas":
                        var newSize = {};
                        var matrix = ej.Matrix.identity();
                        ej.Matrix.rotate(matrix, -node.rotateAngle, pivot.x, pivot.y);
                        ej.Matrix.scale(matrix, sw, sh, pivot.x, pivot.y);
                        ej.Matrix.rotate(matrix, node.rotateAngle, pivot.x, pivot.y);
                        newPosition = ej.Matrix.transform(matrix, ej.datavisualization.Diagram.Point(node.offsetX, node.offsetY));
                        width = node.width * sw;
                        height = node.height * sh;

                        if (updateMinMax) {
                            node.minHeight = height;
                            node.minWidth = width;
                        }
                        if (isHelper != true)
                            newSize = this._getMinMaxSize(node, width, height);
                        else {
                            newSize.width = width;
                            newSize.height = height;

                        }
                        if (newSize && newSize.width > 1) {
                            var x = node.offsetX - node.width / 2;
                            node.width = newSize.width;
                            node.offsetX = x + node.width / 2;
                        }
                        if (newSize && newSize.height > 1) {
                            var y = node.offsetY - node.height / 2;
                            node.height = newSize.height;
                            node.offsetY = y + node.height / 2;
                        }
                        if (!skipScalOnChild)
                            ej.datavisualization.Diagram.SvgContext._alignOnCanvas1(node, this, true);
                        break;
                    case "stack":
                        var matrix = ej.Matrix.identity();
                        ej.Matrix.rotate(matrix, -node.rotateAngle, pivot.x, pivot.y);
                        ej.Matrix.scale(matrix, sw, sh, pivot.x, pivot.y);
                        ej.Matrix.rotate(matrix, node.rotateAngle, pivot.x, pivot.y);
                        newPosition = ej.Matrix.transform(matrix, ej.datavisualization.Diagram.Point(node.offsetX, node.offsetY));
                        width = (node.width * sw) - (node.marginLeft + node.marginRight);
                        height = (node.height * sh) - (node.marginTop + node.marginBottom);


                        newSize = this._getMinMaxSize(node, width, height);
                        if (newSize.width > 1) {
                            x = node.offsetX - node.width / 2;
                            node.width = newSize.width - node.marginLeft;
                            node.offsetX = x + node.width / 2 + (node.marginLeft);
                        }
                        if (newSize.height > 1) {
                            y = node.offsetY - node.height / 2;
                            node.height = newSize.height - node.marginTop;
                            node.offsetY = y + node.height / 2 + (node.marginTop);
                        }
                        ej.datavisualization.Diagram.SvgContext._alignOnStack(node, this);
                        break;
                }
            }
            ej.datavisualization.Diagram.DiagramContext.update(node, this);
        },
        _updateParentBounds: function (node) {
            node = this.nameTable[this._getChild(node)];
            if (node && !node.container) {
                ej.datavisualization.Diagram.Util._updateGroupBounds(node, this);
                ej.datavisualization.Diagram.DiagramContext.update(node, this);
                if (node.parent) {
                    this._updateParentBounds(node.parent);
                }
            }
        },
        _dock: function (connector, nameTable, updateSelection) {
            var length = connector.segments.length;
            var srcPointslength = connector.segments[0].points.length;
            var targetPointslength = connector.segments[connector.segments.length - 1].points.length;
            ej.datavisualization.Diagram.Util.dock(connector, nameTable);
            if (length != connector.segments.length && this._svg) {
                ej.datavisualization.Diagram.Util._updateConnectorSegments(connector, connector.sourcePort, connector.targetPort, this);
                ej.datavisualization.Diagram.DiagramContext._refreshSegments(connector, this);
            }
            if (this.selectionList[0] == connector) {
                if (updateSelection || srcPointslength != connector.segments[0].points.length || targetPointslength != connector.segments[connector.segments.length - 1].points.length) {
                    ej.datavisualization.Diagram.SvgContext._refreshEndPointHandles(this.selectionList[0], this._svg, this._currZoom);
                }
            }
            this._updateQuad(connector);
        },

        _setEndPoint: function (connector, point, isTarget) {
            ej.datavisualization.Diagram.Util._setLineEndPoint(connector, point, isTarget);
            this._updateQuad(connector);
        },

        _updateAssociatedConnectorEnds: function (node, nameTable) {
            var i, len;
            var connector;
            for (i = 0, len = node.inEdges.length; i < len; i++) {
                connector = nameTable[node.inEdges[i]];
                if (connector)
                    this._dock(connector, nameTable);
            }
            for (i = 0, len = node.outEdges.length; i < len; i++) {
                connector = nameTable[node.outEdges[i]];
                if (connector)
                    this._dock(connector, nameTable);
            }
        },
        _updateChildBounds: function (node, nameTable) {
            var offX, offY;
            if (node.width == 0 && node.height == 0) {
                offX = node.offsetX;
                offY = node.offsetY;
                ej.datavisualization.Diagram.Util._updateGroupBounds(node, this);
                this._translate(node, offX - node.offsetX, offY - node.offsetY, nameTable);
            }
            else {
                offX = node.offsetX;
                offY = node.offsetY;
                var childBounds = ej.datavisualization.Diagram.Util._getChildrenBounds(node, this);
                node.offsetX = (childBounds.x + childBounds.width / 2);
                node.offsetY = (childBounds.y + childBounds.height / 2);
                var dx = offX - node.offsetX;
                var dy = offX - node.offsetY;
                this._translate(node, dx, dy, nameTable);
                var deltaWidth = node.width / childBounds.width;
                var deltaHeight = node.height / childBounds.height;
                this._scale(node, deltaWidth, deltaHeight, node.pivot, nameTable);;
                this._translate(node, offX - node.offsetX, offY - node.offsetY, nameTable);
            }
        },
        _updateQuad: function (object) {
            if (this._spatialSearch && this._spatialSearch.quadTable[object.name])
                if (object.segments || object.shape)
                    ej.datavisualization.Diagram.SpatialUtil._updateQuad(this, this._spatialSearch, object);
        }
        //#endregion
    });
    ej.datavisualization.Diagram.Locale = {};
    ej.datavisualization.Diagram.Locale["en-US"] = {
        cut: "Cut",
        copy: "Copy",
        paste: "Paste",
        undo: "Undo",
        redo: "Redo",
        selectAll: "SelectAll",
        grouping: "Grouping",
        group: "Group",
        ungroup: "Ungroup",
        order: "Order",
        bringToFront: "BringToFront",
        moveForward: "MoveForward",
        sendBackward: "SendBackward",
        sendToBack: "SendToBack"
    }

    $.fn.pinchDiagram = function (rootgroup, map) {

        var startTouches = [],

        handleTouchStart = function (evt) {
            var touches = evt.touches;
            if (touches.length >= 2) {
                for (var i = 0; i < touches.length; i++) {
                    var touch = touches[i]
                      , found = false;
                    for (var j = 0; j < startTouches.length; j++) {
                        var startTouch = startTouches[j];
                        if (touch.identifier === startTouch.identifier) {
                            found = true;
                            break;
                        }
                    }
                    if (!found) {
                        var touchCopy = $.extend({}, touch);
                        startTouches.push(touchCopy);
                    }
                }
            }

            evt.preventDefault();
        },
        getDistance = function (touch1, touch2) {
            var x = touch2.pageX - touch1.pageX,
                y = touch2.pageY - touch1.pageY;
            return Math.sqrt((x * x) + (y * y));
        },

        handleTouchEnd = function (evt) {
            var changedTouches = evt.changedTouches;
            for (var i = 0; i < changedTouches.length; i++) {
                var changedTouch = changedTouches[i];
                for (var j = 0; j < startTouches.length; j++) {
                    var startTouch = startTouches[j];
                    if (startTouch.identifier === changedTouch.identifier) {
                        var idx = startTouches.indexOf(startTouch);
                        startTouches.splice(idx, 1);
                    }
                }
            }
            evt.preventDefault();
        },

        updateTouch = function (dstTouch, srcTouch) {
            dstTouch.pageX = srcTouch.pageX;
            dstTouch.pageY = srcTouch.pageY;
        },

        handleTouchMove = function (evt) {
            evt.preventDefault();
            var touches = evt.touches, z;
            if (touches.length >= 2) {
                var touch0 = touches[0]
                  , touch1 = touches[1]
                  , startTouch0 = startTouches[0]
                  , startTouch1 = startTouches[1];
                z = getDistance(touch0, touch1) / getDistance(startTouch0, startTouch1);
                var focusPoint = map._mousePosition(evt, false);
                ej.datavisualization.Diagram.ZoomUtil.zoomPan(map, z, 0, 0, focusPoint, true, true);
                updateTouch(startTouch0, touch0);
                updateTouch(startTouch1, touch1);
            }
        };
        this[0].addEventListener('touchstart', handleTouchStart, false);
        this[0].addEventListener('touchend', handleTouchEnd, false);
        this[0].addEventListener('touchmove', handleTouchMove, false);


    };
    //#endregion

})(jQuery, Syncfusion);