﻿/**
* @fileOverview Plugin to style the Html Chart elements
* @copyright Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/

(function ($, ej) {
    /**
     * @class ejChart
     * @requires jQuery.js
     * @requires ej.core.js
     * @requires ej.data.js
     * @requires ej.chart.js
     * @requires jQuery.globalize.js
     * @classdesc The chart can be easily configured to the DOM element, such as div. you can create a grid with a highly customizable look and feel.
     * @example 
     * &lt;div id="container"&gt;&lt;/div&gt; <br> 
     * &lt;script&gt;
     * // Create Chart
     * $('#container').ejChart(); 	
     * &lt;/script&gt;
     */

    ej.widget("ejChart", "ej.datavisualization.Chart", /** @lends ejChart# */{

        // widget element will be automatically set in this
        element: null,

        // user defined model will be automatically set in this
        model: null,

        validTags: ["div"],

        // default model
        defaults: /** @lends ejChart# */ {
            /**		
			* Options for customizing the color, opacity and width of the border of chart.
			* @type {object}
			*/
            border: /** @lends ejChart# */ {
                /**		
			* Specifies the border color of the chart.
            * @default null
			* @type {string}
			* @example  				
			* &lt;div id="container"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#container").ejChart({
            *    border: { color: "green" }                      
            * });
            * &lt;/script&gt;                
			* @alias ejChart#border->color
			*/
                color: 'transparent',
                /**		
			* Specifies the border width of the chart.
			* @default 0
			* @type {number}		 
			* @example 
			* &lt;div id="container"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#container").ejChart({
            *    border: { width: 2 }                      
            * });
            * &lt;/script&gt; 
		    * @alias ejChart#border->width
			*/
                width: 0,
                /**		
			* Specifies the border opacity of the chart
			* @default 0.3
			* @type {number}			
			* @example 
			* &lt;div id="container"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#container").ejChart({
            *    border: { opacity: 0.5 }                      
            * });
            * &lt;/script&gt; 
			 * @alias ejChart#border->opacity
			*/
                opacity: 0.3
            },
            /**		
			* Specifies options for configuring the border and background for chart plotting area.
			* @type {object}
			*/
            chartArea: /** @lends ejChart# */
            {
                /**		
			* Options for customizing the color, opacity and width of the border of chart plotting area.
			* @type {object}
			 * @alias ejChart#chartArea->border
			*/
                border: {
                    /**		
          * Specifies the border color of chart plotting area.
          * @default Gray
          * @type {string}				
          * @example 
          * &lt;div id="container"&gt;&lt;/div&gt; 
          * &lt;script&gt;
          * $("#container").ejChart({
          *    chartArea: { border: { color :"green"} }                      
          * });
          * &lt;/script&gt; 
          * @alias ejChart#chartArea->border->color
          */
                    color: 'Gray',
                    /**		
          * Specifies the border width of chart plotting area.
          * @default 0.5
          * @type {number}
          * @example 
          * &lt;div id="container"&gt;&lt;/div&gt; 
          * &lt;script&gt;
          * $("#container").ejChart({
          *     chartArea: { border: { width : 0.2} }                      
          * });
          * &lt;/script&gt; 
          * @alias ejChart#chartArea->border->width
          */
                    width: 0.5,
                    /**		
          * Specifies the border opacity of chart plotting area.
          * @default 0.3
          * @type {number}	
          * @example 
          * &lt;div id="container"&gt;&lt;/div&gt; 
          * &lt;script&gt;
          * $("#container").ejChart({
          *     chartArea: { border: { opacity : 0.5} }                      
          * });
          * &lt;/script&gt; 
          * @alias ejChart#chartArea->border->opacity
          */
                    opacity: 0.3
                },
                /**		
           * Specifies the background for chart plotting area.
           * @default transparent
           * @type {string}				
           * @example 
           * &lt;div id="container"&gt;&lt;/div&gt; 
           * &lt;script&gt;
           * $("#container").ejChart({
           *     chartArea: { background : "white" }                      
           * });
           * &lt;/script&gt; 
           * @alias ejChart#chartArea->background
           */
                background: 'transparent'

            },
            /**		
			* This is a horizontal axis which contains options to configure axis. This is the primary x axis for all the series in series array. If you need to override x axis for particular series, you can create an axis object by providing unique name using name property and add it to axes array. Then, assign the name to the series’s xAxisName property to link both axis and series.
			* @type {object}
			*/
            primaryXAxis: /** @lends ejChart# */
     {
         /**		
* Specifies the position of the axis labels.
* @default "outside"
* @type {enum}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryXAxis: { labelPosition : "inside" }                       
      * });
      * &lt;/script&gt; 
 * @alias ejChart#primaryXAxis->labelPosition
*/
         labelPosition: 'outside',
		  /**		
* Specifies the position of the axis tick lines.
* @default "outside"
* @type {enum}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryXAxis: { tickLinesPosition : "inside" }                       
      * });
      * &lt;/script&gt; 
 * @alias ejChart#primaryXAxis->tickLinesPosition
*/
         tickLinesPosition: 'outside',
     /**		
    * This is a horizontal axis alternate grid band which contains options to highlight alternate grid bands.
    * @type {object}
  * @alias ejChart#primaryXAxis->alternateGridBand
  */
 alternateGridBand:
            {
/**		
* Specifies the Odd Alternative Grid Band.
* @type {object}
  * @alias ejChart#primaryXAxis->alternateGridBand->odd
  */
  odd: {
/**		
* Specifies the fill color of Odd grid bands
* @default transparent
* @type {string}				     
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryXAxis: { alternateGridBand: { odd :{ fill : "red" } } }                      
      * });
      * &lt;/script&gt; 
 * @alias ejChart#primaryXAxis->alternateGridBand->odd->fill
*/
                    fill: "transparent",
                    /**		
* Specifies the opacity of the Odd grid band.
* @default 1
* @type {number}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryXAxis: { alternateGridBand: { odd :{ opacity : 0.5 } } }                      
      * });
      * &lt;/script&gt; 
 * @alias ejChart#primaryXAxis->alternateGridBand->odd->opacity
*/
                    opacity: 1
                },
/**		
* Specifies the Even Alternative Grid Band.
* @type {object}
 * @alias ejChart#primaryXAxis->alternateGridBand->even
  */
                even: {
                    /**		
* Specifies the fill color of Even grid bands
* @default transparent
* @type {string}				     
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryXAxis: { alternateGridBand: { even :{ fill : "green" } } }                    
      * });
      * &lt;/script&gt; 
 * @alias ejChart#primaryXAxis->alternateGridBand->even->fill
*/

                    fill: "transparent",
                    /**		
* Specifies the opacity of the Even grid band.
* @default 1
* @type {number}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryXAxis: { alternateGridBand: { even :{ opacity : 0.5 } } }                   
      * });
      * &lt;/script&gt; 
 * @alias ejChart#primaryXAxis->alternateGridBand->even->opacity
*/
                    opacity: 1
                }
            },
			 /**		
     * Options for configuring major grid lines color, width, dash arrays etc., 
     * @type {object}
     * @alias ejChart#primaryXAxis->majorGridLines
     */
         majorGridLines:
{
    /**		
* Specifies the width of the major grid lines.
* @default 1
* @type {number}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
 * &lt;script&gt;
 * $("#container").ejChart({
 *     primaryXAxis: { majorGridLines: { width : 0.5} }                      
 * });
 * &lt;/script&gt; 
 * @alias ejChart#primaryXAxis->majorGridLines->width
*/
    width: 1,
    /**		
* Controls the pattern of dashes and gaps used to stroke the major grid lines.
* @default null
* @type {string}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
 * &lt;script&gt;
 * $("#container").ejChart({
 *     primaryXAxis: { majorGridLines: { dashArray : "2,3"} }                      
 * });
 * &lt;/script&gt; 
 * @alias ejChart#primaryXAxis->majorGridLines->dashArray
*/
    dashArray: "",
    /**		
* Specifies the visibility of the major grid lines.
* @default true
* @type {boolean}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* primaryXAxis: { majorGridLines: { visible: false } }                      
* });
* &lt;/script&gt; 
* @alias ejChart#primaryXAxis->majorGridLines->visible
*/
    visible: true,
    /**		
* Specifies the opacity of the major grid lines.
* @default 1
* @type {number}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* primaryXAxis: { majorGridLines: { opacity: 0.5 } }                      
* });
* &lt;/script&gt; 
* @alias ejChart#primaryXAxis->majorGridLines->opacity
*/
    opacity: 1

},
         /**		
     * Options for configuring major tick lines color, width, dash arrays etc.,
     * @type {object}
 * @alias ejChart#primaryXAxis->majorTickLines
     */
         majorTickLines:
 {
     /**		
* Specifies the width of the major tick lines.
* @default 1
* @type {number}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* primaryXAxis: { majorTickLines: { width: 2 } }                      
* });
* &lt;/script&gt; 
 * @alias ejChart#primaryXAxis->majorTickLines->width
*/
     width: 1,
     /**		
* Length of the major tick lines.
* @default 5
* @type {number}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* primaryXAxis: { majorTickLines: { size: 2 } }                      
* });
* &lt;/script&gt; 
* @alias ejChart#primaryXAxis->majorTickLines->size
*/
     size: 5,
     /**		
* Specifies the visibility of the major tick lines.
* @default true
* @type {boolean}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* primaryXAxis: { majorTickLines: { visible: false } }                      
* });
* &lt;/script&gt;  
 * @alias ejChart#primaryXAxis->majorTickLines->visible
*/
     visible: true
 },
         /**		
     * Options for configuring minor grid lines color, width, dash arrays etc., 
     * @type {object}
      * @alias ejChart#primaryXAxis->minorGridLines
     */
         minorGridLines:
 {
     /**		
* Specifies the width of the minorGridLines.
* @default 1
* @type {number}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* primaryXAxis: { minorGridLines: { width: 2 } }                      
* });
* &lt;/script&gt;  
* @alias ejChart#primaryXAxis->minorGridLines->width
*/
     width: 1,
     /**		
* Controls the pattern of dashes and gaps used to stroke the minor grid lines.
* @default null
* @type {string}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* primaryXAxis: { minorGridLines: { dashArray: "2,3" } }                      
* });
* &lt;/script&gt;
* @alias ejChart#primaryXAxis->minorGridLines->dashArray
*/
     dashArray: "",
     /**		
* Specifies the visibility of the minorGridLines. The user can modify the visibility of the minorGridLines in primaryXAxis.
* @default false
* @type {boolean}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* primaryXAxis: { minorGridLines: { visible: true } }                      
* });
* &lt;/script&gt; 
* @alias ejChart#primaryXAxis->minorGridLines->visible
*/
     visible: true

 },
         /**		
     * Options for configuring minor tick lines color, width, dash arrays etc,.
     * @type {object}
     * @alias ejChart#primaryXAxis->minorTickLines
     */
         minorTickLines:
{
    /**		
* Specifies the width of the minor tick lines.
* @default 1
* @type {number}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* primaryXAxis: { minorTickLines: { width: 2 } }                      
* });
* &lt;/script&gt; 
* @alias ejChart#primaryXAxis->minorTickLines->width
*/
    width: 1,
    /**		
* Length of the minor tick lines.
* @default 5
* @type {number}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* primaryXAxis: { minorTickLines: { size: 2 } }                      
* });
* &lt;/script&gt; 
* @alias ejChart#primaryXAxis->minorTickLines->size
*/
    size: 5,
    /**		
* Specifies the visibility of the minor tick lines.
* @default false
* @type {boolean}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* primaryXAxis: { minorTickLines: { visible: true } }                      
* });
* &lt;/script&gt; 
* @alias ejChart#primaryXAxis->minorTickLines->visible
*/
    visible: true
},
         /**		
      * Specifies the number of minor ticks to render per major tick/interval.
      * @default null
      * @type {number}			
      * @example 
      * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryXAxis: { minorTicksPerInterval: 5 }                      
      * });
      * &lt;/script&gt; 
      * @alias ejChart#primaryXAxis->minorTicksPerInterval
      */
         minorTicksPerInterval: null,
         /**		
     * Index of the column object in columnDefinitions array to which this axis is associated with.
     * @default null
     * @type {number}			
     * @example 
     * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryXAxis: { columnIndex: 2 }                      
      * });
      * &lt;/script&gt; 
     * @alias ejChart#primaryXAxis->columnIndex
     */
         columnIndex: null,
         /**		
      * An axis can be spanned along multiple columns or plotting areas. This property specifies the number of columns/plotting areas this axis should be spanned.
      * @default null
      * @type {number}			
      * @example 
      * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryXAxis: { columnSpan: 2 }                      
      * });
      * &lt;/script&gt; 
      * @alias ejChart#primaryXAxis->columnSpan
      */
         columnSpan: null,
         /**		
      * Rotates the axis labels by the specified angle. Angle must be given in degrees.
      * @default null
      * @type {number}			
      * @example 
      * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryXAxis: { labelRoatation: 90 }                      
      * });
      * &lt;/script&gt; 
      * @alias ejChart#primaryXAxis->labelRotation
      */
         labelRotation: null,
         /**		
     * You can plot any type of data like date time, double, string etc., This property determines the type of data that this axis will handle. See {@link ValueType}
     * @default null
     * @type {enum}			
     * @example 
      * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryXAxis: { valueType: "double" }                      
      * });
      * &lt;/script&gt;  
     * @alias ejChart#primaryXAxis->valueType
     */
         valueType: null,
         /**		
       * Unique name of the axis.
       * @default null
       * @type {string}			
       * @example 
       * &lt;div id="container"&gt;&lt;/div&gt; 
       * &lt;script&gt;
       * $("#container").ejChart({
       * primaryXAxis: { name: "xAxis" }                      
       * });
       * &lt;/script&gt;  
       * @alias ejChart#primaryXAxis->name
       */
         name: null,
         /**		
      * Provides the format for axis labels.
      * @default null
      * @type {string}				
      * @example 
       * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryXAxis: { labelFormat: "{value}%" }                      
      * });
      * &lt;/script&gt; 
      * @alias ejChart#primaryXAxis->labelFormat
      */
         labelFormat: null,
         /**		
     * Specifies the desired number of intervals for the range. With this setting, you can request axis to calculate nice numbers such that they result in the number of intervals approximately equal to your desired interval.
     * @default null
     * @type {number}				
     * @example 
      * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryXAxis: { desiredIntervals: 5 }                      
      * });
      * &lt;/script&gt; 
     * @alias ejChart#primaryXAxis->desiredIntervals
     */
         desiredIntervals: null,
         /**		
      * Specifies whether the type of the interval calculated is in days, months, hours, minutes etc., This is applicable only when valueType is ‘datetime’. See {@link IntervalType}
      * @default null
      * @type {enum}			
      * @example 
       * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryXAxis: { intervalType: "days" }                      
      * });
      * &lt;/script&gt; 
       * @alias ejChart#primaryXAxis->intervalType
      */
         intervalType: null,
         /**		
      * Rounds the axis labels to the specified number of decimals.
      * @default null
      * @type {number}				
      * @example 
       * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryXAxis: { roundingPlaces: 3 }                      
      * });
      * &lt;/script&gt;  
        * @alias ejChart#primaryXAxis->roundingPlaces
      */
         roundingPlaces: null,
         /**		
      * Specifies the logarithmic base value. This is applicable only when valueType is logarithmic.
      * @default 10
      * @type {number}			
      * @example 
      * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryXAxis: { logBase: 5 }                      
      * });
      * &lt;/script&gt; 
       * @alias ejChart#primaryXAxis->logBase
      */
         logBase: 10,
         /**		
      * Horizontal/vertical padding for the plotting area based on the orientation of the axis.
      * @default 10
      * @type {number}			
      * @example 
      * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryXAxis: { plotOffset: 0 }                      
      * });
      * &lt;/script&gt; 
      * @alias ejChart#primaryXAxis->plotOffset
      */
         plotOffset: 0,
         labels: [],
         /**		
             * Options to configure stripLine’s color, text, border etc.,
             * @name ejChart#primaryXAxis->stripLine 
             * @default [ ]
             * @type {array}
             */
         stripLine: [
                {
                    /**		
     * Specifies the visibility of the stripLine.
     * @default false
     * @type {boolean}			
     * @example 
     * &lt;div id="container"&gt;&lt;/div&gt; 
     * &lt;script&gt;
     * $("#container").ejChart({
     * primaryXAxis: { stripLine:[{ visible : true }]}                      
     * });
     * &lt;/script&gt; 
     * @alias ejChart#primaryXAxis->stripLine->visible
     */
                    visible: false,
                    /**		
   * Indicates whether to render the stripLine from the minimum/start value of the axis.
   * @default false
   * @type {boolean}			
   * @example 
   * &lt;div id="container"&gt;&lt;/div&gt; 
   * &lt;script&gt;
   * $("#container").ejChart({
   * primaryXAxis: { stripLine:[{ startFromAxis : true }]}                      
   * });
   * &lt;/script&gt; 
   * @alias ejChart#primaryXAxis->stripLine->startFromAxis
   */
                    startFromAxis: false,
                    /**		
   * Text to be displayed inside the stripLine.
   * @default "stripLine"
   * @type {string}			
   * @example 
   * &lt;div id="container"&gt;&lt;/div&gt; 
   * &lt;script&gt;
   * $("#container").ejChart({
   * primaryXAxis: { stripLine:[{ text : "Empty Point" }]}                      
   * });
   * &lt;/script&gt; 
   * @alias ejChart#primaryXAxis->stripLine->text
   */
                    text: "stripLine",
                    /**		
   * Alignment of the text displayed in stripLine. See {@link TextAlignment}
   * @default "middlecenter"
   * @type {enum}			
   * @example 
   * &lt;div id="container"&gt;&lt;/div&gt; 
   * &lt;script&gt;
   * $("#container").ejChart({
   * primaryXAxis: { stripLine:[{ textAlignment : "middletop" }]}                      
   * });
   * &lt;/script&gt; 
   * @alias ejChart#primaryXAxis->stripLine->textAlignment
   */
                    textAlignment: "middlecenter",
                    /**		
    * Specifies the font of stripLine in primaryXAxis. These are font properties for stripLine text
    * @type {object}
    * @alias ejChart#primaryXAxis->stripLine->font
    */
                    font: {
                        /**		
  * Specifies the fontFamily of stripLine in primaryXAxis. Stripline text render with this fontFamily
  * @default "middlecenter"
  * @type {enum}			
  * @example 
  * &lt;div id="container"&gt;&lt;/div&gt; 
  * &lt;script&gt;
  * $("#container").ejChart({
  * primaryXAxis: { stripLine:[{ font : { fontFamily : "Algerian"} }]}                      
  * });
  * &lt;/script&gt; 
  * @alias ejChart#primaryXAxis->stripLine->font->fontFamily
  */
                        fontFamily: 'Segoe UI',
                        /**		
 * Specifies the fontStyle of stripLine in primaryXAxis. Stripline text render with this fontStyle. See {@link FontStyle}
 * @default "Normal"
 * @type {enum}			
 * @example 
 * &lt;div id="container"&gt;&lt;/div&gt; 
 * &lt;script&gt;
 * $("#container").ejChart({
 * primaryXAxis: { stripLine:[{ font : { fontStyle: "Bold"} }]}                      
 * });
 * &lt;/script&gt; 
 * @alias ejChart#primaryXAxis->stripLine->font->fontStyle
 */
                        fontStyle: 'Normal',
                        /**		
 * Specifies the size of stripLine in primaryXAxis. Stripline text render with this size
 * @default "12px"
 * @type {string}			
 * @example 
 * &lt;div id="container"&gt;&lt;/div&gt; 
 * &lt;script&gt;
 * $("#container").ejChart({
 * primaryXAxis: { stripLine:[{ font : { size: "15px"} }]}                      
 * });
 * &lt;/script&gt; 
 * @alias ejChart#primaryXAxis->stripLine->font->size
 */
                        size: '12px',
                        /**		
 * Specifies the fontWeight of stripLine in primaryXAxis. Stripline text render with this fontWeight
 * @default "regular"
 * @type {string}			
 * @example 
 * &lt;div id="container"&gt;&lt;/div&gt; 
 * &lt;script&gt;
 * $("#container").ejChart({
 * primaryXAxis: { stripLine:[{ font : { fontWeight: "lighter"} }]}                      
 * });
 * &lt;/script&gt; 
 * @alias ejChart#primaryXAxis->stripLine->font->fontWeight
 */
                        fontWeight: 'Regular',
                        /**		
* Specifies the color of stripLine in primaryXAxis. Stripline text render with this color
* @default "black"
* @type {string}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* primaryXAxis: { stripLine:[{ font : { color: "green"} }]}                      
* });
* &lt;/script&gt; 
* @alias ejChart#primaryXAxis->stripLine->font->color
*/
                        color: 'black',
                        /**		
* Specifies the opacity of stripLine in primaryXAxis. Stripline text render with this opacity
* @default 1
* @type {number}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* primaryXAxis: { stripLine:[{ font : { opacity: 0.5} }]}                      
* });
* &lt;/script&gt; 
* @alias ejChart#primaryXAxis->stripLine->font->opacity
*/
                        opacity: 1
                    },
                    /**		
* Specifies the start value of the stripLine.
* @default null
* @type {number}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* primaryXAxis: { stripLine:[{ start: 2 }]}                      
* });
* &lt;/script&gt; 
* @alias ejChart#primaryXAxis->stripLine->start
*/
                    start: null,
                    /**		
* Specifies the end value of the stripLine.
* @default null
* @type {number}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* primaryXAxis: { stripLine:[{ end: 5 }]}                      
* });
* &lt;/script&gt; 
* @alias ejChart#primaryXAxis->stripLine->end
*/
                    end: null,
                    /**		
* Background color of the stripLine.
* @default "gray"
* @type {string}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* primaryXAxis: { stripLine:[{ color: "green" }]}                      
* });
* &lt;/script&gt; 
* @alias ejChart#primaryXAxis->stripLine->color
*/
                    color: 'gray',
                    /**		
* Border color of the stripLine.
* @default "gray"
* @type {string}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* primaryXAxis: { stripLine:[{ borderColor: "green" }]}                      
* });
* &lt;/script&gt; 
* @alias ejChart#primaryXAxis->stripLine->borderColor
*/
                    borderColor: 'black',
                    /**		
* Specifies the z order position of the stripLine.
* @default "over"
* @type {enum}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* primaryXAxis: { stripLine:[{ zIndex: "behind" }]}                      
* });
* &lt;/script&gt; 
* @alias ejChart#primaryXAxis->stripLine->zIndex
*/
                    zIndex: 'over'
                }
         ],
         /**		
    * Contains property to customize the title in chart.
    * @type {object}
      * @alias ejChart#primaryXAxis->title
    */
         title:
 {

     /**		
   * The value of the title of chart can be specified using this property.
   * @default ""
   * @type {string}				
   * @example 
    * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryXAxis: { title: { text: "Year" } }                      
      * });
      * &lt;/script&gt; 
     * @alias ejChart#primaryXAxis->title->text
   */
     text: "",
     /**		
* Specifies the font. These font properties are customization are applied for title text. 
* @type {object}
 * @alias ejChart#primaryXAxis->title->font
*/
     font:
{
    /**		
  * Specifies the title fontfamily of primaryXAxis. This fontFamily is applied to the title text of primaryXAxis.
  * @default "Segoe UI"
  * @type {string}			 
  * @example 
   * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryXAxis: { title: { font : { fontFamily : "Algerain"} } }                      
      * });
      * &lt;/script&gt;  
  * @alias ejChart#primaryXAxis->title->font->fontFamily
  */
    fontFamily: 'Segoe UI',
    /**		
    * Specifies the title fontStyle of primaryXAxis. This fontStyle is applied to the title text of primaryXAxis.
    * @default ej.datavisualization.Chart.FontStyle.Normal
    * @type {enum}				 
    * @example 
    * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryXAxis: { title: { font : { fontStyle : "Italic"} } }                      
      * });
      * &lt;/script&gt;  
    * @alias ejChart#primaryXAxis->title->font->fontStyle
    */
    fontStyle: 'Normal',
    /**		
 * Specifies the title size of primaryXAxis. This font size is applied to the title text of primaryXAxis.
 * @default "16px"
 * @type {string}				
 * @example 
 * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryXAxis: { title: { font : { size : "14px"} } }                      
      * });
      * &lt;/script&gt;   
  * @alias ejChart#primaryXAxis->title->font->size
 */
    size: '16px',
    /**		
 * Specifies the title opacity of primaryXAxis. This opacity value is applied to the title text of primaryXAxis.
 * @default 1
 * @type {number}				
 * @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryXAxis: { title: { font : { opacity : 0.8} } }                      
      * });
      * &lt;/script&gt;  
  * @alias ejChart#primaryXAxis->title->font->opacity
 */
    opacity: 1,
    /**		
 * Specifies the title fontWeight of primaryXAxis. This fontWeight is applied to the title text of primaryXAxis. See {@link FontWeight}
 * @default ej.datavisualization.Chart.FontWeight.Regular
 * @type {enum}				 
 * @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryXAxis: { title: { font : { fontWeight : "lighter"} } }                      
      * });
      * &lt;/script&gt;  
   * @alias ejChart#primaryXAxis->title->font->fontWeight
 */
    fontWeight: 'regular'
}
 },

         /**		
      * If the range is not given explicitly, range will be calculated automatically. You can customize the automatic range calculation using rangePadding. See {@link RangePadding}
      * @default ej.datavisualization.Chart.rangePaddding.None
      * @type {enum}				
      * @example 
      * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryXAxis: { rangePadding : "normal" }                      
      * });
      * &lt;/script&gt;  
       * @alias ejChart#primaryXAxis->rangePadding
      */
         rangePadding: 'None',
         additionalPadding: [1, 1],
         orientation: 'Horizontal',
         /**		
      * Specifies the maximum number of labels to be displayed in 100 pixels.
      * @default 3
      * @type {number}				
      * @example 
      * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryXAxis: { maximumLabels : 5 }                      
      * });
      * &lt;/script&gt;  
      * @alias ejChart#primaryXAxis->maximumLabels
      */
         maximumLabels: 3,
         /**		
     * Specifies a value that indicates whether to position the axis opposite to its default position.
     * @default false
     * @type {boolean}			
     * @example 
     * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryXAxis: { opposedPosition : true }                      
      * });
      * &lt;/script&gt;  
      * @alias ejChart#primaryXAxis->opposedPosition
     */
         opposedPosition: false,
         /**		
       * Specifies the options to configure axis line.
       * @type {object}
       * @alias ejChart#primaryXAxis->axisLine
       */
         axisLine:
  {
      /**		
     * Specifies the visibility of axis line.
     * @default true
     * @type {boolean}			
     * @example 
     * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryXAxis: { axisLine : { visible : false } }                      
      * });
      * &lt;/script&gt;  
     * @alias ejChart#primaryXAxis->axisLine->visible
     */
      visible: true,
      /**		
     * Specifies the width of axisLine in primaryXAxis.
     * @default 1
     * @type {number}			
     * @example 
     * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryXAxis: { axisLine : { width : 2 } }                      
      * });
      * &lt;/script&gt;  
     * @alias ejChart#primaryXAxis->axisLine->width
     */
      width: 1,
      /**		
 * Controls the pattern of dashes and gaps used to stroke the axis line.
 * @default null
 * @type {string}			
 * @example 
 * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryXAxis: { axisLine : { dashArray : "2,3" } }                      
      * });
      * &lt;/script&gt;  
  * @alias ejChart#primaryXAxis->axisLine->dashArray
 */
      dashArray: "",
      /**		
* Specifies the horizontal/vertical padding of axis line. Normally, it is used along with plotOffset to pad the plot area.
* @default null
* @type {number}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryXAxis: { axisLine : { offset : 5 } }                      
      * });
      * &lt;/script&gt;  
 * @alias ejChart#primaryXAxis->axisLine->offset
*/
      offset: 0
  },
         /**
         * Specifies the action to take when the axis labels are overlapping with each other. See {@link LabelIntersectAction}
         * @default ej.datavisualization.Chart.LabelIntersectAction.None
         * @type {enum}		
         * @example 		 
         * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryXAxis: { labelIntersectAction : "multipleRows" }                      
      * });
      * &lt;/script&gt;  
         * @alias ejChart#primaryXAxis->labelIntersectAction
         */
         labelIntersectAction: "none",

         /**		
      * Determines how to position labels at the edge of the axis. See {@link EdgeLabelPlacement} for the available options.
     * @default ej.datavisualization.Chart.EdgeLabelPlacement.None
      * @type {enum}			 
      * @example 
       * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryXAxis: { edgeLabelPlacement : "shift" }                      
      * });
      * &lt;/script&gt;  
       * @alias ejChart#primaryXAxis->edgeLabelPlacement
     */
         edgeLabelPlacement: "none",	 
	 
		 
         /**		
      * Renders the axis in inversed position.
      * @default true
      * @type {boolean}			 
      * @example 
       * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryXAxis: { isInversed : true}                      
      * });
      * &lt;/script&gt;  
       * @alias ejChart#primaryXAxis->isInversed
     */
         isInversed:false,
		 

         /**		
    * Specifies the font of primaryXAxis.
    * @type {object}
    * @alias ejChart#primaryXAxis->font

    */
         font:
  {
      /**		
      * Specifies the fontfamily of primaryXAxis. The axis labels render with this specified fontFamily.
      * @default "Segoe UI"
      * @type {string}				
      * @example 
       * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryXAxis: { font : { fontFamily : "Algerian"} }                      
      * });
      * &lt;/script&gt;   
       * @alias ejChart#primaryXAxis->font->fontFamily
      */
      fontFamily: 'Segoe UI',
      /**		
     * Specifies the fontStyle of primaryXAxis. The axis labels render with this specified fontStyle. See {@link FontStyle}
     * @default ej.datavisualization.Chart.FontStyle.Normal
     * @type {enum}				
     * @example 
     * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryXAxis: { font : { fontStyle : "Italic"} }                      
      * });
      * &lt;/script&gt;  
     * @alias ejChart#primaryXAxis->font->fontStyle
     */
      fontStyle: 'Normal',
      /**		
      * Specifies the title size of primaryXAxis. The axis labels render with this specified size.
      * @default "13px"
      * @type {string}			
      * @example 
       * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryXAxis: { font : { size : "12px"} }                      
      * });
      * &lt;/script&gt;  
      * @alias ejChart#primaryXAxis->font->size
      */
      size: '13px',
      /**		
      * Specifies the fontWeight of primaryXAxis. The axis labels render with this specified fontWeight.See {@link FontWeight}
      * @default ej.datavisualization.Chart.FontWeight.Regular
      * @type {enum}				
      * @example 
       * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryXAxis: { font : { fontWeight : "lighter"} }                      
      * });
      * &lt;/script&gt;  
      * @alias ejChart#primaryXAxis->font->fontWeight
      */
      fontWeight: 'regular',
      /**		
     * Specifies the title opacity of primaryXAxis. The axis labels render with this specified opacity.
     * @default 1
     * @type {number}			
     * @example 
     * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryXAxis: { font : { opacity : 0.5} }                      
      * });
      * &lt;/script&gt;  
     * @alias ejChart#primaryXAxis->font->opacity
     */
      opacity: 1
  },
         /**		
      * Specifies the visibility of the axis.
      * @default true
      * @type {boolean}				
      * @example 
       * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryXAxis: { visible: false }                      
      * });
      * &lt;/script&gt;  
      * @alias ejChart#primaryXAxis->visible
      */
         visible: true,
         /**		
    * Options to configure the visibility of the crosshair label. 
    * @type {object}
     * @alias ejChart#primaryXAxis->crosshairLabel
    */
         crosshairLabel:
   {
       /**		
      * Specifies the visibility of crosshair label. 
      * @default false
      * @type {boolean}			
      * @example 
       * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryXAxis: { crosshairLabel : { visible : true} }                      
      * });
      * &lt;/script&gt;  
       * @alias ejChart#primaryXAxis->crosshairLabel->visible
      */
       visible: false
   },
         /**		
       * This property determines the factor by which the axis is scaled. Value must be specified between 0 and 1
       * @default 1
       * @type {number}			
       * @example 
        * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryXAxis: { zoomFactor : 0.5 }                      
      * });
      * &lt;/script&gt;  
       * @alias ejChart#primaryXAxis->zoomFactor
       */
         zoomFactor: 1,
         /**		
      * This property determines the starting position of the zoomed axis. Value must be specified between 0 and 1.
      * @default 0
      * @type {number}				
      * @example 
       * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryXAxis: { zoomPosition :0.5 }                      
      * });
      * &lt;/script&gt;  
     * @alias ejChart#primaryXAxis->zoomPosition
      */
         zoomPosition: 0
     },

            /**		
           * This is a vertical axis which contains options to configure axis. This is the primary y axis for all the series in series array. If you need to override y axis for particular series, you can create an axis object by providing unique name using name property and add it to axes array. Then, assign the name to the series’s yAxisName property to link both axis and series.
           * @type {object}
           */
            primaryYAxis: /** @lends ejChart# */
      {
          /**		
* Specifies the position of the axis labels.
* @default "outside"
* @type {enum}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { labelPosition : "inside" }                       
      * });
      * &lt;/script&gt; 
 * @alias ejChart#primaryYAxis->labelPosition
*/
          labelPosition: 'outside',
		   /**		
* Specifies the position of the axis tick lines.
* @default "outside"
* @type {enum}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { tickLinesPosition : "inside" }                       
      * });
      * &lt;/script&gt; 
 * @alias ejChart#primaryYAxis->tickLinesPosition
*/
          tickLinesPosition: 'outside',
          /**		
         * This is a Vertical axis alternate grid band which contains options to highlight alternate grid bands.
         * @type {object}
		 * @alias ejChart#primaryYAxis->alternateGridBand
         */
          alternateGridBand:
                     {
                         /**		
                         * Specifies the Odd Alternative Grid Band.
                         * @type {object}
						 * @alias ejChart#primaryYAxis->alternateGridBand->odd
                         */
                         odd: {
                             /**		
                             * Specifies the fill color of Odd grid bands
                             * @default transparent
                             * @type {string}	
                             * @example 
                    * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { alternateGridBand: { odd : { fill :"red" }  } }                      
      * });
      * &lt;/script&gt; 
                           * @alias ejChart#primaryYAxis->alternateGridBand->odd->fill							 
                             */
                             fill: "transparent",
                             /**		
         * Specifies the opacity of the Odd grid band.
         * @default 1
         * @type {number}				
          * @example 
                    * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
    * primaryYAxis: { alternateGridBand: { odd : { opacity :0.5 }  } }                       
      * });
      * &lt;/script&gt; 
                           * @alias ejChart#primaryYAxis->alternateGridBand->odd->opacity							 
                             */
                             opacity: 1
                         },
                         /**		
                         * Specifies the Even Alternative Grid Band.
                         * @type {object}
						  * @alias ejChart#primaryYAxis->alternateGridBand->even
                         */
                         even: {
                             /**		
         * Specifies the fill color of Even grid bands
         * @default transparent
         * @type {string}
         * @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { alternateGridBand: { even : {fill : "red" } } }                      
      * });
      * &lt;/script&gt; 
 * @alias ejChart#primaryYAxis->alternateGridBand->even->fill
*/		 

                             fill: "transparent",
                             /**		
         * Specifies the opacity of the Even grid band.
         * @default 1
         * @type {number}				
         * @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { alternateGridBand: { even : {opacity : 0.5 } } }                      
      * });
      * &lt;/script&gt; 
 * @alias ejChart#primaryYAxis->alternateGridBand->even->opacity
*/		
                             opacity: 1
                         }
                     },
					  /**		
    * Options for configuring major grid lines color, width, dash arrays etc., 
    * @type {object}
     * @alias ejChart#primaryYAxis->majorGridLines
    */
          majorGridLines:
     {
         /**		
* Specifies the width of the major grid lines.
* @default 1
* @type {number}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { majorGridLines : {width : 2} }                      
      * });
      * &lt;/script&gt;   
* @alias ejChart#primaryYAxis->majorGridLines->width
*/
         width: 1,
         /**		
* Controls the pattern of dashes and gaps used to stroke the major grid lines.
* @default null
* @type {string}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { majorGridLines : {dashArray : "2,3"} }                      
      * });
      * &lt;/script&gt;   
* @alias ejChart#primaryYAxis->majorGridLines->dashArray
*/
         dashArray: "",
         /**		
* Specifies the visibility of the major grid lines.
* @default true
* @type {boolean}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { majorGridLines : {visible : false} }                      
      * });
      * &lt;/script&gt;   
* @alias ejChart#primaryYAxis->majorGridLines->visible
*/
         visible: true,
         /**		
* Specifies the opacity of the major grid lines.
* @default 1
* @type {number}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { majorGridLines : {opacity : 0.5} }                      
      * });
      * &lt;/script&gt;  
* @alias ejChart#primaryYAxis->majorGridLines->opacity
*/
         opacity: 1

     },
          /**		
* Options for configuring major tick lines color, width, dash arrays etc.,
* @type {object}
* @alias ejChart#primaryYAxis->majorTickLines
*/
          majorTickLines:
     {
         /**		
* Specifies the width of the major tick lines.
* @default 1
* @type {number}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { majorTickLines : {width : 2} }                      
      * });
      * &lt;/script&gt;  
* @alias ejChart#primaryYAxis->majorTickLines->width
*/
         width: 1,
         /**		
* Length of the major tick lines.
* @default 5
* @type {number}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { majorTickLines : {size : 2} }                      
      * });
      * &lt;/script&gt;  
* @alias ejChart#primaryYAxis->majorTickLines->size
*/
         size: 5,
         /**		
* Specifies the visibility of the major tick lines.
* @default true
* @type {boolean}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { majorTickLines : {visible : false} }                      
      * });
      * &lt;/script&gt;  
* @alias ejChart#primaryYAxis->majorTickLines->visible
*/
         visible: true
     },
          /**		
     * Options for configuring minor grid lines color, width, dash arrays etc.,
     * @type {object}
  * @alias ejChart#primaryYAxis->minorGridLines
     */
          minorGridLines:
     {
         /**		
* Specifies the width of the minor grid lines.
* @default 1
* @type {number}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { minorGridLines : {width : 2} }                      
      * });
      * &lt;/script&gt;   
* @alias ejChart#primaryYAxis->minorGridLines->width
*/
         width: 1,
         /**		
* Controls the pattern of dashes and gaps used to stroke the minor grid lines.
* @default null
* @type {string}		
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { minorGridLines : {dashArray : "2,3"} }                      
      * });
      * &lt;/script&gt;   
* @alias ejChart#primaryYAxis->minorGridLines->dashArray
*/
         dashArray: "",
         /**		
* Specifies the visibility of the minorGridLines. The user can modify the visibility of the minorGridLines in primaryYAxis.
* @default false
* @type {boolean}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { minorGridLines : {visible : true} }                      
      * });
      * &lt;/script&gt;  
* @alias ejChart#primaryYAxis->minorGridLines->visible
*/
         visible: true

     },
          /**		
* Options for configuring minor tick lines color, width, dash arrays etc.,
* @type {object}
* @alias ejChart#primaryYAxis->minorTickLines
*/
          minorTickLines:
     {
         /**		
* Specifies the width of the minor tick lines.
* @default 1
* @type {number}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { minorTickLines : {width : 2} }                      
      * });
      * &lt;/script&gt;  
* @alias ejChart#primaryYAxis->minorTickLines->width
*/
         width: 1,
         /**		
* Length of the minor tick lines.
* @default 5
* @type {number}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { minorTickLines : {size : 2} }                      
      * });
      * &lt;/script&gt;  
* @alias ejChart#primaryYAxis->minorTickLines->size
*/
         size: 5,
         /**		
* Specifies the visibility of the minor tick lines.
* @default false
* @type {boolean}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { minorTickLines : {visible : true} }                      
      * });
      * &lt;/script&gt;  
* @alias ejChart#primaryYAxis->minorTickLines->visible
*/
         visible: true
     },
          /**		
* Specifies the number of minor ticks to render per major tick/interval.
* @default null
* @type {number}			
* @example 
 * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { minorTicksPerInterval: 3 }                      
      * });
      * &lt;/script&gt; 
* @alias ejChart#primaryYAxis->minorTicksPerInterval
*/
          minorTicksPerInterval: null,
          /**		
* Index of the row object in rowDefinitions array to which this axis is associated with.
* @default null
* @type {number}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { rowIndex: 1 }                      
      * });
      * &lt;/script&gt; 
* @alias ejChart#primaryYAxis->rowIndex
*/
          rowIndex: null,
          /**		
 * An axis can be spanned along multiple rows or plotting areas. This property specifies the number of rows/plotting areas this axis should be spanned.
 * @default null
 * @type {number}				
 * @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { rowSpan: 2 }                      
      * });
      * &lt;/script&gt; 
* @alias ejChart#primaryYAxis->rowSpan
 */
          rowSpan: null,
          /**		
* You can plot any type of data like date time, double, string etc., This property determines the type of data that this axis will handle.
* @default null
* @type {enum}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { valueType: "double" }                      
      * });
      * &lt;/script&gt;  
* @alias ejChart#primaryYAxis->valueType
*/
          valueType: null,
          /**		
  * Unique name of the axis.
  * @default null
  * @type {string}			
  * @example 
  * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { name: "yAxis" }                      
      * });
      * &lt;/script&gt; 
* @alias ejChart#primaryYAxis->name
  */
          name: null,
          /**		
 * Provides the format for axis labels.
 * @default null
 * @type {string}				
 * @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { labelFormat: "{value}F" }                      
      * });
      * &lt;/script&gt;  
 * @alias ejChart#primaryYAxis->labelFormat
 */
          labelFormat: null,
          /**		
* Specifies the desired number of intervals for the range. With this setting, you can request axis to calculate nice numbers such that they result in the number of intervals approximately equal to your desired interval.
* @default null
* @type {number}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { desiredIntervals: 5 }                      
      * });
      * &lt;/script&gt; 
 * @alias ejChart#primaryYAxis->desiredIntervals
*/
          desiredIntervals: null,
          /**		
 * Specifies whether the type of the interval calculated is in days, months, hours, minutes etc., This is applicable only when valueType is ‘datetime’. See {@link IntervalType}
 * @default null
 * @type {enum}			
 * @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { intervalType: "days" }                      
      * });
      * &lt;/script&gt;  
  * @alias ejChart#primaryYAxis->intervalType
 */
          intervalType: null,
          /**		
 * Rounds the axis labels to the specified number of decimals.
 * @default null
 * @type {number}			
 * @example 
 * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { roundingPlaces: 2 }                      
      * });
      * &lt;/script&gt; 
  * @alias ejChart#primaryYAxis->roundingPlaces
 */
          roundingPlaces: null,
          labels: [],
          /**		
* Options to configure the title font and alignment of the axis title.
* @type {object}
* @alias ejChart#primaryYAxis->title
*/
          title:
    {
        /**		
* Text to be displayed as a title for axis.
* @default ""
* @type {string}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { title :{ text: "yAxis" } }                      
      * });
      * &lt;/script&gt; 
* @alias ejChart#primaryYAxis->title->text
*/
        text: "",
        /**		
* Specifies the font. These font properties are customization are applied for title text.
* @type {object}
* @alias ejChart#primaryYAxis->title->font
*/
        font:
     {
         /**		
* Specifies the title fontfamily of primaryYAxis. This fontFamily is applied to the title text of primaryYAxis.
* @default "Segoe UI"
* @type {string}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { title :{ font :{ fontFamily: "Algerian" } } }                      
      * });
      * &lt;/script&gt; 
* @alias ejChart#primaryYAxis->title->font->fontFamily
*/
         fontFamily: 'Segoe UI',
         /**		
* Specifies the title fontStyle of primaryYAxis. This fontStyle is applied to the title text of primaryYAxis. See {@link FontStyle}
* @default ej.datavisualization.Chart.FontStyle.Normal
* @type {enum}			 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { title :{ font :{ fontStyle : "Italic" } } }                      
      * });
      * &lt;/script&gt;  
* @alias ejChart#primaryYAxis->title->font->fontStyle
*/
         fontStyle: 'Normal',
         /**		
* Specifies the title opacity of primaryYAxis. This font size is applied to the title text of primaryYAxis.
* @default 1
* @type {number}			 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { title :{ font :{ opacity: 0.5 } } }                      
      * });
      * &lt;/script&gt;  
* @alias ejChart#primaryYAxis->title->font->opacity
*/
         opacity: 1,
         /**		
* Specifies the title size of primaryYAxis. This opacity value is applied to the title text of primaryYAxis.
* @default "16px"
* @type {string}			 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { title :{ font :{ size: "12px" } } }                      
      * });
      * &lt;/script&gt;  
* @alias ejChart#primaryYAxis->title->font->size
*/
         size: '16px',
         /**		
* Specifies the title fontWeight of primaryYAxis. This fontWeight is applied to the title text of primaryYAxis. See {@link FontWeight}
* @default ej.datavisualization.Chart.FontWeight.Regular
* @type {enum}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { title :{ font :{ fontWeight: "normal" } } }                      
      * });
      * &lt;/script&gt;  
* @alias ejChart#primaryYAxis->title->font->fontWeight
*/
         fontWeight: 'regular'
     }
    },
          /**		
* If the range is not given explicitly, range will be calculated automatically. You can customize the automatic range calculation using rangePadding. See {@link RangePadding}
* @default ej.datavisualization.Chart.RangePadding.None
* @type {enum}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { rangePadding : "none" }                      
      * });
      * &lt;/script&gt;   
* @alias ejChart#primaryYAxis->rangePadding
*/
          rangePadding: 'Normal',

          /**		
            * Options to configure stripLine’s color, text, border etc.,
            * @name ejChart#primaryYAxis->stripLine 
            * @default [ ]
            * @type {array}
            */
          stripLine: [
               {
                   /**		
     * Specifies the visibility of the stripLine.
     * @default false
     * @type {boolean}			
     * @example 
     * &lt;div id="container"&gt;&lt;/div&gt; 
     * &lt;script&gt;
     * $("#container").ejChart({
     * primaryYAxis: { stripLine:[{ visible : true }]}                      
     * });
     * &lt;/script&gt; 
     * @alias ejChart#primaryYAxis->stripLine->visible
     */
                   visible: false,
                   /**		
   * Indicates whether to render the stripLine from the minimum/start value of the axis.
   * @default false
   * @type {boolean}			
   * @example 
   * &lt;div id="container"&gt;&lt;/div&gt; 
   * &lt;script&gt;
   * $("#container").ejChart({
   * primaryYAxis: { stripLine:[{ startFromAxis : true }]}                      
   * });
   * &lt;/script&gt; 
   * @alias ejChart#primaryYAxis->stripLine->startFromAxis
   */
                   startFromAxis: false,
                   /**		
  * Text to be displayed inside the stripLine.
  * @default "stripLine"
  * @type {string}			
  * @example 
  * &lt;div id="container"&gt;&lt;/div&gt; 
  * &lt;script&gt;
  * $("#container").ejChart({
  * primaryYAxis: { stripLine:[{ text : "Empty Point" }]}                      
  * });
  * &lt;/script&gt; 
  * @alias ejChart#primaryYAxis->stripLine->text
  */
                   text: "stripLine",
                   /**		
  * Alignment of the text displayed in stripLine. See {@link TextAlignment}
  * @default "middlecenter"
  * @type {enum}			
  * @example 
  * &lt;div id="container"&gt;&lt;/div&gt; 
  * &lt;script&gt;
  * $("#container").ejChart({
  * primaryYAxis: { stripLine:[{ textAlignment : "middletop" }]}                      
  * });
  * &lt;/script&gt; 
  * @alias ejChart#primaryYAxis->stripLine->textAlignment
  */
                   textAlignment: "middlecenter",
                   /**		
    * Specifies the font of stripLine in primaryYAxis. These are font properties for stripLine text
    * @type {object}
    * @alias ejChart#primaryYAxis->stripLine->font
    */
                   font: {
                       /**		
 * Specifies the fontFamily of stripLine in primaryYAxis. Stripline text render with this fontFamily
 * @default "middlecenter"
 * @type {enum}			
 * @example 
 * &lt;div id="container"&gt;&lt;/div&gt; 
 * &lt;script&gt;
 * $("#container").ejChart({
 * primaryYAxis: { stripLine:[{ font : { fontFamily : "Algerian"} }]}                      
 * });
 * &lt;/script&gt; 
 * @alias ejChart#primaryYAxis->stripLine->font->fontFamily
 */
                       fontFamily: 'Segoe UI',
                       /**		
* Specifies the fontWeight of stripLine in primaryYAxis. Stripline text render with this fontWeight
* @default "regular"
* @type {string}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* primaryYAxis: { stripLine:[{ font : { fontWeight: "lighter"} }]}                      
* });
* &lt;/script&gt; 
* @alias ejChart#primaryYAxis->stripLine->font->fontWeight
*/
                       fontWeight: 'Regular',
                       /**		
* Specifies the fontStyle of stripLine in primaryYAxis. Stripline text render with this fontStyle. See {@link FontStyle}
* @default "Normal"
* @type {enum}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* primaryYAxis: { stripLine:[{ font : { fontStyle: "Bold"} }]}                      
* });
* &lt;/script&gt; 
* @alias ejChart#primaryYAxis->stripLine->font->fontStyle
*/
                       fontStyle: 'Normal',
                       /**		
* Specifies the size of stripLine in primaryYAxis. Stripline text render with this size
* @default "12px"
* @type {string}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* primaryYAxis: { stripLine:[{ font : { size: "15px"} }]}                      
* });
* &lt;/script&gt; 
* @alias ejChart#primaryYAxis->stripLine->font->size
*/
                       size: '12px',
                       /**		
* Specifies the color of stripLine in primaryYAxis. Stripline text render with this color
* @default "black"
* @type {string}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* primaryYAxis: { stripLine:[{ font : { color: "green"} }]}                      
* });
* &lt;/script&gt; 
* @alias ejChart#primaryYAxis->stripLine->font->color
*/
                       color: 'black',
                       /**		
* Specifies the opacity of stripLine in primaryYAxis. Stripline text render with this opacity
* @default 1
* @type {number}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* primaryYAxis: { stripLine:[{ font : { opacity: 0.5} }]}                      
* });
* &lt;/script&gt; 
* @alias ejChart#primaryYAxis->stripLine->font->opacity
*/
                       opacity: 1
                   },
                   /**		
* Specifies the start value of the stripLine.
* @default null
* @type {number}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* primaryYAxis: { stripLine:[{ start: 2 }]}                      
* });
* &lt;/script&gt; 
* @alias ejChart#primaryYAxis->stripLine->start
*/
                   start: null,
                   /**		
* Specifies the end value of the stripLine.
* @default null
* @type {number}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* primaryYAxis: { stripLine:[{ end: 5 }]}                      
* });
* &lt;/script&gt; 
* @alias ejChart#primaryYAxis->stripLine->end
*/
                   end: null,
                   /**		
* Background color of the stripLine.
* @default "gray"
* @type {string}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* primaryYAxis: { stripLine:[{ color: "green" }]}                      
* });
* &lt;/script&gt; 
* @alias ejChart#primaryYAxis->stripLine->color
*/
                   color: 'gray',
                   /**		
* Border color of the stripLine.
* @default "gray"
* @type {string}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* primaryYAxis: { stripLine:[{ borderColor: "green" }]}                      
* });
* &lt;/script&gt; 
* @alias ejChart#primaryYAxis->stripLine->borderColor
*/
                   borderColor: 'black',
                   /**		
* Specifies the z order position of the stripLine.
* @default "over"
* @type {enum}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* primaryYAxis: { stripLine:[{ zIndex: "behind" }]}                      
* });
* &lt;/script&gt; 
* @alias ejChart#primaryYAxis->stripLine->zIndex
*/
                   zIndex: 'over'
               }
          ],
          /**		
 * Specifies the logarithmic base value. This is applicable only when valueType is logarithmic.
 * @default 10
 * @type {number}				
 * @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { logBase: 5 }                      
      * });
      * &lt;/script&gt;   
 * @alias ejChart#primaryYAxis->logBase
 */
          logBase: 10,
          /**		
 * Horizontal/vertical padding for the plotting area based on the orientation of the axis.
 * @default 10
 * @type {number}			 
 * @example 
 * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { plotOffset: 5 }                      
      * });
      * &lt;/script&gt;   
  * @alias ejChart#primaryYAxis->plotOffset
 */
          plotOffset: 0,
          orientation: 'Vertical',
          /**		
* Specifies the maximum number of labels to be displayed in 100 pixels.
* @default 3
* @type {number}			 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { maximumLabels: 5 }                      
      * });
      * &lt;/script&gt;   
 * @alias ejChart#primaryYAxis->maximumLabels
*/
          maximumLabels: 3,
          /**
          * Specifies the action to take when the axis labels are overlapping with each other. See {@link LabelIntersectAction}
     * @default ej.datavisualization.Chart.LabelIntersectAction.None
      * @type {enum}			 
      * @example 
      * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { labelIntersectAction: "multipleRows" }                      
      * });
      * &lt;/script&gt;    
       * @alias ejChart#primaryYAxis->labelIntersectAction
      */
          labelIntersectAction: "none",
          /**		
    * Determines how to position labels at the edge of the axis. See {@link EdgeLabelPlacement} for the available options.
   * @default ej.datavisualization.Chart.EdgeLabelPlacement.None
    * @type {enum}			 
    * @example 
    * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { edgeLabelPlacement: "shift" }                      
      * });
      * &lt;/script&gt; 
     * @alias ejChart#primaryYAxis->edgeLabelPlacement
    */
          edgeLabelPlacement: "none",
		  
		  /**		
      * Renders the axis in inversed position.
      * @default true
      * @type {boolean}			 
      * @example 
       * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { isInversed : true}                      
      * });
      * &lt;/script&gt;  
       * @alias ejChart#primaryYAxis->isInversed
     */
         isInversed:false,		

          /**		
* Options to configure the visibility of the crosshair label.
* @type {object}
* @alias ejChart#primaryYAxis->crosshairLabel
*/
          crosshairLabel:
   {
       /**		
* Specifies the visibility of crosshairLabel. This is the property to change the visibility of the axis labels. 
* @default false
* @type {boolean}			 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { crosshairLabel: { visible : true } }                      
      * });
      * &lt;/script&gt; 
 * @alias ejChart#primaryYAxis->crosshairLabel->visible
*/
       visible: false
   },
          /**		
 * Specifies the visibility of the axis. 
 * @default true
 * @type {boolean}			
 * @example 
 * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { visible : false }                      
      * });
      * &lt;/script&gt;  
  * @alias ejChart#primaryYAxis->visible
 */
          visible: true,
          /**		
* Specifies a value that indicates whether to position the axis opposite to its default position. 
* @default false
* @type {boolean}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { opposedPosition : true }                      
      * });
      * &lt;/script&gt; 
 * @alias ejChart#primaryYAxis->opposedPosition
*/
          opposedPosition: false,
          /**		
* Specifies the font of primaryYAxis.  These font properties are applied for the axis labels. 
* @type {object}
* @alias ejChart#primaryYAxis->font
*/
          font:
   {
       /**		
* Specifies the fontfamily of primaryYAxis. The axis labels render with this specified fontFamily.
* @default "Segoe UI"
* @type {string}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { font: { fontFamily : "Algerian" } }                      
      * });
      * &lt;/script&gt; 
 * @alias ejChart#primaryYAxis->font->fontFamily
*/
       fontFamily: 'Segoe UI',
       /**		
* Specifies the fontStyle of primaryYAxis. The axis labels render with this specified fontStyle.  See {@link FontStyle}
* @default ej.datavisualization.Chart.FontStyle.Normal
* @type {enum}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { font: { fontStyle : "italic" } }                      
      * });
      * &lt;/script&gt; 
 * @alias ejChart#primaryYAxis->font->fontStyle
*/
       fontStyle: 'Normal',
       /**		
 * Specifies the title size of primaryYAxis. The axis labels render with this specified size.
 * @default "13px"
 * @type {string}			
 * @example 
 * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { font: { size : "12px" } }                      
      * });
      * &lt;/script&gt; 
  * @alias ejChart#primaryYAxis->font->size
 */
       size: '13px',
       /**		
* Specifies the title opacity of primaryYAxis. The axis labels render with this specified opacity.
* @default 1
* @type {number}		 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { font: { opacity : 0.5 } }                      
      * });
      * &lt;/script&gt; 
* @alias ejChart#primaryYAxis->font->opacity
*/
       opacity: 1,
       /**		
* Specifies the fontWeight of primaryYAxis. The axis labels render with this specified fontWeight.  {@link FontWeight}
* @default ej.datavisualization.Chart.FontWeight.Regular
* @type {enum}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { font: { fontWeight : "normal" } }                      
      * });
      * &lt;/script&gt;  
 * @alias ejChart#primaryYAxis->font->fontWeight
*/
       fontWeight: 'regular'
   },
          /**		
  * Specifies the options to configure axis line.
  * @type {object}
  * @alias ejChart#primaryYAxis->axisLine
  */
          axisLine:
   {
       /**		
* Specifies the visibility of axis line.
* @default true
* @type {boolean}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { axisLine: { visible : false } }                      
      * });
      * &lt;/script&gt; 
 * @alias ejChart#primaryYAxis->axisLine->visible
*/
       visible: true,
       /**		
* Specifies the width of axisLine in primaryYAxis. The user can change the width of the axisLine.
* @default 1
* @type {number}				 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { axisLine: { width : 2 } }                      
      * });
      * &lt;/script&gt; 
* @alias ejChart#primaryYAxis->axisLine->width
*/
       width: 1,
       /**		
* Controls the pattern of dashes and gaps used to stroke the axis line.
* @default null
* @type {string}			 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { crosshairLabel: { axisLine :{ dashArray : "2,3" } } }                      
      * });
      * &lt;/script&gt; 
* @alias ejChart#primaryYAxis->axisLine->dashArray
*/
       dashArray: "",
       /**		
* Specifies the horizontal/vertical padding of axis line. Normally, it is used along with plotOffset to pad the plot area.
* @default null
* @type {number}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { axisLine: { offset : 5 } }                      
      * });
      * &lt;/script&gt; 
* @alias ejChart#primaryYAxis->axisLine->offset
*/
       offset: 0
   },

          /**		
  * This property determines the factor by which the axis is scaled. Value must be specified between 0 and 1. 
  * @default 1
  * @type {number}		
  * @example 
 * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { zoomFactor : 0.5 }                      
      * });
      * &lt;/script&gt; 
   * @alias ejChart#primaryYAxis->zoomFactor
  */
          zoomFactor: 1,
          /**		
 * This property determines the starting position of the zoomed axis. Value must be specified between 0 and 1.
 * @default 0
 * @type {number}			 
 * @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryYAxis: { zoomPosition : 0.5 }                      
      * });
      * &lt;/script&gt;  
 * @alias ejChart#primaryYAxis->zoomPosition
 */
          zoomPosition: 0
      },
            axes:[],

           
            secondaryX: 
             {
                 tickLinesPosition: "outside",
                 labelPosition:"outside",
                
                 majorGridLines:
        {
           
            width: 1,
           
            dashArray: "",
           
            visible: true
        },
                 alternateGridBand:
           {
               odd: {
                   fill: "transparent",
                   opacity: 1
               },
               even: {
                   fill: "transparent",
                   opacity: 1
               }
           },
                
                 majorTickLines:
         {
           
             width: 1,
            
             size: 5,
           
             visible: true
         },
                
                 minorGridLines:
         {
            
             width: 1,
            
             dashArray: "",
            
             visible: true

         },
                
                 minorTickLines:
        {
           
            width: 1,
           
            size: 5,
          
            visible: true
        },
               
                 minorTicksPerInterval: null,
               
                 columnIndex: null,
              
                 columnSpan: null,
                
                 labelRotation: null,
                
                 valueType: null,
               
                 name: null,
              
                 labelFormat: null,
               
                 desiredIntervals: null,
                 
                 intervalType: null,
               
                 roundingPlaces: null,
              
                 logBase: 10,
              
                 plotOffset: 0,
                 labels: [],
                 stripLine: [
              {
                  visible: false,
                  startFromAxis: false,
                  text: "stripLine",
                  textAlignment: "middlecenter",
                  font: { fontFamily: 'Segoe UI', fontStyle: 'Normal', fontWeight: 'regular', size: '12px', color: 'black', opacity: 1 },
                  start: null,
                  end: null,
                  color: 'gray',
                  borderColor: 'black',
                  zIndex: 'over'
              }
                 ],
             
                 title:
         {

           
             text: "",
            
             font:
        {
            
            fontFamily: 'Segoe UI',
           
            fontStyle: 'Normal',
        
            size: '16px',
         
            opacity: 1,
         
            fontWeight: 'regular'
        }

        },
               
                 rangePadding: 'None',
                 additionalPadding: [1, 1],
              
                 orientation: 'Horizontal',
             
                 maximumLabels: 3,
               
                 opposedPosition: false,
               
                 axisLine:
          {
              
              visible: true,
             
              width: 1,
           
              dashArray: "",
             
              offset: 0
          },
                
                 labelIntersectAction: "none",
                
                 edgeLabelPlacement: "none",
                
                 font:
          {
             
              fontFamily: 'Segoe UI',
            
              fontStyle: 'Normal',
             
              size: '13px',
              
              fontWeight: 'regular',
             
              opacity: 1
          },
               
                 visible: true,
                
                 crosshairLabel:
           {
              
               visible: false
           },
              
                 zoomFactor: 1,
              
                 zoomPosition: 0
             },
          
            secondaryY: 
                {
                    tickLinesPosition: "outside",
                    labelPosition: "outside",
                  
                    majorGridLines:
       {
          
           width: 1,
          
           dashArray: "",
          
           visible: true

       },
                    alternateGridBand:
           {
               odd: {
                   fill: "transparent",
                   opacity: 1
               },
               even: {
                   fill: "transparent",
                   opacity: 1
               }
           },
                 
                    majorTickLines:
                        {
                       
                            width: 1,
                      
                            size: 5,
                        
                            visible: true
                        },
                   
                    minorGridLines:
                        {
                       
                            width: 1,
                        
                            dashArray: "",
                         
                            visible: true

                        },
                   
                    minorTickLines:
                        {
                         
                            width: 1,
                          
                            size: 5,
                          
                            visible: true
                        },
                  
                    minorTicksPerInterval: null,
                 
                    rowIndex: null,
                  
                    rowSpan: null,
                   
                    valueType: null,
                   
                    name: null,
                   
                    labelFormat: null,
                   
                    desiredIntervals: null,
                 
                    intervalType: null,
                  
                    roundingPlaces: null,
                    labels: [],
                  
                    title:
                    {
                    
                        text: "",
                       
                        font:
                        {
                            fontFamily: 'Segoe UI',
                           
                            fontStyle: 'Normal',
                          
                            opacity: 1,
                           
                            size: '16px',
                           
                            fontWeight: 'regular'
                        }
                    },
                 
                    rangePadding: 'Normal',

                    stripLine: [
                         {
                             visible: false,
                             startFromAxis: false,
                             text: "stripLine",
                             textAlignment: "middlecenter",
                             font: { fontFamily: 'Segoe UI', fontStyle: 'Normal', fontWeight: 'regular', size: '12px', color: 'black', opacity: 1 },
                             start: null,
                             end: null,
                             color: 'gray',
                             borderColor: 'black',
                             zIndex: 'over'
                        }
                    ],
                   
                    logBase: 10,
                   
                    plotOffset: 0,
                   
                    orientation: 'Vertical',
                   
                    maximumLabels: 3,
                 
                    labelIntersectAction: "none",
                   
                    edgeLabelPlacement: "none",
                   
                    crosshairLabel:
                    {
                      
                        visible: false
                    },
                  
                    visible: true,
                  
                    opposedPosition: false,
                   
                    font:
                    {
                        fontFamily: 'Segoe UI',
                       
                        fontStyle: 'Normal',
                       
                        size: '13px',
                        
                        opacity: 1,
                       
                        fontWeight: 'regular'
                    },
                   
                    axisLine:
                        {
                           
                            visible: true,
                         
                            width: 1,
                          
                            dashArray: "",
                          
                            offset: 0
                        },

                   
                    zoomFactor: 1,
                   
                    zoomPosition: 0
                },
            indicatorDefaults: {
                points: [],
                tooltip: { visible: false, format: "#point.x# : #point.y#", fill: null, border: { width: 1, color: null }, duration: '500ms', enableAnimation: true, opacity: 0.95 },
                seriesName: "",
                font: { fontFamily: 'Segoe UI', fontStyle: 'Normal', fontWeight: 'Regular', size: '12px', color: '#707070', opacity: 1 },
                type: "SMA",
                period: 14,
		standardDeviations:2,		
                kPeriod: 3,
                dPeriod: 3,
                periodLine: { fill: "blue", width: 2 },
                lowerLine: { fill: "#008000", width: 2 },
                upperLine: { fill: "#ff0000", width: 2 },
				macdLine: { fill: "#ff9933", width: 2 },
				histogram: { fill: "#ccccff", opacity: 1, border: { color: "#9999ff", width: 1 } },
                fill: "#00008B",
				width: 2,
                xAxisName: "",
                yAxisName: "",
                visibility: "visible",
                macdType: "line",
                shortPeriod: 12,
                longPeriod: 26,
				trigger: 9,
                enableAnimation:false
            },

            stripLineDefault: { 
                
                visible: false,
                
                startFromAxis: false,
               
                text: "stripLine",
               
                textAlignment: 'middlecenter',
                
                font:
                {
                   
                    fontFamily: 'Segoe UI',
                  
                    fontStyle: 'Normal',
                   
                    fontWeight: 'Regular',
                   
                    size: '12px',
                   
                    color: 'black',
                    
                    opacity: 1
                },
               
                start: null,
               
                end: null,
               
                color: 'gray',
                
                borderColor: 'black',
               
                zIndex: 'over',
               
                borderWidth: 1
            },
            /**		
         * You can split chart into multiple plotting areas horizontally and vertically. In order to split the chart vertically, you need to specify number of row objects in rowDefintions array. Each object in the rowDefnitions represent a plotting area in chart.
         * @type {array}			 
         * @example 
         * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryXAxis :{ rowDefinitions :[{unit : "percentage"}] }                      
      * });
      * &lt;/script&gt;  
         */
            rowDefinitions: null,
            /**		
        * You can split chart into multiple plotting areas horizontally and vertically. In order to split the chart horizontally, you need to specify number of column objects in columDefintions array. Each object in the columnDefnitions represent a plotting area in chart.
        * @type {array}		 
        * @example 
       * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * primaryXAxis :{ columnDefinitions :[{unit : "percentage"}] }                      
      * });
      * &lt;/script&gt; 
        */
            columnDefinitions: null,
            /**		
           * Specifies the chart title. This title property denotes the title of the chart. 
           * @type {object}
           */
            title: /** @lends ejChart# */
				{ 
				    /**		
       * Specifies the text of the chart title. The text which is to be render as chart title is set here.
       * @default ""
       * @type {string}		 
       * @example 
       * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * title : { text : "Power Production"}                     
      * });
      * &lt;/script&gt; 
       * @alias ejChart#title->text
       */
				    text: "",
				    /**		
     * This property is used to change the alignment of the title horizontally. See {@link TextAlignment}
     * @default ej.datavisualization.Chart.TextAlignment.Center
     * @type {enum}			
     * @example 
     * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * title : { textAlignment : "near"}                     
      * });
      * &lt;/script&gt; 
     * @alias ejChart#title->textAlignment
     */
				    textAlignment: "center",
				    /**		
          * Specifies the chart title. These are the font properties involved in chart title customization.
          * @type {object}
           * @alias ejChart#title->font
          */
				    font: {
				        /**		
 * Specifies the title fontfamily of primaryXAxis. Chart title render with this specified fontFamily.
 * @default "Segoe UI"
 * @type {string}				 
 * @example 
  * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * title : { font : { fontFamily : "Algerian" } }                     
      * });
      * &lt;/script&gt; 
  * @alias ejChart#title->font->fontFamily
 */
				        fontFamily: 'Segoe UI',
				        /**		
    * Specifies the title fontStyle of primaryXAxis. Chart title render with this specified fontStyle. See {@link FontStyle}
    * @default ej.datavisualization.Chart.FontStyle.Normal
    * @type {enum}			 
    * @example 
      * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * title : { font : { fontStyle : "italic" } }                     
      * });
      * &lt;/script&gt; 
     * @alias ejChart#title->font->fontStyle
    */
				        fontStyle: 'Normal',
				        /**		
 * Specifies the title size. Chart title render with this specified font size.
 * @default "20px"
 * @type {string}				
 * @example 
 * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * title : { font : { size : "22px" } }                     
      * });
      * &lt;/script&gt; 
  * @alias ejChart#title->font->size
 */
				        size: '20px',
				        /**		
* Specifies the title opacity. Chart title render with this specified font opacity.
* @default 0.5
* @type {number}			 
* @example 
 * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * title : { font : { opacity : 0.8 } }                     
      * });
      * &lt;/script&gt; 
 * @alias ejChart#title->font->opacity
*/
				        opacity: 1,
				        /**		
 * Specifies the title fontWeight. Chart title render with this specified fontWeight.
 * @default ej.datavisualization.Chart.FontWeight.Regular
 * @type {enum}			 
 * @example 
 * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * title : { font : { fontWeight : "lighter" } }                     
      * });
      * &lt;/script&gt; 
 * @alias ejChart#title->font->fontWeight
 */
				        fontWeight: 'regular'
				    },
/**		
  * Specifies the options to customize the chart subtitle.
  * @type {object}
  * @alias ejChart#title->subTitle
  */
				
  subTitle:
         {
		 /**		
* Specifies the text to be displayed as subtitle.
* @default ""
* @type {string}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * title: { subTitle: { text : "Performace chart" } }                      
      * });
      * &lt;/script&gt; 
 * @alias ejChart#title->subTitle->text
*/
             text: "",
			 /**		
* Specifies the text alignment for subtitle text.
* @default "far"
* @type {enum}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * title: { subTitle: { textAlignment : "near" } }                      
      * });
      * &lt;/script&gt; 
 * @alias ejChart#title->subTitle->textAlignment
*/
             textAlignment: 'far',
			 /**		
  * Specifies the font options for customizing the subtitle.
  * @type {object}
  * @alias ejChart#title->subTitle->font
  */
             font:
             {
 /**		
* Specifies the font family of subtitle.
* @default "Segoe UI"
* @type {string}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * title: {subTitle : {font :{ fontFamily : "Algerian" } } }                      
      * });
      * &lt;/script&gt; 
 * @alias ejChart#title->subTitle->font->fontFamily
*/
             fontFamily: 'Segoe UI',
/**		
* Specifies the font style of subtitle.
* @default "Normal"
* @type {enum}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * title: { subTitle : {font :{ fontStyle : "Normal" } } }                     
      * });
      * &lt;/script&gt; 
 * @alias ejChart#title->subTitle->font->fontStyle
*/
             fontStyle: 'Normal',   
/**		
* Specifies the font size of subtitle.
* @default "12px"
* @type {enum}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * title: { subTitle : {font :{ size : "14px" } } }                     
      * });
      * &lt;/script&gt; 
 * @alias ejChart#title->subTitle->font->size
*/			 
             size: '12px',
			 /**		
* Specifies the font opacity of subtitle.
* @default 1
* @type {double}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * title: { subTitle : {font :{ opacity : 0.5 } } }                     
      * });
      * &lt;/script&gt; 
 * @alias ejChart#title->subTitle->font->opacity
*/	
             opacity: 1,
			 /**		
* Specifies the font weight of subtitle.
* @default "regular"
* @type {enum}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * title: { subTitle : {font :{ fontWeight : "regular" } } }                     
      * });
      * &lt;/script&gt; 
 * @alias ejChart#title->subTitle->font->fontWeight
*/	
             fontWeight: 'regular'
              }
           }
				    
	},  				



				

            lineCap: { butt: 'butt', round: 'round', square: 'square' },
            lineJoin: { round: 'round', bevel: 'bevel', miter: 'miter' },
            legendAlignment: { near: 'near', center: 'center', far: 'far' },
            legendPosition: { top: 'top', bottom: 'bottom', right: 'right', left: 'left', custom: 'custom' },
           
            enableAnimation: true,
            /**		
          * Contains all the properties to customize legend.
          * @type {object}
          */
            legend: /** @lends ejChart# */
            {
			/**		
  * Specifies the title of the legend.
  * @type {object}
  * @alias ejChart#legend->title
  */
                title:
                      {
					  /**		
* Specifies the text to be displayed as legend title.
* @default ""
* @type {string}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * legend: { title: { text : "Countries" } }                      
      * });
      * &lt;/script&gt; 
 * @alias ejChart#legend->title->text
*/
                          text: "",
						  /**		
* Specifies the text alignment of legend title.
* @default "center"
* @type {enum}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * legend: { title: { textAlignment : "near" } }                      
      * });
      * &lt;/script&gt; 
 * @alias ejChart#legend->title->textAlignment
*/
                          textAlignment: 'center',
						  /**		
  * Specifies the font options to customize the legend title.
  * @type {object}
  * @alias ejChart#legend->title->font
  */
                          font:
                              {
							  /**		
* Specifies the size of legend title text.
* @default "12px"
* @type {string}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * legend: { title: { font :{size: "14px" } } }                      
      * });
      * &lt;/script&gt; 
 * @alias ejChart#legend->title->font->size
*/
                                  size: '12px',
								  /**		
* Specifies the font family of legend title text.
* @default "Segoe UI"
* @type {string}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * legend: { title: { font :{fontFamily: "Algerian" } } }                      
      * });
      * &lt;/script&gt; 
 * @alias ejChart#legend->title->font->fontFamily
*/
                                  fontFamily: "Segoe UI",
								   /**		
* Specifies the font style of legend title text.
* @default "normal"
* @type {enum}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * legend: { title: { font :{fontStyle: "normal" } } }                      
      * });
      * &lt;/script&gt; 
 * @alias ejChart#legend->title->font->fontStyle
*/
                                  fontStyle: 'normal',
								  /**		
* Specifies the font weight of legend title text.
* @default "normal"
* @type {enum}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * legend: { title: { font :{fontWeight: "normal" } } }                      
      * });
      * &lt;/script&gt; 
 * @alias ejChart#legend->title->font->fontWeight
*/
								  fontWeight : 'normal'
                              }
                      },
              

                /**		
          * Options for customizing the color and width of the border of legend.
          * @type {object}
           * @alias ejChart#legend->border
          */
                border:
                {
                    /**		
* Specifies the border color of legend.
* @default "transparent"
* @type {string}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * legend : {border :{ color :"green"}}                     
      * });
      * &lt;/script&gt;   
* @alias ejChart#legend->border->color
*/
                    color: 'transparent',

                    /**		
* Specifies the border width of legend.
* @default 1
* @type {number}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * legend :{ border :{width :2}}                     
      * });
      * &lt;/script&gt;  
 * @alias ejChart#legend->border->width
*/
                    width: 1
                },
                /**		
 * Toggles the legend visibility.
 * @default true
 * @type {boolean}			 
 * @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * legend :{visible : false}                     
      * });
      * &lt;/script&gt;   
  * @alias ejChart#legend->visible
 */
                visible: true,
                /**		
* This is used to specify the gap/padding between the legend items.
* @default 10
* @type {number}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * legend :{itemPadding : 5}                     
      * });
      * &lt;/script&gt;  
 * @alias ejChart#legend->itemPadding
*/
                itemPadding: 10,
                /**		
 * This property specifies the shape of the legend items. See {@link Shape}
 * @default ej.datavisualization.Chart.Shape.None
 * @type {enum}				 
 * @example 
 * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * legend :{ shape : "circle" }                      
      * });
      * &lt;/script&gt;  
  * @alias ejChart#legend->shape
 */
                shape: 'None',
                /**		
 * This property is used to change the alignment of the legend horizontally.. See {@link Alignment}
 * @default ej.datavisualization.Chart.Alignment.Center
 * @type {enum}				 
 * @example 
 * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * legend :{alignment : "far"}                    
      * });
      * &lt;/script&gt;   
  * @alias ejChart#legend->alignment
 */
                alignment: 'Center',
                /**		
* This property is used to change the alignment of the data label vertically. See {@link Position}
* @default ej.datavisualization.Chart.Position.Bottom
* @type {enum}				 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * legend :{ position : "top"}                    
      * });
      * &lt;/script&gt;   
* @alias ejChart#legend->position
*/
                position: 'Bottom',
                /**		
          * Contains property to customize the position of the legend
          * @type {object}
          * @alias ejChart#legend->location
          */
                location:
                {
                    /**		
 * This property specifies the x position for rendering legend.
 * @default 0
 * @type {number}				 
 * @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * legend :{location :{x :20}}                    
      * });
      * &lt;/script&gt;   
 * @alias ejChart#legend->location->x
 */
                    x: 0,
                    /**		
* This property specifies the y position for rendering legend.
* @default 0
* @type {number}				 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * legend :{location : {y : 100}}                  
      * });
      * &lt;/script&gt;  
* @alias ejChart#legend->location->y
*/
                    y: 0
                },
                /**		
          * Contains property to customize the legend item style.
          * @type {object}
           * @alias ejChart#legend->itemStyle
          */
                itemStyle:
                {
                    /**		
* Specifies the legend item height.
* @default 10
* @type {number}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * legend :{ itemStyle :{height : 20}}                    
      * });
      * &lt;/script&gt;  
* @alias ejChart#legend->itemStyle->height
*/
                    height: 10,
                    /**		
 * Specifies the legend item width.
 * @default 10
 * @type {number}				 
 * @example 
 * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * legend :{ itemStyle :{width : 15}}                    
      * });
      * &lt;/script&gt; 
      * @alias ejChart#legend->itemStyle->width
 */
                    width: 10,
                    /**		
         * Options for customizing the color and width of the border of legend.
          * @type {object}
           * @alias ejChart#legend->itemStyle->border
          */
                    border:
                    {
                        /**		
 * Specifies the border color of legend.
 * @default "transparent"
 * @type {string}				 
 * @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * legend :{ itemStyle :{border : { color : "green' }}}                    
      * });
      * &lt;/script&gt; 
 * @alias ejChart#legend->itemStyle->border->color
 */
                        color: 'transparent',
                        /**		
 * Specifies the border width of legend.
 * @default 1
 * @type {number}				 
 * @example 
 * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * legend :{ itemStyle :{border :{ width : 2 }}}                    
      * });
      * &lt;/script&gt;  
 * @alias ejChart#legend->itemStyle->border->width
 */
                        width: 1
                    }
                },
                /**		
 * This property specifies the number of rows for the legend items to arrange.
 * @default null
 * @type {number}			
 * @example 
 * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * legend :{ rowCount :2}                    
      * });
      * &lt;/script&gt; 
 * @alias ejChart#legend->rowCount
 */
                rowCount: null,
                /**		
 * This property specifies the number of columns for the legend items to arrange.
 * @default null
 * @type {number}			 
 * @example 
 * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * legend :{ columnCount : 2}                    
      * });
      * &lt;/script&gt; 
 * @alias ejChart#legend->columnCount
 */
                columnCount: null,
                /**		
       * Specifies the opacity of legend
       * @default 1
       * @type {number}				 
       * @example 
       * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * legend :{ opacity : 0.5}                    
      * });
      * &lt;/script&gt; 
       * @alias ejChart#legend->opacity
       */
                opacity: 1,
                /**		
      * Specifies the fill color of legend
      * @default null
      * @type {string}				 
      * @example 
      * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * legend :{ fill : "green"}                    
      * });
      * &lt;/script&gt; 
     * @alias ejChart#legend->fill
      */
                fill: null,
                /**		
          * Specifies the legend font. These font properties are used to customize the legend item text.
          * @type {object}
           * @alias ejChart#legend->font
          */
                font:
                {
                    /**		
    * Specifies the legend fontfamily color. Legend item text render with this specified font family.
    * @default "Segoe UI"
    * @type {string}				
    * @example 
    * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * legend :{ font :{fontFamily : "algerian"}}                    
      * });
      * &lt;/script&gt;  
   * @alias ejChart#legend->font->fontFamily
    */
                    fontFamily: 'Segoe UI',
                    /**		
    * Specifies the legend font style. Legend item text render with this specified font style. See {@link FontStyle}
    * @default ej.datavisualization.Chart.FontStyle.Normal
    * @type {enum}			
    * @example 
   * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * legend :{ font :{fontStyle : "italic"}}                    
      * });
      * &lt;/script&gt; 
    * @alias ejChart#legend->font->fontStyle
    */
                    fontStyle: 'Normal',
                    /**		
    * Specifies the legend font weight.  Legend item text render with this specified font weight.{@link FontWeight}
    * @default ej.datavisualization.Chart.FontWeight.Regular
    * @type {enum}				 
    * @example 
    * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * legend :{ font :{fontWeight : "lighter"}}                    
      * });
      * &lt;/script&gt;  
    * @alias ejChart#legend->font->fontWeight
    */
                    fontWeight: 'Regular',
                    /**		
     * Specifies the legend font size.  Legend item text render with this specified size.
     * @default "12px"
     * @type {string}			 
     * @example 
     * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * legend :{ font :{size : "14px"}}                    
      * });
      * &lt;/script&gt; 
     * @alias ejChart#legend->font->size
     */
                    size: '12px'
                },
                /**		
* Contains property to customize the size of legend.
* @type {object}
* @alias ejChart#legend->size
                  */
                size:
                    {
                        /**
* Specifies the legend height.
* @default null
* @type {number}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
    * $("#container").ejChart({
    * legend :{ size :{height : 20%}}                    
    * });
    * &lt;/script&gt;  
* @alias ejChart#legend->size->height
*/
                        height: null,
                        /**
* Specifies the legend width.
* @default null
* @type {number}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
        * $("#container").ejChart({
        * legend :{ size :{width : 20%}}                    
        * });
        * &lt;/script&gt;  
    * @alias ejChart#legend->size->width
    */
                        width:null
                    }
            },
            /**		
         * Contains properties for customizing the technical indicators.
         * @type {array}
         */
            indicators: /** @lends ejChart# */[
              {
                  points: [],
				  /**
				  * Contains property to customize the tooltip of indicators.
                  * @type {object}
                  * @alias ejChart#indicators->tooltip
                  */
                  tooltip: 
				  { 
				   /**
* Specifies the visibility of indicator tooltip.
* @default false
* @type {boolaean}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
        * $("#container").ejChart({
        * indicators :[{ tooltip :{visible : true}}]                    
        * });
        * &lt;/script&gt;  
    * @alias ejChart#indicators->tooltip->visible
    */
				  visible: false,
				  /**
* Specifies the format of indicator tooltip.
* @default "#point.x# : #point.y#"
* @type {string}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
        * $("#container").ejChart({
        * indicators :[{ tooltip :{format : "#point.x#"}}]                    
        * });
        * &lt;/script&gt;  
    * @alias ejChart#indicators->tooltip->format
    */
				  format: "#point.x# : #point.y#",
				  /**
* Specifies the fill color of indicator tooltip.
* @default null
* @type {string}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
        * $("#container").ejChart({
        * indicators :[{ tooltip :{format : "#point.x#"}}]                    
        * });
        * &lt;/script&gt;  
    * @alias ejChart#indicators->tooltip->format
    */
				  fill: null,
				      /**
                     * Contains property to customize the border of the tooltip in indicators.
                     * @type {object}
                     * @alias ejChart#indicators->tooltip->border
                     */
				  border: {
				      /**
* Specifies the border width of indicator tooltip.
* @default 1
* @type {number}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
     * &lt;script&gt;
       * $("#container").ejChart({
       * indicators :[{ tooltip :{border : { width :2}} }]                    
       * });
       * &lt;/script&gt;  
   * @alias ejChart#indicators->tooltip->border->width
   */
				      width: 1,
				      /**
* Specifies the border color of indicator tooltip.
* @default null
* @type {string}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
    * &lt;script&gt;
      * $("#container").ejChart({
      * indicators :[{ tooltip :{border : { color :"#0000ff"}} }]                    
      * });
      * &lt;/script&gt;  
  * @alias ejChart#indicators->tooltip->border->color
  */
				      color: null
				  },
				      /**
  * Specifies the animation duration of indicator tooltip.
  * @default "500ms"
  * @type {string}			
  * @example 
  * &lt;div id="container"&gt;&lt;/div&gt; 
        * &lt;script&gt;
          * $("#container").ejChart({
          * indicators :[{ tooltip :{duration : "300ms"}}]                    
          * });
          * &lt;/script&gt;  
      * @alias ejChart#indicators->tooltip->duration
      */
				  duration: '500ms',
				      /**
  * Specifies the animation of the indicator tooltip.  ejChart supports animation for the tooltip. This can be enable/disable by this property
  * @default true
  * @type {boolean}			
  * @example 
  * &lt;div id="container"&gt;&lt;/div&gt; 
        * &lt;script&gt;
          * $("#container").ejChart({
          * indicators :[{ tooltip :{enableAnimation : false}}]                    
          * });
          * &lt;/script&gt;  
      * @alias ejChart#indicators->tooltip->enableAnimation
      */
				  enableAnimation: true,
				      /**
  * Specifies the opacity of indicator tooltip.
  * @default 0.95
  * @type {number}			
  * @example 
  * &lt;div id="container"&gt;&lt;/div&gt; 
        * &lt;script&gt;
          * $("#container").ejChart({
          * indicators :[{ tooltip :{opacity : 0.5}}]                    
          * });
          * &lt;/script&gt;  
      * @alias ejChart#indicators->tooltip->opacity
      */
				  opacity: 0.95 
				  },
                  /**
* Specifies the series name of indicator.
* @default ""
* @type {string}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
    * &lt;script&gt;
      * $("#container").ejChart({
      * indicators :[{ seriesName : "rsi"}]                    
      * });
      * &lt;/script&gt;  
  * @alias ejChart#indicators->seriesName
  */
                  seriesName: "",
                  /**
* Specifies the type of the indicator to render.
* @default "sma"
* @type {string}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* indicators :[{ type : "momentum"}]                    
* });
* &lt;/script&gt;  
* @alias ejChart#indicators->type
*/
                  type: "SMA",
                  /**
* Specifies the period of the indicator. Calculations are made based on this for indicator
* @default 14
* @type {number}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* indicators :[{ period : 20}]                    
* });
* &lt;/script&gt;  
* @alias ejChart#indicators->period
*/
                  period: 14,
                  /**
* Specifies the standardDeviations for Bollingerband indicator.
* @default 2
* @type {number}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* indicators :[{ standardDeviations : 3}]                    
* });
* &lt;/script&gt;  
* @alias ejChart#indicators->standardDeviations
*/
                  standardDeviations: 2,
                  /**
* Specifies the kperiod for the stochastic indicator.
* @default 3
* @type {number}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* indicators :[{ kPeriod : 4}]                    
* });
* &lt;/script&gt;  
* @alias ejChart#indicators->kPeriod
*/
                  kPeriod: 3,
                  /**
* Specifies the dperiod for the stochastic indicator.
* @default 3
* @type {number}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* indicators :[{ dPeriod : 4}]                    
* });
* &lt;/script&gt;  
* @alias ejChart#indicators->dPeriod
*/
                  dPeriod: 3,
                  /**
                 * Contains property to customize the period line in indicators.
                 * @type {object}
                 * @alias ejChart#indicators->periodLine
                 */
                  periodLine: {
                      /**
* Specifies the fill color of period line.
* @default "blue"
* @type {string}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* indicators :[{ periodLine : {fill: "#ff0000"}}]                    
* });
* &lt;/script&gt;  
* @alias ejChart#indicators->periodLine->fill
*/
                      fill: "blue",
                      /**
* Specifies the width of period line.
* @default 2
* @type {number}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* indicators :[{ periodLine : {width: 3}}]                    
* });
* &lt;/script&gt;  
* @alias ejChart#indicators->periodLine->width
*/
                      width: 2
                  },
                  /**
               * Contains property to customize the lower line in indicators.
               * @type {object}
               * @alias ejChart#indicators->lowerLine
               */
                  lowerLine: {
                      /**
* Specifies the fill color of lower line.
* @default "#008000"
* @type {string}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* indicators :[{ lowerLine : {fill: "#ff0000"}}]                    
* });
* &lt;/script&gt;  
* @alias ejChart#indicators->lowerLine->fill
*/

                      fill: "#008000",
                      /**
* Specifies the width of lower line.
* @default 2
* @type {number}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* indicators :[{ lowerLine : {width: 3}}]                    
* });
* &lt;/script&gt;  
* @alias ejChart#indicators->lowerLine->width
*/
                      width: 2
                  },
                  /**
               * Contains property to customize the upper line in indicators.
               * @type {object}
               * @alias ejChart#indicators->upperLine
               */
                  upperLine: {
                      /**
* Specifies the fill color of upper line.
* @default "#ff9933"
* @type {string}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* indicators :[{ upperLine : {fill: "#ff0000"}}]                    
* });
* &lt;/script&gt;  
* @alias ejChart#indicators->upperLine->fill
*/
                      fill: "#ff0000",
                      /**
* Specifies the width of upper line.
* @default 2
* @type {number}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* indicators :[{ upperLine : {width: 3}}]                    
* });
* &lt;/script&gt;  
* @alias ejChart#indicators->upperLine->width
*/
                      width: 2
                  },
                  /**
               * Contains property to customize the macd line in indicators.
               * @type {object}
               * @alias ejChart#indicators->macdLine
               */
                  macdLine: {
                      /**
* Specifies the fill color of macd line.
* @default "#ff9933"
* @type {string}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* indicators :[{ macdLine : {fill: "#ff0000"}}]                    
* });
* &lt;/script&gt;  
* @alias ejChart#indicators->macdLine->fill
*/
                      fill: "#ff9933",
                      /**
* Specifies the width of macd line.
* @default 2
* @type {number}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* indicators :[{ macdLine : {width: 3}}]                    
* });
* &lt;/script&gt;  
* @alias ejChart#indicators->macdLine->width
*/
                      width: 2 
                  },
                  /**
               * Contains property to customize the histogram in macd indicator.
               * @type {object}
               * @alias ejChart#indicators->histogram
               */
                  histogram: {
                      /**
* Specifies the fill color of histogram rendered in macd indicator.
* @default "#ccccff"
* @type {string}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* indicators :[{ histogram : {fill: "#ff0000"}}]                    
* });
* &lt;/script&gt;  
* @alias ejChart#indicators->histogram->fill
*/
                      fill: "#ccccff",
                      /**
* Specifies the opacity of histogram rendered in macd indicator.
* @default 1
* @type {number}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* indicators :[{ histogram : {opacity: 0.5}}]                    
* });
* &lt;/script&gt;  
* @alias ejChart#indicators->histogram->opacity
*/
                      opacity: 1,
                      /**
               * Contains property to customize the boder of histogram in macd indicator.
               * @type {object}
               * @alias ejChart#indicators->histogram->border
               */
                      border: {
                          /**
* Specifies the border color of histogram rendered in macd indicator.
* @default "#9999ff"
* @type {string}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* indicators :[{ histogram : {border: {color: "#ff0000"}}}]                    
* });
* &lt;/script&gt;  
* @alias ejChart#indicators->histogram->border->color
*/
                          color: "#9999ff",
                          /**
* Specifies the border width of histogram rendered in macd indicator.
* @default 1
* @type {width}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* indicators :[{ histogram : {border: {width: 2}}}]                    
* });
* &lt;/script&gt;  
* @alias ejChart#indicators->histogram->border->width
*/
                          width: 1
                      }
                  },
                  /**
* Specifies the fill color of the indicator line
* @default "#00008B"
* @type {string}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* indicators :[{ fill : "#ff0000"}]                    
* });
* &lt;/script&gt;  
* @alias ejChart#indicators->fill
*/
                  fill: "#00008B",
                  /**
               * Contains property to customize the font of the text in indicator.
               * @type {object}
               * @alias ejChart#indicators->font
               */
                  font: {
                      /**
* Specifies the font family of the text in indicator
* @default "segoe UI"
* @type {string}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* indicators :[{ font :{ fontFamily: "Algerian" }}]                    
* });
* &lt;/script&gt;  
* @alias ejChart#indicators->font->fontFamily
*/
                      fontFamily: 'Segoe UI',
                      /**
* Specifies the font style of the text in indicator
* @default "Normal"
* @type {string}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* indicators :[{ font :{ fontStyle: "Italic" }}]                    
* });
* &lt;/script&gt;  
* @alias ejChart#indicators->font->fontStyle
*/
                      fontStyle: 'Normal',
                      /**
* Specifies the font weight of the text in indicator
* @default "Regular"
* @type {string}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* indicators :[{ font :{ fontWeight: "Regular" }}]                    
* });
* &lt;/script&gt;  
* @alias ejChart#indicators->font->fontWeight
*/
                      fontWeight: 'Regular',
                      /**
* Specifies the size of the text in indicator
* @default "12px"
* @type {string}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* indicators :[{ font :{ size: "14px" }}]                    
* });
* &lt;/script&gt;  
* @alias ejChart#indicators->font->size
*/
                      size: '12px',
                      /**
* Specifies the font color of the text in indicator
* @default "#707070"
* @type {string}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* indicators :[{ font :{ color: "#ff00ff" }}]                    
* });
* &lt;/script&gt;  
* @alias ejChart#indicators->font->color
*/
                      color: '#707070',
                      /**
* Specifies the font opacity of the text in indicator
* @default 0.5
* @type {number}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* indicators :[{ font :{ opacity: 1 }}]                    
* });
* &lt;/script&gt;  
* @alias ejChart#indicators->font->opacity
*/
                      opacity: 1
                  },
                  /**
* Specifies the width of the indicator line
* @default 2
* @type {number}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* indicators :[{ width :  3}]                    
* });
* &lt;/script&gt;  
* @alias ejChart#indicators->width
*/
                  width: 2,
                  /**
* Specifies the xAxisName of the indicator
* @default ""
* @type {string}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* indicators :[{ xAxisName :  "xAxis"}]                    
* });
* &lt;/script&gt;  
* @alias ejChart#indicators->xAxisName
*/
                  xAxisName: "",
                  /**
* Specifies the yAxisName of the indicator
* @default ""
* @type {string}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* indicators :[{ yAxisName :  "yAxis"}]                    
* });
* &lt;/script&gt;  
* @alias ejChart#indicators->yAxisName
*/
                  yAxisName: "",
                  /**
* Specifies the type of macd indicator. It can be a line or histogram or both.
* @default "line"
* @type {string}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* indicators :[{ macdType :  "both"}]                    
* });
* &lt;/script&gt;  
* @alias ejChart#indicators->macdType
*/
                  macdType: "line",
                  /**
* Specifies the short period for macd indicator
* @default 13
* @type {number}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* indicators :[{ shortPeriod :  14"}]                    
* });
* &lt;/script&gt;  
* @alias ejChart#indicators->shortPeriod
*/
                  shortPeriod: 12,
                  /**
* Specifies the long period for macd indicator
* @default 26
* @type {number}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* indicators :[{ longPeriod :  14"}]                    
* });
* &lt;/script&gt;  
* @alias ejChart#indicators->longPeriod
*/
                  longPeriod: 26,
                  /**
* Specifies the trigger value for macd indicator
* @default 9
* @type {number}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* indicators :[{ trigger :  14}]                    
* });
* &lt;/script&gt;  
* @alias ejChart#indicators->trigger
*/
                  trigger: 9,
                  /**
* Specifies the visibility of indicator
* @default "visible"
* @type {string}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* indicators :[{ visibility :  "visible"}]                    
* });
* &lt;/script&gt;  
* @alias ejChart#indicators->trigger
*/
                  visibility: "visible",
                  /**
* Specifies the animation of the indicator.  ejChart supports animation for the indicator. This can be enable/disable by this property
* @default false
* @type {boolean}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* indicators :[{ enableAnimation :  true}]                    
* });
* &lt;/script&gt;  
* @alias ejChart#indicators->enableAnimation
*/
                  enableAnimation:false
              }
            ],
            /**		
         * Specifies the properties used for customizing the series.
         * @type {array}
         */
            series: /** @lends ejChart# */[
                {
                    /**		
     * Specifies the type of series to be rendered in chart. see {@link Type}
     * @default "line"
     * @type {enum}			 
     * @example 
     * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * series : [{type : "column" }]                   
      * });
      * &lt;/script&gt; 
     * @alias ejChart#series->type
     */
                    type: 'column',
                    /**		
    * Specifies the animation of the series.  ejChart supports animation for the series. This can be enable/disable by this property
    * @default true
    * @type {boolean}			 
    * @example 
    * &lt;div id="container"&gt;&lt;/div&gt; 
     * &lt;script&gt;
     * $("#container").ejChart({
     * series : [{enableAnimation : false }]                   
     * });
     * &lt;/script&gt; 
    * @alias ejChart#series->enableAnimation
    */
                    enableAnimation: false,
                    /**		
    * Used in Polar and Radar series to specify whether the line/area series has to be rendered in a closed state by joining the start and end point of the series.
    * @default true
    * @type {boolean}			 
    * @example 
    * &lt;div id="container"&gt;&lt;/div&gt; 
     * &lt;script&gt;
     * $("#container").ejChart({
     * series : [{isClosed : false }]                   
     * });
     * &lt;/script&gt; 
    * @alias ejChart#series->isClosed
    */
                    isClosed: true,
                    /**		
    * Used in Polar and Radar series to specify whether column type has to be rendered the stacked value of chart.
    * @default true
    * @type {boolean}			 
    * @example 
    * &lt;div id="container"&gt;&lt;/div&gt; 
     * &lt;script&gt;
     * $("#container").ejChart({
     * series : [{isStacking : false }]                   
     * });
     * &lt;/script&gt; 
    * @alias ejChart#series->isStacking
    */
                    isStacking: true,
                    /**		
    * Specifies the type of series that can be drawn in a Radar or Polar series. It supports line, column and area type. See {@link DrawType}
    * @default true
    * @type {boolean}			 
    * @example 
    * &lt;div id="container"&gt;&lt;/div&gt; 
     * &lt;script&gt;
     * $("#container").ejChart({
     * series : [{drawType : false }]                   
     * });
     * &lt;/script&gt; 
    * @alias ejChart#series->drawType
    */
                    drawType: 'line',
                    /**		
    * Sets the radius of the hole on the doughnut series with respect to plot area. Value ranges from 0 to 1.
    * @default 0.4
    * @type {number}			 
    * @example 
    * &lt;div id="container"&gt;&lt;/div&gt; 
     * &lt;script&gt;
     * $("#container").ejChart({
     * series : [{doughnutCoefficient : 0.5 }]                   
     * });
     * &lt;/script&gt; 
    * @alias ejChart#series->doughnutCoefficient
    */
                    doughnutCoefficient: 0.4,
                    /**		
   * Represents the distance the slice has to be moved out when it is exploded.
   * @default 25
   * @type {number}			 
   * @example 
   * &lt;div id="container"&gt;&lt;/div&gt; 
    * &lt;script&gt;
    * $("#container").ejChart({
    * series : [{explodeOffset : 20 }]                   
    * });
    * &lt;/script&gt; 
   * @alias ejChart#series->explodeOffset
   */
                    explodeOffset: 25,
                    /**		
  * Sets the rendering mode of the pyramid as linear or surface.
  * @default "linear"
  * @type {enum}			 
  * @example 
  * &lt;div id="container"&gt;&lt;/div&gt; 
   * &lt;script&gt;
   * $("#container").ejChart({
   * series : [{pyramidMode : "linear" }]                   
   * });
   * &lt;/script&gt; 
  * @alias ejChart#series->pyramidMode
  */
                    pyramidMode: 'linear',
/**		
  * Sets the funnel width.
  * @default "11.6%"(11.6% of actualwidth)
  * @type {string}
  * @example 
  * &lt;div id="container"&gt;&lt;/div&gt; 
   * &lt;script&gt;
   * $("#container").ejChart({
   * series : [{funnelWidth : '40%' }]                   
   * });
   * &lt;/script&gt; 
   * @alias ejChart#series->funnelWidth
  */
                    funnelWidth: '11.6%',
                    /**		
  * Sets the funnel height.
  * @default "32.7%"(32.7% of actualheight)
  * @type {string}
  * @example 
  * &lt;div id="container"&gt;&lt;/div&gt; 
   * &lt;script&gt;
   * $("#container").ejChart({
   * series : [{funnelHeight : '40%' }]                   
   * });
   * &lt;/script&gt; 
   * @alias ejChart#series->funnelHeight
  */
                    funnelHeight:'32.7%',
                    /**		
  * Specifies the position of the axis labels to render labels either inside or outside of plot area. See {@link LabelPosition}
  * @default "inside"
  * @type {enum}			 
  * @example 
  * &lt;div id="container"&gt;&lt;/div&gt; 
   * &lt;script&gt;
   * $("#container").ejChart({
   * series : [{labelPosition : "outside" }]                   
   * });
   * &lt;/script&gt; 
  * @alias ejChart#series->labelPosition
  */
                    labelPosition: 'inside',
                    /**		
 * Specifies the gap between each slice of a pyramid series in pixels.
 * @default 0
 * @type {number}			 
 * @example 
 * &lt;div id="container"&gt;&lt;/div&gt; 
  * &lt;script&gt;
  * $("#container").ejChart({
  * series : [{gapRatio : 2 }]                   
  * });
  * &lt;/script&gt; 
 * @alias ejChart#series->gapRatio
 */
                    gapRatio: 0,
                    /**		
* Specifies the points of the series.  This is to specify the point values for the series
* @default [ ] 
* @type {array}			 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
 * &lt;script&gt;
 * $("#container").ejChart({
 * series : [{points : [{x : 2000, y : 15}] }]                   
 * });
 * &lt;/script&gt; 
* @alias ejChart#series->points
*/
                    points: null,
                    /**		
* Sets the radius of the pie series with respect to plot area. Value ranges from 0 to 1.
* @default 0.8
* @type {number}			 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
 * &lt;script&gt;
 * $("#container").ejChart({
 * series : [{pieCoefficient : 0.6 }]                   
 * });
 * &lt;/script&gt; 
* @alias ejChart#series->pieCoefficient
*/
                    pieCoefficient: 0.8,
                    /**		
* Sets the radius of the doughnut series with respect to plot area. Value ranges from 0 to 1. 
* @default 0.8
* @type {number}			 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* series : [{doughnutSize : 0.6 }]                   
* });
* &lt;/script&gt; 
* @alias ejChart#series->doughnutSize
*/
                    doughnutSize: 0.8,
                    /**		
* Specifies the dataSource for series. 
* @default null	
* @type {object}
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* series : [{dataSource: data.open }]                   
* });
* &lt;/script&gt; 
* @alias ejChart#series->dataSource
*/
                    dataSource: null,
                    /**		
* Specifies the bullFillColor for series.  This is used in hilo series types
* @default null
* @type {string}			 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* series : [{bullFillColor: "green" }]                   
* });
* &lt;/script&gt; 
* @alias ejChart#series->bullFillColor
*/
                    bullFillColor: null,
                    /**		
* Specifies the bearFillColor for series.  This is used in hilo series types
* @default null
* @type {string}			 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* series : [{bearFillColor: "blue" }]                   
* });
* &lt;/script&gt; 
* @alias ejChart#series->bearFillColor
*/
                    bearFillColor: null,
                    /**		
* Specifies the query for dataSource in series.  This is used to take the query from dataSource
* @default null
* @type {object}			 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* var query =  ej.Query().from("Orders").take(10);
* $("#container").ejChart({
* series : [{query: query }]                   
* });
* &lt;/script&gt; 
* @alias ejChart#series->query
*/
                    query: null,
                    /**		
* Specifies the xName for dataSource in series.  This is used to take the x values from dataSource
* @default null	
* @type {string}
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* series : [{xName: "XValue" }]                   
* });
* &lt;/script&gt; 
* @alias ejChart#series->xName
*/
                    xName: '',
                    /**		
* Specifies the yName for dataSource in series.  This is used to take the y values from dataSource
* @default null
* @type {string}			 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* series : [{yName: "YValue" }]                   
* });
* &lt;/script&gt; 
* @alias ejChart#series->yName
*/
                    yName: '',
                    /**		
* Specifies the visibility for series.  This is used to change the visibility of series
* @default "visible"
* @type {string}			 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* series : [{visibility: "hidden" }]                   
* });
* &lt;/script&gt; 
* @alias ejChart#series->visibility
*/
                    visibility: "visible",
                    /**		
* Specifies the starting angle for rendering pie / doughnut series.
* @default null
* @type {number}			 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* series : [{startAngle: 140 }]                   
* });
* &lt;/script&gt; 
* @alias ejChart#series->startAngle
*/
                    startAngle: null,
                    /**		
* Specifies the ending angle for rendering pie / doughnut series.
* @default null
* @type {number}			 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
        * $("#container").ejChart({
        * series : [{endAngle: 270 }]                   
        * });
        * &lt;/script&gt; 
        * @alias ejChart#series->endAngle
        */
                    endAngle:null,
                    /**		
* Specifies the XAxisName for series.  This is used to specify the name of the xAxis
* @default null
* @type {string}			 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* series : [{xAxisName: "xAxis" }]                   
* });
* &lt;/script&gt; 
* @alias ejChart#series->xAxisName
*/
                    xAxisName: null,
                    /**		
* Specifies the yAxisName for series.  This is used to specify the name of the yAxis
* @default null
* @type {string}			 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* series : [{yAxisName: "yAxis" }]                   
* });
* &lt;/script&gt; 
* @alias ejChart#series->yAxisName
*/
                    yAxisName: null,
                    /**		
* Explodes all the pie slices. (Also works for doughnut series)es
* @default null
* @type {boolean}			 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* series : [{explodeAll: true }]                   
* });
* &lt;/script&gt; 
* @alias ejChart#series->explodeAll
*/
                    explodeAll: null,
                    /**		
* Index of a slice to be exploded from the whole pie. (Also works for doughnut series)
* @default null
* @type {number}			 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* series : [{explodeIndex : 2 }]                   
* });
* &lt;/script&gt; 
* @alias ejChart#series->explodeIndex
*/
                    explodeIndex: null,  
                    /**		
* Enabling this property can avoid pie series data label overlap each other.
* @default null
* @type {number}			 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* series : [{enableSmartLabels : false }]                   
* });
* &lt;/script&gt; 
* @alias ejChart#series->enableSmartLabels
*/
                    enableSmartLabels: true,
                    /**		
      * Contains all the properties to customize tooltip
      * @type {object}
       * @alias ejChart#series->tooltip
      */
                    tooltip: {
                        /**		
* tooltip visibility can be toggled using this property
* @default false
* @type {boolean}			 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* series : [{tooltip : {visible : true} }]                   
* });
* &lt;/script&gt; 
* @alias ejChart#series->tooltip->visible
*/
                        visible: false,
                        /**		
* Formatting the values of point on a tooltip can be customized using this property.
* @default "#point.x# : #point.y#"
* @type {string}			 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* series : [{tooltip : {format : "#point.x# : #point.y#"} }]                   
* });
* &lt;/script&gt; 
* @alias ejChart#series->tooltip->format
*/
                        format: "#point.x# : #point.y#",
                        /**		
* Specifies the fill color of the tooltip.
* @default null
* @type {string}			 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* series : [{tooltip : {fill : "green"} }]                   
* });
* &lt;/script&gt; 
* @alias ejChart#series->tooltip->fill
*/
                        fill: null,
                        /**		
      * Options for customizing the color, opacity and width of the border of tooltip.
      * @type {object}
       * @alias ejChart#series->tooltip->border
      */
                        border: {
                            /**		
* Specifies the width of tooltip.
* @default 1
* @type {number}			 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* series : [{tooltip : {border : { width :2} }]                   
* });
* &lt;/script&gt; 
* @alias ejChart#series->tooltip->border->width
*/
                            width: 1,
                            /**		
* Specifies the color of tooltip.
* @default null
* @type {string}			 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* series : [{tooltip : {border : { color :"green"} }]                   
* });
* &lt;/script&gt; 
* @alias ejChart#series->tooltip->border->color
*/
                            color: null
                        },
                        /**		
* Enabling this property animates the tooltip on moving the cursor from one point to the other.
* @default true
* @type {boolean}			 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* series : [{tooltip : { enableAnimation: false }]                   
* });
* &lt;/script&gt; 
* @alias ejChart#series->tooltip->enableAnimation
*/
                        enableAnimation: true,
                        /**		
* Specifies the duration of the tooltip to stay awake.
* @default "500ms"
* @type {string}			 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* series : [{tooltip : { duration: "300ms" }]                   
* });
* &lt;/script&gt; 
* @alias ejChart#series->tooltip->duration
*/
                        duration: '500ms',
                        /**		
* Specifies the opacity of the tooltip. Values ranges from 0 to 1.
* @default 0.95
* @type {number}			 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* series : [{tooltip : { opacity: 0.5 }]                   
* });
* &lt;/script&gt; 
* @alias ejChart#series->tooltip->opacity
*/
                        opacity: 0.95
                    },
                    /**		
         * Specifies the fill color of series.
         * @default null
         * @type {string}			 
         * @example 
        * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * series :[{fill : "green"}]                 
      * });
      * &lt;/script&gt;
        * @alias ejChart#series->fill
         */
                    fill: null,
                    /**		
       * Specifies the opacity of series.  Series render with this specified opacity.
       * @default 1
       * @type {number}				 
       * @example 
       * &lt;div id="container"&gt;&lt;/div&gt; 
     * &lt;script&gt;
     * $("#container").ejChart({
     * series :[{opacity : 0.5}]                  
     * });
     * &lt;/script&gt; 
        * @alias ejChart#series->opacity
       */
                    opacity: 1,
                    /**		
      * Specifies the style to draw the end point of a line like butt, round, square. See {@link LineCap}
      * @default ej.datavisualization.Chart.LineCap.Butt
      * @type {enum}				 
      * @example 
      * &lt;div id="container"&gt;&lt;/div&gt; 
     * &lt;script&gt;
     * $("#container").ejChart({
     * series :[{lineCap : "butt"}]                  
     * });
     * &lt;/script&gt;
       * @alias ejChart#series->lineCap
      */
                    lineCap: 'butt',
                    /**		
     * Specifies the shape to use at the intersection of two lines drawn.  See {@link LineJoin}
     * @default ej.datavisualization.Chart.LineJoin.Round
     * @type {enum}				 
     * @example 
     * &lt;div id="container"&gt;&lt;/div&gt; 
     * &lt;script&gt;
     * $("#container").ejChart({
     * series :[{lineCap : "round"}]                  
     * });
     * &lt;/script&gt; 
      * @alias ejChart#series->lineJoin
     */
                    lineJoin: 'round',
                    /**		
     * Controls the pattern of dashes and gaps used to stroke the line series.
     * @default ""
     * @type {string}				 
     * @example 
    * &lt;div id="container"&gt;&lt;/div&gt; 
     * &lt;script&gt;
     * $("#container").ejChart({
     * series :[{dashArray : "2,3"}]                  
     * });
     * &lt;/script&gt; 
      * @alias ejChart#series->dashArray
     */
                    dashArray: "",
                    /**		
         * Specifies the border of the series. These are the properties involved in customizing the series border.
         * @type {object}
           * @alias ejChart#series->border
         */
                    border: {
                        /**		
   * Specifies the border width of series.Series in chart render with this specified value as border width
   * @default 1
   * @type {number}			 
   * @example 
   * &lt;div id="container"&gt;&lt;/div&gt; 
     * &lt;script&gt;
     * $("#container").ejChart({
     * series :[{border :{ width : 2 } }]                  
     * });
     * &lt;/script&gt;
    * @alias ejChart#series->border->width
   */
                        width: 1,
                        /**		
  * Specifies the border color of series. Series in chart render with this specified color as border color
  * @default "transparent"
  * @type {string}			 
  * @example 
 * &lt;div id="container"&gt;&lt;/div&gt; 
     * &lt;script&gt;
     * $("#container").ejChart({
     * series :[{border :{ color : "green" } }]                  
     * });
     * &lt;/script&gt;
  * @alias ejChart#series->border->color
  */
                        color: 'transparent'
                    },
                    width: 2,
                    /**		
       * Contains the customizing properties to add marker symbols to the points plotted in the chart.
       * @type {object}
         * @alias ejChart#series->marker
       */
                    marker: {
                        /**		
 * Specifies the shape of the marker. See {@link Shape}
 * @default ej.datavisualization.Chart.Shape.Circle
 * @type {enum}				
 * @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
     * &lt;script&gt;
     * $("#container").ejChart({
     * series :[{marker :{ shape: "rectangle"}]                  
     * });
     * &lt;/script&gt;
  * @alias ejChart#series->marker->shape
 */
                        shape: 'circle',
                        /**		
        * Specifies the size of the marker.
        * @type {object}
         * @alias ejChart#series->marker->size
        */
                        size: {
                            /**		
 * Specifies the width of the marker.
 * @default 6
 * @type {number}				 
 * @example 
 * &lt;div id="container"&gt;&lt;/div&gt; 
     * &lt;script&gt;
     * $("#container").ejChart({
     * series :[{marker :{ size :{ width : 2 } } }]                  
     * });
     * &lt;/script&gt;
 * @alias ejChart#series->marker->size->width
 */
                            width: 6,
                            /**		
* Specifies the height of the marker. 
* @default 6
* @type {number}				 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
     * &lt;script&gt;
     * $("#container").ejChart({
     * series :[{marker :{size :{height : 5}}}]                 
     * });
     * &lt;/script&gt;
* @alias ejChart#series->marker->size->height
*/
                            height: 6
                        },
                        /**		
* Toggles the visibility of the marker.
* @default false
* @type {boolean}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
     * &lt;script&gt;
     * $("#container").ejChart({
     * series :[{marker :{ visible : true}}]                  
     * });
     * &lt;/script&gt; 
* @alias ejChart#series->marker->visible
*/
                        visible: false,
                        /**		
* Specifies the opacity of the marker. Values ranges from 0 to 1.
* @default 1
* @type {number}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
     * &lt;script&gt;
     * $("#container").ejChart({
     * series :[{marker :{ opacity : 0.5 }}]                  
     * });
     * &lt;/script&gt;
* @alias ejChart#series->marker->opacity
*/
                        opacity: 1,
                        /**		
* Specifies the fill color of the marker.
* @default null
* @type {string}				 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
     * &lt;script&gt;
     * $("#container").ejChart({
     * series :[{marker : { fill : "green" } }]                  
     * });
     * &lt;/script&gt;
* @alias ejChart#series->marker->fill
*/
                        fill: null,
                        /**		
      * Options for customizing the color, opacity and width of the border of marker.
      * @type {object}
       * @alias ejChart#series->marker->border
      */
                        border: {
                            /**		
                        * Specifies the border color of marker.
                        * @default "white"
                        * @type {string}				 
                        * @example 
                        * &lt;div id="container"&gt;&lt;/div&gt; 
                        * &lt;script&gt;
                        * $("#container").ejChart({
                        * series :[{color : "green"}]                  
                        * });
                        * &lt;/script&gt; 
                        * @alias ejChart#series->marker->border->color
                        */
                            color: 'white',
                            /**		
* Specifies the width of the marker
* @default 3
* @type {number}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * series :[{marker :{border :{width : 2}}}]                  
      * });
      * &lt;/script&gt;
* @alias ejChart#series->marker->border->width
*/
                            width: 3
                        },
                        /**		
       * Contains the customizing properties to add data labels of the points plotted in the chart.
       * @type {object}
        * @alias ejChart#series->marker->dataLabel
       */
                        dataLabel: {
                            /**		
* Specifies the visibility of dataLabel in the marker. The user can change the visibility of dataLabel by applying this property.
* @default false
* @type {boolean}			 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * series :[{marker :{dataLabel :{visible : true}}]                  
      * });
      * &lt;/script&gt; 
* @alias ejChart#series->marker->dataLabel->visible
*/
                            visible: false,
                            /**		
* Specifies the rotation angle of dataLabel in the marker. The user can change the rotation angle of dataLabel by applying this property.
* @default null
* @type {number}			 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * series :[{marker :{dataLabel :{angle : 90}}]                  
      * });
      * &lt;/script&gt; 
* @alias ejChart#series->marker->dataLabel->angle
*/
                            angle:0,
                            /**		
* This property is used to change the alignment of the data label vertically.
* @default ej.datavisualization.Chart.verticalTextAlignment.Center
* @type {enum}				 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
     * &lt;script&gt;
     * $("#container").ejChart({
     * series :[{marker :{dataLabel :{verticalTextAlignment : "far"}}}]                  
     * });
     * &lt;/script&gt;
* @alias ejChart#series->marker->dataLabel->verticalTextAlignment
*/
                            verticalTextAlignment: 'center',
                            /**		
* This property is used to change the alignment of the data label horizontally.
* @default ej.datavisualization.Chart.horizontalTextAlignment.Center
* @type {enum}			 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
    * &lt;script&gt;
    * $("#container").ejChart({
    * series :[{marker :{dataLabel :{horizontalTextAlignment : "far"}}}]                  
    * });
    * &lt;/script&gt;
* @alias ejChart#series->marker->dataLabel->horizontalTextAlignment
*/
                            horizontalTextAlignment: 'center',
                            /**		
* This property is used to change the position of the text in data label. See {@link TextPosition}
* @default ej.datavisualization.Chart.textPosition.Top
* @type {enum}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
     * &lt;script&gt;
     * $("#container").ejChart({
     * series :[{marker :{dataLabel :{textPosition : "bottom"}}}]                 
     * });
     * &lt;/script&gt;
* @alias ejChart#series->marker->dataLabel->textPosition
*/
                            textPosition: 'top',
                            /**		
* Specifies the rendering shape of the marker. See {@link Shape}
* @default ej.datavisualization.Chart.Shape.None
* @type {enum}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * series :[{marker :{dataLabel :{shape : "circle"}}}]                 
      * });
      * &lt;/script&gt;
* @alias ejChart#series->marker->dataLabel->shape
*/
                            shape: 'none',
                            /**		
* Specifies the opacity of dataLabel.
* @default 1
* @type {number}				 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * series :[{marker :{dataLabel :{opacity : 0.5}}}]                 
      * });
      * &lt;/script&gt;
* @alias ejChart#series->marker->dataLabel->opacity
*/
                            opacity: 1,
                            /**		
         * Specifies the fill color of dataLabel.
         * @default null
         * @type {string}				 
         * @example 
         * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * series :[{marker :{dataLabel :{fill : "green"}}}]                 
      * });
      * &lt;/script&gt; 
         * @alias ejChart#series->marker->dataLabel->fill
         */
                            fill: null,
                            /**		
 * Options for customizing the color, opacity and width of the border of datalabel.
 * @type {object}
  * @alias ejChart#series->marker->dataLabel->border
 */
                            border: {
                                /**		
         * Specifies the border color of datalabel.
         * @default null
         * @type {string}				 
         * @example 
         * &lt;div id="container"&gt;&lt;/div&gt; 
     * &lt;script&gt;
     * $("#container").ejChart({
     * series :[{marker :{dataLabel :{border : {color : "green"}}}}]                 
     * });
     * &lt;/script&gt;
         * @alias ejChart#series->marker->dataLabel->border->color
         */
                                color: 'white',
                                /**		
         * Specifies the border width of dataLabel.
         * @default 0.1
         * @type {number}				 
         * @example 
         * &lt;div id="container"&gt;&lt;/div&gt; 
     * &lt;script&gt;
     * $("#container").ejChart({
     * series :[{marker :{dataLabel :{border :{ width :2 }}}}]                 
     * });
     * &lt;/script&gt; 
        * @alias ejChart#series->marker->dataLabel->border->width
         */
                                width: 0.1
                            },
                            /**		
     * Contains the options to customize the line connecting the point and the data label.
     * @type {object}
     * @alias ejChart#series->marker->dataLabel->connectorLine
     */
                            connectorLine: {
                                /**		
            * Specifies the width of the connector line.
            * @default 0.5
            * @type {number}				 
            * @example 
            * &lt;div id="container"&gt;&lt;/div&gt; 
     * &lt;script&gt;
     * $("#container").ejChart({
     * series :[{marker :{dataLabel :{connectorLine :{ width : 2 }}}}]                 
     * });
     * &lt;/script&gt; 
            * @alias ejChart#series->marker->dataLabel->connectorLine->width
            */
                                width: 0.5,
                                /**		
            * Specifies whether to connect the point and data label using bezier curve or straight line. See {@link Type}
            * @default ej.datavisualization.Chart.Type.Line
            * @type {enum}			 
            * @example 
           * &lt;div id="container"&gt;&lt;/div&gt; 
     * &lt;script&gt;
     * $("#container").ejChart({
     * series :[{marker :{dataLabel :{connectorLine :{ type : "spline" }}}}]                 
     * });
     * &lt;/script&gt;
            * @alias ejChart#series->marker->dataLabel->connectorLine->type
            */
                                type: 'line'
                            },
                            /**		
     * Specifies the font of the dataLabel. These are the properties involved in customizing the data label font.
     * @type {object}
      * @alias ejChart#series->marker->dataLabel->font 
     */
                            font: {
                                /**		
           * Specifies the fontFamily of dataLabel. Text in the data label render with the specified font family.
           * @default "Segoe UI"
           * @type {string}				 
           * @example 
          * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * series :[{marker :{dataLabel :{ font :{fontFamily : "algerian"}}}}]                 
      * });
      * &lt;/script&gt; 
          * @alias ejChart#series->marker->dataLabel->font->fontFamily
           */
                                fontFamily: 'Segoe UI',
                                /**		
        * Specifies the fontStyle of dataLabel. Text in the data label render with the specified font style. See {@link FontStyle}
        * @default ej.datavisualization.Chart.FontStyle.Normal
        * @type {enum}			 
        * @example 
        * &lt;div id="container"&gt;&lt;/div&gt; 
    * &lt;script&gt;
    * $("#container").ejChart({
    * series :[{marker :{dataLabel :{font :{ fontStyle : "italic" }}}}]                 
    * });
    * &lt;/script&gt; 
        * @alias ejChart#series->marker->dataLabel->font->fontStyle
        */
                                fontStyle: 'Normal',
                                /**		
         * Specifies the fontWeight of dataLabel. Text in the data label render with the specified font weight. See {@link FontWeight}
         * @default ej.datavisualization.Chart.FontWeight.Regular
         * @type {enum}				 
         * @example 
         * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * series :[{marker :{dataLabel :{font : { fontWeight : "lighter" }}}}]                 
      * });
      * &lt;/script&gt;
         * @alias ejChart#series->marker->dataLabel->font->fontWeight
         */
                                fontWeight: 'Regular',
                                /**		
        * Specifies the font size of dataLabel. Text in the data label render with the specified font size.
        * @default "12px"
        * @type {string}			 
        * @example 
        * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * series :[{marker :{dataLabel :{font : { size : "14px" }}}}]                 
      * });
      * &lt;/script&gt; 
        * @alias ejChart#series->marker->dataLabel->font->size
        */
                                size: '12px',
                                /**		
      * Specifies the opacity of the text in dataLabel. Text in the data label render with the specified opacity.
      * @default 1
      * @type {number}				 
      * @example 
      * &lt;div id="container"&gt;&lt;/div&gt; 
     * &lt;script&gt;
     * $("#container").ejChart({
     * series :[{marker :{dataLabel :{font :{ opacity : 0.5 }}}}]                 
     * });
     * &lt;/script&gt;
      * @alias ejChart#series->marker->dataLabel->font->opacity
      */
                                opacity: 1
                            },
                            /**		
     * Specifies the margin for the data label.
     * @type {object}
      * @alias ejChart#series->marker->dataLabel->margin
     */
                            margin: {
                                /**		
     * Specifies the left margin value in dataLabel. By specifying this property, we can adjust the text in data label to left.
     * @default 5
     * @type {number}				 
     * @example 
     * &lt;div id="container"&gt;&lt;/div&gt; 
     * &lt;script&gt;
     * $("#container").ejChart({
     * series :[{marker :{dataLabel :{margin :{ left : 10}}}}]                 
     * });
     * &lt;/script&gt; 
     * @alias ejChart#series->marker->dataLabel->margin->left
     */
                                left: 5,
                                /**		
     * Specifies the top margin value in dataLabel. By specifying this property, we can adjust the text in data label to top.
     * @default 5
     * @type {number}				 
     * @example 
     * &lt;div id="container"&gt;&lt;/div&gt; 
     * &lt;script&gt;
     * $("#container").ejChart({
     * series :[{marker :{dataLabel :{margin :{ top :10 } }}}]                 
     * });
     * &lt;/script&gt;
     * @alias ejChart#series->marker->dataLabel->margin->top
     */
                                top: 5,
                                /**		
      * Specifies the bottom margin value in dataLabel. By specifying this property, we can adjust the text in data label to bottom.
      * @default 5
      * @type {number}				
      * @example 
      * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * series :[{marker :{dataLabel :{margin :{ bottom :10 }}}}]                 
      * });
      * &lt;/script&gt;
      * @alias ejChart#series->marker->dataLabel->margin->bottom
      */
                                bottom: 5,
                                /**		
     * Specifies the right margin value in dataLabel. By specifying this property, we can adjust the text in data label to right.
     * @default 5
     * @type {number}			
     * @example 
      * &lt;div id="container"&gt;&lt;/div&gt; 
     * &lt;script&gt;
     * $("#container").ejChart({
     * series :[{marker :{dataLabel :{margin :{ right :10 }}}}]                 
     * });
     * &lt;/script&gt;
     * @alias ejChart#series->marker->dataLabel->margin->right
     */
                                right: 5
                            }

                        }
                    },
                    /**		
      * Specifies the font that is common to all series. These are the properties involved in customizing the font of the series in chart. 
      * @type {object}
       * @alias ejChart#series->font
      */
                    font: {
                        /**		
     * Specifies the fontFamily, that is common to all series. Text in the series, render with the specified font family.
     * @default "Segoe UI"
     * @type {string}				 
     * @example 
      * &lt;div id="container"&gt;&lt;/div&gt; 
     * &lt;script&gt;
     * $("#container").ejChart({
     * series :[{ font : { fontFamily : "Algerian"}}]                 
     * });
     * &lt;/script&gt; 
     * @alias ejChart#series->font->fontFamily
     */
                        fontFamily: 'Segoe UI',
                        /**		
    * Specifies the fontStyle, that is common to all series. Text in the series, render with the specified font style.
    * @default ej.datavisualization.Chart.FontStyle.Normal
    * @type {enum}		
    * @example 
     * &lt;div id="container"&gt;&lt;/div&gt; 
    * &lt;script&gt;
    * $("#container").ejChart({
    * series : [{font :{fontStyle : "italic"}} ]                
    * });
    * &lt;/script&gt;
   * @alias ejChart#series->font->fontStyle
    */
                        fontStyle: 'Normal',
                        /**		
    * Specifies the fontWeight, that is common to all series. Text in the series, render with the specified font weight.
    * @default ej.datavisualization.Chart.FontWeight.Regular
    * @type {enum}				 
    * @example 
    * &lt;div id="container"&gt;&lt;/div&gt; 
     * &lt;script&gt;
     * $("#container").ejChart({
     * series :[{font :{fontWeight : "lighter"}}]                 
     * });
     * &lt;/script&gt;
    * @alias ejChart#series->font->fontWeight
    */
                        fontWeight: 'Regular',
                        /**		
    * Specifies the font size, that is common to all series. Text in the series, render with the specified font size.
    * @default "12px"
    * @type {string}				 
    * @example 
    * &lt;div id="container"&gt;&lt;/div&gt; 
     * &lt;script&gt;
     * $("#container").ejChart({
     * series :[{font :{size : "14px"}}]                 
     * });
     * &lt;/script&gt; 
    * @alias ejChart#series->font->size
    */
                        size: '12px',
                        /**		
   * Specifies the color, that is common to all series. Text in the series, render with the specified font color.
   * @default "#707070"
   * @type {string}				 
   * @example 
    * &lt;div id="container"&gt;&lt;/div&gt; 
     * &lt;script&gt;
     * $("#container").ejChart({
     * series :[{font :{color : "green"}}]                 
     * });
     * &lt;/script&gt;
   * @alias ejChart#series->font->color
   */
                        color: '#707070',
                        /**		
  * Specifies the opacity, that is common to all series. Text in the series, render with the specified font opacity.
  * @default 1
  * @type {number}
  * @example 
  * &lt;div id="container"&gt;&lt;/div&gt; 
    * &lt;script&gt;
    * $("#container").ejChart({
    * series :[{font :{opacity : 0.5}}]                 
    * });
    * &lt;/script&gt;
  * @alias ejChart#series->font->opacity
  */
                        opacity: 1
                    },
                    _isdesigntime:true

                }
            ],
            /**		
         * Options for configuring the properties commonly for all the series. You can also override the options for specific series by setting the options directly in each series object in series array.
         * @type {object}
         */
            commonSeriesOptions: /** @lends ejChart# */ {
                /**		
    * Specifies the type of series to be rendered in chart. See {@link Type}
    * @default ej.datavisualization.Chart.Type.Line
    * @type {enum}			 
    * @example 
    * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{ type : "spline"}                  
      * });
      * &lt;/script&gt; 
    * @alias ejChart#commonSeriesOptions->type
    */
                type:'column',
                /**		
   * Specifies the series animation common to all series. By specifying this, we can enable/disable the animation of the series.
   * @default true
   * @type {boolean}				 
   * @example 
   * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{ enableAnimation : false}                  
      * });
      * &lt;/script&gt; 
   * @alias ejChart#commonSeriesOptions->enableAnimation
   */
                enableAnimation: false,
                /**		
* Used in Polar and Radar series to specify whether the line/area series has to be rendered in a closed state by joining the start and end point of the series.
* @default true
* @type {boolean}				 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{ isClosed : false}                  
      * });
      * &lt;/script&gt; 
* @alias ejChart#commonSeriesOptions->isClosed
*/
                isClosed: true,
                /**		
* Used in Polar and Radar series to specify whether column type has to be rendered the stacked value of chart.
* @default false
* @type {boolean}				 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{ isStacking : "true"}                  
      * });
      * &lt;/script&gt; 
* @alias ejChart#commonSeriesOptions->isStacking
*/
                isStacking: false,
                /**		
* Specifies the type of series that can be drawn in a Radar or Polar series. It supports line, column and area type.  See {@link DrawType}
* @default ej.datavisualization.Chart.DrawType.Line
* @type {enum}				 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{ drawType : "area"}                  
      * });
      * &lt;/script&gt; 
* @alias ejChart#commonSeriesOptions->drawType
*/
                drawType: 'line',
                /**		
  * Sets the radius of the hole on the doughnut series with respect to plot area. Value ranges from 0 to 1.
  * @default 0.4
  * @type {number}				 
  * @example 
 * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{ doughnutCoefficient : 0.5}                  
      * });
      * &lt;/script&gt; 
  * @alias ejChart#commonSeriesOptions->doughnutCoefficient
  */
                doughnutCoefficient: 0.4,
                /**		
   * Represents the distance the slice has to be moved out when it is exploded.
   * @default 0.4
   * @type {number}				
   * @example 
  * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{ explodeOffset : 20}                  
      * });
      * &lt;/script&gt; 
  * @alias ejChart#commonSeriesOptions->explodeOffset
   */
                explodeOffset: 25,
                /**		
 * Sets the rendering mode of the pyramid as linear or surface. See {@link PyramidMode}
 * @default ej.datavisualization.Chart.PyramidMode.Linear
 * @type {enum}				 
 * @example 
 * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{ pyramidMode : "linear"}                  
      * });
      * &lt;/script&gt; 
 * @alias ejChart#commonSeriesOptions->pyramidMode
 */
                pyramidMode: 'linear',
/**		
  * Sets the funnel width.
  * @default "11.6%"(11.6% of actualwidth)
  * @example 
  * &lt;div id="container"&gt;&lt;/div&gt; 
   * &lt;script&gt;
   * $("#container").ejChart({
   * series : [{funnelWidth : '40%' }]                   
   * });
   * &lt;/script&gt; 
   * @alias ejChart#commonSeriesOptions->funnelWidth
  */
                funnelWidth: '11.6%',
/**		
  * Sets the funnel height.
  * @default "32.7%"(32.7% of actualheight)
  * @example 
  * &lt;div id="container"&gt;&lt;/div&gt; 
   * &lt;script&gt;
   * $("#container").ejChart({
   * series : [{funnelHeight : '40%' }]                   
   * });
   * &lt;/script&gt; 
   * @alias ejChart#commonSeriesOptions->funnelHeight
  */
                funnelHeight: '32.7%',
                /**		
 * Specifies the position of the axis labels to render labels either inside or outside of plot area. See {@link LabelPosition}
 * @default ej.datavisualization.Chart.LabelPosition.Inside
 * @type {enum}			 
 * @example 
 * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{ labelPosition : "outside"}                  
      * });
      * &lt;/script&gt;  
 * @alias ejChart#commonSeriesOptions->labelPosition
 */
                labelPosition: 'inside',
                /**		
* Specifies the gap between each slice of a pyramid series in pixels.
* @default 0
* @type {number}			 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{ gapRatio : 5}                  
      * });
      * &lt;/script&gt;  
* @alias ejChart#commonSeriesOptions->gapRatio
*/
                gapRatio: 0,
                /**		
* Sets the radius of the pie series with respect to plot area. Value ranges from 0 to 1.
* @default 0.8
* @type {number}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{ pieCoefficient : 1}                  
      * });
      * &lt;/script&gt;  
* @alias ejChart#commonSeriesOptions->pieCoefficient
*/
                pieCoefficient: 0.8,
                /**		
* Sets the radius of the doughnut series with respect to plot area. Value ranges from 0 to 1.
* @default 0.8
* @type {number}			 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{ doughnutSize : 0.9}                  
      * });
      * &lt;/script&gt; 
* @alias ejChart#commonSeriesOptions->doughnutSize
*/
                doughnutSize: 0.8,
                /**		
* Specifies the dataSource for series. 
* @default null	
* @type {object}
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* commonSeriesOptions : {dataSource: data.open }                   
* });
* &lt;/script&gt; 
* @alias ejChart#commonSeriesOptions->dataSource
*/
                dataSource: null,
                /**		
* Specifies the xName for dataSource in series.  This is used to take the x values from dataSource
* @default null	
* @type {string}
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* commonSeriesOptions : {xName: "XValue" }                   
* });
* &lt;/script&gt; 
* @alias ejChart#commonSeriesOptions->xName
*/
                xName: '',
                /**		
* Specifies the yName for dataSource in series.  This is used to take the y values from dataSource
* @default null	
* @type {string}
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* commonSeriesOptions :{yName: "XValue" }               
* });
* &lt;/script&gt; 
* @alias ejChart#commonSeriesOptions->yName
*/
				yName:'', 
                /**		
  * Specifies the starting angle for rendering pie / doughnut series.
  * @default null
  * @type {number}			 
  * @example 
  * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{ startAngle : 150}                  
      * });
      * &lt;/script&gt; ; 
  * @alias ejChart#commonSeriesOptions->startAngle
  */
                startAngle: null,
                /**		
* Specifies the ending angle for rendering pie / doughnut series.
* @default null
* @type {number}			 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
* &lt;script&gt;
* $("#container").ejChart({
* commonSeriesOptions :{ endAngle : 270}                  
* });
* &lt;/script&gt; ; 
* @alias ejChart#commonSeriesOptions->endAngle
*/
                endAngle:null,
                /**		
* Specifies the name of the xAxis.
* @default null
* @type {string}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{ xAxisName : "xAxis"}                  
      * });
      * &lt;/script&gt; 
* @alias ejChart#commonSeriesOptions->xAxisName
*/
                xAxisName: null,
                /**		
* Specifies the name of the yAxis. 
* @default null
* @type {string}			 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{ yAxisName : "yAxis"}                  
      * });
      * &lt;/script&gt; 
* @alias ejChart#commonSeriesOptions->yAxisName
*/
                yAxisName: null,
                /**		
* Explodes all the pie slices. (Also works for doughnut series)
* @default false
* @type {boolean}			 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{ explodeAll : true}                  
      * });
      * &lt;/script&gt; 
* @alias ejChart#commonSeriesOptions->explodeAll
*/
                explodeAll: null,
                /**		
* Index of a slice to be exploded from the whole pie. (Also works for doughnut series)
* @default null
* @type {number}			 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{ explodeIndex : 2}                  
      * });
      * &lt;/script&gt; 
* @alias ejChart#commonSeriesOptions->explodeIndex
*/
                explodeIndex: null,
                /**		
* Enabling this property can avoid pie series data label overlap each other.
* @default true
* @type {boolean}				 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{ enableSmartLabels : false}                  
      * });
      * &lt;/script&gt;  
* @alias ejChart#commonSeriesOptions->enableSmartLabels
*/
                enableSmartLabels: true,
                /**		
         * Contains all the properties to customize tooltip
         * @type {object}
         * @alias ejChart#commonSeriesOptions->tooltip
         */
                tooltip: {
                    /**		
* tooltip visibility can be toggled using this property
* @default false
* @type {boolean}				 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{ tooltip :{visible : true} }                  
      * });
      * &lt;/script&gt; 
* @alias ejChart#commonSeriesOptions->tooltip->visible
*/
                    visible: false,
                    /**		
* Formatting the values of point on a tooltip can be customized using this property.
* @default "#point.x# : #point.y#"
* @type {string}			 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{ format : "#point.x# : #point.y#%"}                  
      * });
      * &lt;/script&gt;  
* @alias ejChart#commonSeriesOptions->tooltip->format
*/
                    format: "#point.x# : #point.y#",
                    /**		
* Specifies the fill color of the tooltip.
* @default null
* @type {string}			 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{tooltip :{fill : "green"}}                  
      * });
      * &lt;/script&gt;  
* @alias ejChart#commonSeriesOptions->tooltip->fill
*/
                    fill: null,
                    /**		
         * Options for customizing the color, opacity and width of the border of tooltip.
         * @type {object}
          * @alias ejChart#commonSeriesOptions->tooltip->border
         */
                    border: {
                        /**		
* Specifies the border color of tooltip.
* @default null
* @type {string}				 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{tooltip :{border:{ color : "green" }}}                  
      * });
      * &lt;/script&gt;  
* @alias ejChart#commonSeriesOptions->tooltip->border->color
*/
                        color: null,
                        /**		
* Specifies the border width of tooltip.
* @default 1
* @type {number}			 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{tooltip :{border :{ width : 2}}}                  
      * });
      * &lt;/script&gt;   
* @alias ejChart#commonSeriesOptions->tooltip->border->width
*/
                        width: 1
                    },
                    /**		
 * Enabling this property animates the tooltip on moving the cursor from one point to the other.
 * @default true
 * @type {boolean}			 
 * @example 
 * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{tooltip :{enableAnimation : false}}                  
      * });
      * &lt;/script&gt;  
 * @alias ejChart#commonSeriesOptions->tooltip->enableAnimation
 */
                    enableAnimation: true,
                    /**		
 * Specifies the duration of the tooltip to stay awake.
 * @default "500ms"
 * @type {string}				 
 * @example 
 * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{tooltip :{duration : "300ms"}}                  
      * });
      * &lt;/script&gt;   
 * @alias ejChart#commonSeriesOptions->tooltip->duration
 */
                    duration: '500ms',
                    /**		
 * Specifies the opacity of the tooltip. Values ranges from 0 to 1.
 * @default 0.5
 * @type {number}			
 * @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{tooltip :{opacity : 0.5}}                  
      * });
      * &lt;/script&gt;  
 * @alias ejChart#commonSeriesOptions->tooltip->opacity
 */
                    opacity: 0.95
                },
                /**		
         * Specifies the fill color of series.
         * @default null
         * @type {string}			 
         * @example 
        * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{fill : "green"}                  
      * });
      * &lt;/script&gt;
        * @alias ejChart#commonSeriesOptions->fill
         */
                fill: null,
                /**		
        * Specifies the opacity of series. The value ranges form 0 to 1.
        * @default 1
        * @type {number}				 
        * @example 
        * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{opacity : 0.5}                  
      * });
      * &lt;/script&gt; 
         * @alias ejChart#commonSeriesOptions->opacity
        */
                opacity: 1,
                /**		
       * Specifies the style to draw the end point of a line like butt, round, square. See {@link LineCap}
       * @default ej.datavisualization.Chart.LineCap.Butt
       * @type {enum}				 
       * @example 
       * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{lineCap : "butt"}                  
      * });
      * &lt;/script&gt;
        * @alias ejChart#commonSeriesOptions->lineCap
       */
                lineCap: 'butt',
                /**		
      * Specifies the shape to use at the intersection of two lines drawn.  See {@link LineJoin}
      * @default ej.datavisualization.Chart.LineJoin.Round
      * @type {enum}				 
      * @example 
      * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{lineCap : "round"}                  
      * });
      * &lt;/script&gt; 
       * @alias ejChart#commonSeriesOptions->lineJoin
      */
                lineJoin: 'round',
                /**		
      * Controls the pattern of dashes and gaps used to stroke the line series.
      * @default ""
      * @type {string}				 
      * @example 
     * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{dashArray : "2,3"}                  
      * });
      * &lt;/script&gt; 
       * @alias ejChart#commonSeriesOptions->dashArray
      */
                dashArray: "",
                /**		
         * Options for customizing the color, opacity and width of the border of series.
         * @type {object}
           * @alias ejChart#commonSeriesOptions->border
         */
                border: {
                    /**		
   * Specifies the border color of series.
   * @default "transparent"
   * @type {string}			 
   * @example 
  * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{border :{ color : "green" } }                  
      * });
      * &lt;/script&gt;
   * @alias ejChart#commonSeriesOptions->border->color
   */
                    color: 'transparent',
                    /**		
    * Specifies the border width of series.
    * @default 1
    * @type {number}			 
    * @example 
    * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{border :{ width : 2 } }                  
      * });
      * &lt;/script&gt;
     * @alias ejChart#commonSeriesOptions->border->width
    */
                    width: 1
                },
                width: 2,
                /**		
         * Contains the customizing properties to add marker symbols to the points plotted in the chart 
         * @type {object}
           * @alias ejChart#commonSeriesOptions->marker
         */
                marker:
                {
                    /**		
  * Specifies the shape of the marker. See {@link Shape}
  * @default ej.datavisualization.Chart.Shape.Circle
  * @type {enum}				
  * @example 
 * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{marker :{ shape: "rectangle"}                  
      * });
      * &lt;/script&gt;
   * @alias ejChart#commonSeriesOptions->marker->shape
  */
                    shape: 'circle',
                    /**		
         * Specifies the size of the marker.
         * @type {object}
          * @alias ejChart#commonSeriesOptions->marker->size
         */
                    size: {
                        /**		
  * Specifies the width of the marker.
  * @default 6
  * @type {number}				 
  * @example 
  * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{marker :{ size :{ width : 2 } } }                  
      * });
      * &lt;/script&gt;
  * @alias ejChart#commonSeriesOptions->marker->size->width
  */
                        width: 6,
                        /**		
* Specifies the height of the marker.
* @default 6
* @type {number}				 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{marker :{size :{height : 5}}}                  
      * });
      * &lt;/script&gt;
* @alias ejChart#commonSeriesOptions->marker->size->height
*/
                        height: 6
                    },
                    /**		
* Toggles the visibility of the marker.
* @default false
* @type {boolean}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{marker :{ visible : true}}                  
      * });
      * &lt;/script&gt; 
* @alias ejChart#commonSeriesOptions->marker->visible
*/
                    visible: false,
                    /**		
* Specifies the opacity of the marker. Values ranges from 0 to 1.
* @default 1
* @type {number}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{marker :{ opacity : 0.5 }}                  
      * });
      * &lt;/script&gt;
* @alias ejChart#commonSeriesOptions->marker->opacity
*/
                    opacity: 1,
                    /**		
* Specifies the fill color of the marker.
* @default null
* @type {string}				 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{marker : { fill : "green" } }                  
      * });
      * &lt;/script&gt;
* @alias ejChart#commonSeriesOptions->marker->fill
*/
                    fill: null,
                    /**		
       * Options for customizing the color, opacity and width of the border of marker.
       * @type {object}
        * @alias ejChart#commonSeriesOptions->marker->border
       */
                    border: {
                        /**		
                        * Specifies the border color of marker.
                        * @default "white"
                        * @type {string}				 
                        * @example 
                        * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{color : "green"}                  
      * });
      * &lt;/script&gt; 
                        * @alias ejChart#commonSeriesOptions->marker->border->color
                        */
                        color: 'white',
                        /**		
* Specifies the border width of marker.
* @default 3
* @type {number}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{marker :{border :{width : 2}}}                  
      * });
      * &lt;/script&gt;
* @alias ejChart#commonSeriesOptions->marker->border->width
*/
                        width: 3
                    },
                    /**		
       * Contains the customizing properties to add data labels of the points plotted in the chart.
       * @type {object}
        * @alias ejChart#commonSeriesOptions->marker->dataLabel
       */
                    dataLabel:
                    {
                        /**		
* Toggles the visibility of dataLabel in the marker.
* @default false
* @type {boolean}			 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{marker :{dataLabel :{visible : true}}                  
      * });
      * &lt;/script&gt; 
* @alias ejChart#commonSeriesOptions->marker->dataLabel->visible
*/
                        visible: false,
                        /**		
 * rotates dataLabel in the marker.
* @default null
* @type {number}			 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{marker :{dataLabel :{angle : 90}}                  
      * });
      * &lt;/script&gt; 
* @alias ejChart#commonSeriesOptions->marker->dataLabel->angle
*/
                        angle:0,
                        /**
* This property is used to change the alignment of the data label vertically.
* @default ej.datavisualization.Chart.verticalTextAlignment.Center
* @type {enum}				 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{marker :{dataLabel :{verticalTextAlignment : "far"}}}                  
      * });
      * &lt;/script&gt;
* @alias ejChart#commonSeriesOptions->marker->dataLabel->verticalTextAlignment
*/
                        verticalTextAlignment: 'center',
                        /**		
* This property is used to change the alignment of the data label horizontally.
* @default ej.datavisualization.Chart.horizontalTextAlignment.Center
* @type {enum}			 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{marker :{dataLabel :{horizontalTextAlignment : "far"}}}                  
      * });
      * &lt;/script&gt;
* @alias ejChart#commonSeriesOptions->marker->dataLabel->horizontalTextAlignment
*/
                        horizontalTextAlignment: 'center',
                        /**		
* This property is used to change the position of the text in data label. See {@link TextPosition}
* @default ej.datavisualization.Chart.textPosition.Top
* @type {enum}			
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{marker :{dataLabel :{textPosition : "bottom"}}}                 
      * });
      * &lt;/script&gt;
* @alias ejChart#commonSeriesOptions->marker->dataLabel->textPosition
*/
                        textPosition: 'top',
                        /**		
* Specifies the rendering shape of the marker. See {@link Shape}
* @default ej.datavisualization.Chart.Shape.None
* @type {enum}				
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{marker :{dataLabel :{shape : "circle"}}}                 
      * });
      * &lt;/script&gt;
* @alias ejChart#commonSeriesOptions->marker->dataLabel->shape
*/
                        shape: 'none',

                        /**		
* Specifies the opacity of dataLabel.
* @default 1
* @type {number}				 
* @example 
* &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{marker :{dataLabel :{opacity : 0.5}}}                 
      * });
      * &lt;/script&gt;
* @alias ejChart#commonSeriesOptions->marker->dataLabel->opacity
*/
                        opacity: 1,
                        /**		
         * Specifies the fill color of datalabel.
         * @default null
         * @type {string}				 
         * @example 
         * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{marker :{dataLabel :{fill : "green"}}}                 
      * });
      * &lt;/script&gt; 
         * @alias ejChart#commonSeriesOptions->marker->dataLabel->fill
         */
                        fill: null,
                        /**		
 * Options for customizing the color, opacity and width of the border of datalabel.
 * @type {object}
  * @alias ejChart#commonSeriesOptions->marker->dataLabel->border
 */
                        border: {
                            /**		
          * Specifies the border color of datalabel.
          * @default null
          * @type {string}				 
          * @example 
          * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{marker :{dataLabel :{border : {color : "green"}}}}                 
      * });
      * &lt;/script&gt;
          * @alias ejChart#commonSeriesOptions->marker->dataLabel->border->color
          */
                            color: 'white',
                            /**		
          * Specifies the border width of datalabel.
          * @default 0.1
          * @type {number}				 
          * @example 
          * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{marker :{dataLabel :{border :{ width :2 }}}}                 
      * });
      * &lt;/script&gt; 
         * @alias ejChart#commonSeriesOptions->marker->dataLabel->border->width
          */
                            width: 0.1
                        },
                        /**		
      * Contains the options to customize the line connecting the point and the data label.
      * @type {object}
      * @alias ejChart#commonSeriesOptions->marker->dataLabel->connectorLine
      */
                        connectorLine:
                        {
                            /**		
             * Specifies the width of the connector line.
             * @default 0.5
             * @type {number}				 
             * @example 
             * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{marker :{dataLabel :{connectorLine :{ width : 2 }}}}                 
      * });
      * &lt;/script&gt; 
             * @alias ejChart#commonSeriesOptions->marker->dataLabel->connectorLine->width
             */
                            width: 0.5,
                            /**		
             * Specifies whether to connect the point and data label using bezier curve or straight line. See {@link Type}
             * @default ej.datavisualization.Chart.Type.Line
             * @type {enum}			 
             * @example 
            * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{marker :{dataLabel :{connectorLine :{ type : "spline" }}}}                 
      * });
      * &lt;/script&gt;
             * @alias ejChart#commonSeriesOptions->marker->dataLabel->connectorLine->type
             */
                            type: 'line'
                        },
                        /**		
      * Specifies the font of the dataLabel. These are the properties involved in customizing the data label font.
      * @type {object}
       * @alias ejChart#commonSeriesOptions->marker->dataLabel->font 
      */
                        font:
                        {
                            /**		
           * Specifies the fontFamily of dataLabel. Text in the data label render with the specified font family.
           * @default "Segoe UI"
           * @type {string}				 
           * @example 
          * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{marker :{dataLabel :{ font :{fontFamily : "algerian"}}}}                 
      * });
      * &lt;/script&gt; 
          * @alias ejChart#commonSeriesOptions->marker->dataLabel->font->fontFamily
           */
                            fontFamily: 'Segoe UI',
                            /**		
          * Specifies the fontStyle of dataLabel. Text in the data label render with the specified font style. See {@link FontStyle}
          * @default ej.datavisualization.Chart.FontStyle.Normal
          * @type {enum}			 
          * @example 
          * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{marker :{dataLabel :{font :{ fontStyle : "italic" }}}}                 
      * });
      * &lt;/script&gt; 
          * @alias ejChart#commonSeriesOptions->marker->dataLabel->font->fontStyle
          */
                            fontStyle: 'Normal',
                            /**		
         * Specifies the fontWeight of dataLabel. Text in the data label render with the specified font weight. See {@link FontWeight}
         * @default ej.datavisualization.Chart.FontWeight.Regular
         * @type {enum}				 
         * @example 
         * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{marker :{dataLabel :{font : { fontWeight : "lighter" }}}}                 
      * });
      * &lt;/script&gt;
         * @alias ejChart#commonSeriesOptions->marker->dataLabel->font->fontWeight
         */
                            fontWeight: 'Regular',
                            /**		
        * Specifies the font size of dataLabel. Text in the data label render with the specified font size.
        * @default "12px"
        * @type {string}			 
        * @example 
        * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{marker :{dataLabel :{font : { size : "14px" }}}}                 
      * });
      * &lt;/script&gt; 
        * @alias ejChart#commonSeriesOptions->marker->dataLabel->font->size
        */
                            size: '12px',
                            /**		
        
       * Specifies the opacity of the text in dataLabel. Text in the data label render with the specified opacity.
       * @default 1
       * @type {number}				 
       * @example 
       * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{marker :{dataLabel :{font :{ opacity : 0.5 }}}}                 
      * });
      * &lt;/script&gt;
       * @alias ejChart#commonSeriesOptions->marker->dataLabel->font->opacity
       */
                            opacity: 1
                        },
                        /**		
      * Specifies the margin for the data label.
      * @type {object}
       * @alias ejChart#commonSeriesOptions->marker->dataLabel->margin
      */
                        margin:
                        {
                            /**		
      * Specifies the left margin value for dataLabel. By specifying this property, we can adjust the text in data label to left.
      * @default 5
      * @type {number}				 
      * @example 
      * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{marker :{dataLabel :{margin :{ left : 10}}}}                 
      * });
      * &lt;/script&gt; 
      * @alias ejChart#commonSeriesOptions->marker->dataLabel->margin->left
      */
                            left: 5,
                            /**		
      * Specifies the top margin value for dataLabel. By specifying this property, we can adjust the text in data label to top.
      * @default 5
      * @type {number}				 
      * @example 
      * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{marker :{dataLabel :{margin :{ top :10 } }}}                 
      * });
      * &lt;/script&gt;
      * @alias ejChart#commonSeriesOptions->marker->dataLabel->margin->top
      */
                            top: 5,
                            /**		
      * Specifies the bottom margin value for dataLabel. By specifying this property, we can adjust the text in data label to bottom.
      * @default 5
      * @type {number}				
      * @example 
      * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{marker :{dataLabel :{margin :{ bottom :10 }}}}                 
      * });
      * &lt;/script&gt;
      * @alias ejChart#commonSeriesOptions->marker->dataLabel->margin->bottom
      */
                            bottom: 5,
                            /**		
      * Specifies the right margin value for dataLabel. By specifying this property, we can adjust the text in data label to right.
      * @default 5
      * @type {number}			
      * @example 
       * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{marker :{dataLabel :{margin :{ right :10 }}}}                 
      * });
      * &lt;/script&gt;
      * @alias ejChart#commonSeriesOptions->marker->dataLabel->margin->right
      */
                            right: 5
                        }
                    }
                },
                /**		
      * Specifies the font that is common to all series. These are the properties involved in customizing the font of the series in chart. 
      * @type {object}
       * @alias ejChart#commonSeriesOptions->font
      */
                font: {
                    /**		
      * Specifies the fontFamily, that is common to all series. Text in the series, render with the specified font family.
      * @default "Segoe UI"
      * @type {string}				 
      * @example 
       * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{ font : { fontFamily : "Algerian"}}                 
      * });
      * &lt;/script&gt; 
      * @alias ejChart#commonSeriesOptions->font->fontFamily
      */
                    fontFamily: 'Segoe UI',
                    /**		
      * Specifies the fontStyle, that is common to all series. Text in the series, render with the specified font style.
      * @default ej.datavisualization.Chart.FontStyle.Normal
      * @type {enum}		
      * @example 
       * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions : {font :{fontStyle : "italic"}}                 
      * });
      * &lt;/script&gt;
     * @alias ejChart#commonSeriesOptions->font->fontStyle
      */
                    fontStyle: 'Normal',
                    /**		
     * Specifies the fontWeight, that is common to all series. Text in the series, render with the specified font weight.
     * @default ej.datavisualization.Chart.FontWeight.Regular
     * @type {enum}				 
     * @example 
     * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{font :{fontWeight : "lighter"}}                 
      * });
      * &lt;/script&gt;
     * @alias ejChart#commonSeriesOptions->font->fontWeight
     */
                    fontWeight: 'Regular',
                    /**		
     * Specifies the font size, that is common to all series. Text in the series, render with the specified font size.
     * @default "12px"
     * @type {string}				 
     * @example 
     * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{font :{size : "14px"}}                 
      * });
      * &lt;/script&gt; 
     * @alias ejChart#commonSeriesOptions->font->size
     */
                    size: '12px',
                    /**		
    * Specifies the color, that is common to all series. Text in the series, render with the specified font color.
    * @default "#707070"
    * @type {string}				 
    * @example 
     * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{font :{color : "green"}}                 
      * });
      * &lt;/script&gt;
    * @alias ejChart#commonSeriesOptions->font->color
    */
                    color: '#707070',
                    /**		
    * Specifies the opacity, that is common to all series. Text in the series, render with the specified font opacity.
    * @default 1
    * @type {number}
	* @example 
    * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * commonSeriesOptions :{font :{opacity : 0.5}}                 
      * });
      * &lt;/script&gt;
    * @alias ejChart#commonSeriesOptions->font->opacity
    */
                    opacity: 1
                }
            },
            /**		
     * Contains the properties to customize crosshair or trackball.
     * @type {object}
     */
            crosshair: /** @lends ejChart# */
            {
                /**		
     * Contains property to customize the marker in crosshair.
     * @type {object}
      * @alias ejChart#crosshair->marker
     */
                marker:
                {
                    /**		
    * Toggles the visibility of the marker in crosshair.
    * @default true
    * @type {boolean}			
    * @example 
     * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * crosshair :{marker :{visible :false}}              
      * });
      * &lt;/script&gt;
     * @alias ejChart#crosshair->marker->visible
    */
                    visible: true,
                    /**		
     * Contains property to customize the size of marker.
     * @type {object}
       * @alias ejChart#crosshair->marker->size
     */
                    size:
                    {
                        /**		
   * Specifies the width of the marker in crosshair.
   * @default 10
   * @type {number}			 
   * @example 
    * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * crosshair :{marker :{size : {width :15}}}              
      * });
      * &lt;/script&gt;
    * @alias ejChart#crosshair->marker->size->width
   */
                        width: 10,
                        /**		
 * Specifies the height of the marker in crosshair.
 * @default 10
 * @type {number}				 
 * @example 
  * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * crosshair :{marker :{size :{ height :15 }}}              
      * });
      * &lt;/script&gt; 
 * @alias ejChart#crosshair->marker->size->height
 */
                        height: 10
                    },
                    /**		
 * Specifies the opacity of the marker in crosshair.
 * @default true
 * @type {boolean}			 
 * @example 
  * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * crosshair :{marker :{opacity :2}}              
      * });
      * &lt;/script&gt; 
  * @alias ejChart#crosshair->marker->opacity
 */
                    opacity: 1,
                    /**		
     * Options for customizing the width of the border of marker.
     * @type {object}
       * @alias ejChart#crosshair->marker->border
     */
                    border:
                    {
                        /**		
      * Specifies the border width of the marker in crosshair.
      * @default 3
      * @type {number}			 
      * @example 
       * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * crosshair :{marker :{border :{ width :2 }}}              
      * });
      * &lt;/script&gt;
       * @alias ejChart#crosshair->marker->border->width
      */
                        width: 3
                    }
                },
                /**		
      * Toggles the visibility of the crosshair / trackball in the plot area
      * @default false
      * @type {boolean}				
      * @example 
       * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * crosshair :{visible :true}              
      * });
      * &lt;/script&gt;
       * @alias ejChart#crosshair->visible
      */
                visible: false,
                /**		
      * Specifies the type of the crosshair. It may be trackball or crosshair.
      * @default ej.datavisualization.Chart.CrosshairType.Crosshair
      * @type {enum}				 
      * @example 
       * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * crosshair :{type : "trackball"}              
      * });
      * &lt;/script&gt; 
       * @alias ejChart#crosshair->type
      */
                type: "crosshair"
            },


            pointStyle:
            {
                lineCap: 'butt', lineJoin: 'round', opacity: 1, interior: null, borderColor: null, borderWidth: 1
            },
            textStyle:
            {
                marker: { textAlignment: 'center', textPosition: 'top' },
                font: { fontFamily: 'Segoe UI', fontStyle: 'Normal', fontWeight: 'Regular', size: '12px', color: '#707070', opacity: 1 }
            },
            symbolShape: {
                None: 0,
                LeftArrow: 1,
                RightArrow: 2,
                Circle: 3,
                Cross: 4,
                HorizLine: 5,
                VertLine: 6,
                Diamond: 7,
                Rectangle: 8,
                Triangle: 9,
                InvertedTriangle: 10,
                Hexagon: 11,
                Pentagon: 12,
                Star: 13,
                Ellipse: 14,
                Wedge: 15,
                Trapezoid: 16,
                UpArrow: 17,
                DownArrow: 18,
                Image: 19,
                SeriesType: 20

            },
            initSeriesRender: true,
            /**		
     * By specifying this property the user can change the theme of the chart. See {@link Theme}
     * @default ej.datavisualization.Chart.Theme.Flatlight
     * @type {enum}				 
     * @example 
     * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * theme : "flatdark"            
      * });
      * &lt;/script&gt;
     */
            theme: "flatlight",
            /**		
    * Sets a value whether to make the chart responsive on resize.
    * @default false
    * @type {boolean}			 
    * @example 
     * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * canResize : true             
      * });
      * &lt;/script&gt;
    */
            canResize: false,
			    /**		
    * To enable the 3D view of chart control. 3D view is supported only for column, bar, stacking column, stacking bar, pie and doughnut series types.
    * @default false
    * @type {boolean}			 
    * @example 
     * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * enable3D : true             
      * });
      * &lt;/script&gt;
    */
            enable3D: false,
			 /**		
    * Enables the 3D chart to perform rotation.
    * @default false
    * @type {boolean}			 
    * @example 
     * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * enableRotation : true             
      * });
      * &lt;/script&gt;
    */
            enableRotation: false,
			 /**		
    * The sideBySideSeriesPlacement property defines the appearance of the different set of data on 3D chart
    * @default false
    * @type {boolean}			 
    * @example 
     * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * sideBySideSeriesPlacement : true             
      * });
      * &lt;/script&gt;
    */
            sideBySideSeriesPlacement: false,
			 /**		
    * Enables the 3D chart to perform rotation.
    * @default 90
    * @type {number}			 
    * @example 
     * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * perspectiveAngle : 60             
      * });
      * &lt;/script&gt;
    */
            perspectiveAngle: 90,   
/**		
     * The rotation property is used to spin the 3D chart.
    * @default 0
    * @type {number}			 
    * @example 
     * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * rotation : 45             
      * });
      * &lt;/script&gt;
    */			
            rotation: 0,
			/**		
    * The tilt property defines the angle of the slope of 3D chart.
    * @default 0
    * @type {number}			 
    * @example 
     * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * tilt : 5             
      * });
      * &lt;/script&gt;
    */		
            tilt: 0,
			/**		
    * In 3D, Cartesian axes lines are represented as wall. The property wallSize defines the width of the wall.
    * @default 2
    * @type {number}			 
    * @example 
     * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * wallSize : 5             
      * });
      * &lt;/script&gt;
    */		
            wallSize: 2,
			/**		
    * The depth property defines the depth of the 3D chart from front view of the series to wall.
    * @default 100
    * @type {number}			 
    * @example 
     * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * depth : 100            
      * });
      * &lt;/script&gt;
    */		
            depth:100,


            /**		
    * By enabling this property, the ejChart will render in Html5 canvas.
	* This canvas rendering supports all other functionalities except 3D and animation.
    * @default false
    * @type {boolean}			 
    * @example 
     * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * enableCanvasRendering : true             
      * });
      * &lt;/script&gt;
    */
            enableCanvasRendering: false,
            /**		
     * Contains property to customize zooming in chart.
     * @type {object}
     */
            zooming: /** @lends ejChart# */
            {
                /**		
   * Enabling this property will allow zooming for chart plot area.
   * @default false
   * @type {boolean}				 
   * @example 
     * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * zooming :{enable :true}          
      * });
      * &lt;/script&gt;
    * @alias ejChart#zooming->enable
   */
                enable: false,
                /**		
   * Specifies whether zooming has to be vertical or horizontal.
   * @default 'x,y'
   * @type {string}			 
   * @example 
   * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * zooming :{type : "y"}            
      * });
      * &lt;/script&gt; 
   * @alias ejChart#zooming->type
   */
                type: 'x,y',
                /**		
   * Enabling this property will allow user to zoom plot are on rolling mouse wheel.
   * @default false
   * @type {boolean}			 
   * @example 
    * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * zooming:{enableMouseWheel : true}            
      * });
      * &lt;/script&gt; 
   * @alias ejChart#zooming->enableMouseWheel
   */
                enableMouseWheel: false,
                /**		
 * Enabling this property will allow user to pan the zoomed chart on mouse up.
 * @default false
 * @type {boolean}			 
 * @example 
  * &lt;div id="container"&gt;&lt;/div&gt; 
    * &lt;script&gt;
    * $("#container").ejChart({
    * zooming:{enableDeferredZoom : true}            
    * });
    * &lt;/script&gt; 
    * @alias ejChart#zooming->enableDeferredZoom
 */
          enableDeferredZoom : false
            },
            type: 'x,y',
            /**		
* This property is to specify the localization of chart.
* @default "en-US"
* @type {string}				 
* @example 
 * &lt;div id="container"&gt;&lt;/div&gt; 
      * &lt;script&gt;
      * $("#container").ejChart({
      * locale : "en-US"            
      * });
      * &lt;/script&gt;
*/
            locale: "en-US",

            xZoomFactor: 1,

            yZoomFactor: 1,

            xZoomPosition: 0,

            yZoomPosition: 0,
            /**     
              * Fires on load of chart.
              * @event
              * @name ejChart#load	
              * @param {Object} argument.Data parameters from chart     
			 * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
			 * @param {object}  argument.model returns the chart model
			 * @param {string}  argument.type returns the name of the event
              * @example 
              * //load event for chart
              * $("#container").ejChart({
              *    load: function (args) {}
              * });
              */
            load: "",
            /**     
              * Fires on rendering the axis labels.
              * @event
              * @name ejChart#axesLabelRendering
              * @param {Object} argument.Axis parameters from chart   
              * @param {Object} argument.Label parameters from chart for processing of labels
			  * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
			  * @param {object}  argument.model returns the chart model
			  * @param {string}  argument.type returns the name of the event
              * @example 
              * //axesLabelRendering event for chart
              * $("#container").ejChart({
              *    axesLabelRendering: function (args) {}
              * });
              
              */
            axesLabelRendering: "",
            /**     
             * Fires on axes range calculation.
             * @event
             * @name ejChart#axesRangeCalculate	
             * @param {Object} argument.Data parameters from chart     
			 * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
			 * @param {object}  argument.model returns the chart model
			 * @param {string}  argument.type returns the name of the event
             * @example 
             * //axesRangeCalculate event for chart
             * $("#container").ejChart({
             *    axesRangeCalculate: function (args) {}
             * });
             
             */
            axesRangeCalculate: "",
            /**     
             * Fires on rendering the axes title.
             * @event
             * @name ejChart#axesTitleRendering	
             * @param {Object} argument.Data parameters from chart     
			 * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
			 * @param {object}  argument.model returns the chart model
			 * @param {string}  argument.type returns the name of the event
             * @example 
             * //axesTitleRendering event for chart
             * $("#container").ejChart({
             *    axesTitleRendering: function (args) {}
             * });
             
             */
            axesTitleRendering: "",
            /**     
             * Fires on chart area bounds calculation.
             * @event
             * @name ejChart#chartAreaBoundsCalculate	
             * @param {Object} argument.Data parameters from chart     
			 * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
			 * @param {object}  argument.model returns the chart model
			 * @param {string}  argument.type returns the name of the event
             * @example 
             * //chartAreaBoundsCalculate event for chart
             * $("#container").ejChart({
             *    chartAreaBoundsCalculate: function (args) {}
             * });
             
             */
            chartAreaBoundsCalculate: "",
            /**     
             * Fires on rendering of legend item.
             * @event
             * @name ejChart#legendItemRendering
             * @param {Object} argument.Data parameters from chart     
			 * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
			 * @param {object}  argument.model returns the chart model
			 * @param {string}  argument.type returns the name of the event
             * @example 
             * //legendItemRendering event for chart
             * $("#container").ejChart({
             *    legendItemRendering: function (args) {}
             * });
             
             */
            legendItemRendering: "",
            /**     
             * Fires on calculating the legend bounds
             * @event
             * @name ejChart#legendBoundsCalculate
             * @param {Object} argument.Data parameters from chart     
			 * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
			 * @param {object}  argument.model returns the chart model
			 * @param {string}  argument.type returns the name of the event
             * @example 
             * //legendBoundsCalculate event for chart
             * $("#container").ejChart({
             *    legendBoundsCalculate: function (args) {}
             * });
             
             */
            legendBoundsCalculate: "",
            /**     
             * Fires on pre render.
             * @event
             * @name ejChart#preRender	
             * @param {Object} argument.Data parameters from chart     
			 * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
			 * @param {object}  argument.model returns the chart model
			 * @param {string}  argument.type returns the name of the event
             * @example 
             * //preRender event for chart
             * $("#container").ejChart({
             *    preRender: function (args) {}
             * });
             
             */
            preRender: "",
            /**     
             * Fires on rendering the series.
             * @event
             * @name ejChart#seriesRendering
             * @param {Object} argument.Data parameters from chart     
			 * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
			 * @param {object}  argument.model returns the chart model
			 * @param {string}  argument.type returns the name of the event
             * @example 
             * //seriesRendering event for chart
             * $("#container").ejChart({
             *    seriesRendering: function (args) {}
             * });
             
             */
            seriesRendering: "",
            /**     
             * Fires on rendering the symbols.
             * @event
             * @name ejChart#symbolRendering
             * @param {Object} argument.Data parameters from chart     
			 * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
			 * @param {object}  argument.model returns the chart model
			 * @param {string}  argument.type returns the name of the event
             * @example 
             * //symbolRendering event for chart
             * $("#container").ejChart({
             *    symbolRendering: function (args) {}
             * });
             
             */
            symbolRendering: "",
            /**     
             * Fires on rendering the title.
             * @event
             * @name ejChart#titleRendering	
             * @param {Object} argument.Data parameters from chart     
			 * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
			 * @param {object}  argument.model returns the chart model
			 * @param {string}  argument.type returns the name of the event
             * @example 
             * //titleRendering event for chart
             * $("#container").ejChart({
             *    titleRendering: function (args) {}
             * });
             
             */
            titleRendering: "",
           subtitleRendering: "",
           
              
             
            /**     
             * Fires on initializing the axis labels.
             * @event
             * @name ejChart#axesLabelsInitialize
             * @param {Object} argument.Data parameters from chart     
			 * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
			 * @param {object}  argument.model returns the chart model
			 * @param {string}  argument.type returns the name of the event
             * @example 
             * //axesLabelsInitialize event for chart
             * $("#container").ejChart({
             *    axesLabelsInitialize: function (args) {}
             * });
             
             */
            axesLabelsInitialize: "",
            /**     
             * Fires on click of point region.
             * @event
             * @name ejChart#pointRegionClick	
             * @param {Object} argument.Data parameters from chart     
			 * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
			 * @param {object}  argument.model returns the chart model
			 * @param {string}  argument.type returns the name of the event
             * @example 
             * //pointRegionClick event for chart
             * $("#container").ejChart({
             *    pointRegionClick: function (args) {}
             * });
             
             */
            pointRegionClick: "",
            /**     
             * Fires on mousemove over the point region.
             * @event
             * @name ejChart#pointRegionMouseMove	
             * @param {Object} argument.Data parameters from chart     
			 * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
			 * @param {object}  argument.model returns the chart model
			 * @param {string}  argument.type returns the name of the event
             * @example 
             * //pointRegionMouseMove event for chart
             * $("#container").ejChart({
             *    pointRegionMouseMove: function (args) {}
             * });
             
             */
            pointRegionMouseMove: "",
            /**     
             * Fires on click of legend item
             * @event
             * @name ejChart#legendItemClick	
             * @param {Object} argument.Data parameters from chart     
			 * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
			 * @param {object}  argument.model returns the chart model
			 * @param {string}  argument.type returns the name of the event
             * @example 
             * //legendItemClick event for chart
             * $("#container").ejChart({
             *    legendItemClick: function (args) {}
             * });
             
             */
            legendItemClick: "",
            /**     
             * Fires on mouse move over legend item.
             * @event
             * @name ejChart#legendItemMouseMove	
             * @param {Object} argument.Data parameters from chart     
			 * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
			 * @param {object}  argument.model returns the chart model
			 * @param {string}  argument.type returns the name of the event
             * @example 
             * //legendItemMouseMove event for chart
             * $("#container").ejChart({
             *    legendItemMouseMove: function (args) {}
             * });
             
             */
            legendItemMouseMove: "",
            /**     
             * Fires on rendering the display text.
             * @event
             * @name ejChart#displayTextRendering		
             * @param {Object} argument.Data parameters from chart     
			 * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
			 * @param {object}  argument.model returns the chart model
			 * @param {string}  argument.type returns the name of the event
             * @example 
             * //displayTextRendering event for chart
             * $("#container").ejChart({
             *    displayTextRendering: function (args) {}
             * });
             
             */
            displayTextRendering: "",
            /**     
             * Fires on initialize the tooltip.
             * @event
             * @name ejChart#toolTipInitialize	
             * @param {Object} argument.Data parameters from chart     
			 * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
			 * @param {object}  argument.model returns the chart model
			 * @param {string}  argument.type returns the name of the event
             * @example 
             * //toolTipInitialize event for chart
             * $("#container").ejChart({
             *    toolTipInitialize: function (args) {}
             * });
             
             */
            toolTipInitialize: "",
            /**     
             * Fires on track the axis tooltip.
             * @event
             * @name ejChart#trackAxisToolTip	
             * @param {Object} argument.Data parameters from chart     
			 * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
			 * @param {object}  argument.model returns the chart model
			 * @param {string}  argument.type returns the name of the event
             * @example 
             * //trackAxisToolTip event for chart
             * $("#container").ejChart({
             *    trackAxisToolTip: function (args) {}
             * });
             
             */
            trackAxisToolTip: "",
            /**     
             * Fires on tracking the tooltip.
             * @event
             * @name ejChart#trackToolTip	
             * @param {Object} argument.Data parameters from chart     
			 * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
			 * @param {object}  argument.model returns the chart model
			 * @param {string}  argument.type returns the name of the event
             * @example 
             * //trackToolTip event for chart
             * $("#container").ejChart({
             *    trackToolTip: function (args) {}
             * });
             
             */
            trackToolTip: "",
            /**     
             * Fires on completion of animation.
             * @event
             * @name ejChart#animationComplete
             * @param {Object} argument.Data parameters from chart     
			 * @param {boolean}  argument.cancel if the event should be canceled; otherwise, false.
			 * @param {object}  argument.model returns the chart model
			 * @param {string}  argument.type returns the name of the event
             * @example 
             * //animationComplete event for chart
             * $("#container").ejChart({
             *    animationComplete: function (args) {}
             * });
             
             */
            animationComplete: "",
            /**     
             * Fires when chart is destroyed completely.
             * @event
             * @name ejChart#destroy
             * @example 
             * //animationComplete event for chart
             * $("#container").ejChart("destroy");
             
             */
            destroy: "",
            /**     
            * Fires after chart is created.
            * @event
            * @name ejChart#create		
            * @example 
            * //create event for chart
            * $("#container").ejChart("create");
            
            */
            create: "",

            margin: { left: 10, right: 10, top: 10, bottom: 10 },
            size: {},
            elementSpacing: 10,

            seriesColors: [],
            seriesBorderColors: [],
            dateStart: 25568.791666666668,
            pointColors: [],
            pointBorderColors: []
        },
        /**
          * Specify the data types for default properties 
          * @private
          */
        dataTypes: {
            commonSeriesOptions:{dataSource:"data"},
            axes: "array",
            series: "array",
            seriesColors: "array",
            palette: "array",
            rowDefinitions: "array",
            columnDefinitions: "array",
            seriesBorderColors: "array",
            pointColors: "array",
            pointBorderColors: "array",
            initSeriesRender: "boolean",
            theme: "enum",
            canResize: "boolean",
            elementSpacing: "number",
            primaryXAxis: {
                labels: "array",
                stripLine: "array",
                orientation: "enum",
                rangePadding: "enum",
                tickLinesPosition: "enum",
                labelPosition:"enum",
                opposedPosition: "boolean",
                zoomFactor: "number",
                zoomPosition: "number"
            },
            primaryYAxis: {
                labels: "array",
                stripLine: "array",
                orientation: "enum",
                rangePadding: "enum",

                opposedPosition: "boolean",
                zoomFactor: "number",
                zoomPosition: "number"
            },
            legend: {

                shape: "enum",
                alignment: "enum",
                position: "enum",
                itemPadding: "number"
            },
            zooming: {
                enable: "boolean",
                type: "string",
                enableMouseWheel: "boolean"
            },
            size: {
                width: "string",
                height: "string"
            }

        },

        observables: ["xZoomFactor", "yZoomFactor", "xZoomPosition", "yZoomPosition"],
		
		 _tags: [{
            tag: "series",
            attr: ["xAxisName", "yAxisName", "endAngle", "startAngle", "explodeIndex", "labelPosition", "xName", "yName", "pyramidMode", "pieCoefficient", "explodeAll", "explodeOffset", "funnelWidth", "funnelHeight", "gapRatio", "isClosed", "isStacking", "bearFillColor", "bullFillColor", "dataSource", "enableAnimation", "doughnutCoefficient", "doughnutSize", "enableSmartLabels", 
			       [
				     {
				       tag: "points", attr:["x", "y", "text", "isEmpty", "fill", "visible"]
				     }
				   ],			     
			      ],
                 singular:"series",			  
               },{
			     tag:"axes",
				 attr:["columnIndex", "rowIndex", "desiredIntervals", "edgeLabelPlacement", "intervalType", "labelFormat", "labelPosition", "labelRotation", "logBase", "labelIntersectAction", "opposedPosition", "plotOffset", "rangePadding", "roundingPlaces", "valueType", "zoomFactor", "zoomPosition", "orientation",
				   [
				     {
				       tag: "stripLine", attr:["borderColor", "startFromAxis", "zIndex", "textAlignment"],
					   singular:"stripLine"
				     }
				   ],			     
				 ],
				 singular:"axis",
			   },			   
			   {
			      tag:"primaryXAxis.stripLine",
				  attr:["borderColor", "startFromAxis", "zIndex", "textAlignment"],
				  singular:"primaryXAxis.stripLine",
			 },
			 {
			      tag:"primaryYAxis.stripLine",
				  attr:["borderColor", "startFromAxis", "zIndex", "textAlignment"],
				  singular:"primaryYAxis.stripLine",
			 }
         ],
        _xZoomFactor: ej.util.valueFunction("xZoomFactor"),
        _yZoomFactor: ej.util.valueFunction("yZoomFactor"),
        _xZoomPosition: ej.util.valueFunction("xZoomPosition"),
        _yZoomPosition: ej.util.valueFunction("yZoomPosition"),

        /**
        * Create the chart widget
        * @private
        */
        _init: function () {

            this._renderSfChart();

        },
        _destroy: function () {
            $('#template_group_' + this._id).remove();
            $(this.element).removeClass("e-chart e-js").find("#" + this.svgObject.id).remove();
            $(this.element).removeClass("e-chart e-js").find("#legend_" + this.svgObject.id).remove();
        },
		
		_series: function (index, property, value, old) {	           
		  this.redraw();		  
		  this._trigger("refresh");           
        },
		_series_points:function(index, property, value, old){		   
		   this.redraw();
		  this._trigger("refresh");    
		},
		_primaryXAxis_stripLine:function(index, property, value, old){		   
		   this.redraw();
		  this._trigger("refresh");    
		},
		_primaryYAxis_stripLine:function(index, property, value, old){		   
		   this.redraw();
		  this._trigger("refresh");    
		},		 
		_axes:function(index, property, value, old){		 
		  this.redraw();
		  this._trigger("refresh"); 
		},
		_axes_stripLine:function(index, property, value, old){
		  this.redraw();
		  this._trigger("refresh");
		},
		
        /**
        * redraw the chart widget
		* @return jQuery
		* @example 
		* &lt;div id="container"&gt;&lt;/div&gt; <br> 
		* &lt;script&gt;
		* // Redraw Chart
		* var chartObj = $("#container").data("ejChart");
		* chartObj.redraw(); // redraw the chart
		* &lt;/script&gt;
		* @example 
		* &lt;div id="container"&gt;&lt;/div&gt; <br> 
		* &lt;script&gt;
		* $("#container").ejChart("redraw");	
		* &lt;/script&gt;
		
         */
		redraw: function (excludeDataUpdate) {		   
		    this.model.primaryXAxis._valueType = null;
		    this.model.primaryXAxis.position = null;		    
		    this.model.primaryYAxis._valueType = null;
		    this.model.primaryYAxis.position = null;
            for (var i = 0; i < this.model.axes.length; i++){          
                this.model.axes[i]._valueType = null;
                this.model.axes[i].position = null;
            } 
          
			for (var i = 0; i < this.model.series.length; i++) {
                this.model.series[i].position = null;
            }
			
            if(this.model.enable3D)
            ej.Ej3DRender.transform = null;
            
			
            if (this.model.enableCanvasRendering) {
                if (this.model.zooming.enable && this.svgRenderer.ctx)
                    this.svgRenderer.ctx.clearRect(0, 0, ej.util.isNullOrUndefined(this.model.size.width) ? $("#" + this._id).width() : this.model.size.width, ej.util.isNullOrUndefined(this.model.size.height) ? "450" : this.model.size.height);
                else {
                    $(this.svgObject).remove();
					var width=this.svgWidth;
                    $("#canvas_trackSymbol").remove();
                    this.svgRenderer = new ej.EjCanvasRender(this.element); // to create canvas container
                    this.svgRenderer.svgObj.height = ej.util.isNullOrUndefined(this.model.size.height) ? "450" : this.model.size.height;
                    this.svgRenderer.svgObj.width = ej.util.isNullOrUndefined(this.model.size.width) ? width : this.model.size.width;
                    this.svgObject = this.svgRenderer.svgObj;
                    var ctx = this.svgRenderer.svgObj.getContext("2d");

                    $(this.legendSvgContainer).remove();
                    $(this.legendContainer).remove();
                    this.legendContainer = $("<div></div>").attr('id', "legend_" + this._id).css("height", "0px");
                    this.legendSvgContainer = this.svgRenderer.createLegendCanvas(this.element); //creating new CANVAS element for legend
                    this.svgRenderer.append(this.legendSvgContainer, this.legendContainer);
                    $(this.legendContainer).appendTo(this.chartContainer);
                }
            }
            else if ((this.svgObject.id).indexOf("_canvas") != -1) {
                $(this.svgObject).remove();
                this.svgRenderer = new ej.EjSvgRender(this.element);  // to create svg container
                this.svgObject = this.svgRenderer.svgObj;
                this.canvasX = this.canvasY = 0;

                $(this.legendSvgContainer).remove();
				$(this.legendContainer).remove();
                this.legendContainer = $("<div></div>").attr('id', "legend_" + this._id).css("height", "0px");
                this.legendSvgContainer = this.svgRenderer.createLegendSvg(this.element); //creating new SVG element for legend
                this.svgRenderer.append(this.legendSvgContainer, this.legendContainer);
				$(this.legendContainer).appendTo(this.chartContainer);
            } else {
                $(this.svgObject).empty();              // using existing svg container			   
                $(this.legendSvgContainer).empty();
            }
			
            this.bindTo(excludeDataUpdate);
        },
		
		 /**
        * export the chart widget
		* @return jQuery
		* @example 
		* &lt;div id="container"&gt;&lt;/div&gt; <br> 
		* &lt;script&gt;
		* // Export Chart
		* var canvas = $("#container").ejChart("exportChart"); 
        * var dt = canvas.toDataURL();
        * this.href = dt;
		* &lt;/script&gt;
         */
		exportChart: function (x)
        {         
             var Id = this._id;
            if ( $("#Export_"+Id).length <= 0) {

            var Id = this._id;
            var chart = document.getElementById(Id + '_canvas');
            var legend = document.getElementById('legend_' + Id + '_canvas');

            var exportChart = document.createElement('canvas');            
            exportChart.setAttribute('id', 'Export_'+Id);
            exportChart.setAttribute('width', this.svgWidth);
            exportChart.setAttribute('height', this.svgHeight);

            //$("body").append(exportChart);
            var exprtCtx = exportChart.getContext("2d");
            
            var legendPos = this.model.LegendBounds;
            exprtCtx.drawImage(chart, 0, 0);
			
			if(legendPos)
            exprtCtx.drawImage(legend, legendPos.X, legendPos.Y);
            //$("#Export_" +Id).css('display', 'none');
          }
            return exportChart;
        },
		
        /**
                 * To configure the properties at runtime using SetModel		
                 * @private
                 */
        _setModel: function (options) {
            for (var prop in options) {
                this.disableAnimation();
                switch (prop) {
                    case "theme":
                        this.model._themeChanged = true;
                        this.model.theme = options[prop];
                        this.setTheme(ej.EjSvgRender.themes, this.model.theme);
                        $.extend(true, this.model.primaryXAxis, ej.EjSvgRender.themes[this.model.theme].primaryXAxis);
                        $.extend(true, this.model.primaryYAxis, ej.EjSvgRender.themes[this.model.theme].primaryYAxis);
                        for (var k = 0; k < this.model.axes.length; k++) {
                            if (this.model.axes[k].orientation && this.model.axes[k].orientation.toLowerCase() == "horizontal")
                                $.extend(true, this.model.axes[k], ej.EjSvgRender.themes[this.model.theme].secondaryX);
                            else
                                $.extend(true, this.model.axes[k], ej.EjSvgRender.themes[this.model.theme].secondaryY);
                        }
                        break;
                    case "commonSeriesOptions":
                        for (var i = 0; i < this.model.series.length; i++)
                            $.extend(true, this.model.series[i], {}, options[prop]);
                        break;
                    case "series":
                        $.extend(true, this.model.series, {}, options[prop]);
                        break;
                    case "legend":
                        $.extend(true, this.model.legend, {}, options[prop]);
                        break;
                    case "axes":
                        $.extend(true, this.model.axes, {}, options[prop]);
                        break;
                    case "primaryXAxis":
                        this.model.primaryXAxis.setRange = (options[prop].range) ? true : false;
                        this.model.primaryXAxis.actual_Range = (this.model._axes[0].setRange) ? null : this.model._axes[0].actual_Range;
                        $.extend(true, this.model.primaryXAxis, {}, options[prop]);
                        break;
                    case "primaryYAxis":
                        this.model.primaryYAxis.setRange = (options[prop].range) ? true : false;
                        this.model.primaryYAxis.actual_Range = (this.model._axes[1].setRange) ? null : this.model._axes[1].actual_Range;
                        $.extend(true, this.model.primaryYAxis, {}, options[prop]);
                        break;
                    case "xZoomFactor":
                        this.model.primaryXAxis.zoomFactor = this._xZoomFactor();
                        break;
                    case "yZoomFactor":
                        this.model.primaryYAxis.zoomFactor = this._yZoomFactor();
                        break;
                    case "xZoomPosition":
                        this.model.primaryXAxis.zoomPosition = this._xZoomPosition();
                        break;
                    case "yZoomPosition":
                        this.model.primaryYAxis.zoomPosition = this._yZoomPosition();
                        break;
                    case "drilldown":
                        this.model.series = [];
                        this.model.explodeValue = null;
                        $.extend(true, this.model, {}, options[prop]);
                        break;
                    case "datasource":
                        for (var i = 0; i < this.model.series.length; i++) {
                            this.model.series[i].dataSource = null;
                            this.model.series[i].points = null;
                        }
                        $.extend(true, this.model, {}, options[prop]);
                        break;

                    default:
                        $.extend(true, this.model, {}, options[prop]);
                }
            }

            if (this.model.enableCanvasRendering) {
                $(this.svgObject).remove();
                $("#canvas_trackSymbol").remove();
                this.svgRenderer = new ej.EjCanvasRender(this.element); // to create canvas container
                this.svgRenderer.svgObj.height = ej.util.isNullOrUndefined(this.model.size.height) ? "450" : this.model.size.height;
                this.svgRenderer.svgObj.width = ej.util.isNullOrUndefined(this.model.size.width) ? $("#" + this._id).width() : this.model.size.width;
                this.svgObject = this.svgRenderer.svgObj;

                $(this.legendSvgContainer).remove();
                this.legendSvgContainer = this.svgRenderer.createLegendCanvas(this.element); //creating new CANVAS element for legend
                this.svgRenderer.append(this.legendSvgContainer, this.legendContainer);
            }
            else if ((this.svgObject.id).indexOf("_canvas") != -1) {
                $(this.svgObject).remove();
                this.svgRenderer = new ej.EjSvgRender(this.element);  // to create svg container
                this.svgObject = this.svgRenderer.svgObj;
                this.canvasX = this.canvasY = 0;

                $(this.legendSvgContainer).remove();
                this.legendSvgContainer = this.svgRenderer.createLegendSvg(this.element); //creating new SVG element for legend
                this.svgRenderer.append(this.legendSvgContainer, this.legendContainer);
            }
            else {
                $(this.svgObject).empty();              // using existing svg container
                $(this.legendSvgContainer).empty();
            }
            
            this.bindTo();
        }
    });

    /**
	 * Enum for chart crosshairType.	 
	 * @enum {string}
	 * @global 
	 */
    ej.datavisualization.Chart.CrosshairType = {
        /**  set crosshair for chart. */
        Crosshair: 'crosshair',
        /**  set trackBall for chart. */
        TrackBall: 'trackBall'
    };
    /**
	 * Enum for chart valueType.	 
	 * @enum {string}
	 * @global 
	 */
    ej.datavisualization.Chart.ValueType = {
        /**  set valueType for chart to double. */
        Double: 'double',
        /**  set valueType for chart to dateTime. */
        DateTime: 'datetime',
        /**  set valueType for chart to category. */
        Category: 'category',
        /**  set valueType for chart to logarithmic. */
        Logarithmic: 'logarithmic'
    };
    /**
	 * Enum for chart series type.	 
	 * @enum {string}
	 * @global 
	 */
    ej.datavisualization.Chart.Type = {
        /**  sets the seriesType of chart to line. */
        Line: 'line',
        /**  sets the seriesType of chart to spline. */
        Spline: 'spline',
        /**  sets the seriesType of chart to column. */
        Column: 'column',
        /**  sets the seriesType of chart to doughnut. */
        Doughnut: 'doughnut',
        /**  sets the seriesType of chart to area. */
        Area: 'area',
        /**  sets the seriesType of chart to splinearea. */
        SplineArea: 'splinearea',
        /**  sets the seriesType of chart to stepline. */
        StepLine: 'stepline',
        /**  sets the seriesType of chart to steparea. */
        StepArea: 'steparea',
        /**  sets the seriesType of chart to pie. */
        Pie: 'pie',
        /**  sets the seriesType of chart to hilo. */
        Hilo: 'hilo',
        /**  sets the seriesType of chart to hiloopenclose. */
        HiloOpenClose: 'hiloopenclose',
        /**  sets the seriesType of chart to candle. */
        Candle: 'candle',
        /**  sets the seriesType of chart to bubble. */
        Bubble: 'bubble',
        /**  sets the seriesType of chart to scatter. */
        Scatter: 'scatter',
        /**  sets the seriesType of chart to bar. */
        Bar: 'bar',
        /**  sets the seriesType of chart to stackingarea. */
        StackingArea: 'stackingarea',
        /**  sets the seriesType of chart to rangecolumn. */
        RangeColumn: 'rangecolumn',
        /**  sets the seriesType of chart to stackingcolumn. */
        StackingColumn: 'stackingcolumn',
        /**  sets the seriesType of chart to stackingbar. */
        StackingBar: 'stackingbar',
        /**  sets the seriesType of chart to pyramid. */
        Pyramid: 'pyramid',
        /**  sets the seriesType of chart to funnel. */
        Funnel: 'funnel',
        /**  sets the seriesType of chart to polar. */
        Polar: 'polar',
        /**  sets the seriesType of chart to radar. */
        Radar: 'radar',
        /**  sets the seriesType of chart to rangeArea. */
        RangeArea: 'rangearea'

    };
    /**
	 * Enum for chart labelPlacement.	 
	 * @enum {string}
	 * @global 
	 */
    ej.datavisualization.Chart.LabelPlacement = {
        /**  specifies the placement of labels between the ticks. */
        BetweenTicks: "betweenTicks",
        /**  specifies the placement of labels on the ticks. */
        OnTicks: "onTicks"
    };
    /**
    * Enum for chart labelIntersectAction.	 
    * @enum {string}
    * @global 
    */
    ej.datavisualization.Chart.LabelIntersectAction = {
        /**  No action is made on intersection of labels. */
        None: "none",
        /**  Rotate the labels to 90 degree on intersect. */
        Rotate90: "rotate90",
        /**  Rotate the labels to 45 degree on intersect. */
        Rotate45: "rotate45",
        /**  Wrap the label to multiple lines on intersect. */
        Wrap: "wrap",
        /**  Trim the text and display whole text on mouse over. */
        Trim: "trim",
        /**  Hide the label which intersect. */
        Hide: "hide",
        /**  Labels are placed on another row on intersect. */
        MultipleRows: "multipleRows"
    };
    /**
 * Enum for chart edgeLabelPlacement.	 
 * @enum {string}
 * @global 
 */
    ej.datavisualization.Chart.EdgeLabelPlacement = {
        /**  Places the edge labels in the same position. */
        None: "none",
        /**  Shift the edge labels inside the chart area. */
        Shift: "shift",
        /**  Hide the edge labels which exceeds the chart area boundary. */
        Hide: "hide"
    };
    /**
	 * Enum for chart themes.	 
	 * @enum {string}
	 * @global 
	 */
    ej.datavisualization.Chart.Theme = {
        /**  Render chart in azure theme. */
        Azure: 'azure',
        /**  Render chart in flatlight theme. */
        FlatLight: 'flatlight',
        /**  Render chart in azuredark theme. */
        Azuredark: 'azuredark',
        /**  Render chart in lime theme. */
        Lime: 'lime',
        /**  Render chart in limedark theme. */
        LimeDark: 'limedark',
        /**  Render chart in saffron theme. */
        Saffron: 'saffron',
        /**  Render chart in saffrondark theme. */
        SaffronDark: 'saffrondark',
        /**  Render chart in gradientlight theme. */
        GradientLight: 'gradientlight',
        /**  Render chart in gradientdark theme. */
        GradientDark: 'gradientdark'
    };
    /**
	 * Enum for chart style of font.	 
	 * @enum {string}
	 * @global 
	 */
    ej.datavisualization.Chart.FontStyle = {
        /**  Render normal font. */
        Normal: 'normal',
        /**  Render bold font. */
        Bold: 'bold',
        /**  Render italic font. */
        Italic: 'italic'
    };
    /**
	 * Enum for weight of font.	 
	 * @enum {string}
	 * @global 
	 */
    ej.datavisualization.Chart.FontWeight = {
        /**  Render regular font. */
        Regular: 'regular',
        /**  Render lighter font. */
        Lighter: 'lighter'
    };
    /**
	 * Enum for chart orientation.	 
	 * @enum {string}
	 * @global 
	 */
    ej.datavisualization.Chart.Orientation = {
        /**  Sets chart orientation to horizontal. */
        Horizontal: 'horizontal',
        /**  Sets chart orientation to vertical. */
        Vertical: 'vertical'
    };
    /**
	 * Enum for chart interval type.	 
	 * @enum {string}
	 * @global 
	 */
    ej.datavisualization.Chart.IntervalType = {
        /**  Sets chart interval type to days. */
        Days: 'days',
        /**  Sets chart interval type to hours. */
        Hours: 'hours',
        /**  Sets chart interval type to seconds. */
        Seconds: 'seconds',
        /**  Sets chart interval type to milliseconds. */
        Milliseconds: 'milliseconds',
        /**  Sets chart interval type to minutes. */
        Minutes: 'minutes',
        /**  Sets chart interval type to months. */
        Months: 'months',
        /**  Sets chart interval type to years. */
        Years: 'years'
    };
    /**
	 * Enum for range padding.	 
	 * @enum {string}
	 * @global 
	 */
    ej.datavisualization.Chart.RangePadding = {
        /**  Sets chart range padding as additional. */
        Additional: 'additional',
        /**  Sets chart range padding as normal. */
        Normal: 'normal',
        /**  Sets chart range padding as none. */
        None: 'none',
        /**  Sets chart range padding as round. */
        Round: 'round'
    };
    /**
	 * Enum for text alignment.	 
	 * @enum {string}
	 * @global 
	 */
    ej.datavisualization.Chart.TextAlignment = {
        /**  Support for changing text alignment to middleTop. */
        MiddleTop: 'middletop',
        /**  Support for changing text alignment to middleCenter. */
        MiddleCenter: 'middlecenter',
        /**  Support for changing text alignment to middleBottom. */
        MiddleBottom: 'middlebottom'
    };
    /**
	 * Enum for label position.	 
	 * @enum {string}
	 * @global 
	 */
    ej.datavisualization.Chart.LabelPosition = {
        /**  Support for changing the labelPosition to inside. */
        Inside: 'inside',
        /**  Support for changing the labelPosition to outside. */
        Outside: 'outside'
    };
    /**
	 * Enum for zIndex.	 
	 * @enum {string}
	 * @global 
	 */
    ej.datavisualization.Chart.ZIndex = {
        /**  Support for changing the zIndex to over. */
        Over: 'over',
        /**  Support for changing the labelPosition to behind. */
        Behind: 'behind'
    };
    /**
	 * Enum for chart unit.	 
	 * @enum {string}
	 * @global 
	 */
    ej.datavisualization.Chart.Unit = {
        /**  Specifies the unit in percentage. */
        percentage: 'percentage',
        /**  Specifies the unit in pixel. */
        pixel: 'pixel'
    };
    /**
	 * Enum for chart pyramid mode.	 
	 * @enum {string}
	 * @global 
	 */
    ej.datavisualization.Chart.PyramidMode = {
        /**  Specifies the mode of the pyramid as linear. */
        Linear: 'linear',
        /**  Specifies the mode of the pyramid as surface. */
        Surface: 'Surface'
    };
    /**
    * Enum for chart drawType mode.	 
    * @enum {string}
    * @global 
    */
    ej.datavisualization.Chart.DrawType = {
        /**  Specifies the drawType as line. */
        Line: 'line',
        /**  Specifies the drawType as column. */
        Column: 'column',
        /**  Specifies the drawType as area. */
        Area: 'area'
    };
    /**
	 * Enum for chart shape.	 
	 * @enum {string}
	 * @global 
	 */
    ej.datavisualization.Chart.Shape = {
        /**  Sets the shape to none. */
        None: 'none',
        /**  Sets the shape to leftarrow. */
        LeftArrow: 'leftarrow',
        /**  Sets the shape to rightarrow. */
        RightArrow: 'rightarrow',
        /**  Sets the shape to circle. */
        Circle: 'circle',
        /**  Sets the shape to cross. */
        Cross: 'cross',
        /**  Sets the shape to horizline. */
        HorizLine: 'horizline',
        /**  Sets the shape to vertline. */
        VertLine: 'vertLine',
        /**  Sets the shape to diamond. */
        Diamond: 'diamond',
        /**  Sets the shape to rectangle. */
        Rectangle: 'rectangle',
        /**  Sets the shape to triangle. */
        Triangle: 'triangle',
        /**  Sets the shape to invertedtriangle. */
        InvertedTriangle: 'invertedtriangle',
        /**  Sets the shape to hexagon. */
        Hexagon: 'hexagon',
        /**  Sets the shape to pentagon. */
        Pentagon: 'pentagon',
        /**  Sets the shape to star. */
        Star: 'star',
        /**  Sets the shape to ellipse. */
        Ellipse: 'ellipse',
        /**  Sets the shape to wedge. */
        Wedge: 'wedge',
        /**  Sets the shape to trapezoid. */
        Trapezoid: 'trapezoid',
        /**  Sets the shape to uparrow. */
        UpArrow: 'uparrow',
        /**  Sets the shape to downarrow. */
        DownArrow: 'downarrow',
        /**  Sets the shape to image. */
        Image: 'image'
    };
    /**
	 * Enum for hilopenclose drawmode.	 
	 * @enum {string}
	 * @global 
	 */
    ej.datavisualization.Chart.DrawMode = {
        /**  Specifies the draw mode as both. */
        Both: 'both',
        /**  Specifies the draw mode as open. */
        Open: 'open',
        /**  Specifies the draw mode as close */
        Close: 'close'
    };
    /**
	 * Enum for linecap.	 
	 * @enum {string}
	 * @global 
	 */
    ej.datavisualization.Chart.LineCap = {
        /**  Sets the linecap as butt. */
        Butt: 'butt',
        /**  Sets the linecap as round. */
        Round: 'round',
        /**  Sets the linecap as square. */
        Square: 'square'
    };
    /**
	 * Enum for line join.	 
	 * @enum {string}
	 * @global 
	 */
    ej.datavisualization.Chart.LineJoin = {
        /**  Sets the lineJoin to round. */
        Round: 'round',
        /**  Sets the lineJoin to bevel. */
        Bevel: 'bevel',
        /**  Sets the lineJoin to miter. */
        Miter: 'miter'
    };
    /**
	 * Enum for position.	 
	 * @enum {string}
	 * @global 
	 */
    ej.datavisualization.Chart.Position = {
        /**  Sets the position to top. */
        Top: 'top',
        /**  Sets the position to middle. */
        Middle: 'middle',
        /**  Sets the position to bottom. */
        Bottom: 'bottom'
    };
    /**
	 * Enum for alignment.	 12
	 * @enum {string}
	 * @global 
	 */
    ej.datavisualization.Chart.Alignment = {
        /**  Sets the lineJoin to center. */
        Center: 'center',
        /**  Sets the lineJoin to near. */
        Near: 'near',
        /**  Sets the lineJoin to far. */
        Far: 'far'
    };
    $.extend(ej.datavisualization.Chart.prototype, ej.ejChart);
})(jQuery, Syncfusion);