/**
* @fileOverview Plugin to create the Gantt
* @copyright Copyright Syncfusion Inc. 2001 - 2013. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
* @version 12.1 
* @author <a href="mailto:licensing@syncfusion.com">Syncfusion Inc</a>
*/

(function ($, ej, undefined) {
    /**
* @namespace ej
* @class ejGantt
* @requires jQuery
* @requires jquery.globalize.js
* @requires jquery.easing.1.3.js
* @requires jsrender.js
* @requires ej.web.all.js
* @classdesc Custom Design for Html Gantt control.
* @example 
* &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
* &lt;script&gt;
* // Create Gantt
* $('#gantt').ejGantt(); 	
* &lt;/script&gt;
*/
   
    ej.widget("ejGantt", "ej.Gantt", {

        // widget element will be automatically set in this
        _rootCSS: "e-gantt",

        element: null,

        validTags: ["div"],
        // user defined model will be automatically set in this
        model: null,
        _tags: [{
            tag: "holidays",
            attr: ["day", "background", "label"],
            content: "template"
        },
        {
            tag: "stripLines",
            attr: ["day", "label", "lineStyle", "lineColor", "lineWidth"],
            content: "template"
        },
         {
             tag: "editDialogFields",
             attr: ["field", "editType"],
             content: "template"
         },
         {
             tag: "addDialogFields",
             attr: ["field", "editType"],
             content: "template"
         },
         {
            tag: "sortSettings.sortedColumns",
            attr: ["field","direction"]
         }
        ],
        _holidays: function (index, property, value, old) {
            $("div.e-secondary-canvas-holiday").remove();
            this._$ganttchartHelper.ejGanttChart("refreshHolidays");
            this._trigger("refresh");
        },
        _stripLines: function (index, property, value, old) {
            $("div.e-stripLines").remove();
            this._$ganttchartHelper.ejGanttChart("refreshStripLines");
            this._trigger("refresh");
        },
        _editDialogFields: function (index, property, value, old) {
            this._trigger("refresh");
        },
        _addDialogFields: function (index, property, value, old) {
            this._trigger("refresh");
        },
        defaults: {
            /**		
            * Enables or disables sorting. When enabled, we can sort the column by clicking on the column.
            * @default false
            * @type {boolean}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;        
            * 	$("#gantt").ejGantt({ allowSorting:  true });            
            * &lt;/script&gt;
            * @memberof ejGantt
			* @instance
            */
            allowSorting: false,

            /**		
            * Enables or disables the ability to resize column.
            * @default false
            * @type {boolean}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;                   
            * 	$("#gantt").ejGantt({ allowColumnResize:  true });			* 
            * &lt;/script&gt;
            * @memberof ejGantt
			* @instance
            */
            allowColumnResize: false,

            /**		
            * Enables or disables the interactive selection of a row.
            * @default true
            * @type {boolean}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;   
            * 	$("#gantt").ejGantt({ allowSelection:  true });			* 
            * &lt;/script&gt;
            * @memberof ejGantt
			* @instance
            */
            allowSelection: true,

            /**		
            * Collection of data or hierarchical data  to represent in gantt
            * @default 
            * @type {array}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt; 		
            * 	$("#gantt").ejGantt(
            *  {
            *     dataSource:[{Id:2,TaskName:"Testing",startDate:"12/1/2000",Duration:5 }]	
            *  });		
            * &lt;/script&gt;
            * @memberof ejGantt
			* @instance
            */
            dataSource:null,

            /**		
            * It receives query to retrieve data from the table (query is same as SQL). 
            * @default 
            * @type {object}
            * @example
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;  			
            * 	$("#gantt").ejGantt(
            *  {
            *     query:ej.Query().from("Categories").select("CategoryID,CategoryName").take(3);	
            *  });		
            * &lt;/script&gt;
            * @memberof ejGantt
			* @instance
            */
            query: null,

           /**		
           * Specifies the mapping property path for task Id in datasource
           * @default ""
           * @type {string}
           * @example 
           * &lt;div id="gantt"&gt;&lt;/div&gt; 
           * &lt;script&gt;  				
           * 	$("#gantt").ejGantt({  taskIdMapping : "ID" });	
           * &lt;/script&gt;
           * @memberof ejGantt
			* @instance
           */
            taskIdMapping: "",

            /**		
            * Specifies the mapping property path for parent task Id in selfreference datasource
            * @default ""
            * @type {string}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;  		
            * 	$("#gantt").ejGantt({  parentTaskIdMapping : "ID" });	            
            * &lt;/script&gt;
            * @memberof ejGantt
			* @instance
            */
            parentTaskIdMapping: "",
            
            /**		
            * Specifies the mapping property path for task name in datasource
            * @default ""
            * @type {string}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;		
            * 	$("#gantt").ejGantt({  taskNameMapping : "Name" });	
            * &lt;/script&gt;
            * @memberof ejGantt
			* @instance
            */
            taskNameMapping: "",

            /**		
            * Specifies the mapping property path for start date of a task  in datasource
            * @default ""
            * @type {string}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;		 			
            * 	$("#gantt").ejGantt({  startDateMapping : "startdate" });	         
            * &lt;/script&gt;
            * @memberof ejGantt
			* @instance
            */
            startDateMapping: "",

            /**		
           * Specifies the mapping property path for end Date of a task  in datasource
           * @default ""
           * @type {string}
           * @example 
           * &lt;div id="gantt"&gt;&lt;/div&gt; 
           * &lt;script&gt;				
           * 	$("#gantt").ejGantt({  endDateMapping : "EndDate" });	
           * &lt;/script&gt;
           * @memberof ejGantt
		   * @instance
           */
            endDateMapping: "",

            /**		
           * Specifies the mapping property path for baseline start date of a task  in datasource
           * @default ""
           * @type { string}
           * @example 
           * &lt;div id="gantt"&gt;&lt;/div&gt; 
           * &lt;script&gt;			
           * 	$("#gantt").ejGantt({  baselineStartDateMapping : "BaselineStartDate" });		
           * &lt;/script&gt;
           * @memberof ejGantt
			* @instance
           */
            baselineStartDateMapping: "",

            /**		
            *Specifies the mapping property path for baseline end date in datasource
            * @default ""
            * @type {string}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#gantt").ejGantt({  baselineEndDateMapping : "BaselineEndDate" });
            * &lt;/script&gt;
            * @memberof ejGantt
			* @instance
            */
            baselineEndDateMapping: "",

            /**		
            * Specifies the mapping property path for sub tasks in datasource 
            * @default ""
            * @type {string}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;				
            * 	$("#gantt").ejGantt({  childMapping : "Children" });
            * &lt;/script&gt;
            * @memberof ejGantt
			* @instance
            */
            childMapping: "",

           /**		
           * Specifies the mapping property path for duration of a task in datasource
           * @default ""
           * @type {string}
           * @example 
           * &lt;div id="gantt"&gt;&lt;/div&gt; 
           * &lt;script&gt;		
           * 	$("#gantt").ejGantt({  durationMapping : "Duration" });
           * &lt;/script&gt;
           * @memberof ejGantt
			* @instance
           */
            durationMapping: "",

            /**		
           * Specifies the mapping property path for milestone in datasource
           * @default ""
           * @type {string}
           * @example 
           * &lt;div id="gantt"&gt;&lt;/div&gt; 
           * &lt;script&gt;				
           * 	$("#gantt").ejGantt({  milestoneMapping : "milestone" });	
           * &lt;/script&gt;
           * @memberof ejGantt
			* @instance
           */
            milestoneMapping: "",

           /**		
           *Specifies the mapping property path for  progress percentage  of a task in datasource
           * @default ""
           * @type {string}
           * @example 
           * &lt;div id="gantt"&gt;&lt;/div&gt; 
           * &lt;script&gt;			
           * 	$("#gantt").ejGantt({  progressMapping : "progress" });			
           * &lt;/script&gt;
           * @memberof ejGantt
			* @instance
           */
            progressMapping: "Progress",

            /**		
           *Specifies the mapping property path for predecessors  of a task in datasource
           * @default ""
           * @type {string}
           * @example 
           * &lt;div id="gantt"&gt;&lt;/div&gt; 
           * &lt;script&gt;				
           * 	$("#gantt").ejGantt({  predecessorMapping : "predecessor" });		
           * &lt;/script&gt;
           * @memberof ejGantt
			* @instance
           */
            predecessorMapping: "",

            /**		
            * Specifies the mapping property path for resources of a task in datasource
            * @default ""
            * @type {string}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;				
            * 	$("#gantt").ejGantt({  resourceInfoMapping : "resources" });	
            * &lt;/script&gt;
            * @memberof ejGantt
			* @instance
            */
            resourceInfoMapping: "",

            /**		
           * Collection of data  regarding resources involved in entire project       
           * @default []
           * @type {array}
           * @example 
           * &lt;div id="gantt"&gt;&lt;/div&gt; 
           * &lt;script&gt;			
           * 	$("#gantt").ejGantt(
           *  {
           *    resources:[{id:1; name:"jack" }]	
           *  });		
           * &lt;/script&gt;
           * @memberof ejGantt
			* @instance
           */
            resources: [],

            /**		
           * Collection of holidays with date, background and label information to be displayed in gantt. 
           * @default []
           * @type {array}
           * @example 
           * &lt;div id="gantt"&gt;&lt;/div&gt; 
           * &lt;script&gt;				
           * 	$("#gantt").ejGantt(
           *  {
           *    holidays:[{day:"12/2/2000",background:"cyan",label:"local holiday" }]	
           *  });		
           * &lt;/script&gt;
           * @memberof ejGantt
		   * @instance
           */
            holidays: [],


            /**		
           * Specifies whether to highlight the weekends in gantt .
           * @default true
           * @type {boolean}
           * @example 
           * &lt;div id="gantt"&gt;&lt;/div&gt; 
           * &lt;script&gt;	
           * 	$("#gantt").ejGantt({ highlightWeekends:  true });			* 
           * &lt;/script&gt;
           * @memberof ejGantt
			* @instance
           */
            highlightWeekends: true,

            /**		
           * Specifies start date of the gantt schedule. By default, start date will be rounded to its previous Sunday.
           * @default null
           * @type {string}
           * @example 
           * &lt;div id="gantt"&gt;&lt;/div&gt; 
           * &lt;script&gt;				
           * 	$("#gantt").ejGantt(
           *  {
           *     scheduleStartDate:"12/2/2000"
           *  });		
           * &lt;/script&gt;
           * @memberof ejGantt
			* @instance
           */
            scheduleStartDate: null,


            /**		
           * Specifies end date of the gantt schedule. By default, end date will be rounded to its next Saturday.
           * @default null
           * @type {string}
           * @example 
           * &lt;div id="gantt"&gt;&lt;/div&gt; 
           * &lt;script&gt;	 			
           * 	$("#gantt").ejGantt(
           *  {
           *     scheduleEndDate:"12/2/2000"
           *  });		
           * &lt;/script&gt;
           * @memberof ejGantt
			* @instance
           */
            scheduleEndDate: null,

            /**		
           * Indicates whether we can edit the progress of a task interactively in gantt chart.
           * @default true
           * @type {boolean}
           * @example 
           * &lt;div id="gantt"&gt;&lt;/div&gt; 
           * &lt;script&gt;	
           * 	$("#gantt").ejGantt({ enableProgressBarResizing:  true });			
           * &lt;/script&gt;
           * @memberof ejGantt
			* @instance
           */
            enableProgressBarResizing: true,

            /**		
           * Specifies the height of a single row in gantt. Also, we need to set same height in the CSS style with class name e-rowcell. 
           * @default "30"
           * @type {number}
           * @example 
           * &lt;div id="gantt"&gt;&lt;/div&gt; 
           * &lt;script&gt;				
           * 	$("#gantt").ejGantt({  
           *			rowHeight : 30,
           * 			});
           * &lt;/script&gt;
           * @memberof ejGantt
			* @instance
           */
            rowHeight: 30,

           /**		
           * Specifies whether to include weekends while calculating the duration of a task. 
           * @default true
           * @type {boolean}
           * @example 
           * &lt;div id="gantt"&gt;&lt;/div&gt; 
           * &lt;script&gt;	
           * 	$("#gantt").ejGantt({ includeWeekend:  true });			
           * &lt;/script&gt;
           * @memberof ejGantt
			* @instance
           */
            includeWeekend: true,

            /**		
			* Specifies the toolbarSettings options.
			* @type {object}
            * @memberof ejGantt
			* @instance
			*/
            toolbarSettings: {

                /**		
                * Specifies the state of enabling or disabling toolbar
                 * @alias ejGantt#toolbarSettings->showToolBar
                * @default true
                * @type {boolean}
                * @example 
                * &lt;div id="gantt"&gt;&lt;/div&gt; 
                * &lt;script&gt;	
                * 	$("#gantt").ejGantt({ showToolBar:  true });			 
                * &lt;/script&gt;
                * @memberof ejGantt
			    * @instance
                */
                showToolbar: false,


                /**		
                * Specifies the list of toolbar items to rendered in toolbar
                * @alias ejGantt#toolbarSettings->toolbarItems
                * @default []
                * @type {array}
                * @example 
                * &lt;div id="gantt"&gt;&lt;/div&gt; 
                * &lt;script&gt;	
                * 	$("#gantt").ejGantt({ toolbarItems: [ej.Gantt.ToolbarItems.Add,ej.Gantt.ToolbarItems.Edit] });			 
                * &lt;/script&gt;
                * @memberof ejGantt
			    * @instance
                */
                toolbarItems: []
            },

            /**		
            * Specifies the options for striplines
            * @default "[]"
            * @type {string}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#gantt").ejGantt(stripLines: [
            *    {
            *     day: "12/2/2000,
            *     label: "Project Release",
            *     lineStyle: "dotted",
            *     lineColor: "Darkblue",
            *     lineWidth: 2
            *   }
            * ]); 
            * &lt;/script&gt;
            * @memberof ejGantt
			* @instance
            */
            stripLines: [],            
            /**		
            * Specifies the working time schedule fo day           
            * @default "TimeScale24"
            * @type {enum}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;				
            * 	$("#gantt").ejGantt({  
            *			workingTimeScale : "TimeScale24Hours" 
            });
            * &lt;/script&gt;
            * @memberof ejGantt
			* @instance
            */
            workingTimeScale: 'TimeScale8Hours',


            /**		
            * Specifies whether rounding off the day working time edits
          
            * @default "true"   
            * @type {boolean}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;				
            * 	$("#gantt").ejGantt({  
            *			roundOffDayworkingTime : true });
            * &lt;/script&gt;
            * @memberof ejGantt
            * @instance
            */
            roundOffDayworkingTime: true,

            /**		
            * Specifies the duration unit for each tasks whether days or hours
           
            * @default "day"
            * @type {enum}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;				
            * 	$("#gantt").ejGantt({  
            *			durationUnit : day });
            * &lt;/script&gt;
            * @memberof ejGantt
            * @instance
            */
            durationUnit: 'day',
            /**		
            * Specified the format for weekview for schedule header
            * @alias ejGantt#scheduleHeaderSettings->weekHeaderFormat
            * @default "MMM dd , yyyy"
            * @type {string}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;				
            * 	$("#gantt").ejGantt({  
            *			scheduleHeaderSettings:{weekHeaderFormat : "MMM dd , yyyy" }
            });
            * &lt;/script&gt;              
            */
            /**		
			* Specifies the options for customizing schedule header. 
			* @type {object}
            * @memberof ejGantt
			* @instance
			*/
            scheduleHeaderSettings:
            {
                /**		
               * Specified the format for week view in schedule header
               * @alias ejGantt#scheduleHeaderSettings->weekHeaderFormat
               * @default "ddd"
               * @type {string}
               * @example 
               * &lt;div id="gantt"&gt;&lt;/div&gt; 
               * &lt;script&gt;				
               * 	$("#gantt").ejGantt({  
               *			scheduleHeaderSettings:{weekHeaderFormat : "MMM dd , yyyy" }
               });
               * &lt;/script&gt;                                  */
                
                weekHeaderFormat: "MMM dd , yyyy",

                /**		
                * Specified the format for day view in schedule header
                * @alias ejGantt#scheduleHeaderSettings->dayHeaderFormat
                * @default "ddd"
                * @type {string}
                * @example 
                * &lt;div id="gantt"&gt;&lt;/div&gt; 
                * &lt;script&gt;				
                * 	$("#gantt").ejGantt({  
                *			scheduleHeaderSettings:{dayHeaderFormat : "ddd" }
                });
                * &lt;/script&gt;              
		
                */
                dayHeaderFormat: "ddd",

                /**		
               * Specified the format for year view in schedule header
               * @alias ejGantt#scheduleHeaderSettings->yearHeaderFormat
               * @default "yyyy"
               * @type {string}
               * @example 
               * &lt;div id="gantt"&gt;&lt;/div&gt; 
               * &lt;script&gt;				
               * 	$("#gantt").ejGantt({  
               *			scheduleHeaderSettings:{yearHeaderFormat : "yyyy" }
               });
               * &lt;/script&gt;               
               */
                yearHeaderFormat: "yyyy",

                /**		
               * Specified the format for month view in schedule header
               * @alias ejGantt#scheduleHeaderSettings->monthHeaderFormat
               * @default "MMM"
               * @type {string}
               * @example 
               * &lt;div id="gantt"&gt;&lt;/div&gt; 
               * &lt;script&gt;				
               * 	$("#gantt").ejGantt({  
               *			scheduleHeaderSettings:{monthHeaderFormat : "MMM" }
               });
               * &lt;/script&gt;              
               */
                monthHeaderFormat: "MMM",


                /**		
                * Specified the background for weekends in gantt
                * @alias ejGantt#scheduleHeaderSettings->hourHeaderFormat
                * @default "#F2F2F2"
                * @type {string}
                * @example 
                * &lt;div id="gantt"&gt;&lt;/div&gt; 
                * &lt;script&gt;			
                * 	$("#gantt").ejGantt({  
                *			scheduleHeaderSettings:{hourHeaderFormat : 'HH'}
                });
                * &lt;/script&gt;               
                */
                hourHeaderFormat: 'HH',

                /**		
               * Specifies the schedule mode
               * @alias ejGantt#scheduleHeaderSettings->scheduleHeaderType
               * @default "week"
               * @type {enum}
               * @example 
               * &lt;div id="gantt"&gt;&lt;/div&gt; 
               * &lt;script&gt;				
               * 	$("#gantt").ejGantt({  
               *			scheduleHeaderSettings:{scheduleHeaderType : "week"}
               });
               * &lt;/script&gt;              
               */
                scheduleHeaderType: 'week',


                /**		
                * Specified the background for weekends in gantt
                * @alias ejGantt#scheduleHeaderSettings->weekendBackground
                * @default "#F2F2F2"
                * @type {string}
                * @example 
                * &lt;div id="gantt"&gt;&lt;/div&gt; 
                * &lt;script&gt;			
                * 	$("#gantt").ejGantt({  
                *			scheduleHeaderSettings:{weekendBackground : "#F2F2F2"}});
                * &lt;/script&gt;
                */
                weekendBackground: '#F2F2F2'


            },

            /**		
            * Specifies the background of the taskbar in gantt
            * @default ""
            * @type {string}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;	
            * 	$("#gantt").ejGantt({  
            *			taskbarBackground : "#F2F2F2"});
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            taskbarBackground: "",

            /**		
            *Specifies the background of progressbar in gantt
            * @default ""
            * @type {string}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;	
            * 	$("#gantt").ejGantt({  
            *			progressbarBackground : "#F2F2F2"});
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            progressbarBackground: "",

            /**		
            * Specifies the background of connector lines in Gantt
            * @default ""
            * @type {string}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;				
            * 	$("#gantt").ejGantt({  
            *			connectorLineBackground : "#F2F2F2"});
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            connectorLineBackground: "",

            /**		
            * Specifies the background of parent taskbar in gantt
            * @default ""
            * @type {string}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#gantt").ejGantt({  
            *			parentTaskbarBackground : "#F2F2F2"});
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            parentTaskbarBackground: "",

            /**		
            *Specifies the background of parent progressbar in gantt
            * @default ""
            * @type {string}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#gantt").ejGantt({  
            *			parentProgressbarBackground : "#F2F2F2"});
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */

            parentProgressbarBackground: "",

            /**		
            * Specifies the width of the connector lines in gantt
            * @default "1"
            * @type {number}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt; 			
            * 	$("#gantt").ejGantt({  
            *			connectorlineWidth : 1 });
             * &lt;/script&gt;
             * @memberof ejGantt
			   * @instance
            */
            connectorlineWidth: 1,

            /**		
            *Specifies whether to display task name beside task bar.
            * @default "true"
            * @type {boolean}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#gantt").ejGantt({  
            *			showTaskNames : true});
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            showTaskNames: true,


            /**		
            *Specifies whether to show grid cell tooltip.
            * @default "true"
            * @type {boolean}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt; 			
            * 	$("#gantt").ejGantt({  
            *			showGridCellTooltip : true});
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            showGridCellTooltip: false,

            /**		
            *Specifies whether to show grid cell tooltip over expander cell alone.
            * @default "true"
            * @type {boolean}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#gantt").ejGantt({  
            *			showGridExpandCellTooltip : true});
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            showGridExpandCellTooltip: false,

            /**		
            * Specifies whether display task progress inside taskbar.
            * @default "true"
            * @type {boolean}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#gantt").ejGantt({  
            *			showProgressStatus : true});
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            showProgressStatus: true,

            /**		
            * Specifies whether to display resource names for a task beside taskbar.
            * @default "true"
            * @type {boolean}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt; 			
            * 	$("#gantt").ejGantt({  
            *			showResourceNames : true});
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            showResourceNames: true,

            /**		
            * Enables or disables tooltip while editing (dragging/resizing) the taskbar.
            * @default "true"
            * @type {boolean}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt; 			
            * 	$("#gantt").ejGantt({  
            *			enableTaskbarDragTooltip : true});
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            enableTaskbarDragTooltip: true,

            /**		
            * Enables or disables tooltip for taskbar.
            * @default true
            * @type {boolean}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#gantt").ejGantt({  enableTaskbarTooltip : true });	
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            enableTaskbarTooltip: true,

            /**		
            * Specifies the editSettings options in gantt. 
            * @type {object}
            * @memberof ejGantt
			   * @instance
            */
            editSettings: {

            /**		
            * specifies the option for enabling / disablig editing in gantt grid part
            * @alias ejGantt#editSettings->allowEditing
            * @default false
            * @type {boolean}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#gantt").ejGantt({  editSettings:{allowEditing : true} });	
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
              allowEditing: false,

            /**		
            * enables/disables add gantt in toolbar
            * @alias ejGantt#editSettings->allowAdding
            * @default false
            * @type {boolean}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt; 			
            * 	$("#gantt").ejGantt({  editSettings:{allowAdding : true} });
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            allowAdding: false,

            /**		
            * enables/disables delete gantt in toolbar
            * @alias ejGantt#editSettings->allowDeleting
            * @default false
            * @type {boolean}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#gantt").ejGantt({  editSettings:{allowDeleting : true} });	
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
             allowDeleting: false,


            /**		
            * specifies the editmode in gantt , "normal" is for dialog editing ,"cellEditing" is for cell type editing
            * @alias ejGantt#editSettings->editMode
            * @default normal
            * @type {string}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#gantt").ejGantt({  editSettings:{editMode : "normal"} });
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
                editMode: "normal",
            },

            ganttRecords: [],
            parentRecords: [],

            /**		
            * Enables/Disables Keyboard navigation in gantt
            * @default true
            * @type {boolean}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt; 			
            * 	$("#gantt").ejGantt({ allowKeyboardNavigation : true});			
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            allowKeyboardNavigation: true,

            /**		
             * Specify the CSS class to gantt to achieve custom theme.
             * @default ""
             * @type {string}
             * @example 
             * &lt;div id="gantt"&gt;&lt;/div&gt; 
             * &lt;script&gt;		
             * 	$("#gantt").ejGantt({  cssClass : "gradient-lime" });
             * &lt;/script&gt;
             * @memberof ejGantt
			   * @instance
            */
            cssClass: "",

            /**		
            * Specify the locale for gantt
            * @default "en-US"
            * @type {string}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;		
            * 	$("#gantt").ejGantt({  locale : "it-IT" });
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            locale: "en-US",

            /**		
            * Specifies enabling / diabling multiple soting for gantt columns
            * @default false
            * @type {boolean}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#gantt").ejGantt({ allowMultiSorting : true});			
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            allowMultiSorting: false,

            /**		
            *  Specifes the sorting options for gantt.
            * @type {object}
            * @memberof ejGantt
			   * @instance
            */
            sortSettings: {
           /**		
           * Specifes the sorted columns columns for gantt
           * @alias ejGantt#sortSettings->sortedColumns
           * @default []
           * @type {array}
           * @example 
           * &lt;div id="gantt"&gt;&lt;/div&gt; 
           * &lt;script&gt;		
           * 	$("#gantt").ejGantt({ sortSettings{sortedColumns : []}});	           
           * &lt;/script&gt;
           * @memberof ejGantt
			   * @instance
            */
                sortedColumns: []
            },

           
            /**		
            * Enables/Disables enableAltRow row effect in gantt
            * @default true
            * @type {boolean}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#gantt").ejGantt({ enableAltRow : true});			
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            enableAltRow: true,

            /**		
            * Enables/Disables virtualization for rendering gantt items.
            * @default false
            * @type {boolean}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#gantt").ejGantt({ enableVirtualization : true});			
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            enableVirtualization: false,

            /**		
             * Specified the height of the progressbar in taskbar
             * @default "100"
             * @type {number}
             * @example 
             * &lt;div id="gantt"&gt;&lt;/div&gt; 
             * &lt;script&gt;		
             * 	$("#gantt").ejGantt({  
             *			progressbarHeight : 100 });
             * &lt;/script&gt;
             * @memberof ejGantt
			   * @instance
            */
            progressbarHeight: 100,

            /**		
             * Specifies the template for tooltip on mouseaction on taskbars
             * @default null
             * @type {string}
             * @example 
             * &lt;div id="gantt"&gt;&lt;/div&gt; 
             * &lt;script&gt;			
             * 	$("#gantt").ejGantt(
             *  {
             *     taskbarTooltipTemplate: ""
             *  });		
             * &lt;/script&gt;
             * @memberof ejGantt
			   * @instance
            */
            taskbarTooltipTemplate: null,

            /**		
             * Specifies the template for tooltip on resizing progressbar
             * @default null
             * @type {string}
             * @example 
             * &lt;div id="gantt"&gt;&lt;/div&gt; 
             * &lt;script&gt;		
             * 	$("#gantt").ejGantt(
             *  {
             *     progressbarTooltipTemplate: ""
             *  });		
             * &lt;/script&gt;
             * @memberof ejGantt
			   * @instance
            */
            progressbarTooltipTemplate: null,

            /**		
             * Specifies the template for tooltip on mouseaction on taskbars
             * @default null
             * @type {string}
             * @example 
             * &lt;div id="gantt"&gt;&lt;/div&gt; 
             * &lt;script&gt;		
             * 	$("#gantt").ejGantt(
             *  {
             *     taskbarTooltipTemplateId: ""
             *  });		
             * &lt;/script&gt;
             * @memberof ejGantt
			   * @instance
            */
            taskbarTooltipTemplateId: null,
            /**		
            * Specifies the dateFormat for gantt , given format is displayed in tooltip , grid .
            * @default ""
            * @type {string}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;		
            * 	$("#gantt").ejGantt(
            *  {
            *     dateFormat: "dd/MM/yyyy"
            *  });		
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            dateFormat: "",

            /**		
            * Specifies the mapping property name for resource ID in resource Collection in gantt
            * @default ""
            * @type {string}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;	
            * 	$("#gantt").ejGantt(
            *  {
            *     resourceIdMapping: "peopleID"
            *  });		
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            resourceIdMapping: "",

            /**		
            * Specifies the mapping property path for resource name of a task in gantt
            * @default ""
            * @type {string}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;		
            * 	$("#gantt").ejGantt(
            *  {
            *     resourceNameMapping: "EmployeeName"
            *  });		
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            resourceNameMapping: "",

             /**		
             * Specifies the template ID for customized tooltip for progressbar editing in gantt
             * @default null
             * @type {string}
             * @example 
             * &lt;div id="gantt"&gt;&lt;/div&gt; 
             * &lt;script&gt;	
             * 	$("#gantt").ejGantt(
             *  {
             *     progressbarTooltipTemplateId: "tooltiptemplateID"
             *  });		
             * &lt;/script&gt;
             * @memberof ejGantt
			   * @instance
             */
            progressbarTooltipTemplateId: null,

            /**		
            * Specifies the template Id for customized tooltip for taskbar editing in gantt
            * @default null
            * @type {string}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;		
            * 	$("#gantt").ejGantt(
            *  {
            *     taskbarEditingTooltipTemplateId: "TooltipTemplateId"
            *  });		
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            taskbarEditingTooltipTemplateId: null,

            /**		
            * Specifies the template Id for customized tooltip for taskbar editing in gantt
            * @default null
            * @type {string}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#gantt").ejGantt(
            *  {
            *     taskbarEditingTooltipTemplate: "tooltiptemplate"
            *  });		
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            taskbarEditingTooltipTemplate: null,

          /**		
          * Specifies the selected row Index in gantt , the row with given index is highlighted
          * @default  "-1"
          * @type {number}
          * @example 
          * &lt;div id="gantt"&gt;&lt;/div&gt; 
          * &lt;script&gt;			
          * 	$("#gantt").ejGantt(
          *  {
          *     selectedRowIndex:2
          *  });		
          * &lt;/script&gt;
          * @memberof ejGantt
			   * @instance
          */
          selectedRowIndex: -1,


         /**		
         * Enables or Disables gantt chart editing in gantt
         * @default  "true"
         * @type {boolean}
         * @example 
         * &lt;div id="gantt"&gt;&lt;/div&gt; 
         * &lt;script&gt;		
         * 	$("#gantt").ejGantt(
         *  {
         *     allowGanttChartEditing:true
         *  });		
         * &lt;/script&gt;
         * @memberof ejGantt
			   * @instance
         */
            allowGanttChartEditing: true,

         /**		
         * Specifies the size option of gantt control.
         * @type {object}
         * @memberof ejGantt
			   * @instance
         */
            sizeSettings: {
                /**		
                * Specifies the height of gantt control
                * @alias ejGantt#sizeSettings->height
                * @default  "450px"
                * @type {string}
                * @example 
                * &lt;div id="gantt"&gt;&lt;/div&gt; 
                * &lt;script&gt;			
                * 	$("#gantt").ejGantt(
                *  {
                *     sizeSettings:{height: "700px"}
                *  });		
                * &lt;/script&gt;
               
                */
                height: null,

                /**		
                * Specifies the width of gantt control
                * @alias ejGantt#sizeSettings->width
                * @default  "1000px"
                * @type {string}
                *  @example 
                * &lt;div id="gantt"&gt;&lt;/div&gt; 
                * &lt;script&gt;		
                * 	$("#gantt").ejGantt(
                *  {
                *     sizeSettings:{width: "700px"}
                *  });		
                * &lt;/script&gt;
              
                */
                width: null,
            },

          /**		
           * Specifies the selected row index in gantt
           * @default  null
           * @type {number}
           * @example 
           * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;	
           * 	$("#gantt").ejGantt(
           *  {
           *     selectedItem: 2
           *  });		
           * &lt;/script&gt;
           * @memberof ejGantt
			   * @instance
           */
           selectedItem: null,

          /**		
          * Specifies the weekendBackground color in gantt
          * @default  "#F2F2F2"
          * @type {string}
          * @example 
          * &lt;div id="gantt"&gt;&lt;/div&gt; 
          * &lt;script&gt;		
          * 	$("#gantt").ejGantt(
          *  {
          *     weekendBackground: "blue"
          *  });		
          * &lt;/script&gt;
          * @memberof ejGantt
			   * @instance
          */
            weekendBackground: '#F2F2F2',

            /**		
           * Specifies the baseline background color in gantt
           * @default  "#fba41c"
           * @type {string}
           * @example 
           * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;	
           * 	$("#gantt").ejGantt(
           *  {
           *     baselineColor: "blue"
           *  });		
           * &lt;/script&gt;
           * @memberof ejGantt
			   * @instance
           */
            baselineColor: '#fba41c',

            /**		
           * Specifies the tree expander column in gantt
           * @default  0
           * @type {number}
           * @example 
           * &lt;div id="gantt"&gt;&lt;/div&gt; 
           * &lt;script&gt;		
           * 	$("#gantt").ejGantt(
           *  {
           *     treeColumnIndex: 1
           *  });		
           * &lt;/script&gt;
           * @memberof ejGantt
		   * @instance
           */
            treeColumnIndex: 0,
            
            /**		
           * Specifies the fields to be included in the edit dialog in gantt
           * @default  []
           * @type {Array}
           * @example 
           * &lt;div id="gantt"&gt;&lt;/div&gt; 
           * &lt;script&gt;			
           * 	$("#gantt").ejGantt(
           *  {
           *     editDialogFields: [{ field: "taskId", editType: "stringedit" }]
           *  });		
           * &lt;/script&gt;
           * @memberof ejGantt
			   * @instance
           */
            editDialogFields: [],
            

             /**		
           * Specifies the fields to be included in the add dialog in gantt
           * @default  []
           * @type {Array}
           * @example 
           * &lt;div id="gantt"&gt;&lt;/div&gt; 
           * &lt;script&gt;			
           * 	$("#gantt").ejGantt(
           *  {
           *     addDialogFields: [{ field: "taskId", editType: "stringedit" }]
           *  });		
           * &lt;/script&gt;
           * @memberof ejGantt
			   * @instance
           */
            addDialogFields: [],
            /**		
            * Enables or Disables rendering baselines in Gantt , when enabled baseline is rendered in gantt
            * @default  "false"
            * @type {boolean}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;		
            * 	$("#gantt").ejGantt(
            *  {
            *     renderBaseline: false
            *  });		
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            renderBaseline: false,

            /**		
            * Enables or disables the contextmenu for gantt , when enabled contextmenu appears on right clicking gantt
            * @default  "false"
            * @type {boolean}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#gantt").ejGantt(
            *  {
            *     enableContextMenu: false
            *  });		
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            enableContextMenu: false,

           

            /**		
            * Enables or disables the option for dynamically updating the Gantt size on window resizing
            * @default  "false"
            * @type {boolean}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#gantt").ejGantt(
            *  {
            *     enableResize: false
            *  });		
            * &lt;/script&gt;
            * @memberof ejGantt
		    * @instance
            */
            enableResize:false,

            /**		
            * Enables or disables the collapse all tasks for gantt , when enabled all sub tasks will disappears in gantt
            * @default  "false"
            * @type {boolean}
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;			
            * 	$("#gantt").ejGantt(
            *  {
            *     enableCollapseAll: false
            *  });		
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            enableCollapseAll: false,
            /**    
			* Triggered before the row is going to be selected.
			* @event
			* @name ejGantt#rowSelecting 
			* @param {Object} argument Arguments when rowSelecting event is triggered.  
			* @param {boolean} argument.cancel Returns the cancel option value.
			* @param {object} argument.rowElement Returns the selecting row element.
			* @param {string} argument.recordIndex Returns the index of selecting row record.
			* @param {object} argument.data Returns the data selecting record.
			* @example 
			* &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;
			* $("#gantt").ejGantt({
			*    rowSelecting: function (args) {}
			* });
			* &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            rowSelecting: null,

            /**    
			* Triggered after the row is selected.
			* @event
			* @name ejGantt#rowSelected 
			* @param {Object} argument Arguments when rowSelected event is triggered.  
			* @param {boolean} argument.cancel Returns the cancel option value.
			* @param {object} argument.rowElement Returns the selecting row element.
			* @param {string} argument.recordIndex Returns the index of selecting row record.
			* @param {object} argument.data Returns the data of selected record.
			* @example 
			* &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;
			* $("#gantt").ejGantt({
			*    rowSelected: function (args) {}
			* });
			* &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            rowSelected: null,

            /**    
            * Triggered while rendering each cell in the grid tree
            * @event
            * @name ejGantt#queryCellInfo 
            * @param {Object} argument Arguments when queryCellInfo event is triggered.  
            * @param {boolean} argument.cancel Returns the cancel option value.
            * @param {object} argument.rowElement Returns the selecting row element.
            * @param {string} argument.cellValue Returns the value of cell.
            * @param {object} argument.data Returns the data of current cell record.
            * @param {object} argument.column Returns the column of cell belongs.
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#gantt").ejGantt({
            *    queryCellInfo: function (args) {}
            * });
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            queryCellInfo: null,

            /**    
            * Triggered while rendering each taskbar in the gantt chart
            * @event
            * @name ejGantt#queryTaskbarInfo 
            * @param {Object} argument Arguments when queryTaskbarInfo event is triggered.  
            * @param {boolean} argument.cancel Returns the cancel option value.
            * @param {object} argument.TaskbarBackground Returns the taskbar background of current item.
            * @param {string} argument.ProgressbarBackground Returns the progressbar background of current item.
            * @param {object} argument.data Returns the data of the record.
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#gantt").ejGantt({
            *    queryTaskbarInfo: function (args) {}
            * });
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            queryTaskbarInfo: null,

            /**    
            * Triggered while enter the edit mode in the grid tree cell
            * @event
            * @name ejGantt#beginEdit 
            * @param {Object} argument Arguments when beginEdit event is triggered.  
            * @param {boolean} argument.cancel Returns the cancel option value.
            * @param {object} argument.rowElement Returns the row element of editing cell.
            * @param {object} argument.cellElement Returns the Element of editing cell.
            * @param {object} argument.data Returns the data of current cell record.
            * @param {number} argument.columnIndex Returns the column Index of cell belongs.
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#gantt").ejGantt({
            *    beginEdit: function (args) {}
            * });
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            beginEdit: null,

            /**    
            * Triggered after save the modified cellValue in treegrid
            * @event
            * @name ejGantt#endEdit 
            * @param {Object} argument Arguments when endEdit event is triggered.  
            * @param {boolean} argument.cancel Returns the cancel option value.
            * @param {object} argument.rowElement Returns the row element of editing cell.
            * @param {object} argument.cellElement Returns the Element of editing cell.
            * @param {object} argument.data Returns the data of edited cell record.
            * @param {string} argument.columnName Returns the column name of edited cell belongs.
            * @param {object} argument.columnObject Returns the column object of edited cell belongs.
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#gantt").ejGantt({
            *    endEdit: function (args) {}
            * });
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            endEdit: null,


            /**    
            * Triggered while rendering each row
            * @event
            * @name ejGantt#rowDataBound 
            * @param {Object} argument Arguments when rowDataBound event is triggered.  
            * @param {boolean} argument.cancel Returns the cancel option value.
            * @param {object} argument.rowElement Returns the row element of editing cell.
            * @param {object} argument.data Returns the data of edited cell record..
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#gantt").ejGantt({
            *    rowDataBound: function (args) {}
            * });
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            rowDataBound: null,

            /**    
            * Triggered  while expanding the gantt record
            * @event
            * @name ejGantt#expanding 
            * @param {Object} argument Arguments when expanding event is triggered.  
            * @param {boolean} argument.cancel Returns the cancel option value.
            * @param {object} argument.recordIndex Returns the row index of record.
            * @param {object} argument.data Returns the data of edited cell record..
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#gantt").ejGantt({
            *    expanding: function (args) {}
            * });
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            expanding: null,


            /**    
            * Triggered  after expand the record
            * @event
            * @name ejGantt#expanded 
            * @param {Object} argument Arguments when expanded event is triggered.  
            * @param {boolean} argument.cancel Returns the cancel option value.
            * @param {object} argument.recordIndex Returns the row index of record.
            * @param {object} argument.data Returns the data of edited cell record..
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#gantt").ejGantt({
            *    expanded: function (args) {}
            * });
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            expanded: null,

            /**    
            * Triggered while collapsing the gantt record
            * @event
            * @name ejGantt#collapsing 
            * @param {Object} argument Arguments when collapsing event is triggered.  
            * @param {boolean} argument.cancel Returns the cancel option value.
            * @param {object} argument.recordIndex Returns the row index of collapsing record.
            * @param {object} argument.data Returns the data of edited cell record..
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#gantt").ejGantt({
            *    collapsing: function (args) {}
            * });
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            collapsing: null,

            /**    
            * Triggered after collapsing the gantt record
            * @event
            * @name ejGantt#collapsed 
            * @param {Object} argument Arguments when collapsed event is triggered.  
            * @param {boolean} argument.cancel Returns the cancel option value.
            * @param {object} argument.recordIndex Returns the row index of collapsed record.
            * @param {object} argument.data Returns the data of edited cell record..
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#gantt").ejGantt({
            *    collapsed: function (args) {}
            * });
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            collapsed: null,


            /**    
            * Triggered after collapsing the gantt record
            * @event
            * @name ejGantt#actionBegin 
            * @param {Object} argument Event parameters when gantt is initialized:          
			* @param {boolean}  argument.cancel Returns the cancel option value.
			* @param {object}  argument.model Returns the grid model.
			* @param {string}  argument.type Returns the name of the event.

            * @param {Object} argument Event parameters while perform sorting in grid tree action starts:
            * @param {boolean}  argument.cancel Returns the cancel option value.
            * @param {string}  argument.columnName Returns the current grouped column field name.
			* @param {object}  argument.model Returns the gantt model.
            * @param {string}  argument.requestType Returns request type.
            * @param {string}  argument.type Returns the name of the event. 
            * @param {string}  argument.columnSortDirection Returns the direction of sorting ascending or descending
            
            * @param {Object} argument Event parameters while searching action starts:
            * @param {boolean}  argument.cancel Returns the cancel option value.
            * @param {string}  argument.keyValue Returns the value of searching element.
			* @param {object}  argument.model Returns the gantt model.
            * @param {string}  argument.requestType Returns request type.
            * @param {string}  argument.type Returns the name of the event. 
             
            * @param {Object} argument Event parameterswhile performing the delete operation starts:
            * @param {boolean}  argument.cancel Returns the cancel option value.
            * @param {string}  argument.data Returns the data od deleting element.
			* @param {object}  argument.model Returns the gantt model.
            * @param {string}  argument.requestType Returns request type.
            * @param {string}  argument.type Returns the name of the event. 

            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#gantt").ejGantt({
            *    actionBegin: function (args) {}
            * });
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            actionBegin: null,

            /**    
            * Triggered after collapsing the gantt record
            * @event
            * @name ejGantt#actionComplete 
            * @param {Object} argument Event parameters when gantt is initialized:          
			* @param {boolean}  argument.cancel Returns the cancel option value.
			* @param {object}  argument.model Returns the grid model.
			* @param {string}  argument.type Returns the name of the event.

            * @param {Object} argument Event parameters after perform the sorting in grid tree is completed:
            * @param {boolean}  argument.cancel Returns the cancel option value.
            * @param {string}  argument.columnName Returns the current grouped column field name.
			* @param {object}  argument.model Returns the gantt model.
            * @param {string}  argument.requestType Returns request type.
            * @param {string}  argument.type Returns the name of the event. 
            * @param {string}  argument.columnSortDirection Returns the direction of sorting ascending or descending
            
            * @param {Object} argument Event parameters after searching completed:
            * @param {boolean}  argument.cancel Returns the cancel option value.
            * @param {string}  argument.keyValue Returns the value of searched element.
			* @param {object}  argument.model Returns the gantt model.
            * @param {string}  argument.requestType Returns request type.
            * @param {string}  argument.type Returns the name of the event. 
             
            * @param {Object} argument Event parameterswhile performing after completing the delete operation is completed:
            * @param {boolean}  argument.cancel Returns the cancel option value.
            * @param {string}  argument.data Returns the data od deleted element.
			* @param {object}  argument.model Returns the gantt model.
            * @param {string}  argument.requestType Returns request type.
            * @param {string}  argument.type Returns the name of the event. 

            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#gantt").ejGantt({
            *    actionComplete: function (args) {}
            * });
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            actionComplete: null,

            /**    
            * Triggered while editing the gantt chart (dragging, resizing the taskbar )
            * @event
            * @name ejGantt#taskbarEditing 
            * @param {Object} argument Arguments when taskbarEditing event is triggered.  
            * @param {boolean} argument.cancel Returns the cancel option value.
			* @param {object}  argument.model Returns the gantt model.
			* @param {object}  argument.rowData Returns the row object being edited.
			* @param {object}  argument.editingFields Returns the field values of record being edited.
            * @param {string}  argument.type Returns the name of the event. 
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#gantt").ejGantt({
            *    taskbarEditing: function (args) {}
            * });
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            taskbarEditing: null,

            /**    
            * Triggered while after completing the editing operation in taskbar
            * @event
            * @name ejGantt#taskbarEdited 
            * @param {Object} argument Arguments when taskbarEdited event is triggered.  
            * @param {boolean} argument.cancel Returns the cancel option value.
            * @param {object} argument.data Returns the data of edited record.
            * @param {object} argument.previousData Returns the previous data value of edited record.  
            * @param {boolean} argument.dragging Returns 'true' if taskbar is dragged.  
            * @param {boolean} argument.leftResizing Returns 'true' if taskbar is left resized.  
            * @param {boolean} argument.rightResizing Returns 'true' if taskbar is right resized.  
            * @param {boolean} argument.progressResizing Returns 'true' if taskbar is progress resized.  
			* @param {object}  argument.editingFields Returns the field values of record being edited.
			* @param {object}  argument.model Returns the gantt model.
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#gantt").ejGantt({
            *    taskbarEdited: function (args) {}
            * });
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            taskbarEdited: null,

            /**    
            * Triggered while gantt is loaded
            * @event
            * @name ejGantt#load 
            * @param {Object} argument Arguments when load event is triggered.             
            * @param {boolean} argument.cancel Returns the cancel option value.
			* @param {object}  argument.model Returns the gantt model
            * @param {string}  argument.type Returns the name of the event. 
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#gantt").ejGantt({
            *    load: function (args) {}
            * });
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            load: null,

            /**    
            * Triggered while Context Menu is rendered in Gantt control
            * @event
            * @name ejGantt#contextMenuOpen 
            * @param {Object} argument Arguments when context menu is rendered.  
            * @param {boolean} argument.cancel Returns the cancel option value.
            * @param {boolean} argument.contextMenuItems Returns the default context menu items to which we add custom items.
			* @param {object}  argument.model Returns the gantt model.
            * @param {string}  argument.requestType Returns request type.
            * @param {string}  argument.type Returns the name of the event. 
            * @example 
            * &lt;div id="gantt"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#gantt").ejGantt({
            *    contextMenuOpen: function (args) {}
            * });
            * &lt;/script&gt;
            * @memberof ejGantt
			   * @instance
            */
            contextMenuOpen: null,

        },

        dataTypes: {
            allowSorting: "boolean",
            allowColumnResize: "boolean",
            allowSelection: "boolean",
            dataSource: "data", //inline or remote data
            taskIdMapping: "string",
            taskNameMapping: "string",
            startDateMapping: "string",
            endDateMapping: "string",
            baselineStartDateMapping: "string",
            baselineEndDateMapping: "string",
            childMapping: "string",
            durationMapping: "string",
            milestoneMapping: "string",
            progressMapping: "string",
            predecessorMapping: "string",
            resourceInfoMapping: "string",
            resources: "array",
            holidays: "array",
            highlightWeekends: "boolean",
            enableProgressBarResizing: "boolean",
            rowHeight: "number",
            includeWeekend: "boolean",
            toolbarSettings: {
                toolbarItems: "array"
            },
            stripLines: "array",
            scheduleHeaderSettings: "data",
            taskbarBackground: "string",
            progressbarBackground: "string",
            connectorLineBackground: "string",
            parentTaskbarBackground: "string",
            parentProgressbarBackground: "string",
            connectorlineWidth: "number",
            showTaskNames: "boolean",
            showProgressStatus: "boolean",
            showResourceNames: "boolean",
            enableTaskbarDragTooltip: "boolean",
            enableTaskbarTooltip: "boolean",
            editSettings: "data",
            ganttRecords: "array",
            parentRecords: "array",
            allowKeyboardNavigation: "boolean",
            cssClass: "string",
            locale: "string",
            allowMultiSorting: "boolean",
            showGridExpandCellTooltip: "boolean",
            sortSettings: {
                sortedColumns: "array"
            },
            enableAltRow: "boolean",
            enableVirtualization: "boolean",
            progressbarHeight: "number",
            dateFormat: "string",
            resourceIdMapping: "string",
            resourceNameMapping: "string",
          //  selectedRowIndex: "number",
            allowGanttChartEditing: "boolean",
            size: {
                height: "string",
                width: "string"
            },
            selectedItem: "data",
            weekendBackground: "string",
            baselineColor: "string",
            renderBaseline: "boolean",
            showGridCellTooltip: "boolean",
            treeColumnIndex: "number",
            editDialogFields: "array",
            enableResize:"boolean"
        },

        observables: ["selectedItem", "selectedRowIndex","dataSource"],
        selectedItem: ej.util.valueFunction("selectedItem"),
        selectedRowIndex: ej.util.valueFunction("selectedRowIndex"),
        dataSource: ej.util.valueFunction("dataSource"),

        getColumns: function() {
            return this._columns;
        },

        setColumns: function(value) {
            this._columns = value;
        },

        _init: function () {
            var proxy = this,
                model = proxy.model, startDate, endDate;
            proxy._initPrivateProperties();
            proxy._setCultureInfo();
            proxy.element.addClass("e-gantt-core");

            if (model.isdesignMode) {
                model.taskIdMapping = "Id";
                model.taskNameMapping = "Name";
                model.startDateMapping = "StartDate";
                model.durationMapping = "Duration";
                model.progressMapping = "Progress";
                model.scheduleStartDate = "02/23/2014";
                model.scheduleEndDate = "03/10/2014";
                this.dataSource ([{ Id: 1, Name: "Task 1", StartDate: "02/23/2014", Duration: 5, Progress: 40 },
                { Id: 2, Name: "Task 2", StartDate: "02/24/2014",Duration:5,Progress:40 },
                { Id: 3, Name: "Task 3", StartDate: "02/25/2014", Duration: 5, Progress: 40 }]); 
            }
            
            if (model.durationUnit == "hours") {
                model.durationUnit = "hour";
            }
            if (this.dataSource() !== null) {
                this._checkDataBinding();
            }
            else {
                proxy.setColumns(proxy.createTreeGridColumns());
                proxy._initialize();
            }
            //
            //Call collapse All
            if (model.enableCollapseAll) {
                if (this.selectedRowIndex() != -1) {
                    proxy._deSelectRowItem();
                }
                proxy._collapseAll();
            }
            if (model.selectedRowIndex >= 0 && model.selectedRowIndex < proxy._updatedGanttRecords.length) {
                var args = {};
                args.target = "ejTreeGrid";
                model.selectedItem = args.data = proxy._updatedGanttRecords[model.selectedRowIndex];
                args.recordIndex = model.selectedRowIndex;
                proxy.rowSelected(args);
                proxy._$treegrid.focus();
            }
        },

        _deSelectRowItem: function () {
            var proxy = this, model = proxy.model;
            proxy._$ganttchartHelper.ejGanttChart("selectRows", -1);
            proxy._$treegridHelper.ejTreeGrid("selectRows", -1);
            this.selectedRowIndex(-1);
            model.selectedItem = null;
        },
        
        _checkDataBinding: function () {
            var proxy = this, model = proxy.model;

            if (this.dataSource() instanceof ej.DataManager) {
                this._initDataSource();
            }
            else if (this.dataSource().length > 0) {
                if ((model.taskIdMapping.length > 0) && (model.parentTaskIdMapping.length > 0)) {

                    //cloning the datasource
                    var dataArray = this.dataSource().slice(0);
                    var data = [];
                    $.each(dataArray, function (indx, value) {
                        data.push(jQuery.extend(true, {}, value));
                    });
                    proxy._reconstructDatasource(data);
                    proxy._createGanttRecords(proxy.secondaryDatasource);
                }
                else {
                    proxy._createGanttRecords(this.dataSource());
                }
                proxy._initialize();
            }
        },

        _initDataSource: function () {
            var proxy = this, model = proxy.model;     
            var query = this._columnToSelect();
            var proxy = this;
            var queryPromise = this.dataSource().executeQuery(query);
            queryPromise.done(ej.proxy(function (e) {
                if (proxy.dataSource().dataSource.offline) {
                    proxy._retrivedData = proxy.dataSource().dataSource.json;
                } else {
                    proxy._retrivedData = e.result;
                }
                if ((model.taskIdMapping.length > 0) && (model.parentTaskIdMapping.length > 0)) {
                    //cloning the datasource
                    var dataArray = e.result.slice(0);
                    var data = [];
                    $.each(dataArray, function (indx, value) {
                        data.push(jQuery.extend(true, {}, value));
                    });
                    proxy._reconstructDatasource(data);
                }
                else {
                    proxy._reconstructDatasource(e.result);
                }
                proxy._createGanttRecords(proxy.secondaryDatasource);
                proxy._initialize();
            }));
        },

        _columnToSelect: function (mapper) {
            var proxy = this,
                model = proxy.model,
                column = [], queryManager = ej.Query();

                queryManager = model.query;
            return queryManager;
        },

        _reconstructDatasource: function (datasource) {
            var proxy = this, model = proxy.model,
                childItems, data,tempRecord=[];
            
            for (var i = 0; i < datasource.length; i++) {
                var data = {};
                data = ej.DataManager(datasource).executeLocal(ej.Query().where(model.parentTaskIdMapping,
                    ej.FilterOperators.equal,
                    datasource[i][model.taskIdMapping]));
               

                if ((ej.isNullOrUndefined(datasource[i][model.parentTaskIdMapping]) || datasource[i][model.parentTaskIdMapping] == 0)
                    && data.length > 0) {
                    datasource[i][model.childMapping] = data;
                    proxy.secondaryDatasource.push(datasource[i]);
                }
                else if (ej.isNullOrUndefined(datasource[i][model.parentTaskIdMapping]) && !(data && data.length > 0)) {
                    proxy.secondaryDatasource.push(datasource[i]);
                }

                else if (data && data.length > 0 && !(ej.isNullOrUndefined(data[0][model.parentTaskIdMapping]))) {
                    proxy._appendChildDataItems(proxy.secondaryDatasource, data);
                }
                else if ((ej.isNullOrUndefined(datasource[i][model.parentTaskIdMapping]) || datasource[i][model.parentTaskIdMapping] == 0)
                    && data.length == 0) {
                    proxy.secondaryDatasource.push(datasource[i]);
                }

                if (data && data.length > 0) {

                    proxy._datasourceChildItems = proxy._reconstructDatasource(data);
                    if (ej.isNullOrUndefined(datasource[i][model.childMapping])) {
                        datasource[i][model.childMapping] = proxy._datasourceChildItems;
                        proxy._getParentIndex(datasource);
                    }
                    proxy._datasourceChildItems = [];

                }
                
                else if (!(ej.isNullOrUndefined(datasource[i][model.parentTaskIdMapping]))) {
                    tempRecord.push(datasource[i]);
                }
            }

            if (tempRecord && tempRecord.length > 0) {
                return tempRecord;
            }
        },


        _appendChildDataItems: function (parentDatasource, data) {
            var proxy = this,
                model = proxy.model;

            for (var count = 0; count < parentDatasource.length; count++) {

                if (parentDatasource[count][model.taskIdMapping] === data[0][model.parentTaskIdMapping]) {
                    parentDatasource[count][model.childMapping] = data;
                }
                else if (!(ej.isNullOrUndefined(parentDatasource[count][model.childMapping])) &&
                    parentDatasource[count][model.childMapping].length > 0) {
                    proxy._appendChildDataItems(parentDatasource[count], data);
                }
            }

            if ((ej.isNullOrUndefined(parentDatasource.length)) && parentDatasource) {
                if (parentDatasource[model.taskIdMapping] === data[0][model.parentTaskIdMapping]) {
                    parentDatasource[model.childMapping] = data;
                }
                else if (!(ej.isNullOrUndefined(parentDatasource[model.childMapping])) &&
                    parentDatasource[model.childMapping].length > 0) {
                    proxy._appendChildDataItems(parentDatasource[model.childMapping], data);
                }
            }

        },
        _getParentIndex: function (datasource) {
            var proxy = this, model = proxy.model,
                dataArr = proxy.secondaryDatasource, parentIndex = 0;

            if (datasource.length > 0) {
                parentIndex = datasource[0][model.parentTaskIdMapping];
            }
            for (var i = 0; i < dataArr.length; i++) {
                if (dataArr[i][model.taskIdMapping] == parentIndex && ej.isNullOrUndefined(dataArr[i][model.childMapping])) {
                    dataArr[i][model.childMapping] = (datasource);
                    return true;
                }
                else {
                    var childItems = dataArr[i][model.childMapping];
                    if (childItems) {
                        for (var i = 0; i < childItems.length; i++) {
                            if (childItems[i][model.taskIdMapping] == parentIndex && ej.isNullOrUndefined(childItems[i][model.childMapping])) {
                                childItems[i][model.childMapping] = (datasource);
                                return true;
                            }
                        }
                    }
                }
            }

        },

        //refresh the chart with updated schedule dates
        updateScheduleDates: function (startDate, endDate) {
            
            var proxy = this, model = this.model;
                model.scheduleStartDate = startDate;
                model.scheduleEndDate = endDate;
                proxy._scheduleDays = [];
                proxy._scheduleMonths = [];
                proxy._scheduleWeeks = [];
                proxy._scheduleYears = [];
                proxy._calculateHeaderDates();
                var chartObject = $("#ejGanttChart" + proxy._id).ejGanttChart("instance");
                var chartModel = chartObject.model;
                proxy._updateLeftValue();
                chartModel.projectStartDate = proxy._getDateFromFormat(proxy._projectStartDate);
                chartModel.projectEndDate = proxy._getDateFromFormat(proxy._projectEndDate);
                chartModel.scheduleDays = proxy._scheduleDays;
                chartModel.scheduleMonths = proxy._scheduleMonths;
                chartModel.scheduleWeeks = proxy._scheduleWeeks;
                chartModel.scheduleYears = proxy._scheduleYears;
                chartModel.renderBaseline = model.renderBaseline;
                $("#ejGanttChart" + proxy._id).ejGanttChart("refreshChartHeader", proxy._getDateFromFormat(startDate), proxy._getDateFromFormat(endDate));
                $("#ejGanttChart" + proxy._id).ejGanttChart("refreshContainersWidth");
                proxy._$ganttchartHelper.ejGanttChart("refreshHelper", proxy._currentViewData, proxy._updatedGanttRecords, proxy._totalCollapseRecordCount);
                if (model.predecessorMapping) {
                    proxy._$ganttchartHelper.ejGanttChart("clearConnectorLines");
                    proxy._connectorlineIds = [];
                    proxy._connectorLinesCollection = [];
                    proxy._isValidationEnabled = false;
                    proxy._createConnectorLinesCollection();
                    proxy._isValidationEnabled = true;
                }
                chartObject._$bodyContainer.ejScroller("refresh");
        },
        reRenderChart: function (scheduleMode) {
            var proxy = this, model = proxy.model,
                startDate = proxy._getDateFromFormat(model.scheduleStartDate),
                endDate = proxy._getDateFromFormat(model.scheduleEndDate);
            model.ganttRecords = [];
            model.parentRecords = [];
            $("#ejGanttChart" + proxy._id).empty();

            switch (scheduleMode) {
                case ej.Gantt.ScheduleHeaderType.Week:
                    model.scheduleHeaderSettings.scheduleHeaderType = ej.Gantt.ScheduleHeaderType.Week;
                    proxy._perDayWidth = 30;
                    proxy._calculateWeekSplit(startDate, endDate);
                    break;

                case ej.Gantt.ScheduleHeaderType.Day:
                    model.scheduleHeaderSettings.scheduleHeaderType = ej.Gantt.ScheduleHeaderType.Day;
                    model.scheduleHeaderSettings.dayHeaderFormat = "dd, MMM yy";
                    proxy._perHourWidth = 20;
                    if (model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale24Hours)
                        proxy._perDayWidth = (proxy._perHourWidth * 24);//24 hours
                    else if (model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale8Hours)
                        proxy._perDayWidth = (proxy._perHourWidth * 24);//9 hours
                    proxy._calculateDaySplit(startDate, endDate);
                    break;

                case ej.Gantt.ScheduleHeaderType.Month:
                    model.scheduleHeaderSettings.scheduleHeaderType = ej.Gantt.ScheduleHeaderType.Month;
                    model.scheduleHeaderSettings.monthHeaderFormat = "MMM yyyy";
                    model.scheduleHeaderSettings.weekHeaderFormat = "M/dd";
                    proxy._perDayWidth = 10;
                    proxy._perWeekWidth = 70;
                    proxy._calculateMonthSplit(startDate, endDate);
                    break;

                case ej.Gantt.ScheduleHeaderType.Year:
                    model.scheduleHeaderSettings.scheduleHeaderType = ej.Gantt.ScheduleHeaderType.Year;
                    proxy._perDayWidth = 3;
                    proxy._perMonthWidth = 90;
                    proxy._calculateYearSplit(startDate, endDate);
                    break;
            }

            proxy.element.ejGantt("destroy").ejGantt(model)
            proxy._isTreeGridRendered = false;
            proxy._isGanttChartRendered = false;

        },

        _updateGanttRecords: function() {
            var proxy = this, model = proxy.model, count = model.ganttRecords.length;
            for (var i = 0; i < count; i++) {
                model.ganttRecords[i].left = (model.ganttRecords[i].left/proxy._prevDayWidth)*proxy._perDayWidth;
                model.ganttRecords[i].width = (model.ganttRecords[i].width / proxy._prevDayWidth) * proxy._perDayWidth;
                model.ganttRecords[i].width = model.ganttRecords[i].isMilestone == true ? 26 : model.ganttRecords[i].width,
                model.ganttRecords[i].progressWidth = model.ganttRecords[i]._calculateProgressWidth(model.ganttRecords[i].width, model.ganttRecords[i].status);
            }

        },
        
        _initPrivateProperties: function () {

            var proxy = this;
            model = proxy.model;
            scheduleMode = model.scheduleHeaderSettings.scheduleHeaderType;
            proxy._isFromGantt = true;
            proxy._disabledToolItems = [],
            proxy._id = proxy.element.attr('id'),
            proxy._scheduleWeeks = [],
            proxy._duplicate = false,          
            proxy._wrongenddate=false,
            proxy._scheduleYears = [],//new property for year schedule modes

            proxy._scheduleMonths = [], //new property for month

            proxy._scheduleYears = [],//property for schedule years
            proxy._scheduleDays = [],//property for schedule days

            proxy._projectStartDate, //property instead of scheduleWeeks[0] and scheduleYears[0]
            proxy._projectEndDate,

            proxy._columns = [],
            proxy._rows = [],
            proxy._storedIndex = -1,
            proxy._perDayWidth,
            proxy._prevDayWidth = 0,


            proxy._perMonthWidth,//new property for month
            proxy._perWeekWidth,//new property for month-week schedule

            proxy._$treegridPane = null,
            proxy._$ganttchartPane = null,
            proxy._$treegrid = null,
            proxy._$ganttchart = null,
            proxy._$ejGantt = null,
            proxy._$treegridHelper = null,
            proxy._$ganttchartHelper = null;
            proxy._tdsOffsetWidth = [];
            proxy._ids = [];
            proxy._predecessorsCollection = [];
            proxy._connectorLinesCollection = [];            
            proxy._updatedConnectorLineCollection = [];
            proxy._connectorlineIds = [];
            proxy._updatedGanttRecords = [];
            proxy._currentViewData = [];
            proxy._gridRows = null;

            //variables used for ExpandCollapse action in non Virtualization 
            proxy._collapsedRecordCount = 0;
            proxy._expandedRecordsCount = 0;
            proxy._totalCollapseRecordCount = 0;
            proxy._isInExpandCollapse = false;

            proxy._hiddenRecordCount = 0;
            
            proxy.prevPredecessorTO = null;
            proxy.prevPredecessorFrom = null;
            proxy.prevPredecessorcount = 0;
            proxy._isValidationEnabled = true;
            proxy._isTreeGridRendered = false;//indicate treegrid part is rendered or not for refresh row
            proxy._isGanttChartRendered = false;//indicate gantChart part is rendered or not
            proxy._holidaysList = proxy._getHoliday();
            proxy._stringHolidays = proxy._getStringHolidays();
            proxy._isinBeginEdit = false;
            proxy._isMileStoneEdited = false;
            proxy._cellEditType = null;
            proxy._isinAddnewRecord = false;

            //variables for context menu items
            proxy._contextMenuItems = proxy._getContextMenuItems();
            proxy._subContextMenuItems = proxy._getsubContextMenuItems();
            proxy._totalBorderWidth = 2;//Left and Right border width
            proxy._totalBorderHeight = model.toolbarSettings.showToolbar ? 3 : 2,//top,bottom,toolbar div
            //private variable decalartion for localization
            proxy._columnHeaderTexts = null;
            proxy._editDialogTexts = null;
            proxy._months = null;  
            proxy._days = null;
            proxy._emptyRecordText = null;
            proxy._commonColumnWidth = 150;
            proxy._searchString = "",
            proxy._emptyDataColumns = [],
            proxy.secondaryDatasource = [];
            proxy._datasourceChildItems = [];
            proxy._$predecessorTable = null;
            proxy._mappingItems = [];
            proxy._editedDialogRecord = null;
            proxy._calculateDimensions();
            proxy._retrivedData = this.dataSource();
            if (scheduleMode == "week") {
                proxy._perDayWidth = 30;
            }
            else if (scheduleMode == "year") {
                proxy._perDayWidth = 3;
                proxy._perMonthWidth = 90;
            }
            else if (scheduleMode == "month") {
                proxy._perDayWidth = 10;
                proxy._perWeekWidth = 70;
            }
            else if (scheduleMode == "day") {
                proxy._perHourWidth = 20;
                if (model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale24Hours)
                    proxy._perDayWidth = (proxy._perHourWidth * 24);//24 hours
                else if (model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale8Hours)
                    proxy._perDayWidth = (proxy._perHourWidth * 24);//9 hours
            }
        },
        //calculate height and width for gantt at load time
        _calculateDimensions: function ()
        {
            var proxy = this,
                sizeSettingHeight = this.model.sizeSettings.height,
                sizeSettingsWidth = this.model.sizeSettings.width,
                elementStyleHeight = proxy.element[0].style.height,
                parentHeight=$(proxy.element).parent().height(),
                parentWidth=$(proxy.element).parent().width();
            proxy._ganttHeight = ej.isNullOrUndefined(sizeSettingHeight) ? (elementStyleHeight ? proxy.element.height() : "450px") : sizeSettingHeight,
            proxy._ganttWidth = ej.isNullOrUndefined(sizeSettingsWidth) ? proxy.element.width() : sizeSettingsWidth,
            proxy._ganttHeight = proxy._ganttHeight.toString().indexOf('%') !== -1 ? (parentHeight * parseInt(proxy._ganttHeight) / 100) :parseInt(proxy._ganttHeight),
            proxy._ganttWidth = proxy._ganttWidth.toString().indexOf('%') !== -1 ? (parentWidth * parseInt(proxy._ganttWidth) / 100) : parseInt(proxy._ganttWidth);
        },
        _setCultureInfo:function() {
             var proxy = this,
                model = proxy.model,
                culture = model.locale;

            model.dateFormat = !model.dateFormat ? ((ej.Gantt.localization[culture] && ej.Gantt.localization[culture]["calendars"] &&
                    ej.Gantt.localization[culture]["calendars"]["standard"]["patterns"]) ?
                (ej.Gantt.localization[culture]["calendars"]["standard"]["patterns"]["d"]) :
                Globalize.culture(culture) ? Globalize.culture(culture)["calendars"]["standard"]["patterns"]["d"] :
                    ej.Gantt.localization["en-US"]["calendars"]["standard"]["patterns"]["d"]) : model.dateFormat;

            
            //EmptyRecord text to be displayed with dataSource is null
            proxy._emptyRecordText = ej.Gantt.localization[culture] ?
                ej.Gantt.localization[culture]["emptyRecord"] :
                ej.Gantt.localization["en-US"]["emptyRecord"];
            
            //ColumnHeaderText to be displayed in treegrid
            proxy._columnHeaderTexts = ej.Gantt.localization[culture] ?
                ej.Gantt.localization[culture]["columnHeaderTexts"] :
                ej.Gantt.localization["en-US"]["columnHeaderTexts"];
            
            //EditDialog Text to be displayed in popup window
            proxy._editDialogTexts = ej.Gantt.localization[culture] ?
                ej.Gantt.localization[culture]["editDialogTexts"] :
                ej.Gantt.localization["en-US"]["editDialogTexts"];
            
            //Month names to be displayed in schedule
            proxy._months = (ej.Gantt.localization[culture] && ej.Gantt.localization[culture]["calendars"]) ?
                ej.Gantt.localization[culture]["calendars"]["standard"]["months"]["namesAbbr"] :
                Globalize.culture(culture) ? Globalize.culture(culture)["calendars"]["standard"]["months"]["namesAbbr"] :
                ej.Gantt.localization["en-US"]["calendars"]["standard"]["months"]["namesAbbr"];
            
            //Day names to displayed in schedule
            proxy._days = (ej.Gantt.localization[culture] && ej.Gantt.localization[culture]["calendars"]) ?
                ej.Gantt.localization[culture]["calendars"]["standard"]["months"]["namesAbbr"] :
                Globalize.culture(culture) ? Globalize.culture(culture)["calendars"]["standard"]["days"]["namesAbbr"] :
                ej.Gantt.localization["en-US"]["calendars"]["standard"]["days"]["namesAbbr"];

        },

        //Populate available fields
        _getMappingItems: function () {
            var proxy = this,
                model = proxy.model,
                mappingItems = [],
                length = proxy._columns.length;

            for (var i = 0; i < length; i++) {
                mappingItems.push(proxy._columns[i].mappingName);
            }
            return mappingItems;
        },

        //populate the context menu with items
        _getContextMenuItems: function () {
            var contextMenuItems = [];

            contextMenuItems = [{
                headerText: "Task Details...",
                eventHandler: null,
                isDefault:true,

            }, {
                headerText: "Add New Task",
                eventHandler: null,
                isDefault: true
            }
            , {
                headerText: "Indent",
                eventHandler: null,
                isDefault: true
            }, {
                headerText: "Outdent",
                eventHandler: null,
                isDefault: true
            }, {
                headerText: "Delete",
                eventHandler: null,
                isDefault: true
            }         
           ];
            return contextMenuItems;
        },

        //populate sub context menu items
        _getsubContextMenuItems: function () {
            var contextMenuItems = [];

            contextMenuItems = [{
                iconPath: null,
                headerText: "Above",
                eventHandler: null
            }, {
                iconPath: null,
                headerText: "Below",
                eventHandler: null
            }
            ];
            return contextMenuItems;
        },


        _initialize: function () {
            var proxy = this, model = proxy.model,
            startDate, endDate;

            proxy._$treegridPane = ej.buildTag('div.e-treegridPane');
            proxy._$ganttchartPane = ej.buildTag('div.e-ganttchartPane');
            proxy._$ejGantt = ej.buildTag('div.e-gantt-Spliter#e-ejSpliter' + proxy._id, "", {}, { 'unselectable': "on" });     

            proxy.setColumns(proxy.createTreeGridColumns());
            model.predecessorMapping && proxy._updatePredecessors();

            proxy._trigger("load");
            proxy._render();
            proxy._isTreeGridRendered = true;
            proxy._updatedGanttRecords = proxy.getUpdatedRecords();
            proxy._currentViewData = proxy.getCurrentViewData();
            proxy._enableCreateCollection = false;
            proxy._connectorLinesCollection = [];
            model.predecessorMapping && proxy._createConnectorLinesCollection("Load");//validation dones here 
            proxy._calculateScheduleDates();
            proxy._calculateHeaderDates();
            proxy._updateLeftValue();
            proxy._enableCreateCollection = true;//
            proxy._connectorLinesCollection = [];
            proxy._isValidationEnabled = false;          //no validation require here
            model.predecessorMapping && proxy._createConnectorLinesCollection();//connectorline oboject creates here
            proxy._isValidationEnabled = true;//reassign this value
           // proxy._$treegridHelper.ejTreeGrid("renderRecords");
            proxy._renderGanttChart();
            model.predecessorMapping && proxy._$ganttchartHelper && proxy._$ganttchartHelper.ejGanttChart("renderConnectorLines", proxy._connectorLinesCollection);
            proxy._isGanttChartRendered = true;
            proxy._gridRows = proxy.getRows();
            proxy._ganttChartRows = proxy.getGanttChartRows();
            proxy._createSubContextMenuTemplate();
            proxy._createContextMenuTemplate();
            proxy._wireEvents();
        },

        _render: function() {
            var proxy = this, element = proxy.element, model = proxy.model;
            if (proxy.model.toolbarSettings.showToolbar) {
                element.append(proxy._renderToolBar());
            }
            proxy._ganttHeight = parseInt(proxy._ganttHeight) - proxy._getToolBarHeight() - proxy._totalBorderHeight;
            proxy._$treegrid = ej.buildTag("div.ejTreeGrid#ejTreeGrid" + proxy._id, "", { "height": proxy._ganttHeight }, {});
            proxy._$ganttchart = ej.buildTag("div.ejGanttChart#ejGanttChart" + proxy._id, "", { "height": proxy._ganttHeight }, {});
            proxy._$ganttchartPane.append(proxy._$ganttchart);
            proxy._$treegridPane.append(proxy._$treegrid);
            proxy._$ejGantt.append(proxy._$treegridPane);
            proxy._$ejGantt.append(proxy._$ganttchartPane);    
            
            element.append(proxy._$ejGantt);
            proxy._renderGantt();
            proxy._renderTreeGrid();
            proxy._$treegridPane.css({ 'overflow': 'hidden' });
            if (model.editSettings.allowEditing || model.editSettings.editMode == "normal" || model.editSettings.editMode == "dialogTemplate") {
                proxy.editDialogTemplate();
                element.append(proxy._renderDialog());
            }
            if (model.editSettings.allowAdding) {
                proxy.addDialogTemplate();
                var $dialog = ej.buildTag("div.e-dialog e-dialog-content e-shadow e-widget-content", "", { display: "none" }, { id: this._id + "_dialogAdd" });
                element.append($dialog);
            }
        },

        _renderDialog: function () {
            var $dialog = ej.buildTag("div.e-dialog e-dialog-content e-shadow e-widget-content", "", { display: "none" }, { id: this._id + "_dialogEdit" });
            return $dialog;
        },

        editDialogTemplate: function () {

            var proxy = this,
                model = proxy.model,
                columns = proxy._columns,
                length = columns.length,
                emptyDataColumns = [], model = proxy.model,column,predecessorColoumnIndex;

            proxy._mappingItems = proxy._getMappingItems();

            if (length == 0)
                return;

            if (model.editDialogFields.length > 0) {
                var filteredColumns = [];
                var count=0,resultColumn;
                for(;count<model.editDialogFields.length;count++)
                {
                    resultColumn = $.grep(proxy._columns, function (val) {
                        return val.mappingName === model.editDialogFields[count].field;
                    });
                    resultColumn.length && filteredColumns.push(resultColumn[0]);
                } 
                columns = filteredColumns;
            }
           
            var $tbody = ej.buildTag('div', "", {}, { 'unselectable': 'on' });
            $form = ej.buildTag('form', "", { 'height': 'auto', 'width': 'auto', 'font-family': 'Segoe UI', 'font-size': '14px' }, { id: proxy._id + "EditForm" });
            $table = ej.buildTag('table', "", { width: "500px" }, { 'unselectable': "on" });
            $tr = ej.buildTag('tr');
            for (var i = 0; i < columns.length; i++) {
                if ($.inArray(columns[i].mappingName, proxy._mappingItems) != -1) {
                    if (columns[i].mappingName !== model.predecessorMapping)
                    {
                        if ($tr.children("td").length < 2) {
                            $td = ej.buildTag('td', "", { "text-align": "left", 'padding': '5px 15px 0', 'font-weight': 'normal', "outline": "none" }, { 'unselectable': "on" });
                            $innerTable = ej.buildTag('table', "", { "outline": "none" }, { 'unselectable': "on" });

                            $inTr = ej.buildTag('tr');

                            $inTd = ej.buildTag('td.editLabel', "", { "outline": "none" }, { 'unselectable': "on" });
                            $inTd.append("<label for='" + columns[i].field + "' style='font-weight:normal;'>" + proxy._columnHeaderTexts[columns[i].field] + "</label>");

                            $inTr.append($inTd);

                            $innerTable.append($inTr);

                            $inTr2 = ej.buildTag('tr');
                            $inTd2 = ej.buildTag('td.e-editValue');

                            //column = ej.TreeGrid.getColumnByField(proxy._columns, columns[i].field);
                            column = columns[i];
                            proxy.initCellEditType(column, $inTd2);

                            $inTr2.append($inTd2);
                            $innerTable.append($inTr2);

                            $td.append($innerTable);
                            $tr.append($td);

                            //if (i % 2 === 0 && proxy._columnHeaderTexts[columns[i].field] === "Resources") {
                            //    $td.attr("colspan", "2");
                            //    $table.append($tr);
                            //    $tr = $tempTr = ej.buildTag('tr');
                            //}
                        }
                        else {
                            $table.append($tr);
                            $tr = $tempTr = ej.buildTag('tr');
                            i--;
                        }
                    }else
                    {
                        predecessorColoumnIndex=i;
                    }
                }
            }
            $table.append($tr);
            //      $("body").append($table);
            $tr = ej.buildTag("tr");

            if (model.predecessorMapping && predecessorColoumnIndex) {

                $td = ej.buildTag('td', "", { "text-align": "left", 'padding': '10px 15px 0', 'font-weight': 'normal',"outline":"none" }, { colspan: 2, 'unselectable': "on" });

                $innerTable = ej.buildTag('table#predecessoreditTable', "", { "width": "100%", "outline": "none" }, { 'unselectable': "on" });

                $inTr = ej.buildTag('tr');
                $inTd = ej.buildTag('td.editLabel', "", {"outline":"none"}, { 'unselectable': "on" });
                
                $inTd.append("<span class='e-addpre e-icon e-enable e-edit-dialog' style='cursor:pointer'>Add New</span>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<span class='e-deletepre e-icon e-disable e-edit-dialog' style='cursor:pointer'>&nbsp;&nbsp;Remove</span>");

                $inTr.append($inTd);
                $innerTable.append($inTr);

                $inTr2 = ej.buildTag('tr');
                $inTd2 = ej.buildTag('td.e-editValue');

                $preDiv = ej.buildTag("div#treegrid" + proxy._id + "predecessoredit", "", { "width": "100%", "height": "150px" }, {});

                $inTd2.append($preDiv);
             
                $inTr2.append($inTd2);
                $innerTable.append($inTr2);

                $td.append($innerTable);
                $tr.append($td);
                $table.append($tr);
            }

            
            $form.append($table);
            $form.appendTo($tbody);
           
            $tbody = proxy.renderDiaglogButton($form, $tbody);
            $.templates(proxy._id + "_JSONDialogEditingTemplate", $tbody.html());
        },
        addDialogTemplate: function () {

            var proxy = this,
                model = proxy.model,
                columns = proxy._columns,
                length = columns.length,
                emptyDataColumns = [], model = proxy.model, column, predecessorColoumnIndex;

            proxy._mappingItems = proxy._getMappingItems();

            if (length == 0)
                return;

            if (model.addDialogFields.length > 0) {
                var filteredColumns = [];
                var count = 0, resultColumn;
                for (; count < model.addDialogFields.length; count++) {
                    resultColumn = $.grep(proxy._columns, function (val) {
                        return val.mappingName === model.addDialogFields[count].field;
                    });
                    resultColumn.length && filteredColumns.push(resultColumn[0]);
                }
                columns = filteredColumns;
            }

            var $tbody = ej.buildTag('div', "", {}, { 'unselectable': 'on' });
            $form = ej.buildTag('form', "", { 'height': 'auto', 'width': 'auto', 'font-family': 'Segoe UI', 'font-size': '14px' }, { id: proxy._id + "AddForm" });
            $table = ej.buildTag('table', "", { width: "500px" }, { 'unselectable': "on" });
            $tr = ej.buildTag('tr');
            for (var i = 0; i < columns.length; i++) {
                if ($.inArray(columns[i].mappingName, proxy._mappingItems) != -1) {
                    if (columns[i].mappingName !== model.predecessorMapping) {
                        if ($tr.children("td").length < 2) {
                            $td = ej.buildTag('td', "", { "text-align": "left", 'padding': '5px 15px 0', 'font-weight': 'normal', "outline": "none" }, { 'unselectable': "on" });
                            $innerTable = ej.buildTag('table', "", { "outline": "none" }, { 'unselectable': "on" });

                            $inTr = ej.buildTag('tr');

                            $inTd = ej.buildTag('td.editLabel', "", { "outline": "none" }, { 'unselectable': "on" });
                            $inTd.append("<label for='" + columns[i].field + "' style='font-weight:normal;'>" + proxy._columnHeaderTexts[columns[i].field] + "</label>");

                            $inTr.append($inTd);

                            $innerTable.append($inTr);

                            $inTr2 = ej.buildTag('tr');
                            $inTd2 = ej.buildTag('td.e-editValue');

                            column = columns[i];
                            proxy.initCellEditType(column, $inTd2,"Add");

                            $inTr2.append($inTd2);
                            $innerTable.append($inTr2);

                            $td.append($innerTable);
                            $tr.append($td);

                        }
                        else {
                            $table.append($tr);
                            $tr = $tempTr = ej.buildTag('tr');
                            i--;
                        }
                    } else {
                        predecessorColoumnIndex = i;
                    }
                }
            }
            $table.append($tr);

            $tr = ej.buildTag("tr");

            if (model.predecessorMapping && predecessorColoumnIndex) {

                $td = ej.buildTag('td', "", { "text-align": "left", 'padding': '10px 15px 0', 'font-weight': 'normal', "outline": "none" }, { colspan: 2, 'unselectable': "on" });

                $innerTable = ej.buildTag('table#predecessoreditTable', "", { "width": "100%", "outline": "none" }, { 'unselectable': "on" });

                $inTr = ej.buildTag('tr');
                $inTd = ej.buildTag('td.editLabel', "", { "outline": "none" }, { 'unselectable': "on" });

                $inTd.append("<span class='e-addpre e-icon e-enable e-add-dialog' style='cursor:pointer'>Add New</span>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<span class='e-deletepre e-icon e-disable e-add-dialog' style='cursor:pointer'>&nbsp;&nbsp;Remove</span>");

                $inTr.append($inTd);
                $innerTable.append($inTr);

                $inTr2 = ej.buildTag('tr');
                $inTd2 = ej.buildTag('td.e-editValue');

                $preDiv = ej.buildTag("div#treegrid" + proxy._id + "predecessorAdd", "", { "width": "100%", "height": "150px" }, {});

                $inTd2.append($preDiv);

                $inTr2.append($inTd2);
                $innerTable.append($inTr2);

                $td.append($innerTable);
                $tr.append($td);
                $table.append($tr);
            }


            $form.append($table);
            $form.appendTo($tbody);

            $tbody = proxy.renderDiaglogButton($form, $tbody);
            $.templates(proxy._id + "_JSONDialogAddingTemplate", $tbody.html());
        },
        _clearContextMenu: function () {
            //variables for context menu items
         
            $('.e-contextmenu').remove();
            $('.e-innerContextmenu').remove();
        },

        //JSRender Template for ContextMenu
        _createContextMenuTemplate: function () {
            var proxy = this;
            helpers = {
                getHeaderName: $.proxy(proxy._getHeaderName, proxy),
            };
            $.views.helpers(helpers);
            var menuItemList = "<li style='list-style-type:none;width:150px;height:25px;display:inline-block;'>";
            var listChild = "<div class='e-menuitem' id={{:headerText}}  style='left:0px;padding-top:3px;height:25px;width:150px;cursor:pointer;display:block;position:absolute;'  {{if !isDefault}}onClick='{{:eventHandler}}'{{/if}}>" +
                            "<div class='e-icon' style='left:10px;top:4px;height:20px;position:absolute;" +
                            "background-image:{{:iconPath}};background-repeat:no-repeat;'/>" +
                            "<div style='left:35px;position:absolute;'>" +
                            "<span style='font-family:Segoe UI;font-size:12px;padding-left:5px;'>{{:headerText}}</span></div>" +
                            "{{if ~getHeaderName(#data)}}<span class='e-icon e-expander' style='height:16px;width:16px;right:5px;top:7px;position:absolute;'></span>{{/if}}";

            menuItemList += listChild;
            menuItemList += "</div></li>";
            var templates = {};
            templates[proxy._id + "contextMenuTemplate"] = menuItemList;
            $.templates(templates);
        },

        //helper methods for context menu template
        _getHeaderName: function (data) {
            if (data.headerText == "Add New Task" && this._subContextMenuItems.length > 0) {
                return true;
            }
            return false;
        },

        //JSRender Template for Inner Context Menu
        _createSubContextMenuTemplate: function () {
            var proxy = this,
                helpers = {
                    getHeaderName: proxy._getHeaderName
                };
            $.views.helpers(helpers);

            var menuItemList = "<li style='list-style-type:none;width:120px;height:25px;display:inline-block;'>";
            var listChild = "<div class='e-menuitem' id={{:headerText}} style='left:0px;padding-top:3px;" +
                "height:25px;width:120px;cursor: pointer;display:block;position:absolute;'>" +
                "<div style='left:10px;height:20px;width:16px;position:absolute;padding-top:5px;" +
                "background-image:{{:iconPath}};background-repeat:no-repeat;'/>" +
               "<div style='left:10px;position:absolute;'>" +
                "<span style='font-family:Segoe UI;font-size:12px;padding-left:5px;'>{{:headerText}}" +
                "</span></div></div>";


            menuItemList += listChild;
            menuItemList += "</li>";

            var templates = {};
            templates[proxy._id + "subContextMenuTemplate"] = menuItemList;
            $.templates(templates);
        },

        initCellEditType: function (column, element,editTarget) {

            var proxy = this,
                model = proxy.model,
                id,    
                helpers = {};
            id = editTarget ? editTarget : "";
            if (ej.isNullOrUndefined(column["editType"]))
                column["editType"] = "stringedit";

            switch (column["editType"]) {
                case "stringedit":
                    if (column.mappingName === model.predecessorMapping) {
                        helpers["_" + proxy._id + "predecessor"] = proxy._getPredecessorsValue;
                        $.views.helpers(helpers);
                        element.html(ej.buildTag('input.e-field e-ejinputtext', "", {}, { value: "{{:~_" + proxy._id + "predecessor('" + proxy._id + "Object','" + model.predecessorMapping + "','" + column.field + "')}}", id: proxy._id + column.field, name: column.field }));
                    } else {
                        element.html(ej.buildTag('input.e-field e-ejinputtext', "", {}, { value: "{{:#data['" + column.field + "']}}", id: proxy._id + column.field + id, name: column.field, dialog: editTarget }));
                    }
                    break;
                case "booleanedit":
                    element.html('{{if ' + column.field + '}} <input class="e-field e-checkbox" type ="checkbox" id=' + proxy._id + column.field + ' name=' + column.field + ' checked="checked"></input>{{else}} <input class="e-field e-checkbox" type ="checkbox" id=' + proxy._id + column.field + ' name=' + column.field + ' > {{/if}}');
                    break;
                case "numericedit":
                    var $numericText = ej.buildTag('input.e-numerictextbox e-field', "", {}, { type: "text", value: "{{:#data['" + column.field + "']}}", id: proxy._id + column.field + id, name: column.field, dialog: editTarget });
                    element.append($numericText);
                    break;
                case "datepicker":
                case "datetimepicker":
                    var $datePicker = ej.buildTag('input.e-' + column["editType"] + ' e-field', "", {}, { type: "text", value: "{{:#data['" + column.field + "']}}", id: proxy._id + column.field + id, name: column.field, dialog: editTarget });
                    element.append($datePicker);
                    break;
                case "dropdownedit":
                    var $dropDownList = ej.buildTag('input.e-field e-dropdownlist' + ' e-field', "", {}, { type: "text", value: "{{:#data['" + column.field + "']}}", id: proxy._id + column.field + id, name: column.field, dialog: editTarget });
                    element.append($dropDownList);                    
                    break;
            }
        },


        _getPredecessorsValue: function (gridObject, mappingName) {
            return this.data.item ? this.data.item[mappingName] : "";
        },

        _updateEditFormData:function()
        {
            var proxy = this;
        },
        _onHoliDayCheckBefore: function (startDate) {
            var proxy = this,
                holidays = proxy.model.holidays,
                includeWeekend = proxy.model.includeWeekend;


            if (holidays && holidays.length) {
                var holidayIndex = 0,
                    holidayslength = holidays.length,
                    holiday, flag;
                    for (holidayIndex = 0; holidayIndex < holidayslength; holidayIndex++) {
                        holiday = proxy._getDateFromFormat(holidays[holidayIndex].day);
                        if (holiday.getTime() == startDate.getTime()) {
                            startDate.setDate(startDate.getDate() - 1);
                            if (this.model.includeWeekend === false) {
                                proxy._setBeforeWeekend(startDate);
                            }
                        }
                        else {
                            return startDate;
                        }
                    }
            }
            else {
                return startDate;
            }
        },
        _onHoliDayCheck: function (startDate)
        {
            var proxy = this,
                holidays = proxy.model.holidays,
                includeWeekend = proxy.model.includeWeekend;
                

            if (holidays && holidays.length) {
                var holidayIndex = 0,
                    holidayslength = holidays.length,
                    holiday, flag;
                do {
                    for (holidayIndex = 0; holidayIndex < holidayslength; holidayIndex++) {
                        holiday = proxy._getDateFromFormat(holidays[holidayIndex].day);
                        if (holiday.getTime()==startDate.getTime()) {
                            startDate.setDate(startDate.getDate() + 1);
                            if (this.model.includeWeekend === false) {
                                if (startDate.getDay() == 0) {
                                    startDate.setDate(startDate.getDate() + 1);
                                } else if (startDate.getDay() == 6) {
                                    startDate.setDate(startDate.getDate() + 2);
                                }
                            }
                        }
                        else
                        {
                            return startDate;
                        }
                    }
                }while(1);

            }
            else
            {
                return startDate;
            }
        },
        _editStartDateChange:function(element,args)
        {
            var proxy = this,
                id = proxy._id,
                model = proxy.model,
                targetId = element.attr("id"),
                holidays = this.model.holidays,
                dialog = element.attr("dialog"),
                selectedItem = this.selectedItem(),
                editedObj = this._editedDialogRecord,
                startDateId, endDateId, durationId;
               

                if (dialog === "Add")
                {
                    startDateId = "#" + id + "startDateAdd";
                    endDateId = "#" + id + "endDateAdd";
                    durationId = "#" + id + "durationAdd";
                }
                else
                {
                    startDateId = "#" + id + "startDate";
                    endDateId = "#" + id + "endDate";
                    durationId = "#" + id + "duration";
                }

                var startDate = $(startDateId).val();
                endDate = $(endDateId).val();
                duration = parseInt($(durationId).val());

                if (!startDate)
                {
                    startDate = editedObj?editedObj.startDate:undefined;
                }
                if (isNaN(duration)) {
                    duration = editedObj ? editedObj.duration : undefined;
                }
                if (!endDate) {
                    endDate = editedObj ? editedObj.endDate : undefined;
                }

                if ((targetId === id + "startDate") || (targetId === id + "startDateAdd"))
                { 
                    startDate = proxy._getDateFromFormat(args.value);
                    var tempEndDate = new Date();
                    stratDate=proxy._onHoliDayCheck(startDate);
                    //check start date is in week end days
                    if (this.model.includeWeekend === false) {
                        if (startDate.getDay() === 0) {
                            startDate.setDate(startDate.getDate() + 1);
                        }
                        else if (startDate.getDay() === 6) {
                            startDate.setDate(startDate.getDate() + 2);
                        }
                    }
                    tempEndDate = startDate;
                    startDate = Globalize.format(startDate, this.model.dateFormat);
                    //$("#" + id + "startDate").val(startDate);
                    if (editedObj)
                        editedObj.startDate = startDate;

                if (model.dateFormat.indexOf("hh")!=-1)
                    $(startDateId).ejDateTimePicker("option", "value", startDate);
                else
                    $(startDateId).ejDatePicker("option", "value", startDate);

                if (!endDate || isNaN(duration))
                    return;

                if (model.durationMapping) {

                    //check week end is inside the period

                    if (this.model.includeWeekend === false) {
                        for (count = 1; count < duration; count++) {
                            if (tempEndDate.getDay() == 0)
                                tempEndDate.setDate(tempEndDate.getDate() + 1);
                            else if (tempEndDate.getDay() == 6)
                                tempEndDate.setDate(tempEndDate.getDate() + 2);
                            tempEndDate.setDate(tempEndDate.getDate() + 1);
                        }
                    } else {
                        tempEndDate.setDate(tempEndDate.getDate() + duration - 1);
                    }

                    if (this.model.includeWeekend === false) {
                        if (tempEndDate.getDay() == 0)
                            tempEndDate.setDate(tempEndDate.getDate() + 1);
                        else if (tempEndDate.getDay() == 6)
                            tempEndDate.setDate(tempEndDate.getDate() + 2);
                    }

                    //holiday collection checking in end date
                    if (holidays && holidays.length) {
                        var holidayIndex = 0,
                            holidayslength = holidays.length,
                            holiday;
                        for (holidayIndex = 0; holidayIndex < holidayslength; holidayIndex++) {
                            holiday = new Date(holidays[holidayIndex].day);
                            if (holiday >= proxy._getDateFromFormat(new Date(startDate), this.model.dateFormat) && holiday <= tempEndDate) {
                                tempEndDate.setDate(tempEndDate.getDate() + 1);
                                if (this.model.includeWeekend === false) {
                                    if (tempEndDate.getDay() == 0) {
                                        tempEndDate.setDate(tempEndDate.getDate() + 1);
                                    } else if (tempEndDate.getDay() == 6) {
                                        tempEndDate.setDate(tempEndDate.getDate() + 2);
                                    }
                                }
                            }
                        }
                    }

                    if (this.model.includeWeekend === false) {
                        if (tempEndDate.getDay() == 0)
                            tempEndDate.setDate(tempEndDate.getDate() + 1);
                        else if (tempEndDate.getDay() == 6)
                            tempEndDate.setDate(tempEndDate.getDate() + 2);
                    }

                    tempEndDate = Globalize.format(tempEndDate, this.model.dateFormat);
                    //temp =this._calculateFormatedDate(temp, this.model.dateFormat);
                    if (editedObj)
                        editedObj.endDate = tempEndDate;

                    if (model.dateFormat.indexOf("hh") != -1)
                        $(endDateId).ejDateTimePicker("option", "value", new Date(tempEndDate));
                    else
                        $(endDateId).ejDatePicker("option", "value", new Date(tempEndDate));

                    //$("#" + id + "endDate").val(tempEndDate);
                    //$("#" + id + "endDate").attr("value", tempEndDate);
                }
                else {
                    var dateDiff = proxy._daydiff(proxy._getDateFromFormat(this.selectedItem().startDate), proxy._getDateFromFormat(editedObj.startDate));
                    editedObj.duration -= dateDiff;
                }
            }

            else if((targetId=== id + "endDate") ||(targetId===id + "endDateAdd"))
            {
                endDate = proxy._getDateFromFormat(args.value);

                endDate = proxy._onHoliDayCheck(endDate);
                if (this.model.includeWeekend === false) {
                    if (endDate.getDay() === 0) {
                        endDate.setDate(endDate.getDate() - 2);
                    }
                    else if (endDate.getDay() === 6) {
                        endDate.setDate(endDate.getDate() - 1);
                    }
                }
                endDate = Globalize.format(endDate, this.model.dateFormat);

                if (editedObj)
                    editedObj.endDate = endDate;

                if (model.dateFormat.indexOf("hh") != -1)
                    $(endDateId).ejDateTimePicker("option", "value", new Date(endDate));
                else
                    $(endDateId).ejDatePicker("option", "value", new Date(endDate));
             
                if (!startDate || isNaN(duration))
                    return;

                startDate = proxy._getDateFromFormat(startDate);
                endDate = proxy._getDateFromFormat(endDate);

                if (startDate.getTime() <= endDate.getTime())
                {
                        
                    var tempDuration = 0;
                    dateDiff = proxy._daydiff(proxy._getDateFromFormat(startDate), proxy._getDateFromFormat(endDate));

                    if (this.model.includeWeekend === false) {
                        offset = proxy._calculateDateDifference(new Date(startDate), dateDiff);
                        offset += 1;
                    }
                    else
                        offset = dateDiff + 1;

                    for (var count = 0; count < holidays.length; count++) {
                        if (new Date(holidays[count].day) >= new Date(startDate) && new Date(holidays[count].day) <= new Date(endDate)) {
                            offset--;
                        }
                    }
                    tempDuration = offset;
                    if (editedObj)
                        editedObj.duration = tempDuration;

                    $(durationId).ejNumericTextbox("option", "value", tempDuration);
                }
                else {
                    if (editedObj)
                        editedObj.endDate = args.prevDate;

                    if (model.dateFormat.indexOf("hh") != -1)
                        $(endDateId).ejDateTimePicker("option", "value", new Date(args.prevDate));
                    else
                        $(endDateId).ejDatePicker("option", "value", new Date(args.prevDate));

                }
            }
            else if ((targetId === id + "duration") || (targetId === id + "durationAdd"))
            {
                startDate = proxy._getDateFromFormat(startDate);
                var tempEndDate = new Date(startDate);

                if (!endDate || !startDate)
                    return;

                duration = args.value;

                //check week end is inside the period
                if (this.model.includeWeekend === false) {
                    for (count = 1; count < duration; count++) {
                        if (tempEndDate.getDay() == 0)
                            tempEndDate.setDate(tempEndDate.getDate() + 1);
                        else if (tempEndDate.getDay() == 6)
                            tempEndDate.setDate(tempEndDate.getDate() + 2);
                        tempEndDate.setDate(tempEndDate.getDate() + 1);
                    }
                } else {
                    tempEndDate.setDate(tempEndDate.getDate() + duration - 1);
                }

                if (this.model.includeWeekend === false) {
                    if (tempEndDate.getDay() == 0)
                        tempEndDate.setDate(tempEndDate.getDate() + 1);
                    else if (tempEndDate.getDay() == 6)
                        tempEndDate.setDate(tempEndDate.getDate() + 2);
                }
                //holiday collection checking in end date
                if (holidays && holidays.length) {
                    var holidayIndex = 0,
                        holidayslength = holidays.length,
                        holiday;
                    for (holidayIndex = 0; holidayIndex < holidayslength; holidayIndex++) {
                        holiday = new Date(holidays[holidayIndex].day);
                        if (holiday >= proxy._getDateFromFormat(startDate, this.model.dateFormat) && holiday <= tempEndDate) {
                            tempEndDate.setDate(tempEndDate.getDate() + 1);
                            if (this.model.includeWeekend === false) {
                                if (tempEndDate.getDay() == 0) {
                                    tempEndDate.setDate(tempEndDate.getDate() + 1);
                                } else if (tempEndDate.getDay() == 6) {
                                    tempEndDate.setDate(tempEndDate.getDate() + 2);
                                }
                            }
                        }
                    }
                }

                if (this.model.includeWeekend === false) {
                    if (tempEndDate.getDay() == 0)
                        tempEndDate.setDate(tempEndDate.getDate() + 1);
                    else if (tempEndDate.getDay() == 6)
                        tempEndDate.setDate(tempEndDate.getDate() + 2);
                }
                tempEndDate = Globalize.format(tempEndDate, this.model.dateFormat);

                if (editedObj) {
                    editedObj.endDate = tempEndDate;
                    editedObj.duration = duration;
                }
                if (model.dateFormat.indexOf("hh") != -1)
                    $(endDateId).ejDateTimePicker("option", "value", new Date(tempEndDate));
                else
                    $(endDateId).ejDatePicker("option", "value", new Date(tempEndDate));
            }
        },

        _taskNameCollection:function()
        {
            var proxy = this,
            records = proxy._updatedGanttRecords,
            names = [];
            for(var i=0;i<records.length;i++)
            {
               
                var temp = { id: records[i].taskId.toString(), text: (records[i].taskId.toString()+"-"+records[i].taskName), value: records[i].taskName };
                names.push(temp);
            }
            return names;
        }
        ,

        _idFromPredecessor:function(pre)
        {
            var str = "123FS+2";
            var preArray = pre.split(',');
            var preIdArray = [];
           

            for (var j = 0; j < preArray.length; j++)
            {
                var strArray = [];
                for (var i = 0; i < preArray[j].length; i++) {
                    if (!isNaN(preArray[j].charAt(i))) {
                        strArray.push(preArray[j].charAt(i));
                    }
                    else {
                        break;
                    }
                }
                preIdArray.push((strArray.join('')));
            }
            return preIdArray;
        },
        _preIdChangByName:function()
        {
            var proxy = this;
            var $form = $("#" + proxy._id + "PreEditForm");
            $targetTr = $form.closest("tr");
            $val = $form.find(".onEdit");
            var temp = $val.val();
            var names = proxy._taskNameCollection();

            var id = $.map(names, function (obj, index) {
                if (obj.text === $val.val()) {
                    return obj.id;
                }
            });
            id = id[0];
            $targetTr.find(".id").html(id);
        },
        _preBeginEdit:function(args)
        {
            if (args.columnIndex === 0)
                args.cancel = true;
        },
        _preEndEdit:function(editDialogId,args)
        {
            var proxy = this;
            if (args.columnName === "name")
            {
                var ds = args.model.dataSource;
                var names = proxy._taskNameCollection();
                var id = $.map(names, function (obj, index) {
                    if (obj.value === args.value) {
                        return obj.id;
                    }
                });
                id = id[0];
                args.model.selectedItem.id = id;
                
                var curent = args.model.dataSource.indexOf(args.model.selectedItem.item);

                if (curent === -1) {
                    args.model.dataSource.push(args.model.selectedItem.item);
                    curent = args.model.dataSource.indexOf(args.model.selectedItem.item);
                }
                args.model.dataSource[curent].id = id;
                if (!args.model.selectedItem.type) {
                    args.model.selectedItem.type = "Finish-Start";
                    args.model.dataSource[curent].type = "Finish-Start";
                }
                $(editDialogId).ejTreeGrid("refreshRow", args.model.selectedRowIndex);
                $(editDialogId).ejTreeGrid("selectRows", args.model.selectedRowIndex);

                proxy.enbleDisableAddPreButton('enable');
            }
        },
        _deleteDisableEnable:function(args)
        {
            var proxy = this;
            $(".e-deletepre").unbind("click", $.proxy(proxy._deletepredecessor, proxy));
            $(".e-deletepre").bind("click", $.proxy(proxy._deletepredecessor, proxy));
            $(".e-deletepre").removeClass("e-disable");
            $(".e-deletepre").addClass("e-enable");
        },
        _preDblClickHandler:function(e)
        {
            var proxy = this;
            $target = $(e.target);
            $sample = $("#" + proxy._id + "PreEditForm");
            //proxy._on(proxy.element, "click", ".e-tdprecontent", proxy._preClickHandler);
            // proxy._off(proxy.element, "dblclick", ".e-tdprecontent", proxy._preDblClickHandler);
            if ($sample.length === 0)
            {
                $form = ej.buildTag("form.#" + proxy._id + "PreEditForm", "", {}, {});
                $form.submit(function (event) { event.preventDefault()});
                var s = $target.attr("edittype");
                var field = $target.attr("field");
                var types = [{ id: "SS", text: "Start-Start", value: "Start-Start" }, { id: "SF", text: "Start-Finish", value: "Start-Finish" }, { id: "FS", text: "Finish-Start", value: "Finish-Start" }, { id: "FF", text: "Finish-Finish", value: "Finish-Finish" }];

                switch(field)
                {
                    case "taskName":
                        $attchelemet = ej.buildTag("input.e-field e-dropdownlist e-field onEdit", "", {}, { type: "text", id: proxy._id + 'taskNameEdit',value:e.target.innerHTML });
                        $form.append($attchelemet);
                        $target.empty().append($form);
                        $target.addClass("onEdit");
                        $attchelemet.ejDropDownList({
                            dataSource:proxy._taskNameCollection(),
                            width: "auto",
                            change: $.proxy(proxy._preIdChangByName, proxy),
                        });
                        $attchelemet.focus();
                        break;
                    case "type":
                        $attchelemet = ej.buildTag("input.e-field e-dropdownlist e-field onEdit", "", {}, { type: "text", id: proxy._id + 'TyepeEdit', value: e.target.innerHTML });
                        $form.append($attchelemet);
                        $target.empty().append($form);
                        $target.addClass("onEdit");
                        $attchelemet.ejDropDownList({
                            dataSource:types,
                            width: "auto"
                        });
                        $attchelemet.focus();
                        break;
                    case "offset":
                        $attchelemet = ej.buildTag('input.e-numerictextbox e-field onEdit', "", {}, { type: "text", id: proxy._id + 'OffsetEdit' });
                        var cellValue;
                        if (isNaN(parseInt(e.target.innerHTML))) {
                            cellValue = 0;
                        }
                        else
                            cellValue = parseInt(e.target.innerHTML);
                        $form.append($attchelemet);
                        $target.empty().append($form);
                        $target.addClass("onEdit");
                        $attchelemet.ejNumericTextbox({
                            width:"auto",                  
                            showSpinButton: true,
                            value: cellValue
                        });

                        $attchelemet.focus();
                        break;
                    case "id":
                        break;

                }
            }
        },
        _predecessorEditCollection:function(){
        
            var proxy = this,
               model = proxy.model;
            var gridId = "#" + proxy._id + "predecessor";
            var types = [{ id: "SS", text: "Start-Start", value: "Start-Start" }, { id: "SF", text: "Start-Finish", value: "Start-Finish" }, { id: "FS", text: "Finish-Start", value: "Finish-Start" }, { id: "FF", text: "Finish-Finish", value: "Finish-Finish" } ];
            var data = [];
            var selectedItem = model.selectedItem;
            var names = proxy._taskNameCollection();
            if (!ej.isNullOrUndefined(selectedItem) && !ej.isNullOrUndefined(selectedItem.predecessor) && !ej.isNullOrUndefined(selectedItem.item[model.predecessorMapping]))
            {
                var predecessor = selectedItem.predecessor;
                //var item = selectedItem.item;
                //var prede = proxy._idFromPredecessor(item.predecessor);

                for (var i = 0; i < predecessor.length; i++) {
                    var id = predecessor[i].from;

                    if (selectedItem.taskId.toString()!==id.toString())
                    {
                        var taskName, type, lags = 0;
                        for (var j = 0; j < names.length; j++) {
                            if (names[j].id === id) {
                                taskName = names[j].text;
                                break;
                            }
                        }
                        for (var k = 0; k < types.length; k++) {
                            if (types[k].id == predecessor[i].predecessorsType) {
                                type = types[k].text;
                            }
                        }
                        lags = predecessor[i].offset;
                        var obj = { id: id, name: taskName, type: type, offset: lags };
                        data.push(obj);
                    }
                }
            }
            return data;
        },
        _refreshEditForm: function (args) {
            var proxy = this,
                elementFocused = false,
                $formElement,
                percent = 86,
                i = 0, form, length,
                $element,
                inputWidth = "165px",
                model = proxy.model,
                width,
                params = {},
                value,
                column,
                customParams,
                toformat, newIdInstant,
                formatVal, editTreeGridId;
            selectedItem = model.selectedItem;
            
          
            if (args.requestType == "add") {
                form = document.getElementById(proxy._id + "AddForm");
                editTreeGridId = "#treegrid" + proxy._id + "predecessorAdd";
            }
            else {
                form = document.getElementById(proxy._id + "EditForm");
                editTreeGridId = "#treegrid" + proxy._id + "predecessoredit";
            }

            $formElement = $(form).find("input,select");
            length = $formElement.length;
            for (i; i < length; i++) {
                $element = $formElement.eq(i);
                //  inputWidth = proxy._tdsOffsetWidth[i] * (percent / 100);
                params = {};
                inputWidth = 210;
                if ($element.hasClass("e-numerictextbox")) {
               
                    width = inputWidth;
                    value = $element.val();
                    params.width = width;                    
                    params.showSpinButton = true;
                    params.cssClass = model.cssClass;
                    //for parent editing 
                    var tempId = $element[0].id;
                    tempId=tempId.replace(proxy._id, '');
                    if (selectedItem !== null && selectedItem.hasChildRecords && (tempId == "duration" || tempId == "status"))
                    {
                        params.readOnly = true;
                    }
                    if (tempId == "status") {
                        params.maxValue = 100;
                    }
                    else {
                        params.maxValue = 100000;
                        params.change = $.proxy(proxy._editStartDateChange, proxy, $element);
                    }
                    params.minValue = 0;
                    if (value.length)
                        params.value = parseFloat(value);
                    else
                        params.value = 0;
                    customParams = ej.TreeGrid.getColumnByField(proxy._columns, $element.prop("name"));
                    if (!ej.isNullOrUndefined(customParams["editParams"]))
                        $.extend(params, customParams["editParams"]);
                    $element.ejNumericTextbox(params);
                    $element.prop("name", $element.prop("name").replace(proxy._id, ""));
                }
                else if ($element.hasClass("e-datepicker")) {
                    width = inputWidth;
                    params.width = width;                    
                    params.cssClass = model.cssClass;
                    params.dateFormat = model.dateFormat;
                    params.locale = model.locale;
                    params.displayDefaultDate = true;
                    var tempId = $element[0].id;
                    tempId = tempId.replace(proxy._id, '');
                    if (selectedItem !== null && selectedItem.hasChildRecords && (tempId == "startDate" || tempId == "endDate") && args.requestType !== "add" ) {
                        params.readOnly = true;
                    }
                    params.select = $.proxy(proxy._editStartDateChange, proxy, $element);

                    if ($element.val().length)
                        params.value = proxy._getDateFromFormat($element.val());
                    else
                        params.value = proxy._getDateFromFormat(model.scheduleStartDate);

                    column = ej.TreeGrid.getColumnByField(proxy._columns, $element.prop("name"));
                    if (column["format"] !== undefined && column.format.length > 0) {
                        toformat = new RegExp("\\{0(:([^\\}]+))?\\}", "gm");
                        formatVal = toformat.exec(column.format);
                        params.dateFormat = formatVal[2];
                    }
                    if (!ej.isNullOrUndefined(column["editParams"]))
                        $.extend(params, column["editParams"]);

                    if (model.dateFormat.indexOf("hh") != -1)
                        $element.ejDateTimePicker(params);
                    else
                        $element.ejDatePicker(params);
                }
                else if ($element.hasClass("e-datetimepicker")) {
                    width = inputWidth;
                    params = {
                         width: width,
                        rtl: model.rtl,
                        locale:model.locale,
                        cssClass: model.css,
                        showButton: false
                    };
                    if ($element.val().length)
                        params.value = proxy._getDateFromFormat($element.val());
                    else
                        params.value = new Date();
                    column = ej.TreeGrid.getColumnByField(proxy._columns, $element.prop("name"));
                    if (column["format"] !== undefined && column.format.length > 0) {
                        toformat = new RegExp("\\{0(:([^\\}]+))?\\}", "gm");
                        formatVal = toformat.exec(column.format);
                        params.dateTimeFormat = formatVal[2];
                    }
                    if (!ej.isNullOrUndefined(column["editParams"]))
                        $.extend(params, column["editParams"]);

                    if (model.dateFormat.indexOf("hh") != -1)
                        $element.ejDateTimePicker(params);
                    else
                        $element.ejDatePicker(params);

                }
                else if ($element.hasClass("e-dropdownlist")) {
                    column = ej.TreeGrid.getColumnByField(proxy._columns, $element.prop("name"));
                    var dataSource = column.dropdownData;
                    var checkReadonly=false;
                    if (selectedItem !== null && selectedItem.hasChildRecords && args.requestType !== "add")
                    {
                        checkReadonly=true;
                    }

                    $element.ejDropDownList({
                        width:inputWidth,
                        showCheckbox: true,
                        dataSource: dataSource,
                        readOnly: checkReadonly,
                        fields: { id: model.resourceIdMapping, text: model.resourceNameMapping, value: model.resourceNameMapping },
                        selectedItems: proxy.getIndexofresourceInfo(dataSource,args.data)
                    });
                    $element.ejDropDownList("setSelectedValue", $element.val());
                } else {
                    switch ($element.prop('tagName')) {
                        case "INPUT":

                            if ($element.attr("type") != "checkbox") {
                                //For ID field id is read only

                                if ($element.attr("name") === "taskId") {
                                    if (args.requestType !== "add") {
                                        $element.attr("readonly", "readonly");
                                    }
                                    else if (args.requestType === "add") {
                                        newIdInstant = proxy._updatedGanttRecords.length;
                                        newIdInstant = proxy._getNewTaskIdFordialogEdit(newIdInstant);
                                        $element.val(newIdInstant);
                                    }
                                }
                                else if ($element.attr("name") === "taskName" && args.requestType === "add") {
                                    $element.val("New Task" + newIdInstant);
                                }

                                var tempId = $element[0].id;
                                tempId = tempId.replace(proxy._id, '');

                                $element.css("text-align", $element.attr("name") != null && ej.TreeGrid.getColumnByField(proxy._columns, $element.prop("name")) != null ?
                                    ej.TreeGrid.getColumnByField(proxy._columns, $element.attr("name")).textAlign : "center");
                                $element.outerWidth(inputWidth).height(25);
                            } else
                                $element.width("165px");//(inputWidth > 0 ? ($element.width() > inputWidth ? inputWidth : $element.width()) : 1);
                            break;

                        case "SELECT":
                            $element.width(inputWidth).height(23);
                            break;
                    }
                }
                if (!$element.is(":disabled") && !elementFocused && (!$element.is(":hidden") || typeof $element.data("ejDropDownList") == "object")) {
                    if (!proxy._isEnterKeyPressed) {
                        proxy._focusElements($element.closest('td'));
                        elementFocused = true;
                    }
                }
            }
           

            //render prdecessor table in edit dialog
            if (model.predecessorMapping && $(editTreeGridId).length) {
                var types = [{ id: "SS", text: "Start-Start", value: "Start-Start" }, { id: "SF", text: "Start-Finish", value: "Start-Finish" }, { id: "FS", text: "Finish-Start", value: "Finish-Start" }, { id: "FF", text: "Finish-Finish", value: "Finish-Finish" }];
                var ds = [];
                if (args.requestType !== "add")
                {
                    ds=proxy._predecessorEditCollection();
                }
                $(editTreeGridId).ejTreeGrid({
                    dataSource:ds,
                    allowSorting: false,
                    allowAdding: true,
                    columns: [{ headerText: "ID", field: "id", width: "50px",allowEditing:false },
                        { headerText: "TaskName", field: "name", editType: ej.TreeGrid.EditingType.Dropdown, dropdownData: proxy._taskNameCollection(), width: "170px" },
                        { headerText: "Type", field: "type", editType: ej.TreeGrid.EditingType.Dropdown, dropdownData: types, width: "80px" },
                        { headerText: "Offset", field: "offset", editType: ej.TreeGrid.EditingType.Numeric, width: "50px" }],
                    enableAltRow: true,
                    editSettings: {
                        allowAdding: true,
                        allowDeleting: true,
                        allowEditing: true,
                        editMode: "cellEditing",
                    },
                    endEdit: $.proxy(proxy._preEndEdit, proxy, editTreeGridId),
                    beginEdit: $.proxy(proxy._preBeginEdit, proxy),
                    rowSelected: $.proxy(proxy._deleteDisableEnable, proxy),
                    treeColumnIndex:5,
                });
                
                if (model.selectedItem && model.selectedItem.hasChildRecords && args.requestType!=="add")
                {
                    proxy.enbleDisableDeletePreButton('disable');
                    proxy.enbleDisableAddPreButton('disable');
                }
                else {
                    proxy.enbleDisableDeletePreButton('disable');
                    proxy.enbleDisableAddPreButton('enable');
                }
            }
        },

        enbleDisableDeletePreButton:function(args)
        {
            var proxy = this;
            if(args==="enable")
            {
                $(".e-deletepre").unbind("click", $.proxy(proxy._deletepredecessor, proxy));
                $(".e-deletepre").bind("click", $.proxy(proxy._deletepredecessor, proxy));
                $('.e-deletepre').addClass('e-enable');
                $('.e-deletepre').removeClass('e-disable');
            }
            else {
                $(".e-deletepre").unbind("click", $.proxy(proxy._deletepredecessor, proxy));
                $('.e-deletepre').addClass('e-disable');
                $('.e-deletepre').removeClass('e-enable');
            }
        },
        enbleDisableAddPreButton:function(args)
        {
            var proxy = this;
            if (args === "enable") {
               $(".e-addpre").unbind("click", $.proxy(proxy._addpredecessor, proxy));
               $(".e-addpre").bind("click", $.proxy(proxy._addpredecessor, proxy));
                $('.e-addpre').addClass('e-enable');
                $('.e-addpre').removeClass('e-disable');
            }
            else {
                $(".e-addpre").unbind("click", $.proxy(proxy._addpredecessor, proxy));
                $('.e-addpre').addClass('e-disable');
                $('.e-addpre').removeClass('e-enable');
            }
        },
        _disableAddButton: function (treeGridId) {
            var proxy = this;
            var table = $(treeGridId +"e-table");
            var flag = false;
            var len = table[0].rows.length;
            proxy.enbleDisableAddPreButton('disable');
            for (var j = 0; j < len; j++)
            {
                var currentRow = table[0].rows[j];
                if(currentRow.cells.length===4)
                if(currentRow.cells[1].innerText==="")
                {
                    flag = true;
                }
            }
            if (!flag) {
                proxy.enbleDisableAddPreButton('enable');
            }
        },
        _addpredecessor: function (e) {
            var proxy = this;
            var args = {},treeGridId;
            args["requestType"] = ej.TreeGrid.Actions.Save;
            args["_cAddedRecord"] = {item:{ id: "", name: "", type: "", offset: "" },hasChildRecords:false,level:0};
            proxy.enbleDisableAddPreButton('disable');
            if ($(e.target).hasClass("e-edit-dialog"))
                treeGridId="#treegrid" + proxy._id + "predecessoredit";
            else
                treeGridId = "#treegrid" + proxy._id + "predecessorAdd";

            var selectedIndex = $(treeGridId).ejTreeGrid("option", "selectedRowIndex");
            $(treeGridId).ejTreeGrid("clearSelection", selectedIndex);
            $(treeGridId).ejTreeGrid("processBindings", args);
            proxy.enbleDisableDeletePreButton("disable");
        },

        _deletepredecessor:function(e)
        {
            var proxy = this, treeGridId;

            if ($(e.target).hasClass("e-edit-dialog"))
                treeGridId = "#treegrid" + proxy._id + "predecessoredit";
            else
                treeGridId = "#treegrid" + proxy._id + "predecessorAdd";

            var selectedItem = $(treeGridId).ejTreeGrid("option", "selectedRowIndex");
            var args = {};
            args["requestType"] = ej.TreeGrid.Actions.Delete;
            if (selectedItem !== -1) {
                $(treeGridId).ejTreeGrid("deleteRow");
                proxy.enbleDisableDeletePreButton('disable');
            }
            proxy._disableAddButton(treeGridId);
        },


        getColumnIndexByField: function (field) {

            var proxy = this,
                columns = proxy.model.columns,
                length = columns.length,
                column = 0;

            for (column; column < length; column++) {

                if (columns[column]["field"] == field) break;

            }

            return column;
        },

        getIndexofresourceInfo: function (dataSource,data) {
            var resourceInfo = data.resourceInfo,
                count = 0, length = resourceInfo && resourceInfo.length, resourceIndex = [];

            for (count; count < length; count++)
                resourceIndex.push(dataSource.indexOf(resourceInfo[count]));

            return resourceIndex;

        },
        
        _focusElements: function ($currentCell) {
            if ($currentCell.length) {
                $currentCell.focus();
                var $childElem = $currentCell.children();
                if ($childElem[0].tagName.toLowerCase() == "select" || $childElem[0].tagName.toLowerCase() == "input") {
                    $childElem.focus().select();
                    $childElem[0].focus();
                }
                else if ($childElem.find(".e-field.e-dropdownlist").length)
                    $childElem.find(".e-ddl").focus();
                else
                    $childElem.find('input,select').select().focus();
            }
        },

        renderDiaglogButton: function (form, tbody) {

            var btnId,
                proxy = this,
                model = proxy.model;
            if (form[0].id === (proxy._id + "EditForm"))
                btnId = "EditDialog_";
            else
                btnId = "AddDialog_";

            var savebtn = ej.buildTag('input', "",
                 {
                     'border-radius':'3px'
                 },
                 { type: "button", id: btnId + proxy._id + "_Save" }),
             saveText = proxy._editDialogTexts["saveButton"];
            
            savebtn.ejButton(
                {
                    cssClass: model.cssClass,
                    text: saveText,
                    width: "70"
                });

            var cancelText = proxy._editDialogTexts["cancelButton"],
             cancelbtn = ej.buildTag('input', "",
                 {
                     'margin-left': '20px',
                     'border-radius': '3px'
                 },
                 {
                     type: "button",
                     id: btnId + proxy._id + "_Cancel"
                 });
            
            cancelbtn.ejButton(
                {
                    cssClass: model.cssClass,
                    text: cancelText,
                    width: "70"
                });

            //Sample delete button
            var delbtn = ej.buildTag('input', "",
                {
                    'margin-left': '20px',
                    'border-radius': '3px'
                },
                {
                    type: "button",
                    id: "EditDialog_" + proxy._id + "_Delete"
                });

            delbtn.ejButton(
                {
                    cssClass: model.cssClass,
                    text: "Delete",
                    width: "70"
                });



            var btnDiv = ej.buildTag('div', "", { 'margin-top': '20px','float':'right','margin-bottom':'15px' ,'margin-right':'15px'}, { 'class': "e-editform-btn" });

            btnDiv.append(savebtn);
            if(form[0].id===(proxy._id+"EditForm") && model.editSettings.allowDeleting)
                btnDiv.append(delbtn);
            btnDiv.append(cancelbtn);
            form.appendTo(tbody);
            btnDiv.appendTo(tbody);
            
            return tbody;
        },
        _toolbarItemLeave:function(args)
        {
            var i = 0;
        },
        _renderToolBar: function() {
            var proxy = this,
                model = proxy.model,
                $div = ej.buildTag("div.e-gantttoolbar#e-gantttoolbar" + proxy._id, "", { 'height': '50px'}, { id: proxy._id + "_toolbarItems"}),
                $ul = ej.buildTag("ul", "", { 'width': proxy._ganttWidth - proxy._totalBorderWidth }, {});
            (!ej.isNullOrUndefined(model.toolbarSettings.toolbarItems) && model.toolbarSettings.toolbarItems.length) && proxy._renderLi($ul);
            $div.append($ul);
            var $customUl = ej.buildTag("ul");
            $div.append($customUl);
            var helper = {};
            helper.click = proxy._toolBarClick;
            helper.cssClass = "";
            helper.rtl = false;
            helper.itemSeparator = false;
            helper.itemLeave = proxy._toolbarItemLeave
            helper.width = proxy._ganttWidth - proxy._totalBorderWidth;
            helper.fields = {
                id: "",
                tooltipText: "",
                imageUrl: "",
                text: "",
                imageAttributes: "",
                spriteCSS: "",
                htmlAttributes: "",
            };
            $div.ejToolbar(helper);
            $div.ejToolbar("disableItem", proxy._disabledToolItems);
            proxy._disabledToolItems = $();
            return $div;
        },

        _renderLi: function ($ul) {
            var proxy = this,
                toolBarItems = proxy.model.toolbarSettings.toolbarItems,
                length = toolBarItems.length,
                i = 0,
                $li;
            for (i; i < length; i++) {

                $li = ej.buildTag("li", "", {}, {
                    id: proxy._id + "_" + toolBarItems[i],                    
                    "tabindex": "0"
                });

                if (toolBarItems[i] !== "search")
                    $li.css({ 'width': '30px', 'height': '24px' });

                proxy._renderLiContent($li, toolBarItems[i]);
                $ul.append($li);
            }
        },

        _renderLiContent: function ($li, item) {
            var $a, $input;
            var selectedRowIndex = this.model.selectedRowIndex;
            var editSetting = this.model.editSettings;
            switch (item) {

                case "add":
                    $a = ej.buildTag("span.e-addnewitem e-toolbaricons e-icon e-gantt-add", "", {});
                    //title: toolBarItems[i],
                    $li.attr("title","Add");
                    if (!this.model.editSettings.allowAdding)
                        this._disabledToolItems.push($li.get(0));
                    break;

                case "edit":
                    $a = ej.buildTag("span.e-edititem e-toolbaricons e-icon e-gantt-edit", "", {});
                    $li.attr("title", "Edit");
                    if (!this.model.editSettings.allowEditing || selectedRowIndex == -1) {
                        this._disabledToolItems.push($li.get(0));
                    }
                    
                    break;

                case "delete":
                    $li.attr("title", "Delete");
                    $a = ej.buildTag("span.e-deleteitem e-toolbaricons e-icon e-gantt-delete", "", {});
                    
                    if (!this.model.editSettings.allowDeleting || selectedRowIndex == -1) {
                        this._disabledToolItems.push($li.get(0));
                    }
                    
                    break;

                case "update":
                    $li.attr("title", "Update");
                    $a = ej.buildTag("span.e-saveitem e-toolbaricons e-icon e-gantt-save e-disabletool", "", {});
                    this._disabledToolItems.push($li.get(0));
                    break;

                case "cancel":
                    $li.attr("title", "Cancel");
                    $a = ej.buildTag("span.e-cancel e-toolbaricons e-icon e-gantt-cancel e-disabletool", "", {});
                    this._disabledToolItems.push($li.get(0));
                    break;

                case "indent":
                    $li.attr("title", "Indent");
                    $input = ej.buildTag("span.e-indent e-toolbaricons e-icon e-disabletool e-gantt-indent", "", {}, {});
                    $li.append($input);
                    this._disabledToolItems.push($li.get(0));
                    break;

                case "outdent":
                    $li.attr("title", "Outdent");
                    $input = ej.buildTag("span.e-outdent e-toolbaricons e-icon e-disabletool e-gantt-outdent", "", {}, {});
                    $li.append($input);
                    this._disabledToolItems.push($li.get(0));
                    break;

                case "expandAll":
                    $li.attr("title", "ExpandAll");
                    $input = ej.buildTag("span.e-expandall e-toolbaricons e-icon e-gantt-expandall", "", {}, {});
                    $li.append($input);
                    break;

                case "collapseAll":
                    $li.attr("title", "CollapseAll");
                    $input = ej.buildTag("span.e-collapseall e-toolbaricons e-icon e-gantt-collapseall", "", {}, {});
                    $li.append($input); 
                    break;
                case "prevTimeSpan":
                    $li.attr("title", "Previous Timespan");
                    $input = ej.buildTag("span.e-prevtimespan e-toolbaricons e-icon e-gantt-prevtimespan", "", {}, {});
                    $li.append($input);
                    break;
                case "nextTimeSpan":
                    $li.attr("title", "Next Timespan");
                    $input = ej.buildTag("span.e-nexttimespan e-toolbaricons e-icon e-gantt-nexttimespan", "", {}, {});
                    $li.append($input);
                    break;
                case "search":
                    $input = ej.buildTag("input.e-ejinputtext", "", { 'margin': '4px','text-indent':'4px' }, { type: "text", placeholder: "Search" }, { 'color': "#E8E9E9" });
                    $li.css({ 'float': 'right', 'padding': '2px' });
                    $li.attr("title", "Search");
                    $li.addClass('e-search');
                    $li.append($input);
                    this.model.allowSearching = true;

                    $input.keydown($.proxy(this._keyDown, this));

                    break;
            }
            $li.append($a);
        },


        _keyDown: function (e) {

            if (e.which ===13) { //13 is key code for Enter Key 
                this._searchString = e.currentTarget.value;

                this._toolbarOperation(this._id + "_search", e.currentTarget.value);
				e.preventDefault();
				return false;//prevent post back
            }          
        },

        
        _updateToolbarOptions:function(searchString){

            var proxy = this,
                model = proxy.model,
                $addElement = $($('.e-addnewitem')[0]).parent(),
                $editElement = $($('.e-edititem')[0]).parent(),
                $deleteElement = $($('.e-deleteitem')[0]).parent(),
                $indentElement = $($('.e-indent')[0]).parent(),
                $outdentElement = $($('.e-outdent')[0]).parent();
                

            if (searchString.length) {

                var disabledItems = [];

                if (model.editSettings.allowAdding) {
                    $addElement && disabledItems.push($addElement.removeClass('e-disable')[0]);
                }

                if (model.editSettings.allowEditing) {
                    $editElement && disabledItems.push($editElement.removeClass('e-disable')[0]);
                }

                if (model.editSettings.allowDeleting) {
                    $deleteElement && disabledItems.push($deleteElement.removeClass('e-disable')[0]);
                }

                
                if ($indentElement && $indentElement.length)
                    $indentElement && disabledItems.push($indentElement.removeClass('e-disable')[0]);

                if ($outdentElement && $outdentElement.length)
                    $outdentElement && disabledItems.push($outdentElement.removeClass('e-disable')[0]);

                $('.e-gantttoolbar').ejToolbar('disableItem', disabledItems);

            } else {
                var enabledItems = [];

                if (model.editSettings.allowAdding) {
                    $addElement && enabledItems.push($addElement[0]);
                }

                if (model.selectedItem) {

                    if (model.editSettings.allowEditing) {
                        $editElement && enabledItems.push($editElement[0]);
                    }

                    if (model.editSettings.allowDeleting) {
                        $deleteElement && enabledItems.push($deleteElement[0]);
                    }

                    proxy.updateIndentOutdentOption(model.selectedItem);
                }

                $('.e-gantttoolbar').ejToolbar('enableItem', enabledItems);
            }
        },

        _renderGantt: function() {
            
            var proxy = this,                                                                                
                leftPaneSize,
                rightPaneSize,
                ganttWidth = parseInt(proxy._ganttWidth) - proxy._totalBorderWidth;

            //calculate treegrid pane size
            leftPaneSize = (2*proxy._commonColumnWidth+3) / ganttWidth * 100;
            leftPaneSize = leftPaneSize < 30 ? leftPaneSize : 30;

            //Here 7 is the splitter span width
            rightPaneSize = 100 - leftPaneSize - (7 / ganttWidth * 100);

            $("#e-ejSpliter" + proxy._id).ejSplitter({
                //border width and height excluded
                height: proxy._ganttHeight,
                width: proxy._ganttWidth - proxy._totalBorderWidth,
                orientation: ej.Orientation.Horizontal,
                properties: [{ paneSize: leftPaneSize + "%",collapsible:false }, { paneSize: rightPaneSize + "%",collapsible:false }],
                enableAutoResize: false,
                resize: $.proxy(proxy._onResize,proxy)
            });
        },

        _renderTreeGrid: function() {
            var proxy = this, model = proxy.model;
            proxy._$treegridHelper = $("#ejTreeGrid" + proxy._id).ejTreeGrid({
                enableAltRow: model.enableAltRow,
                allowColumnResize: model.allowColumnResize,
                enableVirtualization: model.enableVirtualization,
                allowSorting: model.allowSorting,
                allowMultiSorting: model.allowMultiSorting,
                sortSettings: model.sortSettings,
                allowSelection: model.allowSelection,
                selectionType:"single",
                selectedRowIndex: this.selectedRowIndex(),
                allowSearching: model.allowSearching,
                parentIdMapping:model.parentTaskIdMapping,
                allowKeyboardNavigation: model.allowKeyboardNavigation,
                cssClass: model.cssClass,
                locale: model.locale,
                editSettings: model.editSettings,
                toolbarSettings:model.toolbarSettings,
                rowTemplate: model.rowTemplate,
                rowDataBound: model.rowDataBound,
                queryCellInfo: model.queryCellInfo,
                dataSource:this.dataSource(),
                flatRecords: model.ganttRecords,
                parentRecords: model.parentRecords,
                records: proxy._rows,
                ids: proxy._ids,
                columns: proxy._columns,
                dateFormat: model.dateFormat,
                resourceInfoMapping: model.resourceInfoMapping,
                resourceNameMapping: model.resourceNameMapping,
                resourceIdMapping:model.resourceIdMapping,
                taskIdMapping: model.taskIdMapping,
                showGridCellTooltip: model.showGridCellTooltip,
                showGridExpandCellTooltip: model.showGridExpandCellTooltip,
                taskNameMapping: model.taskNameMapping,
                startDateMapping: model.startDateMapping,
                endDateMapping: model.endDateMapping,
                childMapping: model.childMapping,
                durationMapping: model.durationMapping,
                progressMapping: model.progressMapping,
                predecessorMapping: model.predecessorMapping,
                rowHeight: model.rowHeight,
                emptyRecordText: proxy._emptyRecordText,
                isFromGantt: proxy._isFromGantt,
                treeColumnIndex: model.treeColumnIndex,
                workingTimeScale:model.workingTimeScale,
            });
        },

        _renderGanttChart: function() {
            var proxy = this,
                model = this.model;
            proxy._$ganttchartHelper = $("#ejGanttChart" + proxy._id).ejGanttChart(
                {
                    dataSource: this.dataSource(),
                    scheduleStartDate: model.scheduleStartDate,
                    scheduleEndDate: model.scheduleEndDate,
                    startDateMapping: model.startDateMapping,
                    endDateMapping: model.endDateMapping,
                    progressMapping: model.progressMapping,
                    durationMapping: model.durationMapping,
                    childPropertyName: model.childMapping,
                    predecessorMapping: model.predecessorMapping,
                    enableVirtualization: model.enableVirtualization,
                    highlightWeekends: model.highlightWeekends,
                    milestoneMapping: model.milestoneMapping,
                    enableRowHover: model.enableRowHover,
                    perDayWidth: proxy._perDayWidth,
                    workingTimeScale: model.workingTimeScale,
                    roundOffDayworkingTime: model.roundOffDayworkingTime,
                    durationUnit: model.durationUnit,
                    
                    perMonthWidth: proxy._perMonthWidth,//new property for year - month schedule
                    perWeekWidth: proxy._perWeekWidth,//new property for week - month schedule
                    perHourWidth: proxy._perHourWidth,

                    includeWeekend: model.includeWeekend,
                    connectorlineWidth: model.connectorlineWidth,
                    scheduleHeaderSettings: model.scheduleHeaderSettings,
                    taskbarBackground: model.taskbarBackground,
                    progressbarBackground: model.progressbarBackground,
                    connectorLineBackground: model.connectorLineBackground,
                    parentTaskbarBackground: model.parentTaskbarBackground,
                    parentProgressbarBackground: model.parentProgressbarBackground,
                    holidays: model.holidays,
                    dateFormat: model.dateFormat,
                    locale: model.locale,
                    enableTaskbarTooltip: model.enableTaskbarTooltip,
                    enableTaskbarDragTooltip:model.enableTaskbarDragTooltip,
                    ganttRecords: model.ganttRecords,
                    parentRecords: model.parentRecords,
                    rows: proxy._rows,
                    scheduleWeeks: proxy._scheduleWeeks,

                    projectStartDate: proxy._projectStartDate, //new property instead of scheduleWeeks[0] and scheduleYears[0]
                    projectEndDate: proxy._projectEndDate,

                    scheduleYears: proxy._scheduleYears, //new property for year
                    scheduleMonths: proxy._scheduleMonths, //new property for month
                    scheduleDays:proxy._scheduleDays,
                    progressbarHeight: model.progressbarHeight,
                    tooltipTemplate: model.taskbarTooltipTemplate,
                    tooltipTemplateId: model.taskbarTooltipTemplateId,
                    progressbarTooltipTemplate: model.progressbarTooltipTemplate,
                    progressbarTooltipTemplateId: model.progressbarTooltipTemplateId,
                    queryTaskbarInfo: model.queryTaskbarInfo,
                    showTaskNames: model.showTaskNames,
                    showProgressStatus: model.showProgressStatus,
                    showResourceNames: model.showResourceNames,
                    resourceInfoMapping: model.resourceInfoMapping,
                    resourceNameMapping: model.resourceNameMapping,
                    enableProgressBarResizing: model.enableProgressBarResizing,
                    allowGanttChartEditing: model.allowGanttChartEditing,
                    taskbarEditingTooltipTemplateId: model.taskbarEditingTooltipTemplateId,
                    taskbarEditingTooltipTemplate:model.taskbarEditingTooltipTemplate,
                    _ids: proxy._ids,
                    stripLines: model.stripLines,
                    _predecessorCollection: proxy._predecessorsCollection,
                    weekendBackground: model.weekendBackground,
                    allowKeyboardNavigation: model.allowKeyboardNavigation,
                    updatedGanttRecords: proxy._updatedGanttRecords,
                    renderBaseline: model.renderBaseline,
                    baselineColor:model.baselineColor,
                    editSettings: model.editSettings,
                    columnHeaderTexts: proxy._columnHeaderTexts,
                    localizedDays: proxy._days,
                    localizedMonths:proxy._months,
                    rowHeight: model.rowHeight,
                    allowSelection:model.allowSelection
                });
        },

        createTreeGridColumns: function () {

            var proxy = this, model = proxy.model, column, columns = [];

            var mapping = (model.taskIdMapping)//?model.taskIdMapping:"Task Id";

            if (mapping.length) {
                column = {
                    field: "taskId",
                    headerText: proxy._columnHeaderTexts["taskId"],
                    width: 30,
                    editType: ej.Gantt.EditingType.String,
                    mappingName: mapping
                };

                columns.push(column);
                //proxy._emptyDataColumns.push(column.field);
            }

            mapping = model.taskNameMapping;// "Task Name";

            if (mapping.length) {
                column = {
                    field: "taskName",
                    headerText: proxy._columnHeaderTexts["taskName"],
                    width: 150,
                    editType: ej.Gantt.EditingType.String,
                    mappingName: mapping
                };

                columns.push(column);
                //proxy._emptyDataColumns.push(column.field);
            }

            mapping = model.startDateMapping;// "Start Date";

            if (mapping.length) {
                column = {
                    field: "startDate",
                    headerText:proxy._columnHeaderTexts["startDate"],
                    width: 150,
                    editType: ej.Gantt.EditingType.DatePicker,
                    mappingName: mapping
                };

                columns.push(column);
                //proxy._emptyDataColumns.push(column.field);
            }


            mapping = model.endDateMapping;// "End Date";

            if (mapping.length) {
                column = {
                    field: "endDate",
                    headerText: proxy._columnHeaderTexts["endDate"],
                    width: 150,
                    editType: ej.Gantt.EditingType.DatePicker,
                    mappingName:mapping
                };

                columns.push(column);
                //proxy._emptyDataColumns.push(column.field);
            }

            mapping = model.resourceInfoMapping;//"Resources";

            if (mapping.length) {
                column = {
                    field: "resourceInfo",
                    headerText:proxy._columnHeaderTexts["resourceInfo"],
                    width: 150,
                    editType: ej.Gantt.EditingType.Dropdown,
                    mappingName: mapping,
                    dropdownData: model.resources //model.resources is null
                };
                columns.push(column);
                //proxy._emptyDataColumns.push(column.field);
            }

            mapping = model.durationMapping;// "Duration";

            if (mapping.length) {
                column = {
                    field: "duration",
                    headerText: proxy._columnHeaderTexts["duration"],
                    width: 150,
                    editType: ej.Gantt.EditingType.Numeric,
                    mappingName:mapping
                };

                columns.push(column);
                //proxy._emptyDataColumns.push(column.field);
            }

            mapping = model.progressMapping;// "Progress";

            if (mapping.length) {
                column = {
                    field: "status",
                    headerText: proxy._columnHeaderTexts["status"],
                    width: 150,
                    editType: ej.Gantt.EditingType.Numeric,
                    mappingName:mapping
                };
                columns.push(column);
                //proxy._emptyDataColumns.push(column.field);
            }
            mapping = model.predecessorMapping;//)?model.predecessorMapping: "Predecessor";

            if (mapping.length) {
                column = {
                    field: "predecessor",
                    headerText:proxy._columnHeaderTexts["predecessor"],
                    width: 150,
                    editType: ej.Gantt.EditingType.String,
                    mappingName: mapping
                };
                columns.push(column);
                //proxy._emptyDataColumns.push(column.field);
            }
            
            //mapping = (model.baselineStartDateMapping )?model.baselineStartDateMapping: "Baseline StartDate";

            //if (mapping.length) {
            //    column = {
            //        field: "baselineStartDate",
            //        headerText: proxy._columnHeaderTexts["baselineStartDate"],
            //        width: 150,
            //        editType: ej.Gantt.EditingType.DatePicker,
            //        mappingName: mapping
            //    };
            //    columns.push(column);
            //    proxy._emptyDataColumns.push(column.field);
            //}
            //mapping = (model.baselineEndDateMapping)?model.baselineEndDateMapping: "Baseline EndDate";

            //if (mapping.length) {
            //    column = {
            //        field: "baselineEndDate",
            //        headerText:proxy._columnHeaderTexts["baselineEndDate"],
            //        width: 150,
            //        editType: ej.Gantt.EditingType.DatePicker,
            //        mappingName: mapping
            //    };
            //    columns.push(column);
            //    proxy._emptyDataColumns.push(column.field);
            //}
            return columns;
        },
        

        _createGanttRecords: function(data) {
            var proxy = this,
                model = proxy.model,
                ganttRecords = model.ganttRecords,
                length = data.length,
                count = 0,
                parentGanttRecord,
                parentRecords = model.parentRecords,
                enableSorting = model.allowSorting,
                enableAltRow = model.enableAltRow,
                rows = proxy._rows,
                ids = proxy._ids;


            for (count; count < length; count++) {
                parentGanttRecord = proxy._createGanttRecord(data[count], 0, null,undefined,"Load");
                proxy._storedIndex++;
                //if (enableAltRow)
                parentGanttRecord.isAltRow = proxy._storedIndex % 2 == 0 ? false : true;
                parentGanttRecord.index = proxy._storedIndex;
                rows[proxy._storedIndex] = parentGanttRecord;
                ids[proxy._storedIndex] = parentGanttRecord["taskId"].toString();
                ganttRecords.push(parentGanttRecord);
                //if (enableSorting)
                parentRecords.push(parentGanttRecord);
                parentGanttRecord.childRecords && proxy._addNestedGanttRecords(parentGanttRecord.childRecords);
            }

            for (var i = 0; i < ganttRecords.length; i++) {
                
                if (ganttRecords[i].isMilestone) {
                    if (ganttRecords[i].parentItem) {
                        ganttRecords[i].startDate = ganttRecords[i].parentItem.endDate;
                    } else {
                        ganttRecords[i].startDate = ganttRecords[i - 1].endDate;
                    }
                }

                if (ganttRecords[i].parentItem) {
                        proxy._updateParentItem(ganttRecords[i]);
                }
                
            }
        },
        
        //Update left value on scheduleDate changes
        _updateLeftValue:function()
        {
            var proxy = this, model = this.model, records = model.ganttRecords;
            $.each(records, function (index,ganttRecord ) {
                ganttRecord.left = ganttRecord._calculateLeft(proxy._projectStartDate, proxy._perDayWidth, proxy._holidaysList, model);
                if (model.renderBaseline && ganttRecord.baselineStartDate && ganttRecord.baselineEndDate) {
                    ganttRecord.baselineLeft = ganttRecord._calculateBaselineLeft(proxy._projectStartDate, proxy._perDayWidth, model.includeWeekend, model.dateFormat, model.endDateMapping, proxy._holidaysList);
                }
            });
        },
        //Calculate schedule dates from GanttRecord Collections
        _calculateScheduleDates:function(editArgs)
        {
            var proxy = this,
                minStartDate,
                maxEndDate,
                tempStartDate,
                tempEndDate,
                model = this.model,
                records = model.ganttRecords,
                updatedDates;
            if (((!model.scheduleEndDate || !model.scheduleStartDate) && records.length > 0)  || editArgs) {

                $.each(records, function (index, value) {
                        tempStartDate = proxy._getDateFromFormat(value.startDate);
                        tempEndDate = proxy._getDateFromFormat(value.endDate);
                        baseLineStartDate = value.baselineStartDate ? proxy._getDateFromFormat(value.baselineStartDate) : null;
                        baseLineEndDate = value.baselineEndDate ? proxy._getDateFromFormat(value.baselineEndDate) : null;
                        //minimum startDate
                        if (minStartDate) {
                            if (minStartDate.getTime() >= tempStartDate.getTime()) {
                                minStartDate = tempStartDate;
                            }
                            if (baseLineStartDate && model.renderBaseline && (minStartDate.getTime() >= baseLineStartDate.getTime())) {
                                minStartDate = baseLineStartDate;
                            }
                        } else {
                            if (baseLineStartDate && model.renderBaseline && tempStartDate.getTime() >= baseLineStartDate.getTime())
                                minStartDate = baseLineStartDate;
                            else
                                minStartDate = tempStartDate;
                        }
                        //Maximum endDate
                        if (maxEndDate) {
                            if (maxEndDate.getTime() <= tempEndDate.getTime()) {
                                maxEndDate = tempEndDate;
                            }
                            if (baseLineEndDate && model.renderBaseline && (maxEndDate.getTime() <= baseLineEndDate.getTime())) {
                                maxEndDate = baseLineEndDate;
                            }

                        } else {
                            if (baseLineEndDate && model.renderBaseline && tempEndDate.getTime() <= baseLineEndDate.getTime())
                                maxEndDate = baseLineEndDate;
                            else
                                maxEndDate = tempEndDate;
                        }
                });
                updatedDates = proxy._updateScheduleDatesByTaskLables(minStartDate, maxEndDate);
                minStartDate = updatedDates.minStartDate;
                maxEndDate = updatedDates.maxEndDate;
            }
            else if ((!model.scheduleEndDate || !model.scheduleStartDate) && records.length === 0) {
                minStartDate = proxy._getDateFromFormat(new Date());
                maxEndDate = proxy._getDateFromFormat(new Date(minStartDate));
                maxEndDate.setDate(maxEndDate.getDate() + 20);
            }
            if (!editArgs) {
                model.scheduleStartDate = minStartDate ? proxy.getFormatedDate(minStartDate) : model.scheduleStartDate;
                model.scheduleEndDate = maxEndDate ? proxy.getFormatedDate(maxEndDate) : model.scheduleEndDate;
            }
            else {
                editArgs.minStartDate = minStartDate;
                editArgs.maxEndDate = maxEndDate;
            }

        },

        //update schedule dates as per showTaskName and showResourceName values  and 
        //holidays collection and strip line collections at loadtime and edit time
        _updateScheduleDatesByTaskLables:function(startDate,endDate)
        {
            var proxy = this,
                model = this.model,
                scheduleEndDate,
                scheduleHeaderType = model.scheduleHeaderSettings.scheduleHeaderType,
                resourceStringWidth = proxy._getResourceStringWidth(),
                numOfDays, returnValues = {},
                scheduleEndDate = model.scheduleEndDate && this._getDateFromFormat(model.scheduleEndDate);
              
            if (scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Week) {
                //if (model.showTaskNames) {
                //    startDate.setDate(startDate.getDate() - 7);//one week before
                //}
                if (!model.scheduleEndDate || (scheduleEndDate.getTime() !== endDate.getTime()))
                {
                    numOfDays = resourceStringWidth > 0 ? (resourceStringWidth / proxy._perDayWidth)+7 : 7;//one week after
                    endDate.setDate(endDate.getDate() + numOfDays);
                }
            }
            if (scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Year) {
                //if (model.showTaskNames) {
                //    startDate.setMonth(startDate.getMonth() - 2);//2 month before
                //}
                if (!model.scheduleEndDate || (scheduleEndDate.getTime() !== endDate.getTime())) {
                    numOfDays = resourceStringWidth > 0 ? (resourceStringWidth / proxy._perMonthWidth) + 1 : 1;//1 month after
                    endDate.setMonth(endDate.getMonth() + numOfDays);
                }
            }
             

            if (scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Month) {
                //if (model.showTaskNames) {
                //    startDate.setDate(startDate.getDate() - 14);//two week before
                //}
                if (!model.scheduleEndDate || (scheduleEndDate.getTime() !== endDate.getTime())) {
                    numOfDays = resourceStringWidth > 0 ? (resourceStringWidth / proxy._perDayWidth) + 7 : 7;//one week after
                    endDate.setDate(endDate.getDate() + numOfDays);
                }
            }


            if (scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Day) {
                //if (model.showTaskNames) {
                //    startDate.setHours(startDate.getHours() - 8);//8hrs before
                //}
                if (!model.scheduleEndDate || (scheduleEndDate.getTime() !== endDate.getTime())) {
                    numOfDays = resourceStringWidth > 0 ? (resourceStringWidth / proxy._perHourWidth) + 7 : 7;//7hrs after
                    endDate.setHours(endDate.getHours() + numOfDays);
                }
            }


            //Check striplines are in range of schedule dates
            if (model.stripLines.length > 0) {
                $.each(model.stripLines, function (idx, value) {
                    var currentValue = proxy._getDateFromFormat(value.day)
                    if (!(currentValue.getTime() > startDate.getTime()) || !(currentValue.getTime() < endDate.getTime())) {
                        if (currentValue.getTime() < startDate.getTime())
                            startDate = currentValue;
                        else
                            endDate = currentValue;
                    }
                });
            }
            //Check holidays are in range of schedule dates
            if (proxy._holidaysList.length > 0) {
                $.each(proxy._holidaysList, function (idx, value) {
                    if (!(value.getTime() > startDate.getTime()) || !(value.getTime() < endDate.getTime())) {
                        if (value.getTime() < startDate.getTime())
                            startDate = value;
                        else
                            endDate = value;
                    }
                });
            }


            returnValues.minStartDate = startDate;
            returnValues.maxEndDate = endDate;
           
            return returnValues;

        },

        //Get reosurce collections width
        _getResourceStringWidth:function(){
            var proxy = this,
                model = this.model,
                resource = model.resources,
                totalString = "",width;
            if (resource.length > 0 && model.showResourceNames) {
                for (var count = 0; count < resource.length; count++) {
                    totalString += resource[count][model.resourceNameMapping] + " ,";
                }
                var $span = ej.buildTag("span", "", { "font-family": "Segoe UI", "font-size": "12px" }, {});
                $span.text(totalString);
                $(document.body).append($span);
                width = $span.width();
                $span.remove();
                return width;
            } else {
                return 0;
            }
        },

        //calculate project dates by schedule mode types
        _calculateHeaderDates: function () {

            var proxy = this,
                model=this.model,
                startDate = proxy._getDateFromFormat(model.scheduleStartDate),
                endDate = proxy._getDateFromFormat(model.scheduleEndDate);

            if (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Week)
                proxy._calculateWeekSplit(startDate, endDate);

            if (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Year) {
                proxy._calculateYearSplit(startDate, endDate);//method for year split
            }

            if (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Month)
                proxy._calculateMonthSplit(startDate, endDate);//method for Month split

            if (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Day)
                proxy._calculateDaySplit(startDate, endDate);
        },
        //AddNested Gantt Records
        _addNestedGanttRecords: function (data) {
            var proxy = this,
                rows = proxy._rows,
                ids = proxy._ids,
                model = proxy.model,
                ganttRecords = model.ganttRecords,
                count = 0,
                length = data.length,
                records = [],
                record,
                enableAltRow = model.enableAltRow;
            
            for (count; count < length; count++) {
                record = data[count];
                proxy._storedIndex++;
                //if (enableAltRow)
                record.isAltRow = proxy._storedIndex % 2 == 0 ? false : true;;
                record.index = proxy._storedIndex;
                rows[proxy._storedIndex] = record;
                ids[proxy._storedIndex] = record["taskId"].toString();
                ganttRecords.push(record);
                records = record.childRecords;
                if (records) {
                    var j = 0, recordlength = records.length, childGanttRecord = null;
                    for (j; j < recordlength; j++) {
                        childGanttRecord = records[j];
                        proxy._storedIndex++;
                        //if (enableAltRow)
                        childGanttRecord.isAltRow = proxy._storedIndex % 2 == 0 ? false : true;
                        childGanttRecord.index = proxy._storedIndex;
                        rows[proxy._storedIndex] = childGanttRecord;
                        ids[proxy._storedIndex] = childGanttRecord["taskId"].toString();
                        ganttRecords.push(childGanttRecord);
                        childGanttRecord.childRecords && proxy._addNestedGanttRecords(childGanttRecord.childRecords);
                    }
                }

            }
            
        },
        
        _createGanttRecord: function(data, level, parentItem, expanded,creatAt) {
            var proxy = this, ganttRecord, model = proxy.model, //column = proxy._emptyDataColumns,
                child = data[model.childMapping],
                startDate = data[model.startDateMapping],
                endDate = data[model.endDateMapping],
                duration = data[model.durationMapping] ? data[model.durationMapping] : 0,
                status =data[model.progressMapping]?data[model.progressMapping]:0,
                startDateType = proxy._getDateFromFormat(startDate),
                endDateType = proxy._getDateFromFormat(endDate),
                resourceInfo = data[model.resourceInfoMapping],
                predecessors = data[model.predecessorMapping],
                baselineStartDate = data[model.baselineStartDateMapping],
                baselineStartDateType = proxy._getDateFromFormat(baselineStartDate, model.dateFormat),
                baselineEndDate = data[model.baselineEndDateMapping],
                baselineEndDateType = proxy._getDateFromFormat(baselineEndDate, model.dateFormat);
            resourceName = [];
            predecessorscol = [];
            var sTime = startDateType ? new Date(startDateType.getFullYear(), startDateType.getMonth(), startDateType.getDate()).getTime() : null,
                eTime = endDateType ? new Date(endDateType.getFullYear(), endDateType.getMonth(), endDateType.getDate()).getTime() : null;

            ganttRecord = new ej.Gantt.GanttRecord();
            ganttRecord.taskId = data[model.taskIdMapping],
            ganttRecord.taskName = data[model.taskNameMapping],
            ganttRecord.startDate = proxy.getFormatedDate(startDateType),
            ganttRecord.endDate = proxy.getFormatedDate(endDateType),

            ganttRecord.taskbarBackground = null,
            ganttRecord.progressbarBackground = null,
            ganttRecord.parentProgressbarBackground = null,
            ganttRecord.parentTaskbarBackground = null,

            ganttRecord.cellBackgroundColor = null,
            ganttRecord.rowBackgroundColor = null,
            ganttRecord.treeMappingName = [],

            ganttRecord.baselineStartDate = proxy.getFormatedDate(baselineStartDateType),
            ganttRecord.baselineEndDate = proxy.getFormatedDate(baselineEndDateType),
            ganttRecord.duration = duration;
            if (endDateType && (ej.isNullOrUndefined(duration) || sTime != eTime)) {
                ganttRecord._calculateDuration(startDateType, endDateType, model.includeWeekend, model.holidays, data[model.milestoneMapping],model);
                duration = ganttRecord.duration;
            }
            ganttRecord.isMilestone = duration == 0 ? true : (data[model.milestoneMapping]) ? data[model.milestoneMapping] : false,
            ganttRecord.duration = (ganttRecord.isMilestone && duration != 0) ? 0 : duration,
            ganttRecord.status = status,
            ganttRecord.predecessor = predecessors && ganttRecord._calculatePredecessor(predecessors);

            if (ganttRecord.predecessor)
            {
                for (var i = 0; i < ganttRecord.predecessor.length; i++) {
                    predecessorscol[i] = ganttRecord.predecessor[i].from.toString() + ganttRecord.predecessor[i].predecessorsType.toString();                  //&& ganttRecord.predecessor[i].predecessorsType && ganttRecord.predecessor[i].to;                    
                }
                ganttRecord.predecessorsName = predecessorscol.join(' ');
            }
            ganttRecord.resourceInfo = resourceInfo && ganttRecord._setResourceInfo(data[(model.resourceInfoMapping)], model.resourceIdMapping, model.resourceNameMapping, model.resources);
          
            if (ganttRecord.resourceInfo) {
                for(var i=0;i<ganttRecord.resourceInfo.length;i++)
                    resourceName[i] = ganttRecord.resourceInfo[i].resourceName;
                ganttRecord.resourceNames = resourceName.join(' ');
            }
            ganttRecord.parentItem = parentItem;
            var tempData;
            if (model.parentTaskIdMapping && creatAt)
            {
                tempData = ej.DataManager(proxy._retrivedData).executeLocal(ej.Query().where(model.taskIdMapping,
                ej.FilterOperators.equal,
                ganttRecord.taskId));
                ganttRecord.item = tempData[0];
            }
            else
            {
                if (this.dataSource() instanceof ej.DataManager && this.dataSource().dataSource.json && this.dataSource().dataSource.offline && creatAt) {
                var tempData = ej.DataManager(proxy._retrivedData).executeLocal(ej.Query().where(model.taskIdMapping,
                ej.FilterOperators.equal,
                ganttRecord.taskId));
                if (tempData.length > 0) {
                    ganttRecord.item = tempData[0];
                } else {
                    ganttRecord.item = data;
                }
                }
                else {
                    ganttRecord.item = data;
                }
            }
            ganttRecord.isSelected = proxy.selectedItem() ? proxy.selectedItem()[(model.taskIdMapping) ? model.taskIdMapping : "Task Id"] == ganttRecord.taskId ? true : false : false,
            ganttRecord.level = level;
            if(!ganttRecord.endDate)
            {
                ganttRecord._calculateEndDate(model.includeWeekend, this._holidaysList, model, proxy._perDayWidth);
            }

            ganttRecord.width = ganttRecord._calculateWidth(proxy._perDayWidth, proxy._holidaysList,model),
            ganttRecord.width = ganttRecord.width == 0 ? 26 : ganttRecord.width,
            ganttRecord.progressWidth = ganttRecord._calculateProgressWidth(ganttRecord.width, status),
            ganttRecord.childRecords = child && proxy._createChildRecords(child, level + 1, ganttRecord),
            ganttRecord.hasChildRecords = child ? true : false,
            ganttRecord.expanded = expanded !== undefined ? expanded : child ? child.length > 0 : false;
            if (model.enableVirtualization === false)
            {
                ganttRecord.isExpanded=true;
            }

            if (!creatAt) {
                ganttRecord.left = ganttRecord._calculateLeft(proxy._projectStartDate,
                                   proxy._perDayWidth, proxy._holidaysList, model);
                if (model.renderBaseline && ganttRecord.baselineStartDate && ganttRecord.baselineEndDate)
                    ganttRecord.baselineLeft = ganttRecord._calculateBaselineLeft(proxy._projectStartDate, proxy._perDayWidth, model.includeWeekend, model.dateFormat, model.endDateMapping, proxy._holidaysList);
            }
            if (model.renderBaseline && ganttRecord.baselineStartDate && ganttRecord.baselineEndDate) {
                ganttRecord.baselineWidth = ganttRecord._calculateBaseLineWidth(proxy._perDayWidth, model);
            }
            else
                model.renderBaseline = false;
           

            if (predecessors)
                proxy._predecessorsCollection.push(ganttRecord);
            
            return ganttRecord;
        },
        
        _getHoliday: function () {
            if (this.model.holidays != null) {
                var holidayList = this.model.holidays,
                    holidays = [],
                    holidayLength = holidayList.length;
                if (holidayLength > 0) {
                    for (var i = 0; i < holidayLength; i++) {
                        holidays[i] = this.getDateType(holidayList[i].day);
                    }
                    return holidays;
                }
            }
            return false;
        },

        _getStringHolidays: function() {
            if (this._holidaysList != null && this._holidaysList.length > 0) {
                var holidayList = this._holidaysList,
                    holidays = [],
                    holidayLength = holidayList.length;
                if (holidayLength > 0) {
                    for (var i = 0; i < holidayLength; i++) {
                        holidays[i] = Globalize.format(holidayList[i], this.model.dateFormat);
                    }
                    return holidays;
                }
            }
            return false;
        },
        
        //create childRecords for particular GanttRecord
        _createChildRecords: function (data, level, parentItem) {
            var ganttRecords = [],
                proxy = this,
                i = 0,
                length = data.length;

            for (i = 0; i < length; i++) {
                if (data[i]) {
                    var parentRecord = proxy._createGanttRecord(data[i], level, parentItem,undefined,"Load");
                    ganttRecords.push(parentRecord);
                }
            }
            return ganttRecords;
        },

        _createResourceInfoCollection: function (data) {
            var proxy = this,
                count = 0,
                length = data.length;
            for (count; count < length; count++) {
                proxy._resourceInfoCollection.push(proxy._createResourceInfo(data[count]));
            }
        },

        _createResourceInfo: function (data) {
            var model = this.model, resourceInfo = {};
            resourceInfo.resourceId = data[model.resourceIdMapping];
            resourceInfo.resourceName = data[model.resourceNameMapping];
            return resourceInfo;
        },

        _calculateWeekSplit: function (startdate, enddate) {
            var proxy = this;
            var roundOffStartDate = startdate.getDay() == 0 ? (startdate.getDate()) - 7 :
                (startdate.getDate()) - startdate.getDay();
            startdate.setDate(roundOffStartDate);
            do {
                proxy._scheduleWeeks.push(new Date(startdate));
                startdate.setDate(startdate.getDate() + 7);
            } while (!(startdate > enddate));

            proxy._projectStartDate= new Date(proxy._scheduleWeeks[0]);
            proxy._projectEndDate = new Date(proxy._scheduleWeeks[proxy._scheduleWeeks.length - 1]);
        },

        //method for calculatting years (year-month schedule mode)
        _calculateYearSplit: function (startdate, enddate) {
            var proxy = this;
            startdate.setMonth(0);
            startdate.setDate(1);
            do {
                proxy._scheduleYears.push(new Date(startdate));
                startdate.setMonth(startdate.getMonth() + 12);
            } while (!(startdate >= enddate));

            var projectStartDate, projectEndDate;
            projectStartDate = new Date(proxy._scheduleYears[0].getFullYear(), 0, 1);
            projectEndDate = new Date(proxy._scheduleYears[proxy._scheduleYears.length - 1].getFullYear(), 11, 31);
            proxy._projectStartDate = projectStartDate;
            proxy._projectEndDate = projectEndDate;
        },

        //Method for calculating days (day-hour schedule mode)
        _calculateDaySplit: function (startdate, enddate) {
            var proxy = this;
            startdate.setHours(0);
            do {
                proxy._scheduleDays.push(new Date(startdate));
                startdate.setDate(startdate.getDate() + 1);
            } while ((startdate <= enddate));
            proxy._projectStartDate = new Date(proxy._scheduleDays[0]);
            proxy._projectEndDate = new Date(proxy._scheduleDays[proxy._scheduleDays.length - 1]);
        },

        //new method for calculatting months
        _calculateMonthSplit: function (startdate, enddate) {
            var proxy = this;
            dt = new Date(startdate.getFullYear(), startdate.getMonth() - 1, 1);
            startdate = dt;

            do {
                proxy._scheduleMonths.push(new Date(startdate));
                if (startdate.getMonth() == 0 || startdate.getMonth() == 2 || startdate.getMonth() == 4 || startdate.getMonth() == 6 || startdate.getMonth() == 7 || startdate.getMonth() == 9 || startdate.getMonth() == 11)
                    startdate.setDate(startdate.getDate() + 31);
                else if (startdate.getMonth() == 3 || startdate.getMonth() == 5 || startdate.getMonth() == 8 || startdate.getMonth() == 10)
                    startdate.setDate(startdate.getDate() + 30);
                else if (startdate.getMonth() == 1) {
                    if(startdate.getFullYear()%4==0)
                        startdate.setDate(startdate.getDate() + 29);
                    else
                        startdate.setDate(startdate.getDate() + 28);
                }
            } while (!(startdate >= enddate));

            var projectStartDate, projectEndDate;
            projectStartDate = new Date(proxy._scheduleMonths[0]);
            projectEndDate = new Date(proxy._scheduleMonths[proxy._scheduleMonths.length - 1]);
            projectEndDate = new Date(projectEndDate.getFullYear(), projectEndDate.getMonth() + 1, 0);
            proxy._projectStartDate = projectStartDate;
            proxy._projectEndDate = projectEndDate;
        },



        _updatePredecessors: function () {
            var proxy = this,
                count = 0,
                predecessorsCollection = proxy._predecessorsCollection,
                length = predecessorsCollection.length,
                ganttRecord,
                connectorsCollection,
            i = 0,
            successorGanttRecord,
            connectorCount;
            for (count; count < length; count++) {
                ganttRecord = predecessorsCollection[count];
                connectorsCollection = ganttRecord["predecessor"];
                connectorCount = connectorsCollection.length;
                for (i=0; i < connectorCount; i++) {
                    var connector = connectorsCollection[i];
                    successorGanttRecord = proxy.model.ganttRecords[proxy._ids.indexOf(connector.from)];
                    connector.to = ganttRecord['taskId'].toString();
                    if (successorGanttRecord) {
                        if (successorGanttRecord.predecessor) {
                            successorGanttRecord.predecessor.push(connector);
                        } else {
                            successorGanttRecord.predecessor = [];
                            successorGanttRecord.predecessor.push(connector);
                            predecessorsCollection.push(successorGanttRecord);
                        }
                    }

                }                
            }
        },
        
        getDateType: function (date) {
            if (date != null) {
                if (typeof (date) == "object") {
                    return date;
                }
                else {
                    var hyphenRegex = new RegExp("\\-", "g"),
                    dotRegex = new RegExp("\\.", "g");
                    date = date.replace(hyphenRegex, "/");
                    date = date.replace(dotRegex, "/");
                    return new Date(date);
                }
            }
            return null;
        },

        getFormatedDate: function(date) {
            return Globalize.format(date, this.model.dateFormat);
        },

        _getProgressWidth: function (parentwidth, percent) {
            return (parentwidth * percent) / 100;
        },

        
        _wireEvents: function () {
            var proxy = this,
                model=proxy.model,
                treeGrid = $("#ejTreeGrid" + proxy._id),
                ganttChart = $("#ejGanttChart" + proxy._id),
                gantt = proxy._$ejGantt;

            proxy._on(proxy.element, "click", proxy.clickHandler);
            proxy._on(proxy.element, "contextmenu", proxy._rightClick);
            if (model.enableResize) {
                proxy._on($(window), "resize", proxy.windowResize);
            }
            //proxy._on(proxy.element, "dblclick", ".e-tdprecontent", proxy._preDblClickHandler);
            //proxy._on(proxy.element, "click", ".e-tdprecontent", proxy._preClickHandler);
            treeGrid.ejTreeGrid({ rowSelecting: $.proxy(proxy.rowSelecting, proxy) });
            treeGrid.ejTreeGrid({ rowSelected: $.proxy(proxy.rowSelected, proxy) });
            //treeGrid.ejTreeGrid({ rowHover: $.proxy(proxy._treeGridRowHover, proxy) });
            treeGrid.ejTreeGrid({ actionBegin: $.proxy(proxy.actionBegin, proxy) });
            treeGrid.ejTreeGrid({ actionComplete: $.proxy(proxy.actionComplete, proxy) });

            if (model.queryCellInfo) {
                treeGrid.ejTreeGrid({ queryCellInfo: $.proxy(proxy._queryCellInfo, proxy) });
            }
            
            if (model.rowDataBound) {
                treeGrid.ejTreeGrid({ rowDataBound: $.proxy(proxy._rowDataBound, proxy) });
            }
            
            treeGrid.ejTreeGrid({ beginEdit: $.proxy(proxy._beginEdit, proxy) });
            treeGrid.ejTreeGrid({ endEdit: $.proxy(proxy._endEdit, proxy) });            
            
            treeGrid.ejTreeGrid({ expanding: $.proxy(proxy.expanding, proxy) });
            treeGrid.ejTreeGrid({ collapsing: $.proxy(proxy.collapsing, proxy) });
            treeGrid.ejTreeGrid({ expanded: $.proxy(proxy.expanded, proxy) });
            treeGrid.ejTreeGrid({ collapsed: $.proxy(proxy.collapsed, proxy) });
            treeGrid.ejTreeGrid({ refreshRow: $.proxy(proxy.refreshRow, proxy) });
            treeGrid.ejTreeGrid({ cancelEditCell: $.proxy(proxy.cancelEditCell, proxy) });
            
            
            ganttChart.ejGanttChart({ rowSelecting: $.proxy(proxy.rowSelecting, proxy) });
            ganttChart.ejGanttChart({ rowSelected: $.proxy(proxy.rowSelected, proxy) });
            ganttChart.ejGanttChart({ rowHover: $.proxy(proxy._ganttChartRowHover, proxy) });
            ganttChart.ejGanttChart({ actionBegin: $.proxy(proxy.actionBegin, proxy) });
            ganttChart.ejGanttChart({ actionComplete: $.proxy(proxy.chartactionComplete, proxy) });
            ganttChart.ejGanttChart({ refreshRow: $.proxy(proxy.refreshRowData, proxy) }); 
            ganttChart.ejGanttChart({ zooming: $.proxy(proxy.zoomingChart, proxy) });
            ganttChart.ejGanttChart({ queryTaskbarInfo: $.proxy(proxy.queryTaskbarInfo, proxy) });
            ganttChart.ejGanttChart({ expanding: $.proxy(proxy.expanding, proxy) });
            ganttChart.ejGanttChart({ collapsing: $.proxy(proxy.collapsing, proxy) });
            ganttChart.ejGanttChart({ expanded: $.proxy(proxy.expanded, proxy) });
            ganttChart.ejGanttChart({ collapsed: $.proxy(proxy.collapsed, proxy) });

            ganttChart.ejGanttChart({ taskbarEditing: $.proxy(proxy.taskbarEditing, proxy) });
            ganttChart.ejGanttChart({ taskbarEdited: $.proxy(proxy.taskbarEdited, proxy) });

            gantt.ejSplitter({ allowResizing: $.proxy(proxy._onResize, proxy) });
            
            proxy._enableEditingEvents();
        },
 

        _onResize:function(args){
            var proxy = this;
            
            proxy._$treegridHelper.ejTreeGrid("refreshScroller", args.prevPane.size);
            proxy._$ganttchartHelper.ejGanttChart("refreshScroller", args.nextPane.size);

        },

        clickHandler: function (e) {
            var proxy = this;
            var $target = $(e.target);

            //if ($target.closest(".e-popup").length == 0 &&
            //  $target.closest(".e-rowcell").find("#" + proxy._id + "EditForm").length == 0) {
                
            //}


            proxy._clearContextMenu();

            if (e.toElement) {
                e.toElement.tabIndex = 0;
                e.toElement.focus();
            }
            //Skip the scroll bar click in Gantt.
            if ($target.hasClass("e-vhandle") || $target.hasClass("e-vscrollbar") || $target.hasClass("e-vup") || $target.hasClass("e-vhandlespace") || $target.hasClass("e-vdown"))
                return;
            if ($target.hasClass("e-hhandle") || $target.hasClass("e-hscrollbar") || $target.hasClass("e-hup") || $target.hasClass("e-hdown") || $target.hasClass("e-hhandlespace"))
                return;
            if (proxy._isinBeginEdit) {

                if (!$target.closest('td').hasClass("e-editedcell") && !$target.hasClass('e-date') && !$target.hasClass('e-arrow') && !$target.hasClass('e-down-arrow') && $target.closest("form#ejTreeGrid" + proxy._id + "EditForm").length == 0) {
                    proxy._$treegridHelper.ejTreeGrid("cancelEditCell");
                    proxy._isinBeginEdit = false;
                }
                else if ($target.closest('td').hasClass("e-editedcell") && !$target.hasClass('e-date') && !$target.hasClass('e-arrow') && !$target.hasClass('e-down-arrow'))
                {
                    $target.focus();
                }
            }
        },

        windowResize: function (e) {
            var proxy = this,
                ejGanttSplit = ("#e-ejSpliter" + this._id),
                toolbar = ("#" + this._id + "_toolbarItems"),
                ganttchart = ("#ejGanttChart" + this._id),
                treegrid = ("#ejTreeGrid" + this._id),
                ganttbody = (".e-ganttviewerbodyContianer"),
                gantthead = (".e-ganttviewerheaderContainer"),
                treegridhelp = ("#ejTreeGrid" + this._id),
                treegridcontent = ("#ejTreeGrid" + this._id + "e-gridcontent"),
                sizeSettingsWidth = proxy.model.sizeSettings.width,
                sizeSettingsHeight = proxy.model.sizeSettings.height,
                elementStyleHeight = proxy.element[0].style.height,
                elementStyleWidth = proxy.element[0].style.width,
                width, height, maxScrollWidth;
            //Width calculation
            if ((sizeSettingsWidth && sizeSettingsWidth.indexOf("%") != -1) || elementStyleWidth.indexOf("%") != -1) {

                var ganttWidth = sizeSettingsWidth ? sizeSettingsWidth : elementStyleWidth;
                var containerWidth = $(proxy.element).parent().width() ? $(proxy.element).parent().width() : $(proxy.element).width();
                width = (containerWidth / 100) * parseInt(ganttWidth);
                
            }
            else
                width = $(proxy.element).width();
            //height calculation
            if ((sizeSettingsHeight && sizeSettingsHeight.indexOf("%") != -1 ) || elementStyleHeight.indexOf("%") != -1) {
                var ganttHeight = sizeSettingsHeight ? sizeSettingsHeight : elementStyleHeight;
                var containerHeight = $(proxy.element).parent().height() ? $(proxy.element).parent().height() : $(proxy.element).height();
                var tempHeight;
                if ($(proxy.element).parent().height())
                    tempHeight = (containerHeight / 100) * parseInt(ganttHeight);
                else
                    tempHeight = $(proxy.element).height();
                height = tempHeight;
            }
            else
                height = $(proxy.element).height();

            //Exclude bordor from width and height
            height = height - proxy._totalBorderHeight;
            width = width - proxy._totalBorderWidth;
            width = Math.round(width);

            var ganttWidth, treeGridWidth, top,left;
            $(ejGanttSplit).width(width);
            $(ejGanttSplit).height(height - $(toolbar).height());
            $(ejGanttSplit).ejSplitter("refresh");
            $(toolbar).width(width);
            $(toolbar).children(".e-ul:first-child").width(width);

            ganttWidth = $(ganttchart).width();
            treeGridWidth = $(treegrid).width();
            $(ganttchart).height(height - $(toolbar).height());

            top = $(ganttbody).ejScroller("option", "scrollTop");
            left = $(ganttbody).ejScroller("option", "scrollLeft");
            //set height for scroller div
            $(ganttbody).ejScroller({
                width: ganttWidth,
                height: (height - $(toolbar).height() - $(gantthead).height() - proxy._totalBorderHeight),
            });
            $(ganttbody).ejScroller("refresh");
            maxScrollWidth = proxy._$ganttchartHelper.ejGanttChart("getMaxScrollWidth");
            if (left > maxScrollWidth)
                left = maxScrollWidth > 0 ? maxScrollWidth : 0;

            $(ganttbody).ejScroller("option", "scrollTop", top);
            $(ganttbody).ejScroller("option", "scrollLeft", left);

            $(treegridhelp).height(height - $(toolbar).height());
            $(treegridcontent).height((height - $(toolbar).height() - $(gantthead).height() - proxy._totalBorderHeight));
            left = $(treegridcontent).ejScroller("option", "scrollLeft");
            $(treegridcontent).ejScroller({
                width: treeGridWidth,
            });
            $(treegridcontent).ejScroller("refresh");
            maxScrollWidth = proxy._$treegridHelper.ejTreeGrid("getMaxScrollWidth");
            if (left > maxScrollWidth)
                left = maxScrollWidth > 0 ? maxScrollWidth : 0;

            $(treegridcontent).ejScroller("option", "scrollLeft", left);

            proxy._$treegridHelper.ejTreeGrid("updateViewPortHeight");
            proxy._$ganttchartHelper.ejGanttChart("updateViewPortHeight");
            if(proxy.model.enableVirtualization)
            {
                proxy._$treegridHelper.ejTreeGrid("processBindings");
                var tempArgs = {};
                tempArgs.requestType = ej.TreeGrid.Actions.Refresh;
                proxy._$treegridHelper.ejTreeGrid("sendDataRenderingRequest", tempArgs);
                proxy._$ganttchartHelper.ejGanttChart("refreshHelper", proxy._currentViewData, proxy._updatedGanttRecords);
                proxy._$ganttchartHelper.ejGanttChart("onScrollHelper", top);
            }
        },

        
        // handler for mouse right click
        _rightClick: function (e) {
            var proxy = this,
                $target = $(e.target),
                div = $target[0].parentNode,
                $ganttGridRows,
                row,
                recordIndexr,
                item,selectIndex,
                args = {};
            proxy._$treegridHelper.ejTreeGrid("disableTooltip");
           
            if ($(div).hasClass("e-chartcell") || $(div).hasClass("e-ganttrowcell")) {
                $ganttGridRows = proxy._$ganttchartHelper.ejGanttChart("getGanttChartRows");
                args.target = "ejTreeGrid";
            } else {
                $ganttGridRows = $(proxy._$treegridHelper.ejTreeGrid("getRows"));
                args.target = "ejGanttChart";
            }
            row = $target.closest('tr');
            recordIndexr = $ganttGridRows.index(row);
            proxy._currentViewData = proxy.getCurrentViewData();
            item = proxy._currentViewData[recordIndexr];
            recordIndexr = proxy._updatedGanttRecords.indexOf(item);
            args.data = item;
            args.recordIndex = recordIndexr;

            if (item && proxy.model.enableContextMenu) {
                e.preventDefault();
                proxy._contextMenuItems = [];
                proxy._contextMenuItems = proxy._getContextMenuItems();
                proxy._subContextMenuItems = [];
                proxy._subContextMenuItems = proxy._getsubContextMenuItems();
                proxy._updateIndentOutdentContextmenuOption(recordIndexr, item);
                proxy._clearContextMenu();
                if (proxy._contextMenuItems.length > 0)
                    proxy._renderContextMenu(e, recordIndexr, item);

                proxy.rowSelected(args);
                proxy._$treegridHelper.ejTreeGrid("selectRows", recordIndexr);
                proxy._$ganttchartHelper.ejGanttChart("selectRows", recordIndexr);
            }
            else if (proxy.dataSource()==null || proxy.dataSource().length == 0) {
                proxy._contextMenuItems = [];
                proxy._subContextMenuItems = [];
                proxy._contextMenuItems = proxy._getContextMenuItems();
                proxy._updateIndentOutdentContextmenuOption(recordIndexr, item);
                proxy._clearContextMenu();
                if (proxy._contextMenuItems.length > 0)
                    proxy._renderContextMenu(e, recordIndexr, item);
            }
        },

        _updateIndentOutdentContextmenuOption: function (recordIndex, ganttRecord) {
            var proxy = this;
            if (recordIndex === 0) {;
                proxy._contextMenuItems.splice(2, 2);
            }
            else if(recordIndex>0){
                if (ganttRecord.level === 0) {
                    proxy._contextMenuItems.splice(3, 1);
                }
                else {
                    var previousGanttRecord = proxy._updatedGanttRecords[recordIndex - 1];
                    if (ganttRecord.level - previousGanttRecord.level === 1) {
                        proxy._contextMenuItems.splice(2, 1);
                    }
                    if(ganttRecord.isMilestone)
                        proxy._contextMenuItems.splice(3, 1);
                    if(previousGanttRecord.isMilestone)
                        proxy._contextMenuItems.splice(2, 1);
                }
            }
            else if (recordIndex < 0) {
                proxy._contextMenuItems.splice(0, 1);
                proxy._contextMenuItems.splice(1, 3);
            }

            var addIndex = -1, editIndex = -1, deleteIndex = -1;

            if (!model.editSettings.allowAdding) {
                $.each(proxy._contextMenuItems, function (idx, val) {
                    if (val.headerText === "Add New Task") {
                        addIndex = idx;
                    }
                });
                if(addIndex !== -1)
                    proxy._contextMenuItems.splice(addIndex, 1);
            }

            if (!model.editSettings.allowDeleting)
            {
                $.each(proxy._contextMenuItems, function (idx, val) {
                    if (val.headerText === "Delete") {
                        deleteIndex = idx;
                    }
                });
                if (deleteIndex !== -1)
                    proxy._contextMenuItems.splice(deleteIndex, 1);
            }

            if (!model.editSettings.allowEditing)
            {
                $.each(proxy._contextMenuItems, function (idx, val) {
                    if (val.headerText === "Task Details...") {
                        editIndex = idx;
                    }});
                proxy._contextMenuItems.splice(editIndex, 1);
            }

            if( proxy._searchString.length>0 && addIndex!==-1)
            {
                proxy._contextMenuItems.splice(addIndex, 1);
            }


        },
      
        queryTaskbarInfo: function (args) {        
            this._trigger("queryTaskbarInfo", args);
        },
        

        zoomingChart: function (args) {
            var proxy = this;
            proxy.reRenderChart(args.delta);
        },

        refreshRowData: function (args) {
            var proxy = this;
            proxy._$treegridHelper.ejTreeGrid("refreshRow", args.index);
        },

        expanding: function (args) {
            var proxy = this;           
            if (!proxy._trigger("expanding", args)) {
                if (proxy.model.enableVirtualization) {                    
                    ej.TreeGrid.sendExpandCollapseRequest(proxy, args);
                } else {
                    proxy._isInExpandCollapse = true;
                    
                    ej.TreeGrid.sendExpandCollapseRequest(proxy, args);
                    proxy._isInExpandCollapse = false;
                    var expandedCount = proxy._expandedRecordsCount;
                    proxy._$ganttchartHelper.ejGanttChart("reRenderGanttGridLinesTable", expandedCount);
                }
            }
        },

        collapsing: function (args) {
            var proxy = this;
            if (!proxy._trigger("collapsing", args)) {
                if (proxy.model.enableVirtualization) {                    
                    ej.TreeGrid.sendExpandCollapseRequest(proxy,args);
                } else {
                    proxy._gridRows = proxy.getRows();
                    proxy._isInExpandCollapse = true;
                    //proxy.sendExpandCollapseRequest(args);
                    ej.TreeGrid.sendExpandCollapseRequest(proxy, args);
                    proxy._isInExpandCollapse = false;
                    var collapsedCount = proxy._collapsedRecordCount;                       
                    proxy._$ganttchartHelper.ejGanttChart("reRenderGanttGridLinesTable", -collapsedCount);
                }
                var selectItem = proxy.selectedItem();
                if (!args.expanded && selectItem) {
                    var expanded = proxy.getExpandStatus(selectItem);
                    if (!expanded) {
                        proxy._deSelectRowItem();
                        if (proxy.model.toolbarSettings.showToolbar) {
                            if (proxy.model.toolbarSettings.toolbarItems.indexOf("delete") !== -1) {
                                $('.e-gantttoolbar').ejToolbar('disableItem', $($('.e-deleteitem')[0]).parent()[0]);
                                if (proxy.model.toolbarSettings.toolbarItems.indexOf("indent") !== -1)
                                    $('.e-gantttoolbar').ejToolbar('disableItem', $($('.e-indent')[0]).parent()[0]);
                                if (proxy.model.toolbarSettings.toolbarItems.indexOf("outdent") !== -1)
                                    $('.e-gantttoolbar').ejToolbar('disableItem', $($('.e-outdent')[0]).parent()[0]);
                                if (proxy.model.toolbarSettings.toolbarItems.indexOf("edit") !== -1)
                                    $('.e-gantttoolbar').ejToolbar('disableItem', $($('.e-edititem')[0]).parent()[0]);
                            }
                        }
                    }
                }
            }
        },

        expanded: function (args) {
            var proxy = this;            
            proxy._updatedGanttRecords = proxy.getUpdatedRecords();
            proxy._currentViewData = proxy.getCurrentViewData();
            if (proxy.model.enableVirtualization) {
                if (proxy.model.predecessorMapping) {
                    proxy._isValidationEnabled = false;
                    proxy._$ganttchartHelper.ejGanttChart("clearConnectorLines");
                    proxy._connectorlineIds = [];
                    proxy._connectorLinesCollection = [];
                    proxy._createConnectorLinesCollection();
                }
                proxy._$ganttchartHelper.ejGanttChart("refreshHelper", proxy._currentViewData, proxy._updatedGanttRecords);
            }
            proxy._trigger("expanded", args);
        },

        collapsed: function (args) {
            var proxy = this;
            proxy._updatedGanttRecords = proxy.getUpdatedRecords();
            proxy._currentViewData = proxy.getCurrentViewData();
            if (proxy.model.enableVirtualization) {
                if (proxy.model.predecessorMapping) {
                    proxy._isValidationEnabled = false;
                    proxy._connectorlineIds = [];
                    proxy._connectorLinesCollection = [];
                    proxy._$ganttchartHelper.ejGanttChart("clearConnectorLines");
                    proxy._createConnectorLinesCollection();
                }
                proxy._$ganttchartHelper.ejGanttChart("refreshHelper", proxy._currentViewData, proxy._updatedGanttRecords);
            }
            proxy._trigger("collapsed", args);
        },

        refreshRow: function (args) {
            var proxy = this;
            proxy._$ganttchartHelper.ejGanttChart("refreshRow", args.recordIndex);
        },

        _enableEditingEvents: function () {
            var proxy = this,
                model = proxy.model;

            if (model.editSettings.allowEditing|| model.editSettings.editMode == "dialogTemplate" ||
                (model.toolbarSettings.showToolbar && ((model.editSettings.allowAdding && model.toolbarSettings.toolbarItems.indexOf("add") !== -1) ||
                    (model.editSettings.allowEditing && model.toolbarSettings.toolbarItems.indexOf("index") !== -1)))) {
                
                proxy._on($("#" + proxy._id + "_dialogEdit"),
                    "click keypress", "#EditDialog_" + proxy._id + "_Save ,#EditDialog_" + proxy._id + "_Cancel,#EditDialog_" + proxy._id + "_Delete", proxy._buttonClick);

                proxy._on($("#" + proxy._id + "_dialogAdd"),
                   "click keypress", "#AddDialog_" + proxy._id + "_Save ,#AddDialog_" + proxy._id + "_Cancel", proxy._buttonClick);
                // $(proxy.element).on("click", ".e-icon", $.proxy(proxy._buttonClick, proxy));
            }
        },
        
        cancelEditCell: function () {

            var proxy = this;
            
            if (proxy.model.toolbarSettings.toolbarItems.indexOf("cancel") !== -1) {
                proxy._disabledToolItems.push($($('.e-cancel')[0]).parent()[0]);
            }

            if (proxy.model.toolbarSettings.toolbarItems.indexOf("save") !== -1) {
                proxy._disabledToolItems.push($($('.e-saveitem')[0]).parent()[0]);
            }

            $('.e-gantttoolbar').ejToolbar('disableItem', proxy._disabledToolItems);
        },

        _keyPressed: function (action, target, e) {
        },

        _buttonClick: function (e) {

            if (e.keyCode !== undefined && e.keyCode != 13)
                return true;
            
            var proxy = this,   
                model = proxy.model,
                args = {};
            
            if (model.editSettings.allowEditing || model.editSettings.editMode == "dialogTemplate" ||
                (model.toolbarSettings.showToolbar && ((model.editSettings.allowAdding && model.toolbarSettings.toolbarItems.indexOf("add") !== -1) ||
                    (model.editSettings.allowEditing && model.toolbarSettings.toolbarItems.indexOf("index") !== -1)))) {

                if (e.target.id == "EditDialog_" + proxy._id + "_Save") {
                    if (!proxy._sendSaveRequest("Edit"))
                        $("#" + proxy._id + "_dialogEdit").ejDialog("close");
                } else if (e.target.id == "EditDialog_" + proxy._id + "_Cancel") {
                    $("#" + proxy._id + "_dialogEdit").ejDialog("close");
                }
                    //For delete option in editing dialog window
                else if (e.target.id == "EditDialog_" + proxy._id + "_Delete") {

                    proxy._$treegridHelper.ejTreeGrid("deleteRow");
                    $("#" + proxy._id + "_dialogEdit").ejDialog("close");
                }
                else if (e.target.id == "AddDialog_" + proxy._id + "_Save") {
                    if (!proxy._sendSaveRequest("Add"))
                        if (!this._duplicate&&!this._wrongenddate) {
                            $("#" + proxy._id + "_dialogAdd").ejDialog("close");                            
                        }
                }
                else if (e.target.id == "AddDialog_" + proxy._id + "_Cancel") {
                  //  proxy._ids.splice(proxy._ids.length - 1, 1);
                    $("#" + proxy._id + "_dialogAdd").ejDialog("close");
                }
            }
            else {
                proxy._sendCancelRequest();
            }

            return false;
        },

        rowSelecting: function (args) {
            var proxy = this;
            if (proxy.model.rowSelecting) {
                if (proxy._trigger("rowSelecting", args))
                    return true;
            }
            return true;
        },

        rowSelected:function(args){
            var proxy = this;
            if (args.target == "ejTreeGrid")
                proxy._$ganttchartHelper.ejGanttChart("selectRows", args.recordIndex);
            if (args.target == "ejGanttChart")
                proxy._$treegridHelper.ejTreeGrid("selectRows", args.recordIndex);
            var idx = args.recordIndex;
            this.selectedItem(args.data);
            this.selectedRowIndex(idx);
            if (proxy.model.toolbarSettings.showToolbar) {

                if (proxy.model.toolbarSettings.toolbarItems.indexOf("indent") !== -1 || proxy.model.toolbarSettings.toolbarItems.indexOf("outdent") !== -1) {

                    proxy.updateIndentOutdentOption(args.data);
                }

                var enableItems = [];

                if (proxy.model.editSettings.allowDeleting) {
                    if (proxy.model.toolbarSettings.toolbarItems.indexOf("delete") !== -1)
                        enableItems.push($($('.e-deleteitem')[0]).parent()[0]);
                }
                if (proxy.model.editSettings.allowAdding) {
                    if (proxy.model.toolbarSettings.toolbarItems.indexOf("add") !== -1)
                        enableItems.push($($('.e-addnewitem')[0]).parent()[0]);
                }
                if (proxy.model.editSettings.allowEditing) {
                    if (proxy.model.toolbarSettings.toolbarItems.indexOf("edit") !== -1)
                        enableItems.push($($('.e-edititem')[0]).parent()[0]);
                }

                $('.e-gantttoolbar').ejToolbar('enableItem', enableItems);
            }

            if (proxy.model.rowSelected)
                proxy._trigger("rowSelected", args);           
        },

        _treeGridRowHover: function (args) {
            var proxy = this;
            if (args.reason == "mouseenter")
                proxy._$ganttchartHelper.ejGanttChart("addRowHover", args.index);
            else if (args.reason == "mouseleave")
                proxy._$ganttchartHelper.ejGanttChart("removeRowHover");
        },

        updateIndentOutdentOption: function (ganttRecord) {
            var proxy = this;
            proxy._updatedGanttRecords = proxy.getUpdatedRecords();
            var recordIndex = proxy._updatedGanttRecords.indexOf(ganttRecord),
                previousGanttRecord;

            var indentIconElement =  $($('.e-indent')[0]).parent()[0],
                outentIconElement = $($('.e-outdent')[0]).parent()[0],
                disabledItems = [];

            if (recordIndex === 0) {
                if (indentIconElement)
                    $('.e-gantttoolbar').ejToolbar('disableItem', indentIconElement);

                if (outentIconElement)
                    $('.e-gantttoolbar').ejToolbar('disableItem', outentIconElement);
                
                $('.e-gantttoolbar').ejToolbar('disableItem', disabledItems);
            }
            else {
                if (ganttRecord.level === 0) {
                    if (indentIconElement)
                        $('.e-gantttoolbar').ejToolbar('enableItem', indentIconElement);
                    if (outentIconElement)
                        $('.e-gantttoolbar').ejToolbar('disableItem', outentIconElement);
                }
                else {
                    previousGanttRecord = proxy._updatedGanttRecords[recordIndex - 1];
                    if (ganttRecord.level - previousGanttRecord.level === 1) {
                        if (outentIconElement)
                            $('.e-gantttoolbar').ejToolbar('enableItem', outentIconElement);
                        if (indentIconElement)
                            $('.e-gantttoolbar').ejToolbar('disableItem', indentIconElement);
                    }
                    else {
                        if (indentIconElement)
                            $('.e-gantttoolbar').ejToolbar('enableItem', indentIconElement);
                        if (outentIconElement)
                            $('.e-gantttoolbar').ejToolbar('enableItem', outentIconElement);
                    }
                    
                }
            }
        },

        _ganttChartRowHover: function (args) {
            var proxy = this;
            if (args.reason == "mouseenter")
                proxy._$treegridHelper.ejTreeGrid("addRowHover", args.index);
            else if (args.reason == "mouseleave")
                proxy._$treegridHelper.ejTreeGrid("removeRowHover");
        },
        _removeChildRecordsPredecessor:function(record)
        {
            var proxy = this;
            if (record.hasChildRecords) {
                var length = record.childRecords.length, index = 0;
                for (index; index < length; index++) {
                    record.childRecords[index].predecessor && proxy._removePredecessor(record.childRecords[index].predecessor, record.childRecords[index]);
                    if(record.childRecords[index].hasChildRecords)
                    {
                        proxy._removeChildRecordsPredecessor(record.childRecords[index]);
                    }
                }
            }
        },
        getExpandedRecordCount: function (record, count)
        {
            var currentRecord, proxy = this;
            if (!record.hasChildRecords)
                return 0;
            for (var i = 0; i < record.childRecords.length; i++) {
                currentRecord = record.childRecords[i];
                if (proxy.getExpandStatus(currentRecord))
                    count++;
                
                if (currentRecord.hasChildRecords) {
                    count = proxy.getExpandedRecordCount(currentRecord, count);
                }
            }
            return count;
        },

        _updateExpandStatus:function()
        {
            var proxy = this,
                records = proxy._rows,
            length = records.length, oldValue;
            //proxy._totalCollapseRecordCount = 0;
            for (var i = 0; i < length; i++) {
                oldValue = records[i].isExpanded;
                if (proxy.getExpandStatus(records[i]) !== records[i].isExpanded) {
                    records[i].isExpanded = proxy.getExpandStatus(records[i]);
                    if (records[i].isExpanded) {
                        proxy._totalCollapseRecordCount--;
                    }
                    else {
                        proxy._totalCollapseRecordCount++;
                    }
                }
            }
        },
        actionComplete: function (args) {
            var proxy = this,model = proxy.model;
            proxy._updatedGanttRecords = proxy.getUpdatedRecords();
            proxy._currentViewData = proxy.getCurrentViewData();
            proxy._gridRows = proxy.getRows();
            proxy._ganttChartRows = proxy.getGanttChartRows();
            if (args.requestType === "searching" || args.requestType === "sorting") {
                proxy._$ganttchartHelper.ejGanttChart("clearConnectorLines");
               
                var visibleRecordCount = proxy._$ganttchartHelper.ejGanttChart("getVisibleRecordsCount");
                if (!model.enableVirtualization)
                {
                    proxy._updateExpandStatus();
                    var filteredCollapseCount = 0;
                    filteredCollapseCount = proxy._currentViewData.filter(function (record) {
                        return (proxy.getExpandStatus(record) === false);
                    });
                    if (args.requestType === "searching" || proxy._searchString)
                    {
                        
                        proxy._$ganttchartHelper.ejGanttChart("refreshHelper", proxy._currentViewData, proxy._updatedGanttRecords, filteredCollapseCount.length);
                        proxy._$ganttchartHelper.ejGanttChart("refrehGridLinesTable", (proxy._currentViewData.length - filteredCollapseCount.length));
                    }
                    else
                    {
                        proxy._$ganttchartHelper.ejGanttChart("refreshHelper", proxy._currentViewData, proxy._updatedGanttRecords, filteredCollapseCount.length);
                        proxy._$ganttchartHelper.ejGanttChart("refrehGridLinesTable", (proxy._currentViewData.length - proxy._totalCollapseRecordCount));
                    }
                    proxy._$treegridHelper.ejTreeGrid("updateHeight", (proxy._updatedGanttRecords.length - filteredCollapseCount.length) * proxy.model.rowHeight);
                    proxy._$ganttchart.ejGanttChart("setCollapsedRecordCount", filteredCollapseCount.length);
                    proxy._$treegridHelper.ejTreeGrid("setCollapsedRecordCount", filteredCollapseCount.length);
                }
                else
                {
                    proxy._$ganttchartHelper.ejGanttChart("refreshHelper", proxy._currentViewData, proxy._updatedGanttRecords);
                }


                proxy._isValidationEnabled = false;
                proxy._connectorlineIds = [];
                proxy._connectorLinesCollection = [];
                proxy._createConnectorLinesCollection();
            }

            if (args.requestType === "delete") {

                this.dataSource(proxy._$treegridHelper.ejTreeGrid("getDataSource"));


                model.selectedItem = null;
                this.selectedRowIndex(-1);
                var childCount = 0,
                    expandedRecordCount=0;
                //Collapse record counts
                if (!model.enableVirtualization) {
                    if (args.data.hasChildRecords) {
                        childCount = proxy._$treegridHelper.ejTreeGrid("getChildCount", args.data, 0);
                        expandedRecordCount = proxy.getExpandedRecordCount(args.data, 0);
                        if (!args.data.expanded) {
                            proxy._$ganttchartHelper.ejGanttChart("reRenderGanttGridLinesTable", -1);
                            proxy._totalCollapseRecordCount -= (childCount - expandedRecordCount);
                        }
                        else {
                            proxy._$ganttchartHelper.ejGanttChart("reRenderGanttGridLinesTable", -(expandedRecordCount+1));
                            proxy._totalCollapseRecordCount -= (childCount - expandedRecordCount);
                        }
                    }
                    else {
                        proxy._$ganttchartHelper.ejGanttChart("reRenderGanttGridLinesTable", -1);
                    }
                }
                //Delete from parent collection if item is in parentsCollection
                if (model.parentRecords.indexOf(args.data) !== -1) {
                    model.parentRecords.splice(model.parentRecords.indexOf(args.data), 1);
                }
                //Delete predecessor from child records
                if (args.data.hasChildRecords) {
                    proxy._removeChildRecordsPredecessor(args.data)
                }

                //Delete Predecessor from record
                args.data.predecessor && proxy._removePredecessor(args.data.predecessor, args.data);

                //Update parent item if item has parent
                if (args.data.parentItem)
                {
                    parentRecord=args.data.parentItem;
                    if(args.data.parentItem.childRecords.length>0)
                    {
                        proxy._updateParentItem(args.data);
                    }else
                    {
                        parentRecord.expanded=false;
                        parentRecord.hasChildRecords = false;
                        proxy.refreshGanttRecord(parentRecord);
                    }
                }
                proxy._rows = proxy._$treegridHelper.ejTreeGrid("getFlatRecords");
                proxy._ids = proxy._ids = proxy._$treegridHelper.ejTreeGrid("getUpdatedIds");
                proxy._isValidationEnabled = false;
                if (proxy.model.predecessorMapping) {
                    proxy._connectorlineIds = [];
                    proxy._connectorLinesCollection = [];
                    proxy._predecessorsCollection = [];
                    proxy._$ganttchartHelper.ejGanttChart("clearConnectorLines");
                    proxy._createConnectorLinesCollection();
                }
                //Scroller is not correctly updated before connector line cleared.
                proxy._$ganttchartHelper.ejGanttChart("refreshHelper", proxy.getCurrentViewData(), proxy.getUpdatedRecords(), proxy._totalCollapseRecordCount);


                if (proxy.model.toolbarSettings.showToolbar) {
                    if (proxy.model.toolbarSettings.toolbarItems.indexOf("delete") !== -1) {
                        $('.e-gantttoolbar').ejToolbar('disableItem', $($('.e-deleteitem')[0]).parent()[0]);
                        if (proxy.model.toolbarSettings.toolbarItems.indexOf("indent") !== -1) 
                            $('.e-gantttoolbar').ejToolbar('disableItem', $($('.e-indent')[0]).parent()[0]);
                        if (proxy.model.toolbarSettings.toolbarItems.indexOf("outdent") !== -1) 
                            $('.e-gantttoolbar').ejToolbar('disableItem', $($('.e-outdent')[0]).parent()[0]);
                        if (proxy.model.toolbarSettings.toolbarItems.indexOf("edit") !== -1)
                            $('.e-gantttoolbar').ejToolbar('disableItem', $($('.e-edititem')[0]).parent()[0]);

                    }
                }
                proxy.updateAltRow(proxy.getUpdatedRecords, 0, 1);//for set e-alt-row style after deletion of element
                
            }

            if (args.requestType === "selection") {
                proxy._$ganttchartHelper.ejGanttChart("selectRows", args.recordIndex);
            }

            if (args.requestType === "rowHover") {
                proxy._$ganttchartHelper.ejGanttChart("addRowHover", args.index);
            }
            
            if (args.requestType === "scroll") {
                
                proxy._$ganttchartHelper.ejGanttChart("onScrollHelper", args.delta);
            }

            if (args.requestType === "save") {
                if (args._cAddedRecord) {

                    //For change the id collection after new record is created//
                    proxy._$treegridHelper.ejTreeGrid("renderRecord", args);

                    //if records are sorted or searched then sort newly added record
                    treegridobj = proxy._$treegridHelper.ejTreeGrid("instance");
                    if (treegridobj.model.sortSettings.sortedColumns.length > 0 || (treegridobj.model.allowSearching && treegridobj._searchString.length > 0)) {
                        var evgArgs = {};
                        proxy._$treegridHelper.ejTreeGrid("processBindings", evgArgs);
                        var tempArgs = {};
                        tempArgs.requestType = ej.TreeGrid.Actions.Refresh;
                        proxy._$treegridHelper.ejTreeGrid("sendDataRenderingRequest", tempArgs);
                    }
                    //get all records from treegrid
                    this.dataSource(proxy._$treegridHelper.ejTreeGrid("getDataSource"));
                    proxy._ids = proxy._$treegridHelper.ejTreeGrid("getUpdatedIds");
                    proxy.model.ganttRecords = proxy._$treegridHelper.ejTreeGrid("getFlatRecords");
                    proxy._updatedGanttRecords = proxy._$treegridHelper.ejTreeGrid("getUpdatedRecords");
                    proxy._rows = proxy._$treegridHelper.ejTreeGrid("getFlatRecords");
                    proxy._currentViewData = proxy._$treegridHelper.ejTreeGrid("getCurrentViewData");
                    proxy._$ganttchartHelper.ejGanttChart("setUpdatedRecords", proxy._currentViewData, proxy._updatedGanttRecords, proxy._rows, proxy._ids);

                    if (treegridobj.model.sortSettings.sortedColumns.length > 0 || (treegridobj.model.allowSearching && treegridobj._searchString.length > 0)) {
                        proxy._$ganttchartHelper.ejGanttChart("refreshHelper", proxy.getCurrentViewData(), proxy.getUpdatedRecords(), proxy._totalCollapseRecordCount);
                        if (!model.enableVirtualization) {
                            var filteredCollapseCount = 0;
                            filteredCollapseCount = proxy._updatedGanttRecords.filter(function (record) {
                                return (proxy.getExpandStatus(record) === false);
                            });
                            proxy._$ganttchartHelper.ejGanttChart("refrehGridLinesTable", (proxy._currentViewData.length - filteredCollapseCount.length));
                        }
                    }
                    else {
                        proxy._$ganttchartHelper.ejGanttChart("renderRecord", args, proxy._totalCollapseRecordCount);
                        //update grid lines as per new records parent item
                        if (proxy.model.selectedItem) {
                            if (!proxy.model.selectedItem.expanded && proxy.model.selectedItem.childRecords) {
                                if (!args.position)
                                    proxy._totalCollapseRecordCount++;
                                else if (args.position == "Above" && proxy._currentViewData.length != 1)
                                    proxy._$ganttchartHelper.ejGanttChart("reRenderGanttGridLinesTable", 1);

                            }
                            else if (proxy._currentViewData.length != 1)
                                proxy._$ganttchartHelper.ejGanttChart("reRenderGanttGridLinesTable", 1);
                        }
                        else if (proxy._currentViewData.length != 1)
                            proxy._$ganttchartHelper.ejGanttChart("reRenderGanttGridLinesTable", 1);
                    }
                    //for soritng
                    if (!args._cAddedRecord.parentItem)
                        model.parentRecords.splice(args._cAddedRecord.index, 0, args._cAddedRecord);
                    else
                        proxy._updateParentItem(args._cAddedRecord);

                    proxy.refreshGanttRecord(args._cAddedRecord)
                } else if (args._cModifiedData) {
                    args._cModifiedData.left = args._cModifiedData._calculateLeft(proxy._projectStartDate, proxy._perDayWidth, proxy._holidaysList, model);
                    args._cModifiedData.width = args._cModifiedData._calculateWidth(proxy._perDayWidth, proxy._holidaysList, model);
                    args._cModifiedData.progressWidth = args._cModifiedData._getProgressWidth(args._cModifiedData.width, args._cModifiedData.status);
                    
                    proxy.refreshGanttRecord(args._cModifiedData);

                    if (args._cModifiedData.parentItem)
                        proxy._updateParentItem(args._cModifiedData);

                    if (args._cModifiedData.predecessor) {
                        if (args.previousValue) {
                            proxy._removeConnectorLine(args.previousValue, args._cModifiedData);
                        }
                    }
                }
                
                if (proxy.model.predecessorMapping) {

                    if ((args._cAddedRecord && args._cAddedRecord.predecessor)
                        || (args._cModifiedData && args._cModifiedData.predecessor)) {
                        proxy._isValidationEnabled = true;
                    }
                    else
                        proxy._isValidationEnabled = false;
                    if (args._cAddedRecord) {
                      
                        proxy._$ganttchartHelper.ejGanttChart("clearConnectorLines");
                        proxy._connectorlineIds = [];
                        proxy._connectorLinesCollection = [];
                        proxy._createConnectorLinesCollection();
                        proxy._addConnectorLine(args._cAddedRecord);
                    } else {
                        if (args._cModifiedData) {
                            if (args.previousValue) {
                                proxy._removeConnectorLine(args.previousValue, args._cModifiedData);
                            }
                            proxy._addConnectorLine(args._cModifiedData);
                            if (args._cModifiedData.predecessor) {
                                proxy._isMileStoneEdited = args._cModifiedData.isMilestone;
                                proxy._updatedConnectorLineCollection = [];
                                proxy._connectorlineIds = [];
                                proxy._validatePredecessor(args._cModifiedData);
                                if (proxy._updatedConnectorLineCollection.length > 0) {
                                    proxy._$ganttchartHelper.ejGanttChart("appendConnectorLine", proxy._updatedConnectorLineCollection);
                                }
                            }
                            if (args._cModifiedData.parentItem)
                                proxy._updateParentItem(args._cModifiedData);
                        }
                    }
                }
            }

            if (args.requestType === "validatePredecessor") {
                var result = proxy._editedPredecessorValidation(args);
                args.result = result;
                return;
            }
            proxy._ganttActionCompleteTrigger(args);
        },

        chartactionComplete: function (args) {
            var proxy = this;

            proxy._updatedGanttRecords = proxy.getUpdatedRecords();
            proxy._currentViewData = proxy.getCurrentViewData();

            if (args.requestType === "updateConnectors") {
                if (proxy.model.predecessorMapping) {
                    proxy._isValidationEnabled = false;
                    proxy._connectorlineIds = [];
                    proxy._connectorLinesCollection = [];
                    proxy._$ganttchartHelper.ejGanttChart("clearConnectorLines");
                    proxy._createConnectorLinesCollection();
                }
            }

            if (args.requestType === "rowHover") {
                proxy._$treegridHelper.ejTreeGrid('addRowHover', args.index);
            }
            
            if (args.requestType === "scroll") {

                proxy._isTreeGridRendered = false;
                proxy._isGanttChartRendered = false;
                if (args.vscrollExsist && args.delta !== undefined)
                    proxy._$treegridHelper.ejTreeGrid('onScrollHelper', args.delta);

                proxy._updatedGanttRecords = proxy.getUpdatedRecords();
                proxy._currentViewData = proxy.getCurrentViewData();

                if (proxy.model.enableVirtualization) {

                    if (proxy.model.predecessorMapping) {

                        if (proxy._connectorLinesCollection.length > 0) {
                            proxy._$ganttchartHelper.ejGanttChart("clearConnectorLines");
                        }
                        proxy._isValidationEnabled = false;
                        proxy._connectorlineIds = [];
                        proxy._connectorLinesCollection = [];
                        proxy._createConnectorLinesCollection();
                    }
                }
                proxy._isTreeGridRendered = true;
                proxy._isGanttChartRendered = true;
            }
            
            if (args.requestType === "selection") {
                proxy._$treegridHelper.ejTreeGrid("selectRows", args.recordIndex);
            }
            //for validate the predecessor on mouse hover and mouse up of second drag point
            if (args.requestType === "validatePredecessor") {
                args.data[this.model.taskIdMapping] = args.data.taskID;
                var flag= proxy._editedPredecessorValidation(args);
                args.predecessorValidation = flag;
            }

            //on mouse up if validation is true then draw connector line
            if (args.requestType === "drawConnectorLine") {

                var currentPredecessor = args.toItem._calculatePredecessor(args.predecessor);
                args.toItem.item[proxy.model.predecessorMapping] = args.predecessorString[0];

                if (!args.fromItem.predecessor) {// for parent item
                    args.fromItem['predecessor'] = currentPredecessor;
                }
                else {
                    args.fromItem.predecessor.push(currentPredecessor[0]);
                }
                if (args.toItem.predecessor)
                {
                    args.toItem.predecessor.push(currentPredecessor[0]);
                }
                else
                {
                    args.toItem.predecessor=[];
                    args.toItem.predecessor.push(currentPredecessor[0]);
                }

                proxy._isMileStoneEdited = args.toItem.isMilestone;
                proxy._updatedConnectorLineCollection = [];
                proxy._connectorlineIds = [];
                proxy._validatePredecessor(args.toItem);
                if (proxy._updatedConnectorLineCollection.length > 0) {
                    proxy._$ganttchartHelper.ejGanttChart("appendConnectorLine", proxy._updatedConnectorLineCollection);
                }
            }
            
            proxy._ganttActionCompleteTrigger(args);
        },

        _clearConnectorLines: function () {
            var proxy = this,
                count = 0,
                length = proxy._connectorLinesCollection.length,
                connectorLine,
                childId,
                childGanttRecord,
                predecessors,
                predecessorslength,
                i = 0,
                predecessor;
            
            for (count; count < length; count++) {

                connectorLine = proxy._connectorLinesCollection[count];
                childId = connectorLine && connectorLine.ConnectorLineId.split("child")[1];
                childGanttRecord = proxy._rows[proxy._ids.indexOf(childId)];
                predecessors = childGanttRecord.predecessor;
                predecessorslength =predecessors&& predecessors.length;
                
                for (i = 0; i < predecessorslength; i++) {

                    predecessor = predecessors[i];

                    if (predecessor.to === childId && predecessor.isdrawn) {
                        predecessor.isdrawn = false;
                    }
                }
            }
            
            proxy._$ganttchartHelper.ejGanttChart("clearConnectorLines");
        },
        

        taskbarEditing: function (args) {
            
            this._trigger("taskbarEditing", args);
        },
        
        _refreshParent: function (item) {
            this.refreshGanttRecord(item);
            if (item.parentItem) {
                this._refreshParent(item.parentItem);
            }
        },

        taskbarEdited: function (args) {
            var proxy = this,
                ganttRecord = args.data, model = proxy.model,
                projectStartDate = new Date(proxy._projectStartDate),
                remainDays,
                day,
                offset = 0;
            
            proxy._isValidationEnabled = false;
            
            if (args.dragging) {
                if (args.previousData.left !== ganttRecord.left) {
                    remainDays = ganttRecord.left % proxy._perDayWidth,
                           day = (ganttRecord.left - remainDays) / proxy._perDayWidth,
                           offset = 0;
                    
                    if (remainDays > 0 && (model.workingTimeScale != ej.Gantt.workingTimeScale.TimeScale24Hours)) {
                        offset = remainDays >= proxy._perDayWidth / 2 ? 1 : 0;
                    }
                    var remainingHours = Math.round(remainDays / (proxy._perDayWidth / 24));//Hour calculation

                    projectStartDate.setDate(projectStartDate.getDate() + day + offset);
                    if (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Day) {
                        projectStartDate.setHours(remainingHours);
                    }
                    else if (model.dateFormat.indexOf("hh:") &&
                     model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale8Hours) {
                        var remainingHours = Math.round(remainDays / (proxy._perDayWidth / 9));
                        projectStartDate.setHours(8);
                    }
                      
                    if ((model.workingTimeScale != ej.Gantt.workingTimeScale.TimeScale24Hours)) {
                        if (remainDays >= (proxy._perDayWidth / 2)) {
                            ganttRecord.left = ganttRecord.left + proxy._perDayWidth;//- remainDays;
                            if (model.roundOffDayworkingTime)
                                ganttRecord.left -= remainDays;
                        } else {
                            ganttRecord.left = ganttRecord.left;// - remainDays;
                            if (model.roundOffDayworkingTime)
                                ganttRecord.left -= remainDays;
                        }
                    }
                    
                    if (this._stringHolidays &&
                     this._stringHolidays.indexOf(ganttRecord._getFormatedDate(projectStartDate, model.dateFormat)) != -1) {
                        projectStartDate.setDate(projectStartDate.getDate() + 1);
                        ganttRecord.left += proxy._perDayWidth;
                    }
                    
                    if (this.model.includeWeekend == false) {
                        if (projectStartDate.getDay() === 0) {
                            projectStartDate.setDate(projectStartDate.getDate() + 1);
                            ganttRecord.left += proxy._perDayWidth;
                        } else if (projectStartDate.getDay() === 6) {
                            projectStartDate.setDate(projectStartDate.getDate() + 2);
                            ganttRecord.left += (2 * proxy._perDayWidth);
                        }
                    }

                    if (this._stringHolidays &&
                    this._stringHolidays.indexOf(ganttRecord._getFormatedDate(projectStartDate, model.dateFormat)) != -1) {
                        projectStartDate.setDate(projectStartDate.getDate() + 1);
                        ganttRecord.left += proxy._perDayWidth;
                    }
                    
                    ganttRecord.startDate = ganttRecord._getFormatedDate(projectStartDate, model.dateFormat);//_calculateFormatedDate
                    if (model.startDateMapping)
                        ganttRecord.item[model.startDateMapping] = ganttRecord.startDate;
                    ganttRecord._calculateEndDate(model.includeWeekend, this._holidaysList, model, proxy._perDayWidth);
                    ganttRecord.width = ganttRecord._calculateTaskbarWidth(proxy._perDayWidth,model);
                    ganttRecord.progressWidth = ganttRecord._getProgressWidth(ganttRecord.width, ganttRecord.status);
                    proxy._isValidationEnabled = true;
                }

            } else if (args.rightResizing) {
                
                if (args.previousData.width !== ganttRecord.width) {
                    day = ganttRecord.width / proxy._perDayWidth;
                    var rem = ganttRecord.width % proxy._perDayWidth;
                    offset = 0;
                    if (rem > 0 && (model.workingTimeScale != "TimeScale24Hours")) {
                        offset = rem >= (proxy._perDayWidth / 2) ? 1 : 0;
                    }

                    var totalLength = ganttRecord.left + ganttRecord.width;
                    var remainingLength = totalLength % proxy._perDayWidth;

                    var remainingHours = Math.round(remainingLength / (proxy._perDayWidth / 24));//hour calculation

                    var startDate = proxy._getDateFromFormat(ganttRecord.startDate);

                    if ((model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Day &&
                        model.durationUnit == ej.Gantt.DurationUnit.Hour)) {//model.dateFormat.indexOf("hh") == -1
                        var startDateHour = (ganttRecord.left % proxy._perDayWidth) / proxy._perHourWidth;
                        var hours = Math.round(totalLength / (proxy._perHourWidth));
                        hours -= startDateHour;

                        var endDate = ganttRecord._dateUpdate(startDate, 0, hours);
                        startDate.setHours(startDateHour);
                    }

                    else if ((model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Week
                         && model.dateFormat.indexOf("hh") != -1)) {
                        if (model.durationUnit == ej.Gantt.DurationUnit.Hour) {
                            var startDateHour = Math.round((ganttRecord.left % proxy._perDayWidth) / (proxy._perDayWidth / 24));
                            var remainingHourDiff = Math.round(totalLength / (proxy._perDayWidth / 24));
                            remainingHourDiff -= startDateHour;
                            endDate = ganttRecord._dateUpdate(startDate, 0, remainingHourDiff);
                        }
                    }

                    else
                        var endDate = ganttRecord._dateUpdate(startDate, day - 1 + offset, 0);

                    if (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Day ||
                        (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Week && model.dateFormat.indexOf("hh") != -1))
                        endDate.setHours(Math.round(remainingHours));
                    else if (model.dateFormat.indexOf("hh:") &&
                       model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale8Hours) {
                        endDate.setHours(Math.round(17));
                    }

                    if (model.holidays && model.holidays.length) {
                        var holidayIndex = 0,
                            holidayslength = model.holidays.length,
                            holiday;
                        for (holidayIndex = 0; holidayIndex < holidayslength; holidayIndex++) {
                            holiday = new Date(this._holidaysList[holidayIndex]);
                            if (endDate === holiday) {
                                endDate.setDate(endDate.getDate() - 1);
                            }
                        }
                    }

                    if (this.model.includeWeekend == false) {
                        if (endDate.getDay() == 0) {
                            endDate.setDate(endDate.getDate() - 2);
                        } else if (endDate.getDay() == 6) {
                            endDate.setDate(endDate.getDate() - 1);
                        }
                    }
                    
                    if (this._stringHolidays &&
                   this._stringHolidays.indexOf(ganttRecord._getFormatedDate(endDate, model.dateFormat)) != -1) {
                        endDate.setDate(endDate.getDate() + 1);
                        if (endDate.getDay() == 6) {
                            endDate.setDate(endDate.getDate() + 2);
                        }
                    }
                    
                    ganttRecord.endDate = ganttRecord._calculateFormatedDate(endDate, model.dateFormat);
                    if (model.endDateMapping)
                        ganttRecord.item[model.endDateMapping] = ganttRecord.endDate;
                    ganttRecord._calculateDuration(startDate, endDate, model.includeWeekend, model.holidays, ganttRecord.isMilestone,model);
                    ganttRecord.width = ganttRecord._calculateTaskbarWidth(proxy._perDayWidth,model);
                    ganttRecord.progressWidth = ganttRecord._getProgressWidth(ganttRecord.width, ganttRecord.status);
                    proxy._isValidationEnabled = true;
                }

            } else if (args.leftResizing) {
                if (args.previousData.left !== ganttRecord.left) {
                    remainDays = ganttRecord.left % proxy._perDayWidth;
                    day = (ganttRecord.left - remainDays) / proxy._perDayWidth;
                    offset = 0;
                    if (remainDays > 0 && (model.workingTimeScale != "TimeScale24Hours")) {
                        offset = remainDays >= proxy._perDayWidth / 2 ? 1 : 0;
                    }
                    var remainingHours = Math.round(remainDays / (proxy._perDayWidth / 24));//Hour calculation

                    projectStartDate.setDate(projectStartDate.getDate() + day + offset);

                    if (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Day ||
                        (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Week && model.dateFormat.indexOf("hh") != -1)) {
                        if (model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale8Hours &&
                            (remainingHours >= 17||model.durationUnit==ej.Gantt.DurationUnit.Day))
                            projectStartDate.setHours(8);
                        else
                            projectStartDate.setHours(remainingHours);
                    }
                    else if (model.dateFormat.indexOf("hh:") &&
                       model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale8Hours) {
                        var remainingHours = Math.round(remainDays / (proxy._perDayWidth / 9));
                        projectStartDate.setHours(8);
                    }

                    if (this._stringHolidays &&
                    this._stringHolidays.indexOf(ganttRecord._getFormatedDate(projectStartDate, model.dateFormat)) != -1) {
                        projectStartDate.setDate(projectStartDate.getDate() + 1);
                        ganttRecord.left += proxy._perDayWidth;
                    }
                    
                    if (this.model.includeWeekend == false) {
                        if (projectStartDate.getDay() === 0) {
                            projectStartDate.setDate(projectStartDate.getDate() + 1);
                            ganttRecord.left += proxy._perDayWidth;
                        } else if (projectStartDate.getDay() === 6) {
                            projectStartDate.setDate(projectStartDate.getDate() + 2);
                            ganttRecord.left += (2 * proxy._perDayWidth);
                        }
                    }
                    
                    if (this._stringHolidays &&
                    this._stringHolidays.indexOf(ganttRecord._getFormatedDate(projectStartDate, model.dateFormat)) != -1) {
                        projectStartDate.setDate(projectStartDate.getDate() + 1);
                        ganttRecord.left += proxy._perDayWidth;
                    }

                    
                    if (model.workingTimeScale != ej.Gantt.workingTimeScale.TimeScale24Hours &&
                        model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Day &&
                        model.durationUnit != ej.Gantt.DurationUnit.Hour) {

                        if (remainDays >= (proxy._perDayWidth / 2)) {
                            ganttRecord.left = ganttRecord.left + proxy._perDayWidth;// - remainDays;
                            if (model.roundOffDayworkingTime)
                                ganttRecord.left -= remainDays;
                        } else {
                            ganttRecord.left = ganttRecord.left;//- (remainingHours * 20);
                            if (model.roundOffDayworkingTime)
                                ganttRecord.left -= remainDays;
                        }
                    }
                    else if (model.scheduleHeaderSettings.scheduleHeaderType != ej.Gantt.ScheduleHeaderType.Day &&
                        model.dateFormat.indexOf("hh") == -1) {
                        if (remainDays >= (proxy._perDayWidth / 2)) {
                            ganttRecord.left = ganttRecord.left + proxy._perDayWidth;// - remainDays;
                            if (model.roundOffDayworkingTime)
                                ganttRecord.left -= remainDays;
                        } else {
                            ganttRecord.left = ganttRecord.left;//- (remainingHours * 20);
                            if (model.roundOffDayworkingTime)
                                ganttRecord.left -= remainDays;
                        }
                    }
                      

                    else if (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Day
                        && (model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale8Hours ||
                        model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale24Hours || model.durationUnit == ej.Gantt.DurationUnit.Hour)) {
                        var remainingHourDiff = ganttRecord.left % proxy._perHourWidth;

                        if (remainingHourDiff >= (proxy._perHourWidth / 2)) {
                            ganttRecord.left = ganttRecord.left + proxy._perHourWidth;// - remainDays;

                            ganttRecord.left -= remainingHourDiff;
                        } else {
                            ganttRecord.left -= remainingHourDiff;
                        }
                    }

                    ganttRecord.startDate = ganttRecord._calculateFormatedDate(projectStartDate, model.dateFormat);
                    if (model.startDateMapping)
                        ganttRecord.item[model.startDateMapping] = ganttRecord.startDate;
                    ganttRecord._calculateDuration(projectStartDate, proxy._getDateFromFormat(ganttRecord.endDate), model.includeWeekend, model.holidays, ganttRecord.isMilestone,model);
                    ganttRecord.width = ganttRecord._calculateTaskbarWidth(proxy._perDayWidth, model);
                    ganttRecord.progressWidth = ganttRecord._getProgressWidth(ganttRecord.width, ganttRecord.status);
                    proxy._isValidationEnabled = true;
                }
            } else if (args.progressResizing) {
                ganttRecord.status = ganttRecord._getProgressPercent(ganttRecord.width, ganttRecord.progressWidth);
                if (ganttRecord.parentItem) {
                    ganttRecord._updateParentProgress(ganttRecord.parentItem, model.progressMapping);
                }
                proxy._refreshParent(ganttRecord);
                //proxy.refreshGanttRecord(ganttRecord);
                //proxy.refreshGanttRecord(ganttRecord.parentItem);
            }
            if (proxy._isValidationEnabled) {
                proxy._updateEditedGanttRecord(ganttRecord);
                if (ganttRecord.predecessor) {
                    proxy._isMileStoneEdited = ganttRecord.isMilestone;
                    proxy._updatedConnectorLineCollection = [];
                    proxy._connectorlineIds = [];
                    proxy._editedTaskBarItem = ganttRecord;
                    proxy._validatePredecessor(ganttRecord);
                    //proxy._$ganttchartHelper.ejGanttChart("clearConnectorLines");
                    //proxy._createConnectorLinesCollection();

                    if (proxy._updatedConnectorLineCollection.length > 0) {
                        proxy._$ganttchartHelper.ejGanttChart("appendConnectorLine", proxy._updatedConnectorLineCollection);
                    }
                }
                proxy._editedTaskBarItem = null;
                if (ganttRecord.parentItem)
                    proxy._updateParentItem(ganttRecord);
                proxy.refreshGanttRecord(ganttRecord);
            }
            proxy._trigger("taskbarEdited", args);
            if (!args.cancel && (args.leftResizing || args.rightResizing || args.dragging)) {
                proxy._updateScheduleDatesOnEditing(args);
            }
        },

        actionBegin: function (args) {

            var proxy = this;

            if (!proxy._trigger("actionBegin", args)) {

                if (args.requestType === "beginedit") {
                    proxy._sendEditRequest();
                }   
                
            }

        },

        _ganttActionCompleteTrigger: function (args) {
            this._trigger("actionComplete", args);
            if (!args.cancel && args.requestType === 'save') {
                if (args._cModifiedData) {
                    args.data = args._cModifiedData;
                }
                if (args._cAddedRecord) {
                    args.data = args._cAddedRecord;
                }
                this._updateScheduleDatesOnEditing(args);
            }
        },

        _queryCellInfo: function (args) {
            this._trigger("queryCellInfo", args);
        },

        _beginEdit: function (args) {
            var proxy = this;
            if (!proxy._trigger("beginEdit", args)) {
                proxy._isinBeginEdit = true;
                if (proxy.model.toolbarSettings.showToolbar) {

                    var toolBarEnabledItems = [];

                    var cancelElement = $($('.e-cancel')[0]).parent()[0];
                    var saeveElement = $($('.e-saveitem')[0]).parent()[0];

                    if (cancelElement) {
                        toolBarEnabledItems.push(cancelElement);
                    }

                    if (saeveElement) {
                        toolBarEnabledItems.push(saeveElement);
                    }

                    $('.e-gantttoolbar').ejToolbar('enableItem', toolBarEnabledItems);
                    var disableToolItems = [];
                    if (proxy.model.editSettings.allowAdding && proxy.model.toolbarSettings.toolbarItems.indexOf("add") !== -1)
                        disableToolItems.push($($('.e-addnewitem')[0]).parent()[0]);
                    if (proxy.model.editSettings.allowEditing && proxy.model.toolbarSettings.toolbarItems.indexOf("edit") !== -1)
                        disableToolItems.push($($('.e-edititem')[0]).parent()[0]);
                    if (proxy.model.editSettings.allowDeleting && proxy.model.toolbarSettings.toolbarItems.indexOf("delete") !== -1)
                        disableToolItems.push($($('.e-deleteitem')[0]).parent()[0]);
                    $('.e-gantttoolbar').ejToolbar('disableItem', disableToolItems);
                }
            }
        },

        _endEdit: function (args) {
            var proxy = this,model=this.model;
            
            proxy._isinBeginEdit = false;

            if (proxy._trigger("endEdit", args)) {
                var predecessorString = "";
                args.data[args.columnName] = args.previousValue;
                if (args.columnName === "predecessor") {
                    predecessorString = proxy._predecessorToString(args.data.predecessor, args.data);
                    args.data.item[args.columnObject.mappingName] = predecessorString;
                } else {
                    args.data.item[args.columnObject.mappingName] = args.previousValue;
                }
            }
            else {

                if (args.isModified) {
                    proxy._currentViewData = proxy._$treegridHelper.ejTreeGrid("getCurrentViewData");
                    proxy._isValidationEnabled = true;
                    proxy._updateEditedGanttRecords(args);
                }
            }
            proxy.refreshGanttRecord(args.data);
            
            delete args.isModified;
            if (proxy.model.toolbarSettings.showToolbar) {
                var toolBarDisableItems = [];

                if (proxy.model.toolbarSettings.toolbarItems.indexOf("cancel") !== -1) {
                    toolBarDisableItems.push($($('.e-cancel')[0]).parent()[0]);
                }

                if (proxy.model.toolbarSettings.toolbarItems.indexOf("update") !== -1) {
                    toolBarDisableItems.push($($('.e-saveitem')[0]).parent()[0]);
                }
                
                $('.e-gantttoolbar').ejToolbar('disableItem', toolBarDisableItems);
            }

            if (!args.cancel && (args.columnName === "startDate" || args.columnName === "endDate" || args.columnName === "duration")) {
                proxy._updateScheduleDatesOnEditing(args);
            }


            // proxy._trigger("endEdit", args);
        },

        //updated the schedule dates while cellediting ,taskBarediting and dialogEditing and dialogAdding
        _updateScheduleDatesOnEditing:function(args)
        {
            var proxy = this,
                model = this.model,
                startDate = proxy._getDateFromFormat(args.data.startDate),
                endDate = proxy._getDateFromFormat(args.data.endDate),
                scheduleStartDate = proxy._projectStartDate,    //_getDateFromFormat(model.scheduleStartDate),
                scheduleEndDate = proxy._getDateFromFormat(model.scheduleEndDate),
                minStartDate, maxEndDate,
                isDateChanged = false,
                tempStartDate = model.scheduleStartDate,
                updatedDates,
                tempEndDate = model.scheduleEndDate;
                proxy._calculateDatesForScheduleCheck(startDate);
            if (!model.predecessorMapping) {
                if (!(startDate.getTime() >= scheduleStartDate.getTime()) || !(startDate.getTime() <= scheduleEndDate.getTime())) {
                    if (startDate.getTime() < scheduleStartDate.getTime()) {
                        minStartDate = startDate;
                        scheduleStartDate = startDate;
                    }
                    else {
                        maxEndDate = proxy._getDateFromFormat(args.data.startDate);
                        scheduleEndDate = proxy._getDateFromFormat(args.data.startDate);
                    }
                }
                if (!(endDate.getTime() >= scheduleStartDate.getTime()) || !(endDate.getTime() <= scheduleEndDate.getTime())) {
                    if (endDate.getTime() < scheduleStartDate.getTime())
                        minStartDate = endDate;
                    else
                        maxEndDate = endDate;
                }
                if (maxEndDate) {
                    isDateChanged = true;
                    tempEndDate = args.data._getFormatedDate(maxEndDate, model.dateFormat);
                }
                if (minStartDate) {
                    isDateChanged = true;
                    tempStartDate = args.data._getFormatedDate(minStartDate, model.dateFormat);
                }
                if (isDateChanged) {
                    updatedDates = proxy._updateScheduleDatesByTaskLables(proxy._getDateFromFormat(tempStartDate), proxy._getDateFromFormat(tempEndDate));
                    proxy.updateScheduleDates(args.data._getFormatedDate(updatedDates.minStartDate, model.dateFormat), args.data._getFormatedDate(updatedDates.maxEndDate, model.dateFormat));
                }
            }
            else {
                var editArgs = {};
                editArgs.onEditing = true;
                proxy._calculateScheduleDates(editArgs);
                proxy._calculateDatesForScheduleCheck(editArgs.minStartDate);
                if (editArgs.minStartDate.getTime() < scheduleStartDate || editArgs.maxEndDate.getTime() > scheduleEndDate) {
                    proxy.updateScheduleDates(args.data._getFormatedDate(editArgs.minStartDate, model.dateFormat), args.data._getFormatedDate(editArgs.maxEndDate, model.dateFormat));
                }
            }
        },
        //add dates before edited dates for scheduleupdate 
        _calculateDatesForScheduleCheck:function(startdate)
        {
            var proxy = this;
               
            if (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Week) {

                startdate.setDate(startdate.getDate() - 3);
            }

            if (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Year) {
                startdate.setDate(startdate.getDate() - 5);
            }
            if (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Month) {
                startdate.setDate(startdate.getDate() - 3);
            }

            if (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Day) {
                startdate.setHours(startdate.getHours() - 2);
            }
        }
        ,
        //update schedule dates by tool bar operation
        _updateScheduleDatesByToolBar:function(args)
        {
            var proxy = this,
                 startDate = args === "prevTimeSpan" ? proxy._projectStartDate : proxy._getDateFromFormat(proxy.model.scheduleStartDate);
                 endDate = proxy._getDateFromFormat(proxy.model.scheduleEndDate),
                 chartObject = $("#ejGanttChart" + proxy._id).ejGanttChart("instance"),
                 maxScrollWidth = 0;

            if (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Week) {
                if (args === "prevTimeSpan") {
                    startDate.setDate(startDate.getDate() - 6);
                }
                else {
                    endDate.setDate(endDate.getDate() + 7);
                }
            }

            if (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Year) {
                if (args === "prevTimeSpan")
                    startDate.setDate(startDate.getDate() - 360);
                else
                    endDate.setDate(endDate.getDate() + 365);
            }
            if (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Month) {
                
                if (args === "prevTimeSpan")
                    startDate.setDate(startDate.getDate());
                else
                    endDate.setDate(endDate.getDate() + 30);
            }

            if (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Day) {
                if (args === "prevTimeSpan")
                    startDate.setDate(startDate.getDate() - 1);
                else
                    endDate.setDate(endDate.getDate() + 1);
            }
            if (args === "prevTimeSpan") {
                proxy.updateScheduleDates(proxy._getFormatedDate(startDate, model.dateFormat), proxy._getFormatedDate(endDate, model.dateFormat));
                chartObject._$bodyContainer.ejScroller("scrollX", 0, true);
            }
            else if (args === "nextTimeSpan") {
                proxy.updateScheduleDates(proxy._getFormatedDate(startDate, model.dateFormat), proxy._getFormatedDate(endDate, model.dateFormat));
                maxScrollWidth = chartObject.getMaxScrollWidth();
                chartObject._$bodyContainer.ejScroller("scrollX", maxScrollWidth, true);
            }
        },
        _rowDataBound: function (args) {
            this._trigger("rowDataBound", args);
        },
        _refreshToolBar: function () {
            var $toolbar = $("#" + this._id + "_toolbarItems");
            $toolbar.find("li").removeClass("e-hover");
        },

        _toolBarClick: function (sender) {
            var proxy = this,
                model=proxy.model,
                $gridEle = $(this.itemsContainer).closest(".e-gantt"),
                gridInstance = $gridEle.ejGantt("instance"),
                gridId = $gridEle.attr('id');

            gridInstance._clearContextMenu();
            if (sender.event == undefined && sender.target.tagName == "INPUT" && sender.currentTarget.id == gridId + "_search")
                return false;

            if (gridInstance.model.dateFormat.indexOf("hh") != -1)
                $.isFunction($.fn.ejDateTimePicker) && $("#" + gridId + "EditForm").find(".e-datepicker").ejDateTimePicker("hide");
            else
                $.isFunction($.fn.ejDatePicker) && $("#" + gridId + "EditForm").find(".e-datepicker").ejDatePicker("hide");


            if ($gridEle.ejGantt("instance")._trigger("toolBarClick", sender))
                return false;
            
            switch (sender.currentTarget.id) {

                case gridId + "_add":
                    gridInstance._toolbarOperation(gridId + "_add");
                    break;

                case gridId + "_edit":
                    gridInstance._toolbarOperation(gridId + "_edit");
                    break;

                case gridId + "_delete":
                    gridInstance._toolbarOperation(gridId + "_delete");
                    break;

                case gridId + "_update":
                    gridInstance._toolbarOperation(gridId + "_update");
                    break;

                case gridId + "_cancel":
                    gridInstance._toolbarOperation(gridId + "_cancel");
                    break;

                case gridId + "_search":
                    gridInstance._toolbarOperation(gridId + "_search", $(sender.currentTarget).find("input").val());
                    break;

                case gridId + "_indent":
                    gridInstance._toolbarOperation(gridId + "_indent");
                    break;

                case gridId + "_outdent":
                    gridInstance._toolbarOperation(gridId + "_outdent");
                    break;
                    
                case gridId + "_expandAll":
                    gridInstance._toolbarOperation(gridId + "_expandAll");
                    break;
                 
                case gridId + "_collapseAll":
                    gridInstance._toolbarOperation(gridId + "_collapseAll");
                    break;
                case gridId + "_prevTimeSpan":
                    gridInstance._toolbarOperation(gridId + "_prevTimeSpan");
                    break;
                case gridId + "_nextTimeSpan":
                    gridInstance._toolbarOperation(gridId + "_nextTimeSpan");
                    break;
            }
            return false;
        },

        _toolbarOperation: function (operation, searchEle) {
            var $gridEle = this.element, gridObject = $gridEle.ejGantt("instance"), gridId = $gridEle.attr('id'), proxy = this,
                rowindex = proxy.selectedRowIndex();
            switch (operation) {

                case gridId + "_add":
                    proxy._sendAddRequest();
                    break;

                case gridId + "_edit":
                    proxy._sendEditRequest();
                    break;

                case gridId + "_delete":
                    proxy._$treegridHelper.ejTreeGrid("deleteRow");
                    break;

                case gridId + "_update":
                    proxy._$treegridHelper.ejTreeGrid("endEdit");
                    //gridObject.sendSaveRequest();

                    if (proxy.model.toolbarSettings.toolbarItems.indexOf("cancel") !== -1) {
                        proxy._disabledToolItems.push($($('.e-cancel')[0]).parent()[0]);
                    }

                    if (proxy.model.toolbarSettings.toolbarItems.indexOf("update") !== -1) {
                        proxy._disabledToolItems.push($($('.e-saveitem')[0]).parent()[0]);
                    }
                    $('.e-gantttoolbar').ejToolbar('disableItem', proxy._disabledToolItems);
                    
                    proxy._disabledToolItems = [];
                    
                    break;

                case gridId + "_cancel":
                    proxy._$treegridHelper.ejTreeGrid("cancelEditCell");                                                            
                    break;

                case gridId + "_search":
                    proxy._$treegridHelper.ejTreeGrid("search", searchEle);
                    proxy._searchString = searchEle;

                    proxy._updateToolbarOptions(searchEle);
                    
                    break;

                case gridId + "_indent":
                    proxy._sendIndentRequest();
                    proxy._$treegrid.focus();
                    break;

                case gridId + "_outdent":
                    proxy._sendOutdentRequest();
                    proxy._$treegrid.focus();
                    break;

                case gridId + "_expandAll":
                    proxy._expandAll();
                    proxy._$treegrid.focus();
                    break;

                case gridId + "_collapseAll":                   
                    proxy._deSelectRowItem();
                    proxy._collapseAll();
                    if (proxy.model.toolbarSettings.showToolbar){
                        if (proxy.model.toolbarSettings.toolbarItems.indexOf("delete") !== -1) {
                            $('.e-gantttoolbar').ejToolbar('disableItem', $($('.e-deleteitem')[0]).parent()[0]);
                            if (proxy.model.toolbarSettings.toolbarItems.indexOf("indent") !== -1)
                                $('.e-gantttoolbar').ejToolbar('disableItem', $($('.e-indent')[0]).parent()[0]);
                            if (proxy.model.toolbarSettings.toolbarItems.indexOf("outdent") !== -1)
                                $('.e-gantttoolbar').ejToolbar('disableItem', $($('.e-outdent')[0]).parent()[0]);
                            if (proxy.model.toolbarSettings.toolbarItems.indexOf("edit") !== -1)
                                $('.e-gantttoolbar').ejToolbar('disableItem', $($('.e-edititem')[0]).parent()[0]);                          
                        }
                    }

                    proxy._$treegrid.focus();
                    break;
                case gridId + "_prevTimeSpan":
                    proxy._updateScheduleDatesByToolBar("prevTimeSpan");
                    break;
                case gridId + "_nextTimeSpan":
                    proxy._updateScheduleDatesByToolBar("nextTimeSpan");
                    break;

            }
            proxy._refreshToolBar();
            return false;
        },
        
        _setModel: function (options) {
            
            var proxy = this, option,
                model = proxy.model;
            
            for (option in options) {
                switch (option) {
                    case "sortSettings":
                        proxy._sendSortingRequest(options[option]);
                        break;
                    case "destroy":
                        proxy.destroy();
                        break;
                    case "allowGanttChartEditing":
                        proxy._ganttChartEditing(options[option]);
                        break;
                    case "enableProgressBarResizing":
                        proxy._resizeProgressbar(options[option]);
                        break;
                    case "enableTaskbarTooltip":
                        proxy._showTooltip(options[option]);
                        break;
                    case "enableTaskbarDragTooltip":
                        proxy._showEditingTooltip(options[option]);
                        break;
                    case "enableAltRow":
                        proxy._updateAltRow(options[option]);
                        break;
                    case "locale":
                        model.ganttRecords = [];
                        model.parentRecords = [];
                        proxy._clearContextMenu();
                        model.locale = options[option];
                        proxy.element.ejGantt("destroy").ejGantt(model);
                        break;
                    case "allowSelection":
                        proxy._updateRowSelection(options[option]);
                        break;
                    case "editSettings":
                        $.extend(model.editSettings, options[option]);
                        proxy._updateEditSettings(options[option]);
                        break;
                    case "taskbarBackground":
                        proxy._updateTaskbarBackground(options[option]);
                        break;
                    case "progressbarBackground":
                        proxy._updateProgressbarBackground(options[option]);
                        break;
                    case "parentTaskbarBackground":
                        proxy._updateParentTaskbarBackground(options[option]);
                        break;
                    case "parentProgressbarBackground":
                        proxy._updateParentProgressbarBackground(options[option]);
                        break;
                    case "showTaskNames":
                        proxy._updateRenderTaskNames(options[option]);
                        break;
                    case "showProgressStatus":
                        proxy._updateRendeProgressStatus(options[option]);
                        break;
                    case "showResourceNames":
                        proxy._updateRenderResourceNames(options[option]);
                        break;
                    case "progressbarHeight":
                        proxy._updateProgressbarHeight(options[option]);
                        break;
                    case "baselineColor":
                        proxy._updateBaselineColor(options[option]);
                        break;
                    case "renderBaseline":
                        proxy._updateRenderBaseline(options[option]);
                        break;
                    case "allowColumnResize":
                        proxy._updateAllowColumnResize(options[option]);
                        break;
                    case "allowKeyboardNavigation":
                        proxy._updateAllowKeyboardNavigation(options[option]);
                        break;
                    case "selectedItem":
                        proxy._updateSelectedItem(options[option]);
                        break;
                    case "dataSource":
                        model.dataSource = [];
                        model.ganttRecords = [];
                        model.parentRecords = [];
                        model.scheduleStartDate = null;
                        model.scheduleEndDate = null;
                        model.dataSource = (options[option]);
                        proxy.element.ejGantt("destroy").ejGantt(model);
                        break;
                    case "showGridCellTooltip":
                        proxy._updateShowGridCellTooltip(options[option]);
                        break;
                    case "showGridExpandCellTooltip":
                        proxy._updateShowGridExpandCellTooltip(options[option]);
                        break;
                    case "highlightWeekends":
                        proxy._updateHighlightWeekends(options[option]);
                        break;
                    case "connectorLineBackground":
                        proxy._updateConnectorLineBackground(options[option]);
                        break;
                    case "connectorlineWidth":
                        proxy._updateConnectorlineWidth(options[option]);
                        break;
                    case "weekendBackground":
                        proxy._updateWeekendBackground(options[option]);
                        break;
                    case "enableContextMenu":
                        proxy.model.enableContextMenu = options[option];
                        break;
                    case "enableResize":
                        if (model.enableResize) {
                            proxy.model.enableResize = options[option];
                            proxy._on($(window), "resize", proxy.windowResize);
                        }
                        else {
                            proxy._off($(window), "resize", proxy.windowResize);
                        }
                        break;
                    case "selectedRowIndex":
                        if (this.selectedRowIndex() !== -1 && !ej.isNullOrUndefined(this.selectedRowIndex()) && this.selectedRowIndex() < proxy._updatedGanttRecords.length) {
                            var args = {};
                            args.recordIndex = this.selectedRowIndex();
                            args.data = proxy._updatedGanttRecords[args.recordIndex];
                            args.target = "ejTreeGrid";
                            proxy.rowSelected(args);
                            proxy._$treegridHelper.ejTreeGrid("selectRows", args.recordIndex);
                            proxy._$ganttchartHelper.ejGanttChart("selectRows", args.recordIndex);
                            proxy._$ganttchartHelper.ejGanttChart("updateSelectedItem", args.recordIndex);
                        }
                        else if (this.selectedRowIndex() === -1) {
                            proxy._$treegridHelper.ejTreeGrid("clearSelection");
                        }
                        break;
                }
            }
        },

        _updateWeekendBackground: function (bgcolor) {
            var proxy = this;
            this.model.weekendBackground = bgcolor;
            proxy._$ganttchartHelper.ejGanttChart("updateWeekendBackground", bgcolor);

        },

        _updateConnectorlineWidth: function (lineWidth) {
            var proxy = this;
            this.model.connectorlineWidth = lineWidth;
            proxy._$ganttchartHelper.ejGanttChart("updateConnectorlineWidth", lineWidth);
            proxy._$ganttchartHelper.ejGanttChart("clearConnectorLines");
            proxy._$ganttchartHelper.ejGanttChart("renderConnectorLines",
                proxy._connectorLinesCollection);

        },

        _updateConnectorLineBackground: function (bgcolor) {
            var proxy = this;
            this.model.connectorLineBackground = bgcolor;
            proxy._$ganttchartHelper.ejGanttChart("updateConnectorLineBackground", bgcolor);
            proxy._$ganttchartHelper.ejGanttChart("clearConnectorLines");
            proxy._$ganttchartHelper.ejGanttChart("renderConnectorLines",
                proxy._connectorLinesCollection);

        },

        _updateHighlightWeekends: function (bool) {
            var proxy = this;
            this.model.highlightWeekends = bool;
            proxy._$ganttchartHelper.ejGanttChart("updateHighlightWeekends", bool);
        },

        _updateShowGridCellTooltip: function (bool) {
            var proxy = this;
            proxy._$treegridHelper.ejTreeGrid("updateShowGridCellTooltip", bool);
        },

        _updateShowGridExpandCellTooltip: function (bool) {
            var proxy = this;
            proxy._$treegridHelper.ejTreeGrid("updateShowGridExpandCellTooltip", bool);
        },

        _updateSelectedItem: function (item) {
            var proxy = this,
                args = {};
            if (item[proxy.model.taskIdMapping] != null) {


                args.recordIndex =proxy._ids.indexOf((item[proxy.model.taskIdMapping]).toString());
                args.item = proxy.model.ganttRecords[args.recordIndex];
                args.target = "ejTreeGrid";
                proxy.rowSelected(args);
                proxy._$treegridHelper.ejTreeGrid("selectRows", args.recordIndex);
                proxy._$ganttchartHelper.ejGanttChart("selectRows", args.recordIndex);
                proxy._$ganttchartHelper.ejGanttChart("updateSelectedItem", args.recordIndex);
            }
        },

        _updateAllowKeyboardNavigation: function (bool) {
            var proxy = this;
            proxy._$treegridHelper.ejTreeGrid("updateAllowKeyboardNavigation", bool);
            proxy._$ganttchartHelper.ejGanttChart("updateAllowKeyboardNavigation", height);
        },
        
        _updateAllowColumnResize: function (bool) {
            var proxy = this;
            proxy._$treegridHelper.ejTreeGrid("updateAllowColumnResize", bool);
        },
        
        _updateProgressbarHeight: function (height) {
            var proxy = this;
            this.model.progressbarHeight = height;
            proxy._$ganttchartHelper.ejGanttChart("updateProgressbarHeight", height);
        },
        
        _updateBaselineColor: function (color) {
            var proxy = this;
            this.model.baselineColor = color;
            proxy._$ganttchartHelper.ejGanttChart("updateBaselineColor", color);
        },
        
        _updateRenderBaseline: function (bool) {
            var proxy = this;
            this.model.renderBaseline = bool;
            proxy._$ganttchartHelper.ejGanttChart("updateRenderBaseline", bool);
            proxy._$ganttchartHelper.ejGanttChart("renderConnectorLines",
                proxy._connectorLinesCollection);
        },
        
        _updateRenderTaskNames: function (bool) {
            var proxy = this;
            this.model.showTaskNames = bool;
            proxy._$ganttchartHelper.ejGanttChart("updateRenderTaskNames", bool);
        },
        
        _updateRendeProgressStatus: function (bool) {
            var proxy = this;
            this.model.showProgressStatus = bool;
            proxy._$ganttchartHelper.ejGanttChart("updateRendeProgressStatus", bool);
        },
        
        _updateRenderResourceNames: function (bool) {
            var proxy = this;
            this.model.showResourceNames = bool;
            proxy._$ganttchartHelper.ejGanttChart("updateRenderResourceNames", bool);
        },
        
        _updateTaskbarBackground: function (bgcolor) {
            var proxy = this;
            this.model.taskbarBackground = bgcolor;
            proxy._$ganttchartHelper.ejGanttChart("updateTaskbarBackground", bgcolor);
        },

        _updateProgressbarBackground: function (bgcolor) {
            var proxy = this;
            this.model.progressbarBackground = bgcolor;
            proxy._$ganttchartHelper.ejGanttChart("updateProgressbarBackground", bgcolor);
        },

        _updateParentTaskbarBackground: function (bgcolor) {
            var proxy = this;
            this.model.parentTaskbarBackground = bgcolor;
            proxy._$ganttchartHelper.ejGanttChart("updateParentTaskbarBackground", bgcolor);
        },

        _updateParentProgressbarBackground: function (bgcolor) {
            var proxy = this;
            this.model.parentProgressbarBackground = bgcolor;
            proxy._$ganttchartHelper.ejGanttChart("updateParentProgressbarBackground", bgcolor);
        },
        
        _updateEditSettings: function (edit) {
            var proxy = this;
            proxy._$treegridHelper.ejTreeGrid("updateEditSettings", edit);
            
        },
        
        _updateRowSelection: function (bool) {
            var proxy = this;
            proxy._$treegridHelper.ejTreeGrid("updateRowSelection", bool);
        },

        _updateAltRow: function (bool) {
            var proxy = this;
            proxy._$treegridHelper.ejTreeGrid("updateAltRow", bool);
        },
        
        /**
       * To Open the dialog to add new task to the gantt
       * @return jQuery
       * @example 
       * &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
       * &lt;script&gt;
       * // Create Gantt
       * var ganttObj = $("#gantt").data("ejGantt");
       * gantObj.ejGantt("openAddDialog"); // To open the add dialog
       * &lt;/script&gt;
       * @example 
       *  &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
       * &lt;script&gt;
       * // open Add dialog
       * $("#gantt").ejGantt("openAddDialog");	
       * &lt;/script&gt;
       * @memberof ejGantt
       * @instance
        */
        openAddDialog: function() {
            this._sendAddRequest();
        },

        /**
        * To Open the dialog to edit existing task to the gantt
        * @return jQuery
        * @example 
        * &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
        * &lt;script&gt;
        * // Create Gantt
        * var ganttObj = $("#gantt").data("ejGantt");
        * gantObj.ejGantt("openEditDialog"); // To open the add dialog
        * &lt;/script&gt;
        * @example 
        *  &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
        * &lt;script&gt;
        * // open Add dialog
        * $("#gantt").ejGantt("openEditDialog");	
        * &lt;/script&gt;
        * @memberof ejGantt
        * @instance
         */
        openEditDialog:function() {
            this._sendEditRequest();
        },
        
        /**
        * To search an item with search string provided at the run time
        * @return jQuery
        * @example 
        * &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
        * &lt;script&gt;
        * // Create Gantt
        * var ganttObj = $("#gantt").data("ejGantt");
        * gantObj.ejGantt("searchItem",$("#text").val()); // To search a task
        * &lt;/script&gt;
        * @example 
        *  &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
        * &lt;script&gt;
        * // To search a task
        * $("#gantt").ejGantt("searchItem",$("#text").val());	
        * &lt;/script&gt;
        * @memberof ejGantt
        * @instance
         */
        searchItem: function (searchString) {
            var proxy = this;
            proxy._$treegridHelper.ejTreeGrid("search", searchString);
        },
        

        /**
        * To delete a selected item in gantt
        * @return jQuery
        * @example 
        * &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
        * &lt;script&gt;
        * // Create Gantt
        * var ganttObj = $("#gantt").data("ejGantt");
        * gantObj.ejGantt("deleteItem"); // To delete a task
        * &lt;/script&gt;
        * @example 
        *  &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
        * &lt;script&gt;
        * // To delete an item
        * $("#gantt").ejGantt("deleteItem");	
        * &lt;/script&gt;
        * @memberof ejGantt
        * @instance
         */
        deleteItem: function () {
            var proxy = this;
            proxy._$treegridHelper.ejTreeGrid("deleteRow");
        },


        /**
          * To Expand all the parent items in gantt
          * @return jQuery
          * @example 
          * &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
          * &lt;script&gt;
          * // Create Gantt
          * var ganttObj = $("#gantt").data("ejGantt");
          * gantObj.ejGantt("expandAllItems"); // To expand all parent items in gantt
          * &lt;/script&gt;
          * @example 
          *  &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
          * &lt;script&gt;
          * // To expand all items
          * $("#gantt").ejGantt("expandAllItems");	
          * &lt;/script&gt;
          * @memberof ejGantt
          * @instance
           */

        expandAllItems:function() {
            this._expandAll();
        },

        /**
          * To collapse all the parent items in gantt
          * @return jQuery
          * @example 
          * &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
          * &lt;script&gt;
          * // Create Gantt
          * var ganttObj = $("#gantt").data("ejGantt");
          * gantObj.ejGantt("collapseAllItems"); // To collapse all parent items in gantt
          * &lt;/script&gt;
          * @example 
          *  &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
          * &lt;script&gt;
          * // To expand all items
          * $("#gantt").ejGantt("collapseAllItems");	
          * &lt;/script&gt;
          * @memberof ejGantt
          * @instance
           */
        collapseAllItems:function() {
            this._collapseAll();
        },
        
          /**
          * To indent a selected item in gantt
          * @return jQuery
          * @example 
          * &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
          * &lt;script&gt;
          * // Create Gantt
          * var ganttObj = $("#gantt").data("ejGantt");
          * gantObj.ejGantt("indentItem"); // To indent a selected item in gantt
          * &lt;/script&gt;
          * @example 
          *  &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
          * &lt;script&gt;
          * // To indent a selected item in gantt
          * $("#gantt").ejGantt("indentItem");	
          * &lt;/script&gt;
          * @memberof ejGantt
          * @instance
           */
        indentItem:function() {
            this._sendIndentRequest();
        },

        /**
       * To outdent a selected item in gantt
       * @return jQuery
       * @example 
       * &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
       * &lt;script&gt;
       * // Create Gantt
       * var ganttObj = $("#gantt").data("ejGantt");
       * gantObj.ejGantt("outdentItem"); // To outdent a selected item in gantt
       * &lt;/script&gt;
       * @example 
       *  &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
       * &lt;script&gt;
       * // To outdent a selected item in gantt
       * $("#gantt").ejGantt("outdentItem");	
       * &lt;/script&gt;
       * @memberof ejGantt
       * @instance
        */
        outdentItem:function() {
            this._sendOutdentRequest();
        },
        

        /**
        * To cancel the edited state of an item in gantt
        * @return jQuery
        * @example 
        * &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
        * &lt;script&gt;
        * // Create Gantt
        * var ganttObj = $("#gantt").data("ejGantt");
        * gantObj.ejGantt("cancelEdit"); // To cancel edited
        * &lt;/script&gt;
        * @example 
        *  &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
        * &lt;script&gt;
        * // To outdent a selected item in gantt
        * $("#gantt").ejGantt("cancelEdit");	
        * &lt;/script&gt;
        * @memberof ejGantt
        * @instance
         */
        cancelEdit:function() {
            this.sendCancelRequest();
        },
        

        /**
       * To expand and collapse an item in gantt using item's ID
       * @return jQuery
       * @example 
       * &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
       * &lt;script&gt;
       * // Create Gantt
       * var ganttObj = $("#gantt").data("ejGantt");
       * gantObj.ejGantt("expandCollapseRecord" , "23"); // To expand collapse an item
       * &lt;/script&gt;
       * @example 
       *  &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
       * &lt;script&gt;
       * // To expand collapse an item
       * $("#gantt").ejGantt("expandCollapseRecord" , "23");	
       * &lt;/script&gt;
       * @memberof ejGantt
       * @instance
        */
        expandCollapseRecord: function (taskId) {
            var proxy = this, args = {},
                record = proxy.model.ganttRecords[proxy._ids.indexOf(taskId)],
                expand = record.expanded == true ? false : true;
            args.data = record;
            args.recordIndex = proxy._ids.indexOf(taskId);
            args.expanded = expand;
            args.requestType = "expandCollapse";
            proxy._$treegridHelper.ejTreeGrid("sendExpandCollapseRequest", args);
        },



        /**
       * To save the edited state of an item in gantt
       * @return jQuery
       * @example 
       * &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
       * &lt;script&gt;
       * // Create Gantt
       * var ganttObj = $("#gantt").data("ejGantt");
       * gantObj.ejGantt("saveEdit"); // To save edited state of an item
       * &lt;/script&gt;
       * @example 
       *  &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
       * &lt;script&gt;
       * // To expand collapse an item
       * $("#gantt").ejGantt("saveEdit");	
       * &lt;/script&gt;
       * @memberof ejGantt
       * @instance
        */
        saveEdit: function () {
            var proxy = this;
            proxy._$treegridHelper.ejTreeGrid("endEdit");
        },
        
        _showTooltip: function (boolValue) {
            var proxy = this;
            this.model.enableTaskbarTooltip = boolValue;
            proxy._$ganttchartHelper.ejGanttChart("showTooltip", boolValue);
        },

        _showEditingTooltip: function (boolValue) {
            var proxy = this;
            this.model.enableTaskbarDragTooltip = boolValue;
            proxy._$ganttchartHelper.ejGanttChart("showEditingTooltip", boolValue);
        },
        
        _ganttChartEditing:function(boolValue) {
            var proxy = this;
            proxy.model.allowGanttChartEditing = boolValue;
            proxy._$ganttchartHelper.ejGanttChart("ganttChartEditing", boolValue);
        },
        
        _resizeProgressbar: function (boolValue) {
            var proxy = this;
            proxy.model.enableProgressBarResizing = boolValue;
            proxy._$ganttchartHelper.ejGanttChart("resizeProgressbar", boolValue);

        },
        
        _sendSortingRequest: function(sortSettings) {
            var proxy = this, columnName, columnSortDirection;
            columnName = sortSettings.sortedColumns[0].field;
            columnSortDirection = sortSettings.sortedColumns[0].direction;
            proxy._$treegridHelper.ejTreeGrid("sortColumn", columnName, columnSortDirection);
        },
        
        sendCancelRequest: function () {
            var proxy = this;
            proxy._$treegridHelper.ejTreeGrid("cancelEditCell");

            if (proxy.model.toolbarSettings.toolbarItems.indexOf("cancel") !== -1) {
                proxy._disabledToolItems.push($($('.e-cancel')[0]).parent()[0]);
            }

            if (proxy.model.toolbarSettings.toolbarItems.indexOf("save") !== -1) {
                proxy._disabledToolItems.push($($('.e-saveitem')[0]).parent()[0]);
            }

            $('.e-gantttoolbar').ejToolbar('disableItem', proxy._disabledToolItems);
            proxy._disabledToolItems = [];
        },
        
        _sendAddRequest: function () {
            
            var proxy = this,                
                columns = proxy._columns,
                length = columns.length,
                columnCount = 0,
                cloneData = {},
                args = {};
            proxy._isinAddnewRecord = true;
            
            for (columnCount; columnCount < length; columnCount++)
                cloneData[columns[columnCount].mappingName] = "";

            args.data = cloneData;
            args.requestType = "add";            
          //  proxy._$treegridHelper.ejTreeGrid("clearSelection");
            proxy.renderedEditDialog(args);
        },

        _sendEditRequest: function ($tr) {
            var proxy = this,
                model = proxy.model,
                args,
                data;
            
            if (ej.isNullOrUndefined($tr)) {
                proxy._currentTrIndex = this.selectedRowIndex();
                proxy._$currentTr = $(proxy._$treegridHelper.ejTreeGrid("getRows")).eq(this.selectedRowIndex());
            } else {
                proxy._currentTrIndex = $tr.index();
                proxy._$currentTr = $tr;
            }
            data = proxy.getUpdatedRecords()[this.selectedRowIndex()];

            args = { rowElement: proxy._$currentTr, data: data };
            proxy._trigger("beginEdit", args);
            args.requestType = "beginedit";
            if(args.data)
                proxy.renderedEditDialog(args);
        },
        _updateAddData:function(obj)
        {
            var proxy = this,model=this.model,id,startDate;
            var cloneObj = {};
           
            if (!obj[model.taskIdMapping])
            {
                 id= proxy._updatedGanttRecords.length;
                 id = proxy._getNewTaskId(id);
                 var indx = proxy._ids.indexOf(id.toString());
                 proxy._ids.splice(indx,1);
                 obj[model.taskIdMapping] = id;
            }

            if (model.taskNameMapping && !obj[model.taskNameMapping]) {
                obj[model.taskNameMapping] = "New Task" + obj[model.taskIdMapping];
            }

            if (!obj[model.startDateMapping]) {
                obj[model.startDateMapping] = model.scheduleStartDate;
            }

            if (model.durationMapping && ej.isNullOrUndefined(obj[model.durationMapping])) {
                if (!obj[model.endDateMapping])
                obj[model.durationMapping] = "5";
            }
            if (model.progressMapping) {
                obj[model.progressMapping] = obj[model.progressMapping] > 100 ?
                    100 : obj[model.progressMapping];
            }

            if (!obj[model.endDateMapping] && model.endDateMapping) {

                if (!obj[model.durationMapping]) {
                    var startDate = proxy._getDateFromFormat(model.scheduleStartDate);
                    startDate.setDate(startDate.getDate() + 4);
                    obj[model.endDateMapping] = Globalize.format(startDate, this.model.dateFormat);
                }
            }
        },
        _sendSaveRequest: function (saveType) {
            var obj = {},
                doc = document,
                proxy = this,
                model=proxy.model,
                index = 0,
                formelement,
                length,
                editedRowWrap,
                columnName,
                $element,
                startdate,
                enddate,
                column,
                value,dialogId,treeGridId
            args = {};
            if(saveType==="Add")
            {
                formelement = doc.getElementById(proxy._id + "AddForm");
                length = formelement && formelement.length;
                dialogId = "Add";
                treeGridId = "#treegrid" + proxy._id + "predecessorAdd";
                $element = $("#" + proxy._id + "taskId" + dialogId);             
                column = ej.TreeGrid.getColumnByField(proxy._columns, "taskId");
                proxy._cellEditType = column.editType;
                if (column && $element.length>0)
                    value = proxy.getCurrentEditCellData($element, column.dropdownData);

                if (proxy._ids.indexOf(value) != -1 && value)
                    this._duplicate = true;
                else if (value) {
                    this._duplicate = false;
                }
            }
            else
            {
                formelement = doc.getElementById(proxy._id + "EditForm");
                length = formelement && formelement.length;
                treeGridId = "#treegrid" + proxy._id + "predecessoredit";
                dialogId = "";
            }
            editedRowWrap = $(formelement).closest('div');


            if (!this.editFormValidate())
                return true;            
                      
            if (!this._duplicate) {


                for (var count = 0; count < proxy._columns.length; count++) {
                    $element = $(formelement).find("#" + proxy._id + proxy._columns[count].field + dialogId);
                    if ($element.length > 0) {
                        proxy._cellEditType =proxy._columns[count].editType;
                        value = proxy.getCurrentEditCellData($element, proxy._columns[count].dropdownData); // formelement[index].value;
                        if (proxy._isinAddnewRecord === false && proxy._columns[count].mappingName === proxy.model.predecessorMapping) {
                            args.previousValue = proxy._updatePredecessorValue(obj, value);
                        }
                        if ($element.type != "checkbox")
                            obj[proxy._columns[count].mappingName] = value;
                    }
                }
                date1 = proxy._getDateFromFormat(obj[model.startDateMapping]);
                date2 = proxy._getDateFromFormat(obj[model.endDateMapping]);
                var diffdays=0;
                if (date1 && date2)
                    diffdays = date2.getTime() - date1.getTime();
                if (diffdays < 0)
                    this._wrongenddate = true;
                else
                    this._wrongenddate = false;
                if (!this._wrongenddate) {
                    // when adding new task resource value changes.
                if (obj[model.resourceIdMapping] && editedRowWrap.hasClass("e-addedrow"))
                {
                        var resource = [];
                        $.each(obj[model.resourceIdMapping], function (indx, value) { resource.push(value[model.resourceIdMapping]); })
                        obj[model.resourceIdMapping] = resource;
                    }

                    if (!obj[model.taskIdMapping] && saveType === "Edit")
                        obj[model.taskIdMapping] = proxy._editedDialogRecord.taskId;

                if (saveType === "Add")
                {
                        proxy._updateAddData(obj);
                    }

                    args.data = obj;


                    //getting predecessor from edit dialog table    
                    var prdecessor_validation_flag = false;
                    var results = [], resultFlag = false;;
                if (model.predecessorMapping )
                {
                        if (saveType === "Edit") {
                            resultFlag = model.editDialogFields.length === 0 ? true : false;
                            results = $.grep(model.editDialogFields, function (val, idx) {
                                return (val.field === model.predecessorMapping);
                            });
                    }else if(saveType === "Add")
                    {
                        resultFlag = model.addDialogFields.length=== 0 ? true : false;
                            results = $.grep(model.addDialogFields, function (val, idx) {
                                return (val.field === model.predecessorMapping);
                            });
                        }
                    }

                if (results.length > 0 || resultFlag)
                {
                        var pre = [];
                        var taskNameFlag = true;
                        pre = $(treeGridId).ejTreeGrid("option", "dataSource");
                        $.each(pre, function (idx, value) {
                        if(!(value.id.length>0 && value.name.length && value.type.length))
                        {
                                taskNameFlag = false;
                            }
                        });

                        if (taskNameFlag) {
                            var predecessorColl = [], predecessorString = [];//from,to,offset,predecessorType,isdrawn
                            var types = [{ id: "SS", text: "Start-Start", value: "Start-Start" }, { id: "SF", text: "Start-Finish", value: "Start-Finish" }, { id: "FS", text: "Finish-Start", value: "Finish-Start" }, { id: "FF", text: "Finish-Finish", value: "Finish-Finish" }];
                            var tempType;
                            for (var i = 0; i < pre.length; i++) {
                                var predecessor = {};
                                predecessor["from"] = obj.taskID;
                                predecessor["to"] = pre[i].id;
                                predecessor["isdrawn"] = false;
                            predecessor["offset"] =isNaN(parseInt(pre[i].offset)) ? 0 : parseInt(pre[i].offset);
                                for (var j = 0; j < types.length; j++) {
                                    if (pre[i].type == types[j].text) {
                                        predecessor["predecessorType"] = types[j].id;
                                        tempType = types[j].id;
                                        break;
                                    }
                                }
                                var tem = pre[i].id + tempType//+data[i].lags.toString();
                            pre[i].offset=isNaN(parseInt(pre[i].offset)) ? 0 : parseInt(pre[i].offset);
                                if (pre[i].offset !== 0) {
                                    if (pre[i].offset < 0)
                                        tem += pre[i].offset.toString();
                                    else
                                        tem += "+" + pre[i].offset.toString();
                                }
                                predecessorString.push(tem);
                                predecessorColl.push(predecessor);
                            }
                            args.predecessorString = predecessorString;

                            //befor save validate the edit form data
                            prdecessor_validation_flag = proxy._editedPredecessorValidation(args);

                        } else {
                            //Break here and give notification to users
                            alert("Fill all the columns in predecessor table")
                            return true;
                        }

                        if (prdecessor_validation_flag) {
                            if (proxy._isinAddnewRecord === false) {// && proxy.model.predecessorMapping
                                args.previousValue = proxy._updatePredecessorValue(obj, predecessorString.join(','));
                            }
                            obj[model.predecessorMapping] = predecessorString.join(',');
                        }
                        else {
                            alert("Cyclic Dependency Occured, Please Check The Predecessor");
                            return true;
                        }
                    }

                    args.requestType = ej.TreeGrid.Actions.Save;
                    args.recordIndex = (this.selectedRowIndex() !== -1) ? this.selectedRowIndex() : -1;

                    if (proxy._trigger("actionBegin", args))
                        return true;


                    if (editedRowWrap.hasClass("e-editedrow")) {
                        args._cModifiedData = proxy._updateRecord(obj);
                        if (proxy._editedDialogRecord) {
                            if (!args._cModifiedData.startDate) {
                                args._cModifiedData.startDate = proxy._editedDialogRecord.startDate;
                            }
                            if (!args._cModifiedData.endDate) {
                                args._cModifiedData.endDate = proxy._editedDialogRecord.endDate;
                            }
                            if (!args._cModifiedData.duration) {
                                args._cModifiedData.duration = proxy._editedDialogRecord.duration;
                            }
                            proxy._editedDialogRecord = null;
                        }

                        if (args.data[model.endDateMapping] && !args.data[model.durationMapping]) {
                            args._cModifiedData._calculateDuration(proxy._getDateFromFormat(args._cModifiedData.startDate), proxy._getDateFromFormat(args._cModifiedData.endDate), model.includeWeekend, model.holidays, args._cModifiedData.isMilestone, model);
                        }

                    }
                    else if (editedRowWrap.hasClass("e-addedrow")) {

                        var parentItem, Level = 0, cIndex;
                        if (model.selectedItem) {
                            if (model.selectedItem.hasChildRecords) {//this is parent item
                                Level = model.selectedItem.level + 1
                                parentItem = model.selectedItem;
                                cIndex = 0;
                            }
                            else if ((!model.selectedItem.hasChildRecords && model.selectedItem.parentItem)) {
                                Level = model.selectedItem.level;
                                parentItem = model.selectedItem.parentItem;
                                cIndex = parentItem.childRecords.indexOf(model.selectedItem) + 1;
                            }
                            else {
                                Level = 0;
                                parentItem = null;
                            }
                        }
                        args._cAddedRecord = proxy._createGanttRecord(obj, Level, parentItem, false);
                        if (model.predecessorMapping && args._cAddedRecord.predecessor && args._cAddedRecord.parentItem) {
                            var predecessorIdArray = proxy._idFromPredecessor(args._cAddedRecord.item[model.predecessorMapping]);
                            if (predecessorIdArray.indexOf(args._cAddedRecord.parentItem.taskId.toString()) !== -1) {
                                alert("Cyclic Dependency Occured, Please Check The Predecessor");
                                return true;
                            }
                        }
                    }

                    if (args._cAddedRecord) {
                        args._cAddedRecord.taskId =args._cAddedRecord.taskId;
                        args._cAddedRecord.index = args.recordIndex;
                        //proxy._$treegridHelper.ejTreeGrid("processBindings", args);
                    }

                    proxy.actionComplete(args);
                    proxy._cModifiedData = null;
                    proxy._cAddedRecord = null;
                    proxy._primaryKeyValues = [];
                    proxy._isinAddnewRecord = false;
                    return false;
                }
                else {
                    alert("Invalid End date");                           
                }
            }
            else {
                alert("Duplicate ID");
                         
            }
                
        },

        _recordReturnerByID:function(id)
        {
            var proxy = this,
                records = proxy._rows;
            for (var i = 0; i < records.length; i++) {
                if (records[i].taskId.toString() === id.toString()) {
                    return records[i]
                }
            }
            return null;

        },
        _editedPredecessorValidation: function (args) {

            var proxy = this,
                records = proxy._rows,
                flag = true,
                recordId = args.data[this.model.taskIdMapping],
                predecessor = args.predecessorString.join(','),predecessorIdArray;
            if (predecessor.length > 0) {
                predecessorIdArray = proxy._idFromPredecessor(predecessor);
                for (var count = 0; count < predecessorIdArray.length; count++) {
                    //Check edited item has parent item in predecessor collection
                    var editingData = proxy._recordReturnerByID(recordId);
                    if (editingData && editingData.parentItem) {
                        if (predecessorIdArray.indexOf(editingData.parentItem.taskId.toString()) !== -1) {
                            return false;
                        }
                    }
                    // Check if predecessor exist more then one 
                    var tempIdArray = predecessorIdArray.slice(0),checkArray=[],countFlag=true;
                    $.each(tempIdArray, function (index, value) { 
                        if(checkArray.indexOf(value)===-1)
                            checkArray.push(value);
                        else
                            countFlag = false;
                    });
                    if (countFlag === false) {
                        return false;

                    }
                    //Cyclick check  
                    currentId = predecessorIdArray[count];
                    var visitedIdArray = [];
                    var predecessorCollection = predecessorIdArray.slice(0);
                    predecessorCollection.splice(count, 1);


                    while (currentId !== null) {
                        var currentIdArray = [];
                        if (visitedIdArray.indexOf(currentId) === -1)
                        {
                            currentRecord = proxy._recordReturnerByID(currentId);
                          //  var currentPredecessor="";
                            if (!ej.isNullOrUndefined(currentRecord.predecessor) && currentRecord.predecessor.length>0)
                            {
                                $.each(currentRecord.predecessor, function (index, value) {
                                    if (currentRecord.taskId.toString() !== value.from)
                                        currentIdArray.push(value.from.toString());
                                });
                            //    currentPredecessor=currentRecord.predecessor[0].from
                            }
                            if (recordId.toString() === currentRecord.taskId.toString() || currentIdArray.indexOf(recordId.toString()) !== -1) { // || predecessorCollection.indexOf(currentPredecessor) !== -1
                                //cycylic occurs//break;
                                return false;
                            }
                            visitedIdArray.push(currentId);
                            if (!ej.isNullOrUndefined(currentRecord.predecessor) && currentRecord.predecessor.length > 0) {
                                var result;
                                if (currentIdArray.length > 1) {
                                    result=this._predecessorValidation(currentIdArray, args);
                                }
                                else
                                    currentId = currentRecord.predecessor[0].from;
                                if (result === false) {
                                    return false;
                                }
                            }
                            else
                                break;
                        }
                        else
                        {
                            break;
                        }
                    }
                }
            }
            return flag;
        },

        _predecessorValidation: function (predecessor,args) {
            var proxy = this;
            var recordId=args.data[this.model.taskIdMapping];
            for (var count = 0; count < predecessor.length; count++) {
                currentId = predecessor[count];
                var visitedIdArray = [];
                var predecessorCollection = predecessor.slice(0);
                predecessorCollection.splice(count, 1);

                while (currentId !== null) {
                    var currentIdArray = [];
                    if (visitedIdArray.indexOf(currentId) === -1) {
                        currentRecord = proxy._recordReturnerByID(currentId);
                        //  var currentPredecessor="";
                        if (!ej.isNullOrUndefined(currentRecord.predecessor) && currentRecord.predecessor.length > 0) {
                            $.each(currentRecord.predecessor, function (index, value) {
                                if (currentRecord.taskId.toString() !== value.from)
                                    currentIdArray.push(value.from.toString());
                            });
                            //    currentPredecessor=currentRecord.predecessor[0].from
                        }
                        if (recordId.toString() === currentRecord.taskId.toString() || currentIdArray.indexOf(recordId.toString()) !== -1) { // || predecessorCollection.indexOf(currentPredecessor) !== -1
                            //cycylic occurs//break;
                            return false;
                        }
                        visitedIdArray.push(currentId);
                        if (!ej.isNullOrUndefined(currentRecord.predecessor) && currentRecord.predecessor.length > 0) {
                            currentId = currentRecord.predecessor[0].from;
                        }
                        else
                            break;
                    }
                    else {
                        break;
                    }
                }
            }
            return true;
            
        },
        _sendCancelRequest: function () {
            var proxy = this,
                model=proxy.model,
                args = {};

            if (model.dateFormat.indexOf("hh") != -1)
                $("#" + proxy._id + "EditForm").find(".e-datepicker").ejDateTimePicker("destroy");
            else
                $("#" + proxy._id + "EditForm").find(".e-datepicker").ejDatePicker("destroy");

            args.requestType = ej.TreeGrid.Actions.Cancel;
            proxy.processBindings(args);
            proxy._primaryKeyValues = [];
            proxy.model.currentData = null;
        },
        
        _updatePredecessorValue: function (obj, value) {
            var proxy = this,
                prevPredecessors,
                modifiedPredecessors,
                length=0,
                predecessor,
                ganttPredecessor = [],
                count = 0;
            prevPredecessors = proxy.selectedItem()["predecessor"];

            if (value.length > 0) {
                modifiedPredecessors = proxy.selectedItem()._calculatePredecessor(value);
            }
            if (modifiedPredecessors)
                length = modifiedPredecessors.length;

            var index = 0, prevPrdecessorlength=0;
            if(prevPredecessors)
                prevPrdecessorlength = prevPredecessors.length;


            for (index = 0; index < prevPrdecessorlength; index++) {
                predecessor = prevPredecessors[index];
                if (predecessor.from === proxy.selectedItem().taskId.toString()) {
                    ganttPredecessor.push(predecessor);
                }
            }
            for (count = 0; count < length; count++) {
                ganttPredecessor.push(modifiedPredecessors[count]);
            }
            proxy.selectedItem().predecessor = ganttPredecessor;
            if (proxy.model.predecessorMapping)
                proxy.selectedItem().item[proxy.model.predecessorMapping] = value;

            return prevPredecessors;          //
        },


        getCurrentEditCellData: function ($element, dropdownData) {
            var proxy = this, model = proxy.model, date;
            if ($("#" + proxy._id + "EditForm").length || $("#" + proxy._id + "AddForm").length) {
                var cellValue="";// $element = $("#" + proxy._id + proxy._columnFieldName), 
                switch (proxy._cellEditType) {
                    case ej.TreeGrid.EditingType.String:
                        cellValue = $element.val();
                        break;
                    case ej.TreeGrid.EditingType.Numeric:
                        cellValue = $element.ejNumericTextbox("getValue");
                        $element.ejNumericTextbox("getValue");
                        break;
                    case ej.TreeGrid.EditingType.Dropdown:
                        cellValue = proxy._getSelectedItem($element.ejDropDownList("model.selectedItems"), dropdownData);
                        break;
                    case ej.TreeGrid.EditingType.Boolean:
                        cellValue = $element.is(':checked');
                        break;

                    case ej.TreeGrid.EditingType.DatePicker:
                        if (model.dateFormat.indexOf("hh") != -1)
                            date = $element.ejDateTimePicker("model.value");
                        else
                            date = $element.ejDatePicker("model.value");
                        cellValue = Globalize.format(date, model.dateFormat);
                        break;
                    case ej.TreeGrid.EditingType.DateTimePicker:
                        cellValue = $element.ejDateTimePicker("model.value");
                        break;
                }

                //if (typeof cellValue == "string" && cellValue.length )//&& model.columns[proxy._cellEditingDetails.columnIndex].type == "number")
                //    cellValue = parseFloat(cellValue);
                return cellValue;
            }
            return null;
        },


        _getSelectedItem: function (indexArray, dropDownData) {
            var count = 0,
                length = indexArray.length,
                    selectedItems = [];
            if (dropDownData) {
                for (count = 0; count < length; count++) {
                    $.each(dropDownData, function (index, resourceInfo) {
                        if (indexArray[count] === index) {
                            selectedItems.push(resourceInfo);
                        }
                    });
                }
            }

            return selectedItems;
        },
        _updateRecord: function (data) {
            var proxy = this,model=this.model,
                columns=proxy._columns,
               length,
                index = 0,
                ganttRecord = proxy.getUpdatedRecords()[this.selectedRowIndex()];

            if (model.editDialogFields.length > 0) {
                var filteredColumns = [];
                var count = 0, resultColumn;
                for (; count < model.editDialogFields.length; count++) {
                    resultColumn = $.grep(proxy._columns, function (val) {
                        return val.mappingName === model.editDialogFields[count].field;
                    });
                    resultColumn.length && filteredColumns.push(resultColumn[0]);
                }
                columns = filteredColumns;
            }
            length = columns.length;

            for (index = 0; index < length; index++) {

                if (columns[index].field.toString() === "predecessor")
                    continue;
                    //for predecessor from edit dialog window 
                
                ganttRecord[columns[index].field] = data[columns[index].mappingName];
                ganttRecord.item[columns[index].mappingName] = data[columns[index].mappingName];//field
            }
            
            return ganttRecord;
        },

        _sendIndentRequest: function () {

            var proxy = this,
                model = proxy.model,
                data = proxy.getCurrentData(), args = {}, eveargs = {},
                treegridobj = proxy._$treegridHelper.ejTreeGrid("instance"),
                flatRecords = treegridobj.model.flatRecords;

            if (ej.isNullOrUndefined(data)) {
                alert("There is no gantt Record was not selected to perform the Indent ");
            }
            else {

                proxy._updatedGanttRecords = proxy.getUpdatedRecords();
                var previousGanttRecord = proxy._updatedGanttRecords[this.selectedRowIndex() - 1];
                args.data = data;
                args.requestType = "beginedit"
                if (!proxy._trigger("actionBegin", args)) {

                    if (data.parentItem) {
                        var childIndex = data.parentItem.childRecords.indexOf(data);
                        data.parentItem.childRecords.splice(childIndex, 1);
                        if(!model.parentTaskIdMapping)
                            data.parentItem.item[model.childMapping].splice(childIndex, 1);
                    } else {
                        if (this.dataSource() instanceof ej.DataManager) {
                            if (this.dataSource().dataSource.offline && this.dataSource().dataSource.json) {
                                var dataSourceIndex = this.dataSource().dataSource.json.indexOf(data.item);
                                if (!model.parentTaskIdMapping)
                                    this.dataSource().dataSource.json.splice(dataSourceIndex, 1);
                            }
                        }
                        else {
                            var dataSourceIndex = this.dataSource().indexOf(data.item);
                            if (!model.parentTaskIdMapping)
                                this.dataSource().splice(dataSourceIndex, 1);
                        }
                    }
                    if (data.level === previousGanttRecord.level) {
                        if (previousGanttRecord.childRecords) {
                            if (!previousGanttRecord.expanded) {
                                previousGanttRecord.childRecords.splice(previousGanttRecord.childRecords.length, 0, data);
                                data.parentItem = previousGanttRecord;
                                if (!model.parentTaskIdMapping)
                                    previousGanttRecord.item[model.childMapping].splice(previousGanttRecord.childRecords.length, 0, data.item);
                                else
                                    data.item[model.parentTaskIdMapping] = previousGanttRecord.taskId;
                            }
                        } else {
                            previousGanttRecord.childRecords = [];
                            previousGanttRecord.childRecords.push(data);
                            data.parentItem = previousGanttRecord;
                            previousGanttRecord.item[model.childMapping] = [];
                            if (!model.parentTaskIdMapping)
                                previousGanttRecord.item[model.childMapping].push(data.item);
                            else
                                data.item[model.parentTaskIdMapping] = previousGanttRecord.taskId;
                        }
                    } else if (previousGanttRecord.level - data.level === 1) {
                        previousGanttRecord.parentItem.childRecords.splice(previousGanttRecord.parentItem.childRecords.length, 0, data);
                        if (!model.parentTaskIdMapping)
                            previousGanttRecord.parentItem.item[model.childMapping].splice(previousGanttRecord.parentItem.childRecords.length, 0, data.item);
                        else
                            data.item[model.parentTaskIdMapping] = previousGanttRecord.parentItem.taskId;
                        data.parentItem = previousGanttRecord.parentItem;
                    } else if (previousGanttRecord.level - data.level > 1) {

                        var parentItem = proxy.getParentItem(previousGanttRecord, data.level);
                        parentItem.childRecords.splice(parentItem.childRecords.length, 0, data);
                        if (!model.parentTaskIdMapping)
                            parentItem.item[model.childMapping].splice(parentItem.childRecords.length, 0, data.item);
                        else
                            data.item[model.parentTaskIdMapping] = parentItem.taskId;
                        data.parentItem = parentItem;

                    }
                }
                if (data.parentItem.isMilestone) {
                    data.parentItem.isMilestone = false;
                }
                previousGanttRecord.hasChildRecords = previousGanttRecord.childRecords ? previousGanttRecord.childRecords.length > 0 : false;
                data.level += 1;
                proxy.updateLevel(data, +1);
                proxy.refreshGanttRecord(data);
                proxy.updateIndentOutdentOption(data);
                //update parent recordsCollections
                if (previousGanttRecord.level === 0) {
                    if (model.parentRecords.indexOf(previousGanttRecord) === -1) {
                        model.parentRecords.push(previousGanttRecord);
                    }
                }
                if (data.level > 0) {
                    if (model.parentRecords.indexOf(data) !== -1) {
                        var idx = model.parentRecords.indexOf(data);
                        model.parentRecords.splice(idx, 1);
                        treegridobj.model.parentRecords = model.parentRecords;
                    }
                }
                //Update parentitem
                if (data.parentItem) {
                   // data._updateParentProgress(data.parentItem, model.progressMapping);
                    proxy._updateParentItem(data);
                }
                //Remove child predecessor from Parent item
                if (previousGanttRecord.predecessor && previousGanttRecord.predecessor.length > 0 && proxy.model.predecessorMapping && previousGanttRecord.hasChildRecords) {
                    proxy._updatePredecessorOnIndentOutdent(previousGanttRecord);
                }
                proxy.refreshGanttRecord(previousGanttRecord);
                if (!proxy.getExpandStatus(data)) {
                    var childCount = proxy._$treegridHelper.ejTreeGrid("getChildCount", data, 0);
                    if (model.enableVirtualization) {
                        var flatIndex = flatRecords.indexOf(data);
                        if (childCount > 0 && !data.expanded) {
                            childCount = 0;
                        }
                        flatRecords.splice(flatIndex, childCount + 1);
                    }
                    else {
                        if (childCount>0 && !data.expanded) {
                            childCount = 0;
                        }
                        proxy._totalCollapseRecordCount += (childCount + 1);
                        proxy._$ganttchartHelper.ejGanttChart("reRenderGanttGridLinesTable", -(childCount + 1));
                    }
                    var expanargs = {};
                    expanargs.expanded = true;
                    expanargs.data = data.parentItem;
                    proxy.expanding(expanargs);
                }
                if (proxy.model.predecessorMapping) {
                    proxy._isValidationEnabled = false;
                    proxy._connectorlineIds = [];
                    proxy._connectorLinesCollection = [];
                    proxy._$ganttchartHelper.ejGanttChart("clearConnectorLines");
                    proxy._createConnectorLinesCollection();
                }
                //row selection
                var rowToindex = proxy._updatedGanttRecords.indexOf(data);
                var $ganttChartRows = proxy.getGanttChartRows();
                args = {
                    rowElement: $ganttChartRows.eq(rowToindex),
                    data: proxy.model.selectedItem,
                    recordIndex: rowToindex
                };
                proxy._$ganttchartHelper.ejGanttChart("selectRows", args.recordIndex);
                proxy._$treegridHelper.ejTreeGrid("selectRows", args.recordIndex);
                this.selectedItem(args.data);
                this.selectedRowIndex(args.recordIndex);

                eveargs.data = data;
                eveargs.requestType = "endedit";
                this._trigger("actionComplete", eveargs);
            }
        },
        
        _updatePredecessorOnIndentOutdent:function(parentRecord)
        {

            var proxy = this, len = parentRecord.predecessor.length,
                predecessorCollection = parentRecord.predecessor,
                predecessorIndex,
                childRecord,
                id,
                updatedPredecessor = [];
            for (var count = 0; count < len; count++) {
                //remove predecessor connect with parent item
                if (predecessorCollection[count].to === parentRecord.taskId.toString()) {
                    childRecord = proxy._rows[proxy._ids.indexOf(predecessorCollection[count].from)];
                    predecessorIndex = childRecord.predecessor.indexOf(predecessorCollection[count]);
                    childRecord.predecessor.splice(predecessorIndex, 1);
                    id = "parent" + childRecord['taskId'] + "child" + parentRecord['taskId'];
                    proxy._$ganttchartHelper.ejGanttChart("removeConnectorline", id);
                }
                    //remove predecessor if parent record as predecessor of it's child record
                else if (predecessorCollection[count].from === parentRecord.taskId.toString()) {
                    childRecord = proxy._rows[proxy._ids.indexOf(predecessorCollection[count].to)];
                    if (parentRecord.childRecords.indexOf(childRecord) !== -1) {
                        predecessorIndex = childRecord.predecessor.indexOf(predecessorCollection[count]);
                        childRecord.predecessor.splice(predecessorIndex, 1);
                        var stringPredecessor = proxy._predecessorToString(childRecord.predecessor, childRecord);
                        childRecord.item[model.predecessorMapping] = stringPredecessor;
                        id = "parent" + parentRecord['taskId'] + "child" + childRecord['taskId'];
                        proxy._$ganttchartHelper.ejGanttChart("removeConnectorline", id);
                        proxy.refreshGanttRecord(childRecord);
                    }
                    else
                    {
                        updatedPredecessor.push(predecessorCollection[count]);
                    }
                }
            }
            parentRecord.predecessor = updatedPredecessor;
            parentRecord.item[model.predecessorMapping] = "";

            //if (updatedPredecessor.length > 0) {
            //    proxy._updatedConnectorLineCollection = [];
            //    proxy._connectorlineIds = [];
            //    proxy._validatePredecessor(parentRecord);
            //    if (proxy._updatedConnectorLineCollection.length > 0) {
            //        proxy._$ganttchartHelper.ejGanttChart("appendConnectorLine", proxy._updatedConnectorLineCollection);
            //    }
            //}
        },
        
        _removePredecessor:function(predecessor,record)
        {
            var proxy = this, length = predecessor.length, count = 0, model = proxy.model, parentGanttRecord, childGanttRecord;
            for (count; count < length; count++)
            {
                if (predecessor[count].from !== record.taskId.toString())
                {
                    childGanttRecord = proxy._rows[proxy._ids.indexOf(predecessor[count].from)];  //index st
                }
                else if (predecessor[count].to !== record.taskId.toString())
                {
                    childGanttRecord = proxy._rows[proxy._ids.indexOf(predecessor[count].to)]
                }

                if (childGanttRecord) {
                    var cIndex = childGanttRecord.predecessor.indexOf(predecessor[count]);
                    if (cIndex !== -1)
                        childGanttRecord.predecessor.splice(cIndex, 1);

                    if (childGanttRecord.item[model.predecessorMapping]) {
                        childGanttRecord.item[model.predecessorMapping] = proxy._predecessorToString(childGanttRecord.predecessor, childGanttRecord);
                        proxy.refreshGanttRecord(childGanttRecord);
                    }
                }
            }

        },

        _predecessorToString:function(predecessorCollection,record)
        {
            var proxy = this, predecessorString=[],count=0,length=predecessorCollection.length;
            
            for (count; count < length;count++)
            {
                if(record.taskId.toString()!==predecessorCollection[count].from)
                    {
                        var tem = predecessorCollection[count].from + predecessorCollection[count].predecessorsType;
                        predecessorCollection[count].offset = isNaN(predecessorCollection[count].offset) ? 0 : predecessorCollection[count].offset;

                        if (predecessorCollection[count].offset !== 0) {
                            if (predecessorCollection[count].offset < 0)
                                tem += predecessorCollection[count].offset.toString();
                            else if (predecessorCollection[count].offset > 0)
                                tem += "+" + predecessorCollection[count].offset.toString();
                        }
                        predecessorString.push(tem);
                }
            }
           
            return predecessorString.join(',');
        },
        //get the parentItem of selected ganttRecord to perform the indent operation
        
        getParentItem:function(ganttRecord,level) {

            var proxy = this;

            if (ganttRecord.parentItem.level === level)
                return ganttRecord.parentItem;

            return proxy.getParentItem(ganttRecord.parentItem, level);
        },

        //Change the position or index for the outdent element 
        getSubChangeIndex: function (itemLevel, itemIndex, item) {
            var proxy = this, changetoIndex;
            for (var items = 0; items < proxy._updatedGanttRecords.length; items++) {
                if (proxy._updatedGanttRecords[items].level == itemLevel && proxy._updatedGanttRecords[items].index > itemIndex) {
                    if (item.parentItem && proxy._updatedGanttRecords[items].parentItem.taskId == item.parentItem.taskId)
                        changetoIndex = proxy._updatedGanttRecords[items].index;
                    break;
                }
            }
            return changetoIndex;
        },

        //get the next sample level item from 
        _nextSameLevelItem:function(data,totRecords)
        {
            var proxy = this,
                level = data.parentItem.level, dataIndex = totRecords.indexOf(data), nextItem;
            for (i = dataIndex; i < totRecords.length; i++)
            {
                if (level === totRecords[i].level || level > totRecords[i].level) {
                    nextItem = totRecords[i];
                    break;
                }
            }
            return nextItem;
        },
        _sendOutdentRequest: function () {
            var proxy = this,
                model = proxy.model,
                data = proxy.getCurrentData(),
                args = {},
                eveargs = {},
                updateNextItem,
                rowNextItem,
                updateInsertIndex,
                rowInsertIndex,
                dataUpdatedRecordIndex,
                dataRowIndex,
                childDataIndex,
                insertParentItem,
                rowNextItemChildIndex,
                dataChildCount, splicedRows, splicedUpdatedRows,
                dataFlatIndex,
                flatNextItem,
                flatInsertIndex,
                splicedFlatRows,
                treeGridFlatRecords,
                isFlatRecordChange=false,
                isChangeUpdatedRecords=true,
                treegridobj = proxy._$treegridHelper.ejTreeGrid("instance");

            if (ej.isNullOrUndefined(data)) {
                alert("There is no gantt Record was not selected to perform the Outdent ");
            } else {
                args.data = data;
                args.requestType = "actionBegin";
                if (!proxy._trigger("actionBegin", args)) {

                    if (data.level === 0)
                        return;
                    else {
                        proxy._updatedGanttRecords = proxy.getUpdatedRecords();
                        //find where to insert data
                        updateNextItem = proxy._nextSameLevelItem(data, proxy._updatedGanttRecords);
                        rowNextItem = proxy._nextSameLevelItem(data, proxy._rows);
                        dataUpdatedRecordIndex = proxy._updatedGanttRecords.indexOf(data);
                        dataRowIndex = proxy._rows.indexOf(data);
                        treeGridFlatRecords = treegridobj.model.flatRecords;

                        //find postion of data in flat records
                        if (treeGridFlatRecords !== proxy._updatedGanttRecords) {
                            dataFlatIndex = treeGridFlatRecords.indexOf(data);
                            flatNextItem = proxy._nextSameLevelItem(data, treeGridFlatRecords);
                            isFlatRecordChange = true;
                        }
                        //find child index of record in parentItem
                        childDataIndex = data.parentItem.childRecords.indexOf(data);
                        insertParentItem = data.parentItem.parentItem;
                        rowNextItemChildIndex = insertParentItem && data.parentItem.parentItem.childRecords.indexOf(rowNextItem);

                        //remove data from current parent item
                        data.parentItem.childRecords.splice(childDataIndex, 1);

                        if(!model.parentTaskIdMapping)
                            data.parentItem.item[model.childMapping].splice(childDataIndex, 1);

                        if (data.parentItem.childRecords.length == 0) {

                            data.parentItem.childRecords = null;
                            data.parentItem.expanded = false;
                            data.parentItem.hasChildRecords = false;
                        }
                        else
                        {
                            proxy._updateParentItem(data.parentItem.childRecords[0]);
                        }

                        //add to next parent item
                        if (insertParentItem) {
                            insertParentItem.childRecords.splice(rowNextItemChildIndex, 0, data);
                            if (!model.parentTaskIdMapping)
                                insertParentItem.item[model.childMapping].splice(rowNextItemChildIndex, 0, data.item);
                            data.parentItem = insertParentItem;
                        } else {

                            if (this.dataSource() instanceof ej.DataManager) {
                                if (this.dataSource().dataSource.offline && this.dataSource().dataSource.json) {
                                    if (!model.parentTaskIdMapping)
                                        this.dataSource().dataSource.json.push(data.item);
                                }
                            } else {
                                if (!model.parentTaskIdMapping)
                                    this.dataSource().push(data.item);
                            }
                            data.parentItem = null;
                        }
                        //set value to need to updated the _updatedRecord collections
                        if (treegridobj.model.sortSettings.sortedColumns.length > 0 || (treegridobj.model.allowSearching && treegridobj._searchString.length > 0)) {
                            isChangeUpdatedRecords = false
                        }

                        //Records updates _rows collections
                        dataChildCount = proxy._$treegridHelper.ejTreeGrid("getChildCount", data, 0);
                        splicedRows = proxy._rows.splice(dataRowIndex, dataChildCount + 1);
                        splicedIds = proxy._ids.splice(dataRowIndex, dataChildCount + 1);

                        //Records updates _updatedGanttRecords collections
                        if (isChangeUpdatedRecords) {
                            if ((model.enableVirtualization && data.expanded) || !model.enableVirtualization)
                                splicedUpdatedRows = proxy._updatedGanttRecords.splice(dataUpdatedRecordIndex, dataChildCount + 1);
                            else
                                splicedUpdatedRows = proxy._updatedGanttRecords.splice(dataUpdatedRecordIndex, 1);
                        }

                        //Record update flatrecords
                        if (isFlatRecordChange) {
                            if ((model.enableVirtualization && data.expanded) || !model.enableVirtualization)
                                splicedFlatRows = treeGridFlatRecords.splice(dataFlatIndex, dataChildCount + 1);
                            else
                                splicedFlatRows = treeGridFlatRecords.splice(dataFlatIndex, 1);
                        }

                        if (rowNextItem) {
                            updateInsertIndex = proxy._updatedGanttRecords.indexOf(updateNextItem);
                            rowInsertIndex = proxy._rows.indexOf(rowNextItem);
                            flatInsertIndex = treeGridFlatRecords.indexOf(rowNextItem);
                            //change the position of records in _rows collections
                        }
                        else {
                            updateInsertIndex = proxy._updatedGanttRecords.length;
                            rowInsertIndex = proxy._rows.length;
                            flatInsertIndex = treeGridFlatRecords.length;
                        }

                        if (data.hasChildRecords && data.childRecords.length > 0) {

                            for (i = 0; i < splicedRows.length; i++) {
                                proxy._rows.splice(rowInsertIndex, 0, splicedRows[i]);
                                proxy._ids.splice(rowInsertIndex, 0, splicedIds[i]);
                                splicedRows[i].level -= 1;
                                rowInsertIndex++;
                            }

                            //insert into updated records
                            if (isChangeUpdatedRecords) {
                                if ((model.enableVirtualization && data.expanded) || !model.enableVirtualization) {
                                    for (i = 0; i < splicedUpdatedRows.length; i++) {
                                        proxy._updatedGanttRecords.splice(updateInsertIndex, 0, splicedUpdatedRows[i]);
                                        updateInsertIndex++;
                                    }
                                } else {
                                    proxy._updatedGanttRecords.splice(updateInsertIndex, 0, data);
                                }
                            }
                            //insert into flat records collection
                            if (isFlatRecordChange) {
                                if ((model.enableVirtualization && data.expanded) || !model.enableVirtualization) {
                                    for (i = 0; i < splicedFlatRows.length; i++) {
                                        treeGridFlatRecords.splice(flatInsertIndex, 0, splicedFlatRows[i]);
                                        flatInsertIndex++;
                                    }
                                } else {
                                    treeGridFlatRecords.splice(flatInsertIndex, 0, data);
                                }
                            }
                        }
                        else {
                            proxy._rows.splice(rowInsertIndex, 0, splicedRows[0]);
                            proxy._ids.splice(rowInsertIndex, 0, splicedIds[0]);
                            splicedRows[0].level -= 1;
                            if (isChangeUpdatedRecords) {
                                proxy._updatedGanttRecords.splice(updateInsertIndex, 0, splicedUpdatedRows[0]);
                            }
                            if (isFlatRecordChange) {
                                treeGridFlatRecords.splice(flatInsertIndex, 0, splicedFlatRows[0]);
                            }
                        }
                        //update parentitem of selected item after changing of its child 
                        if (data.parentItem) {
                            //change the structure of milestone after outdent
                            if (data.parentItem.isMilestone) {
                                data.parentItem.isMilestone = false;
                            }

                            data.parentItem.hasChildRecords && proxy._updateParentItem(data.parentItem.childRecords[0]);
                            //proxy.refreshGanttRecord(data.parentItem);
                        }

                        if (data.hasChildRecords) {
                            proxy._updateParentItem(data.childRecords[0]);
                            data._updateParentProgress(data, model.progressMapping);
                        }

                        //update parent recordsCollections
                        if (data.level === 0) {
                            if (model.parentRecords.indexOf(data) === -1) {
                                model.parentRecords.push(data);
                                treegridobj.model.parentRecords = model.parentRecords;
                            }
                        }

                        //update predecessor
                        if (data.predecessor && data.predecessor.length > 0 && proxy.model.predecessorMapping && data.hasChildRecords) {
                            proxy._updatePredecessorOnIndentOutdent(data)
                        }

                        //Refreshing the Gantt and TreeGrid data
                        treegridobj.model.records = proxy._rows;
                        treegridobj.model.ids = proxy._ids;
                        args.requestType = "outdent";
                        proxy._$treegridHelper.ejTreeGrid("processBindings", args);
                        var tempArgs = {};
                        tempArgs.requestType = ej.TreeGrid.Actions.Refresh;
                        proxy._$treegridHelper.ejTreeGrid("sendDataRenderingRequest", tempArgs);
                        proxy._updatedGanttRecords = proxy.getUpdatedRecords();
                        proxy._currentViewData = proxy.getCurrentViewData();

                        if (proxy.model.predecessorMapping) {
                            proxy._isValidationEnabled = false;
                            proxy._connectorlineIds = [];
                            proxy._connectorLinesCollection = [];
                            proxy._$ganttchartHelper.ejGanttChart("clearConnectorLines");
                            proxy._createConnectorLinesCollection();
                        }
                        proxy._$ganttchartHelper.ejGanttChart("refreshHelper", proxy._currentViewData, proxy._updatedGanttRecords, proxy._totalCollapseRecordCount);
                        proxy._$treegridHelper.ejTreeGrid("refreshHeight");
                        proxy.updateAltRow(proxy._updatedGanttRecords, 0, 1);

                        //   Making the outdented row as selected row 
                        var rowToindex = proxy._updatedGanttRecords.indexOf(data);
                        var $ganttChartRows = proxy.getGanttChartRows();
                        args = {
                            rowElement: $ganttChartRows.eq(rowToindex),
                            data: proxy.model.selectedItem,
                            recordIndex: rowToindex
                        };
                        proxy._$ganttchartHelper.ejGanttChart("selectRows", args.recordIndex);
                        proxy._$treegridHelper.ejTreeGrid("selectRows", args.recordIndex);
                        this.selectedItem(args.data);
                        this.selectedRowIndex(args.recordIndex);
                        proxy.updateIndentOutdentOption(data);
                        eveargs.data = data;
                        eveargs.requestType = "actionComplete";
                        this._trigger("actionComplete", eveargs);
                    }
                }
            }
        },
        
        _refreshChildLevel: function (ganttRecord) {

            var proxy = this,
                count = 0,
                childRecords = ganttRecord.childRecords,
                length = childRecords.length,
                record;

            for (count = 0; count < length; count++) {
                record = childRecords[count];                
                proxy.refreshGanttRecord(record);
                if (record.hasChildRecords) {
                    proxy._refreshChildLevel(record);
                }
            }
        },

        _updateChildLevel:function(ganttRecord) {

            var proxy = this,
                count = 0,
                childRecords = ganttRecord.childRecords,
                length = childRecords.length,
                record;
            
            for (count = 0; count < length; count++) {
                record = childRecords[count];                
                record.level = record.level - 1;
               // proxy.refreshGanttRecord(record);
                if (record.hasChildRecords) {
                    proxy._updateChildLevel(record);
                }
            }
        },

        _removeChildRecords:function(ganttRecord,index){

            if (ganttRecord.parentItem) {
                var proxy = this,
                    model = proxy.model,
                    childIndex = 0,
                    record,
                    addedChildGanttRecordCount = 0,
                    length = 0;
                parentChildRecords = ganttRecord.parentItem.childRecords,
                parentChildRecordsLength = parentChildRecords && parentChildRecords.length;

                for (childIndex = index; childIndex < parentChildRecordsLength; childIndex++) {

                    record = parentChildRecords[childIndex];


                    if (record) {

                        if (ganttRecord.childRecords) {

                            length = ganttRecord.childRecords.length;
                            ganttRecord.childRecords.splice(length, 0, record);
                            if (!model.parentTaskIdMapping)
                                ganttRecord.item[model.childMapping].splice(length, 0, record.item);
                            else
                                record.item[model.parentTaskIdMapping] = ganttRecord.taskId;
                        } else {
                            ganttRecord.childRecords = [];
                            ganttRecord.item[model.childMapping] = [];
                            ganttRecord.childRecords.push(record);
                            if (!model.parentTaskIdMapping)
                                ganttRecord.item[model.childMapping].push(record.item);
                            else
                                record.item[model.parentTaskIdMapping] = ganttRecord.taskId;
                        }
                        record.parentItem = ganttRecord;                                             
                        addedChildGanttRecordCount++;
                    }
                }

                if (ganttRecord.parentItem.childRecords) {

                    ganttRecord.parentItem.childRecords.splice(index, addedChildGanttRecordCount);
                    if(!model.parentTaskIdMapping)
                        ganttRecord.parentItem.item[model.childMapping].splice(index, addedChildGanttRecordCount);
                    if (ganttRecord.parentItem.childRecords.length == 0) {
                        ganttRecord.parentItem.childRecords = null;
                        ganttRecord.parentItem.expanded = false;
                        ganttRecord.parentItem.hasChildRecords = false;
                        proxy.refreshGanttRecord(ganttRecord.parentItem);
                    }
                }
            }
        },

        updateChildGanttRecordLevel: function (data,index) {
            var childIndex = 0, proxy = this, model = proxy.model,
                parentChildRecords = data.parentItem&& data.parentItem.parentItem&& data.parentItem.parentItem.childRecords,
                parentChildRecordsLength =parentChildRecords&&parentChildRecords.length,
                addedChildRecordCount = 0;
            for (childIndex = index; childIndex < parentChildRecordsLength; childIndex++) {
                var childGanttRecord = parentChildRecords[childIndex];
                if (childGanttRecord.childRecords) {
                    childGanttRecord.childRecords.splice(childGanttRecord.childRecords.length, 0, childGanttRecord);
                    childGanttRecord.item[model.childMapping].splice(childGanttRecord.childRecords.length, 0, childGanttRecord.item);
                }
                else {
                    childGanttRecord.childRecords = [];
                    childGanttRecord.item[model.childMapping] = [];
                    if (childGanttRecord) {
                        childGanttRecord.childRecords.push(childGanttRecord);
                        childGanttRecord.item[model.childMapping].push(childGanttRecord.item);
                    }
                }
                proxy.refreshGanttRecord(data.parentItem);
                data.parentItem = childGanttRecord;
                ++addedChildGanttRecordCount;
            }
            data.parentItem.childRecords.splice(index, addedChildGanttRecordCount);
            if (data.parentItem.childRecords.length == 0) {
                data.parentItem.childRecords = null;
                data.parentItem.expanded = false;
                data.parentItem.hasChildRecords = false;
            }

            proxy.refreshGanttRecord(data.parentItem);

        },

        updateLevel: function (childGanttRecord,offset) {
            var proxy = this,
                count = 0,
                childRecords = childGanttRecord.childRecords,
                length =childRecords&& childRecords.length,
                ganttRecord;
            for (count; count < length; count++) {
                ganttRecord = childRecords[count];
                ganttRecord.level += offset;
                proxy.refreshGanttRecord(ganttRecord);
                if (ganttRecord.childRecords) 
                    proxy.updateLevel(ganttRecord, offset);                
            }
        },

        addNewGanttRecord:function() {
            var proxy = this, eventArgs = {},newRecord;
            newRecord = this.model.ganttRecords[this.model.ganttRecords.length].item;
            eventArgs.requestType = "save";
            eventArgs._cAddedRecord = jQuery.extend(true, {}, newRecord);
            eventArgs.recordIndex = index + 1;
            proxy.subContextMenuAction(eventArgs);
            proxy._clearContextMenu();
        },
        getExpandStatus: function (record) {

            var parentRecord = record.parentItem;

            if (parentRecord != null) {

                if (parentRecord.expanded === false) {
                    return false;
                } else if (parentRecord.parentItem) {

                    if (parentRecord.parentItem.expanded === false) {
                        return false;
                    } else {
                        return this.getExpandStatus(parentRecord.parentItem);
                    }

                } else return true;
            } else return true;
        },
        subContextMenuAction: function (args) {
            var proxy = this, eventArgs = {}, model = proxy.model, selectionIndex;
            proxy._updatedGanttRecords = proxy.getUpdatedRecords();
            proxy._currentViewData = proxy.getCurrentViewData();
            proxy._gridRows = proxy.getRows();
            proxy._ganttChartRows = proxy.getGanttChartRows();
            if (args.requestType === "save") {

                if (args._cAddedRecord) {

                    eventArgs.selectedItem = model.selectedItem;

                    args._cAddedRecord.predecessor = null;
                    if (proxy.model.predecessorMapping)
                    args._cAddedRecord.item[model.predecessorMapping] = null;//args._cAddedRecord.item.Predecessor

                    eventArgs.data = args._cAddedRecord.item;
                    if (eventArgs.data.duration === 0)
                    {
                        eventArgs.data.duration = 1;
                    }
                    eventArgs.requestType = ej.TreeGrid.Actions.Save;
                    eventArgs.recordIndex = args.recordIndex;

                    eventArgs._cAddedRecord = proxy._createGanttRecord(eventArgs.data, args._cAddedRecord.level, null);//level
                    eventArgs._cAddedRecord.taskId = proxy._getNewTaskId(eventArgs._cAddedRecord.taskId);
                    var index = proxy._ids.indexOf(eventArgs._cAddedRecord.taskId.toString());
                    proxy._ids.splice(index,1);

                    if(model.taskIdMapping)
                    eventArgs._cAddedRecord.item[model.taskIdMapping] = eventArgs._cAddedRecord.taskId;
                    eventArgs._cAddedRecord.taskName = "New Task " + eventArgs._cAddedRecord.taskId;
                    if (model.taskNameMapping)
                    eventArgs._cAddedRecord.item[model.taskNameMapping] = "New Task " + eventArgs._cAddedRecord.taskId;
                    eventArgs._cAddedRecord.item[model.childMapping] = null;

                    if (args._cAddedRecord.hasChildRecords && args.position==="Below" ) { 
                        eventArgs._cAddedRecord.parentItem = model.selectedItem;
                        eventArgs._cAddedRecord.level = model.selectedItem.level + 1;
                        eventArgs._cAddedRecord.expanded = false;
                    }
                    else if (args._cAddedRecord.hasChildRecords && args.position === "Above") {

                        if (args._cAddedRecord.parentItem)
                        {
                            eventArgs._cAddedRecord.parentItem = args._cAddedRecord.parentItem;
                            eventArgs._cAddedRecord.level = args._cAddedRecord.parentItem.level + 1;
                            eventArgs._cAddedRecord.expanded = false;
                        }
                        else
                        {
                            eventArgs._cAddedRecord.parentItem = null;
                            eventArgs._cAddedRecord.expanded = false;
                        }
                        
                    }
                    else if (!args._cAddedRecord.hasChildRecords && args._cAddedRecord.parentItem) {
                        eventArgs._cAddedRecord.parentItem = args._cAddedRecord.parentItem;
                        eventArgs._cAddedRecord.level = args._cAddedRecord.parentItem.level + 1;
                        eventArgs._cAddedRecord.expanded = false;
                    }
                    else
                    {
                        eventArgs._cAddedRecord.parentItem = null;

                    }
                    //if (eventArgs._cAddedRecord.parentItem && !model.enableVirtualization)
                    //{
                    //    eventArgs._cAddedRecord.isExpanded = eventArgs._cAddedRecord.parentItem.expanded;
                    //}




                    //if (args._cAddedRecord.parentItem) {
                    //    eventArgs._cAddedRecord.parentItem = args._cAddedRecord.parentItem;
                    //    eventArgs._cAddedRecord.parentItem.childRecords.push(eventArgs._cAddedRecord);
                    //}
                    eventArgs._cAddedRecord.hasChildRecords = false;
                    eventArgs._cAddedRecord.childRecords = null;
                    eventArgs._cAddedRecord.index = args.recordIndex;
                    eventArgs._cAddedRecord.isAltRow = (eventArgs._cAddedRecord.index+1) % 2 == 0 ? false : true;
                    eventArgs.actionRequestType = ej.TreeGrid.Actions.ContextMenuAdd;
                    eventArgs.position = args.position;

                    if (!model.enableVirtualization) {
                        eventArgs._cAddedRecord.isExpanded = proxy.getExpandStatus(eventArgs._cAddedRecord);
                        if (!eventArgs._cAddedRecord.isExpanded) {
                            proxy._totalCollapseRecordCount += 1;
                        }
                    }

                    proxy.actionComplete(eventArgs);

                    //proxy._$treegridHelper.ejTreeGrid("renderInitialRecord", eventArgs);
                    //proxy._$treegridHelper.ejTreeGrid("renderRecords", eventArgs);

                    //proxy._$ganttchartHelper.ejGanttChart("reRenderGanttGridLinesTable", 1);
                }
            }
            //proxy._connectorlineIds = [];
            //proxy._connectorLinesCollection = [];
            //proxy._$ganttchartHelper.ejGanttChart("clearConnectorLines");
            //proxy._createConnectorLinesCollection();
            //proxy._ganttActionCompleteTrigger(args);
            selectionIndex = proxy._updatedGanttRecords.indexOf(model.selectedItem);
            //if (args.recordIndex != 0 && eventArgs._cAddedRecord.isExpanded)
            //    selectionIndex = args.recordIndex + 1;
            //else
            //    selectionIndex = args.recordIndex;
            proxy._$treegridHelper.ejTreeGrid("selectRows", selectionIndex);
            proxy._$ganttchartHelper.ejGanttChart("selectRows", selectionIndex);
        },

        _getNewTaskId: function (taskId) {
            var proxy = this, tempTaskId;
            if (proxy._ids.indexOf(taskId.toString()) == -1) {
                              proxy._ids.push(taskId.toString());
                                return taskId;
            } else {
                taskId++;
                tempTaskId = proxy._getNewTaskId(taskId);
                return tempTaskId;
            }
        },

        _getNewTaskIdFordialogEdit: function (taskId) {
            var proxy = this, tempTaskId;
            if (proxy._ids.indexOf(taskId.toString()) == -1) {              
                return taskId == 0 ? 1 : taskId;
            } else {
                taskId++;
                tempTaskId = proxy._getNewTaskIdFordialogEdit(taskId);
                return tempTaskId;
            }
        },
        _updateNewTaskId: function () {
            var proxy = this, model = proxy.model;
            proxy._ids = [];
            $.each(proxy._rows, function (index, value) {
                if (value && value.taskId)
                    proxy._ids.push(value.taskId.toString());
            });
        },
        contextMenuAction: function (args) {
            var proxy = this;
            if (args.requestType == "contextMenuAdd")
                proxy._sendAddRequest();
            if (args.requestType == "contextMenuIndent")
                proxy._sendIndentRequest();
            if (args.requestType == "contextMenuOutdent")
                proxy._sendOutdentRequest();
            if (args.requestType == "contextMenuDelete")
                proxy._$treegridHelper.ejTreeGrid("deleteRow");
            if (args.requestType == "contextMenuTaskDetails")
                proxy._sendEditRequest();
        },

        _renderContextMenu: function (e, index, item) {

            var proxy = this,
                eventArgs = {},
                args = {},
                posx,
				subposx,
                posy,
                contextMenu,
                contextMenuUList,
                subContextMenu,
                subContextMenuUList;
            //Initialize the contextmenu item to avoid duplicates
            //proxy._contextMenuItems = proxy._getContextMenuItems();
            //proxy._subContextMenuItems = proxy._getsubContextMenuItems();
            if (!e) e = window.event;
            if (e.pageX || e.pageY) {
                subposx = posx = e.pageX;
                posy = e.pageY;
            } else if (e.clientX || e.clientY) {
                subposx = posx = e.clientX + document.body.scrollLeft
                    + document.documentElement.scrollLeft;
                posy = e.clientY + document.body.scrollTop
                    + document.documentElement.scrollTop;
            }
            if ($(window).width() < posx + 150) {
                posx = posx - 150;
                subposx = posx - 122;
            }
            else
                subposx = subposx + 152;
            if ($(window).height() < posy + (25*proxy._contextMenuItems.length))
                posy = posy - (25 * proxy._contextMenuItems.length);
            args.requestType = "ContextMenuOpen";
            args.contextMenuItems = proxy._contextMenuItems;
            args.innerContextMenuItems = proxy._subContextMenuItems;
            proxy._trigger("contextMenuOpen", args);
            contextMenu = ej.buildTag("div.e-contextmenu", "", {
                'height': 'auto',
                'width': '150px',
                'position': 'absolute',
                'left': posx + 'px',
                'top': posy + 'px',
                'background-color': '#F0F0F0',
                'border': '1px solid #99bce8',
                'z-index': '10',
            }, {});

            contextMenuUList = ej.buildTag("ul", $.render[proxy._id + "contextMenuTemplate"](args.contextMenuItems), {
                'height': 'auto',
                'width': 'auto',
                'top': '0px',
                'display': 'inline'
            }, {
                'data-icon': false,
                'type': 'none',
                'data-role': 'list-divider'
            });

            subContextMenu = ej.buildTag("div.e-innerContextmenu", "", {
                'height': 'auto',
                'width': '120px',
                'position': 'absolute',
                'left': subposx + 'px',
                'top': (posy + 30) + 'px',
                'background-color': '#F0F0F0',
                'border': '1px solid #99bce8',
                'z-index': '10',
                'visibility': 'hidden',
            }, {});

            subContextMenuUList = ej.buildTag("ul", $.render[proxy._id + "subContextMenuTemplate"](args.innerContextMenuItems), {
                'height': 'auto',
                'width': 'auto',
                'top': '0px',
                'display': 'inline'
            }, {
                'data-icon': false,
                'type': 'none',
                'data-role': 'list-divider'
            });
            contextMenu.append(contextMenuUList);
            $(document.body).append(contextMenu);

            if (args.innerContextMenuItems.length > 0) {
                subContextMenu.append(subContextMenuUList);
                $(document.body).append(subContextMenu);
            }
         


            $(contextMenu).css({ 'height': 'auto' });
            proxy._on(contextMenu, "contextmenu", function (argsE) {
                argsE.preventDefault();
            });

            //click event handlers for contextmenu items and subcontextmenu items

                $('.e-menuitem').click(function () { 
                    var choice = $(this).attr('id');
                    switch (choice) {
                        case "Task":
                            eventArgs.requestType = "contextMenuTaskDetails";
                            proxy.contextMenuAction(eventArgs);
                            proxy._clearContextMenu();
                            break;
                        case "Indent": eventArgs.requestType = "contextMenuIndent";
                            proxy.contextMenuAction(eventArgs);
                            proxy._clearContextMenu();
                            break;
                        case "Outdent": eventArgs.requestType = "contextMenuOutdent";
                            proxy.contextMenuAction(eventArgs);
                            proxy._clearContextMenu();
                            break;
                        case "Delete": eventArgs.requestType = "contextMenuDelete";
                            proxy.contextMenuAction(eventArgs);
                            proxy._clearContextMenu();
                            break;
                        case "Above": eventArgs.requestType = "save";
                            eventArgs._cAddedRecord = jQuery.extend(true, {}, item);
                            eventArgs.recordIndex = index == 0 ? 0 : index;
                            eventArgs.position = "Above";
                            proxy.subContextMenuAction(eventArgs);
                            proxy._clearContextMenu();
                            break;
                        case "Below": eventArgs.requestType = "save";
                            eventArgs._cAddedRecord = jQuery.extend(true, {}, item);
                            eventArgs.recordIndex = index;
                            eventArgs.position = "Below";
                            proxy.subContextMenuAction(eventArgs);
                            proxy._clearContextMenu();
                            break;
                        case "Open":
                            eventArgs.requestType = "contextMenuAdd";
                            proxy.contextMenuAction(eventArgs);
                            proxy._clearContextMenu();
                            break;
                        case "Add":
                            proxy._setInitialData();
                            break;
                        default:
                            proxy._clearContextMenu();
                            break;
                    }
                });
            //Mouseenter and mouse leave handler for contextmenu items and Subcontextmenuitems
                $(".e-menuitem").mouseenter(function () {
                    $(this).addClass("e-contextmenu-mouseover");
                    if ($(this).attr('id') == "Add" || $(this).attr('id') == "Above" || $(this).attr('id') == "Below" || $(this).attr('id') == "Open") {
                        $('.e-innerContextmenu').css({ 'visibility': 'visible' });
                        $('#Add').addClass("e-contextmenu-mouseover");
                    }
                    else {
                        $('.e-innerContextmenu').css({ 'visibility': 'hidden' });
                    }
                });
                $(".e-menuitem").mouseleave(function () {
                    $(this).removeClass("e-contextmenu-mouseover");
                });
            e.preventDefault();
        },

        _setInitialData: function () {
            var eventArgs = {}, proxy = this,
                model = proxy.model, data = [], item, initialData = {};
            proxy._ids = [];
            initialData[model.startDateMapping] = model.scheduleStartDate ? model.scheduleStartDate : null;
            initialData[model.durationMapping] = 5;
            initialData[model.taskNameMapping] = "New Task 1";
            initialData[model.taskIdMapping] = "1";
            data.push(initialData);

            if (proxy.dataSource()==null || proxy.dataSource().length == 0) {
                //proxy._createGanttRecords(data);
                item = proxy._createGanttRecord(data[0], 0, null);
                item.index = 0;
                eventArgs.requestType = "save";
                eventArgs._cAddedRecord = jQuery.extend(true, {}, item);
                eventArgs.recordIndex = 0;
                proxy.actionComplete(eventArgs);
                proxy._clearContextMenu();
            }
        },

        sendExpandCollapseRequest: function (args) {
            
            var proxy = this,
                ganttRecord = args.data,
                model = proxy.model,
                index = proxy._currentViewData.indexOf(ganttRecord),
                $row = $($(proxy._gridRows)[index]),
                height = 0,
                isModified = ganttRecord.expanded !== args.expanded;
           
            if (args.expanded) {
                ganttRecord.expanded = args.expanded;
                proxy._expandedRecordsCount = 0;
                proxy.expandGanttRecord(ganttRecord, args.expanded, args);
                if (isModified)
                    proxy._totalCollapseRecordCount -= proxy._expandedRecordsCount;
                //$row.find(".e-treegridcollapse").removeClass('e-treegridcollapse').addClass('e-treegridexpand');
                //$row.removeClass('e-treegridrowcollapse').addClass('e-treegridrowexpand');                
                if (model.enableAltRow)
                    proxy.updateAltRow(ganttRecord, index, 1);
                
            }
            else {
                proxy._collapsedRecordCount = 0;
                proxy.collapseGanttRecord(ganttRecord, args.expanded);
                if (isModified)
                    proxy._totalCollapseRecordCount += proxy._collapsedRecordCount;
                ganttRecord.expanded = args.expanded;
                $row.find(".e-treegridexpand").removeClass('e-treegridexpand').addClass('e-treegridcollapse');
                $row.removeClass('e-treegridrowexpand').addClass('e-treegridrowcollapse');               
                    
                if (model.enableAltRow)
                    proxy.updateAltRow(ganttRecord, index, proxy._collapsedRecordCount + 1);                
            }
            height = (proxy._updatedGanttRecords.length - proxy._totalCollapseRecordCount) * model.rowHeight;
            proxy._$ganttchart.ejGanttChart("updateHeight", height);
            if (args.expanded)
                proxy._trigger("expanded", args);
            else
                proxy._trigger("collapsed", args);
        },

        expandGanttRecord: function (ganttRecord, expanded, args) {
            
            var proxy = this,
                rowClassName = ".gridrowtaskId" + ganttRecord.taskId.toString() + "level" + (ganttRecord.level + 1).toString(),
                $rows = $(rowClassName),
                count = 0,
                length = $rows.length,
                row,
                index,
                record,
                $expandedRows = $(rowClassName),
                index = proxy._currentViewData.indexOf(ganttRecord),
                $row = $($(proxy._gridRows)[index]);

            if (ganttRecord.hasChildRecords && ganttRecord.childRecords.length > 0) {
                $row.find(".e-treegridcollapse").removeClass('e-treegridcollapse').addClass('e-treegridexpand');
                $row.removeClass('e-treegridrowcollapse').addClass('e-treegridrowexpand');
            }
          
            proxy._expandedRecordsCount += $expandedRows.length / 2;
            if ($expandedRows.length === 0) {
                if (proxy.model.allowSearching && proxy._searchString.length>0) {
                    args && proxy._$treegridHelper.ejTreeGrid("sendExpandCollapseRequest", args);
                }
            }

            $expandedRows.css({ 'display': 'table-row' });
            proxy.updateConnectorLines($expandedRows, expanded);
            for (count; count < length / 2; count++) {
                row = $rows[count];
                index = $(proxy._gridRows).index(row);
                if (index !== -1) {
                    record = proxy._updatedGanttRecords[index];
                    record.isExpanded = true;
                    if (record.expanded)
                        proxy.expandGanttRecord(record, expanded);
                }
            }
        },

        updateConnectorLines: function ($gridRows, expanded) {
            var proxy = this,
                length = $gridRows.length / 2,
                count = 0,
                row,
                index,
                record;
            
            for (count = 0; count < length; count++) {
                row = $gridRows[count];
                index = $(proxy._gridRows).index(row);
                if (index !== -1) {
                    record = proxy._currentViewData[index];
                    record.isExpanded = expanded;                  
                }
            }
            proxy._connectorlineIds = [];
            proxy._connectorLinesCollection = [];
            proxy._$ganttchartHelper.ejGanttChart("clearConnectorLines");
            proxy._createConnectorLinesCollection();            
        },

        collapseGanttRecord: function (ganttRecord, expanded) {
            var proxy = this,
                rowClassName = ".gridrowtaskId" + ganttRecord.taskId.toString() + "level" + (ganttRecord.level + 1).toString(),
                $rows = $(rowClassName),
                count = 0,
                length = $rows.length,
                row,
                index,
                record,
                $collapsedRows = $(rowClassName);
            proxy._collapsedRecordCount += $collapsedRows.length / 2;
            $collapsedRows.css({ 'display': 'none' });

            proxy.updateConnectorLines($collapsedRows, expanded);

            for (count; count < length / 2; count++) {
                row = $rows[count];
                index = $(proxy._gridRows).index(row);
                //if (index === -1) {
                //    index = $(proxy._ganttChartRows).index($rows[count + $collapsedRows.length / 2]);
                //    $(row).addClass('e-hide');
                //}
                if (index !== -1) {
                    record = proxy.getUpdatedRecords()[index];
                    if (record.expanded)
                        proxy.collapseGanttRecord(record, expanded);
                }
            }
        },

        updateAltRow: function (ganttRecord, recordIndex, offset) {
            var proxy = this,
                count = 0,
                currentViewData = proxy._currentViewData,
                length = currentViewData.length,
                isAltRow = ganttRecord.isAltRow,
                record,
                $gridRows = $(proxy._gridRows);
            for (count = recordIndex + offset; count < length; count++) {
                if ($($gridRows[count]).css('display') === "none")
                    continue;
                record = currentViewData[count];
                record.isAltRow = !isAltRow;
                isAltRow = record.isAltRow;
                if (isAltRow)
                    $($gridRows[count]).addClass('e-alt-row');
                else
                    $($gridRows[count]).removeClass('e-alt-row');
            }
        },
        renderedEditDialog: function (args) {
            var proxy = this;
            switch (args.requestType) {
                case ej.TreeGrid.Actions.Add:
                    var temp = document.createElement('div');
                    $(temp).addClass("e-addedrow");
                    temp.innerHTML = $.render[proxy._id + "_JSONDialogAddingTemplate"](args.data);
                    $("#" + proxy._id + "_dialogAdd").html($(temp));
                    var evntArgs = {};
                    evntArgs.cssClass = this.model.cssClass,
                    evntArgs.enableModal = true,
                    evntArgs.width = "auto",
                    evntArgs.enableResize = false,
                    evntArgs.contentSelector = "#" + proxy._id,
                    evntArgs.rtl = proxy.model.rtl,
                    evntArgs.allowKeyboardNavigation = false,
                    title = proxy._editDialogTexts["addFormTitle"];
                    evntArgs.title = title;
                    $("#" + proxy._id + "_dialogAdd").ejDialog(evntArgs);
                    $("#" + proxy._id + "_dialogAdd").ejDialog("open");
                    proxy._editedDialogRecord = null;
                    break;
                case ej.TreeGrid.Actions.BeginEdit:
                    temp = document.createElement('div');
                    $(temp).addClass("e-editedrow");
                    temp.innerHTML = $.render[proxy._id + "_JSONDialogEditingTemplate"](args.data);
                    $("#" + proxy._id + "_dialogEdit").html($(temp));
                    var evntArgs = {};
                    evntArgs.cssClass = proxy.model.cssClass;
                    evntArgs.rtl = model.rtl;
                    evntArgs.width = "auto";
                    evntArgs.enableResize = false;
                    evntArgs.contentSelector = "#" + proxy._id;
                    evntArgs.enableModal = true;
                    evntArgs.allowKeyboardNavigation = false;
                    var title = proxy._editDialogTexts["editFormTitle"] + " " + proxy.selectedItem()["taskName"];
                    evntArgs.title = title;
                    $("#" + proxy._id + "_dialogEdit").ejDialog(evntArgs);
                    $("#" + proxy._id + "_dialogEdit").ejDialog("open");
                    proxy._editedDialogRecord=jQuery.extend(true, {}, this.selectedItem());
                    break;                    
            }
            proxy._refreshEditForm(args);
            //proxy.setValidation();
        },

        editFormValidate: function () {
            if ($.isFunction($.validator))
                return $("#" + this._id + "EditForm").validate().form();
            return true;
        },

        addFormValidate: function () {
            if ($.isFunction($.validator))
                return $("#" + this._id + "AddForm").validate().form();
            return true;
        },
        getCurrentData: function () {
            var proxy = this,
                updatedRecords = proxy.getUpdatedRecords();
            return updatedRecords && updatedRecords[this.selectedRowIndex()];
        },

        getCurrentViewData: function () {
            return this._$treegridHelper.ejTreeGrid("getCurrentViewData");
        },

        getUpdatedCurrentViewData: function () {
            return this._$treegridHelper.ejTreeGrid("getUpdatedCurrentViewData");
        },

        getRows: function () {
            return this._$treegridHelper.ejTreeGrid("getRows");
        },
        
        getGanttChartRows: function() {
            return this._$ganttchartHelper.ejGanttChart("getGanttChartRows");
        },

        getUpdatedRecords: function () {
            return this._$treegridHelper.ejTreeGrid("getUpdatedRecords");
        },

        _getToolBarHeight: function () {
            var toolbarH = 0;
            if (this.model.toolbarSettings.showToolbar) {
                toolbarH = $(".e-gantttoolbar").height();
            }
            return toolbarH;
        },

        _initValidator: function () {
            var gridObject = this;
            $("#" + this._id + "EditForm").validate({
                errorClass: 'e-field-validation-error',
                errorElement: 'div',
                wrapper: "div",
                errorPlacement: function (error, element) {
                    var $td = element.closest("td"), $container = $(error).addClass("e-error")
                    , $tail = ej.buildTag("div.e-errortail e-toparrow");
                    $td.find(".e-error").remove();
                    element.hasClass("e-numerictextbox") ? $container.insertAfter(element.closest(".e-numeric")) : $container.insertAfter(element);
                    $container.prepend($tail);
                    gridObject.model.editSettings.editMode != "normal" && $container.offset({ left: element.offset().left });
                    $container.fadeIn("slow");
                },

            });
        },

        setValidation: function () {
            this._initValidator();
            for (var i = 0; i < this._columns.length; i++) {
                if (!ej.isNullOrUndefined(this._columns[i]["validationRules"])) {
                    this.setValidationToField(this._columns[i].field, this._columns[i].validationRules);
                }
            }
        },

        setValidationToField: function (name, rules) {
            var ele = $("#" + this._id + name).length > 0 ? $("#" + this._id + name) : $("#" + name);
            ele.rules("add", rules);
            var validator = $("#" + this._id + "EditForm").validate();
            if (!ej.isNullOrUndefined(rules["required"])) {
                validator.settings.messages["Name"] = {};
                validator.settings.messages["Name"]["required"] = ej.TreeGrid.getColumnByField(proxy._columns, name).headerText + " is required";
            }
        },

        _createConnectorLinesCollection: function (args) {

            var proxy = this,
                recordLength = proxy._currentViewData.length,
                count,
                prdecessorIndex = -1,
                predecessorsCollection,
                ganttRecord,
                connectorLinesCollection = proxy._predecessorsCollection,
                connectorLinesLength = connectorLinesCollection.length,
                x = connectorLinesLength / 2,
                connectorLinesCount,
                enableVirtualization = proxy.model.enableVirtualization,
                record;


            if (model.enableVirtualization && args === "Load") {
                //THis is done for validate all the record during load time
                recordLength = proxy._updatedGanttRecords.length;
                for (count = 0; count < recordLength; count++) {
                    ganttRecord = proxy._updatedGanttRecords[count];
                        predecessorsCollection = ganttRecord["predecessor"];
                        if (predecessorsCollection) {
                            record = ganttRecord;
                            proxy._addPredecessorsCollection(ganttRecord, predecessorsCollection);
                        }
                }
            }
            else {

                for (count = 0; count < recordLength; count++) {
                    ganttRecord = proxy._currentViewData[count];
                    if (enableVirtualization === false && ganttRecord.isExpanded === false)
                        continue;
                    if (proxy._currentViewData.indexOf(ganttRecord) !== -1) {
                        predecessorsCollection = ganttRecord["predecessor"];
                        if (predecessorsCollection) {
                            record = ganttRecord;
                            proxy._addPredecessorsCollection(ganttRecord, predecessorsCollection);
                        }
                    }
                }

            }

            if (proxy._connectorLinesCollection.length > 0) {

                proxy._$ganttchartHelper && proxy._$ganttchartHelper.ejGanttChart("renderConnectorLines", proxy._connectorLinesCollection);

            }
        },

        _addPredecessorsCollection: function (ganttRecord, predecessorsCollection) {
            var proxy = this,
                predecessorsLength,
                predecessorCount,
                predecessor,
                parentGanttRecord,
                childGanttRecord,
                model = proxy.model,
                connectorObj = {},
                predecessorValue = [];
            if (predecessorsCollection) {

                predecessorsLength = predecessorsCollection.length;

                for (predecessorCount = 0; predecessorCount < predecessorsLength; predecessorCount++) {

                    predecessor = predecessorsCollection[predecessorCount];


                        parentGanttRecord = proxy._rows[proxy._ids.indexOf(predecessor.from)];  
                        childGanttRecord = proxy._rows[proxy._ids.indexOf(predecessor.to)];  

                        if (!model.enableVirtualization) {
                            if ((parentGanttRecord && parentGanttRecord.isExpanded === false) || 
                                (childGanttRecord && childGanttRecord.isExpanded === false))
                                continue;
                        }

                        if (proxy._isValidationEnabled && !proxy._isInExpandCollapse && childGanttRecord)
                            proxy._validateChildGanttRecord(parentGanttRecord, childGanttRecord, predecessor);
                }

                //for calculate auto schedule only validation is enough  
                if (!proxy._enableCreateCollection)
                    return;

				// for correct re draw the alreadey created line in multiple predecessor for same task
                var count = 0;
                 $.each(predecessorsCollection, function (inx, value) {

                    if (value.to === ganttRecord.taskId.toString()) {
                        count++;
                    }
                    return count;
                });
				
				
				
                    for (predecessorCount = 0; predecessorCount < predecessorsLength; predecessorCount++) {

                        predecessor = predecessorsCollection[predecessorCount];
						if (count > 1)
                        {
                            predecessor.isdrawn = false;
                        }
						
                        //if (predecessor.isdrawn) {
                        //    predecessor.isdrawn = false;
                        //}
                        //else {

                            parentGanttRecord = proxy._rows[proxy._ids.indexOf(predecessor.from)];
                            childGanttRecord = proxy._rows[proxy._ids.indexOf(predecessor.to)];

                            if (proxy._updatedGanttRecords.indexOf(parentGanttRecord) === -1 || proxy._updatedGanttRecords.indexOf(childGanttRecord) == -1)
                                continue;

                            if (!model.enableVirtualization) {
                                if (parentGanttRecord.isExpanded === false || childGanttRecord.isExpanded === false)
                                    continue;
                            }

                            //if (proxy._isValidationEnabled && !proxy._isInExpandCollapse)
                            //    proxy._validateChildGanttRecord(parentGanttRecord, childGanttRecord, predecessor);

                        if (parentGanttRecord && childGanttRecord) {

                            connectorObj = proxy._createConnectorLineObject(parentGanttRecord, childGanttRecord, predecessor);
                          
                            if (connectorObj) {

                                if (proxy._connectorlineIds.length > 0 && proxy._connectorlineIds.indexOf(connectorObj.ConnectorLineId) == -1) {

                                    proxy._connectorLinesCollection.push(connectorObj);
                                    proxy._connectorlineIds.push(connectorObj.ConnectorLineId);
                                }
                                else if (proxy._connectorlineIds.length == 0) {
                                    proxy._connectorLinesCollection.push(connectorObj);
                                    proxy._connectorlineIds.push(connectorObj.ConnectorLineId);
                                }
                                else if (proxy._connectorlineIds.indexOf(connectorObj.ConnectorLineId) != -1) {
                                    var index = proxy._connectorlineIds.indexOf(connectorObj.ConnectorLineId);
                                    proxy._connectorLinesCollection[index] = connectorObj;
                                }
                                predecessor.isdrawn = true;
                            }
                        }
                   // }
                }

            }
          
        },

        _createConnectorLineObject: function (parentGanttRecord, childGanttRecord, predecessor) {
            var connectorObj = {},
                proxy = this,
                model = proxy.model,
                parentTop,
                childTop,
                parentIndex = proxy._updatedGanttRecords.indexOf(parentGanttRecord),
                childIndex = proxy._updatedGanttRecords.indexOf(childGanttRecord),
                count = 0,
                index = 0;
            
            if (parentIndex === -1 || childIndex === -1){
                return;
            }
            if (!model.enableVirtualization) {
                var collapsedCount = 0;
                if (childIndex > parentIndex) {
                    
                    for (count = 0; count < parentIndex; count++) {
                        if (proxy._updatedGanttRecords[count].isExpanded===false)
                            ++collapsedCount;
                    }
                    index = parentIndex;
                    parentIndex -= collapsedCount;
                    
                    for (index; index < childIndex; index++) {
                        if (proxy._updatedGanttRecords[index].isExpanded === false)
                            ++collapsedCount;
                    }
                    childIndex -= collapsedCount;
                }
                else if (parentIndex > childIndex) {
                    for (count = 0; count < childIndex; count++) {
                        if (proxy._updatedGanttRecords[count].isExpanded === false)
                            ++collapsedCount;
                    }
                    index = childIndex;
                    childIndex -= collapsedCount;
                    
                    for (index ; index < parentIndex; index++) {
                        if (proxy._updatedGanttRecords[index].isExpanded === false)
                            ++collapsedCount;
                    }
                    parentIndex -= collapsedCount;
                }
            }

            if (parentIndex != -1 && childIndex != -1) {
                parentTop = parentIndex * model.rowHeight;
                childTop = childIndex * model.rowHeight;
                connectorObj["ParentLeft"] = parentGanttRecord['left'];
                connectorObj["ChildLeft"] = childGanttRecord['left'];
                connectorObj["ParentWidth"] = parentGanttRecord['width'] == 0 ? 26 : parentGanttRecord['width'];
                connectorObj["ChildWidth"] = childGanttRecord['width'] == 0 ? 26 : childGanttRecord['width'];
                connectorObj["ParentTop"] = parentTop;
                connectorObj["ChildTop"] = childTop;
                connectorObj["Height"] = parentTop > childTop ? parentTop - childTop : childTop - parentTop;
                connectorObj["Type"] = predecessor.predecessorsType;
                connectorObj["ConnectorLineId"] = "parent"+ parentGanttRecord['taskId'] + "child" + childGanttRecord['taskId'];                
                connectorObj["milestoneParent"] = parentGanttRecord.isMilestone ? true : false;
                connectorObj["milestoneChild"] = childGanttRecord.isMilestone ? true : false;
                
                return connectorObj;
            }
        },

        //Validate the child Gantt Record

        _validateChildGanttRecord: function (parentGanttRecord, childGanttRecord, predecessor) {
            var proxy = this,
                model = proxy.model,
                childStartDate,
                parentStartDate,
                childEndDate,
                parentEndDate,
                offset,holiday
                predecessorOffset = 0;
                predecessorOffset = predecessor.offset ? parseInt(predecessor.offset) : 0;

                if (proxy._editedTaskBarItem === childGanttRecord)
                {
                    return;
                }
            switch (predecessor.predecessorsType) {

                case 'SS':

                    parentStartDate = proxy._getDateFromFormat(parentGanttRecord.startDate);
                    childStartDate = proxy._getDateFromFormat(childGanttRecord.startDate);

                        if (childGanttRecord.isMilestone) {
                            parentStartDate.setDate(parentStartDate.getDate() - 1);
                        }

                        if (proxy.model.includeWeekend === false) {
                            proxy._setBeforeWeekend(parentStartDate);
                        }

                        if (predecessorOffset) {

                            parentStartDate.setDate(parentStartDate.getDate() + (Math.floor(predecessorOffset)));

                            if (proxy.model.includeWeekend === false) {

                                if (predecessorOffset < 0) {
                                    proxy._setBeforeWeekend(parentStartDate);
                                }

                                if (predecessorOffset > 0) {
                                    proxy._setAfterWeekend(parentStartDate);
                                }
                            }
                        }

                        if (proxy._stringHolidays &&
                          proxy._stringHolidays.indexOf(childGanttRecord._getFormatedDate(parentStartDate, model.dateFormat)) != -1) {
                            parentStartDate.setDate(parentStartDate.getDate() + 1);
                        }

                        childGanttRecord.startDate = childGanttRecord._getFormatedDate(parentStartDate, model.dateFormat);

                            var currentTaskId = childGanttRecord['taskId'].toString(),
                                 predecessorsCollection = childGanttRecord['predecessor'],
                               childPredecessor = predecessorsCollection.filter(function (data) { return data.to === currentTaskId });

                            if (childPredecessor.length > 1) {

                                var minStartDate = proxy._getPredecessorDate(childGanttRecord, childPredecessor, predecessor.predecessorsType);


                                if (childGanttRecord.isMilestone) {
                                    minStartDate.setDate(minStartDate.getDate() - 1);
                                }

                                if (model.includeWeekend === false) {
                                    proxy._setBeforeWeekend(minStartDate);
                                }
                                childGanttRecord.startDate = childGanttRecord._getFormatedDate(minStartDate, model.dateFormat);

                            }
                            childGanttRecord.left = childGanttRecord._calculateLeft(proxy._projectStartDate,
                                    proxy._perDayWidth, proxy._holidaysList, model);
                        childGanttRecord.width = childGanttRecord._calculateWidth(proxy._perDayWidth, proxy._holidaysList, model);
                    break;

                case 'SF':

                    parentStartDate = proxy._getDateFromFormat(parentGanttRecord.startDate);
                    childEndDate = proxy._getDateFromFormat(childGanttRecord.endDate);                    

                        parentStartDate.setDate(parentStartDate.getDate() - 1);

                        if (proxy.model.includeWeekend === false) {
                            proxy._setBeforeWeekend(parentStartDate);
                        }

                        if (predecessorOffset) {

                            parentStartDate.setDate(parentStartDate.getDate() + (Math.floor(predecessorOffset)));

                            if (proxy.model.includeWeekend === false) {

                                if (predecessorOffset < 0) {
                                    proxy._setBeforeWeekend(parentStartDate);
                                }

                                if (predecessorOffset > 0) {
                                    proxy._setAfterWeekend(parentStartDate);
                                }
                            }
                        }


                        if (proxy._stringHolidays &&
                            proxy._stringHolidays.indexOf(childGanttRecord._getFormatedDate(parentStartDate, model.dateFormat)) != -1) {
                            parentStartDate.setDate(parentStartDate.getDate() + 1);
                        }

                        childGanttRecord.endDate = childGanttRecord._getFormatedDate(parentStartDate, model.dateFormat);

                        if (childGanttRecord.isMilestone)
                            childGanttRecord.startDate = childGanttRecord._getFormatedDate(parentStartDate, model.dateFormat);
                        else
                        {
                            var tempEndDate = proxy._getDateFromFormat(childGanttRecord.endDate);
                            for(var i=0;i<childGanttRecord.duration-1;i++)
                            {
                                tempEndDate.setDate(tempEndDate.getDate() - 1);
                                if (proxy.model.includeWeekend === false) {
                                    if (predecessorOffset < 0) {
                                        proxy._setBeforeWeekend(tempEndDate);
                                    }
                                }
                                tempEndDate=proxy._onHoliDayCheckBefore(tempEndDate);
                            }
                            childGanttRecord.startDate = childGanttRecord._getFormatedDate(tempEndDate, model.dateFormat);
                        }
                            var currentTaskId = childGanttRecord['taskId'].toString(),
                                       predecessorsCollection = childGanttRecord['predecessor'],
                                     childPredecessor = predecessorsCollection.filter(function (data) { return data.to === currentTaskId });

                            if (childPredecessor.length > 0) {

                                var minStartDate = proxy._getPredecessorDate(childGanttRecord, childPredecessor, predecessor.predecessorsType);

                                minStartDate.setDate(minStartDate.getDate() - 1);

                                if (proxy.model.includeWeekend === false) {
                                    proxy._setBeforeWeekend(minStartDate);
                                }

                                childGanttRecord.endDate = childGanttRecord._getFormatedDate(minStartDate, model.dateFormat);
                                if (childGanttRecord.isMilestone)
                                    childGanttRecord.startDate = childGanttRecord._getFormatedDate(minStartDate, model.dateFormat);
                                else {
                                    var tempEndDate = proxy._getDateFromFormat(childGanttRecord.endDate);
                                    for (var i = 0; i < childGanttRecord.duration - 1; i++) {
                                        tempEndDate.setDate(tempEndDate.getDate() - 1);
                                        if (proxy.model.includeWeekend === false) {
                                            if (predecessorOffset < 0) {
                                                proxy._setBeforeWeekend(tempEndDate);
                                            }
                                        }
                                        tempEndDate = proxy._onHoliDayCheckBefore(tempEndDate);
                                    }
                                    childGanttRecord.startDate = childGanttRecord._getFormatedDate(tempEndDate, model.dateFormat);
                                }
                            }
                            childGanttRecord.left = childGanttRecord._calculateLeft(proxy._projectStartDate, proxy._perDayWidth, proxy._holidaysList, model);
                        childGanttRecord.width = childGanttRecord._calculateWidth(proxy._perDayWidth, proxy._holidaysList, model);

                    break;

                case 'FS':

                    parentEndDate = proxy._getDateFromFormat(parentGanttRecord.endDate);
                    childStartDate = proxy._getDateFromFormat(childGanttRecord.startDate);

                        if (!childGanttRecord.isMilestone) {
                            parentEndDate.setDate(parentEndDate.getDate() + 1);
                        }

                        if (predecessorOffset < 0) {
                            predecessorOffset *= -1;
                            offset = -1;
                            if (model.includeWeekend === false) {
                                proxy._setBeforeWeekend(parentEndDate);
                            }
                        } else {

                            if (model.includeWeekend === false) {
                                proxy._setAfterWeekend(parentEndDate);
                            }
                            offset = 1;
                        }


                        if (predecessorOffset) {

                            for (var i = 0; i < predecessorOffset; i++) {

                                if (proxy.model.includeWeekend === false) {
                                    if (offset < 0) {
                                        proxy._setBeforeWeekend(parentEndDate);
                                    }

                                    if (offset > 0) {
                                        proxy._setAfterWeekend(parentEndDate);
                                    }
                                }
                                parentEndDate.setDate(parentEndDate.getDate() + offset);
                            }

                            if (proxy.model.includeWeekend === false) {
                                proxy._setAfterWeekend(parentEndDate);
                            }
                        }

                        if (proxy._stringHolidays &&
                            proxy._stringHolidays.indexOf(childGanttRecord._getFormatedDate(parentEndDate, model.dateFormat)) != -1) {
                            parentEndDate.setDate(parentEndDate.getDate() + 1);
                        }

                        childGanttRecord.startDate = childGanttRecord._getFormatedDate(parentEndDate, model.dateFormat);

                        if (proxy._editedTaskBarItem!==childGanttRecord) {
                            var predecessorsCollection = childGanttRecord['predecessor'],
                                currentTaskId = childGanttRecord['taskId'].toString(),
                                childPredecessor = predecessorsCollection&&predecessorsCollection.filter(function (data) { return data.to === currentTaskId });

                            if (childPredecessor && childPredecessor.length > 1 && offset>0) {

                                var maxEndDate = proxy._getPredecessorDate(childGanttRecord, childPredecessor, predecessor.predecessorsType);

                                if (!childGanttRecord.isMilestone) {
                                    maxEndDate.setDate(maxEndDate.getDate() + 1);
                                }

                                if (model.includeWeekend === false) {
                                    proxy._setAfterWeekend(maxEndDate);
                                }

                                childGanttRecord.startDate = childGanttRecord._getFormatedDate(maxEndDate, model.dateFormat);
                            }
                       }

                            childGanttRecord.left = childGanttRecord._calculateLeft(proxy._projectStartDate, proxy._perDayWidth, proxy._holidaysList, model);
                        childGanttRecord.width = childGanttRecord._calculateWidth(proxy._perDayWidth,proxy._holidaysList, model);
                    break;

                case 'FF':
                    parentEndDate = proxy._getDateFromFormat(parentGanttRecord.endDate);
                    childEndDate = proxy._getDateFromFormat(childGanttRecord.endDate);

                        if (proxy.model.includeWeekend === false) {
                            proxy._setAfterWeekend(parentEndDate);
                        }

                        if (predecessorOffset) {
                            parentEndDate.setDate(parentEndDate.getDate() + (Math.floor(predecessorOffset)));

                            if (proxy.model.includeWeekend === false) {
                                if (predecessorOffset < 0) {
                                    proxy._setBeforeWeekend(parentEndDate);
                                }

                                if (predecessorOffset > 0) {
                                    proxy._setAfterWeekend(parentEndDate);
                                }
                            }
                        }
                        if (proxy._stringHolidays &&
                           proxy._stringHolidays.indexOf(childGanttRecord._getFormatedDate(parentEndDate, model.dateFormat)) != -1) {
                            parentEndDate.setDate(parentEndDate.getDate() + 1);
                        }

                        childGanttRecord.endDate = childGanttRecord._getFormatedDate(parentEndDate, model.dateFormat);
                        //End Date is changed by start date and duration
                        if (childGanttRecord.isMilestone)
                            childGanttRecord.startDate = childGanttRecord._getFormatedDate(parentEndDate, model.dateFormat);
                        else {
                            var tempEndDate = proxy._getDateFromFormat(childGanttRecord.endDate);
                            for (var i = 0; i < childGanttRecord.duration - 1; i++) {
                                tempEndDate.setDate(tempEndDate.getDate() - 1);
                                if (proxy.model.includeWeekend === false) {
                                    if (predecessorOffset < 0) {
                                        proxy._setBeforeWeekend(tempEndDate);
                                    }
                                }
                                tempEndDate = proxy._onHoliDayCheckBefore(tempEndDate);
                            }
                            childGanttRecord.startDate = childGanttRecord._getFormatedDate(tempEndDate, model.dateFormat);
                        }

                            var currentTaskId = childGanttRecord['taskId'].toString(),
                                        predecessorsCollection = childGanttRecord['predecessor'],
                                      childPredecessor =predecessorsCollection&& predecessorsCollection.filter(function (data) { return data.to === currentTaskId });

                            if (childPredecessor && childPredecessor.length > 1) {

                                var maxEndDate = proxy._getPredecessorDate(childGanttRecord, childPredecessor, predecessor.predecessorsType);

                                if (model.includeWeekend === false) {
                                    proxy._setAfterWeekend(maxEndDate);
                                }

                                if (predecessorOffset >= 0 && (maxEndDate.getTime() !== parentEndDate.getTime())) {
                                    childGanttRecord.endDate = childGanttRecord._getFormatedDate(maxEndDate, model.dateFormat);
                                    if (childGanttRecord.isMilestone)
                                        childGanttRecord.startDate = childGanttRecord._getFormatedDate(maxEndDate, model.dateFormat);
                                    else {
                                        var tempEndDate = proxy._getDateFromFormat(childGanttRecord.endDate);
                                        for (var i = 0; i < childGanttRecord.duration - 1; i++) {
                                            tempEndDate.setDate(tempEndDate.getDate() - 1);
                                            if (proxy.model.includeWeekend === false) {
                                                proxy._setBeforeWeekend(tempEndDate);
                                            }
                                            tempEndDate = proxy._onHoliDayCheckBefore(tempEndDate);
                                        }
                                        childGanttRecord.startDate = childGanttRecord._getFormatedDate(tempEndDate, model.dateFormat);
                                    }
                                }
                            }

                            childGanttRecord.left = childGanttRecord._calculateLeft(proxy._projectStartDate, proxy._perDayWidth, proxy._holidaysList, model);
                            childGanttRecord.width = childGanttRecord._calculateWidth(proxy._perDayWidth, proxy._holidaysList, model);
                    break;
            }

            if (childGanttRecord.parentItem)
                proxy._updateParentItem(childGanttRecord);

            if (proxy._isTreeGridRendered || proxy._isGanttChartRendered) {
                proxy.refreshGanttRecord(childGanttRecord);
            }

        },

        _getPredecessorDate: function (ganttRecord, predecessorsCollection, predecessorType) {
            var minStartDate = null, proxy = this, model = proxy.model,
                    maxEndDate = null,
                    tempMaxEndDate = null,
                    length,
                    i,
                    dateDiff = 0,
                    predecessorOffset,
                    connectorLineObject,
                    offset,
                    validatedpredecessor = predecessorsCollection.filter(function (data) {
                        return data.to === ganttRecord.taskId.toString();
                    });


            if (validatedpredecessor) {

                length = validatedpredecessor.length;

                

                    for (i = 0; i < length; i++) {

                        predecessor = validatedpredecessor[i];

                        parentGanttRecord = proxy._rows[proxy._ids.indexOf(predecessor.from)];
                        childGanttRecord = proxy._rows[proxy._ids.indexOf(predecessor.to)];

                        if (minStartDate === null) {
                            minStartDate = proxy._getDateFromFormat(parentGanttRecord.startDate);
                            if (parseInt(predecessor.offset)) {
                                minStartDate.setDate(minStartDate.getDate() + parseInt(predecessor.offset));
                            }
                        }

                        if (maxEndDate === null) {
                            maxEndDate = proxy._getDateFromFormat(parentGanttRecord.endDate);
                            //if (parseInt(predecessor.offset)) {
                            //    maxEndDate.setDate(maxEndDate.getDate() + parseInt(predecessor.offset));
                            //}
                            tempMaxEndDate = proxy._getDateFromFormat(parentGanttRecord.endDate);
                        }

                        if (proxy._getDateFromFormat(parentGanttRecord.startDate).getTime() < minStartDate.getTime()) {
                            minStartDate = proxy._getDateFromFormat(parentGanttRecord.startDate);
                            if (parseInt(predecessor.offset)) {
                                minStartDate.setDate(minStartDate.getDate() + parseInt(predecessor.offset));
                            }
                        }

                        if (proxy._getDateFromFormat(parentGanttRecord.endDate).getTime() > maxEndDate.getTime()) {
                            maxEndDate = proxy._getDateFromFormat(parentGanttRecord.endDate);
                            
                        }
                        tempMaxEndDate.setDate(tempMaxEndDate.getDate() + parseInt(predecessor.offset));
                        var tempMaxDate = proxy._getDateFromFormat(tempMaxEndDate);
                        if (model.includeWeekend === false && tempMaxDate) {
                            proxy._setAfterWeekend(tempMaxDate);
                        }
                        if (parseInt(predecessor.offset)) {
                            if (maxEndDate.getTime() < tempMaxDate.getTime())
                            maxEndDate.setDate(maxEndDate.getDate() + parseInt(predecessor.offset));
                        }
                        (tempMaxEndDate.setDate(tempMaxEndDate.getDate() - parseInt(predecessor.offset)))
                        if (model.includeWeekend === false) {
                            proxy._setAfterWeekend(maxEndDate);
                            proxy._setAfterWeekend(tempMaxEndDate);
                        }
                }
            }
            if (predecessorType == "FS" || predecessorType == "FF") {
                return maxEndDate;
            }
            else if (predecessorType == "SF" || predecessorType == "SS") {
                return minStartDate;
            }

        },

        _renderPredecessor: function (predecessor, item) {
            //var proxy = this,
            //model = proxy.model,
            //length = predecessor.length, predecessorValues = [];

            //for (var i = 0; i < length; i++) {
            //    if (predecessor[i].offset < 0) {
            //        predecessorValues.push(predecessor[i].from + "" + predecessor[i].predecessorsType + ""
            //            + predecessor[i].offset + "d");
            //    }
            //    else if (predecessor[i].offset >= 1) {
            //        predecessorValues.push(predecessor[i].from + "" + predecessor[i].predecessorsType + "+"
            //            + predecessor[i].offset + "d");
            //    }
            //    else {
            //        predecessorValues.push(predecessor[i].from);
            //    }
            //}
            //if (predecessorValues.length > 0) {
            //    item.item[model.predecessorMapping] = predecessorValues.join(',');
            //    //this.refreshRow(itemIndex, false);
            //}
        },

        _setBeforeWeekend: function(date) {
            if (date.getDay() == 0)
                date.setDate(date.getDate() - 2);
            else if (date.getDay() == 6)
                date.setDate(date.getDate() - 1);
        },
        
        _setAfterWeekend: function(date) {
            if (date.getDay() == 0)
                date.setDate(date.getDate() + 1);
            else if (date.getDay() == 6)
                date.setDate(date.getDate() + 2);
        },
        
        _updateEditedGanttRecords: function (args) {
            var proxy = this, model = proxy.model,
                ganttRecord = args.data,
                startDate = proxy._getDateFromFormat(ganttRecord.startDate),
                isPredecessorsModified = false;

            if (args.columnName === "startDate") {
               
                if (this._stringHolidays &&
                      this._stringHolidays.indexOf(ganttRecord._getFormatedDate(startDate, model.dateFormat)) != -1) {
                    startDate.setDate(startDate.getDate() + 1);
                }
                
                if (proxy.model.includeWeekend === false) {
                    this._setAfterWeekend(startDate);
                    if (this._stringHolidays &&
                      this._stringHolidays.indexOf(ganttRecord._getFormatedDate(startDate, model.dateFormat)) != -1) {
                        startDate.setDate(startDate.getDate() + 1);
                    }
                }
                ganttRecord.startDate = proxy.getFormatedDate(startDate);
                ganttRecord.left = ganttRecord._calculateGanttRecordLeft(startDate, proxy._projectStartDate, proxy._perDayWidth);
                ganttRecord.width = ganttRecord._calculateWidth(proxy._perDayWidth, proxy._holidaysList, model);// model.holidays
                ganttRecord.progressWidth = ganttRecord._calculateProgressWidth(ganttRecord.width, ganttRecord.status);
                if (ganttRecord.parentItem)
                    proxy._updateParentItem(ganttRecord);
            }

            else if (args.columnName === "endDate") {
                //validate start date
                var endDate = proxy._getDateFromFormat(ganttRecord.endDate);
                if (startDate.getTime() <= endDate.getTime()) {

                    if (this._stringHolidays &&
                          this._stringHolidays.indexOf(ganttRecord._getFormatedDate(endDate, model.dateFormat)) != -1) {
                        endDate.setDate(endDate.getDate() + 1);
                        if (endDate.getDay() == 6) {
                            endDate.setDate(endDate.getDate() + 2);
                        }
                    }

                    if (model.includeWeekend === false) {
                        if (endDate.getDay() == 0) {
                            endDate.setDate(endDate.getDate() - 2);
                        } else if (endDate.getDay() == 6) {
                            endDate.setDate(endDate.getDate() - 1);
                        }
                    }
                    ganttRecord.endDate = ganttRecord._calculateFormatedDate(endDate, model.dateFormat);
                    ganttRecord._calculateDuration(startDate, endDate, model.includeWeekend, model.holidays, ganttRecord.isMilestone, model);
                    ganttRecord.width = ganttRecord._calculateTaskbarWidth(proxy._perDayWidth, model);
                    ganttRecord.progressWidth = ganttRecord._calculateProgressWidth(ganttRecord.width, ganttRecord.status);
                    if (ganttRecord.parentItem)
                        proxy._updateParentItem(ganttRecord);
                }
                else
                {
                    ganttRecord.endDate = args.previousValue;
                    ganttRecord.item[model.endDateMapping] = args.previousValue;
                }
                if (ganttRecord.duration === 0)
                    ganttRecord.isMilestone = true;
                else
                    ganttRecord.isMilestone = false;
                
            }
            
            else if (args.columnName == "duration") {
                var currentDuration = ganttRecord.duration,
                    offset = currentDuration - args.previousValue,
                modifiedEndDate = proxy._calculateUpdatedDate(proxy._getDateFromFormat(ganttRecord.endDate), offset);

                if (currentDuration === 0) {
                    ganttRecord.isMilestone = true;
                } else {
                    ganttRecord.isMilestone = false;
                }

                ganttRecord.endDate = modifiedEndDate;
                ganttRecord.width = ganttRecord._calculateWidth(proxy._perDayWidth, proxy.holidays, model);
                ganttRecord.progressWidth = ganttRecord._calculateProgressWidth(ganttRecord.width, ganttRecord.status);
                if(model.endDateMapping)
                    ganttRecord.item[model.endDateMapping] = modifiedEndDate;
                if (ganttRecord.parentItem)
                    proxy._updateParentItem(ganttRecord);
            }

            else if (args.columnName == "predecessor") {
                isPredecessorsModified = true;
                if (args.previousValue) {
                    proxy._removeConnectorLine(args.previousValue, ganttRecord);
                }
                proxy._addConnectorLine(ganttRecord);
            }

            else if (args.columnName == "status") {
                ganttRecord.status = ganttRecord.status > 100 ? 100 : ganttRecord.status;
                ganttRecord.progressWidth = proxy._getProgressWidth(ganttRecord.width, ganttRecord.status);
                if (ganttRecord.parentItem) {
                    if (ganttRecord.parentItem)
                        proxy._updateParentItem(ganttRecord);
                    
                }
            }

            //proxy._updateEditedGanttRecord(ganttRecord);
            if (ganttRecord.predecessor) {
                if (!isPredecessorsModified)
                    proxy._$ganttchartHelper.ejGanttChart("updateConnectorLineOffset", ganttRecord);
                proxy._isMileStoneEdited = ganttRecord.isMilestone;
                proxy._updatedConnectorLineCollection = [];
                proxy._connectorlineIds = [];
                proxy._validatePredecessor(ganttRecord);
                if (proxy._updatedConnectorLineCollection.length > 0) {
                    proxy._$ganttchartHelper.ejGanttChart("appendConnectorLine", proxy._updatedConnectorLineCollection);
                }
            }
            proxy._isValidationEnabled = false;
            
            proxy.refreshGanttRecord(ganttRecord);
        },

        _removeConnectorLine: function (predecessor,ganttRecord) {
            var proxy = this,
                connectorLineId,
                parentGanttRecord,
                record,
                i = 0,
                length = predecessor && predecessor.length,
                index = -1;
                
            for (i = 0; i < length; i++) {
                parentGanttRecord = proxy._rows[proxy._ids.indexOf(predecessor[i].from)];
                record = proxy._rows[proxy._ids.indexOf(predecessor[i].to)];
                
                if (ganttRecord.taskId.toString() === predecessor[i].to.toString()) {
                    
                    index = parentGanttRecord.predecessor.indexOf(predecessor[i]);
                    index >= 0 && parentGanttRecord.predecessor.splice(index, 1);
                }

                if (parentGanttRecord && record) {
                    connectorLineId = "parent"+parentGanttRecord['taskId'] + "child" + record['taskId'];
                    proxy._$ganttchartHelper.ejGanttChart("removeConnectorline", connectorLineId);
                }
            }
        },

        _addConnectorLine:function(ganttRecord) {
            var proxy = this,
                count = 0,
                predecessors = ganttRecord.predecessor,
                length,
                predecessor,
                successorGanttRecord;

            if (predecessors) {

                length = predecessors.length;

                for (count = 0; count < length; count++) {

                    predecessor = predecessors[count];
                    
                    if (predecessor.to === ganttRecord.taskId.toString()) {
                        successorGanttRecord = proxy._rows[proxy._ids.indexOf(predecessor.from)];
                    }

                    if (successorGanttRecord) {
                        if (successorGanttRecord.predecessor) {
                            successorGanttRecord.predecessor.push(predecessor);
                        } else {
                            successorGanttRecord.predecessor = [];
                            successorGanttRecord.predecessor.push(predecessor);
                            proxy._predecessorsCollection.push(successorGanttRecord);
                        }
                    }
                }
            }
        },

        _calculateUpdatedDate: function (modifiedDate, offset) {
            var proxy = this, model = proxy.model,
                i = 0;
            if (offset > 0) {
                for (i; i < offset; i++) {
                    if (model.durationUnit == ej.Gantt.DurationUnit.Day) {
                        modifiedDate = proxy.dateUpdate(modifiedDate, 1, 0);
                    }
                    else if (model.durationUnit == ej.Gantt.DurationUnit.Hour) {
                        modifiedDate = proxy.dateUpdate(modifiedDate, 0, 1);
                    }

                    if (modifiedDate.getDay() == 0)
                        modifiedDate.setDate(modifiedDate.getDate() + 1);
                    else if (modifiedDate.getDay() == 6)
                        modifiedDate.setDate(modifiedDate.getDate() + 2);
                }
            } else {
                var dateOffset = (-1) * offset;
                for (i = 0; i < dateOffset; i++) {
                    if (model.durationUnit == ej.Gantt.DurationUnit.Day) {
                        modifiedDate = proxy.dateUpdate(modifiedDate, -1, 0);
                    }
                    else if (model.durationUnit == ej.Gantt.DurationUnit.Hour) {
                        modifiedDate = proxy.dateUpdate(modifiedDate, 0, -1);
                    }

                    if (modifiedDate.getDay() == 0)
                        modifiedDate.setDate(modifiedDate.getDate() - 2);
                    else if (modifiedDate.getDay() == 6)
                        modifiedDate.setDate(modifiedDate.getDate() - 1);
                }
            }
            modifiedDate = proxy.getFormatedDate(modifiedDate);
            return modifiedDate;
        },

        _updateEditedGanttRecord: function (ganttRecord) {
            var proxy = this;
            if (ganttRecord.predecessor) {
                var predecessorsCollection = ganttRecord.predecessor,
                    count = 0,
                    length = predecessorsCollection.length,
                    predecessor,
                    parentGanttRecord,
                    record,
                    connectorLineId,
                    connectorLineObject;
                for (count = 0; count < length; count++) {
                    proxy._updatedConnectorLineCollection = [];
                    proxy._connectorlineIds = [];
                    predecessor = predecessorsCollection[count];
                    if (predecessor.to === ganttRecord['taskId'].toString()) {

                        parentGanttRecord = proxy._rows[proxy._ids.indexOf(predecessor.from)];
                        record = proxy._rows[proxy._ids.indexOf(predecessor.to)];
                        
                        if (parentGanttRecord && record) {
                            connectorLineId = "parent" + parentGanttRecord['taskId'] + "child" + record['taskId'];
                            proxy._$ganttchartHelper.ejGanttChart("removeConnectorline", connectorLineId);
                            connectorLineObject = proxy._createConnectorLineObject(parentGanttRecord, record, predecessor);
                            if (connectorLineObject) {
                                if (proxy._connectorlineIds.length > 0 && proxy._connectorlineIds.indexOf(connectorLineObject.ConnectorLineId) == -1) {

                                    proxy._updatedConnectorLineCollection.push(connectorLineObject);
                                    proxy._connectorlineIds.push(connectorLineObject.ConnectorLineId);
                                }
                                else if (proxy._connectorlineIds.length == 0) {
                                    proxy._updatedConnectorLineCollection.push(connectorLineObject);
                                    proxy._connectorlineIds.push(connectorLineObject.ConnectorLineId);
                                }
                                proxy._$ganttchartHelper.ejGanttChart("appendConnectorLine", proxy._updatedConnectorLineCollection);
                            }
                        }
                        
                    }
                }
            }
        },
        

        _updateGanttRecord: function (ganttRecord) {
            var proxy = this,
                model = proxy.model;            
            ganttRecord.left = ganttRecord._calculateLeft(proxy._projectStartDate, proxy._perDayWidth, proxy.holidays, model);
            ganttRecord.width = ganttRecord._calculateWidth(proxy._perDayWidth,model.holidays, model);
            proxy.refreshGanttRecord(ganttRecord);            
            if (ganttRecord.parentItem)
                proxy._updateParentItem(ganttRecord);
        },

        refreshGanttRecord: function (ganttRecord) {
            var proxy = this;
            if (proxy._isTreeGridRendered) {
                proxy._currentViewData = proxy.getCurrentViewData();
                var index = proxy._currentViewData.indexOf(ganttRecord);
                proxy._$treegridHelper.ejTreeGrid("refreshRow", index);
                if (proxy._isGanttChartRendered) {
                    proxy._$ganttchartHelper.ejGanttChart("refreshRow", index);
                }
            }
        },

        _updateParentItem: function (ganttRecord) {

            var proxy = this,
                parentGanttRecord = ganttRecord.parentItem,                
                model = proxy.model,                
                prevStartDate = proxy._getDateFromFormat(parentGanttRecord.startDate),
                currentStartDate = proxy._getDateFromFormat(ganttRecord.startDate),
                prevEndDate = proxy._getDateFromFormat(parentGanttRecord.endDate),
                currentEndDate = proxy._getDateFromFormat(ganttRecord.endDate);
                            
            
            if (currentStartDate.getTime() < prevStartDate.getTime()) {
                parentGanttRecord.startDate = ganttRecord.startDate;
                if (model.startDateMapping)
                parentGanttRecord.item[model.startDateMapping] = parentGanttRecord.startDate;                
            }

            if (currentEndDate.getTime() > prevEndDate.getTime()) {                
                dateDiff = proxy._daydiff(prevEndDate, currentEndDate);
                parentGanttRecord.endDate = ganttRecord.endDate;
                if(model.endDateMapping)
                    parentGanttRecord.item[model.endDateMapping] = parentGanttRecord.endDate;

            }

            var count = 0,
                childRecords = parentGanttRecord.childRecords,
                length = childRecords && childRecords.length,
                childGanttRecord,
                minStartDate = null,
                maxEndDate = null,
                parentProgress = 0,
                milestoneCount = 0,
                    totalDuration = 0,
                    completedDuration = 0;

            for (count = 0; count < length; count++) {

                childGanttRecord = childRecords[count];

                if (minStartDate === null) {
                    minStartDate =proxy._getDateFromFormat(childGanttRecord.startDate);
                }
                if (maxEndDate === null) {
                    maxEndDate = proxy._getDateFromFormat(childGanttRecord.endDate);
                }
                if (proxy._getDateFromFormat(childGanttRecord.endDate).getTime() > maxEndDate.getTime()) {
                    maxEndDate =proxy._getDateFromFormat(childGanttRecord.endDate);
                }
                if (proxy._getDateFromFormat(childGanttRecord.startDate).getTime() < minStartDate.getTime()) {
                    minStartDate = proxy._getDateFromFormat(childGanttRecord.startDate);
                }

                if (!childGanttRecord.isMilestone) {
                    //converting days into hours .
                    //By now 24 hours is default//...
                    if (model.durationUnit == ej.Gantt.DurationUnit.Hour) {
                        totalDuration += (childGanttRecord.duration*8);
                        //summation of progress done of child
                        completedDuration += ((childGanttRecord.duration*8) * childGanttRecord.status) / 100;
                    }
                    else {
                        totalDuration += (childGanttRecord.duration * 24);
                        //summation of progress done of child
                        completedDuration += ((childGanttRecord.duration * 24) * childGanttRecord.status) / 100;
                    }


                }

                else
                    milestoneCount++;
            }

            if (prevStartDate.getTime() !== minStartDate.getTime()) {
                parentGanttRecord.startDate = parentGanttRecord._getFormatedDate(minStartDate, model.dateFormat);
                if (model.startDateMapping)
                parentGanttRecord.item[model.startDateMapping] = parentGanttRecord.startDate;
            }
            
            if (prevEndDate.getTime() != maxEndDate.getTime()) {                                                       
                parentGanttRecord.endDate = parentGanttRecord._getFormatedDate(maxEndDate, model.dateFormat);
                if(model.endDateMapping)
                    parentGanttRecord.item[model.endDateMapping] = parentGanttRecord.endDate;

            }

            if (!(model.endDateMapping.length==0 && model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale8Hours &&
                model.durationUnit == ej.Gantt.DurationUnit.Hour &&
                model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Day)) {
                parentGanttRecord._calculateDuration(proxy._getDateFromFormat(parentGanttRecord.startDate),
                    proxy._getDateFromFormat(parentGanttRecord.endDate), model.includeWeekend, model.holidays,
                    parentGanttRecord[model.milestoneMapping], model);

            }

            if ((model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale8Hours ||
                model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale24Hours) &&
            model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Day ){
                var beginDate = proxy._getDateFromFormat(parentGanttRecord.startDate);
                //beginDate.setHours(8);
                var diffDate = (beginDate - proxy._projectStartDate) / 86400000;
            }
            else if (model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale8Hours && model.roundOffDayworkingTime) {
                var diffDate = Math.round((proxy._getDateFromFormat(parentGanttRecord.startDate) - proxy._projectStartDate) / 86400000);
            }
            else {
                var diffDate = Math.round((proxy._getDateFromFormat(parentGanttRecord.startDate) - proxy._projectStartDate) / 86400000);
            }
            parentGanttRecord.left = (diffDate * proxy._perDayWidth);
            parentGanttRecord.width = parentGanttRecord._calculateWidth(proxy._perDayWidth,  proxy._holidaysList, model);//model.holidays
            
            //Calculate progressWidth after Left and width calculation
            parentProgress = totalDuration > 0 ? (completedDuration / totalDuration) * 100 : 0;
            parentGanttRecord.progressWidth = proxy._getProgressWidth(parentGanttRecord.width, parentProgress);
            parentGanttRecord.status = Math.round(parentProgress);

            if (model.progressMapping)
                parentGanttRecord.item[model.progressMapping] = parentGanttRecord.status;

            if (proxy._isTreeGridRendered || proxy._isGanttChartRendered)
                proxy.refreshGanttRecord(parentGanttRecord);

            if (parentGanttRecord.parentItem) {
                proxy._updateParentItem(parentGanttRecord);
            }

            
        },

        _validatePredecessor: function (childGanttRecord) {

            var proxy = this,model=proxy.model;

            if (childGanttRecord.predecessor) {

                var predecessorsCollection = childGanttRecord['predecessor'],
                    count,                    
                    parentGanttRecord,
                    record=null,
                    connectorLineId,
                    isValidated = false,
                    predecessor,
                    connectorLineObject,
                    lowestOffset;

                var currentTaskId = childGanttRecord['taskId'].toString(),

                    predecessors = predecessorsCollection.filter(function (data) { return data.to === currentTaskId }),
                    successors = predecessorsCollection.filter(function (data) { return data.from === currentTaskId });
               var predecessorLength = predecessors.length;

                for (count = 0; count < predecessorLength; count++) {
                    predecessor = predecessors[count];
                    parentGanttRecord = proxy._rows[proxy._ids.indexOf(predecessor.from)];//THis is going to exception when id is not corrct order
                    record = proxy._rows[proxy._ids.indexOf(predecessor.to)];
                    connectorLineId = "parent" + parentGanttRecord['taskId'] + "child" + record['taskId'];
                    if (proxy._$ganttchartHelper)
                        proxy._$ganttchartHelper.ejGanttChart("removeConnectorline", connectorLineId);

                    if (childGanttRecord.taskId.toString() === predecessor.to)
                        proxy._validateChildGanttRecord(parentGanttRecord, record, predecessor);


                    if (childGanttRecord.taskId.toString() === predecessor.from)
                        proxy._validateChildGanttRecord(parentGanttRecord, record, predecessor);

                }
                for (count = 0; count < predecessorLength; count++) {
                predecessor = predecessors[count];
                parentGanttRecord = proxy._rows[proxy._ids.indexOf(predecessor.from)];//THis is going to exception when id is not corrct order
                record = proxy._rows[proxy._ids.indexOf(predecessor.to)];
             
					if ((model.enableVirtualization === false && (parentGanttRecord.isExpanded === false || record.isExpanded == false)))//(model.enableVirtualization === false && !parentGanttRecord.isExpanded && record.isExpanded === false)
						continue;
                    connectorLineObject = proxy._createConnectorLineObject(parentGanttRecord, record, predecessor);
                    if (connectorLineObject) {
                        if (proxy._connectorlineIds.length > 0 && proxy._connectorlineIds.indexOf(connectorLineObject.ConnectorLineId) == -1) {

                            proxy._updatedConnectorLineCollection.push(connectorLineObject);
                            proxy._connectorlineIds.push(connectorLineObject.ConnectorLineId);
                        }
                        else if (proxy._connectorlineIds.length == 0) {
                            proxy._updatedConnectorLineCollection.push(connectorLineObject);
                            proxy._connectorlineIds.push(connectorLineObject.ConnectorLineId);
                        }
                        else if (proxy._connectorlineIds.indexOf(connectorLineObject.ConnectorLineId) != -1) {
                            var index = proxy._connectorlineIds.indexOf(connectorLineObject.ConnectorLineId);
                            proxy._updatedConnectorLineCollection[index] = connectorLineObject;
                        }
                    }                   

                }

                var length = successors.length;

                for (count = 0; count < length; count++) {

                    predecessor = successors[count];
                    parentGanttRecord = proxy._rows[proxy._ids.indexOf(predecessor.from)];
                    record = proxy._rows[proxy._ids.indexOf(predecessor.to)];
                    connectorLineId = "parent" + parentGanttRecord['taskId'] + "child" + record['taskId'];
                    if (proxy._$ganttchartHelper)
                        proxy._$ganttchartHelper.ejGanttChart("removeConnectorline", connectorLineId);
                    proxy._validateChildGanttRecord(parentGanttRecord, record, predecessor);
                      if ((model.enableVirtualization === false && (parentGanttRecord.isExpanded === false || record.isExpanded == false)))
                        continue;
					connectorLineObject = proxy._createConnectorLineObject(parentGanttRecord, record, predecessor);
                    if (connectorLineObject) {
                        if (proxy._connectorlineIds.length > 0 && proxy._connectorlineIds.indexOf(connectorLineObject.ConnectorLineId) == -1) {

                            proxy._updatedConnectorLineCollection.push(connectorLineObject);
                            proxy._connectorlineIds.push(connectorLineObject.ConnectorLineId);
                        }
                        else if (proxy._connectorlineIds.length == 0) {
                            proxy._updatedConnectorLineCollection.push(connectorLineObject);
                            proxy._connectorlineIds.push(connectorLineObject.ConnectorLineId);
                        }
                        else if (proxy._connectorlineIds.indexOf(connectorLineObject.ConnectorLineId) != -1) {
                            var index = proxy._connectorlineIds.indexOf(connectorLineObject.ConnectorLineId);
                            proxy._updatedConnectorLineCollection[index] = connectorLineObject;
                        }
                    }

                    record &&  proxy._validatePredecessor(record);

                }                
            }
        },
       
        _calculateDateDifference: function (emptyDate, dateDiff) {
            var differenceCount = dateDiff >= 0 ? dateDiff : (-1 * dateDiff),
                offset = 0;
            
            if (dateDiff > 0)
                offset = differenceCount - this._calculateWeekendCount(emptyDate, dateDiff);
            else
                offset = dateDiff + this._calculateWeekendCount(emptyDate, dateDiff);
            return offset;
        },

        _calculateWeekendCount: function (emptyDate, dateDiff) {
            var differenceCount = dateDiff >= 0 ? dateDiff : (-1 * dateDiff),
                weekendCount = 0,
                i = 0;
            
            if (dateDiff > 0) {
                for (i = 0; i < dateDiff; i++) {
                    if (emptyDate.getDay() == 0) {
                        weekendCount++;
                        emptyDate.setDate(emptyDate.getDate() + 1);
                    }
                    else if (emptyDate.getDay() == 6) {
                        weekendCount += 2;
                        ++i;
                        emptyDate.setDate(emptyDate.getDate() + 2);
                    } else
                        emptyDate.setDate(emptyDate.getDate() + 1);
                }
            }
            else {
                for (i = 0; i < differenceCount; i++) {
                    emptyDate.setDate(emptyDate.getDate() - 1);
                    if (emptyDate.getDay() == 0 || emptyDate.getDay() == 6) {
                        weekendCount += 1;
                    }
                }
            }
            return weekendCount;
        },

        _daydiff: function (first, second) {
            return ((new Date(second) - new Date(first)) / (1000 * 60 * 60 * 24));
        },

        


        dateUpdate: function (date, days, hours) {
            return new Date(
                date.getFullYear(),
                date.getMonth(),
                date.getDate() + days,
                date.getHours() + hours,
                date.getMinutes(),
                date.getSeconds(),
                date.getMilliseconds()
            );
        },
        
        //Method for collapse all the GanttRecords

        _collapseAll: function () {
            var proxy = this,
                model = proxy.model,
                count = 0,
                ganttRecord,
                args = {},
                enableVirtualization = model.enableVirtualization,
                $gridRows = proxy.getRows(),
                $rowElement = null;

            proxy._gridRows = $gridRows;
            proxy._isInExpandCollapse = true;
             
            //loop excecute for iterate the GanttRecords preseent in the Gantt Control            
            for (count = 0; count < proxy.model.parentRecords.length; count++) {
                if (proxy.model.parentRecords[count].expanded) {
                    ganttRecord = proxy.model.parentRecords[count];
                    args.data = ganttRecord;
                    args.recordIndex = count;
                    args.expanded = false;

                    if (enableVirtualization) {
                        if (ganttRecord.hasChildRecords && ganttRecord.expanded) {
                            ej.TreeGrid.sendExpandCollapseRequest(proxy, args);
                        }
                    } else {
                        if (ganttRecord.hasChildRecords && ganttRecord.expanded) {
                            ej.TreeGrid.sendExpandCollapseRequest(proxy, args);
                        }
                        else
                            ej.TreeGrid.sendExpandCollapseRequest(proxy, args);
                        var collapsedCount = proxy._collapsedRecordCount;
                        proxy._$ganttchartHelper.ejGanttChart("reRenderGanttGridLinesTable", -collapsedCount);
                    }
                }
            }

            proxy._isInExpandCollapse = false;
        },
        
        
        //Method for expand all the GanttRecords
        
        _expandAll: function () {
            
            var proxy = this,
                model = proxy.model,
                count = 0,
                ganttRecord,
                args = {},
                enableVirtualization = model.enableVirtualization;

            proxy._isInExpandCollapse = true;

            //loop excecute for iterate the GanttRecords preseent in the Gantt Control

            for (count = 0; count < proxy._updatedGanttRecords.length; count++) {
                ganttRecord = proxy._updatedGanttRecords[count];
                args.data = ganttRecord;
                args.recordIndex = count;
                args.expanded = true;

                if (enableVirtualization) {
                    if (ganttRecord.hasChildRecords && !ganttRecord.expanded) {
                             ej.TreeGrid.sendExpandCollapseRequest(proxy, args);
                    }
                } else {
                    if (ganttRecord.hasChildRecords && !ganttRecord.expanded) {
                        ej.TreeGrid.sendExpandCollapseRequest(proxy, args);
                        var expandedCount = proxy._expandedRecordsCount;
                        proxy._$ganttchartHelper.ejGanttChart("reRenderGanttGridLinesTable", expandedCount);
                    }
                }
            }

            proxy._isInExpandCollapse = false;
        },
        _getDateFromFormat: function (date) {
            
            if (typeof date === "object") {
                return new Date(date);
            }
            if (date) {
                return Globalize.parseDate(date, this.model.dateFormat) == null ?
                    new Date(date) : Globalize.parseDate(date, this.model.dateFormat);
            }
        },
        _getFormatedDate: function (dateObject, dateformat) {
            return Globalize.format(dateObject, dateformat);
        },

        /**
        * destroy the gantt widget
		* all events bound using this._on will be unbind automatically and bring the control to pre-init state.
		* @alias destroy
		* @return jQuery
		* @example 
		* &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
		* &lt;script&gt;
		* // Create gantt
		* var gantt = $("#gantt").data("ejGantt");
		* gantt.destroy(); // destroy the gantt
		* &lt;/script&gt;
		* @example 
		* &lt;gantt id="gantt"&gt;Gantt&lt;/gantt&gt; <br> 
		* &lt;script&gt;
		* // enable the gantt
		* $("#gantt").ejGantt("destroy");	
		* &lt;/script&gt;
		* @memberof ejGantt
		* @instance
         */
        _destroy: function () {
            var proxy = this;
            proxy.element.empty().removeClass("e-gantt-core e-gantt " + proxy.model.cssClass);
        }
        


    });
    
    ej.Gantt.EditingType = {
        String: "stringedit",
        Boolean: "booleanedit",
        Numeric: "numericedit",
        Dropdown: "dropdownedit",
        DatePicker: "datepicker",
        DateTimePicker:"datetimepicker"
    };

    ej.Gantt.ToolbarItems = {
        Add: "add",
        Edit: "edit",
        Delete: "delete",
        Update: "update",
        Cancel: "cancel",
        Search: "search",
        Indent: "indent",
        Outdent: "outdent",
        ExpandAll: "expandAll",
        CollapseAll: "collapseAll",
        PrevTimeSpan: "prevTimeSpan",
        NextTimeSpan:"nextTimeSpan",
    };

    ej.Gantt.ScheduleHeaderType = {
        Year: "year",
        Month: "month",
        Week: "week",
        Day: "day"
    };

    ej.Gantt.DurationUnit = {
        Day: "day",
        Hour: "hour",
    };

    ej.Gantt.workingTimeScale = {
        TimeScale8Hours: "TimeScale8Hours",
        TimeScale24Hours: "TimeScale24Hours",
    };


    ej.Gantt.localization = {};

    ej.Gantt.localization["en-US"] = {

        //string to display with dataSource contains 0 objects
        emptyRecord: "No records to display",

        //headerText to be displayed in treegrid
        columnHeaderTexts: {
            taskId: "ID",
            taskName: "Task Name",
            startDate: "Start Date",
            endDate: "End Date",
            resourceInfo: "Resources",
            duration: "Duration",
            status: "Progress",
            predecessor: "Predecessor",
            baselineStartDate: "Baseline Start Date",
            baselineEndDate: "Baseline End Date"
        },

        //string to display in dialog 
        editDialogTexts: {
            addFormTitle: "New Task",
            editFormTitle: "Edit Task",
            saveButton: "Save",
            cancelButton: "Cancel"
        },

        calendars: {
            standard: {
                days: {
                    // full name of days
                    names: ["Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday"],
                    // abbreviated names of days
                    namesAbbr: ["Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"],
                },
                months: {
                    // full name of months
                    names: ["January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December"],
                    // abbreviated name of months
                    namesAbbr: ["Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"]
                },

                // set of predefined date and time patterns used by the culture.
                patterns: {
                    d: "M/d/yyyy",
                    D: "dddd, MMMM dd, yyyy",
                    F: "dddd, MMMM dd, yyyy h:mm:ss tt",
                    g: "M/d/yyyy h:mm tt",
                    G: "M/d/yyyy h:mm:ss tt",
                    m: "MMMM dd",
                    M: "MMMM dd",
                    s: "yyyy'-'MM'-'ddTHH':'mm':'ss",
                    t: "h:mm tt",
                    T: "h:mm:ss tt",
                    u: "yyyy'-'MM'-'dd HH':'mm':'ss'Z'",
                    y: "MMMM, yyyy",
                    Y: "MMMM, yyyy"
                }
            }
        }
    };

    /*-----Initialize the GanttRecord object--------------*/

    ej.Gantt.GanttRecord = function() {
        var proxy = this;
        proxy.taskId = null,
        proxy.taskName = null,
        proxy.startDate = null,
        proxy.endDate = null,
        proxy.duration = null,
        proxy.isMilestone = false,
        proxy.status = null,
        proxy.predecessor = null,
        proxy.resourceInfo = null,
        proxy.parentItem = null,
        proxy.isSelected = false,
        proxy.childRecords = null,
        proxy.hasChildRecords = false,
        proxy.expanded = false,
        proxy.level = 0,
        proxy.left = 0,
        proxy.width = 0,
        proxy.progressWidth = 0,
        proxy.item = null,
        proxy.baselineLeft = 0,
        proxy.baselineWidth = 0,
        proxy.baselineStartDate = null,
        proxy.baselineEndDate = null,
        proxy.isReadOnly = false;
    }

    ej.Gantt.GanttRecord.prototype = {

        //calculate the left position of the taskbar
        _calculateLeft: function (projectStartDate, dayWidth, holidays, model) {

            var proxy = this,
                diffDate,
                enddatecount = 0,
                beginDate = proxy._getDateFromFormat(proxy.startDate, model.dateFormat),
                endDate = proxy._getDateFromFormat(proxy.endDate, model.dateFormat),
                endDateHours = endDate && endDate.getHours(),
                endDateMinutes = endDate && endDate.getMinutes(),
                duration = 0, timeScale = model.workingTimeScale;

            if (endDate) {
                endDateHours = endDate.getHours();
                endDateMinutes = endDate.getMinutes();
            }

            if (model.durationUnit == ej.Gantt.DurationUnit.Hour) {
                if (model.durationMapping) {
                    if (timeScale == ej.Gantt.workingTimeScale.TimeScale24Hours) {
                        endDateHours = (parseInt(proxy.duration % 24) > 0) ? parseInt(proxy.duration % 24) : 0;
                        duration = endDateHours > 0 ? parseInt(proxy.duration / 24) + 1 : parseInt(proxy.duration / 24);

                    }
                    else if (timeScale == ej.Gantt.workingTimeScale.TimeScale8Hours) {
                        endDateHours = (parseInt(proxy.duration % 8) > 0) ? parseInt(proxy.duration % 8) : 0;
                        duration = endDateHours > 0 ? parseInt(proxy.duration / 8) + 1 : parseInt(proxy.duration / 8);
                    }
                }

            }
            else {
                duration = parseInt(proxy.duration);
            }

            if (endDate == null) {

                endDate = proxy._getDateFromFormat(proxy.startDate, model.dateFormat);
                endDate.setDate(endDate.getDate() + duration);
            }


            if (model.includeWeekend == false) {

                if (beginDate.getDay() == 0) {
                    beginDate.setDate(beginDate.getDate() + 1);
                }
                if (beginDate.getDay() == 6) {
                    beginDate.setDate(beginDate.getDate() - 1);
                }

                proxy._updateHoliday(beginDate, holidays, model.includeWeekend);

                var emptyDate = new Date(beginDate);
                for (var i = 0; i < duration; i++) {
                    if (emptyDate.getDay() == 0) {
                        enddatecount++;
                    } else if (emptyDate.getDay() == 6) {
                        enddatecount += 2;
                        emptyDate.setDate(emptyDate.getDate() + 2);
                    }
                    emptyDate.setDate(emptyDate.getDate() + 1);
                }
                endDate = new Date(beginDate);
                enddatecount = duration === 0 ? 1 : enddatecount;
                endDate.setDate(endDate.getDate() + (duration + enddatecount - 1));


                if (endDate.getDay() == 0) {
                    endDate.setDate(endDate.getDate() + 1);
                }
                if (endDate.getDay() == 6) {
                    endDate.setDate(endDate.getDate() + 2);
                }
            }

            else if (model.includeWeekend == true) {
                proxy._updateHoliday(beginDate, holidays, model.includeWeekend);
                endDate = new Date(beginDate);
                if (duration > 0) {
                    endDate.setDate(endDate.getDate() + (duration - 1));
                }

            }

            if (endDateHours) {
                if ((timeScale == ej.Gantt.workingTimeScale.TimeScale8Hours) &&
                    model.durationUnit == ej.Gantt.DurationUnit.Hour) {
                    if (endDateHours > 0)
                        endDate.setHours(8 + endDateHours);
                    else
                        endDate.setHours(17);
                }
                else
                    endDate.setHours(endDateHours);
            }
            else if ((timeScale == ej.Gantt.workingTimeScale.TimeScale8Hours && model.durationUnit == ej.Gantt.DurationUnit.Hour)) {
                endDate.setHours(17);
            }

            else if ((timeScale == ej.Gantt.workingTimeScale.TimeScale24Hours && model.dateFormat.indexOf("hh") != -1) ||
                (timeScale == ej.Gantt.workingTimeScale.TimeScale24Hours && model.durationUnit == ej.Gantt.DurationUnit.Hour)) {
                endDate.setHours(24);
            }

            // endDate.setMinutes(endDateMinutes);
            proxy.startDate = proxy._getFormatedDate(beginDate, model.dateFormat);
            proxy.endDate = proxy._getFormatedDate(endDate, model.dateFormat);

            if (model.endDateMapping)
                proxy.item[model.endDateMapping] = proxy.endDate;

            if (model.startDateMapping)
                proxy.item[model.startDateMapping] = proxy.startDate;
            diffDate = Math.round((beginDate - projectStartDate) / 86400000);

            if ((timeScale == ej.Gantt.workingTimeScale.TimeScale24Hours)
                && model.scheduleHeaderSettings.scheduleHeaderType != ej.Gantt.ScheduleHeaderType.Day) {
                diffDate = ((beginDate - projectStartDate) / 86400000);
            }

            else if ((timeScale == ej.Gantt.workingTimeScale.TimeScale8Hours ) &&
                model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Day &&
                model.dateFormat.indexOf("hh") == -1) {
                diffDate = ((beginDate - projectStartDate) / 86400000);
            }

            else if ((timeScale == ej.Gantt.workingTimeScale.TimeScale24Hours || timeScale == ej.Gantt.workingTimeScale.TimeScale8Hours) &&
                  model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Day &&
                   model.dateFormat.indexOf("hh") != -1) {

                diffDate = ((beginDate - projectStartDate) / 86400000);
            }

            else if ((timeScale == ej.Gantt.workingTimeScale.TimeScale8Hours) && model.roundOffDayworkingTime) {
                diffDate = Math.round((beginDate - projectStartDate) / 86400000);
            }


            return (diffDate * dayWidth);
        },

        //calculate the left margin of the baseLine element.
        _calculateBaselineLeft: function (projectStartDate, dayWidth, includeWeekend, dateformat) {

            var diffDate,
                proxy = this,
                beginDate = Globalize.parseDate(proxy.baselineStartDate, dateformat),
                duration = parseInt(proxy.duration),
                enddate = proxy.endDate;

            if (enddate == null) {
                enddate = new Date(beginDate);
                enddate.setDate(enddate.getDate() + duration);
            }
            diffDate = Math.ceil((beginDate - projectStartDate) / 86400000);
            return (diffDate * dayWidth);
        },

        _updateHoliday: function (date, holidays, includeWeekend) {
            var j = 0,
                length = holidays && holidays.length;

            if (length > 0) {

                for (j = 0; j < length; j++) {

                    if (holidays[j].getDate() == date.getDate()) {
                        date.setDate(date.getDate() + 1);
                    }

                }

                if ((includeWeekend == false) && (date.getDay() == 6)) {
                    date.setDate(date.getDate() + 2);
                }
            }
        },

        _calculateGanttRecordLeft: function (startDate, projectStartDate, dayWidth) {
            var proxy = this,
                diffDate = proxy._daydiff(projectStartDate, startDate);
            return (diffDate * dayWidth);
        },

        _calculateReverseLeft: function (projectStartDate, dayWidth, includeWeekend, dateformat) {
            var diffDate,
                proxy = this,
                enddatecount = 0,
                startdate = proxy.startDate,
                duration = proxy.duration && parseInt(proxy.duration);

            if (startdate == null) {

                startdate = proxy._getDateFromFormat(proxy.endDate);
                startdate.setDate(startdate.getDate() - duration);
            }
            if (includeWeekend == false) {

                var emptyDate = proxy._getDateFromFormat(proxy.endDate, dateformat);

                for (var i = 0; i < duration; i++) {

                    if (emptyDate.getDay() == 0) {
                        enddatecount += 2;
                        emptyDate.setDate(emptyDate.getDate() - 2);
                    }
                    else if (emptyDate.getDay() == 6) {
                        enddatecount++;
                    }
                    emptyDate.setDate(emptyDate.getDate() - 1);
                }
                startdate = proxy._getDateFromFormat(proxy.endDate, dateformat);
                enddatecount = duration === 0 ? 1 : enddatecount;
                startdate.setDate(startdate.getDate() - (duration + enddatecount - 1));
            }
            proxy.startDate = proxy._getFormatedDate(startdate, dateformat);
            diffDate = Math.ceil((startdate - projectStartDate) / 86400000);
            return (diffDate * dayWidth);
        },

        _calculateReverseWidth: function (dayWidth, dateFormat, includeWeekend, holidays) {

            var proxy = this,
                enddatecount = 0,
                diffDate,
                emptyDate,
                i = 0,
                startdate = proxy.startDate,
                duration = proxy.duration && parseInt(proxy.duration),
                enddate = proxy.endDate;

            if (startdate == null) {
                startdate = proxy._getDateFromFormat(enddate, dateFormat);
                startdate.setDate(startdate.getDate() - duration + 1);

            }

            if (includeWeekend == false) {

                emptyDate = proxy._getDateFromFormat(enddate, dateFormat);

                for (i = 0; i < duration; i++) {

                    if (emptyDate.getDay() == 0) {

                        enddatecount += 2;
                        emptyDate.setDate(emptyDate.getDate() - 2);

                    } else if (emptyDate.getDay() == 6) {
                        enddatecount++;
                    }

                    emptyDate.setDate(emptyDate.getDate() - 1);

                }

                startdate = proxy._getDateFromFormat(enddate, dateFormat);
                startdate.setDate(startdate.getDate() - (duration + enddatecount - 1));
            }

            if (holidays != null && holidays.length > 0) {

                emptyDate = proxy._getDateFromFormat(startdate, dateFormat);

                for (i = 0; i < duration; i++) {

                    emptyDate.setDate(emptyDate.getDate() + 1);

                    for (var j = 0; j < holidays.length; j++) {

                        if (new Date(holidays[j].day).getDate() == emptyDate.getDate()) {
                            enddatecount++;
                        }

                    }

                    if ((includeWeekend == false) && (emptyDate.getDay() == 0 || emptyDate.getDay() == 6)) {
                        enddatecount++;
                    }

                }

                enddate = proxy._getDateFromFormat(proxy.startDate, dateFormat);
                enddate.setDate(enddate.getDate() + (duration + enddatecount - 1));
            }

            diffDate = Math.ceil((proxy._getDateFromFormat(enddate, dateFormat) - proxy._getDateFromFormat(proxy.startDate, dateFormat)) / 86400000) + 1;

            return (diffDate) * dayWidth;
        },

        _calculateWidth: function (dayWidth, holidays, model) {

            var proxy = this,
                diffDate,
                startdate = proxy.startDate,
                enddate = proxy.endDate,
                duration = proxy.duration;

            if (enddate == null) {
                duration = parseInt(duration);
                enddate = proxy._getFormatedDate(startdate, model.dateFormat);
                enddate.setDate(enddate.getDate() + duration - 1);
            }

            proxy._calculateEndDate(model.includeWeekend, holidays, model, dayWidth);

            if (model.durationUnit == ej.Gantt.DurationUnit.Hour) {
                if (model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale24Hours) {
                    if (model.durationUnit == ej.Gantt.DurationUnit.Hour && model.dateFormat.indexOf("hh") == -1) {
                        diffDate = proxy.duration;
                    }
                    else {
                        diffDate = proxy._hourdiff(proxy._getDateFromFormat(proxy.startDate, model.dateFormat),
                        proxy._getDateFromFormat(proxy.endDate, model.dateFormat));
                    }
                }
                else if (model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale8Hours) {
                    if (model.durationUnit == ej.Gantt.DurationUnit.Hour && model.dateFormat.indexOf("hh") == -1) {
                        diffDate = (proxy.duration / 8) * 24 + (proxy.duration % 8);
                    }
                    else {
                        diffDate = proxy._hourdiff(proxy._getDateFromFormat(proxy.startDate, model.dateFormat),
                        proxy._getDateFromFormat(proxy.endDate, model.dateFormat));
                    }
                }
                return (diffDate * (dayWidth / 24));
            }
            else {
                if ((model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale24Hours)
                      && model.scheduleHeaderSettings.scheduleHeaderType != ej.Gantt.ScheduleHeaderType.Day &&
                    (model.dateFormat.indexOf("hh:") != -1)) {
                    diffDate = ((proxy._getDateFromFormat(proxy.endDate, model.dateFormat) -
                        proxy._getDateFromFormat(proxy.startDate, model.dateFormat)) / 86400000);// + 1;//Math.ceil
                }

                else if ((model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale24Hours)
                  && model.scheduleHeaderSettings.scheduleHeaderType != ej.Gantt.ScheduleHeaderType.Day &&
                   (model.dateFormat.indexOf("hh:") == -1)) {
                    diffDate = ((proxy._getDateFromFormat(proxy.endDate, model.dateFormat) -
                        proxy._getDateFromFormat(proxy.startDate, model.dateFormat)) / 86400000) + 1;//Math.ceil
                }
                    //Calculating width for 8 hour timescale  for dateformats without time
                else if ((model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale8Hours) &&
                model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Day &&
                    model.durationUnit != ej.Gantt.DurationUnit.Hour) {

                    var tStartDate = new Date(proxy.startDate),
                        tEndDate = new Date(proxy.endDate);
                    tStartDate.setHours(8);
                    tEndDate.setHours(17);

                    diffDate = ((tEndDate - tStartDate) / 86400000);
                }

                else if ((model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale8Hours) &&
                         model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Day &&
                         model.durationUnit == ej.Gantt.DurationUnit.Hour) {
                    var tStartDate = new Date(proxy.startDate),
                       tEndDate = new Date(proxy.endDate);

                    diffDate = ((tEndDate - tStartDate) / 86400000);
                }

                else if (model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale8Hours || model.roundOffDayworkingTime)
                    diffDate = Math.round((proxy._getDateFromFormat(proxy.endDate, model.dateFormat) -
                        proxy._getDateFromFormat(proxy.startDate, model.dateFormat)) / 86400000) + 1;


                return (diffDate) * dayWidth;
            }
        },


        _calculateTaskbarWidth: function (dayWidth, model) {
            var proxy = this,
                diffDate = 0,
                dateFormat = model.dateFormat,
                timeScale = model.workingTimeScale;

            if (model.durationUnit == ej.Gantt.DurationUnit.Hour) {
                if (model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale24Hours) {

                    if (model.durationUnit == ej.Gantt.DurationUnit.Hour && model.dateFormat.indexOf("hh") == -1) {
                        diffDate = proxy.duration;
                    }
                    else {
                        diffDate = proxy._hourdiff(proxy._getDateFromFormat(proxy.startDate, dateFormat),
                        proxy._getDateFromFormat(proxy.endDate, dateFormat));
                    }
                }
                else if (model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale8Hours) {
                    if (model.durationUnit == ej.Gantt.DurationUnit.Hour && model.dateFormat.indexOf("hh") == -1) {
                        diffDate = proxy.duration;
                    }
                    else {
                        diffDate = proxy._hourdiff(proxy._getDateFromFormat(proxy.startDate, dateFormat),
                        proxy._getDateFromFormat(proxy.endDate, dateFormat));
                    }
                }
                return (diffDate * (dayWidth / 24));
            }
            else {
                if (timeScale == ej.Gantt.workingTimeScale.TimeScale24Hours &&
                    model.scheduleHeaderSettings.scheduleHeaderType != ej.Gantt.ScheduleHeaderType.Day && model.dateFormat.indexOf("hh") == -1) {
                    diffDate = proxy._daydiff(proxy._getDateFromFormat(proxy.startDate, dateFormat),
                    proxy._getDateFromFormat(proxy.endDate, dateFormat)) + 1;

                }

                else if (timeScale == ej.Gantt.workingTimeScale.TimeScale24Hours) {
                    diffDate = proxy._daydiff(proxy._getDateFromFormat(proxy.startDate, dateFormat),
                    proxy._getDateFromFormat(proxy.endDate, dateFormat));
                }//+ 1;

                else if (timeScale == ej.Gantt.workingTimeScale.TimeScale8Hours) {
                    diffDate = Math.round(proxy._daydiff(proxy._getDateFromFormat(proxy.startDate, dateFormat),
                        proxy._getDateFromFormat(proxy.endDate, dateFormat)) + 1);
                }
                else {
                    diffDate = proxy._daydiff(proxy._getDateFromFormat(proxy.startDate, dateFormat),
                        proxy._getDateFromFormat(proxy.endDate, dateFormat));//+ 1;
                }
                return (diffDate * dayWidth);
            }
        },
        _calculateBaseLineWidth: function (dayWidth, model)
        {
            var proxy = this,
                diffDate = 0,
                dateFormat = model.dateFormat,
                timeScale = model.workingTimeScale;

            if (model.durationUnit == ej.Gantt.DurationUnit.Hour) {
                if (model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale24Hours) {

                    if (model.durationUnit == ej.Gantt.DurationUnit.Hour && model.dateFormat.indexOf("hh") == -1) {
                        diffDate = proxy.duration;
                    }
                    else {
                        diffDate = proxy._hourdiff(proxy._getDateFromFormat(proxy.baselineStartDate, dateFormat),
                        proxy._getDateFromFormat(proxy.baselineEndDate, dateFormat));
                    }
                }
                else if (model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale8Hours) {
                    if (model.durationUnit == ej.Gantt.DurationUnit.Hour && model.dateFormat.indexOf("hh") == -1) {
                        diffDate = proxy.duration;
                    }
                    else {
                        diffDate = proxy._hourdiff(proxy._getDateFromFormat(proxy.baselineStartDate, dateFormat),
                        proxy._getDateFromFormat(proxy.baselineEndDate, dateFormat));
                    }
                }
                return (diffDate * (dayWidth / 24));
            }
            else {
                if (timeScale == ej.Gantt.workingTimeScale.TimeScale24Hours &&
                    model.scheduleHeaderSettings.scheduleHeaderType != ej.Gantt.ScheduleHeaderType.Day && model.dateFormat.indexOf("hh") == -1) {
                    diffDate = proxy._daydiff(proxy._getDateFromFormat(proxy.baselineStartDate, dateFormat),
                    proxy._getDateFromFormat(proxy.baselineEndDate, dateFormat)) + 1;

                }

                else if (timeScale == ej.Gantt.workingTimeScale.TimeScale24Hours) {
                    diffDate = proxy._daydiff(proxy._getDateFromFormat(proxy.baselineStartDate, dateFormat),
                    proxy._getDateFromFormat(proxy.baselineEndDate, dateFormat));
                }//+ 1;

                else if (timeScale == ej.Gantt.workingTimeScale.TimeScale8Hours) {
                    diffDate = Math.round(proxy._daydiff(proxy._getDateFromFormat(proxy.baselineStartDate, dateFormat),
                        proxy._getDateFromFormat(proxy.baselineEndDate, dateFormat)) + 1);
                }
                else {
                    diffDate = proxy._daydiff(proxy._getDateFromFormat(proxy.baselineStartDate, dateFormat),
                        proxy._getDateFromFormat(proxy.baselineEndDate, dateFormat));//+ 1;
                }
                return (diffDate * dayWidth);
            }
        },
        _getFormatedDate: function (dateObject, dateformat) {
            return Globalize.format(dateObject, dateformat);
        },

        _getDateFromFormat: function (dateString, dateformat) {
            if (dateString) {
                return Globalize.parseDate(dateString, dateformat) == null ?
                    new Date(dateString) : Globalize.parseDate(dateString, dateformat);
            }
        },

        _calculateProgressWidth: function (parentWidth, percent) {
            return (parentWidth * percent) / 100;
        },

        _setResourceInfo: function (resourceIdcollection, resourceIdMapping, resourceNameMapping, resourcecollection) {

            var count = 0,
            length = resourceIdcollection.length,
            resources = [];

            for (count; count < length; count++) {

                var resource = resourcecollection.filter(function (resourceInfo) {
                    return resourceIdcollection[count] === resourceInfo[resourceIdMapping];
                });

                resource.length && resources.push(resource[0]);
            }
            return resources;
        },

        _updateEndDate: function (prevStartDate, includeWeekend, dateFormat) {
            var proxy = this,
                formatedPrevStartDate = new Date(prevStartDate),
                formatedStartDate = proxy._getDateFromFormat(proxy.startDate, dateFormat),
                diff = proxy._daydiff(formatedPrevStartDate, formatedStartDate),
            endDate = proxy._getDateFromFormat(proxy.endDate, dateFormat),
            weekendCount = 0;

            if (includeWeekend == false) {
                var count = 0;
                for (count; count <= diff; count++) {
                    endDate.setDate(endDate.getDate() + 1);
                    if (endDate.getDay() == 0 || endDate.getDay() == 6)
                        weekendCount += 1;
                }
            }

            var modifiedEndDate = proxy._getDateFromFormat(proxy.endDate, dateFormat);
            modifiedEndDate.setDate(modifiedEndDate.getDate() + diff + weekendCount);
            proxy.endDate = proxy._getFormatedDate(modifiedEndDate, dateFormat);
        },

        _calculateFormatedDate: function (date, format) {
            return Globalize.format(date, format);
        },

        _updateParentProgress: function (parent,progressMapping) {
            var parentProgress = 0,
                childCount = parent.childRecords && parent.childRecords.length,
                totalDuration = 0,
                completedDuration = 0;


            if (parent.childRecords) {
                for (var i = 0; i < childCount; i++) {

                    //converting days into hours .
                    //By now 24 hours is default
                    totalDuration += (parent.childRecords[i].duration * 24);

                    //summation of progress done of child
                    completedDuration += ((parent.childRecords[i].duration * 24) * parent.childRecords[i].status) / 100;
                  
                }

                parentProgress = (completedDuration / totalDuration) * 100;
                if (isNaN(parentProgress))
                    parentProgress = 0;
                parent.progressWidth = this._getProgressWidth(parent.width, parentProgress);
                parent.status = Math.round(parentProgress);
                if (progressMapping)
                    parent.item[progressMapping] = parent.status;

            }
            if (parent.parentItem) {
                this._updateParentProgress(parent.parentItem, progressMapping);
            }
        },


        _getProgressWidth: function (parentwidth, percent) {
            return (parentwidth * percent) / 100;
        },

        _calculatePredecessor: function (string) {
            var collection = [],
                match,
                obj = {},
                values,
                to = this.taskId.toString(),
                offsetvalue;
            string.split(',').forEach(function (el) {
                values = el.split('+');
                offsetvalue = '+';
                if (el.indexOf('-') >= 0) {
                    values = el.split('-');
                    offsetvalue = '-';
                }
                match = values[0].match(/(\d+|[A-z]+)/g);
                obj = {
                    from: match[0],
                    predecessorsType: match.length > 1 ? match[1].toUpperCase() : "FS",
                    offset: values.length > 1 ? offsetvalue + "" + values[1] : "",
                    isdrawn: false,
                    to: to
                };
                collection.push(obj);
            });
            return collection;
        },

        _updateGanttRecord: function (startDateMappingName, endDateMappingName, durationMappingName, includeWeekend, scheduleStartDay, perDayWidth, dateFormat, holidays) {
            var proxy = this,
                remainDays = proxy.left % perDayWidth,
                day = (proxy.left - remainDays) / perDayWidth,holiday
                startDate = new Date(scheduleStartDay);

            startDate.setDate(scheduleStartDay.getDate() + day);

            if (startDate.getDay() == 0)
                startDate.setDate(startDate.getDate() + 1);
            else if (startDate.getDay() == 6)
                startDate.setDate(startDate.getDate() + 2);

            proxy.startDate = proxy._getFormatedDate(startDate, dateFormat);
            proxy.left = proxy._calculateLeft(scheduleStartDay, perDayWidth, includeWeekend, dateFormat, endDateMappingName);
            proxy.width = proxy._calculateWidth(perDayWidth, includeWeekend, holidays, dateFormat);
            if (proxy.parentItem)
                proxy._updateParentItem(proxy, startDateMappingName, endDateMappingName, durationMappingName, includeWeekend, scheduleStartDay, perDayWidth, dateFormat, holidays);
        },

        _calculateUpdatedDate: function (modifiedDate, offset) {
            var proxy = this,
                i = 0;
            if (offset > 0) {
                for (i; i < offset; i++) {
                    modifiedDate = proxy._dataSubtract(modifiedDate, 1);
                    if (modifiedDate.getDay() == 0)
                        modifiedDate.setDate(modifiedDate.getDate() + 1);
                    else if (modifiedDate.getDay() == 6)
                        modifiedDate.setDate(modifiedDate.getDate() + 2);
                }
            } else {
                var dateOffset = (-1) * offset;
                for (i = 0; i < dateOffset; i++) {
                    modifiedDate = proxy._dataSubtract(modifiedDate, -1);
                    if (modifiedDate.getDay() == 0)
                        modifiedDate.setDate(modifiedDate.getDate() - 2);
                    else if (modifiedDate.getDay() == 6)
                        modifiedDate.setDate(modifiedDate.getDate() - 1);
                }
            }
            modifiedDate = proxy._getFormatedDate(modifiedDate);
            return modifiedDate;
        },

        _dataSubtract: function (date, days) {
            return new Date(
                date.getFullYear(),
                date.getMonth(),
                date.getDate() + days,
                date.getHours(),
                date.getMinutes(),
                date.getSeconds(),
                date.getMilliseconds()
            );
        },

        _calculateEndDate: function (includeWeekend, holidays,model, perDayWidth) {
            var proxy = this,
                count = 0,
                startDate = proxy._getDateFromFormat(proxy.startDate, model.dateFormat),
                endDate = proxy._getDateFromFormat(proxy.endDate, model.dateFormat),
                endDateHours = 0, endDateMinutes = 0,
                duration = 0,// proxy.duration && parseInt(proxy.duration),
                remainingHours = 0, totalLength, remainingLength;

            if (endDate) {
                endDateHours = endDate.getHours();
                endDateMinutes = endDate.getMinutes();
            }

            if (model.durationUnit == ej.Gantt.DurationUnit.Hour) {
                if (model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale24Hours) {
                    if (!model.endDateMapping) {
                        var totalHours = startDate.getHours() + proxy.duration;
                        endDateHours = (parseInt(totalHours % 24) > 0) ? parseInt(totalHours % 24) : 0;
                    } else {
                        if (endDate) {
                            endDateHours = endDate.getHours();
                            endDateMinutes = endDate.getMinutes();
                        } else {
                            endDateHours = (parseInt(proxy.duration % 24) > 0) ? parseInt(proxy.duration % 24) : 0;
                        }
                    }
                    duration = endDateHours > 0 ? parseInt((startDate.getHours() + proxy.duration) / 24) + 1 :
                        parseInt(startDate.getHours() + proxy.duration) / 24;
                   
                }
                else if (model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale8Hours) {
                    if (!model.endDateMapping) {
                        var totalHours = startDate.getHours() + proxy.duration;
                        endDateHours = (parseInt(totalHours % 8) > 0) ? parseInt(totalHours % 8) : 0;
                        endDateHours = proxy._calculateTimeScale8Hour(startDate.getHours(), proxy.duration) % 24;
                    }
                    else {
                        if (endDate) {
                            endDateHours = endDate.getHours();
                            endDateMinutes = endDate.getMinutes();
                        } else {
                            endDateHours = proxy._calculateTimeScale8Hour(startDate.getHours(), proxy.duration) % 24;
                        }
                    }
                    var endHour = proxy._calculateTimeScale8Hour(startDate.getHours(), proxy.duration);
                    var calculatedEndHour = parseInt(endHour / 24) < 1 ? 1 : parseInt(endHour / 24);
                    var checkEndDate = proxy._dateUpdate(startDate, 0, (endHour-startDate.getHours()));
                    if (checkEndDate.getHours() >= 8) {
                        calculatedEndHour += 1;
                    }
                    duration = endDateHours > 0 ? Math.round(calculatedEndHour)
                        : parseInt(proxy.duration) / 8;

                }
                 
                //duration = parseInt(proxy.duration);
            }
            else {
                duration = parseInt(proxy.duration);
            }

            
            if (proxy.width > 0) {
                totalLength = proxy.left + proxy.width;
                remainingLength = totalLength % perDayWidth;
                remainingHours = Math.round(remainingLength / (perDayWidth / 24));//hour calculation
            }

            if (duration === 0) {
                proxy.endDate = proxy.startDate;
                return;
            }

            if (includeWeekend === false) {
                for (count = 1; count < duration; count++) {
                    if (startDate.getDay() == 0)
                        startDate.setDate(startDate.getDate() + 1);
                    else if (startDate.getDay() == 6)
                        startDate.setDate(startDate.getDate() + 2);

                    startDate.setDate(startDate.getDate() + 1);
                }
            } else {
                startDate.setDate(startDate.getDate() + duration - 1);
            }

            if (includeWeekend === false) {
                if (startDate.getDay() == 0)
                    startDate.setDate(startDate.getDate() + 1);
                else if (startDate.getDay() == 6)
                    startDate.setDate(startDate.getDate() + 2);
            }

            if (holidays && holidays.length) {
                var holidayIndex = 0,
                    holidayslength = holidays.length,
                    holiday;
                for (holidayIndex = 0; holidayIndex < holidayslength; holidayIndex++) {
                    holiday = new Date(holidays[holidayIndex]);
                    if (holiday >= proxy._getDateFromFormat(proxy.startDate, model.dateFormat) && holiday <= startDate) {
                        startDate.setDate(startDate.getDate() + 1);
                        if (includeWeekend === false) {
                            if (startDate.getDay() == 0) {
                                startDate.setDate(startDate.getDate() + 1);
                            } else if (startDate.getDay() == 6) {
                                startDate.setDate(startDate.getDate() + 2);
                            }
                        }
                    }
                }
            }

            if (includeWeekend === false) {
                if (startDate.getDay() == 0)
                    startDate.setDate(startDate.getDate() + 1);
                else if (startDate.getDay() == 6)
                    startDate.setDate(startDate.getDate() + 2);
            }
            if (remainingHours > 0)
                startDate.setHours(remainingHours);//endDateHours
            if (endDateHours > 0) {
                if ((model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale8Hours) &&
                    model.durationUnit == ej.Gantt.DurationUnit.Hour) {
                    startDate.setHours(endDateHours);
                }
                else
                    startDate.setHours(endDateHours);
            }
            
            if (model.dateFormat.indexOf("hh:") &&
                      model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale8Hours &&
                model.scheduleHeaderSettings.scheduleHeaderType != ej.Gantt.ScheduleHeaderType.Day) {
                startDate.setHours(17);
            }
            else if (model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale24Hours
                && model.durationUnit == ej.Gantt.DurationUnit.Hour) {
                if (endDateHours > 0) {
                    startDate.setHours(endDateHours);
                }
                else
                    startDate.setHours(24);
            }

            
            proxy.endDate = proxy._calculateFormatedDate(startDate, model.dateFormat);
            if (model.endDateMapping)
                proxy.item[model.endDateMapping] = proxy.endDate;
        },

        _calculateTimeScale8Hour: function (startHour, duration) {
            var endHour = startHour;

            do {
                if ((startHour >= 8 && startHour < 13) || (startHour > 13 && startHour <= 17)) {
                    endHour++;
                    duration--;
                    startHour = startHour == 24 ? 0 : startHour + 1;
                }
                else {
                    startHour = startHour == 24 ? 0 : startHour + 1;
                    
                    endHour++;
                }
            } while (duration > 0);

            return endHour;
        },

        _dateUpdate: function (date, days,hours) {
            return new Date(
                date.getFullYear(),
                date.getMonth(),
                date.getDate() + days,
                date.getHours() + hours,
                date.getMinutes(),
                date.getSeconds(),
                date.getMilliseconds()
            );
        },


        _calculateDuration: function (startDate, endDate, includeWeekend, holidays, milestone,model) {
            var proxy = this,
            dateDiff;

            if (model.durationUnit == ej.Gantt.DurationUnit.Hour) {
                dateDiff = proxy._hourdiff(startDate, endDate);
                if (dateDiff < 0) {
                    //dateDiff = dateDiff * -1;
                }
                if (model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale8Hours) {
                }
            }
            else {
                dateDiff = proxy._daydiff(startDate, endDate);
            }

            if (includeWeekend === false)
                offset = proxy._calculateDateDifference(new Date(startDate), dateDiff);
            else {
                if (model.durationUnit != ej.Gantt.DurationUnit.Hour)
                    offset = dateDiff + 1;
                else
                    offset = dateDiff;
            }

            for (var count = 0; count < holidays.length; count++) {
                if (new Date(holidays[count].day) >= startDate && new Date(holidays[count].day) <= endDate) {
                    if (model.durationUnit == ej.Gantt.DurationUnit.Hour)
                        offset -= 24;
                    else
                        offset--;
                }
            }

            if (model.workingTimeScale == ej.Gantt.workingTimeScale.TimeScale24Hours ||
                model.durationUnit == ej.Gantt.DurationUnit.Hour) {

                var decimal = (offset - parseInt(offset, 10));
                decimal = (decimal * 10);
                if (decimal == 5) { offset = (parseInt(offset, 10) + 0.5); }

                else {
                    offset = Math.round(offset);
                }
            }
            //else if (model.scheduleHeaderSettings.scheduleHeaderType == ej.Gantt.ScheduleHeaderType.Day) {

            //    offset = Math.round(offset) - 1;
            //}
            else
                offset = Math.round(offset);

            if (ej.isNullOrUndefined(milestone))
                proxy.duration = offset;
            else
                proxy.duration = (offset == 0 && milestone == false) ? 1 : offset;
        },

        _calculateDateDifference: function (emptyDate, dateDiff) {
            var differenceCount = dateDiff >= 0 ? dateDiff : (-1 * dateDiff),
                offset = 0;

            if (dateDiff > 0)
                offset = differenceCount - this._calculateWeekendCount(emptyDate, dateDiff) + 1;
            else
                offset = dateDiff + this._calculateWeekendCount(emptyDate, dateDiff);
            return offset;
        },

        _calculateWeekendCount: function (emptyDate, dateDiff) {
            var differenceCount = dateDiff >= 0 ? dateDiff : (-1 * dateDiff),
                weekendCount = 0,
                i = 0;

            if (dateDiff > 0) {
                for (i = 0; i < dateDiff; i++) {
                    if (emptyDate.getDay() == 0) {
                        weekendCount++;
                        emptyDate.setDate(emptyDate.getDate() + 1);
                    }
                    else if (emptyDate.getDay() == 6) {
                        weekendCount += 2;
                        ++i;
                        emptyDate.setDate(emptyDate.getDate() + 2);
                    } else
                        emptyDate.setDate(emptyDate.getDate() + 1);
                }
            }
            else {
                for (i = 0; i < differenceCount; i++) {
                    emptyDate.setDate(emptyDate.getDate() - 1);
                    if (emptyDate.getDay() == 0 || emptyDate.getDay() == 6) {
                        weekendCount += 1;
                    }
                }
            }
            return weekendCount;
        },

        _daydiff: function (first, second) {
            return ((second - first) / (1000 * 60 * 60 * 24));
        },
               
        _hourdiff: function (first, second) {
            //if(first.getTime()>second.getTime())
            //    return ((first - second) / (1000 * 60 * 60));
            //else
                return ((second - first) / (1000 * 60 * 60));
        },

        _getProgressPercent: function (parentwidth, progresswidth) {
            return Math.ceil(((progresswidth / parentwidth) * 100).toFixed(2));
        },

    };

    ej.Gantt._getPredecessorsValue = function (mappingName) {
        return this.data.item ? this.data.item[mappingName] : "";
    };    

    ej.Gantt._getCellValue = function (columnName) {

        var cellValue = this.data[columnName];

        if (cellValue) {
            return cellValue;
        } else {
            return this.data.item && this.data.item[columnName];
        }


    };

})(jQuery, Syncfusion);