﻿(function ($, ej, undefined) {
	ej.gridFeatures = ej.gridFeatures || {};
   /**   
    * @classdesc The grid can be easily configured to the DOM element, such as div. you can create a grid with a highly customizable look and feel.
    * @class ejGrid
    * @param {object} options - settings for grid
    * @requires jQuery
    * @requires jquery.easing.min.js
    * @requires jquery.globalize.min.js    
    * @requires jsrender.min.js
    * @requires ej.core.js
    * @requires ej.data.js
    * @requires ej.grid.js
    * @requires ej.pager.js
    * @requires ej.scroller.js
    * @requires ej.waitingpopup.js
    * @requires ej.radiobutton.js
    * @requires ej.dropdownlist.js
    * @requires ej.dialog.js
    * @requires ej.button.js
    * @requires ej.autocomplete.js
    * @requires ej.checkbox.js
    * @requires ej.datepicker.js
    * @requires ej.datetimepicker.js
    * @requires ej.editor.js
    * @requires ej.toolbar.js
    * @example
    * &lt;div id="Grid"&gt;&lt;/div&gt; 
    * &lt;script&gt;
    * // Create Grid
    * $('#Grid').ejGrid({
    *     dataSource: window.gridData
    * });         
    * &lt;/script&gt;
    */
    ej.widget("ejGrid", "ej.Grid", /** @lends ejGrid# */ {
        //Root Css Class
        _rootCSS: "e-grid",
        // widget element will be automatically set in this
        element: null,
        validTags: ["div"],
        // user defined model will be automatically set in this
        model: null,
        keyConfigs: /** @lends ejGrid# */{
            focus: "e",
            insertRecord: "45", //Insert
            deleteRecord: "46", // delete
            editRecord: "113", //F2
            saveRequest: "13", // enter
            cancelRequest: "27", //Esc
            nextPage: "34", // PgDn
            previousPage: "33", // PgUp
            lastPage: "ctrl+alt+34", //"CtrlAltPgDn",
            firstPage: "ctrl+alt+33", //"CtrlPlusAltPlusPgUp",
            nextPager: "alt+34", //"AltPlusPgDown",
            previousPager: "alt+33", //"AltPlusPgUp",
            firstCellSelection: "36", //"Home",
            lastCellSelection: "35", //"End",
            firstRowSelection: "ctrl+36", //"CtrlPlusHome",
            lastRowSelection: "ctrl+35", //"CtrlPlusEnd",
            upArrow: "38", //Up arrow
            downArrow: "40", //Down arrow
            rightArrow: "39", //Right arrow
            leftArrow: "37", //Left arrow
            moveCellRight: "9", //tab
            moveCellLeft: "shift+9", //shifttab
            selectedGroupExpand: "alt+40", //"AltPlusDownArrow",
            totalGroupExpand: "ctrl+40", //"CtrlPlusDownArrow",
            selectedGroupCollapse: "alt+38", //"AltPlusUpArrow",
            totalGroupCollapse: "ctrl+38" //"CtrlPlusUpArrow",
        },
        _ignoreOnPersist: [
            "query", "isEdit", "toolbarClick", "queryCellInfo", "mergeCellInfo", "currentViewData", "enableAltRow", "enableRTL","contextClick","contextOpen",
            "rowDataBound", "rowTemplate", "detailsDataBound", "detailsTemplate", "childGrid", "summaryRows", "toolbarSettings",
            "editSettings", "allowMultiSorting", "enableAutoSaveOnSelectionChange", "locale", "allowScrolling", "allowCellMerging",
            "allowTextWrap", "cssClass", "dataSource", "groupSettings.enableDropAreaAnimation", "enableRowHover", "showSummary",
            "enableHeaderHover", "allowKeyboardNavigation", "scrollSettings.frozenRows", "scrollSettings.frozenColumns", "enableTouch", "editSettings.rowPosition", "contextMenuSettings.enableContextMenu",
        ],
        ignoreOnExport: [
            "isEdit", "toolbarClick", "query", "queryCellInfo", "selectionType", "currentViewData", "enableAltRow", "enableRTL", "rowDataBound", "rowTemplate",
            "detailsDataBound", "detailsTemplate", "editSettings", "pageSettings", "enableAutoSaveOnSelectionChange", "localization", "allowScrolling",
            "cssClass", "dataSource", "groupSettings.enableDropAreaAnimation", "enableRowHover", "allowSummary",
            "enableHeaderHover", "allowKeyboardNavigation"
        ],
        observables: ["dataSource", "selectedRowIndex", "pageSettings.currentPage"],
        _tags: [{
            tag: "columns",
            attr: ["allowEditing", "allowFiltering", "allowGrouping", "allowSorting", "cssClass", "customAttributes", "dataSource", "defaultValue",
			"disableHtmlEncode", "editTemplate", "editType", "foreignKeyField", "foreignKeyValue", "headerTemplateID", "headerText", "isFrozen",
			"isIdentity", "isPrimaryKey", "isUnbound", "textAlign", "templateID", "textAlign", "headerTextAlign",
            "validationRules.minLength","validationRules.maxLength", "validationRules.range","validationRules.number", "validationRules.required",
            "editParams.decimalPlaces", [{tag:"commands", attr:["type","buttonOptions"]}]            
            ],
            content: "template"
        },{
            tag: "summaryRows",
            attr: ["showCaptionSummary", "showTotalSummary", [{
                tag: "summaryColumns", attr: ["customSummaryValue", "dataMember", "displayColumn", "summaryType"]
            }]]
        },{
            tag: "stackedHeaderRows",
            attr: [
            [{
            tag: "stackedHeaderColumns", attr:["headerText","column"]
            }]]            
        },{ 
			tag:"filterSettings.filteredColumns", attr: []
		},{ 
			tag:"sortSettings.sortedColumns", attr: [] 
		}],
        _dataSource: ej.util.valueFunction("dataSource"),
        _selectedRow: ej.util.valueFunction("selectedRowIndex"),
        _currentPage: ej.util.valueFunction("pageSettings.currentPage"),
        // default model
        defaults: /** @lends ejGrid# */ {

            /**		
             * This specifies the grid to show the paginated data. Also enables pager control at the bottom of grid for dynamic navigation through data source. Paging can be further customized through “pageSettings” property.
             * @default false
             * @type {boolean}
             * @example            
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *     dataSource:window.gridData,
             *     allowPaging:true                      
             * });
             * &lt;/script&gt;                 
             */
            allowPaging: false,
            /**		
             * Gets or sets a value that indicates whether to enable column chooser on grid. On enabling feature able to show/hide grid columns                       
             * @default false
             * @type {boolean}
             * @example            
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *     dataSource:window.gridData,
             *     showColumnChooser:true                      
             * });
             * &lt;/script&gt;                 
             */
            showColumnChooser: false,
            /**		
             * Gets or sets a value that indicates whether to  enable the dynamic sorting behaviour on grid data. Sorting can be done through clicking on particular column header.
             * @default false
             * @type {boolean}
             * @example  
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    dataSource:window.gridData,
             *    allowSorting:true                       
             * });
             * &lt;/script&gt; 
             */
            allowSorting: false,
            /**		
            * Gets or sets a value that indicates stacked header should be shown on grid layout when the property “stackedHeaderRows” is set.  
            * @default false
            * @type {boolean}
            * @example  
            * &lt;div id="Grid"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#Grid").ejGrid({
            *    dataSource:window.gridData,
            *    allowSorting:true,
            *    showStackedHeader:true,
            *    stackedHeaderRows:[{stackedHeaderColumns:[{headerText:"ID & Freight",column:"CustomerID"}
			*	 ,{headerText:"Frieght",column:"Freight,EmployeeID,OrderDate"}
			*	 ,{headerText:"Date & Location Top Level",column:"ShipCity"}
			*	   ]}
			*	  ],
            *    columns: [
            *       { field: "CustomerID", headerText: "Customer ID", width: 80 },
            *        { field: "EmployeeID", headerText: "Employee ID", width: 75, textAlign: ej.TextAlign.Right },
            *       { field: "Freight", width: 75, format: "{0:C}", textAlign: ej.TextAlign.Right },
            *        { field: "OrderDate", headerText: "Order Date", width: 80, format: "{0:MM/dd/yyyy}", textAlign: ej.TextAlign.Right },
            *       { field: "ShipCity", headerText: "Ship City", width: 110 }
            *       ]
            * });
            * &lt;/script&gt; 
            */
            showStackedHeader: false,
            /**		
            * Gets or sets an object that indicates to managing the collection of stacked header rows for the grid.
            * @remark
            * We must set the showStackedHeader as true
            * @default []
            * @name ejGrid#stackedHeaderRows
            * @type {array}
            * @example  
            * &lt;div id="Grid"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#Grid").ejGrid({
            *    dataSource:window.gridData,
            *    allowSorting:true,
            *    showStackedHeader:true,
            *    stackedHeaderRows:[{stackedHeaderColumns:[{headerText:"ID & Freight",column:"CustomerID"}
			*	 ,{headerText:"Frieght",column:"Freight,EmployeeID,OrderDate"}
			*	 ,{headerText:"Date & Location Top Level",column:"ShipCity"}
			*	   ]}
			*	  ],
            *    columns: [
            *       { field: "CustomerID", headerText: "Customer ID", width: 80 },
            *        { field: "EmployeeID", headerText: "Employee ID", width: 75, textAlign: ej.TextAlign.Right },
            *       { field: "Freight", width: 75, format: "{0:C}", textAlign: ej.TextAlign.Right },
            *        { field: "OrderDate", headerText: "Order Date", width: 80, format: "{0:MM/dd/yyyy}", textAlign: ej.TextAlign.Right },
            *       { field: "ShipCity", headerText: "Ship City", width: 110 }
            *       ]
            * });
            * &lt;/script&gt; 
            */
            /**		
             * Gets or sets a value that indicates whether to add stacked header columns into the stacked header rows
             * @remarks
             * We must enable the showStackedHeader 
             * @name ejGrid#stackedHeaderRows->stackedHeaderColumns
             * @default []
             * @type {array}
             * @example  
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    dataSource:window.gridData,
             *    allowSorting:true,
             *    showStackedHeader:true,
             *    stackedHeaderRows:[{stackedHeaderColumns:[{headerText:"ID & Freight",column:"CustomerID"}
             *	 ,{headerText:"Frieght",column:"Freight,EmployeeID,OrderDate"}
             *	 ,{headerText:"Date & Location Top Level",column:"ShipCity"}
             *	   ]}
             *	  ],
             *    columns: [
             *       { field: "CustomerID", headerText: "Customer ID", width: 80 },
             *        { field: "EmployeeID", headerText: "Employee ID", width: 75, textAlign: ej.TextAlign.Right },
             *       { field: "Freight", width: 75, format: "{0:C}", textAlign: ej.TextAlign.Right },
             *        { field: "OrderDate", headerText: "Order Date", width: 80, format: "{0:MM/dd/yyyy}", textAlign: ej.TextAlign.Right },
             *       { field: "ShipCity", headerText: "Ship City", width: 110 }
             *       ]
             * });
             * &lt;/script&gt; 
             **/
             /**		
             * Gets or sets a value that indicates the header text for the particular stacked header column.
             * @remarks
             * We must enable the showStackedHeader 
             * @name ejGrid#stackedHeaderRows->stackedHeaderColumns->headerText
             * @default null
             * @type {string}
             * @example  
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    dataSource:window.gridData,
             *    allowSorting:true,
             *    showStackedHeader:true,
             *    stackedHeaderRows:[{stackedHeaderColumns:[{headerText:"ID & Freight",column:"CustomerID"}
             *	 ,{headerText:"Frieght",column:"Freight,EmployeeID,OrderDate"}
             *	 ,{headerText:"Date & Location Top Level",column:"ShipCity"}
             *	   ]}
             *	  ],
             *    columns: [
             *       { field: "CustomerID", headerText: "Customer ID", width: 80 },
             *        { field: "EmployeeID", headerText: "Employee ID", width: 75, textAlign: ej.TextAlign.Right },
             *       { field: "Freight", width: 75, format: "{0:C}", textAlign: ej.TextAlign.Right },
             *        { field: "OrderDate", headerText: "Order Date", width: 80, format: "{0:MM/dd/yyyy}", textAlign: ej.TextAlign.Right },
             *       { field: "ShipCity", headerText: "Ship City", width: 110 }
             *       ]
             * });
             * &lt;/script&gt; 
             **/
            /**		
            * Gets or sets a value that indicates the header text for the particular stacked header column.
            * @remarks
            * We must enable the showStackedHeader 
            * @name ejGrid#stackedHeaderRows->stackedHeaderColumns->column
            * @default null
            * @type {string}
            * @example  
            * &lt;div id="Grid"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#Grid").ejGrid({
            *    dataSource:window.gridData,
            *    allowSorting:true,
            *    showStackedHeader:true,
            *    stackedHeaderRows:[{stackedHeaderColumns:[{headerText:"ID & Freight",column:"CustomerID"}
            *	 ,{headerText:"Frieght",column:"Freight,EmployeeID,OrderDate"}
            *	 ,{headerText:"Date & Location Top Level",column:"ShipCity"}
            *	   ]}
            *	  ],
            *    columns: [
            *       { field: "CustomerID", headerText: "Customer ID", width: 80 },
            *        { field: "EmployeeID", headerText: "Employee ID", width: 75, textAlign: ej.TextAlign.Right },
            *       { field: "Freight", width: 75, format: "{0:C}", textAlign: ej.TextAlign.Right },
            *        { field: "OrderDate", headerText: "Order Date", width: 80, format: "{0:MM/dd/yyyy}", textAlign: ej.TextAlign.Right },
            *       { field: "ShipCity", headerText: "Ship City", width: 110 }
            *       ]
            * });
            * &lt;/script&gt; 
            **/
			stackedHeaderRows: [],
            /**		
             * Gets or sets a value that indicates whether to enable dynamic filtering behaviour on grid. Filtering can be used to limit the records displayed using required criteria and this can be further customized through “filterSettings” property
             * @default false
             * @type {boolean}
             * @example  
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    dataSource:window.gridData,
             *    allowFiltering:true                       
             * });
             * &lt;/script&gt;
             */
            allowMultipleExporting:false,
            allowFiltering: false,
            /**		
             * Gets or sets a value that indicates whether user can select rows on grid. On enabling feature, selected row will be highlighted. 
             * @default true
             * @type {boolean}
             * @example 
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    dataSource:window.gridData,
             *    allowSelection:true                      
             * });
             * &lt;/script&gt; 
             */
            allowSelection: true,
            /**		
             * Gets or sets a value that indicates whether to enable dynamic grouping behaviour. Grouping can be done by drag on drop desired columns to grid’s GroupDropArea. This can be further customized through “groupSettings” property.
             * @default false
             * @type {boolean}
             * @example 
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    dataSource:window.gridData,
             *    allowGrouping:true                      
             * });
             * &lt;/script&gt; 
             */
            allowGrouping: false,
            /**		
             * Gets or sets a value that indicates summary rows should be shown on grid layout when the property “summaryRows” is set
             * @remarks
             * showSummary must be set as true.
             * summaryRows and summaryColumns must be given. See {@link ejGrid#summaryRows}
             * @default false
             * @type {boolean}
             * @example 
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *     dataSource:window.gridData,
             *     columns: [{ field: "OrderID"}, { field: "Freight" }, { field: "ShipCity" }],
             *     showSummary:true,
             *     summaryRows:[{ title: "sum", summaryColumns: [{summaryType:ej.Grid.SummaryType.Count,displayColumn:"Freight",dataMember:"Freight"}]}]       
             * });
             * &lt;/script&gt;  
             */
            showSummary: false,
            /**		
             * Gets or sets a value that indicates whether to enable dynamic resizabiliy of columns. . Resize the width of the columns by simply click and move the particular column header line
             * @remarks
             * When allowResizing is enabled then we must specify the following properties
             * 1. allowScrolling must be set as true
             * 2. Provide the scrollSettings after enable the allowScrolling. See{@link ejGrid#scrollSettings}            
             * @default false
             * @type {boolean}
             * @example 
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *     dataSource:window.gridData,
             *     allowResizing:true,
             *     allowScrolling:true,
             *     scrollSettings:{width:300,height:300}
             * });
             * &lt;/script&gt; 
             */
            allowResizing: false,
            /**		
            * Gets or sets a value that indicates whether the Content will wrap to the next line if the content exceeds the boundary of the Column Cells.
            * @default false
            * @type {boolean}
            * @example 
            * &lt;div id="Grid"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#Grid").ejGrid({
            *    dataSource:window.gridData,
            *    allowTextWrap:true                      
            * });
            * &lt;/script&gt; 
            */
            allowTextWrap: false,
			/**		
             * Gets or sets a value that indicates whether to customizing cell based on our needs.
             * @remarks
             * Provide the mergeSettings after enable the allowCellMerging. See{@link ejGrid#mergeSettings}            
             * @default false
             * @type {boolean}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   allowCellMerging:true,
             * });
             * &lt;/script&gt; 
             */
            allowCellMerging: false,
            /**		
             * Gets or sets a  value that indicates whether to enable mouse over effect on corresponding grid row.
             * @default true
             * @type {boolean}
             * @example 
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    dataSource:window.gridData,
             *    enableRowHover:true
             * });
             * &lt;/script&gt; 
             */
            enableRowHover: true,
            /**		
             * Gets or sets a value that indicates whether to persist the grid model state in page using applicable medium i.e., HTML5 localStorage or cookies
             * @default false
             * @type {boolean}
             * @example  
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *     dataSource:window.gridData,
             *     allowGrouping: true,
             *     enablePresistence:true
             * });
             * &lt;/script&gt; 
             */
            enablePersistence: false,
            /**		
             * Gets or sets a value that indicates to select the row while initializing the grid
             * @remarks
             * allowSelection must be set as true.
             * @default -1
             * @type {number}
             * @example 
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *     dataSource:window.gridData,
             *     selectedRowIndex:1
             * });
             * &lt;/script&gt; 
             */
            selectedRowIndex: -1,
            /**		
             * Gets or sets a value that indicates whether to enable dynamic searching behaviour in grid. Currently search box can be enabled through “toolbarSettings”
             * @remarks
             * While enabling allowSearching then we must enable toolbar in the grid and add search option in the toolbaritem. See {@link ejGrid#toolbarSettings}
             * @default false
             * @type {boolean}
             * @example 
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *     dataSource:window.gridData,
             *     allowSearching: true,
             *     toolbarSettings:{showToolbar:true,toolbarItems:[ej.Grid.ToolBarItems.Search]}
             * });
             * &lt;/script&gt; 
             */
            allowSearching: false,
            /**		
             * Gets or sets a value that indicates whether to enable mouse over effect  on the corresponding column header cell of the grid
             * @default false
             * @type {boolean}
             * @example 
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    dataSource:window.gridData,
             *    enableHeaderHover:true
             * });
             * &lt;/script&gt; 
             */
            enableHeaderHover: false,
            /**		
             * Gets or sets a value that indicates whether to enable the columns reordering behaviour in the grid.  Reordering can be done through by drag and drop the particular column from one index to another index within the grid.
             * @default false
             * @type {boolean}
             * @example  			
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    dataSource:window.gridData,
             *    allowReordering:true
             * });
             * &lt;/script&gt; 
             */
            allowReordering: false,
            /**		
             * Gets or sets a value that indicates whether to enable keyboard support for performing grid actions. selectionType – Gets or sets a value that indicates whether to enable single row or multiple rows selection behaviour in grid. Multiple selection can be done through by holding CTRL and clicking the grid rows
             * @default true
             * @type {boolean}
             * @example 
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *     dataSource:window.gridData,
             *     allowKeyboardNavigation:false
             * });
             * &lt;/script&gt; 
             */
            allowKeyboardNavigation: true,
            /**		
             * To Disable the mouse swipe property as false.
             * @default true
             * @type {boolean}
             * @example 
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *     dataSource:window.gridData,
             *     enableTouch:false
             * });
             * &lt;/script&gt; 
             */
            enableTouch: true,
            /**		
             * The row selection behavior of grid. Accepting types are "single" and "multiple".
             * @remarks
             * allowSelection must be set as true while using selectionType.
             * @default ej.Grid.SelectionType.Single
             * @type {enum}
             * @example 
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    dataSource:window.gridData,
             *    selectionType:"multiple"
             * });
             * &lt;/script&gt; 
             */
            selectionType: "single",
            /**		
			 * Gets or sets the data to render  the grid with records
			 * @default null
			 * @type {object}
			 * @example 
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
			 * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    dataSource:window.gridData
             * });
             * &lt;/script&gt; 
			 */
            dataSource: null,
            /**		
			 * Gets or sets a value that indicates to render the grid with custom theme. allowScrolling – Gets or sets a value that indicates whether to enable the scrollbar in the grid and view the records by scroll through the grid manually
			 * @default ""
			 * @type {string}
			 * @example 
			 * &lt;div id="Grid"&gt;&lt;/div&gt;
             * &lt;style type="text/css"&gt;
             *    .gradient-green {
             *        font-family: cursive;
             *    }
             *    .gradient-green .e-alt_row {
             *        background: none repeat scroll 0 0 #71A409;
             *    }
             * &lt;/style&gt;
			 * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    dataSource:window.gridData,
             *    cssClass: "gradient-green"
             * });
             * &lt;/script&gt; 
			 */
            cssClass: "",
            /**		
             * Gets or sets a value that indicates whether to enable the scrollbar in the grid and view the records by scroll through the grid manually
             * @remarks
             * Provide the scrollSettings after enable the allowScrolling. See{@link ejGrid#scrollSettings}            
             * @default false
             * @type {boolean}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   allowScrolling:true,
             *   scrollSettings:{width:300,height:100}
             * });
             * &lt;/script&gt; 
             */
            allowScrolling: false,
            /**		
             * Gets or sets a value that indicates whether to customizing the user interface (UI) as locale-specific in order to display regional data i.e. in a language and culture specific to a particular country or region.
             * @default "en-US"
             * @type {string}
             * @example 
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * ej.Pager.locale["es-ES"] = {
             *    pagerInfo: "{0} de {1} páginas ({2} artículos)"
             * };
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   allowPaging:true,
             *   locale : "es-ES" 
             * });
             * &lt;/script&gt;             
             */
            locale: "en-US",
            /**		
             * Gets or sets a value that indicates whether to enable the save action in the grid  through row selection
             * @remarks
             * When enableAutoSaveOnSelectionChange property value as false, then we must include edit option in toolbar and also set allowEditing as true.
             * @default true
             * @type {boolean}
             * @example 
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *     dataSource:window.gridData,
             *     editSettings: { allowEditing: true },
             *     toolbarSettings: { showToolbar: true, toolbarItems: ["cancel", "save"]},
             *     columns: [{ field: "OrderID", isPrimaryKey: true }, { field: "CustomerID" }, { field: "ShipCity" }],
             *     enableAutoSaveOnSelectionChange: false
             * });
             * &lt;/script&gt; 
             */
            enableAutoSaveOnSelectionChange: true,
            /**		
             * Gets or sets a value that indicates whether to enable multi columns sorting behaviour in grid. Sort multiple columns by holding CTRL and click on the corresponding column header.
             * @remarks
             * allowSorting must be set as true while enabling allowMultiSorting. 
             * @default false
             * @type {boolean}
             * @example 
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   allowSorting:true,
             *   allowMultiSorting:true
             * });
             * &lt;/script&gt; 
             */
            allowMultiSorting: false,
            exportToExcelAction:"",
            exportToWordAction:"",
            exportToPdfAction:"",
            /**		
             * Gest or sets an object that indicates whether to customize the editing behaviour of the grid.
             * @type {Object}
             */
            editSettings: /** @lends ejGrid# */ {
                /**		
                 * Gets or sets a value that indicates whether  to enable the edit action in the editing mode.
                 * @remarks
                 * When allowEditing is enabled then we must set columns property "isPrimaryKey" as true for primary column.
                 * We can edit the record in the grid by the following ways.
                 *   1. Enable toolbar in the grid and add editing option in the toolbaritem and click the "edit" icon which is in the toolbar. See {@link ejGrid#toolbarSettings}
                 *   2. Press function key F2.
                 *   3. Double click on the record.
                 * @alias ejGrid#editSettings->allowEditing
                 * @default false
                 * @type {boolean}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *     dataSource: window.gridData,
                 *     columns: [{ field: "OrderID", isPrimaryKey: true }, { field: "CustomerID" }, { field: "ShipCity" }],
                 *     editSettings: { allowEditing: true },
                 *     toolbarSettings: { showToolbar: true, toolbarItems: ["edit"] }
                 * });
                 * &lt;/script&gt;              
                 */
                allowEditing: false,
                /**		
                 * Gets or sets a value that indicates whether  to enable insert action in the editing mode.
                 * @remarks
                 * When allowAdding is enabled then we must set columns property "isPrimaryKey" as true for primary column.
                 * We can add a new record in the grid by the following ways.
                 *   1. Enable toolbar in the grid and include add record option in the toolbaritem and click the "add" icon which is in the toolbar. See {@link ejGrid#toolbarSettings}
                 *   2. Press Insert key.                 
                 * @alias ejGrid#editSettings->allowAdding
                 * @default false
                 * @type {boolean}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *     dataSource: window.gridData,
                 *     columns: [{ field: "OrderID", isPrimaryKey: true }, { field: "CustomerID" }, { field: "ShipCity" }],
                 *     editSettings: { allowAdding: true },
                 *     toolbarSettings: { showToolbar: true, toolbarItems: ["add"] }                             
                 * });
                 * &lt;/script&gt;                 
                 */
                allowAdding: false,
                /**		
                 * Gets or sets a value that indicates whether  to enable the delete action in the editing mode.
                 * @remarks
                 * When allowDeleting is enabled then we must set columns property "isPrimaryKey" as true for primary column.
                 * We can delete a record in the grid by the following ways.
                 *   1. Enable toolbar in the grid and include delete option in the toolbaritem and click the "delete" icon which is in the toolbar. See {@link ejGrid#toolbarSettings}
                 *   2. Press Delete key. 
                 * @alias ejGrid#editSettings->allowDeleting
                 * @default false
                 * @type {boolean}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 *&lt;script&gt;
                 * $("#Grid").ejGrid({
                 *     dataSource: window.gridData,
                 *     columns: [{ field: "OrderID", isPrimaryKey: true }, { field: "CustomerID" }, { field: "ShipCity" }],
                 *     editSettings: { allowDeleting: true },
                 *     toolbarSettings: { showToolbar: true, toolbarItems: ["delete"] }      
                 * });
                 * &lt;/script&gt;                  
                 */
                allowDeleting: false,
                /**		
                 * Gets or sets a value that indicates whether to define the mode of editing See {@link editMode}
                 * @remarks
                 * When allowAdding/allowEditing is enabled then we must set columns property "isPrimaryKey" as true for primary column.
                 * We must enable allowEditing or allowAdding property
                 * If allowAdding is enable then we must enable toolBar in the grid and include the "add" option as the toolBarItem. See {@link ejGrid#toolbarSettings}
                 * @alias ejGrid#editSettings->editMode
                 * @default ej.Grid.EditMode.Normal
                 * @type {enum}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt;
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *     dataSource: window.gridData,
                 *     columns: [{ field: "OrderID", isPrimaryKey: true }, { field: "CustomerID" }, { field: "ShipCity" }],
                 *     editSettings: { allowEditing: true, editMode: ej.Grid.EditMode.Dialog },
                 *     toolbarSettings: { showToolbar: true, toolbarItems: ["edit"] }                             
                 * });
                 * &lt;/script&gt;                          
                 */
                editMode: "normal",
                /**		
                 * This specifies to set the position of an adding new row either in the top or bottom of the grid
                 * @remarks
                 * When allowAdding/allowEditing is enabled then we must set columns property "isPrimaryKey" as true for primary column.
                 * We must enable allowEditing or allowAdding property
                 * If allowAdding is enable then we must enable toolBar in the grid and include the "add" option as the toolBarItem. See {@link ejGrid#toolbarSettings}
                 * @alias ejGrid#editSettings->rowPosition
                 * @default ej.Grid.RowPosition.top
                 * @type {enum}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt;
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *     dataSource: window.gridData,
                 *     columns: [{ field: "OrderID", isPrimaryKey: true }, { field: "CustomerID" }, { field: "ShipCity" }],
                 *     editSettings: { allowEditing: true, allowAdding:true, rowPosition:"bottom" },
                 *     toolbarSettings: { showToolbar: true, toolbarItems: ["add"]  },                             
                 * });
                 * &lt;/script&gt;                          
                 */
                rowPosition: "top",
                /**		
                 * This specifies the id of the template. This template can be used to display the data that you require to be edited using the Dialog Box
                 * @remarks
                 * When dialogEditorTemplateID is used then we must set columns property "isPrimaryKey" as true for primary column.
                 * We must enable allowEditing or allowAdding property
                 * If allowAdding is enable then we must enable toolBar in the grid and include the "add" option as the toolBarItem. See {@link ejGrid#toolbarSettings}
                 * While using dialogEditorTemplateID then editMode must be "ej.Grid.EditMode.DialogTemplate". See {@link editMode}
                 * Provide the template in the script tag and select type as "text/template" and assign the script id as the "dialogEditorTemplateID"
                 * @alias ejGrid#editSettings->dialogEditorTemplateID
                 * @default null
                 * @type {string}
                 * @example               
                 * &lt;div id="Grid"&gt;&lt;/div&gt;
                 * &lt;script id="template" type="text/template"&gt;
                 *    &lt;table&gt;
                 *        &lt;tr&gt;
                 *            &lt;td&gt;OrderID&lt;/td&gt;
                 *            &lt;td&gt;
                 *                &lt;input id="OrderID" name="OrderID" value="{{: OrderID}}" disabled="disabled" /&gt;&lt;/td&gt;
                 *        &lt;/tr&gt;
                 *        &lt;tr&gt;
                 *            &lt;td&gt;CustomerID&lt;/td&gt;
                 *            &lt;td&gt;
                 *                &lt;input id="CustomerID" name="CustomerID" value="{{: CustomerID}}" /&gt;&lt;/td&gt;
                 *        &lt;/tr&gt;
                 *        &lt;tr&gt;
                 *            &lt;td&gt;EmployeeID&lt;/td&gt;
                 *            &lt;td&gt;
                 *                &lt;input id="EmployeeID" name="EmployeeID" value="{{: EmployeeID}}" /&gt;&lt;/td&gt;
                 *        &lt;/tr&gt;
                 *    &lt;/table&gt;
                 * &lt;/script&gt;
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *     dataSource: window.gridData,
                 *     columns: [{ field: "OrderID", isPrimaryKey: true }, { field: "CustomerID" }, { field: "ShipCity" }],
                 *     editSettings: { allowEditing: true, editMode: ej.Grid.EditMode.DialogTemplate, dialogEditorTemplateID: "#template" },
                 *     toolbarSettings: { showToolbar: true, toolbarItems: ["edit"] }                             
                 * });
                 * &lt;/script&gt;                
                 */
                dialogEditorTemplateID: null,
                /**		
                 * Gets or sets a value that indicates whether  to enable the editing action while double click on the record
                 * @remarks
                 * When allowEditOnDblClick is set as false then we must enable toolbar in the grid and also include "edit" option in toolbaritem. Because if false is set then, record is not edited while double click on the row.
                 * We must enable allowEditing property
                 * When allowEditOnDblClick is used then we must set columns property "isPrimaryKey" as true for primary column.
                 * @alias ejGrid#editSettings->allowEditOnDblClick
                 * @default true
                 * @type {boolean}
                 * @example
                 * Defining editEvent with edit option:
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt; 
                 * $("#Grid").ejGrid({
                 *     dataSource: window.gridData,
                 *     columns: [{ field: "OrderID", isPrimaryKey: true }, { field: "CustomerID" }, { field: "ShipCity" }],
                 *     editSettings: { allowEditing: true, allowEditOnDblClick: false },
                 *     toolbarSettings: { showToolbar: true, toolbarItems: ["edit"] }      
                 * });
                 * &lt;/script&gt; 
                 */
                allowEditOnDblClick: true,
                /**		
                 * - This specifies the id of the template. This template can be used to display the data that you require to be edited using the External edit form
                 * @remarks
                 * We must enable allowEditing or allowAdding property
                 * If allowAdding is enable then we must enable toolBar in the grid and include the "add" option as the toolBarItem. See {@link ejGrid#toolbarSettings}
                 * When externalFormTemplateID is used then we must set columns property "isPrimaryKey" as true for primary column.
                 * While using externalFormTemplateID then editMode must be "ej.Grid.EditMode.ExternalFormTemplate". See {@link editMode}
                 * Provide the template in the script tag and select type as "text/template" and assign the script id as the "externalFormTemplateID"
                 * @alias ejGrid#editSettings->externalFormTemplateID
                 * @default null
                 * @type {string}
                 * @example               
                 * &lt;div id="Grid"&gt;&lt;/div&gt;
                 * &lt;script id="template" type="text/template"&gt;
                 *    &lt;table&gt;
                 *        &lt;tr&gt;
                 *            &lt;td&gt;OrderID&lt;/td&gt;
                 *            &lt;td&gt;
                 *                &lt;input id="OrderID" name="OrderID" value="{{: OrderID}}" disabled="disabled" /&gt;&lt;/td&gt;
                 *        &lt;/tr&gt;
                 *        &lt;tr&gt;
                 *            &lt;td&gt;CustomerID&lt;/td&gt;
                 *            &lt;td&gt;
                 *                &lt;input id="CustomerID" name="CustomerID" value="{{: CustomerID}}" /&gt;&lt;/td&gt;
                 *        &lt;/tr&gt;
                 *        &lt;tr&gt;
                 *            &lt;td&gt;EmployeeID&lt;/td&gt;
                 *            &lt;td&gt;
                 *                &lt;input id="EmployeeID" name="EmployeeID" value="{{: EmployeeID}}" /&gt;&lt;/td&gt;
                 *        &lt;/tr&gt;
                 *    &lt;/table&gt;
                 * &lt;/script&gt;
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *     dataSource: window.gridData,
                 *     columns: [{ field: "OrderID", isPrimaryKey: true }, { field: "CustomerID" }, { field: "ShipCity" }],
                 *     editSettings: { allowEditing: true, editMode: ej.Grid.EditMode.ExternalFormTemplate, externalFormTemplateID: "#template" },
                 *     toolbarSettings: { showToolbar: true, toolbarItems: ["edit"] }                             
                 * });
                 * &lt;/script&gt;                
                 */
                externalFormTemplateID: null,
                /**		
                 * This specifies the id of the template. This template can be used to display the data that you require to be edited using the Inline edit form 
                 * @remarks
                 * We must enable allowEditing or allowAdding property
                 * If allowAdding is enable then we must enable toolBar in the grid and include the "add" option as the toolBarItem. See {@link ejGrid#toolbarSettings}
                 * When inlineFormTemplateID is used then we must set columns property "isPrimaryKey" as true for primary column.
                 * While using inlineFormTemplateID then editMode must be "ej.Grid.EditMode.InlineFormTemplate". See {@link editMode}
                 * Provide the template in the script tag and select type as "text/template" and assign the script id as the "inlineFormTemplateID"
                 * @alias ejGrid#editSettings->inlineFormTemplateID
                 * @default null
                 * @type {string}
                 * @example               
                 * &lt;div id="Grid"&gt;&lt;/div&gt;
                 * &lt;script id="template" type="text/template"&gt;
                 *    &lt;table&gt;
                 *        &lt;tr&gt;
                 *            &lt;td&gt;OrderID&lt;/td&gt;
                 *            &lt;td&gt;
                 *                &lt;input id="OrderID" name="OrderID" value="{{: OrderID}}" disabled="disabled" /&gt;&lt;/td&gt;
                 *        &lt;/tr&gt;
                 *        &lt;tr&gt;
                 *            &lt;td&gt;CustomerID&lt;/td&gt;
                 *            &lt;td&gt;
                 *                &lt;input id="CustomerID" name="CustomerID" value="{{: CustomerID}}" /&gt;&lt;/td&gt;
                 *        &lt;/tr&gt;
                 *        &lt;tr&gt;
                 *            &lt;td&gt;EmployeeID&lt;/td&gt;
                 *            &lt;td&gt;
                 *                &lt;input id="EmployeeID" name="EmployeeID" value="{{: EmployeeID}}" /&gt;&lt;/td&gt;
                 *        &lt;/tr&gt;
                 *    &lt;/table&gt;
                 * &lt;/script&gt;
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *     dataSource: window.gridData,
                 *     columns: [{ field: "OrderID", isPrimaryKey: true }, { field: "CustomerID" }, { field: "ShipCity" }],
                 *     editSettings: { allowEditing: true, editMode: ej.Grid.EditMode.InlineTemplateForm, inlineFormTemplateID: "#template" },
                 *     toolbarSettings: { showToolbar: true, toolbarItems: ["edit"] }                             
                 * });
                 * &lt;/script&gt;                
                 */
                inlineFormTemplateID: null,
                /**		
                 * This specifies  to set the position of an External edit form either in the top-right or bottom-left of the grid
                 * @remarks
                 * We must enable allowEditing or allowAdding property.
                 * If allowAdding is enable then we must enable toolBar in the grid and include the "add" option as the toolBarItem. See {@link ejGrid#toolbarSettings}
                 * When formPosition is used then editMode must be "ej.Grid.EditMode.ExternalFormTemplate" or "ej.Grid.editMode.ExternalForm".
                 * We must set columns property "isPrimaryKey" as true for primary column.
                 * @alias ejGrid#editSettings->formPosition
                 * @default ej.Grid.FormPosition.BottomLeft
                 * @type {enum}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt;
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *     dataSource: window.gridData,
                 *     columns: [{ field: "OrderID", isPrimaryKey: true }, { field: "CustomerID" }, { field: "ShipCity" }],
                 *     editSettings: { allowAdding: true, allowEditing: true, editMode: ej.Grid.EditMode.ExternalForm, formPosition: ej.Grid.FormPosition.BottomLeft },
                 *     toolbarSettings: { showToolbar: true, toolbarItems: ["edit"] }                             
                 * });
                 * &lt;/script&gt;    
                 */
                formPosition: "bottomleft",
                /**		
                 * Gets or sets a value that indicates whether the confirm dialog has to be shown while saving or discarding the batch changes  
                 * @remarks
                 * We must set the editMode as batch.
                 * We must enable allowEditing,allowAdding or allowDeleting property                 
                 * @alias ejGrid#editSettings->showConfirmDialog
                 * @default true
                 * @type {boolean}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt;
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *     dataSource: window.gridData,
                 *     columns: [{ field: "OrderID", isPrimaryKey: true }, { field: "CustomerID" }, { field: "ShipCity" }],
                 *     editSettings: { allowEditing: true, editMode: ej.Grid.EditMode.Batch, showConfirmDialog:false },
                 *     toolbarSettings: { showToolbar: true, toolbarItems: ["edit","update","cancel"] }                             
                 * });
                 * &lt;/script&gt;                          
                 */
                showConfirmDialog: true,
                /**		
                 * Gets or sets a value that indicates whether the confirm dialog  has to be shown while deleting record
                 * @remarks
                 * We must enable allowDeleting property                 
                 * @alias ejGrid#editSettings->showDeleteConfirmDialog
                 * @default false
                 * @type {boolean}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt;
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *     dataSource: window.gridData,
                 *     columns: [{ field: "OrderID", isPrimaryKey: true }, { field: "CustomerID" }, { field: "ShipCity" }],
                 *     editSettings: { allowDeleting: true, showDeleteConfirmDialog:true },
                 *     toolbarSettings: { showToolbar: true, toolbarItems: ["edit","update","cancel"] }                             
                 * });
                 * &lt;/script&gt;                          
                 */
                showDeleteConfirmDialog: false
            },
            /**		
            * This property is used to configure the selection behaviour of the grid.            
            * @type Object
            */
            selectionSettings: /** @lends ejGrid# */ {

                /**		
                * Gets or sets  a value that indicates whether to add the default selection actions as a seleciton mode.See {@link selectionMode}
                * @remarks
                * We must enable allowSelection property
                * @alias ejGrid#selectionSettings->selectionMode
                * @default ["row"]
                * @type {enum}
                * @example
                * &lt;div id="Grid"&gt;&lt;/div&gt; 
                * &lt;script&gt;
                * $("#Grid").ejGrid({
                *    dataSource:window.gridData,
                *    allowSelection: true,   
                *    selectionSettings: {selectionMode: ["row","cell","column"] }
                * });
                * &lt;/script&gt;
                */
                selectionMode: ["row"],

                /**		
                * Gets or sets a value that indicates whether to enable the toggle selction behaviour for row, cell and column.
                * @remarks
                * When enableToggle is defined in selectionSettings then "allowSelection" must be set as true.
                * @alias ejGrid#selectionSettings->enableToggle
                * @default false
                * @type {boolean}
                * @example
                * &lt;div id="Grid"&gt;&lt;/div&gt; 
                * &lt;script&gt;
                * $("#Grid").ejGrid({
                *     dataSource:  window.gridData,
                *     allowSelection: true,   
                *     selectionSettings: {enableToggle: true }
                * });
                * &lt;/script&gt;
                */
                enableToggle: false
            },

            /**		
             * Gets or sets an object that indicates whether to modify the pager default configuration.     
             * @type Object
             */
            pageSettings: /** @lends ejGrid# */ {
                /**		
                 * Gets or sets a value that indicates whether to define the number of records displayed per page
                 * @remarks
                 * When pageSize is defined in pageSettings then "allowPaging" must be set as true.
                 * @alias ejGrid#pageSettings->pageSize
                 * @default 12
                 * @type {number}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *     dataSource: window.gridData,
                 *     allowPaging: true,   
                 *     pageSettings: { pageSize: 2 }
                 * });
                 * &lt;/script&gt;
                 */
                pageSize: 12,
                /**		
                 * Gets or sets a value that indicates whether to define the number of pages displayed in the pager for navigation
                 * @remarks
                 * When pageCount is defined in pageSettings then "allowPaging" must be set as true.
                 * @alias ejGrid#pageSettings->pageCount
                 * @default 8
                 * @type {number}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *     dataSource: window.gridData,
                 *     allowPaging: true,    
                 *     pageSettings: { pageCount: 1 }
                 * });
                 * &lt;/script&gt;
                 */
                pageCount: 8,
                /**		
                 * Gets or sets a value that indicates whether to define which page to display currently in the grid
                 * @remarks
                 * When currentPage is defined in pageSettings then "allowPaging" must be set as true.
                 * The currentPage must be less than or equal to total number of pages.
                 * @alias ejGrid#pageSettings->currentPage
                 * @default 1
                 * @type {number}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *     dataSource:  window.gridData,
                 *     allowPaging: true,   
                 *     pageSettings: { currentPage: 1 }
                 * });
                 * &lt;/script&gt;
                 */
                currentPage: 1,
                /**		
                 * Get the value of total number of pages in the grid. The totalPages value is calculated based on pagesize and totalrecords of grid
                 * @remarks
                 * There is no need to set value for this property.
                 * @alias ejGrid#pageSettings->totalPages
                 * @default null
                 * @type {number}  
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt;
                 * &lt;div id="print"&gt;&lt;/div&gt;
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *     dataSource:  window.gridData,
                 *     allowPaging: true    
                 * });
                 * var value = $("#Grid").ejGrid("option", "pageSettings.totalPages");
                 * $("#print").text("TotalPages: " + value);
                 * &lt;/script&gt;
                 */
                totalPages: null,
                /**
				* Gets or sets a value that indicates whether to  enables pager template for the grid.
                * @remarks
                * If enableTemplates property set as true, need to give templateId property.
                * @alias ejGrid#pageSettings->enableTemplates
                * @default false
                * @type {bool}  
                * @example
				* &lt;div id="Grid"&gt;&lt;/div&gt; 
				* &lt;script id="pagerTemplate" type="text/x-jsrender"&gt;
				*  &lt;input type="text" id="txtPageNumber"  value="" style="width: 45px; border: none; cursor: text" /&gt;
				* &lt;input type="button" value="Go" style="border: none; cursor: pointer" id="btnGo" onclick="gotoPage(this)" /&gt;
				* &lt;/script&gt;
				* &lt;script&gt;
				* $("#Grid").ejGrid({
				*  dataSource:window.gridData,
				*  pageSettings:{enableTemplates:true,template:"#pagerTemplate"}
				* });
				* &lt;/script&gt;
				*/
                enableTemplates: false,
                /**
				* Gets or sets a value that indicates whether to  enables default pager for the grid.
                * @alias ejGrid#pageSettings->showDefaults
                * @default true
                * @type {bool}  
                * @example
				* &lt;div id="Grid"&gt;&lt;/div&gt; 
				* &lt;script id="pagerTemplate" type="text/x-jsrender"&gt;
				*  &lt;input type="text" id="txtPageNumber"  value="" style="width: 45px; border: none; cursor: text" /&gt;
				* &lt;input type="button" value="Go" style="border: none; cursor: pointer" id="btnGo" /&gt;
				* &lt;/script&gt;
				* &lt;script&gt;
				* $("#Grid").ejGrid({
				*  dataSource:window.gridData,
				*  pageSettings:{showDefaults:false,enableTemplates:true,templateID:"#pagerTemplate"}
				* });
				* &lt;/script&gt;
				*/
                showDefaults: false,
                /**
				* Gets or sets a value that indicates to add the template as a pager template for grid.
                * @remarks
                * If enableTemplates property set as true, need to give templateId property.
                * @alias ejGrid#pageSettings->template
                * @default null
                * @type {string}  
                * @example
				* &lt;div id="Grid"&gt;&lt;/div&gt; 
				* &lt;script id="pagerTemplate" type="text/x-jsrender"&gt;
				*  &lt;input type="text" id="txtPageNumber"  value="" style="width: 45px; border: none; cursor: text" /&gt;
				* &lt;input type="button" value="Go" style="border: none; cursor: pointer" id="btnGo" /&gt;
				* &lt;/script&gt;
				* &lt;script&gt;
				* $("#Grid").ejGrid({
				*  dataSource:window.gridData,
				*  pageSettings:{enableTemplates:true,template:"#pagerTemplate"}
				* });
				* &lt;/script&gt;
				*/
                template: null,
                /**		
                 * Get the value of total number of records which is bound to  the grid. The totalRecordsCount value is calculated based on dataSource bound to the grid.
                 * @remarks
                 * There is no need to set value for this property.
                 * @alias ejGrid#pageSettings->totalRecordsCount
                 * @default null
                 * @type {number}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt;
                 * &lt;div id="print"&gt;&lt;/div&gt;
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *     dataSource:  window.gridData,
                 *     allowPaging: true
                 * });
                 * var value = $("#Grid").ejGrid("option", "pageSettings.totalRecordsCount");
                 * $("#print").text("TotalRecordsCount: " + value);
                 * &lt;/script&gt;
                 */
                totalRecordsCount: null,
                /**		
                 * Gets or sets a value that indicates whether  to pass the current page information as a query string along with the url while navigating to other page.
                 * @remarks
                 * When currentPage is defined in pageSettings then "allowPaging" must be set as true.
                 * @alias ejGrid#pageSettings->enableQueryString
                 * @default false
                 * @type {boolean}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *     dataSource:  window.gridData,
                 *     allowPaging: true,   
                 *     pageSettings: {enableQueryString: true }
                 * });
                 * &lt;/script&gt;
                 */
                enableQueryString: false
            },
            /**		
             * Gets or sets an object that indicates whether to customize the grouping behaviour of the grid. 
             * @type {Object}             
             */
            groupSettings: /** @lends ejGrid# */ {
                /**		
                 * – Gets or sets a value that indicates whether to showthe group button image(toggle button)in the column header and also in the grouped column in the group drop area .  It can be used to group/ungroup the columns by click on the toggle button. 
                 * @remarks 
                 * When showToggleButton is enabled then "allowGrouping" must be set as true.
                 * @alias ejGrid#groupSettings->showToggleButton
                 * @default false
                 * @type {boolean}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *     dataSource:window.gridData,
                 *     allowGrouping:true,
                 *     groupSettings:{showToggleButton:true}
                 * });
                 * &lt;/script&gt;   
                 */
                showToggleButton: false,
                 /**		
                  * Gets or sets a value that indicates whether to  enable the animation effects to the group drop area
                  * @remarks
                  * allowGrouping must be set as true.
                  * @alias ejGrid#groupSettings->enableDropAreaAnimation
                  * @default true
                  * @type {boolean}
                  * @example
                  * &lt;div id="Grid"&gt;&lt;/div&gt; 
                  * &lt;script&gt;
                  * $("#Grid").ejGrid({
                  *    dataSource:window.gridData,
                  *    allowGrouping: true,
                  *    enableDropAreaAnimation:true                        
                  * });
                  * &lt;/script&gt;            
                  */
                enableDropAreaAnimation: true,
                 /**		
                  * Gets or sets a value that indicates whether to   hide the grouped columns from the grid
                  * @remarks
                  * When showGroupedColumn is enabled then "allowGrouping" must be set as true.
                  * @alias ejGrid#groupSettings->showGroupedColumn
                  * @default false
                  * @type {boolean}
                  * @example
                  * &lt;div id="Grid"&gt;&lt;/div&gt; 
                  * &lt;script&gt;
                  * $("#Grid").ejGrid({
                  *     dataSource:window.gridData,
                  *     allowGrouping:true,
                  *     groupSettings:{showGroupedColumn:false}
                  * });
                  * &lt;/script&gt; 
                  */
                showGroupedColumn: true,
                 /**		
                  * Gets or sets a value that indicates whether to  enable the close button in the grouped column  which is in the group drop area to ungroup the grouped column
                  * @remarks
                  * When showUngroupButton is enabled then "allowGrouping" and showToggleButton must be set as true.
                  * @alias ejGrid#groupSettings->showUngroupButton
                  * @default false
                  * @type {boolean}
                  * @example
                  * &lt;div id="Grid"&gt;&lt;/div&gt; 
                  * &lt;script&gt;
                  * $("#Grid").ejGrid({
                  *     dataSource:window.gridData,
                  *     allowGrouping:true,
                  *     groupSettings:{showToggleButton: true, showUngroupButton:true}
                  * });
                  * &lt;/script&gt; 
                  */
                showUngroupButton: true,
                /**		
                 * Gets or sets a value that indicates whether to  enable animation button option in the group drop area of the grid.
                 * @remarks
                 * When enableDropAreaAutoSizing is enabled then "allowGrouping" must be set as true.
                 * @alias ejGrid#groupSettings->enableDropAreaAutoSizing
                 * @default false
                 * @type {boolean}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *     dataSource:window.gridData,
                 *     allowGrouping:true,
                 *     groupSettings:{enableDropAreaAutoSizing: true}
                 * });
                 * &lt;/script&gt; 
                 */
                enableDropAreaAutoSizing: true,
                /**		
                 * Gets or sets a value that indicates whether to add grouped columns programmatically at initial load
                 * @remarks
                 * When groupedColumns is specified then "allowGrouping" must be set as true.
                 * @alias ejGrid#groupSettings->groupedColumns
                 * @default []
                 * @type {object}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *     dataSource:window.gridData,
                 *     allowGrouping:true,
                 *     groupSettings:{groupedColumns:["OrderID"]}
                 * });
                 * &lt;/script&gt; 
                 */
                groupedColumns: []
            },

            /**		
           * Gets or sets an object that indicates whether to customize the context menu behaviour of the grid.
           * @type {Object}             
           */

            contextMenuSettings: {
                /**
                 * Gets or sets a value that indicates whether to enable the context menu action in the grid.
                 * @remarks
                 * We must provide the Contextmenu Items. See{@link toolbarItems}
                 * If the above options added in contextmenu as a contextmenu item then we must enable allowEditing, allowDeleting , allowAdding , allowGrouping , allowSorting and allowPaging.
                 * @alias ejGrid#contextMenuSettings->enableContextMenu
                 * @default false
                 * @type {boolean}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *    dataSource: window.gridData,
                 *    columns:[{field: "OrderID", isPrimaryKey: true},{field: "EmployeeID"}],
                 *    editSettings: { allowDeleting: true, allowEditing: true, allowAdding: true },
                 *    allowGrouping: true,
                 *    allowSorting: true,
                 *    allowPaging: true,
                 *    contextMenuSettings: { enableContextMenu: true }
                 * });
                 * &lt;/script&gt; 
                 */
                enableContextMenu: false,
                /**		
                 * Gets or sets a value that indicates whether to add the default context menu actions as a context menu items
                 *If enableContextMenu is true it will show all the items related to the target, if u want selected items from contextmenu u have to mention in the contextMenuItems
                 * @remarks
                 * We must enable enableContextMenu property
                 * @alias ejGrid#contextMenuSettings->contextMenuItems
                 * @default []
                 * @type {array}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *    dataSource:window.gridData,
                 *    columns:[{field: "OrderID", isPrimaryKey: true},{field: "EmployeeID"}],
                 *    editSettings: { allowDeleting: true, allowEditing: true, allowAdding: true },
                 *    allowGrouping: true,
                 *    allowSorting: true,
                 *    allowPaging: true,
                 *    contextMenuSettings: { enableContextMenu: true, contextMenuItems:["Add Record,Edit Record,Delete Record"]  }
                 * });
                 * &lt;/script&gt;
                 */
                contextMenuItems: ["Add Record", "Edit Record", "Delete Record", "Sort In Ascending Order", "Sort In Descending Order", "Next Page", "Last Page", "Previous Page", "First Page", "Save", "Cancel", "Grouping", "Ungrouping"],
                /**		
                 * Gets or sets a value that indicates whether to add custom contextMenu items within the toolbar to perform any action in the grid
                 * @remarks
                 * We must enable enableContextMenu property
                 * @alias ejGrid#contextMenuSettings->customContextMenuItems
                 * @default []
                 * @type {array}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;style type="text/css" class="cssStyles"&gt;
                 * &lt;/style&gt;
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *   dataSource:window.gridData, 
                 *   contextMenuSettings: { enableContextMenu: true, customContextMenuItems:["Hidden Columns,Visible Columns"]  }
                 * });
                 * &lt;/script&gt;
                 */
                customContextMenuItems: []
            },
            /**		
             * Gets or sets an object that indicates whether to customize the filtering behaviour of the grid
             * @type {Object}             
             */
            filterSettings: /** @lends ejGrid# */ {
                /**		
                 * This specifies the grid to show the filterBar or filterMenu to the grid records. See {@link filterType}
                 * @remarks
                 * When filterType is specified then "allowFiltering" must be set as true.
                 * @alias ejGrid#filterSettings->filterType
                 * @default ej.Grid.FilterType.FilterBar
                 * @type {enum}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *    dataSource:window.gridData,
                 *    allowFiltering: true, 
                 *    filterSettings: {  filterType: "menu" }                     
                 * });
                 * &lt;/script&gt;
                 */
                filterType: "filterbar",
                /**		
                 * This specifies the grid to starts the filter action while typing in the filterBar or after pressing the enter key. based on the filterBarMode. See {@link filterBarMode}
                 * @remarks
                 * When filterBarMode is specified then "allowFiltering" must be set as true and filterType must be "filterbar".
                 * @alias ejGrid#filterSettings->filterBarMode
                 * @default ej.Grid.FilterBarMode.Immediate
                 * @type {enum} 
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *    dataSource:window.gridData,
                 *    allowFiltering: true, 
                 *    filterSettings:{ filterBarMode: ej.Grid.FilterBarMode.OnEnter }                
                 * });
                 * &lt;/script&gt;
                 */
                filterBarMode: "immediate",
                /**		
                 * This specifies the grid to show  the filter text within the grid pager itself.
                 * @remarks
                 * When filterBarMode is specified then "allowFiltering" must be set as true and filterType must be "filterbar".
                 * @alias ejGrid#filterSettings->showFilterBarMessage
                 * @default true
                 * @type {boolean}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *    dataSource:window.gridData,
                 *    allowFiltering: true, 
                 *    filterSettings: {  showFilterBarStatus: true }                        
                 * });
                 * &lt;/script&gt;
                 */
                showFilterBarStatus: true,
                statusBarWidth: 450,
                /**		
                 * Gets or sets a value that indicates whether to enable the predicate options in the filtering menu  
                 * @remarks
                 * When showPredicate is specified then "allowFiltering" must be set as true and filterType must be "menu".
                 * @alias ejGrid#filterSettings->showPredicate
                 * @default false
                 * @type {boolean}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *    dataSource:window.gridData,
                 *     allowFiltering: true, 
                 *     filterSettings: { showPredicate:true, filterType:"menu"}                       
                 * });
                 * &lt;/script&gt;
                 */
                showPredicate: false,
                /**		
                 * Gets or sets a value that indicates whether to define the filtered columns details programmatically at initial load   
                 * @remarks
                 * When filteredColumns is specified then "allowFiltering" must be set as true and filterType must be "menu".
                 * @alias ejGrid#filterSettings->filteredColumns
                 * @default []
                 * @type {object}                 
                 */
                filteredColumns: [],                
                /**		
                * Gets or sets a value that indicates the maximum number of filter choices that can be showed in the excel styled filter menu. 
                * @remarks
                * When maxFilterChoices is specified then "allowFiltering" must be set as true and filterType must be "excel".
                * @alias ejGrid#filterSettings->maxFilterChoices
                * @default 1000
                * @type {number}
                * @example
                * &lt;div id="Grid"&gt;&lt;/div&gt; 
                * &lt;script&gt;
                * $("#Grid").ejGrid({
                *    dataSource:window.gridData,
                *     allowFiltering: true, 
                *     filterSettings: { maxFilterChoices:200, filterType:"excel"}                       
                * });
                * &lt;/script&gt;
                */
                maxFilterChoices: 1000,
                /**		
                * Gets or sets a value that indicates to perform the filter operation with case sensitive in excel styled filter menu mode
                * @remarks
                * When enableCaseSensitivity is specified then "allowFiltering" must be set as true and filterType must be "excel".
                * @alias ejGrid#filterSettings->enableCaseSensitivity
                * @default false
                * @type {boolean}
                * @example
                * &lt;div id="Grid"&gt;&lt;/div&gt; 
                * &lt;script&gt;
                * $("#Grid").ejGrid({
                *    dataSource:window.gridData,
                *     allowFiltering: true, 
                *     filterSettings: { enableCaseSensitivity:true, filterType:"excel"}                       
                * });
                * &lt;/script&gt;
                */
                enableCaseSensitivity:false
            },
            /**		
             * Gets or sets a value that indicates whether to customize the sorting behaviour of the grid.
             * @type {Object}           
             */
            sortSettings: /** @lends ejGrid# */ {

                /**		
                 * Gets  or sets a value that indicates whether to define the sorted Columns details programmatically at initial load
                 * @remarks
                 * allowSorting must be set as true.
                 * @alias ejGrid#sortSettings->sortedColumns
                 * @default []
                 * @type {object}
                 * @example                 
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;div id="print"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *    dataSource:window.gridData,
                 *    columns:[{field: "OrderID"},{field: "EmployeeID"}],
                 *    allowSorting: true,
                 *    sortSettings: {sortedColumns: [{field:"EmployeeID", direction:"ascending"}] }                  
                 * });
                 * var sortColumn = $("#Grid").ejGrid("option", "sortSettings.sortedColumns");
                 * $("#print").text(sortColumn);
                 * &lt;/script&gt;
                 */

                /**
                 * Gets or sets a value that indicates whether to define the field name of the column to be sort
                 * @remarks
                 * allowSorting must be set as true.
                 * @name ejGrid#sortSettings->sortedColumns->field 	          
                 * @default -
                 * @type {string}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt;          
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *   dataSource:window.gridData,
                 *   columns:[{field: "OrderID"},{field: "EmployeeID"}],
                 *   sortSettings: {sortedColumns: [{field:"EmployeeID"}] }             
                 * });
                 * &lt;/script&gt;  
                 */

                /**
                 * Gets  or sets a value that indicates whether to define the direction to sort the column.
                 * @remarks
                 * allowSorting must be set as true.
                 * @name ejGrid#sortSettings->sortedColumns->direction 	          
                 * @default -
                 * @type {string}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt;          
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *   dataSource:window.gridData,
                 *   columns:[{field: "OrderID"},{field: "EmployeeID"}],
                 *   sortSettings: {sortedColumns: [{field:"EmployeeID", direction:"descending"}] }                    
                 * });
                 * &lt;/script&gt;  
                 */
                sortedColumns: []
            },
            /**		
             * Gets or sets an object that indicates whether to enable the toolbar in the grid and add toolbar items
             * @type {Object}             
             */
            toolbarSettings: /** @lends ejGrid# */ {
                /**		
                 * Gets or sets a value that indicates whether to enable  toolbar in the grid.
                 * @remarks
                 * We must provide the toolbarItems. See{@link toolbarItems}
                 * If editing options added in toolbar as a toolbar item then we must enable allowEditing, allowDeleting and allowAdding.
                 * @alias ejGrid#toolbarSettings->showToolbar
                 * @default false
                 * @type {boolean}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *    dataSource: window.gridData,
                 *    columns:[{field: "OrderID", isPrimaryKey: true},{field: "EmployeeID"}],
                 *    editSettings: { allowEditing: true },
                 *    toolbarSettings: { showToolbar: true, toolbarItems: [ej.Grid.ToolBarItems.Edit] }
                 * });
                 * &lt;/script&gt; 
                 */
                showToolbar: false,
                /**		
                 * Gets or sets  a value that indicates whether  to add the default editing actions as a toolbar items
                 * @remarks
                 * We must enable showToolbar property
                 * @alias ejGrid#toolbarSettings->toolbarItems
                 * @default []
                 * @type {enum}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *    dataSource:window.gridData,
                 *    columns:[{field: "OrderID", isPrimaryKey: true},{field: "EmployeeID"}],
                 *    editSettings: { allowDeleting: true, allowEditing: true, allowAdding: true },
                 *    toolbarSettings: { showToolbar: true, toolbarItems: [ej.Grid.ToolBarItems.Add, ej.Grid.ToolBarItems.Edit, ej.Grid.ToolBarItems.Delete, ej.Grid.ToolBarItems.Update, ej.Grid.ToolBarItems.Cancel] }
                 * });
                 * &lt;/script&gt;
                 */
                toolbarItems: [],
                /**		
                 * Gets or sets a value that indicates whether  to add custom toolbar items within the toolbar to perform any action in the grid 
                 * @remarks
                 * We must enable showToolbar property
                 * @alias ejGrid#toolbarSettings->customToolbarItems
                 * @default []
                 * @type {object}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;style type="text/css" class="cssStyles"&gt;
                 *   .Expand:before
                 *   {
                 *     content:"\e627";
                 *   }
                 * &lt;/style&gt;
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *   dataSource:window.gridData, 
                 *   toolbarSettings:{showToolbar:true,customToolbarItems:["Expand"]}
                 * });
                 * &lt;/script&gt;
                 */
                customToolbarItems: []
            },
            minWidth:0,
            /**		
             * Gets or sets an object that indicates whether to customize the scrolling behaviour of the grid.
             * @type {Object}
             */
            scrollSettings: /** @lends ejGrid# */
            {
                /**		
                 * This specify the grid to show the horizontal scroll bar, to scroll and view the grid contents
                 * @remarks
                 * We must enable allowScrolling property
                 * @alias ejGrid#scrollSettings->width
                 * @default 250
                 * @type {number}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *    dataSource:window.gridData,
                 *    allowScrolling: true,
                 *    scrollSettings:{ width:300 }
                 * });
                 * &lt;/script&gt; 
                 */
                width: "auto",
                /**		
                 * This specify the grid to show the vertical scroll bar, to scroll and view the grid contents.
                 * @remarks
                 * We must enable allowScrolling property
                 * @alias ejGrid#scrollSettings->height
                 * @default 0
                 * @type {number}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *    dataSource:window.gridData,
                 *    allowScrolling: true,
                 *    scrollSettings:{ height:100 }
                 * });
                 * &lt;/script&gt; 
                 */
                height: 0,
                /**		
                 * This specify the grid to enable/disable touch control for scrolling.
                 * @remarks
                 * We must enable allowScrolling property
                 * @alias ejGrid#scrollSettings->enableTouchScroll
                 * @default true
                 * @type {boolean}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *    dataSource:window.gridData,
                 *    allowScrolling: true,
                 *    scrollSettings:{ enableTouchScroll:true }
                 * });
                 * &lt;/script&gt; 
                 */
                enableTouchScroll: true,
                /**		
                 * This specify the grid to to view data that you require without buffering the entire load of a huge database
                 * @remarks
                 * 1.We must enable allowScrolling property
                 * 2.Sets the height and width size
                 * @alias ejGrid#scrollSettings->allowVirtualScrolling
                 * @default false
                 * @type {boolean}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *    dataSource:window.gridData,
                 *    allowScrolling: true,
                 *    scrollSettings:{width:300,height:100,allowVirtualScrolling:true}
                 * });
                 * &lt;/script&gt; 
                 */
                allowVirtualScrolling: false,
                /**		
                * This is used to define the mode of virtual scrolling in grid. See {@link virtualScrollMode}
                * @remarks                 
                * We must enable allowScrolling and allowVirtualScrolling property                 
                * @alias ejGrid#scrollSettings->virtualScrollMode
                * @default ej.Grid.VirtualScrollMode.Normal
                * @type {enum}
                * @example
                * &lt;div id="Grid"&gt;&lt;/div&gt;
                * &lt;script&gt;
                * $("#Grid").ejGrid({
                *     dataSource: window.gridData,                     
                *     allowScrolling:true,
                *     scrollSettings:{ width:500 , height: 550 , allowVirtualScrolling:true, virtualScrollMode:ej.Grid.VirtualScrollMode.Normal }
                * });
                * &lt;/script&gt;                          
                */
                virtualScrollMode:"normal",
                /**		
                 * This specify the grid to freeze particular rows at the time of scrolling.
                 * @remarks
                 * We must enable allowScrolling property
                 * @alias ejGrid#scrollSettings->frozenRows
                 * @default 0
                 * @type {number}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *     dataSource:window.gridData,
                 *     allowScrolling: true,               
                 *     scrollSettings:{width:300,height:200,frozenRows:2 }
                 * });
                 * &lt;/script&gt; 
                 */
                frozenRows: 0,
                /**		
                 * This specify the grid to freeze particular columns  at the time of scrolling.
                 * @remarks
                 * We must enable allowScrolling property
                 * @alias ejGrid#scrollSettings->frozenColumns
                 * @default 0
                 * @type {number}
                 * @example
                 * &lt;div id="Grid"&gt;&lt;/div&gt; 
                 * &lt;script&gt;
                 * $("#Grid").ejGrid({
                 *     dataSource:window.gridData,
                 *     allowScrolling: true,               
                 *     scrollSettings:{width:500,height:100,frozenColumns:2 }
                 * });  
                 * &lt;/script&gt; 
                 */
                frozenColumns: 0
            },
            /**		
             * Gets or sets an object that indicates to managing the collection of summary rows for the grid.
             * @remarks
             * We must enable showSummary property
             * @default []
             * @name ejGrid#summaryRows
             * @type {array}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *      dataSource:window.gridData,
             *      showSummary: true,
             *      columns:[{field: "OrderID"},{field: "Freight"}],
             *      summaryRows: [{
             *         title: "Sum",
             *         summaryColumns: [{
             *            summaryType: ej.Grid.SummaryType.Sum,
             *            displayColumn: "Freight",
             *            dataMember: "Freight"
             *         }]
             *      }]                                    
             * });
             * &lt;/script&gt; 
             */

            /**
             * This specifies the grid to show the title for the summary rows.  
             * @remarks
             * showSummary must be true and summaryRows must be given while using title.
             * @name ejGrid#summaryRows->title 	          
             * @default ""
             * @type {string}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *      dataSource:window.gridData,  
             *      showSummary: true,
             *      columns:[{field: "OrderID"},{field: "Freight"}],
             *      summaryRows: [{
             *         title: "Sum",
             *         summaryColumns: [{
             *            summaryType: ej.Grid.SummaryType.Sum,
             *            displayColumn: "Freight",
             *            dataMember: "Freight"
             *         }]
             *      }]                                    
             * });
             * &lt;/script&gt;
             */

            /**
             * Gets or sets a value that indicates whether to show the summary value within the group caption area for the corresponding summary column while grouping the column
             * @remarks
             * showSummary and allowGrouping must be true. summaryRows must be given while using showCaptionSummary.
             * @name ejGrid#summaryRows->showCaptionSummary 	          
             * @default false
             * @type {boolean}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *      dataSource:window.gridData,  
             *      columns:[{field: "OrderID"},{field: "Freight"}],
             *      allowGrouping: true,
             *      showSummary: true,
             *      summaryRows: [{
             *         title: "Sum",
             *         summaryColumns: [{
             *            summaryType: ej.Grid.SummaryType.Sum,
             *            displayColumn: "Freight",
             *            dataMember: "Freight"
             *         }],
             *         showCaptionSummary: true
             *      }]                                    
             * });
             * &lt;/script&gt;           
             */

            /**
             * Gets or sets a value that indicates whether to show the total summary value  the for the corresponding summary column. The summary row is added after the grid content.
             * @remarks
             * showSummary and allowGrouping must be true. summaryRows must be given while using showTotalSummary.
             * @name ejGrid#summaryRows->showTotalSummary 	          
             * @default true
             * @type {boolean}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *      dataSource:window.gridData, 
             *      columns:[{field: "OrderID"},{field: "Freight"}],
             *      showSummary: true,
             *      summaryRows: [{
             *         title: "Sum",
             *         summaryColumns: [{
             *            summaryType: ej.Grid.SummaryType.Sum,
             *            displayColumn: "Freight",
             *            dataMember: "Freight"
             *         }],
             *         showTotalSummary: true
             *      }]                                    
             * });
             * &lt;/script&gt; 
             */

            /**
             * Gets or sets a value that indicates whether to add summary columns into the summary rows.
             * @remarks            
             * showSummary must be true and summaryRows must be given while using summaryColumns.
             * @name ejGrid#summaryRows->summaryColumns 	          
             * @default []
             * @type {object}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *      dataSource:window.gridData, 
             *      columns:[{field: "OrderID"},{field: "Freight"}],
             *      showSummary: true,
             *      summaryRows: [{
             *         title: "Sum",
             *         summaryColumns: [{
             *            summaryType: ej.Grid.SummaryType.Sum,
             *            displayColumn: "Freight",
             *            dataMember: "Freight"
             *         }]
             *      }]                                    
             * });
             * &lt;/script&gt; 
             */

            /**
             * Gets or sets a value that indicates the type of calculations to be performed for the corresponding summary column
             * @remarks            
             * showSummary must be true and summaryRows must be given while using summaryColumns and their properties.
             * @name ejGrid#summaryRows->summaryColumns->summaryType     
             * @default []
             * @type {object}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *      dataSource:window.gridData, 
             *      columns:[{field: "OrderID"},{field: "Freight"}],
             *      showSummary: true,
             *      summaryRows: [{
             *         title: "Sum",
             *         summaryColumns: [{
             *            summaryType: ej.Grid.SummaryType.Sum,
             *            displayColumn: "Freight",
             *            dataMember: "Freight"
             *         }]
             *      }]                                    
             * });
             * &lt;/script&gt; 
             */

            /**
             * Gets or sets a value that indicates to define the target column at which to display the summary.
             * @remarks            
             * showSummary must be true and summaryRows must be given while using summaryColumns and their properties.
             * @name ejGrid#summaryRows->summaryColumns->displayColumn 	          
             * @default null
             * @type {string}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *      dataSource:window.gridData,
             *      columns:[{field: "OrderID"},{field: "Freight"}],
             *      showSummary: true,
             *      summaryRows: [{
             *         title: "Sum",
             *         summaryColumns: [{
             *            summaryType: ej.Grid.SummaryType.Sum,
             *            displayColumn: "Freight",
             *            dataMember: "Freight"
             *         }]
             *      }]                                    
             * });
             * &lt;/script&gt; 
             */

            /**
             * This specifies summary column used to perform the summary calculation
             * @remarks            
             * showSummary must be true and summaryRows must be given while using summaryColumns and their properties.
             * @name ejGrid#summaryRows->summaryColumns->dataMember 	          
             * @default null
             * @type {string}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *      dataSource:window.gridData,
             *      columns:[{field: "OrderID"},{field: "Freight"}],
             *      showSummary: true,
             *      summaryRows: [{
             *         title: "Sum",
             *         summaryColumns: [{
             *            summaryType: ej.Grid.SummaryType.Sum,
             *            displayColumn: "Freight",
             *            dataMember: "Freight"
             *         }]
             *      }]                                    
             * });
             * &lt;/script&gt; 
             */

            /**
             * Gets or sets a value that indicates the format for the text applied on the column
             * @remarks            
             * showSummary must be true and summaryRows must be given while using summaryColumns and their properties.
             * @name ejGrid#summaryRows->summaryColumns->format 	          
             * @default null
             * @type {string}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *      dataSource:window.gridData,
             *      columns:[{field: "OrderID"},{field: "Freight"}],
             *      showSummary: true,
             *      summaryRows: [{
             *         title: "Sum",
             *         summaryColumns: [{
             *            summaryType: ej.Grid.SummaryType.Sum,
             *            displayColumn: "Freight",
             *            dataMember: "Freight",
             *            format: "{0:C2}"
             *         }]
             *      }]                                    
             * });
             * &lt;/script&gt; 
             */

            /**
             * Gets or sets a value that indicates the text displayed after the summary column value
             * @remarks            
             * showSummary must be true and summaryRows must be given while using summaryColumns and their properties.
             * @name ejGrid#summaryRows->summaryColumns->suffix 	          
             * @default null
             * @type {string}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *      dataSource:window.gridData,
             *      columns:[{field: "OrderID"},{field: "Freight"}],
             *      showSummary: true,
             *      summaryRows: [{
             *         title: "Sum",
             *         summaryColumns: [{
             *            summaryType: ej.Grid.SummaryType.Sum,
             *            displayColumn: "Freight",
             *            dataMember: "Freight",
             *            suffix: "/-"
             *         }]
             *      }]                                    
             * });
             * &lt;/script&gt; 
             */

            /**
             * Gets or sets a value that indicates the text displayed before the summary column value
             * @remarks            
             * showSummary must be true and summaryRows must be given while using summaryColumns and their properties.
             * @name ejGrid#summaryRows->summaryColumns->prefix 	          
             * @default null
             * @type {string}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *      dataSource:window.gridData,
             *      showSummary: true,
             *      summaryRows: [{
             *         title: "Sum",
             *         summaryColumns: [{
             *            summaryType: ej.Grid.SummaryType.Sum,
             *            displayColumn: "Freight",
             *            dataMember: "Freight",
             *            prefix : "Currency:"
             *         }]
             *      }]                                    
             * });
             * &lt;/script&gt; 
             */
			 
			 /**
             * This defines the text alignment of a particular column header cell value. See {@link headerTextAlign}
             * @remarks
             * It is optional.
             * @name ejGrid#columns->headerTextAlign 	          
             * @default ej.TextAlign.Left
             * @type {enum}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   columns:[{field:"OrderID",headerTextAlign:ej.TextAlign.Center},{field:"CustomerID",headerTextAlign:ej.TextAlign.Right},{field:"ShipCity"}]
             * });
             * &lt;/script&gt; 
             */

            /**
             * Gets or sets a value that indicates the text displayed in the summary column as a value
             * @remarks            
             * showSummary must be true and summaryRows must be given while using summaryColumns and their properties.
             * The summaryType property must be set as Custom.
             * @name ejGrid#summaryRows->summaryColumns->customSummaryValue 	          
             * @default null
             * @type {string}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *      dataSource:window.gridData,
             *      columns:[{field: "OrderID"},{field: "Freight"}],
             *      showSummary: true,
             *      summaryRows: [{
             *         title: "Sum",
             *         summaryColumns: [{
             *            summaryType: ej.Grid.SummaryType.Custom,
             *            displayColumn: "Freight",
             *            dataMember: "Freight",
             *            customSummaryValue : "Currency"
             *         }]
             *      }]                                    
             * });    
             * &lt;/script&gt; 
             */
            summaryRows: [],
            /**		
             * Align content in the grid control from right to left by setting the property as true.
             * @default false
             * @type {boolean}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   enableRTL:true,
             * });
             * &lt;/script&gt; 
             */
            enableRTL: false,
            /**		
             * Gets or sets a value that indicates whether to enable the alternative rows differentiation in the grid records based on corresponding theme.
             * @default true
             * @type {boolean}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   enableAltRow:true,
             * });
             * &lt;/script&gt; 
             */
            enableAltRow: true,
            currentViewData: null,
            /**		
             * This specifies the grid to add the details row for the corresponding master row
             * @default null
             * @type {string}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script id="templateData" type="text/x-jsrender"&gt;
             * &lt;table&gt;
             * &lt;tr&gt;
             * &lt;td&gt;
             * &lt;img src="styles/images/Employees/{{:EmployeeID}}.png" alt="{{:EmployeeID}}"/&gt;
             * &lt;/td&gt;
             * &lt;/tr&gt;
             * &lt;/table&gt;
             * &lt;/script&gt;
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   detailsTemplate:"#templateData",
             *   detailsDataBound: "detailGridData",
             * });             
             * &lt;/script&gt;             
             */
            detailsTemplate: null,
            /**		
            * This specifies the grid to add the grid control inside the grid row of the parent with expand/collapse options
            * @default null
            * @type {object}
            * @example 	       
            * &lt;div id="Grid"&gt;&lt;/div&gt;
            * &lt;script&gt;
            * $("#Grid").ejGrid({
            *   dataSource:window.gridData,
            *    childGrid: {
            * dataSource: window.employeeView,
            * queryString: "EmployeeID",
            * }
            * });
            * &lt;/script&gt;
            */
            childGrid: null,
            /**		
             * Gets or sets a value that indicates to render the grid with template rows. The template row must be a table row. That table row must have the JavaScript render binding format ({{:columnName}}) then the grid data source binds the data to the corresponding table row of the template.
             * @default null
             * @type {string}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script id="templateData" type="text/x-jsrender"&gt;
             * &lt;tr&gt;
             * &lt;td&gt;
             * &lt;img src="styles/images/Employees/{{:EmployeeID}}.png" alt="{{:EmployeeID}}"/&gt;
             * &lt;/td&gt;
             * &lt;td&gt;
             * {{:EmployeeID}}
             * &lt;/td&gt;
             * &lt;/tr&gt;
             * &lt;/script&gt;
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *  dataSource:window.gridData,
             *   rowTemplate:"#templateData",
             *   columns:[{headerText:"Employeephoto"},{field:"EmployeeID",headerText:"EmployeeID"}],
             * });
             * &lt;/script&gt;
             */
            rowTemplate: null,
            /**		
             * Triggered detail template row is initialized.
             * @remarks
             * Template must be bind to detailsTemplate property while using this event
             * @event
			 * @name ejGrid#detailsDataBound 	
			 * @param {Object} argument Event parameters from grid              
			 * @param {boolean}  argument.cancel Returns the cancel option value.
			 * @param {object}  argument.detailsElement Returns details row element.
             * @param {object}  argument.data Returns the details row data.
			 * @param {object}  argument.model Returns the grid model.
			 * @param {string}  argument.type Returns the name of the event.
			 * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt;
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    detailsDataBound: function (args){}
             * });
             * &lt;/script&gt;
             */
            detailsDataBound: null,
            /**    
             * Triggered every time a request is made to access row information, element and data.
             * @event
             * @name ejGrid#rowDataBound 	
             * @param {Object} argument Event parameters from grid              
             * @param {object}  argument.row Returns grid row.
             * @param {boolean}  argument.cancel Returns the cancel option value.
             * @param {object}  argument.data Returns current row record object (JSON).
             * @param {object} argument.foreignKeyData Returns the foreign key record object (JSON).
             * @param {object}  argument.model Returns the grid model.
             * @param {string}  argument.type Returns the name of the event.
             * @example 
             * &lt;div id="Grid"&gt;&lt;/div&gt;
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    rowDataBound: function (args){}
             * });
             * &lt;/script&gt;
             */
            rowDataBound: null,
            /**    
             * Triggered every time a request is made to access particular cell information, element and data.
             * @event
             * @name ejGrid#queryCellInfo 	
             * @param {Object} argument Event parameters from grid              
             * @param {object}  argument.cell Returns grid cell.
             * @param {boolean}  argument.cancel Returns the cancel option value.
             * @param {object}  argument.data Returns current row record object (JSON).
             * @param {string}  argument.text Returns the text value in the cell.
             * @param {object} argument.column Returns the column object.
             * @param {object} argument.foreignKeyData Returns the foreign key record object (JSON).
             * @param {object}  argument.model Returns the grid model.
             * @param {string}  argument.type Returns the name of the event.
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    queryCellInfo: function (args){}
             * });
             * &lt;/script&gt;
             */
            queryCellInfo: null,
            /**
             * @callback mergeColback(int no)
               @callback mergeRowback(int no)
               @callback merge(int no , int no)
              */
			 /**    
             * Triggered every time a request is made to access particular cell information, element and data.
             * @event
             * @name ejGrid#mergeCellInfo 	
             * @param {Object} argument Event parameters from grid              
             * @param {object}  argument.cell Returns grid cell.
             * @param {boolean}  argument.cancel Returns the cancel option value.
             * @param {object}  argument.data Returns current row record object (JSON).
             * @param {string}  argument.text Returns the text value in the cell.
             * @param {object}  argument.column Returns the column object.
             * @param  {mergeRowback} argument.rowMerge Returns the merge rows in grid.
             * @param  {mergeColback}argument.colMerge Returns the merge column in grid.
             * @param  {merge} argument.merge Returns the merge the rows and columns in grid.
             * @param {object}  argument.model Returns the grid model.
             * @param {string}  argument.type Returns the name of the event.
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    mergeCellInfo: function (args){}
             * });
             * &lt;/script&gt;
             */
            mergeCellInfo: null,
            /**    
             * Triggered when the grid is rendered completely.
             * @event
             * @name ejGrid#create 	
             * @param {Object} argument Event parameters from grid             
             * @param {boolean}  argument.cancel Returns the cancel option value.
             * @param {object}  argument.model Returns the grid model.
             * @param {string}  argument.type Returns the name of the event.
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt;
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    create: function (args){}
             * });
             * &lt;/script&gt;
             */
            create: null,
            /**    
             * Triggered for every grid action before its starts.
             * @event
             * @name ejGrid#actionBegin              
             * @param {Object} argument Event parameters when grid is initialized:          
             * @param {boolean}  argument.cancel Returns the cancel option value.
             * @param {object}  argument.model Returns the grid model.
             * @param {string}  argument.type Returns the name of the event.
             
             * @param {Object} argument Event parameters when grid paging action starts:
             * @param {boolean}  argument.cancel Returns the cancel option value.
             * @param {number} argument.currentPage  Returns the current selected page number.
             * @param {number} argument.previousPage  Returns the previous selected page number.
             * @param {number} argument.endIndex Returns the end row index of that current page.
             * @param {object}  argument.model Returns the grid model.
             * @param {string}  argument.requestType Returns request type.
             * @param {number} argument.startIndex  Returns the start row index of that current page.
             * @param {string}  argument.type Returns the name of the event.
 
             * @param {Object} argument Event parameters when grid sorting action starts:
             * @param {boolean}  argument.cancel Returns the cancel option value.
             * @param {string}  argument.columnName Returns the current grouped column field name.
             * @param {object}  argument.model Returns the grid model.
             * @param {string}  argument.requestType Returns request type.
             * @param {string}  argument.type Returns the name of the event. 
             * @param {string}  argument.columnSortDirection  Returns the column sort direction.
 
             * @param {Object} argument Event parameters when grid grouping action starts:
             * @param {boolean}  argument.cancel Returns the cancel option value.
             * @param {string}  argument.columnName Returns the current grouped column field name.
             * @param {object}  argument.model Returns the grid model.
             * @param {string}  argument.requestType Returns request type.
             * @param {string}  argument.type Returns the name of the event.        
 
             * @param {Object} argument Event parameters when grid record editing action starts:
             * @param {boolean}  argument.cancel Returns the cancel option value.
             * @param {object}  argument.row  Returns current edited row.
             * @param {object}  argument.model Returns the grid model.
             * @param {string} argument.originalEventType Returns the current action event type.
             * @param {string} argument.primaryKey Returns primary key.
             * @param {string} argument.primaryKeyValue Returns primary key value.
             * @param {string}  argument.requestType Returns request type.
             * @param {number}  argument.rowIndex Returns the edited row index.
             * @param {string}  argument.type Returns the name of the event.
 
             * @param {Object} argument Event parameters when grid record save action starts:
             * @param {boolean}  argument.cancel Returns the cancel option value.
             * @param {object}  argument.data Returns the record object (JSON).
             * @param {object}  argument.foreignKeyData Returns the foreign key record object (JSON).
             * @param {object}  argument.model Returns the grid model.
             * @param {number}  argument.selectedRow Returns the selected row index.
             * @param {string}  argument.requestType Returns request type.
             * @param {string}  argument.type Returns the name of the event. 
 
             * @param {Object} argument Event parameters when grid record cancel action starts:
             * @param {boolean}  argument.cancel Returns the cancel option value.
             * @param {object}  argument.model Returns the grid model.
             * @param {string}  argument.requestType Returns request type.
             * @param {string}  argument.type Returns the name of the event. 
 
             * @param {Object} argument Event parameters when grid record delete action starts:
             * @param {boolean}  argument.cancel Returns the cancel option value.
             * @param {object}  argument.data Returns the record object (JSON).
             * @param {object}  argument.foreignKeyData Returns the foreign key record object (JSON).
             * @param {object}  argument.model Returns the grid model.
             * @param {string}  argument.requestType Returns request type.
             * @param {object}  argument.tr Returns selected row for delete.
             * @param {string}  argument.type Returns the name of the event.
 
             * @param {Object} argument Event parameters when add new record action starts:
             * @param {boolean}  argument.cancel Returns the cancel option value.
             * @param {object}  argument.data Returns the record object (JSON).
             * @param {object}  argument.model Returns the grid model.
             * @param {string}  argument.requestType Returns request type.
             * @param {string}  argument.type Returns the name of the event.
 
             * @param {Object} argument Event parameters when grid filtering action starts:
             * @param {boolean}  argument.cancel Returns the cancel option value.
             * @param {object}  argument.currentFilteringColumn Returns current filtering column field name.
             * @param {object}  argument.filterCollection Returns filter details.
             * @param {object}  argument.model Returns the grid model.
             * @param {string}  argument.requestType Returns request type.
             * @param {string}  argument.type Returns the name of the event.
 
             * @example 
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    actionBegin: function (args){}
             * });
             * &lt;/script&gt;
             */
            actionBegin: null,
            /**    
             * Triggered for every grid action success event.
             * @event
             * @name ejGrid#actionComplete 	
             * @param {Object} argument Arguments in actionComplete when grid is initialized.     
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.requestType Returns request type.
             * @param {string} argument.type Returns the name of the event.
             
             * @param {Object} argument Arguments in actionComplete after grid paging action is completed.
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {number} argument.currentPage Returns the current selected page number.
             * @param {number} argument.previousPage Returns the previous selected page number.
             * @param {number} argument.endIndex Returns the end row index of that current page.
             * @param {object} argument.model Returns the grid model.				
             * @param {string} argument.originalEventType Returns current action event type.
             * @param {string} argument.requestType Returns request type.
             * @param {number} argument.startIndex Returns the start row index of the current page.
             * @param {object} argument.target Returns grid element.
             * @param {string} argument.type Returns the name of the event.
             
             * @param {object} argument Arguments in actionComplete after grid sorting action is completed.				
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {string} argument.columnName Returns the current sorted column field name.
             * @param {string} argument.columnSortDirection Returns the column sort direction.
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.originalEventType Returns current action event type.
             * @param {string} argument.requestType Returns request type.
             * @param {object} argument.target Returns grid element.
             * @param {string} argument.type Returns the name of the event.
             
             * @param {object} argument Arguments in actionComplete after grid grouping action is completed.
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {string} argument.columnName Returns the current grouped column field name.
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.originalEventType Returns current action event type.
             * @param {string} argument.requestType Returns request type.
             * @param {object} argument.target Returns grid element.
             * @param {string} argument.type Returns the name of the event.
             
             * @param {object} argument Arguments in actionComplete after grid record editing action is completed.
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {object} argument.row Returns current edited row.
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.originalEventType Returns current action event type.
             * @param {string} argument.primaryKey Returns primary key.
             * @param {string} argument.primaryKeyValue Returns primary key value.
             * @param {string} argument.requestType Returns request type.
             * @param {number} argument.rowIndex Returns the edited row index.
             * @param {object} argument.target Returns grid element.
             * @param {string} argument.type Returns the name of the event.
             
             * @param {object} argument Arguments in actionComplete after grid record save action is completed.
             * @param {object} argument.cancel Returns the cancel option value.
             * @param {object} argument.data Returns the record object (JSON).
             * @param {number} argument.selectedRow Returns the selectedRow index.
             * @param {object} argument.foreignKeyData Returns the foreign key record object (JSON).
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.originalEventType Returns current action event type.
             * @param {string} argument.requestType Returns request type.
             * @param {object} argument.target Returns grid element.
             * @param {string} argument.type Returns the name of the event.
             
             * @param {object} argument Arguments in actionComplete after grid record cancel action is completed.
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.originalEventType Returns current action event type.
             * @param {string} argument.requestType Returns request type.
             * @param {object} argument.target Returns grid element.
             * @param {string} argument.type Returns the name of the event.
             
             * @param {object} argument Arguments in actionComplete after grid record delete action is completed.
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {object} argument.data Returns the record object (JSON).
             * @param {object} argument.foreignKeyData Returns the foreign key record object (JSON).
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.originalEventType Returns current action event type.
             * @param {string} argument.requestType Returns request type.
             * @param {object} argument.target Returns grid element.
             * @param {object} argument.tr Returns selected row for delete.
             * @param {string} argument.type Returns the name of the event.
             
             * @param {object} argument Arguments in actionComplete after add new record action is completed.
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {object} argument.data Returns empty record object (JSON).
             * @param {object} argument.foreignKeyData Returns the foreign key record object (JSON).
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.originalEventType Returns current action event type.
             * @param {string} argument.requestType Returns request type.
             * @param {object} argument.target Returns grid element.
             * @param {string} argument.type Returns the name of the event.
             
             * @param {object} argument Arguments in actionComplete after grid filtering action is completed.
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {string} argument.currentFilteringColumn Returns current filtering column field name.
             * @param {object} argument.filterCollection Returns filter details.
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.originalEventType Returns current action event type.
             * @param {string} argument.requestType Returns request type.
             * @param {object} argument.target Returns grid element.
             * @param {string} argument.type Returns the name of the event.
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    actionComplete: function (args) {}
             * }); 
             * &lt;/script&gt;
             */
            actionComplete: null,
            /**    
             * Triggered for every grid action server failure event.
             * @event
             * @name ejGrid#actionFailure	
             * @param {Object} argument Arguments in actionComplete when grid is initialized.     
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.requestType Returns request type.
             * @param {string} argument.type Returns the name of the event.
             * @param {object} argument.error Returns the error return by server.
             
             * @param {Object} argument Arguments in actionComplete after grid paging action is completed.
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {number} argument.currentPage Returns the current selected page number.
             * @param {number} argument.previousPage Returns the previous selected page number.
             * @param {number} argument.endIndex Returns the end row index of that current page.
             * @param {object} argument.model Returns the grid model.				
             * @param {string} argument.originalEventType Returns current action event type.
             * @param {string} argument.requestType Returns request type.
             * @param {number} argument.startIndex Returns the start row index of the current page.
             * @param {object} argument.target Returns grid element.
             * @param {string} argument.type Returns the name of the event.
             * @param {object} argument.error Returns the error return by server.
             
             * @param {object} argument Arguments in actionComplete after grid sorting action is completed.				
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {string} argument.columnName Returns the current sorted column field name.
             * @param {string} argument.columnSortDirection Returns the column sort direction.
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.originalEventType Returns current action event type.
             * @param {string} argument.requestType Returns request type.
             * @param {object} argument.target Returns grid element.
             * @param {string} argument.type Returns the name of the event.
             * @param {object} argument.error Returns the error return by server.
             
             * @param {object} argument Arguments in actionComplete after grid grouping action is completed.
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {string} argument.columnName Returns the current grouped column field name.
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.originalEventType Returns current action event type.
             * @param {string} argument.requestType Returns request type.
             * @param {object} argument.target Returns grid element.
             * @param {string} argument.type Returns the name of the event.
             * @param {object} argument.error Returns the error return by server.
             
             * @param {object} argument Arguments in actionComplete after grid record editing action is completed.
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {object} argument.row Returns current edited row.
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.originalEventType Returns current action event type.
             * @param {string} argument.primaryKey Returns primary key.
             * @param {string} argument.primaryKeyValue Returns primary key value.
             * @param {string} argument.requestType Returns request type.
             * @param {number} argument.rowIndex Returns the edited row index.
             * @param {object} argument.target Returns grid element.
             * @param {string} argument.type Returns the name of the event.
             * @param {object} argument.error Returns the error return by server.
             
             * @param {object} argument Arguments in actionComplete after grid record save action is completed.
             * @param {object} argument.cancel Returns the cancel option value.
             * @param {object} argument.data Returns the record object (JSON).
             * @param {number} argument.selectedRow Returns the selectedRow index.
             * @param {object} argument.foreignKeyData Returns the foreign key record object (JSON).
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.originalEventType Returns current action event type.
             * @param {string} argument.requestType Returns request type.
             * @param {object} argument.target Returns grid element.
             * @param {string} argument.type Returns the name of the event.
             * @param {object} argument.error Returns the error return by server.
             
             * @param {object} argument Arguments in actionComplete after grid record delete action is completed.
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {object} argument.data Returns the record object (JSON).
             * @param {object} argument.foreignKeyData Returns the foreign key record object (JSON).
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.originalEventType Returns current action event type.
             * @param {string} argument.requestType Returns request type.
             * @param {object} argument.target Returns grid element.
             * @param {object} argument.tr Returns selected row for delete.
             * @param {string} argument.type Returns the name of the event.
             * @param {object} argument.error Returns the error return by server.
             
             * @param {object} argument Arguments in actionComplete after add new record action is completed.
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {object} argument.data Returns empty record object (JSON).
             * @param {object} argument.foreignKeyData Returns the foreign key record object (JSON).
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.originalEventType Returns current action event type.
             * @param {string} argument.requestType Returns request type.
             * @param {object} argument.target Returns grid element.
             * @param {string} argument.type Returns the name of the event.
             * @param {object} argument.error Returns the error return by server.
             
             * @param {object} argument Arguments in actionComplete after grid filtering action is completed.
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {string} argument.currentFilteringColumn Returns current filtering column field name.
             * @param {object} argument.filterCollection Returns filter details.
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.originalEventType Returns current action event type.
             * @param {string} argument.requestType Returns request type.
             * @param {object} argument.target Returns grid element.
             * @param {string} argument.type Returns the name of the event.
             * @param {object} argument.error Returns the error return by server.
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    actionFailure: function (args) {}
             * }); 
             * &lt;/script&gt;
             */
            actionFailure: null,
            /**    
             * Triggered before the record is going to be edited.
             * @remarks
             * allowEditing and allowSelection must be set as true
             * @event
             * @name ejGrid#beginEdit 	
             * @param {Object} argument Arguments when beginEdit event is triggered.  
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {object} argument.row Returns the current edited row.
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.primaryKey Returns primary key.
             * @param {string} argument.primaryKeyValue Returns primary key value.
             * @param {number} argument.rowIndex Returns the edited row index.
             * @param {string} argument.type Returns the name of the event.
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    beginEdit: function (args) {}
             * });
             * &lt;/script&gt;
             */
            beginEdit: null,
		    /**    
             * Triggered after the record is edited.
             * @event
             * @name ejGrid#endEdit 	
             * @param {Object} argument Arguments when endEdit event is triggered.  
             * @param {object} argument.model Returns the grid model.
		     * @param {object} argument.data Returns modified data.             
             * @param {string} argument.type Returns the name of the event.
             * @example 
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    endEdit: function (args) {}
             * });
             * &lt;/script&gt;
             */
            endEdit: null,
	        /**    
             * Triggered after the record is added.
             * @event
             * @name ejGrid#endAdd 	
             * @param {Object} argument Arguments when endAdd event is triggered.  
             * @param {object} argument.model Returns the grid model.
		     * @param {object} argument.data Returns added data.
             * @param {string} argument.type Returns the name of the event.             
             * @example 
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    endAdd: function (args) {}
             * });
             * &lt;/script&gt;
             */
            endAdd: null,
		    /**    
             * Triggered after the record is deleted.
             * @event
             * @name ejGrid#endDelete 	
             * @param {Object} argument Arguments when endDelete event is triggered.  
             * @param {object} argument.model Returns the grid model.
		     * @param {object} argument.data Returns deleted data.
             * @param {string} argument.type Returns the name of the event.             
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    endDelete: function (args) {}
             * });
             * &lt;/script&gt;
             */
            endDelete: null,
			 /**    
             * Triggered before the batch add.
             * @event
             * @name ejGrid#beforeBatchAdd 	
             * @param {Object} argument Arguments when beforeBatchAdd event is triggered.  
             * @param {object} argument.model Returns the grid model.
		     * @param {object} argument.data Returns deleted data.
             * @param {string} argument.type Returns the name of the event.
             * @param {object} argument.defaultData Returns the default data object.
             * @param {string} argument.primaryKey Returns primaryKey.
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    beforeBatchAdd: function (args) {}
             * });
             * &lt;/script&gt;
             */
            beforeBatchAdd: null,
            /**    
             * Triggered before the batch save.
             * @event
             * @name ejGrid#beforeBatchSave 	
             * @param {Object} argument Arguments when beforeBatchSave event is triggered.  
             * @param {object} argument.model Returns the grid model.
		     * @param {object} argument.data Returns deleted data.
             * @param {string} argument.type Returns the name of the event.
             * @param {object} argument.batchChanges Returns the changed record object.
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    beforeBatchSave: function (args) {}
             * });
             * &lt;/script&gt;
             */
            beforeBatchSave: null,
            /**    
             * Triggered before the batch delete.
             * @event
             * @name ejGrid#beforeBatchDelete 	
             * @param {Object} argument Arguments when beforeBatchDelete event is triggered.  
             * @param {object} argument.model Returns the grid model.
		     * @param {object} argument.data Returns deleted data.
             * @param {string} argument.type Returns the name of the event.
             * @param {string} argument.primaryKey Returns primaryKey.
             * @param {number} argument.rowIndex Returns the row index.
             * @param {object} argument.rowData Returns the row data.
             * @param {object} argument.row Returns the row element.
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    beforeBatchDelete: function (args) {}
             * });
             * &lt;/script&gt;
             */
            beforeBatchDelete: null,
            /**    
             * Triggered when record batch add.
             * @event
             * @name ejGrid#batchAdd 	
             * @param {Object} argument Arguments when batchAdd event is triggered.  
             * @param {object} argument.model Returns the grid model.
		     * @param {object} argument.data Returns deleted data.
             * @param {string} argument.type Returns the name of the event.
             * @param {object} argument.columnObject Returns the column object.
             * @param {number} argument.columnIndex Returns the column index.
             * @param {object} argument.row Returns the row element.
             * @param {object} argument.primaryKey Returns the primaryKey.            
             * @param {object} argument.cell Returns the cell object.   
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    batchAdd: function (args) {}
             * });
             * &lt;/script&gt;
             */
            batchAdd: null,
            /**    
             * Triggered when record batch delete.
             * @event
             * @name ejGrid#batchDelete 	
             * @param {Object} argument Arguments when batchDelete event is triggered.  
             * @param {object} argument.model Returns the grid model.
		     * @param {object} argument.data Returns deleted data.
             * @param {string} argument.type Returns the name of the event.              
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    batchDelete: function (args) {}
             * });
             * &lt;/script&gt;
             */
            batchDelete: null,
            /**    
             * Triggered when record cell save.
             * @event
             * @name ejGrid#cellSave 	
             * @param {Object} argument Arguments when cellSave event is triggered.  
             * @param {object} argument.model Returns the grid model.
		     * @param {object} argument.data Returns deleted data.
             * @param {string} argument.type Returns the name of the event.
             * @param {string} argument.columnName Returns the column name.
             * @param {string} argument.value Returns the cell value.
             * @param {object} argument.rowData Returns the row data object.
             * @param {string} argument.previousValue Returns the previous value of the cell.
             * @param {object} argument.columnObject Returns the column object.
             * @param {object} argument.cell Returns the cell object.
             * @param {boolean} argument.isForeignKey Returns isForeignKey option value.
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    cellSave: function (args) {}
             * });
             * &lt;/script&gt;
             */
            cellSave: null,            
            /**    
             * Triggered when record cell edit.
             * @event
             * @name ejGrid#cellEdit 	
             * @param {Object} argument Arguments when cellEdit event is triggered.  
             * @param {object} argument.model Returns the grid model.
		     * @param {object} argument.data Returns deleted data.
             * @param {string} argument.type Returns the name of the event.
             * @param {object} argument.validationRules Returns the validation rules.
             * @param {string} argument.columnName Returns the column name.
             * @param {string} argument.value Returns the cell value.
             * @param {object} argument.rowData Returns the row data object.
             * @param {string} argument.previousValue Returns the previous value of the cell.
             * @param {object} argument.columnObject Returns the column object.
             * @param {object} argument.cell Returns the cell object.
             * @param {boolean} argument.isForeignKey Returns isForeignKey option value.
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    cellEdit: function (args) {}
             * });
             * &lt;/script&gt;
             */
            cellEdit: null,
            /**    
             * Triggered when column resize start.
             * @event
             * @name ejGrid#resizeStart 	
             * @param {Object} argument Arguments when resizeStart event is triggered.  
             * @param {object} argument.model Returns the grid model.
		     * @param {object} argument.data Returns deleted data.
             * @param {string} argument.type Returns the name of the event.             
             * @param {number} argument.columnIndex Returns the column index.            
             * @param {object} argument.column Returns the column object.            
             * @param {object} argument.target Returns the grid object.
             * @param {number} argument.oldWidth Returns the old width value.            
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    resizeStart: function (args) {}
             * });
             * &lt;/script&gt;
             */
            resizeStart: null,
            /**    
             * Triggered when column resize end.
             * @event
             * @name ejGrid#resizeEnd 	
             * @param {Object} argument Arguments when resizeEnd event is triggered.  
             * @param {object} argument.model Returns the grid model.
		     * @param {object} argument.data Returns deleted data.
             * @param {string} argument.type Returns the name of the event.             
             * @param {number} argument.columnIndex Returns the column index.            
             * @param {object} argument.column Returns the column object.            
             * @param {object} argument.target Returns the grid object.
             * @param {number} argument.oldWidth Returns the old width value. 
             * @param {number} argument.newWidth Returns the new width value.
             * @param {number} argument.extra Returns the extra width value.            
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    resizeEnd: function (args) {}
             * });
             * &lt;/script&gt;
             */
            resizeEnd: null,
            /**    
             * Triggered after column resized.
             * @event
             * @name ejGrid#resized 	
             * @param {Object} argument Arguments when resized event is triggered.  
             * @param {object} argument.model Returns the grid model.
		     * @param {object} argument.data Returns deleted data.
             * @param {string} argument.type Returns the name of the event.             
             * @param {number} argument.columnIndex Returns the column index.            
             * @param {object} argument.column Returns the column object.            
             * @param {object} argument.target Returns the grid object.
             * @param {number} argument.oldWidth Returns the old width value. 
             * @param {number} argument.newWidth Returns the new width value.                      
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    resized: function (args) {}
             * });
             * &lt;/script&gt;
             */
            resized: null,
            /**    
             * Triggered initial load.
             * @event
             * @name ejGrid#load 	
             * @param {Object} argument Arguments when load event is triggered.  
             * @param {object} argument.model Returns the grid model.
		     * @param {object} argument.data Returns deleted data.
             * @param {string} argument.type Returns the name of the event.                                       
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    load: function (args) {}
             * });
             * &lt;/script&gt;
             */
            load: null,
            /**    
             * Triggered when grid going to destroy.
             * @event
             * @name ejGrid#destroy 	
             * @param {Object} argument Arguments when destroy event is triggered.  
             * @param {object} argument.model Returns the grid model.
		     * @param {object} argument.data Returns deleted data.
             * @param {string} argument.type Returns the name of the event.                                       
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    destroy: function (args) {}
             * });
             * &lt;/script&gt;
             */
            destroy: null,
            /**    
             * Triggered before the row is going to be selected.
             * @remarks
             * allowSelection must be set as true
             * @event
             * @name ejGrid#rowSelecting
             * @param {Object} argument Arguments when rowSelecting event is triggered.  
             * @param {number} argument.rowIndex Returns the selected row index value.
             * @param {object} argument.row Returns the selected row element.
             * @param {object} argument.prevRow Returns the previous selected row element.
             * @param {number} argument.prevRowIndex Returns the previous selected row index.
             * @param {object} argument.data Returns current record object (JSON).
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.type Returns the name of the event.
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    rowSelecting: function (args) {}
             * });
             * &lt;/script&gt;
             */
            rowSelecting: null,
            /**    
             * Triggered after the row is selected.
             * @remarks
             * allowSelection must be set as true
             * @event
             * @name ejGrid#rowSelected 	
             * @param {Object} argument Arguments when rowSelected event is triggered.  
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {object} argument.data Returns current record object (JSON).
             * @param {object} argument.foreignKeyData Returns the foreign key record object (JSON).
             * @param {number} argument.rowIndex Returns the row index of the selected row.
             * @param {object} argument.row Returns the current selected row.
             * @param {object} argument.prevRow Returns the previous selected row element.
             * @param {number} argument.prevRowIndex Returns the previous selected row index.
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.type Returns the name of the event.
             * @example 
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    rowSelected: function (args) {}
             * });
             * &lt;/script&gt;
             */
            rowSelected: null,
            /**    
            * Triggered before the cell is going to be selected.
            * @remarks
            * allowSelection must be set as true and selectionMode must contains cell in array
            * @event
            * @name ejGrid#cellSelecting
            * @param {Object} argument Arguments when cellSelecting event is triggered.  
            * @param {number} argument.cellIndex Returns the selected cell index value.
            * @param {number} argument.previousRowCellIndex Returns the previous selected cell index value.
            * @param {object} argument.currentCell Returns the selected cell element.
            * @param {object} argument.previousRowCell Returns the previous selected cell element.
            * @param {object} argument.data Returns current record object (JSON).
            * @param {array}  argument.previousRowCellIndex Returns the previously selected row cell index values
            * @param {boolean} argument.isCtrlKeyPressed Returns whether the ctrl key is pressed while selecting cell
            * @param {boolean} argument.isShiftKeyPressed Returns whether the shift key is pressed while selecting cell
            * @param {object} argument.model Returns the grid model.
            * @param {string} argument.type Returns the name of the event.
            * @example
            * &lt;div id="Grid"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#Grid").ejGrid({
            *    cellSelecting: function (args) {}
            * });
            * &lt;/script&gt;
            */
            cellSelecting: null,
            /**    
           * Triggered after the cell is selected.
           * @remarks
           * allowSelection must be set as true and selectionMode must contains cell in array
           * @event
           * @name ejGrid#cellSelected
           * @param {Object} argument Arguments when cellSelecting event is triggered.  
           * @param {number} argument.cellIndex Returns the selected cell index value.
           * @param {number} argument.previousRowCellIndex Returns the previous selected cell index value.
           * @param {object} argument.currentCell Returns the selected cell element.
           * @param {object} argument.previousRowCell Returns the previous selected cell element.
           * @param {object} argument.data Returns current record object (JSON).
           * @param {array}  argument.selectedRowCellIndex Returns the selected row cell index values.
           * @param {boolean} argument.cancel Returns the cancel option value.
           * @param {object} argument.model Returns the grid model.
           * @param {string} argument.type Returns the name of the event.
           * @example
           * &lt;div id="Grid"&gt;&lt;/div&gt; 
           * &lt;script&gt;
           * $("#Grid").ejGrid({
           *    cellSelected: function (args) {}
           * });
           * &lt;/script&gt;
           */
            cellSelected: null,
            /**    
           * Triggered before the column is going to be selected.
           * @remarks
           * allowSelection must be set as true and selectionMode must contains column in array
           * @event
           * @name ejGrid#columnSelecting
           * @param {Object} argument Arguments when columnSelecting event is triggered.  
           * @param {number} argument.columnIndex Returns the selected column index value.
           * @param {number} argument.previousColumnIndex Returns the previous selected column index value.
           * @param {object} argument.headerCell Returns the selected header cell element.
           * @param {object} argument.prevColumnHeaderCell Returns the previous selected header cell element.
           * @param {object} argument.column Returns corresponding column object (JSON).
           * @param {array}  argument.previousColumnIndex Returns the previously selected column index values
           * @param {boolean} argument.isCtrlKeyPressed Returns whether the ctrl key is pressed while selecting cell
           * @param {boolean} argument.isShiftKeyPressed Returns whether the shift key is pressed while selecting cell
           * @param {object} argument.model Returns the grid model.
           * @param {string} argument.type Returns the name of the event.
           * @example
           * &lt;div id="Grid"&gt;&lt;/div&gt; 
           * &lt;script&gt;
           * $("#Grid").ejGrid({
           *    columnSelecting: function (args) {}
           * });
           * &lt;/script&gt;
           */
            columnSelecting: null,
            /**    
           * Triggered after the column is selected.
           * @remarks
           * allowSelection must be set as true and selectionMode must contains column in array
           * @event
           * @name ejGrid#columnSelected
           * @param {Object} argument Arguments when columnSelected event is triggered.  
           * @param {number} argument.columnIndex Returns the selected cell index value.
           * @param {number} argument.previousColumnIndex Returns the previous selected column index value.
           * @param {object} argument.headerCell Returns the selected header cell element.
           * @param {object} argument.prevColumnHeaderCell Returns the previous selected header cell element.
           * @param {object} argument.column Returns corresponding column object (JSON).
           * @param {array}  argument.selectedColumnsIndex Returns the selected columns values.
           * @param {boolean} argument.cancel Returns the cancel option value.
           * @param {object} argument.model Returns the grid model.
           * @param {string} argument.type Returns the name of the event.
           * @example
           * &lt;div id="Grid"&gt;&lt;/div&gt; 
           * &lt;script&gt;
           * $("#Grid").ejGrid({
           *    columnSelected: function (args) {}
           * });
           * &lt;/script&gt;
           */
            columnSelected: null,
            /**    
			 * Triggered when column dragging begins.
			 * @event
             * @remarks
             * allowGrouping or allowReordering must be set as true
			 * @name ejGrid#columnDragStart 	
			 * @param {Object} argument Arguments when columnDragStart event is triggered.  
			 * @param {boolean} argument.cancel Returns the cancel option value.
			 * @param {object} argument.draggableType Returns draggable element type.
             * @param {object} argument.column Returns the draggable column object.
			 * @param {object} argument.model Returns the grid model.
			 * @param {object} argument.target Returns drag start element.
			 * @param {string} argument.type Returns the name of the event.
			 * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
			 * $("#Grid").ejGrid({
			 *     columnDragStart: function (args) {}
			 * });
             * &lt;/script&gt;
			 */
            columnDragStart: null,
            /**    
             * Triggered when the column is being dragged.
             * @remarks
             * allowGrouping or allowReordering must be set as true
             * @event
             * @name ejGrid#columnDrag 	
             * @param {Object} argument Arguments when columnDrag event is triggered.  
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {object} argument.draggableType Returns draggable element type.
             * @param {object} argument.column Returns the draggable column object.
             * @param {object} argument.model Returns the grid model.
             * @param {object} argument.target Returns target elements based on mouse move position.
             * @param {string} argument.type Returns the name of the event.
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    columnDrag: function (args) {}
             * });
             * &lt;/script&gt;
             */
            columnDrag: null,
            /**    
             * Triggered when the column is dropped.
             * @remarks
             * allowGrouping or allowReordering must be set as true
             * @event
             * @name ejGrid#columnDrop 	
             * @param {Object} argument Arguments when columnDrop event is triggered.  
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {object} argument.draggableType Returns draggable element type.
             * @param {object} argument.column Returns the draggable column object.
             * @param {object} argument.model Returns the grid model.
             * @param {object} argument.target Returns dropped dragged element.
             * @param {string} argument.type Returns the name of the event.
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt;
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *  columnDrop: function (args) {}
             * });
             * &lt;/script&gt;
             */
            columnDrop: null,
            /**    
             * Triggered when record is clicked.
             * @remarks
             * allowSelection must be set as true
             * @event
             * @name ejGrid#recordClick 	
             * @param {Object} argument Arguments when recordClick event is triggered.  
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {object} argument.data Returns current record object (JSON).
             * @param {number} argument.rowIndex Returns the row index of the selected row.
             * @param {object} argument.row Returns the current selected row.
             * @param {object} argument.cell Returns the current selected cell.
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.type Returns the name of the event.
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    recordClick: function (args) {}
             * });
             * &lt;/script&gt;
             */
            recordClick: null,
            /**    
             * Triggered when record is double clicked.
             * @remarks
             * allowSelection must be set as true
             * @event
             * @name ejGrid#recordDoubleClick 	
             * @param {Object} argument Arguments when recordDoubleClick event is triggered.  
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {object} argument.data Returns current record object (JSON).
             * @param {number} argument.rowIndex Returns the row index of the selected row.
             * @param {object} argument.row Returns the current selected row.
             * @param {object} argument.cell Returns the current selected cell.
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.type Returns the name of the event.
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    recordDoubleClick: function (args) {}
             * });
             * &lt;/script&gt;
             */
            recordDoubleClick: null,
            /**    
             * Triggered when right clicked on grid element.
             * @event
             * @name ejGrid#rightClick 	
             * @param {Object} argument Arguments when rightClick event is triggered.  
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {object} argument.currentData Returns current record object (JSON).
             * @param {number} argument.rowIndex Returns the row index of the selected row.
             * @param {object} argument.row Returns the current selected row.
             * @param {object} argument.data Returns the selected row data object.
             * @param {number} argument.cellIndex Returns the cell index of the selected cell.
             * @param {string} argument.cellValue Returns the cell value.
             * @param {object} argument.cell Returns the cell object.
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.type Returns the name of the event.
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    rightClick: function (args) {}
             * });
             * &lt;/script&gt;
             */
            rightClick: null,
            /**    
             * Triggered when detail template row is clicked to collapse.
             * @remarks
             * detailsTemplate and detailsDataBound must be specified.
             * @event
             * @name ejGrid#detailsCollapse 	
             * @param {Object} argument Arguments when detailsCollapse event is triggered.  
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {object} argument.detailsRow Returns detail row element.
             * @param {object} argument.masterData Returns master row of detail row record object (JSON).
             * @param {object} argument.foreignKeyData Returns the foreign key record object (JSON).
             * @param {object} argument.masterRow Returns master row element.
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.type Returns the name of the event.
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    detailsCollapse: function (args) {}
             * });
             * &lt;/script&gt;
             */
            detailsCollapse: null,
            /**    
             * Triggered when detail template row is clicked to expand.
             * @remarks
             * detailsTemplate and detailsDataBound must be specified.
             * @event
             * @name ejGrid#detailsExpand 	
             * @param {Object} argument Arguments when detailsExpand event is triggered.  
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {object} argument.detailsRow Returns detail row element.
             * @param {object} argument.masterData Returns master row of detail row record object (JSON).
             * @param {object} argument.foreignKeyData Returns the foreign key record object (JSON).
             * @param {object} argument.masterRow Returns master row element.
             * @param {object} argument.model Returns the grid model.
             * @param {string} argument.type Returns the name of the event.
             * @example 
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *    detailsExpand: function (args) {}
             * });
             * &lt;/script&gt;
             */
            detailsExpand: null,
            /**    
			 * Triggered when toolbar item is clicked in grid.
             * @remarks
             * showToolbar must be set as true and also add the toolbarItems.
			 * @event
			 * @name ejGrid#toolBarClick 	
			 * @param {Object} argument Arguments when toolBarClick event is triggered.  
			 * @param {boolean} argument.cancel Returns the cancel option value.
			 * @param {object} argument.currentTarget Returns the current item.
			 * @param {object} argument.model Returns the grid model.
			 * @param {boolean} argument.status Returns the status of toolbar item which denotes its enabled state
			 * @param {object} argument.target Returns the target item.
			 * @param {string} argument.type Returns the name of the event.
			 * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
			 * $("#Grid").ejGrid({
			 *    toolbarClick: function (args) {}
			 * });
             * &lt;/script&gt;
			 */
            toolbarClick: null,
            /**    
			 * Triggered before the context menu is opened.
             * @remarks
             * enableContextMenu must be set as true and also add the contextMenuItems.
			 * @event
			 * @name ejGrid#contextOpen	
			 * @param {Object} argument Arguments when contextOpen event is triggered.  
             * @param {boolean} argument.cancel Returns the cancel option value.
             * @param {object} argument.currentTarget Returns the current item.
             * @param {object} argument.model Returns the grid model.
             * @param {boolean} argument.status Returns the status of contextmenu item which denotes its enabled state
             * @param {object} argument.target Returns the target item.
             * @param {string} argument.type Returns the name of the event.
			 * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
			 * $("#Grid").ejGrid({
			 *    contextOpen: function (args) {}
			 * });
             * &lt;/script&gt;
			 */

            contextOpen: null,
            /**    
            * Triggered when context menu item is clicked
            * @remarks
            * enableContextMenu must be set as true and also add the contextMenuItems.
			* @event
            * @name ejGrid#contextClick 	
            * @param {Object} argument Arguments when contextClick event is triggered.  
            * @param {boolean} argument.cancel Returns the cancel option value.
            * @param {object} argument.currentTarget Returns the current item.
            * @param {object} argument.model Returns the grid model.
            * @param {boolean} argument.status Returns the status of contextmenu item which denotes its enabled state
            * @param {object} argument.target Returns the target item.
            * @param {string} argument.type Returns the name of the event.
            * @example
            * &lt;div id="Grid"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#Grid").ejGrid({
            *    contextClick: function (args) {}
            * });
            * &lt;/script&gt;
            */
            contextClick: null,

            /**		
             * Gets or sets an object  that indicates to render the grid with specified columns
             * @name ejGrid#columns 
             * @default []
             * @type {array}
             * @example 
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData
             * });
             * var value = $("#Grid").ejGrid("option", "columns");
             * &lt;/script&gt; 
             */

            /**
             * Gets or sets a value that indicates to display the columns in the grid mapping  with column name of the dataSource.
             * @remarks
             * We must need to specify the field property of the column because the columns which are specified in the field property is only bound to the grid.
             * @name ejGrid#columns->field 	          
             * @default ""
             * @type {string}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   columns:[{field:"OrderID"}]
             * });
             * &lt;/script&gt; 
             */

            /**
			 * Gets or sets a value that indicates to display the title of that particular column.
             * @remarks
             * It is optional if the headerText is not mentioned then it will consider the field name as headerText
             * @name ejGrid#columns->headerText 	          
             * @default ""
             * @type {string}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   columns:[{field:"OrderID",headerText:"Order ID"},{field:"CustomerID",headerText:"Customer ID"}]
             * });
             * &lt;/script&gt; 
			 */

            /**
			 * Gets or sets a value that indicates whether to enable dynamic grouping behaviour for particular column.
             * @remarks
             * It is optional if we need to disable the grouping behaviour for particular column then set this property as false.
             * @name ejGrid#columns->allowGrouping 	          
             * @default true
             * @type {boolean}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   allowGrouping:true,
             *   columns:[{field:"OrderID"},{field:"CustomerID",allowGrouping:false},{field:"ShipCity"}]
             * });
             * &lt;/script&gt; 
			 */

            /**
             * Gets or sets a value that indicates whether to enable dynamic filtering behaviour for particular column.
             * @remarks
             * It is optional if we need to disable the filtering behaviour for particular column then set this property as false.
             * @name ejGrid#columns->allowFiltering 	          
             * @default true
             * @type {boolean}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   allowFiltering:true,
             *   columns:[{field:"OrderID"},{field:"CustomerID",allowFiltering:false},{field:"ShipCity"}]
             * });
             * &lt;/script&gt; 
             */

            /**
             * Gets or sets a value that indicates whether to enable dynamic sorting behaviour for particular column.
             * @remarks
             * It is optional if we need to disable the sorting behaviour for particular column then set this property as false.
             * @name ejGrid#columns->allowSorting 	          
             * @default true
             * @type {boolean}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   allowSorting:true,
             *   columns:[{field:"OrderID"},{field:"CustomerID",allowSorting:false},{field:"ShipCity"}] 
             * });
             * &lt;/script&gt; 
             */

            /**
             * Gets or sets a value that indicates whether to enable editing behaviour for particular column.
             * @remarks
             * It is optional if we need to disable the editing behaviour for particular column then set this property as false.
             * @name ejGrid#columns->allowEditing 	          
             * @default true
             * @type {boolean}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   editSettings:{allowEditing:true},
             *   columns:[{field:"OrderID"},{field:"CustomerID",allowEditing:false},{field:"ShipCity"}] 
             * });
             * &lt;/script&gt; 
             */

            /**
             * Gets or sets a value that indicates whether to bind the column which are not in the datasource 
             * @remarks
             * If we need to bind the column to the grid which is not in the datasource then we must enable isUnBound property.
             * There is no need to specify field property if the column is unBound.
             * @name ejGrid#columns->isUnbound 	          
             * @default false
             * @type {boolean}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   columns:[{field:"OrderID",isUnbound:false},{field:"CustomerID"},{field:"ShipCity",headerText:"ShipCity"}]
             * });
             * &lt;/script&gt; 
             */

            /**
             * Gets or sets a value that indicates whether to  enables column template for a particular column.
             * @remarks
             * Need to bind the templateID, if the columnTemplate is set as true.
             * @name ejGrid#columns->template 	          
             * @default false
             * @type {boolean}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script id="columnTemplate" type="text/x-jsrender"&gt;
             * &lt;img src="styles/images/Employees/{{:EmployeeID}}.png" alt="{{:EmployeeID}}"/&gt;
             * &lt;/script&gt;
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *  dataSource:window.gridData,
             *  columns:[{headerText:"Employee",template:true,templateID:"#columnTemplate"},{field:"EmployeeID"}]
             * });
             * &lt;/script&gt;
             */

            /**
             * Gets or sets a value that indicates to render the element(based on edit type)  for editing the grid record. . See {@link editingType}
             * @remarks
             * allowEditing must be set as true.
             * It is optional.
             * @name ejGrid#columns->editType 	          
             * @default ej.Grid.EditingType.String
             * @type {enum}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   editSettings:{allowEditing:true},
             *   columns:[{field:"OrderID"},{field:"CustomerID"},{field:"Freight",editType:ej.Grid.EditingType.Numeric, editParams: { decimalPlaces: 2 }}]
             * });
             * &lt;/script&gt; 
             */

            /**
            * Gets or sets a template that displays a custom editor used to edit column values. See {@link editTemplate}
            * @remarks
            * allowEditing must be set as true.
            * It is optional.
            * @default null
            * @type {object}
            * @name ejGrid#columns->editTemplate 	          
            * @example
            * &lt;div id="Grid"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#Grid").ejGrid({
            *   dataSource:window.gridData,
            *   editSettings:{allowEditing:true},
            *   columns:[{field:"OrderID"},{field:"CustomerID"},
            *             { field: "EmployeeID",editTemplate: { create: function () { return "&lt;input&gt;"; }, read: function (args) { return args.ejMaskEdit("get_StrippedValue"); }, write: function (args) { args.element.ejMaskEdit({ width: "100%" ,maskFormat: "9",value: args.rowdata !== undefined ? args.rowdata["EmployeeID"]: "" }); } } }]
            * });
            * &lt;/script&gt; 
            */

            /**
             * Gets or sets a value that indicates to align the text within the column. See {@link textAlign}
             * @remarks
             * It is optional.
             * @name ejGrid#columns->textAlign 	          
             * @default ej.TextAlign.Left
             * @type {enum}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   columns:[{field:"OrderID",textAlign:ej.TextAlign.Center},{field:"CustomerID",textAlign:ej.TextAlign.Right},{field:"ShipCity"}]
             * });
             * &lt;/script&gt; 
             */

            /**
             * Gets or sets a value that indicates the column is act as a primary key(read-only) of the grid. The editing is performed based on the primary key column
             * @remarks
             * When editing is enable then we must set isPrimaryKey property as true for the primary key column.
             * @name ejGrid#columns->isPrimaryKey 	          
             * @default false
             * @type {boolean}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({             
             *   dataSource:window.gridData,
             *   editSettings:{allowEditing:true},
             *   columns:[{field:"OrderID",isPrimaryKey:true},{field:"CustomerID"},{field:"ShipCity"}]
             * });
             * &lt;/script&gt; 
             */

            /**
             * Gets or sets a value that indicates thecolumn has an identity in the database.            
             * @name ejGrid#columns->isIdentity 	          
             * @default false
             * @type {boolean}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   columns:[{field:"OrderID"},{field:"CustomerID",isIdentity:true},{field:"ShipCity"}]
             * });
             * &lt;/script&gt; 
             */

            /**
             * Gets or sets a value that indicates whether this column is visible in the grid.
             * @remarks
             * It is optional.
             * @name ejGrid#columns->visible 	          
             * @default true
             * @type {boolean}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   columns:[{field:"OrderID"},{field:"CustomerID",visible:false},{field:"ShipCity"}]
             * });
             * &lt;/script&gt; 
             */

            /**
			 * Gets or sets a value that indicates to bind the external datasource to the particular column when columnEditType as "dropdownedit" and also it is used to bind the datasource to the foreign key column while editing the grid. 
             * //Where data is array of JSON objects of text and value for the drop-down and array of JSON objects for foreign key column.
             * @remarks
             * We must specify the dataSource property.
             * @name ejGrid#columns->dataSource 	          
             * @default null
             * @type {array}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt;  
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   columns:[{field:"OrderID"},{field:"CustomerID",visible:false},{field:"ShipCity"}]
             * });
             * &lt;/script&gt;
             */

            /**
             * Gets or sets a value that indicates to provide custom css for an individual column.
             * @name ejGrid#columns->cssClass 	          
             * @default -
             * @type {string}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;style class="temp"&gt;
             * .temp{
             * color:green;}
             * &lt;/style&gt;
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   columns:[{field:"OrderID"},{field:"CustomerID",cssClass:"temp"},{field:"ShipCity"}]
             * });
             * &lt;/script&gt; 
             */

            /**
             * Gets or sets a value that indicates to display the specified default value while adding a new record to the grid
             * @remarks
             * It is optional.allowAdding must be true while using this property.
             * @name ejGrid#columns->defaultValue 	          
             * @default -
             * @type {string/number/boolean/date}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt;          
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   editSettings: {allowAdding: true},
             *   toolbarSettings: { showToolbar: true, toolbarItems: [ej.Grid.ToolBarItems.Add] },
             *   columns:[{field:"OrderID"},{field:"CustomerID"},{field:"ShipCity",defaultValue:"ABC"}]
             * });
             * &lt;/script&gt;
             */

            /**
			 * Gets or sets a value that indicates to add the template within the header element of the particular column.
             * @remarks
             * It is optional.
             * @name ejGrid#columns->headerTemplateID 	          
             * @default null
             * @type {string}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;div id="customerTemplate"&gt;
             * &lt;span class="e-userlogin e-icon headericon"&gt;&lt;/span&gt;
             *  CUS ID
             * &lt;/div&gt;
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   columns:[{field:"OrderID",headerTemplateID: "#customerTemplate"},{field:"CustomerID"},{field:"ShipCity"}]
             * });
             * &lt;/script&gt;
             */

            /**
			 * Gets or sets a value that indicates to define the width for a particular column in the grid.
             * @remarks
	     * The column width support units in percent, px, number.
             * It is optional.
             * @name ejGrid#columns->width 	          
             * @default -
             * @type {number}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt;          
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   columns:[{field:"OrderID",width:50},{field:"CustomerID",width:"15%"},{field:"ShipCity",width:"70px"}]
             * });
             * &lt;/script&gt;
             */

            /**
             * Gets or sets a value that indicates to define foreign key field name of the grid datasource.
             * @remarks
             * It is optional. If the foreignKeyField name is not specified then it will take the field name from the "field" property.
             * We must specify the data source for column dataSource property
             * @name ejGrid#columns->foreignKeyField  	          
             * @default null
             * @type {string}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt;          
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   columns:[{field:"OrderID"},{field:"EmployeeID",foreignKeyField:"EmployeeID",foreignKeyValue:"FirstName",headerText:"FirstName",dataSource:window.employeeData },{field:"ShipCity"}]
             * });
             * &lt;/script&gt;
             */

            /**
             * Gets or sets a value that indicates to bind the field which is in foreign column datasource based on the foreignKeyField
             * @remarks
             * We must specify the data source for column dataSource property
             * @name ejGrid#columns->foreignKeyValue  	          
             * @default null
             * @type {string}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt;  
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   columns:[{field:"OrderID"},{field:"EmployeeID",foreignKeyField:"EmployeeID",foreignKeyValue:"FirstName",dataSource:window.employeeData,headerText:"FirstName"},{field:"ShipCity"}]
             * });
             * &lt;/script&gt; 
             */

            /**
             * Gets or sets a value that indicates to define constraints for saving data to the database.
             * @remarks
             * allowEditing or allowAdding must be set as true. It is must to add the validations script. They are jquery.validate.min.js and jquery.validate.unobtrusive.min.js
             * @name ejGrid#columns->validationRules 	          
             * @type {object}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt;          
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   editSettings: {allowEditing: true, allowAdding: true},
             *   columns:[{field:"OrderID", validationRules: { required: true, number: true }},{field:"CustomerID"},{field:"ShipCity"}] 
             * });
             * &lt;/script&gt; 
             */

            /**
             * Gets or sets a value that indicates the format for the text applied on the column
             * @name ejGrid#columns->format 	          
             * @default -
             * @type {string}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt;          
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   columns:[{field:"OrderID"},{field:"CustomerID"},{field:"Freight",format:"{0:C}"}]
             * });
             * &lt;/script&gt;  
             */

            /**
             * Gets or sets a value that indicates the attribute values to the td element of a particular column
             * @name ejGrid#columns->customAttributes 	          
             * @default -
             * @type {object}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt;          
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *   dataSource:window.gridData,
             *   columns:[{field:"OrderID"},{field:"CustomerID",customAttributes:{"style":"color:red"}},{field:"Freight"}]
             * });
             * &lt;/script&gt;  
             */

            /**
             * Gets or sets a value that indicates to add the template as a particular column data .
             * @remarks
             * If you want to use templateID for the column template, then columnTemplate must be set as true.
             * @name ejGrid#columns->templateID 	          
             * @default null
             * @type {string}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script id="columnTemplate" type="text/x-jsrender"&gt;
             * &lt;img src="styles/images/Employees/{{:EmployeeID}}.png" alt="{{:EmployeeID}}"/&gt;
             * &lt;/script&gt;
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *  dataSource:window.gridData,
             *  columns:[{headerText:"Employee",template:true,templateID:"#columnTemplate"},{field:"EmployeeID"}]
             * });
             * &lt;/script&gt;
             */

            /**
             * Gets or sets a value that indicates to render the grid content and header with an html elements
             * @remarks
             * It is optional if we need to disable the htmlencode behaviour for particular column then set this property as false
             * @name ejGrid#columns->disableHtmlEncode	          
             * @default false
             * @type {boolean}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *     dataSource:window.gridData,
             *     columns:[{field:"OrderID",headerText:"&lt;div&gtOrder ID&lt;/div&gt;",disableHtmlEncode:true}
             *   });
             * &lt;/script&gt;
            **/

            /**  
             * You can use this property to freeze selected columns in grid at the time of scrolling.
             * @remarks
             * We must enable allowScrolling property
             * @name ejGrid#columns->isFrozen            
             * @default false
             * @type {boolean}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({             
             *   dataSource:window.gridData,
             *   allowScrolling: true,               
             *   scrollSettings:{width:500,height:100 }
             *   columns:[{field:"OrderID",isFrozen:true},{field:"CustomerID"},{field:"ShipCity"}]
             * });
             * &lt;/script&gt; 
             **/

            /**
             * Gets or sets an object  that indicates to define a command column in the grid.
             * @remarks
             * isUnbound must be true while declaring commands button.
             * @name ejGrid#columns->commands 	          
             * @default []
             * @type {array}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *     dataSource:window.gridData,
             *     editSettings:{allowEditing:true,allowAdding:true,allowDeleting:true},
             *     columns:[
             *            { field: "OrderID", isPrimaryKey: true },  
             *            { field: "EmployeeID" },
             *            {
             *               headerText: "Manage Records",
             *               commands: [
             *                   { type: ej.Grid.UnboundType.Edit, buttonOptions: { text: "Edit" } },
             *                   { type: ej.Grid.UnboundType.Delete, buttonOptions: { text: "Delete" } },
             *                   { type: ej.Grid.UnboundType.Save, buttonOptions: { text: "Save" } },
             *                   { type: ej.Grid.UnboundType.Cancel, buttonOptions: { text: "Cancel" } }
             *                ],
             *               isUnbound: true,
             *               width: 130
             *            }
             *     ] 
             * });
             * &lt;/script&gt; 
             */

            /**
             * Gets or sets a value that indicates to add the command column button. See {@link unboundType}
             * @remarks
             * isUnbound must be true while declaring commands button.
             * @name ejGrid#columns->commands->type	          
             * @default -
             * @type {enum}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *     dataSource:window.gridData,
             *     editSettings:{allowEditing:true,allowAdding:true,allowDeleting:true},
             *     columns:[
             *            { field: "OrderID", isPrimaryKey: true },  
             *            { field: "EmployeeID" },
             *            {
             *               headerText: "Manage Records",
             *               commands: [
             *                   { type: ej.Grid.UnboundType.Edit, buttonOptions: { text: "Edit" } },
             *                   { type: ej.Grid.UnboundType.Delete, buttonOptions: { text: "Delete" } },
             *                   { type: ej.Grid.UnboundType.Save, buttonOptions: { text: "Save" } },
             *                   { type: ej.Grid.UnboundType.Cancel, buttonOptions: { text: "Cancel" } }
             *                ],
             *               isUnbound: true, width: 130
             *            }
             *     ] 
             * });
             * &lt;/script&gt; 
             */

            /**
             * Gets or sets an object that indicates to define all the button options which are available in ejButton.
             * @remarks
             * isUnBound must be true while declaring commands button.
             * @name ejGrid#columns->commands->buttonOptions
             * @default -
             * @type {object}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *     dataSource:window.gridData,
             *     editSettings:{allowEditing:true,allowAdding:true,allowDeleting:true},
             *     columns:[
             *            { field: "OrderID", isPrimaryKey: true },  
             *            { field: "EmployeeID" },
             *            {
             *               headerText: "Manage Records",
             *               commands: [
             *                   { type: ej.Grid.UnboundType.Edit, buttonOptions: { text: "Edit" } },
             *                   { type: ej.Grid.UnboundType.Delete, buttonOptions: { text: "Delete" } },
             *                   { type: ej.Grid.UnboundType.Save, buttonOptions: { text: "Save" } },
             *                   { type: ej.Grid.UnboundType.Cancel, buttonOptions: { text: "Cancel" } }
             *                ],
             *               isUnbound: true, width: 130
             *            }
             *     ] 
             * });
             * &lt;/script&gt; 
             */

            /**
             * Gets or sets a value that indicates to customize ejNumericTextbox of an editable column. See {@link editingType}
             * @name ejGrid#columns->editParams           
             * @default -
             * @type {object}
             * @example
             * &lt;div id="Grid"&gt;&lt;/div&gt; 
             * &lt;script&gt;
             * $("#Grid").ejGrid({
             *     dataSource:window.gridData,
             *     editSettings:{allowEditing:true,allowAdding:true,allowDeleting:true},
             *     columns:[{ field: "OrderID"}, { field: "Freight", editType: ej.Grid.EditingType.Numeric, editParams: { decimalPlaces: 2 }}]
             *   });
             * &lt;/script&gt;  
             */

            /**
            * Gets or sets a value that indicates to specify the datatype of the specified columns.
            * @name ejGrid#columns->type 	          
            * @default -
            * @type {string}
            * @example
            * &lt;div id="Grid"&gt;&lt;/div&gt; 
            * &lt;script&gt;
            * $("#Grid").ejGrid({
            *     dataSource:window.gridData,
            *     columns:[{ field: "OrderID"}, { field: "Verified",type: "boolean" }]
            *   });
            * &lt;/script&gt;  
            */

            columns: [],
			/**		
            * Query the dataSource from the table for Grid.
            * @name ejGrid#query
            * @default null
            * @type {object}
            * @example       
            * &lt;div id="Grid"&gt;&lt;/div&gt; <br> 
            * &lt;script type="text/javascript"&gt;
			* var queryOrder=ej.Query().select(["OrderID", "CustomerID"]); 
            * $("#Grid").ejGrid({
            *   dataSource: window.gridData,
            *   query: queryOrder
			* });  
            * &lt;/script&gt;
            */
            query: null,
            isEdit: false,
            /**		
            * Gets or sets a value that indicates whether the grid design has be to made responsive.
            * @name ejGrid#isResponsive
            * @default false
            * @type boolean
            * @example       
            * &lt;div id="Grid"&gt;&lt;/div&gt; <br> 
            * &lt;script type="text/javascript"&gt; 
            * $("#Grid").ejGrid({
            *   dataSource: window.gridData,
                isResponsive: true 
			* });  
            * &lt;/script&gt;
            */
            isResponsive: false,
             /**		
            * Gets or sets a value that indicates whether the grid rows has to be rendered as detail view in mobile mode
            * @name ejGrid#enableResponsiveRow
            * @default false
            * @type boolean
            * @example       
            * &lt;div id="Grid"&gt;&lt;/div&gt; <br> 
            * &lt;script type="text/javascript"&gt; 
            * $("#Grid").ejGrid({
            *   dataSource: window.gridData,
                isResponsive: true,
                enableResponsiveRow: true    
			* });  
            * &lt;/script&gt;
            */
            enableResponsiveRow: false,
        },
        dataTypes: {
            dataSource: "data",
            query:"data",
            columns: "array",
			childGrid: "parent",
            summaryRows: "array",
			stackedHeaderRows: "array",
            toolbarSettings: {
                toolbarItems: "array",
                customToolbarItems: "array"
            },
            contextMenuSettings: {
                contextMenuItems: "array",
                customContextMenuItems: "array"
            },
            selectionSettings: {
                selectionMode: "array"
            },
            sortSettings: {
                sortedColumns: "array"
            },
            filterSettings: {
                filteredColumns: "array",
                filterType: "enum",
                filterBarMode: "enum",
            },
            groupSettings: {
                groupedColumns: "array"
            },
            editSettings: {
                editMode: "enum",
                formPosition: "enum",
                rowPosition: "enum",
            }
        },

        _columns: function (index, property, value, old) {
            var $header = this.element.find(".e-gridheader");
            $header.find("div").first().empty().append(this._renderGridHeader().find("table"));
            this._headerCellgDragDrop();
            this.refreshContent(true);
            this._trigger("refresh");
        },
        _summaryRows: function (index, property, value, old) {
            if (property == "showTotalSummary" || property == "showCaptionSummary"){
                var indx = index.summaryRows;
                var val = value.toLowerCase() == "true" || value.toLowerCase() == "false" ? ej.parseJSON(value) : false;
                this.option("summaryRows")[indx][property] = val;                  
            }         
            this.element.find(".e-gridfooter").remove();
            this._renderGridFooter().insertAfter(this.getContent());                 
            if (property == "showCaptionSummary" || property == "title") {                
                this._isCaptionSummary = this.option("summaryRows")[indx]["showCaptionSummary"];
                this.model.showSummary = this._isCaptionSummary;
                if(this.model.groupSettings.groupedColumns.length != 0)
                    this._refreshCaptionSummary(); 
            }                                                      
        },
        _summaryRows_summaryColumns: function (index, property, value, old) {            
            if (property == "displayColumn" || property == "dataMember") {                
                if(ej.isNullOrUndefined(this.getColumnByField(value)))
                    return;
            }            
            this._createSummaryRows(this.getFooterTable());
            if(this.element.find(".e-groupcaptionsummary").length != 0)
                this._refreshCaptionSummary();  
        },
        _stackedHeaderRows_stackedHeaderColumns:function(index, property, value, old){
           this._refreshStackedHeader();
        },
        _sortSettings_sortedColumns: function (index, property, value, old) {
            var colName, direction;            
            var sortObj = this.model.sortSettings.sortedColumns[index["sortSettings.sortedColumns"]];
            if (property == "field") {               
                colName = this.getColumnByField(value) != null ? value : null;                
                direction =  (sortObj.direction == "ascending" || sortObj.direction == "descending") ? sortObj.direction : null;
            }
            else if (property == "direction") {               
                colName = this.getColumnByField(sortObj.field) != null ? sortObj.field : null;    
                direction =  (value == "ascending" || value == "descending") ? value : null;   
            }
            if(colName != null && direction != null)
                this.sortColumn(colName, direction);              
        },
        _filterSettings_filteredColumns: function (index, property, value, old) {
            var field, operator, matchcase, predicate, filtervalue;           
            var filterObj = this.model.filterSettings.filteredColumns[index["filterSettings.filteredColumns"]];
            switch (property) {
                case "field":
                    field = this.getColumnByField(value) != null ? value : null; 
                    operator = this._map(ej.FilterOperators, filterObj.operator);
                    filtervalue = filterObj.value;
                    predicate = (filterObj.predicate == "and" || filterObj.predicate == "or") ? filterObj.predicate : null;
                    matchcase = filterObj.matchcase;
                    break;
                case "matchcase":
                    field = this.getColumnByField(filterObj.field) != null ? filterObj.field : null; 
                    operator = this._map(ej.FilterOperators, filterObj.operator);
                    filtervalue = filterObj.value;
                    predicate = (filterObj.predicate == "and" || filterObj.predicate == "or") ? filterObj.predicate : null;
                    matchcase = value.toLowerCase() == "true" || value.toLowerCase() == "false" ? ej.parseJSON(value) : false;
                    break;
                case "operator":
                    field = this.getColumnByField(filterObj.field) != null ? filterObj.field : null; 
                    operator = this._map(ej.FilterOperators, value);
                    filtervalue = filterObj.value;
                    predicate = (filterObj.predicate == "and" || filterObj.predicate == "or") ? filterObj.predicate : null;
                    matchcase = filterObj.matchcase;
                    break;
                case "predicate":
                    field = this.getColumnByField(filterObj.field) != null ? filterObj.field : null; 
                    operator = this._map(ej.FilterOperators, filterObj.operator);
                    filtervalue = filterObj.value;
                    predicate = (value == "and" || value == "or") ? value : null;
                    matchcase = filterObj.matchcase;
                    break;
                case "value":
                    field = this.getColumnByField(filterObj.field) != null ? filterObj.field : null; 
                    operator = this._map(ej.FilterOperators, filterObj.operator);
                    filtervalue = value;
                    predicate = (filterObj.predicate == "and" || filterObj.predicate == "or") ? filterObj.predicate : null;
                    matchcase = filterObj.matchcase;
                    break;
            }
            if(field != null && operator != null && filtervalue != null && predicate != null && matchcase != null)
                this.filterColumn(field, operator, filtervalue, predicate, matchcase);
        },
        _map: function (object, value){
            var data = $.map(object, function (obj) {              
                if(obj === value)
                  return obj; 
            });
            return data.length != 0 ? data[0] : null;
        },
		_refreshCaptionSummary: function(){
            var temp = document.createElement('div');                
            temp.innerHTML = ['<table>', $.render[this._id + "_GroupingTemplate"](this.model.currentViewData, { groupedColumns: this.model.groupSettings.groupedColumns }), '</table>'].join("");
            this.getContentTable().get(0).replaceChild(temp.firstChild.firstChild, this.getContentTable().get(0).lastChild);
            this.refreshContent();
        },
        /**
         * Get the content table element of grid
         * @return gridContentTable
         * @example 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // Gets content table of grid control
         * gridObj.getContentTable();
         * &lt;/script&gt;
         * @example 
         * &lt;script&gt;
         * // Gets content table of grid control
         * $("#Grid").ejGrid("getContentTable");        
         * &lt;/script&gt;
         */
        getContentTable: function () {
            return this._gridContentTable;
        },

        setGridContentTable: function (value) {
            this._gridContentTable = value;
        },
        /**
		 * Get the content div element of grid.
		 * @return gridContent
		 * @example 
		 * &lt;script&gt;
		 * // Create grid object.
		 * var gridObj = $("#Grid").data("ejGrid");
         * // Gets content of grid control
		 * gridObj.getContent(); 
		 * &lt;/script&gt;
		 * @example 
		 * &lt;script&gt;
		 * // Gets content of grid control
		 * $("#Grid").ejGrid("getContent");        
		 * &lt;/script&gt;
         */
        getContent: function () {
            return this._gridContent;
        },

        setGridContent: function (value) {
            this._gridContent = value;
        },
        /**
          * Get the header content div element of grid..
          * @return gridHeaderContent
          * @example 
          * &lt;script&gt;
          * // Create grid object.
          * var gridObj = $("#Grid").data("ejGrid");
          * // Gets grid header content of grid control
          * gridObj.getHeaderContent(); 
          * &lt;/script&gt;
          * @example 
          * &lt;script&gt;
          * // Gets grid header content of grid control
          * $("#Grid").ejGrid("getHeaderContent");        
          * &lt;/script&gt;
          */
        getHeaderContent: function () {
            return this._gridHeaderContent;
        },

        setGridHeaderContent: function (value) {
            this._gridHeaderContent = value;
        },
        /**
		 * Get the header table element of grid
		 * @return gridHeaderTable
		 * @example 
		 * &lt;script&gt;
		 * // Create grid object.
		 * var gridObj = $("#Grid").data("ejGrid");
		 * gridObj.getHeaderTable(); 
         * // Gets header table of grid control
		 * &lt;/script&gt;
		 * @example 
		 * &lt;script&gt;
		 * // Gets header table of grid control
		 * $("#Grid").ejGrid("getHeaderTable");        
		 * &lt;/script&gt;
         */
        getHeaderTable: function () {
            return this._gridHeaderTable;
        },

        setGridHeaderTable: function (value) {
            this._gridHeaderTable = value;
        },
        /**
         * Get the rows(tr element)of grid  which is displayed in the current page.
         * @return gridRows
         * @example 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // Gets grid rows of grid control
         * gridObj.getRows(); 
         * &lt;/script&gt;
         * @example 
         * &lt;script&gt;
         * // Gets grid rows of grid control
         * $("#Grid").ejGrid("getRows");        
         * &lt;/script&gt;
         */
        getRows: function () {
            return this._gridRows;
        },
        /**
        * Get the records filtered or searched in Grid
        * @return filteredRecords
        * @example 
        * &lt;script&gt;
        * // Create grid object.
        * var gridObj = $("#Grid").data("ejGrid");
        * // Gets the filtered or searched records in Grid
        * gridObj.getFilteredRecords();  
        * &lt;/script&gt;
        * @example 
        * &lt;script&gt;
        * // Gets the filtered or searched records in Grid
        * $("#Grid").ejGrid("getFilteredRecords");   
        * &lt;/script&gt;
        */
        getFilteredRecords: function () {
            return this._filteredRecords;
        },
        /**
		 * Get the rows(tr element) from the given from and to row index in grid
		 * @return gridRows
		 * @param {number} from Pass the from index from which the rows to be returned
		 * @param {number} to Pass the to index to which the rows to be returned
		 * @example 
		 * &lt;script&gt;
		 * // Create grid object.
		 * var gridObj = $("#Grid").data("ejGrid");
         * // Gets the rows from the specified row index 
		 * gridObj.getRowByIndex(3, 6);  
		 * &lt;/script&gt;
		 * @example 
		 * &lt;script&gt;
		 * // Gets the rows from the specified row index
		 * $("#Grid").ejGrid("getRowByIndex", 3, 6);   
		 * &lt;/script&gt;
         */
        getRowByIndex: function (from, to) {
            try {
                var gridRows = this.getRows(), $gridRows = $(gridRows), $row = $();
                if (ej.isNullOrUndefined(to)) {
                    if (this.model.scrollSettings.frozenColumns > 0) {
                        $row.push(gridRows[0][from]);
                        $row.push(gridRows[1][from]);
                        return $row;
                    }
                    return $(gridRows[from]);
                } else {
                    if (this.model.scrollSettings.frozenColumns > 0) {
                        $row.push($gridRows.eq(0).slice(from, to));
                        $row.push($gridRows.eq(0).slice(from, to));
                        return $row;
                    }
                    return $($gridRows.slice(from, to));
                }
            } catch (e) {
                return $();
            }
        },
        /**
         * Get the column index of the given field in grid.
         * @return Column Index
         * @param {string} fieldName Pass the field name of the column to get the corresponding column index
         * @example 
         * &lt;div id="Grid"&gt;&lt;/div&gt; 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // Gets the column index based on the given field name
         * gridObj.getColumnIndexByField("OrderID"); 
         * &lt;/script&gt;
         * @example 
         * &lt;div id="Grid"&gt;&lt;/div&gt; 
         * &lt;script&gt;
         * // Gets the column index based on the given field name
         * $("#Grid").ejGrid("getColumnIndexByField", "OrderID");        
         * &lt;/script&gt;
         */
        getColumnIndexByField: function (field) {
            for (var column = 0; column < this.model.columns.length; column++) {
                if (this.model.columns[column]["field"] == field)
                    break;
            }
            return column;
        },
        /**
		 * Get the row index based on the given tr element in grid.
		 * @return row index
		 * @param {object} $tr Pass the tr element in grid content to get its row index
		 * @example 
		 * &lt;script&gt;
		 * // Create grid object.
		 * var gridObj = $("#Grid").data("ejGrid");
         * // Gets the row index based on the given row
		 * gridObj.getIndexByRow($(".gridcontent tr").first()); 
		 * &lt;/script&gt;
		 * @example 
		 * &lt;script&gt;
		 * // Gets the row index based on the given row
		 * $("#Grid").ejGrid("getIndexByRow", $(".gridcontent tr").first());        
		 * &lt;/script&gt;
         */
        getIndexByRow: function ($tr) {
            var gridRows = this.getRows(), $gridRows = $(gridRows), rowIndex;
            if (this.model.scrollSettings.frozenColumns > 0) {
                rowIndex = $(gridRows[0]).index($tr);
                if (rowIndex == -1)
                    rowIndex = $(gridRows[1]).index($tr);
                return rowIndex;
            } else
                return $gridRows.index($tr);
        },
        /**
         * Get the names of primary key columns  in Grid
         * @return primary key fields
         * @example 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // Gets the names of primary key columns
         * gridObj.getPrimaryKeyFieldNames(); 
         * &lt;/script&gt;
         * @example 
         * &lt;script&gt;
         * // Gets the names of primary key columns
         * $("#Grid").ejGrid("getPrimaryKeyFieldNames");        
         * &lt;/script&gt;
         */
        getPrimaryKeyFieldNames: function () {
            if (this._primaryKeys.length != 0)
                return this._primaryKeys;
            for (var key = 0, col = this.model.columns, cLen = col.length; key < cLen; key++) {
                if (col[key]["isPrimaryKey"])
                    this._primaryKeys.push(col[key]["field"]);
            }
            return this._primaryKeys;
        },
        /**
         * Get the names of all the visible column collections in grid
         * @return visibleColumns
         * @example 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // Gets the names of all the visible column collections
         * gridObj.getVisibleColumnNames(); 
         * &lt;/script&gt;
         * @example 
         * &lt;script&gt;
         * // Gets the names of all the visible column collections
         * $("#Grid").ejGrid("getVisibleColumnNames");        
         * &lt;/script&gt;
         */
        getVisibleColumnNames: function (headerText) {
            return this._visibleColumns;
        },
        /**
        * Get the names of all the hidden column collections in grid.
        * @return hiddenColumns
        * @example 
        * &lt;script&gt;
        * // Create grid object.
        * var gridObj = $("#Grid").data("ejGrid");
        * // Gets names of all the hidden column collections
        * gridObj.getHiddenColumnNames(); 
        * &lt;/script&gt;
        * @example 
        * &lt;script&gt;
        * // Gets names of all the hidden column collections
        * $("#Grid").ejGrid("getHiddenColumnNames");        
        * &lt;/script&gt;
        */
        getHiddenColumnNames: function (headerText) {
            return this._hiddenColumns;
        },
        /**
         * Get the column details based on the given field in grid
         * @return Column Object
         * @param {string} fieldName Pass the field name of the column to get the corresponding column object
         * @example 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // Gets the column details based on the given field name
         * gridObj.getColumnByField("OrderID");
         * &lt;/script&gt;
         * @example 
         * &lt;script&gt;
         * // Gets the column details based on the given field name
         * $("#Grid").ejGrid("getColumnByField", "OrderID");        
         * &lt;/script&gt;
         */
        getColumnByField: function (field) {
            for (var column = 0; column < this.model.columns.length; column++) {
                if (this.model.columns[column]["field"] == field)
                    break;
            }
            return column == this.model.columns.length ? null : this.model.columns[column];
        },
        getsortColumnByField: function (field) {
            for (var column = 0; column < this.model.sortSettings.sortedColumns.length; column++) {
                if (this.model.sortSettings.sortedColumns[column]["field"] == field)
                    break;
            }
            return column == this.model.sortSettings.sortedColumns.length ? null : this.model.sortSettings.sortedColumns[column];
        },
        /**
         * Get the column details based on the given header text in grid.
         * @return Column Object
         * @param {string} headerText Pass the header text of the column to get the corresponding column object
         * @example 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // Gets the column details based on the given headerText
         * gridObj.getColumnByHeaderText("Order ID"); 
         * &lt;/script&gt;
         * @example 
         * &lt;script&gt;
         * // Gets the column details based on the given headerText
         * $("#Grid").ejGrid("getColumnByHeaderText", "Order ID");        
         * &lt;/script&gt;
         */
        getColumnByHeaderText: function (headerText) {
            for (var column = 0; column < this.model.columns.length; column++) {
                if (this.model.columns[column]["headerText"] == headerText)
                    break;
            }
            return column == this.model.columns.length ? null : this.model.columns[column];
        },
        /**
         * Get the current page data source of grid..
         * @return currentJsonData
         * @example 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // Gets current view data of grid control
         * gridObj.getCurrentViewData(); 
         * &lt;/script&gt;
         * @example 
         * &lt;script&gt;
         * // Gets current view data of grid control
         * $("#Grid").ejGrid("getCurrentViewData");        
         * &lt;/script&gt;
         */
        getCurrentViewData: function () {
            return this._currentJsonData;
        },
        /**
		 * Get the list of field names from column collection in grid.
		 * @return columnFieldNames
		 * @example 
		 * &lt;script&gt;
		 * // Create grid object.
		 * var gridObj = $("#Grid").data("ejGrid");
         * // Gets the column field names based on the given index
		 * gridObj.getColumnFieldNames(); 
		 * &lt;/script&gt;
		 * @example 
		 * &lt;script&gt;
		 * // Gets the column field names based on the given index
		 * $("#Grid").ejGrid("getColumnFieldNames");        
		 * &lt;/script&gt;
         */
        getColumnFieldNames: function () {
            var columnNames = [];
            for (var column = 0; column < this.model.columns.length; column++) {
                if (this.model.columns[column]["field"])
                    columnNames.push(this.model.columns[column]["field"]);
            }
            return columnNames;
        },
        /**
         * Get the browser details
         * @return browserDetails
         * @example 
         * &lt;div id="Grid"&gt;&lt;/div&gt; 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // Gets the browser details of the application being run
         * gridObj.getBrowserDetails(); 
         * &lt;/script&gt;
         * @example 
         * &lt;div id="Grid"&gt;&lt;/div&gt; 
         * &lt;script&gt;
         * // Gets the browser details of the application being run
         * $("#Grid").ejGrid("getBrowserDetails");        
         * &lt;/script&gt;
         */
        getBrowserDetails: function () {
            var b = navigator.userAgent.match(/(firefox|chrome|opera|msie|safari)\s?\/?(\d+(.\d+)*)/i);
            if (!!navigator.userAgent.match(/Trident\/7\./))
                return { browser: "msie", version: $.uaMatch(navigator.userAgent).version };
            return { browser: b[1].toLowerCase(), version: b[2] };
        },
        _initPrivateProperties: function () {
            this._click = 0;
            this._gridHeaderTable = null;
            this._gridWidth = this.element.width();
            this._id = this.element.attr("id");
            this._gridRows = null;
            this._gridContentTable = null;
            this._gridContent = null;
            this._gridSort = null;
            this._gridHeaderContent = null;
            this._gridFooterContent = null;
            this._gridFooterTable = null;
            this._gridRecordsCount = this._dataSource() !== null ? (this.model.pageSettings.totalRecordsCount == null ? this._dataSource().length : this.model.pageSettings.totalRecordsCount) : 0;
            this._links = null;
            this._gridPager = null;
            this._cSortedColumn = null;
            this._cSortedDirection = null;
            this._$curSElementTarget = null;
            this._gridFilterBar = null;
            this._$curFieldName = null;
            this._$prevFieldName = null;
            this._mediaStatus = false;
            this._$fDlgIsOpen = false;
            this._$colType = null;
            this._$colFormat = null;
            this._$prevColType = null;
            this._$prevSElementTarget = null;
            this._currentFilterColumn = null;
            this._filteredRecordsCount = null;
            this._filteredRecords = [];
            this.filterColumnCollection = [];
            this._previousFilterCount = null;
            this._excelFilter = null;
            this._isExcelFilter = this.model.filterSettings.filterType == "excel";
            this._primaryKeys = [];
            this._primaryKeyValues = [];
            this._modifiedRecords = [];
            this._addedRecords = [];
            this._tdsOffsetWidth = [];
            this._deletedRecords = [];
            this._disabledToolItems = $();
            this._validationRules = {};
            this._groupedColumns = [];
            this._scolumns = [];
            this._currentJsonData = [];
            this._groupingColumnIndex = 0;
            this._dataManager = this._dataSource() instanceof ej.DataManager ? this._dataSource() : this._dataSource() != null ? ej.DataManager(this._dataSource()) : null;
            if (this._dataManager != null && this.model.allowScrolling && this.model.scrollSettings.allowVirtualScrolling && this.model.pageSettings.totalRecordsCount != null && this._dataManager.dataSource.json != null)
                this._dataManager.dataSource.json.splice(this.model.pageSettings.totalRecordsCount);
            this._isRemoteSaveAdaptor = (this._dataSource() instanceof ej.DataManager && this._dataSource().adaptor instanceof ej.remoteSaveAdaptor);
            this._disabledSortableColumns = [];
            this._disabledGroupableColumns = [];
            this._disabledFilterableColumns = [];
            this._hiddenColumns = [];
            this._visibleColumns = [];
            this._sortedColumns = [];
            this.multiSortRequest = false;
            this.multiSelectCtrlRequest = false;
            this._multiSelectShiftRequest = false;
            this._enableSelectMultiTouch = false;
            this._enableSortMultiTouch = false;
            this._templateRefresh = false;
            this._initialRender = false;
            this._fieldColumnNames = {};
            this._headerColumnNames = {};
            this.selectedRowsIndexes = [];
            this._isReorder = false;
            this._searchString = "";
            this._searchCount = null;
            this._columnsWidthCollection = [];
            this._Indicator = null;
            this._resizer = null;
            this._bulkEditCellDetails = {
                cellValue: null,
                rowIndex: -1,
                columnIndex: -1,
                fieldName: null,
                _data: null,
                cellEditType: "",
                cancelSave: false,
                defaultData: null,
                insertedTrCollection: [],
                rowData: null
            };
            this.batchChanges = {
                added: [],
                deleted: [],
                changed: []
            };
            this._bulkEditTemplate = $();
            this._confirmDialog = null;
            this._confirmedValue = false;
            this._lastRow = false;
            this._isVirtualRecordsLoaded = false;
            this._scrollValue = 0;
            this._currentTopFrozenRow = this.model.scrollSettings.frozenRows;
            this._rowHeightCollection = [];
            this._scrollObject = null;
            this._customPop = null;
            this.selectedRowCellIndexes = [];
            this._rowIndexesColl = [];
            this.selectedColumnIndexes = [];
            this.commonQuery = $.extend(true, {}, this.model.query);
            if (ej.gridFeatures.group) {
                this._rowCol = this._captionSummary();
                this._isCaptionSummary = (this._rowCol != null && this._rowCol.length) > 0 ? true : false;
            }
            this.phoneMode = this.model.isResponsive && document.documentElement.clientWidth < 360 ? true : false;
            if (this.model.selectionSettings.selectionMode.length > 0)
                this._initSelection();
            this._mediaQuery = false;
            this._columnChooserList = null;
            this._$headerCols = null;
            this._$contentCols = null;
            this._detailsOuterWidth = null;
        },
        _init: function () {
            this._trigger("load");
            if (ej.isNullOrUndefined(this.model.query) || !(this.model.query instanceof ej.Query))
                this.model.query = ej.Query();
            if (ej.gridFeatures.common)
                this._initScrolling();
            this._initPrivateProperties();
            if (this.model.enableResponsiveRow)
                this.element.addClass("e-responsive");
            if (ej.gridFeatures.edit) {
                if (this.model.editSettings.allowEditing || this.model.editSettings.allowAdding)
                    this._processEditing();
            }
            this._checkDataBinding();
        },
        _initColumns: function (object) {
            while (object.items != undefined)
                object = object.items[0];
            if (this.model.columns.length == 0 && object) {
                for (var field in object) {
                    if (object.hasOwnProperty(field) && (typeof (object[field]) != "object" || object[field] instanceof Date)) {
                        var value = object[field];
                        this.model.columns.push({
                            field: field,
                            type: value != null ? (value.getDay ? (value.getHours() > 0 || value.getMinutes() > 0 || value.getSeconds() > 0 || value.getMilliseconds() > 0 ? "datetime" : "date") : typeof (value)) : null
                        });
                    }
                }
                this.model.columns.length && this._renderAfterColumnInitialize();
            } else {
                for (var index = 0; index < this.model.columns.length; index++) {
                    if (ej.isNullOrUndefined(this.model.columns[index].type)) {
                        var $field;
                        if (this.model.columns[index].dataSource && this.model.columns[index].foreignKeyValue)
                            $field = this.model.columns[index].dataSource[0][this.model.columns[index].foreignKeyValue];
                        else
                            $field = !ej.isNullOrUndefined(this.model.columns[index].field) ? ej.getObject(this.model.columns[index].field, object) : null;
                        this.model.columns[index].type = $field != null ? ($field.getDay ? ($field.getHours() > 0 || $field.getMinutes() > 0 || $field.getSeconds() > 0 || $field.getMilliseconds() > 0 ? "datetime" : "date") : typeof ($field)) : null;
                    }
                    else if (this.model.columns[index]["type"] == "date" && this.model.columns[index].format == undefined)
                        if (ej.isNullOrUndefined(Globalize))
                            $.extend(this.model.columns[index], { format: "{0:" + Globalize.culture().calendars.standard.patterns.d + "}" });
                        else
                            $.extend(this.model.columns[index], { format: "{0:M/d/yyyy}" });
                    else if (this.model.columns[index]["type"] == "datetime" && this.model.columns[index].format == undefined)
                        if (ej.isNullOrUndefined(Globalize))
                            $.extend(this.model.columns[index], { format: "{0:" + Globalize.culture().calendars.standard.patterns.d + " " + Globalize.culture().calendars.standard.patterns.t + "}" });
                        else
                            $.extend(this.model.columns[index], { format: "{0:M/d/yyyy h:mm tt}" });
                }
            }
        },
		_initSelection: function(){	
            var mode = this.model.selectionSettings.selectionMode;
            for (i = 0; i < mode.length; i++) {			
                this["_allow" + mode[i] + "Selection"] = true;
            }
		},
        _checkDataBinding: function () {
            if (this.model.enablePersistence)
                this.model.query = new ej.Query();
            this._initialRenderings();
            this._initialRender = true;
            this.model.enableRTL && this.element.addClass("e-rtl");
            if (this.model.allowFiltering && (this.model.filterSettings.filterType == "menu" || this.model.filterSettings.filterType == "excel")) {
                               this._isExcelFilter && this._renderExcelFilter();
                                this._renderFilterDialogs();
                            }
            if (this.model.cssClass != null)
                this.element.addClass(this.model.cssClass);
            if (this.model.showColumnChooser)
                this._renderColumnChooser();
            if (this.model.allowGrouping)
                this.element.append(this._renderGroupDropArea());
            if (this.model.toolbarSettings.showToolbar)
                this.element.append(this._renderToolBar());
            var columns = this.model.columns;
            if (columns && columns.length) {
                var expands = [];
                if (typeof columns[0] === "string")
                    for (var i = 0; i < columns.length; i++)
                        columns[i] = { field: columns[i] };
                for (var i = 0; i < columns.length; i++) {
                    if (!columns[i].field || columns[i].field.indexOf('.') === -1) continue;
                    this._getExpands(columns[i].field, expands);
                }
                this.model.query.expand(expands);
                this._renderAfterColumnInitialize();
            }
            if (this.model.allowPaging)
                this.element.append(this._renderGridPager());
			if (this.model.contextMenuSettings.enableContextMenu)
                 this.element.append(this._renderContext());
            if ($.isFunction($.fn.ejWaitingPopup)) {
                this.element.ejWaitingPopup({ showOnInit: false });
                $("#" + this._id + "_WaitingPopup").addClass("e-gridwaitingpopup");
            }
            if (this._dataSource() instanceof ej.DataManager) {
                this.element.ejWaitingPopup("show");
                if (this._dataSource().ready != undefined) {
                    var proxy = this;
                    this._dataSource().ready.done(function (args) {
                        proxy._initDataSource();
                        proxy.model.dataSource = ej.DataManager(args.result);
                    });
                } else {
                    this.element.ejWaitingPopup("show");
                    this._initDataSource();
                }
            } else {
                this._ensureDataSource();
                this._trigger("actionBegin");
                this._initGridRender();
            }
        },
		 _renderColumnChooser: function () {
            var $columnButton = ej.buildTag("button .e-ccButton", 'Columns', { 'float': 'right' }).attr("type", "button");
            this.element.prepend($columnButton);
            $columnButton.ejButton({
                prefixIcon: "e-down-arrow",
                imagePosition:"imageright",
				contentType:"textandimage",
				type: 'button',
				click: $.proxy(this._ccClickHandler, this),
                width:90
            });
			var buttHeight=$columnButton.outerHeight();
			$columnButton.css('margin-top',0-(buttHeight));
            var $mainDiv = ej.buildTag("div");
            var $outerDiv = ej.buildTag("div .e-grid e-columnChooser",'',{},{id:this._id+"ccDiv"});
            var $searchBox = ej.buildTag("div.e-searchbox e-fields").append(ej.buildTag("input#" + this._id + "_SearchBox.e-ejinputtext e-filtertext", {}, {}, { "type": "text" }))
            var $sapnDiv = ej.buildTag('span .e-searchfind e-icon')
            $searchBox.append($sapnDiv);
            var $listOuterDiv=ej.buildTag('div','', {'height':'228px'},{id:this._id+"liScrollerDiv"})            
            this._renderColumnChooserData(false);
            $listOuterDiv.append(this._columnChooserList);          
            $outerDiv.append($searchBox);
            $outerDiv.append($listOuterDiv);
           
            var $splitterDiv = ej.buildTag('div .e-columnChooserSplitter', '', {'border-bottom':'0px' });
            $outerDiv.append($splitterDiv);
            $buttonDiv = ej.buildTag('div', '', { 'float': 'right', 'margin-top': '6px','margin-right':'-13px' });
            var $addButton = ej.buildTag("button", 'Done');
            var $cancelButton = ej.buildTag("button", 'Cancel', { 'margin-right': '20px','margin-left':'6px' });
            $buttonDiv.append($addButton);
            $buttonDiv.append($cancelButton);
            $outerDiv.append($buttonDiv);
            $addButton.ejButton({
                click: $.proxy(this._addButtonCC, this),
                showRoundedCorner:true,
                width:66
            });
            $cancelButton.ejButton({
                click: $.proxy(this._cancelButtonHandler, this),
                showRoundedCorner:true,
                width:66
            });
              $outerDiv.insertBefore(this.element)
              $outerDiv.ejDialog({ width: 'auto', beforeClose: $.proxy(this._columnChooserBeforeClose, this), showOnInit: false, allowKeyboardNavigation: false, enableResize: false, "enableRTL": this.model.enableRTL, "cssClass": this.model.cssClass, showHeader: false, width: 260 });
              if (ej.browserInfo().name == "msie" && ej.browserInfo().version < 10) {
                  var searchBox = $(".e-columnChooser").find("input#" + this._id + "_SearchBox")[0];
                  this._ieClearRemover(searchBox);
              }
        },
        _renderColumnChooserData: function (refresh) {
            var $listBox = ej.buildTag("div", '', { 'margin-left': '0px', 'width': '250px' });
            for (var index = 0; index < this.model.columns.length; index++) {
                var column = this.model.columns[index];
                var $innerDiv = ej.buildTag('div', '', {}, { 'class': 'e-columnChooserListDiv' });
                var styleAttr = {}
                var colValue = ej.isNullOrUndefined(column.headerText) ? column.field : column.headerText;
                var $input = ej.buildTag('input', '', styleAttr, { 'id': column.field.replace(".","_"), 'value': colValue, 'type': 'checkbox' });
                var label = ej.buildTag('label', colValue, { 'font-size': '13px' }, { 'for': column.field });
                $innerDiv.append($input);
                $innerDiv.append(label);
                $listBox.append($innerDiv);
                $input.ejCheckBox({
                    checked: !ej.isNullOrUndefined(column.visible) ? column.visible : true
                });
            }
            if (!refresh)
                this._columnChooserList = $listBox;
            else {
                this._columnChooserList.empty().append($listBox.children());
                $("#" + this._id + "liScrollerDiv").is(":visible") && $("#" + this._id + "liScrollerDiv").ejScroller('refresh');
            }
        },
		 _columnChooserBeforeClose: function () {
		     $(".e-columnChoosertail").remove();
		     $(".e-columnChoosertailAlt").remove();
		     for (index = 0; index < this.model.columns.length; index++) {
		         var chkState = !ej.isNullOrUndefined(this.model.columns[index].visible) ? this.model.columns[index].visible : true
		         var chkBox = $("#" + this.model.columns[index].field).ejCheckBox('model.checked', chkState);
		     }
			  $("#" + this._id + "_SearchBox").val('');
			 var args={};
			 args.target={};args.target.value='';
			 this._columnChooserSearch(args);
		 },
		 _columnChooserSearch: function (e) {
            if (e.type == 'click') {
                e.target.value = '';
                $("#"+this._id+"_SearchBox").val('');
            }
            var val = e.target.value;
			var span=$("#"+this._id+"_SearchBox").next('span')
            if (val != '') {
                span.removeClass("e-searchfind");
                span.addClass("e-cancel");
            }
            else {
                span.removeClass("e-cancel");
                span.addClass("e-searchfind");
            }
            $(".e-cancel").bind('click', $.proxy(this._columnChooserSearch, this));
            var currentCheckedItemsData = this.model.columns;
            var columnCollection = [];
            if (val != '') 
                currentCheckedItemsData = ej.DataManager(this.model.columns).executeLocal(ej.Query().where("headerText", ej.FilterOperators.startsWith, val,true));
            currentCheckedItemsData.forEach(function (obj) {
                columnCollection.push(obj.field);
            });
            if (!ej.isNullOrUndefined($("#nomatches")[0]))
                $("#nomatches").remove();
            var div = $("#"+this._id+"ccDiv").find("#"+this._id+"liScrollerDiv")

            for (var index = 0; index < this.model.columns.length; index++) {
                var column = this.model.columns[index];
                if (columnCollection.indexOf(column.field) == -1)
                    $("#ej" + column.field).parent('div').css('display', 'none');
                else
                    $("#ej" + column.field).parent('div').css('display', 'block');

            }

            if (columnCollection.length == 0) {
                var $labeldiv = ej.buildTag('div#nomatches', '');
                var $label = ej.buildTag('span', 'No Matches Found');
                $labeldiv.append($label);
                $(div).append($labeldiv);
            }
            $("#"+this._id+"liScrollerDiv").ejScroller('refresh')
        },
		_addButtonCC: function () {
            this._visibleColumns = [];
            this._hiddenColumns = [];
            for (index = 0; index < this.model.columns.length; index++) {
                var chkBox = $("#" + this.model.columns[index].field.replace(".", "_")).data("ejCheckBox");
                var column = this.getColumnByHeaderText(chkBox.model.value);
                if (chkBox.model.checked)
                    this._visibleColumns.push(column.headerText);
                else
                    this._hiddenColumns.push(column.headerText);
            }
            this.showColumns(this._visibleColumns);
            this.hideColumns(this._hiddenColumns);
            $("#"+this._id+"ccDiv").ejDialog('close');
            $(".e-columnChoosertail").remove();
        },
		_cancelButtonHandler: function () {
		    $("#" + this._id + "ccDiv").ejDialog('close');
		    $(".e-columnChoosertailAlt").remove();
            $(".e-columnChoosertail").remove();
		},
		_ccClickHandler: function (e) {
		    var dlgWidth = 230, xPos;
		    xPos = $(".e-ccButton").offset().left + $(".e-ccButton").width();
		    var dialogObj = $("#" + this._id + "ccDiv").data('ejDialog')
		    if (dialogObj && dialogObj.isOpened()) {
		        dialogObj.close();
		        $(".e-columnChoosertail").remove();
		        $(".e-columnChoosertailAlt").remove();
		    }
		    else {
		        $("#" + this._id + "ccDiv").ejDialog({ width: '230px', height: '309px', position: { X: xPos - dlgWidth, Y: $(".e-ccButton").offset().top + 35 } })
                   .ejDialog("open");
		        var maxZindex = parseInt($("#" + this._id + "ccDiv_wrapper").css('z-index'));
		        var $tailDiv = ej.buildTag("div.e-columnChoosertail", '', { 'display': 'block', 'position': 'absolute', 'left': xPos - 29, 'top': $(".e-ccButton").offset().top + 15 });
		        var $tailDiv2 = ej.buildTag("div.e-columnChoosertailAlt", '', { 'display': 'block', 'z-index': maxZindex + 2, 'position': 'absolute', 'left': xPos - 29, 'top': $(".e-ccButton").offset().top + 16 });
		        $tailDiv.insertBefore($("#" + this._id + "ccDiv_wrapper"));
		        $tailDiv2.insertBefore($("#" + this._id + "ccDiv_wrapper"));
		    }
		    $("#" + this._id + "liScrollerDiv").ejScroller({ height: '228', width: '230', buttonSize: 0 })
		    $("#" + this._id + "liScrollerDiv").ejScroller('refresh');
		    $(".e-ejinputtext").bind('keyup', $.proxy(this._columnChooserSearch, this))
		},
        _initDataSource: function () {
            this._ensureDataSource();
            this._trigger("actionBegin");
            var queryPromise = this._dataSource().executeQuery(this.model.query);
            if (this._dataManager.dataSource.table != null)
                this._dataManager.dataSource.table.css("display", "none");
            queryPromise.done(ej.proxy(function (e) {
                this.element.ejWaitingPopup("hide");
                this.model.currentViewData = e.result;
                if (this.model.pageSettings.totalRecordsCount != null && this.model.filterSettings.filteredColumns.length == 0)
                    this._gridRecordsCount = this.model.pageSettings.totalRecordsCount;
                else if (e.count == 0 && e.result.length)
                    this._gridRecordsCount = e.result.length;
                else
                    this._gridRecordsCount = e.count;
                if (this.getPager() != null)
                    this.model.pageSettings.totalRecordsCount = this._gridRecordsCount;
                this._initGridRender();
            }, this));
            var proxy = this;
            queryPromise.fail(function (e) {
                var args = { error: e.error };
                proxy._trigger("actionFailure", args)
            })
        },
        _initialRenderings: function () {
            if (this.model.groupSettings.groupedColumns.length) {
                var sortedColumns = new Array();
                for (var i = 0; i < this.model.sortSettings.sortedColumns.length; i++) {
                    if (ej.isNullOrUndefined(this.model.sortSettings.sortedColumns[i].direction))
                        this.model.sortSettings.sortedColumns[i].direction = ej.sortOrder.Ascending;
                    sortedColumns.push(this.model.sortSettings.sortedColumns[i].field);
                }
                for (var i = 0; i < this.model.groupSettings.groupedColumns.length; i++) {
                    if ($.inArray(this.model.groupSettings.groupedColumns[i], sortedColumns) == -1)
                        this.model.sortSettings.sortedColumns.push({ field: this.model.groupSettings.groupedColumns[i], direction: ej.sortOrder.Ascending });
                }
            }
        },
        _getExpands: function (field, arr) {
            var splits = field.split('.'), tmp = "";
            splits.splice(splits.length - 1, 1);
            for (var i = 0; i < splits.length; i++, tmp = "") {
                for (var j = 0; j < i; j++)
                    tmp += splits[j] + "/";
                tmp = tmp + splits[i];
                if (arr.indexOf(tmp) === -1)
                    arr.push(tmp);
            }
        },
        _renderAfterColumnInitialize: function () {
            this.element.append(this._renderGridHeader());
            if (this.model.allowFiltering && this.model.filterSettings.filterType == "filterbar")
                this._renderFiltering();
            if (this.model.allowPaging)
                this.element.append(this.element.find(".e-pager").first());
        },
        _ensureDataSource: function (args) {
            if (this._dataSource() == null && !(this._dataSource() instanceof ej.DataManager)){
				if(!ej.isNullOrUndefined(args) && args.requestType == "add")
					this.dataSource([]);				
				else
					return;
			}
            this.model.query.requiresCount();
            var queryManagar = this.model.query;
            if (!(this._dataSource() instanceof ej.DataManager))
                this.model.currentViewData = this._dataSource();
            if ((!(this._dataSource() instanceof ej.DataManager) || this._dataManager.dataSource.url == undefined) && (this.model.editSettings.allowEditing || this.model.editSettings.allowAdding) && (!ej.isNullOrUndefined(this._cModifiedData) || !ej.isNullOrUndefined(this._cAddedRecord))) {
                if (ej.isNullOrUndefined(this._cAddedRecord)) {
                    for (var index = 0; index < this._primaryKeys.length; index++)
                        queryManagar = queryManagar.where(this._primaryKeys[index], ej.FilterOperators.equal, this._primaryKeyValues[index]);
                    var currentData = this._dataManager.executeLocal(queryManagar);
                    if (!(this._dataSource() instanceof ej.DataManager))
                        this._dataSource().splice($.inArray(currentData.result[0], this._dataSource()), 1, this._cModifiedData);
                    else
                        $.extend(this._dataSource().dataSource.json[$.inArray(currentData.result[0], this._dataSource().dataSource.json)], this._cModifiedData);
                    this._cModifiedData = null;
                } else {
                    (this._dataSource() instanceof ej.DataManager) ? this._dataSource().dataSource.json.unshift(this._cAddedRecord) : this._dataSource().splice(0, 0, this._cAddedRecord);
                    this._cAddedRecord = null;
                }
                queryManagar.queries = [];
                this.model.isEdit = false;
            }

            if (this.model.editSettings.allowDeleting && !ej.isNullOrUndefined(this._cDeleteData) && (!(this._dataSource() instanceof ej.DataManager) || this._dataManager.dataSource.url == undefined)) {
                if (!(this._dataSource() instanceof ej.DataManager)) {
                    var index = $.inArray(this._cDeleteData[0], this._dataSource());
                    this._dataSource().splice(index, 1);
                }
                else {
                    var index = $.inArray(this._cDeleteData[0], this._dataSource().dataSource.json);
                    this._dataSource().dataSource.json.splice(index, 1);
                }
            }

            if (this.model.sortSettings.sortedColumns.length) {
                for (var i = this.model.sortSettings.sortedColumns.length - 1; i >= 0; i--)
                    queryManagar.sortBy(this.model.sortSettings.sortedColumns[i].field, this.model.sortSettings.sortedColumns[i].direction);

            }

            if (this.model.allowSearching && this._searchString.length) {
                queryManagar.search(this._searchString, this.getColumnFieldNames(), ej.FilterOperators.contains, true);
                if (args.requestType == "searching")
                    this._currentPage(1);
                if (!(this._dataSource() instanceof ej.DataManager))
                this._filteredRecords = this._dataManager.executeLocal(queryManagar).result;
            }

            if (this.model.allowFiltering && this.model.filterSettings.filteredColumns.length) {
                var predicate, firstFilterCondition = this.model.filterSettings.filteredColumns[0];
                if (this._isExcelFilter) {
                    if (ej.isNullOrUndefined(this._excelFilter._predicates[0]))
                        this._excelFilter.getPredicate(this.model.filterSettings.filteredColumns, null, true);
                    var predicates = this._excelFilter._predicates[0];
                    for (var prop in predicates) {
                        var obj = predicates[prop], isTake = obj["from"]!=undefined;
                        if (isTake) 
                           queryManagar.skip(obj["from"] == "top" ? 0 : this._gridRecordsCount - obj["take"]).take(obj["take"]);                                     
                        else
                            predicate = predicate != undefined ? predicate["and"](obj) : obj;
                    }
                }
                else {
                    if (!firstFilterCondition.isComplex)
                        predicate = ej.Predicate(firstFilterCondition.field, firstFilterCondition.operator, firstFilterCondition.value, !firstFilterCondition.matchcase);
                    else
                        predicate = firstFilterCondition;
                    for (var i = 1; i < this.model.filterSettings.filteredColumns.length; i++) {
                        if (!this.model.filterSettings.filteredColumns[i].isComplex)
                            predicate = predicate[this.model.filterSettings.filteredColumns[i].predicate](this.model.filterSettings.filteredColumns[i].field, this.model.filterSettings.filteredColumns[i].operator, this.model.filterSettings.filteredColumns[i].value, !this.model.filterSettings.filteredColumns[i].matchcase);
                        else
                            predicate = predicate["and"](this.model.filterSettings.filteredColumns[i]);
                    }
                }
                predicate && queryManagar.where(predicate);
                if (!(this._dataSource() instanceof ej.DataManager)) {
                    var fresults = this._dataManager.executeLocal(queryManagar);
                    this._filteredRecordsCount = isTake ? fresults.result.length : fresults.count;
                    var lastPage = (this._filteredRecordsCount % this.model.pageSettings.pageSize == 0) ? (this._filteredRecordsCount / this.model.pageSettings.pageSize) : (parseInt(this._filteredRecordsCount / this.model.pageSettings.pageSize, 10) + 1);
                    if (this._currentPage() > lastPage)
                        this._currentPage(lastPage);
                    this._filteredRecords = this._dataManager.executeLocal(queryManagar).result;
                } else if (!ej.isNullOrUndefined(args) && args.requestType == ej.Grid.Actions.Filtering)
                    this._currentPage(1);               
            }


            if (this.model.allowPaging || (this.model.scrollSettings.allowVirtualScrolling && this.model.allowScrolling)) {
                if (this._currentPage() == 0) {
                    if (this._prevPageNo == 0 || this._prevPageNo == null)
                        this._currentPage(1);
                    else
                        this._currentPage(this._prevPageNo);
                }
                queryManagar.page(this._currentPage(), this.model.pageSettings.pageSize);
            }

            if (this.model.allowGrouping) {
                var cloned = queryManagar.clone();
                if (this.model.allowPaging && this.model.groupSettings.groupedColumns.length) {
                    cloned.queries = cloned.queries.slice(0, cloned.queries.length - 1);
                }
                for (var i = 0; i < this.model.groupSettings.groupedColumns.length; i++) {
                    queryManagar.group(this.model.groupSettings.groupedColumns[i]);
                    cloned.group(this.model.groupSettings.groupedColumns[i]);
                }
                if (this.model.groupSettings.groupedColumns.length)
                    this._setAggreatedCollection(cloned);
            }
            if (args != undefined && args.requestType == "add" && (!(this._dataSource() instanceof ej.DataManager) || this._dataManager.dataSource.url == undefined) && this.model.groupSettings.groupedColumns.length == 0 && this.model.scrollSettings.frozenColumns == 0 && this.model.scrollSettings.frozenRows == 0)
                !(this._dataSource() instanceof ej.DataManager) ? this._dataSource().unshift(args.data) : this._dataSource().dataSource.json.unshift(args.data);
            if ((!(this._dataSource() instanceof ej.DataManager) || this._dataManager.dataSource.url == undefined)) {
                var result = this._dataManager.executeLocal(queryManagar);
                this.model.currentViewData = result.result;
                this._gridRecordsCount = result.count;
                this._searchCount = this._searchString.length ? result.count : null;
                this.model.groupSettings.groupedColumns.length && this._setAggregates();
            }

        },
        _initGridRender: function () {
            this.addInitTemplate();
            if (this.model.scrollSettings.frozenColumns > 0)
                this.addFrozenTemplate();
            this.model.allowGrouping && this.addGroupingTemplate();
            if (this.model.allowResizing || this.model.allowResizeToFit)
                this._resizer = new ej.Grid.gridResize(this);
			if (this.model.allowTextWrap == true)
                this.element.addClass("e-wrap");
            this.render();
            if (this.model.allowGrouping && ej.gridFeatures.dragAndDrop)
                this._headerCellgDragDrop();
            if (this.model.allowReordering && ej.gridFeatures.dragAndDrop) {
                this._headerCellreorderDragDrop();
                this._initIndicators();
            }
            this._wireEvents();           
            this._initialRender = false;
            if (this.model.width && !this.model.allowScrolling)
                this.element.width(this.model.width);
            if (this.model.editSettings.allowEditing || this.model.editSettings.allowAdding)
                this._processEditing();
            if (this.model.allowFiltering && (this.model.filterSettings.filterType == "menu" || this.model.filterSettings.filterType == "excel")) {
                this._isExcelFilter && this._renderExcelFilter();
				this._renderFilterDialogs();               
			   if (this.model.enableResponsiveRow)
                    this._renderResponsiveFilter();
            }
        },
        _getMetaColGroup: function () {
            var $colgroup = ej.buildTag("colgroup");
            for (var i = 0; i < this.model.columns.length; i++) {
                var $col = $(document.createElement("col"));
                this.model.columns[i]["visible"] === false && $col.css("display", "none");
                !ej.isNullOrUndefined(this.model.columns[i]["cssClass"]) && $col.addClass(this.model.columns[i]["cssClass"]);
                if (!this.model.groupSettings.showGroupedColumn && $.inArray(this.model.columns[i]["field"], this.model.groupSettings.groupedColumns) != -1)
                    $col.css("display", "none");
                $colgroup.append($col);
            }
            return $colgroup;
        },
        _alternateRow: function () {
            return this.getIndex() % 2 == 0 ? "" : "e-alt_row";
        },
        addInitTemplate: function () {
            var headerCellDiv = this.element.find(".e-headercelldiv"), templates = {};
            var tbody = document.createElement('tbody'), $tbody = $(tbody);
            if (this.model.rowTemplate == null) {
                var tr = document.createElement('tr'),
                    $tr = $(tr),
                    columns = this.model.columns,
                    i;
                if (this._gridRecordsCount)
                    this._initColumns(this.model.currentViewData[0] != undefined ? this.model.currentViewData[0] : this.model.currentViewData.value);
                var helpers = { _gridFormatting: this.formatting };
                $.views.helpers(helpers);

                var viewHelper = {};
                viewHelper["_foreignKey"] = this._foreignKeyBinding; // move to common methods
                $.views.helpers(viewHelper);

                if (this.model.detailsTemplate || this.model.childGrid || this.model.detailsDataBound) {
                    var $tdDetailCell = ej.buildTag("td.e-detailrowcollapse", "<div class='e-icon e-gnextforward'></div>");
                    $tr.append($tdDetailCell);
                }
                for (i = 0; i < this.model.columns.length; i++) {
                    var $tdCell = ej.buildTag("td.e-rowcell");
                    if (this.model.isResponsive)
                        $tdCell.attr("data-cell", this.model.columns[i]["headerText"]);
                    columns[i]["visible"] == false && $tdCell.addClass("e-hide");
                    !this.model.groupSettings.showGroupedColumn && $tdCell.addClass("{{for ~groupedColumns}}" +
                        " {{if #data == '" + this.model.columns[i]["field"] + "'}}e-hide{{/if}}" +
                        "{{/for}}");
                    if (!ej.isNullOrUndefined(columns[i]["templateID"] || columns[i]["template"])) {
                        var viewHelper = {};
                        viewHelper["_" + this._id + "ColumnTemplating"] = ej.proxy(this._gridTemplate, null, this);
                        $.views.helpers(viewHelper);
                        $("#" + this._id + columns[i].headerText + i + "_Template").remove();
                        var scriptElement = this._createTemplateElement(columns[i]);
                        this.model.columns[i]["allowGrouping"] = this.model.columns[i]["allowFiltering"] = this.model.columns[i]["allowSorting"] = false;
                        $tdCell.addClass("e-templatecell").html("{{:~_" + this._id + "ColumnTemplating('" + scriptElement.id + "')}}");
                    } else {
                        var splits = (columns[i].field || "").split("."), sLen = splits.length - 1, braces = "";
                        while (sLen) {
                            braces += "(";
                            sLen--;
                        }
						var columnType=columns[i].type || columns[i].editType
                        switch (columnType) {
                            case "boolean":
							case "booleanedit":
                                $tdCell.addClass("e-boolrowcell").html('{{if ' + columns[i].field + '}} <input type ="checkbox" disabled="disabled" checked="checked"></input>{{else}} <input type ="checkbox" disabled="disabled"  ></input> {{/if}}');
                                break;
                            default:
                                if (columns[i].disableHtmlEncode)
                                    $tdCell.html("{{html:" + "#data['" + splits.join("'] || {})['") + "']}}");
                                else
                                    $tdCell.html("{{:" + braces + "#data['" + splits.join("'] || {})['") + "']}}");
                        }
                        if (columns[i]["format"] != undefined && (!columns[i]["foreignKeyValue"] && !columns[i]["dataSource"]))
                            $tdCell.html("{{:~_gridFormatting('" + columns[i]["format"] + "',"+ braces + "#data['" + splits.join("'] || {})['") +"'],'"+ this.model.locale +"')}}");
                        if (columns[i]["foreignKeyValue"] && columns[i]["dataSource"]) {
                            var foreignKeyColumn = columns[i]["field"] != columns[i]["foreignKeyField"] ? columns[i]["field"] : columns[i]["foreignKeyField"];
                            $tdCell.html("{{:~_foreignKey('" + JSON.stringify(columns[i]) + "',#data['" + foreignKeyColumn + "'],'" + this._id + "Object" + "')}}");
                        }
                        if (columns[i]["isUnbound"]) {
                            var viewHelper = {};
                            viewHelper["_" + this._id + "UnboundTemplate"] = this._unboundTemplateRendering;
                            $.views.helpers(viewHelper);
                            this.model.columns[i]["allowGrouping"] = this.model.columns[i]["allowFiltering"] = this.model.columns[i]["allowSorting"] = false;
                            $("#" + this._id + columns[i].headerText + "_UnboundTemplate").remove();
                            divElement = this._createUnboundElement(columns[i]);
                            $tdCell.addClass("e-unboundcell").addClass("e-" + columns[i]["headerText"].replace(/\s+/g, "")).html("{{:~_" + this._id + "UnboundTemplate('" + divElement.id + "')}}");
                            this.model.scrollSettings.frozenColumns > 0 && $tdCell.addClass("e-frozenunbound");
                            this._isUnboundColumn = true;
                        }

                    }
                    if (!this.phoneMode && columns[i]["textAlign"] != undefined) {
                        $tdCell.css("text-align", columns[i]["textAlign"]);
                        $(headerCellDiv[i]).css("text-align", columns[i]["textAlign"]);
                    }
                    if (!this.phoneMode && !ej.isNullOrUndefined(columns[i]["headerTextAlign"])) {
                        $(headerCellDiv[i]).css("text-align", columns[i]["headerTextAlign"]);
                    }
                    if (!ej.isNullOrUndefined(columns[i]["cssClass"])) {
                        $tdCell.addClass(columns[i]["cssClass"]);
                    }
                    if (!ej.isNullOrUndefined(columns[i]["priority"]))
                        $tdCell.addClass("e-table-priority-" + columns[i]["priority"]);
                    if (!ej.isNullOrUndefined(columns[i]["customAttributes"]))
                        $tdCell.attr(columns[i]["customAttributes"]);
                    $tdCell.attr("role", "gridcell");
                    $tr.append($tdCell);
                    if (this.model.enableAltRow) {
                        helpers["_" + this._id + "AlternateRow"] = this._alternateRow;
                        $.views.helpers(helpers);
                        $tr.addClass("{{:~_" + this._id + "AlternateRow()}}");
                    }
                    $tr.attr("role", "row");
                    if (this.model.scrollSettings.frozenColumns > 0 && this.model.scrollSettings.frozenColumns == i + 1) {
                        tbody.appendChild(tr);
                        templates[this._id + "_JSONFrozenTemplate"] = $tbody.html();
                        $tr.empty();
                        $tbody.empty();
                    }
                }
                tbody.appendChild(tr);
            }
            templates[this._id + "_JSONTemplate"] = this.model.rowTemplate != null ? $(this.model.rowTemplate).html() : $tbody.html();
            $.templates(templates);
        },
        /**
         * Creates a grid control
         * @return jQuery
         * @example 
         * &lt;div id="Grid"&gt;&lt;/div&gt; 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // It renders the grid.
         * gridObj.render(); 
         * &lt;/script&gt;
         * @example 
         * &lt;div id="Grid"&gt;&lt;/div&dgt; 
         * &lt;script&gt;
         * // It renders the grid.
         * $("#Grid").ejGrid("render");        
         * &lt;/script&gt;
         */
        // Grid rendering parts
        render: function () {
            this._renderGridContent().insertAfter(this.element.children(".e-gridheader"));
            this.model.allowResizeToFit && this.setWidthToColumns();
            if (this.model.allowGrouping && ej.gridFeatures.dragAndDrop)
                this._groupHeaderCelldrag();
            this.model.showSummary = this.model.summaryRows.length > 0 || this.model.showSummary;
            if (this.model.showSummary) {
                this._renderGridFooter().insertAfter(this.getContent());
                this._hideCaptionSummaryColumn();
            }
            this._initialEndRendering();

        },
        _createStackedRow: function (stackedHeaderRow, frozenHeader) {
            var $tr = ej.buildTag('tr.e-columnheader e-stackedHeaderRow');
            var sHeader = [];
            for (var c = 0; c < this.model.columns.length; c++) {
                var column = this.model.columns[c];
                if (column.visible != false) {
                    var headerText = ''
                    var sColumn = stackedHeaderRow.stackedHeaderColumns;
                    for (var col = 0; col < sColumn.length; col++) {
                        if (sColumn[col].column.indexOf(column.field) != -1)
                            headerText = sColumn[col].headerText;
                    }
                    sHeader.push(headerText);
                }
            }
            var colsPanList = []
            for (var i = 0; i < sHeader.length; i++) {
                var colSpan = 1;
                for (var j = i + 1; j < sHeader.length; j++) {
                    if (sHeader[i] == sHeader[j]) {
                        colSpan++;
                    }
                    else
                        break;
                }
                colsPanList.push({ sapnCount: colSpan, headerText: sHeader[i] })
                i += colSpan - 1;
            }
            var $tr = ej.buildTag('tr.e-columnheader e-stackedHeaderRow');
            var frzCol = this.model.scrollSettings.frozenColumns;
            if (this.model.allowScrolling && frzCol > 0) {
                var frozenColspanList = [];
                var forzenColumn = 0, index = 0, frzHideCol = 0;
                for (var i = 0; i < this.model.columns.length; i++) {
                    var col = this.model.columns[i];                    
                    if ( i < frzCol && col.visible == false)
                        frzHideCol++;
                }                
                forzenColumn = frzCol - frzHideCol;
                while (forzenColumn > 0) {
                    var spanC = colsPanList[index].sapnCount;
                    if (colsPanList[index].sapnCount < forzenColumn) {
                        frozenColspanList.push(colsPanList[index])
                        if (!frozenHeader)
                            colsPanList.splice(index, 1);
                        else
                            index++;
                    }
                    else if (colsPanList[index].sapnCount > forzenColumn) {
                        colsPanList[index].sapnCount = colsPanList[index].sapnCount - forzenColumn
                        if (frozenHeader)
                            frozenColspanList.push({ sapnCount: forzenColumn, headerText: colsPanList[index].headerText });
                    }
                    else {
                        frozenColspanList.push(colsPanList[index])
                        if (!frozenHeader)
                            colsPanList.splice(index, 1);
                    }
                    forzenColumn -= spanC;
                }
                if (frozenHeader)
                    colsPanList = frozenColspanList
            }
            for (var c = 0; c < colsPanList.length; c++) {
                var $th = ej.buildTag('th.e-headercell e-stackedHeaderCell e-default', colsPanList[c].headerText, {}, { 'colspan': colsPanList[c].sapnCount });
                $tr.append($th);
            }
            return $tr;
        },
        _renderGridHeaderInternalDesign: function (columns, frozenHeader) {
            var $table = ej.buildTag('table.e-table', "", {}, { cellspacing: "0.25px", role: "grid" });
            var $thead = ej.buildTag('thead');
            var $tbody = ej.buildTag('tbody.e-hide');
            var $columnHeader = ej.buildTag('tr.e-columnheader');
            var $colGroup = $(document.createElement('colgroup'));
            var $rowBody = $(document.createElement('tr'));
            if (this.model.detailsTemplate || this.model.childGrid || this.model.detailsDataBound) {
                $columnHeader.append(ej.buildTag('th.e-headercell e-detailheadercell', '<div></div>'));
                $colGroup.append(this._getIndentCol());
            }
            if (this.model.showStackedHeader) {
                for (var index = 0; index < this.model.stackedHeaderRows.length; index++) {
                    var $tr = this._createStackedRow(this.model.stackedHeaderRows[index], frozenHeader);
                    $thead.append($tr);
                }
            }
            for (var columnCount = 0; columnCount < columns.length; columnCount++) {
                var $headerCell = ej.buildTag('th.e-headercell e-default', "", {}, { role: "columnheader" });
                var bodyCell = document.createElement('td');
                var $headerCellDiv = ej.buildTag('div.e-headercelldiv', columns[columnCount]["headerText"] === undefined ? columns[columnCount]["headerText"] = columns[columnCount]["field"] : columns[columnCount]["headerText"], {}, { "ej-mappingname": columns[columnCount]["field"] });
                if (columns[columnCount].disableHtmlEncode)
                    $headerCellDiv.text(columns[columnCount]["headerText"]);
                $headerCell.append($headerCellDiv);
                if (this.model.allowFiltering && (this.model.filterSettings.filterType == "menu" || this.model.filterSettings.filterType == "excel") &&
                (columns[columnCount]["allowFiltering"] == undefined ||
                    columns[columnCount]["allowFiltering"] === true)){
                    $headerCell.append(ej.buildTag('div.e-filtericon e-icon e-filterset'));
					if (ej.browserInfo().name == "msie" && ej.browserInfo().version == "8.0" && this.model.enableRTL)
                        $($headerCellDiv).css("padding","0 0 0 2em");
                }
                var col = document.createElement('col');
                if (columns[columnCount]["priority"])
                    $(bodyCell).addClass("e-table-priority-" + columns[columnCount]["priority"]);
                $rowBody.append(bodyCell);
                $columnHeader.append($headerCell);
                $colGroup.append(col);
                if (columns[columnCount]["visible"] === false)
                    $headerCell.addClass("e-hide") && $(col).css("display", "none") && this._hiddenColumns.push(columns[columnCount].headerText);
                else {
                    this._visibleColumns.push(columns[columnCount].headerText);
                    columns[columnCount]["visible"] = true;
                }
				if (!ej.isNullOrUndefined(columns[columnCount]["headerTextAlign"]))
                    $headerCellDiv.css("text-align", columns[columnCount]["headerTextAlign"]);
                else if (columns[columnCount]["textAlign"] != undefined)
                    $headerCellDiv.css("text-align", columns[columnCount]["textAlign"]);
                columns[columnCount]["allowSorting"] === false && this._disabledSortableColumns.push(columns[columnCount].field);
                columns[columnCount]["allowGrouping"] === false && this._disabledGroupableColumns.push(columns[columnCount].headerText);
                if (!ej.isNullOrUndefined(columns[columnCount]["cssClass"])) {
                    $headerCell.addClass(this.model.columns[columnCount]["cssClass"]);
                    $(col).addClass(this.model.columns[columnCount]["cssClass"]);
                }
                if (!ej.isNullOrUndefined(this.model.columns[columnCount]["headerTemplateID"])) {
                    $headerCellDiv.html($(this.model.columns[columnCount]["headerTemplateID"]).hide().html()).parent().addClass("e-headertemplate");
                    var index = $.inArray(this.model.columns[columnCount].headerText, this._disabledGroupableColumns);
                    index == -1 && this._disabledGroupableColumns.push(this.model.columns[columnCount].headerText);
                }
                if (this.model.groupSettings.showToggleButton && $.inArray(columns[columnCount].headerText, this._disabledGroupableColumns) == -1) {
                    if ($.inArray(columns[columnCount].field, this.model.groupSettings.groupedColumns) != -1)
                        $headerCellDiv.append(this._getToggleButton().addClass("e-toggleungroup"));
                    else
                        $headerCellDiv.append(this._getToggleButton().addClass("e-togglegroup"));
                }
				if (this.model.isResponsive)
                    $headerCell.attr("title", columns[columnCount].headerText);
                if (columns[columnCount]["priority"]) {
                    $headerCell.attr("data-priority", columns[columnCount]["priority"]).addClass("e-table-priority-" + columns[columnCount]["priority"]);
                    $(col).addClass("e-table-priority-" + columns[columnCount]["priority"]);
                }
                this._columnsWidthCollection.push(columns[columnCount]["width"]);
                if (columns[columnCount]["width"] == undefined && this.model.commonWidth !== undefined)
                    this._columnsWidthCollection[columnCount] = this.model.commonWidth;
                this._fieldColumnNames[columns[columnCount].headerText] = columns[columnCount].field;
                this._headerColumnNames[columns[columnCount].field] = columns[columnCount].headerText;
                this.model.allowFiltering && ("menu" == this.model.filterSettings.filterType || this._isExcelFilter) && $headerCell.addClass("e-headercellfilter");
            }
            $thead.append($columnHeader);
            $tbody.append($rowBody);
            $table.append($colGroup).append($thead).append($tbody);
            return $table;
        },
        _renderGridHeader: function () {
            var $div = ej.buildTag('div.e-gridheader'), temp, $frozenDiv, $movableDiv;
            var $innerDiv = ej.buildTag('div');
            if (this.model.allowScrolling)
                $innerDiv.addClass("e-headercontent");
            this.setGridHeaderContent($div);
            this._hiddenColumns = [];
            this._columnsWidthCollection = [];
            this._visibleColumns = [];
            this._disabledGroupableColumns = [];
            this._fieldColumnNames = {};
            this._headerColumnNames = {};
            if (this.model.scrollSettings.frozenColumns > 0) {
                $frozenDiv = ej.buildTag("div.e-frozenheaderdiv", this._renderGridHeaderInternalDesign(this.model.columns.slice(0, this.model.scrollSettings.frozenColumns), true));
                $movableDiv = ej.buildTag("div.e-movableheader", ej.buildTag("div.e-movableheaderdiv", this._renderGridHeaderInternalDesign(this.model.columns.slice(this.model.scrollSettings.frozenColumns), false)));
                $innerDiv.append($frozenDiv).append($movableDiv);
            } else
                $innerDiv.append(this._renderGridHeaderInternalDesign(this.model.columns));
            $div.html($innerDiv);
			if (this.model.isResponsive)
                $div.addClass("e-textover");
            this.setGridHeaderTable(this.getHeaderContent().find(".e-table"));
            return $div;
        },
        _renderGridContent: function () {
            var $div = ej.buildTag('div.e-gridcontent');
            var $innderDiv = ej.buildTag('div');
            var $table = ej.buildTag('table.e-table', "", {}, { cellspacing: "0.25px" });
            var $tbody = $(document.createElement('tbody'));
            $table.append(this.getHeaderTable().find('colgroup').clone()).append($tbody);
            $innderDiv.html($table);
            $div.html($innderDiv);
            this.setGridContentTable($table);
            this.setGridContent($div);
            $table.attr("role", "grid");
            if (this._dataSource() == null) {
                var $emptyTd = ej.buildTag('td', this._getLocalizedLabels("EmptyRecord"), {}, { colSpan: this.model.columns.length });
                $tbody.append($(document.createElement("tr")).append($emptyTd));
                this.setWidthToColumns();
            } else {
                var args = {};
                if (this.model.groupSettings.groupedColumns.length) {
                    if (this._initialRender)
                        args.columnName = this.model.groupSettings.groupedColumns[this.model.groupSettings.groupedColumns.length - 1];
                    args.requestType = ej.Grid.Actions.Grouping;
                } else
                    args.requestType = ej.Grid.Actions.Refresh;
                this.sendDataRenderingRequest(args);
            }
            if (this._isCaptionSummary && args.requestType == "grouping" && this.model.groupSettings.groupedColumns.length > 1) {
                var colgroup = this.getContentTable().find(".e-table").not(".e-recordtable").children("colgroup");
                var $cols1 = $(this.getContentTable().find(".e-recordtable")[0]).children("colgroup").find("col");
                for (i = 0; i < colgroup.length; i++) {
                    var colCount = $(colgroup[i]).find("col").length;
                    $(colgroup[i]).find("col:gt(" + (colCount - $cols1.length - 1) + ")").remove();
                    $(colgroup[i]).append($cols1.clone());
                }
            }
            return $div;
        },
        /**
         * Print the grid control
         * @return jQuery
         * @example 
         * &lt;div id="Grid"&gt;&lt;/div&gt; 
         * &lt;script&gt;
         * // Create grid object.
         * var gridObj = $("#Grid").data("ejGrid");
         * // It prints the grid.
         * gridObj.print(); 
         * &lt;/script&gt;
         * @example 
         * &lt;div id="Grid"&gt;&lt;/div&dgt; 
         * &lt;script&gt;
         * // It prints the grid.
         * $("#Grid").ejGrid("print");        
         * &lt;/script&gt;
         */
			print:function(){
			var allowPaging=this.model.allowPaging;
			var elementClone=this.element.clone();	
			if(allowPaging){
				this.model.allowPaging=false;
				this.refreshContent();
				this.getPager().css('display','none');
				elementClone=this.element.clone();
				this.model.allowPaging=true;
				if(!this.model.allowScrolling){
					this.refreshContent();
					this.getPager().css('display','block');
					}
				}			
				
			if(this.model.allowScrolling){
				var scrollWidth=this.model.scrollSettings.width,scrollHeight=this.model.scrollSettings.height;
			    var scrollContent=this.getContent().find('.e-content')[0];
				$(elementClone.find('.e-gridcontent')).height(scrollContent.scrollHeight);
			    $(elementClone.find('.e-gridcontent')).ejScroller({width:scrollContent.scrollWidth,height:scrollContent.scrollHeight});
			    elementClone.width(scrollContent.scrollWidth);
				if(this.model.allowPaging){
					this.refreshContent();
					this.getPager().css('display','block');
					}
			}
			if (this.model.toolbarSettings.showToolbar)
			    elementClone.find(".e-gridtoolbar").remove();
			ej.print(elementClone);	
			},

        "export": function (action, serverEvent, multipleExport) {
            var modelClone = $.extend(true, {}, this.model);
            for (var i = 0; i < modelClone.columns.length; i++) {
                if (modelClone.columns[i].editType != undefined) {
                    switch (modelClone.columns[i].editType) {
                        case "stringedit":
                            modelClone.columns[i].editType = "string";
                            break;
                        case "numericedit":
                            modelClone.columns[i].editType = "numeric";
                            break;
                        case "dropdownedit":
                            modelClone.columns[i].editType = "dropdown";
                            break;
                        case "booleanedit":
                            modelClone.columns[i].editType = "boolean";
                            break;
                        default:
                            break;
                    }
                }
            }
            for (var i = 0; i < modelClone.filterSettings.filteredColumns.length; i++) {
                if (modelClone.filterSettings.filteredColumns[i].operator == "equal")
                    modelClone.filterSettings.filteredColumns[i].operator = "equals";
                else if (modelClone.filterSettings.filteredColumns[i].operator == "notequal")
                    modelClone.filterSettings.filteredColumns[i].operator = "notequals";
            }
            var attr = { action: action, method: 'post' };
            var form = ej.buildTag('form', "", null, attr);
            var gridob = this;
            if (this.ignoreOnExport) {
                for (var i = 0; i < this.ignoreOnExport.length; i++) {
                    delete modelClone[this.ignoreOnExport[i]];
                }
            }
            if (ej.raiseWebFormsServerEvents) {
                var args = { model: modelClone, originalEventType: serverEvent };
                var clientArgs = { model: JSON.stringify(modelClone) };
                ej.raiseWebFormsServerEvents(serverEvent, args, clientArgs);
            }
            else {
                var gridobjectArray = {};
                if (multipleExport) {
                    $('body').find('.e-grid').each(function (index, object) {
                        var gridObject = $(object).data('ejGrid');
                        if (!ej.isNullOrUndefined(gridObject)) {
                            var modelClone = JSON.parse(JSON.stringify(gridObject.model));
                            if (gridob.ignoreOnExport) {
                                for (var i = 0; i < gridob.ignoreOnExport.length; i++) {
                                    delete modelClone[gridob.ignoreOnExport[i]];
                                }
                                gridobjectArray[index] = JSON.stringify(modelClone);
                                var inputAttr = { name: 'GridModel', type: 'hidden', value: JSON.stringify(modelClone) }
                                var input = ej.buildTag('input', "", null, inputAttr);
                                form.append(input);
                            }
                        }
                    });
                }
                else {
                    var inputAttr = { name: 'GridModel', type: 'hidden', value: JSON.stringify(modelClone) }
                    var input = ej.buildTag('input', "", null, inputAttr);
                    form.append(input);
                    form.append(this);
                }
                $('body').append(form);
                form.submit();
            }
            return true;
        },
        sendDataRenderingRequest: function (args) {
            if (this._templateRefresh) {
                this.refreshTemplate();
                this._templateRefresh = false;
            }
            if (args.requestType == "add" || (this.model.currentViewData != null && this.model.currentViewData.length)) {
                switch (args.requestType) {
                    case ej.Grid.Actions.Refresh:
                    case ej.Grid.Actions.Paging:
                    case ej.Grid.Actions.Sorting:
                    case ej.Grid.Actions.Filtering:
                    case ej.Grid.Actions.Save:
                    case ej.Grid.Actions.Cancel:
                    case ej.Grid.Actions.Delete:
                    case ej.Grid.Actions.Search:
                    case ej.Grid.Actions.Reorder:
                    case ej.Grid.Actions.BatchSave:
                        if (this.model.groupSettings.groupedColumns.length == 0) {
                            var temp = document.createElement('div'),temp1, insertIndex = -1, isRemoteAdaptor = false;
                            if (!this.model.isResponsive)
                                this.getContentTable().find("colgroup").first().replaceWith(this._getMetaColGroup());
                            (this.model.detailsTemplate != null || this.model.childGrid != null || this.model.detailsDataBound != null) && this.getContentTable().find("colgroup").first().prepend(this._getIndentCol());
                            var currentPage = this._currentPage();
                            if (this.model.editSettings.editMode == "externalform" || this.model.editSettings.editMode == "externalformtemplate")
                                $("#" + this._id + "_externalEdit").css("display", "none");
                            if (this.model.scrollSettings.frozenColumns > 0)
                                temp.innerHTML = this._renderByFrozenDesign();
                            else {
                                temp.innerHTML = ['<table>', $.render[this._id + "_JSONTemplate"](this.model.currentViewData), '</table>'].join("");
								if(args.data) {
									temp1 = document.createElement('div');
									temp1.innerHTML = ['<table>', $.render[this._id + "_JSONTemplate"](args.data), '</table>'].join("");
									if (this._dataSource() instanceof ej.DataManager && args.requestType == ej.Grid.Actions.Save) {
									    insertIndex = this._getDataIndex(this.model.currentViewData, args.data);
									    isRemoteAdaptor = this._dataSource().adaptor instanceof ej.remoteSaveAdaptor;
								}
								}
                                var tableEle = this.getContentTable().get(0);
                                var tbodyEle = tableEle.lastChild;
                                var rindex = this.getContentTable().first().find('tbody').first();
                                if ((args.requestType == "save" || args.requestType == "cancel") && this.model.editSettings.editMode != "batch") {
                                    if (this.model.editSettings.editMode.indexOf("inlineform") != -1)
										rowIndex = !ej.isNullOrUndefined(args.selectedRow) ? args.selectedRow : this._selectedRow();
									else
										rowIndex = this.getContentTable().find('.e-' + args.action + 'edrow').index();
                                    var a = this._currentTrIndex;
                                    if (rowIndex == -1)
                                        rowIndex = a;
                                    if (this.model.detailsTemplate != null) {
                                        rowTr = $(tbodyEle.childNodes[rowIndex]);
                                        rowEle = $(tbodyEle.childNodes).not('.e-detailrow');
                                        for (var i = 0; i < rowEle.length; i++) {
                                            if (rowTr.is(rowEle[i]))
                                                rowIndex = i;
                                        }
                                    }

                                    if (this.model.editSettings.editMode == "normal" || this.model.editSettings.editMode == "inlineform" || this.model.editSettings.editMode == "inlineformtemplate") {                                      
                                        $oldChild = this.getContentTable().find('.e-addedrow').get(0);
                                        $editedTr = this.getContentTable().find('.e-editedrow');
                                        $newChild = ($editedTr.length || args.requestType == "cancel") ? temp.firstChild.firstChild.firstChild : temp1.firstChild.firstChild.lastChild;
                                        if ($editedTr.length) {
                                            $newChild = temp.firstChild.firstChild.childNodes[rowIndex];
                                            if (this.model.editSettings.editMode == "inlineform" || this.model.editSettings.editMode == "inlineformtemplate") {
                                                $oldChild = $editedTr.prev('tr').get(0);
                                                $editedTr.remove();
                                            } else
                                                $oldChild = $editedTr.get(0);
                                            $($newChild).find('.e-templatecell').replaceWith($($oldChild).find('.e-templatecell'));
                                            if (args.requestType == "cancel") {
                                                $($oldChild).replaceWith($($newChild));
                                            } else if (!ej.isNullOrUndefined(this._filteredRecordsCount) && this._filteredRecordsCount < this._previousFilterCount) {
                                                if (this.model.detailsTemplate != null && $($oldChild).next('tr.e-detailrow').length)
                                                    tbodyEle.removeChild($($oldChild).next('tr.e-detailrow').get(0));
                                                $($oldChild).remove();
                                                if (this.model.allowPaging && this.model.pageSettings.pageSize <= this.model.currentViewData.length && this.model.groupSettings.groupedColumns.length == 0)
                                                    tbodyEle.appendChild(temp.firstChild.firstChild.lastChild);
                                            } else {
												var $eRow = $(tbodyEle).find(".e-editedrow");
                                                $eRow.find("select.e-dropdownlist").ejDropDownList("destroy");
                                                $eRow.find(".e-datepicker").ejDatePicker("destroy");
                                                $eRow.find(".e-datetimepicker").ejDateTimePicker("destroy");
                                                tbodyEle.replaceChild($newChild, $oldChild);
                                            }
                                        } else {
                                            if (args.requestType == "cancel" || this._dataSource() instanceof ej.DataManager || this._currentPage() != 1 || (args.requestType == "save" && !ej.isNullOrUndefined(this._filteredRecordsCount) && this._filteredRecordsCount == this._previousFilterCount)) {
                                                if (!ej.isNullOrUndefined($oldChild)) {
                                                    $($oldChild).remove();
                                                    if (this._dataSource() instanceof ej.DataManager && insertIndex != -1) {
                                                        if (insertIndex == 0)
                                                            tbodyEle.insertBefore($newChild, tbodyEle.children[insertIndex]);
                                                        else
                                                            $($newChild).insertAfter(tbodyEle.children[insertIndex - 1]);                                                        
                                                    }
                                                    else if ((!(this._dataSource() instanceof ej.DataManager) || isRemoteAdaptor) && this._currentPage() != 1 && args.requestType == "save")
                                                        $(tbodyEle).prepend($(temp.firstChild.firstChild.firstChild));
                                                    if (this.model.allowPaging && this.model.pageSettings.pageSize <= this.model.currentViewData.length && this.model.groupSettings.groupedColumns.length == 0 &&
                                                        ((this._dataSource() instanceof ej.DataManager && insertIndex == -1 && (!isRemoteAdaptor && args.requestType != "save")) ||
                                                        (args.requestType != "save" && !(this._dataSource() instanceof ej.DataManager))))
                                                        tableEle.lastChild.appendChild(temp.firstChild.firstChild.lastChild);
                                                }
                                                if (args.requestType == "cancel" && this._selectedRow() != -1)
                                                    this.clearSelection();

                                            } else if (this.model.currentViewData.length == 1) {
                                                $(tbodyEle).empty();
                                                tbodyEle.appendChild($newChild);
                                            } else if (this.model.editSettings.rowPosition == "bottom") {
                                                rindex.prepend($oldChild);
                                                tbodyEle.replaceChild($newChild, $oldChild);
                                            } else
                                                tbodyEle.replaceChild($newChild, $oldChild);
                                        }
                                    } else if (this.model.editSettings.editMode == "dialog" || this.model.editSettings.editMode == "dialogtemplate" || this.model.editSettings.editMode == "externalform" || this.model.editSettings.editMode == "externalformtemplate") {
                                        $editedTr = this.element.find('.e-editedrow');
                                        if (args.requestType == "cancel" || (!$editedTr.length && !ej.isNullOrUndefined(this._filteredRecordsCount) && this._filteredRecordsCount == this._previousFilterCount)) {
                                            $newChild = temp.firstChild.firstChild.childNodes[rowIndex];
                                            $oldChild = tbodyEle.childNodes[rowIndex];
                                            $($oldChild).replaceWith($($newChild));
                                            this.clearSelection();
                                            this.model.allowPaging && this._refreshGridPager();

                                        } else if ($editedTr.length) {
                                            $newChild = temp.firstChild.firstChild.childNodes[rowIndex];
                                            $oldChild = tbodyEle.childNodes[rowIndex];
											if (this.model.allowCellMerging != null) {
                                                if ($($oldChild.childNodes).hasClass("e-merged")) {
                                                    var index = $($oldChild).children('.e-merged').index();
                                                    var count = $oldChild.children[index].colSpan;
                                                    for (var i = 0 ; i < count; i++) {
                                                        $newChild.childNodes[index + i].className += " e-merged e-hide";
                                                        $newChild.childNodes[index].colSpan = i + 1;
                                                    }
                                                }
                                            }
                                            if (this.model.detailsTemplate != null)
                                                $oldChild = $(tbodyEle.childNodes).not('.e-detailrow').eq(rowIndex).get(0);
                                            if (!ej.isNullOrUndefined(this._filteredRecordsCount) && this._filteredRecordsCount < this._previousFilterCount) {
                                                if (this.model.detailsTemplate != null && $($oldChild).next('tr.e-detailrow').length)
                                                    tbodyEle.removeChild($($oldChild).next('tr.e-detailrow').get(0));
                                                $($oldChild).remove();
                                                if (this.model.allowPaging && this.model.pageSettings.pageSize <= this.model.currentViewData.length)
                                                    tbodyEle.appendChild(temp.firstChild.firstChild.lastChild);
                                            } else
                                                tbodyEle.replaceChild($newChild, $oldChild);
                                        } else if (this.model.currentViewData.length == 1 && this.getContentTable().find('td.e-rowcell').length == 0) {
                                            $newChild = temp.firstChild.firstChild.firstChild;
                                            $(tbodyEle).empty();
                                            tbodyEle.appendChild($newChild);
                                        } else {
                                            newChild = ($editedTr.length || args.requestType == "cancel") ? temp.firstChild.firstChild.firstChild : temp1.firstChild.firstChild.lastChild;
                                            if (!(this._dataSource() instanceof ej.DataManager)) {
                                                if (this._currentPage() == 1)
                                            this.getContentTable().find('tbody').first().prepend($(newChild));
                                                else
                                                    this.getContentTable().find('tbody').first().prepend($(temp.firstChild.firstChild.firstChild));
                                                if (this.model.allowPaging && this.model.pageSettings.pageSize <= this.model.currentViewData.length)
                                                tbodyEle.removeChild(tbodyEle.lastChild);
                                            }
                                            else if (insertIndex != -1) {
                                                if (insertIndex == 0)
                                                    tbodyEle.insertBefore(newChild, tbodyEle.children[insertIndex]);
                                                else
                                                    $(newChild).insertAfter(tbodyEle.children[insertIndex - 1]);
                                                if (this.model.allowPaging && (this.model.pageSettings.pageSize <= this.model.currentViewData.length || insertIndex == this.model.pageSettings.pageSize - 1))
                                                    tbodyEle.removeChild(tbodyEle.lastChild);
                                            }
                                            if (this.model.detailsTemplate != null && $(tableEle.lastChild.lastChild).children('.e-detailrowexpand').length)
                                                tbodyEle.removeChild(tbodyEle.lastChild);
                                        }
                                    }
                                    if (this.model.enableAltRow)
                                        this._refreshAltRow();
                                } else if (args.requestType == "delete") {
                                    if (this._isUnboundColumn) {
                                        $editedrow = this.element.find('.e-editedrow');
                                        $oldChild = this.getContentTable().find('.e-editedrow').get(0);
                                        $newChild = ($editedrow.length) ? temp.firstChild.firstChild.firstChild : temp1.firstChild.firstChild.lastChild;

                                        if ($editedrow.length != 0 && (this.model.editSettings.editMode == "normal" || this.model.editSettings.editMode == "externalform" || this.model.editSettings.editMode == "externalformtemplate")) {
                                            $($oldChild).replaceWith($($newChild));
                                        }
                                        else if (this.model.editSettings.editMode == "inlineform" || this.model.editSettings.editMode == "inlineformtemplate") {
                                            $oldChild = $editedrow.prev('tr').get(0);
                                            $editedrow.remove();
                                        }
                                        else
                                            $oldChild = $editedrow.get(0);
                                    }
                                    if (this.model.allowPaging && this.model.pageSettings.pageSize <= this.model.currentViewData.length)
                                        tbodyEle.appendChild(temp.firstChild.firstChild.lastChild);
                                    if (this.model.detailsTemplate != null) {
                                        var visibleRow = this.getContentTable().find('.e-detailrow:visible');
                                        $.each(visibleRow, function (indx, item) {
                                            if (visibleRow.eq(indx).closest('tr').prev().children('.e-detailrowexpand').length == 0)
                                                visibleRow.eq(indx).remove();
                                        });
                                    }
                                    if (this.model.enableAltRow)
                                        this._refreshAltRow();
                                } else
                                    this.getContentTable().get(0).replaceChild(this.model.rowTemplate != null ? temp.firstChild.lastChild : temp.firstChild.firstChild, this.getContentTable().get(0).lastChild);

                            }
                            this._currentJsonData = this.model.currentViewData;
                            this._gridRows = this.getContentTable().get(0).rows;
                            if (this.model.scrollSettings.frozenColumns > 0)
                                this._gridRows = [this._gridRows, this.getContentTable().get(1).rows];
                            this._eventBindings();
                            var model = {};
                            if ((args.requestType == "sorting" || args.requestType == "filtering") && this.model.scrollSettings.allowVirtualScrolling) {
                                if (args.requestType == "filtering") {
                                    this.getContent().first().ejScroller("refresh").ejScroller("isVScroll") ? this.element.find(".gridheader").addClass("e-scrollcss") : this.element.find(".gridheader").removeClass("e-scrollcss");
                                    var model = this._refreshVirtualPagerInfo();
                                }
                                this._refreshVirtualContent(currentPage, model);
                                args.requestType == "filtering" && this.getContent().first().ejScroller("refresh");
                            }
                            if (this.model.allowPaging) {
                                if (this.model.filterSettings.filteredColumns.length)
                                    this.getPager().ejPager({ totalRecordsCount: this._searchCount == null ? this._filteredRecordsCount : this._searchCount, currentPage: this._currentPage() });
                                else
                                    this.getPager().ejPager({ totalRecordsCount: this._searchCount == null ? this._gridRecordsCount : this._searchCount, currentPage: this._currentPage() });
                                this._refreshGridPager();
                            }
                            break;
                        }
                    case ej.Grid.Actions.Grouping:
                        this._group(args);
                        this._refreshStackedHeader();
                        break;
                    case ej.Grid.Actions.BeginEdit:
                        this._edit(args);
                        break;
                    case ej.Grid.Actions.Add:
                        this._add(args);
                        break;
                    case ej.Grid.Actions.Ungrouping:
                        this._ungroup(args);
                        break;
                    case ej.Grid.Actions.VirtualScroll:
                        !this._isVirtualRecordsLoaded && this._replacingContent();
                        break;
                }
            } else
                this.getContentTable().find('tbody').empty().first().append(this._getEmptyTbody());
            this._completeAction(args);
        },
        _completeAction: function (args) {
            this.model.isEdit = false;
            this._confirmedValue = false;
            if (ej.Grid.Actions.Grouping == args.requestType && ej.isNullOrUndefined(args.columnName))
                return;
            this.setWidthToColumns();
            if (ej.Grid.Actions.UnGrouping == args.requestType || this.model.groupSettings.groupedColumns.length && !$("#" + this._id + "EditForm").length)
                this._recalculateIndentWidth();
            if (ej.Grid.Actions.Paging == args.requestType || ej.Grid.Actions.BatchSave == args.requestType)
                this._refreshGridPager();
            else if ((ej.Grid.Actions.Sorting == args.requestType && this.model.allowSorting) || ej.Grid.Actions.Refresh == args.requestType) {
                if (ej.gridFeatures.sort && this.getHeaderTable() !== null)
                    this._sortCompleteAction(args);
                if(this.model.allowPaging){		
					var pageModel=this.getPager().ejPager("option");
					this._currentPage(pageModel.currentPage);
					delete pageModel.currentPage;
					$.extend(this.model.pageSettings, pageModel);
					delete this.model.pageSettings.masterObject;
					this._refreshGridPager();
				}
                if (!this._initialRender && (this.model.scrollSettings.frozenRows > 0 || this.model.scrollSettings.frozenColumns > 0))
                    this._refreshScroller(args);
            } else if (ej.Grid.Actions.Delete == args.requestType || ej.Grid.Actions.Save == args.requestType || ej.Grid.Actions.Search == args.requestType) {
                this._editEventTrigger(args);
                if (this.model.allowPaging)
                    this._refreshPagerTotalRecordsCount();
            } else if (ej.Grid.Actions.Filtering == args.requestType)   
                this._filterCompleteAction();
            else if (ej.Grid.Actions.BeginEdit == args.requestType || ej.Grid.Actions.Add == args.requestType)
                this._editCompleteAction(args);
            else if (ej.Grid.Actions.Grouping == args.requestType || ej.Grid.Actions.Ungrouping == args.requestType)
                this["_" + args.requestType + "CompleteAction"](args);
            if (this.model.toolbarSettings.showToolbar)
                this.refreshToolbar();
            if (!this._initialRender && this.model.showSummary && this.model.summaryRows.length > 0) {
                this.getFooterTable().find('colgroup').remove();
                this.getFooterTable().append(this.getHeaderTable().find("colgroup").clone());
                this._createSummaryRows(this.getFooterTable());
            }
            if (!this._initialRender && ej.gridFeatures.selection) {
                this._setCurrentRow(args.requestType);
                this.getHeaderTable().find(".e-columnselection").removeClass("e-columnselection");
                this.selectedColumnIndexes = [];
            }
            this.model.editSettings.editMode == "batch" && this.refreshBatchEditMode();
            if (!this._initialRender && this.model.allowScrolling && (this._checkScrollActions(args.requestType) || (this.model.editSettings.editMode.indexOf("inline") != -1 && args.requestType == "beginedit")) ||
                (this.model.scrollSettings.virtualScrollMode == "continuous" && args.requestType == "virtualscroll"))
                this._refreshScroller(args);
            if (this._customPop != null && args.requestType != "sorting") {
                this._customPop.hide();
            }
            if (this.model.allowScrolling && (ej.Grid.Actions.Filtering == args.requestType || ej.Grid.Actions.Paging == args.requestType || ej.Grid.Actions.Sorting == args.requestType ||
                ej.Grid.Actions.Grouping == args.requestType || ej.Grid.Actions.Ungrouping == args.requestType)) {
                this.getContentTable().find("tr:last").find("td").addClass("e-lastrowcell");
            }
            this._trigger("actionComplete", args);
            if ((ej.Grid.Actions.BeginEdit == args.requestType || ej.Grid.Actions.Add == args.requestType) && $.isFunction($.validator))
                this.setValidation();
        },
        _getForeignKeyData: function (data) {
            var proxy = this;
            var column;
            for (i = 0; i < this.model.columns.length; i++) {
                if (this.model.columns[i].foreignKeyValue && this.model.columns[i].dataSource) {
                    var fieldName = ej.isNullOrUndefined(proxy.model.columns[i]["foreignKeyField"]) ? proxy.model.columns[i]["field"] : proxy.model.columns[i]["foreignKeyField"];
                    this.model.columns[i].dataSource.filter(function (col) {
                        var value = data[proxy.model.columns[i]["field"]];
                        var fValue = !isNaN(parseFloat(value)) && isFinite(value) ? parseFloat(value) : value;
                        if (col[fieldName] == fValue)
                            return column = col;
                    });
                }
            }
            return column;
        },
        _foreignKeyBinding: function (curColumn, cellValue, gridId) {
            if (typeof (curColumn) == "string")
                curColumn = JSON.parse(curColumn);
            var cellData;
            curColumn.dataSource.filter(function (col) {
                if (col[curColumn.foreignKeyField] == cellValue)
                    return cellData = curColumn.type == "date" ? new Date(col[curColumn.foreignKeyValue]) : col[curColumn.foreignKeyValue];
            });
            if (curColumn.format) {
                var gridObj = ej.isNullOrUndefined(gridId) ? this : this.getRsc("helpers", gridId);
                cellData = gridObj.formatting(curColumn.format, cellData,gridObj.model.locale);
            }
            return cellData;
        },
        _getDataIndex: function (data, item) {
            var flag = 0, _plen;
            for (var d = 0, len = data.length; d < len; d++) {
                for(var key = 0, _plen = this._primaryKeys.length; key < _plen; key++) {
                 if (data[d][this._primaryKeys[key]] != item[this._primaryKeys[key]])
                     continue;                                  
                 else if(key == _plen-1)
                     flag = 1;
              }
               if(flag) return d;      
            }
            return -1;
        },
        _eventBindings: function () {
            var rowLength = this.model.frozenColumns > 0 ? this._gridRows[0].length : this._gridRows.length;
            var trIndex=0;
			var prev;
			var pageSize = this.model.pageSettings.pageSize;
			if (ej.gridFeatures.common)
                this._refreshUnboundTemplate(this.getContentTable());
            if (this._gridRecordsCount != 0) {
                if (this.model.queryCellInfo != null || this.model.rowDataBound != null || this.model.mergeCellInfo != null) {
                    for (var row = 0; row < rowLength; row++){
						trIndex = row; 
						if(this.model.scrollSettings.allowVirtualScrolling && row < pageSize)
						{
							for(var i=0;i<this.model.query.queries.length;i++)
								prev = this.model.query.queries[i].fn == "onPage" && this.model.query.queries[i].e.pageIndex - 1;
							var value = pageSize * prev;
							if(value != 0)
								trIndex = this.getContentTable().find("tr[name="+value+"]").eq(row).index();
						}
						if(this.getRowByIndex(trIndex).hasClass("e-virtualrow") || ej.isNullOrUndefined(this._currentJsonData[row]))
							break;	
						this._rowEventTrigger(this.getRowByIndex(trIndex), this._currentJsonData[row]);
					}
				}
            }
        },
        _rowEventTrigger: function (row, data) {
            var args = { row: row, data: data };
            this._trigger("rowDataBound", args);
            var tdCells = row.cells;
            var $tdRowcells = $(row).find(".e-rowcell");
            for (var cellIndex = 0; cellIndex < $tdRowcells.length; cellIndex++) {
                var args = { cell: $tdRowcells[cellIndex], data: data, text: $tdRowcells[cellIndex].innerHTML };
                var foreignKeyData = this._getForeignKeyData(args.Data);
                if ($($tdRowcells[cellIndex]).hasClass("e-rowcell"))
                    args.column = this.model.columns[cellIndex];
                if (!ej.isNullOrUndefined(foreignKeyData))
                    args.foreignKeyData = foreignKeyData;
				if (this.model.allowCellMerging == true) {
                    this._cellMerging(args);
                    this._trigger("mergeCellInfo", args);
                }
                this._trigger("queryCellInfo", args);
            }

        },
        formatting: function (formatstring, str,locale) {
            formatstring = formatstring.replace(/%280/g, "\"").replace(/&lt;/g, "<").replace(/&gt;/g, ">");
            locale = Globalize.cultures[locale] ? locale : "en-US";
            var s = formatstring;
            var frontHtmlidx, FrontHtml, RearHtml, lastidxval;
            frontHtmlidx = formatstring.split("{0:");
            lastidxval = formatstring.split("}");
            FrontHtml = frontHtmlidx[0];
            RearHtml = lastidxval[1];
            if (typeof (str) == "string" && $.isNumeric(str))
                str = Number(str);
            if (formatstring.indexOf("{0:") != -1) {
                var toformat = new RegExp("\\{0(:([^\\}]+))?\\}", "gm");
                var formatVal = toformat.exec(formatstring);
                if (formatVal != null && str != null) {
                    if (FrontHtml != null && RearHtml != null)
                        str = FrontHtml + Globalize.format(str, formatVal[2],locale) + RearHtml;
                    else
                        str = Globalize.format(str, formatVal[2],locale);
                } else if (str != null)
                    str = str;
                else
                    str = "";
                return str;
            } else if (this.data != null && this.data.Value == null) {
                $.each(this.data, function (dataIndex, dataValue) {
                    s = s.replace(new RegExp('\\{' + dataIndex + '\\}', 'gm'), dataValue);
                });
                return s;
            } else {
                return this.data.Value;
            }
        },
        
        setWidthToColumns: function () {
            var $cols1 = this.getContentTable().children("colgroup").find("col");
            var $cols2 = this.getHeaderTable().children("colgroup").find("col");
            var width = this.element.width(), frozenWidth = 0, columnsTotalWidth = 0;
            if (this.model.groupSettings.groupedColumns.length && !this.model.allowScrolling && this.model.groupSettings.showGroupedColumn) {
                var browserDetails = this.getBrowserDetails();
                if (browserDetails.browser == "msie" && parseInt(browserDetails.version, 10) > 8)
                    $cols1.first().css("width", ((30 / width) * 100) + "%");
            }
            if (!ej.isNullOrUndefined(this.model.detailsTemplate)) {
                var headerIndx = this.model.groupSettings.groupedColumns.length;
                var contentIndx = this.model.groupSettings.groupedColumns.length != 0 ? 1 : 0;
                $cols1.eq(contentIndx).css("width", this._detailsOuterWidth);
                $cols2.eq(headerIndx).css("width", this._detailsOuterWidth);
            }
            this._detailColsRefresh();
            $cols1 = this._$headerCols;
            $cols2 = this._$contentCols;

            for (var i = 0; i < $cols2.length; i++) {
                if (this.model.allowResizeToFit && this.model.columns[i]["width"] === undefined) {
                    hCellIndex = this.model.groupSettings.groupedColumns.length ? (i + this.model.groupSettings.groupedColumns.length) : i;
                    var contentWidth = this._resizer._getContentWidth(i);
                    var headerWidth = this._resizer._getHeaderContentWidth(this.getHeaderTable().find('.e-headercelldiv').eq(hCellIndex));
                    var finalWidth = contentWidth > headerWidth ? contentWidth : headerWidth;
                    finalWidth = finalWidth + (finalWidth * 0.2);
                    this._columnsWidthCollection[i] = finalWidth;
                    columnsTotalWidth = columnsTotalWidth + finalWidth;
                }
                if (!ej.isNullOrUndefined(this._columnsWidthCollection[i])) {
                    $cols1.eq(i).width(this._columnsWidthCollection[i]);
                    $cols2.eq(i).width(this._columnsWidthCollection[i]);
                } else if (this.model.allowScrolling) {
                    var colWidth = (width / this.model.columns.length).toFixed(2), bSize = this.model.scrollSettings.buttonSize || 18, cWidth = colWidth - (width / bSize);
                    $cols1.eq(i).css("width", cWidth + "px");
                    $cols2.eq(i).css("width", cWidth + "px");
                    this._columnsWidthCollection[i] = parseFloat(cWidth);
                }
            }
			if (columnsTotalWidth > width && this.model.allowResizeToFit) {
                this.model.allowScrolling =true;
                this.model.scrollSettings.width = width;
                this.getHeaderTable().parent().addClass("e-headercontent");
				this.getHeaderTable().width(width);
            }
            if (this.model.isEdit) {
                var clonedCol = $cols1.clone(), $colGroup = this.model.scrollSettings.frozenColumns > 0 ? this.getContent().find(".gridform").find("colgroup") : $("#" + this._id + "EditForm").find("colgroup");
                this.model.scrollSettings.frozenColumns > 0 && $colGroup.first().empty().append(clonedCol.splice(0, this.model.scrollSettings.frozenColumns));
                $colGroup.last().empty().append(clonedCol);
                if(this.model.detailsTemplate != null||this.model.childGrid !=null)
                $colGroup.prepend(this._getIndentCol());
            }
            if (this.model.groupSettings.groupedColumns.length) {
                var $grouedColGroup = this.getContentTable().find(".e-recordtable").children("colgroup");
                for (var i = 0; i < $grouedColGroup.length; i++) {
                    var clonedCol = $cols1.clone();
                    var detailsWidth = this._detailsOuterWidth != null ? this._detailsOuterWidth : "30px";
                    if (this.model.detailsTemplate != null || this.model.childGrid != null) clonedCol.splice(0, 0, $(this._getIndentCol()).width(detailsWidth)[0]);
                    $grouedColGroup.eq(i).empty().append(clonedCol);
                }
            }
            if (this.model.scrollSettings.frozenColumns > 0) {
                var totalWidth = 0, frozenWidth;
                for (var i = 0; i < this._columnsWidthCollection.length; i++) {
                    totalWidth += this._columnsWidthCollection[i];
                    if (this.model.scrollSettings.frozenColumns - 1 == i)
                        frozenWidth = Math.ceil(totalWidth);
                }
                this.getContent().find(".e-frozencontentdiv").outerWidth(frozenWidth)
                    .end().find(".e-movablecontentdiv").outerWidth(totalWidth - frozenWidth);
                this.getHeaderContent().find(".e-frozenheaderdiv").outerWidth(frozenWidth)
                    .end().find(".e-movableheaderdiv").outerWidth(totalWidth - frozenWidth);
            }
        },
        _initialEndRendering: function () {
            // use this method to add behaviour after grid render.
            if (this.model.editSettings.allowEditing || this.model.editSettings.allowAdding) {
                if (this.model.editSettings.editMode == "dialog" || this.model.editSettings.editMode == "dialogtemplate")
                    this.element.append(this._renderDialog());
                else if (this.model.editSettings.editMode == "externalform" || this.model.editSettings.editMode == "externalformtemplate")
                    this.element.append(this._renderExternalForm());
            }
            if (this._selectedRow() != -1)
                this.selectRows(this._selectedRow());
            (this.model.editSettings.editMode == "batch" || this.model.editSettings.showDeleteConfirmDialog) && this._renderConfirmDialog();
            this.model.scrollSettings.frozenColumns > 0 && this._renderAlertDialog();
            if (this.model.allowMultiSorting || this.model.selectionType == "mulitple")
                this._renderMultiTouchDialog();
            if (this.model.scrollSettings.frozenColumns > 0 && !this.model.allowScrolling) {
                this.getContent().remove();
                this.getHeaderTable().eq(1).remove();
                this._alertDialog.find(".e-content").text(this._getLocalizedLabels("FrozenColumnsScrollAlert"));
                this._alertDialog.ejDialog("open");
                return;
            }
            this.model.scrollSettings.allowVirtualScrolling && this._createPagerStatusBar();
            this._getRowHeights();
            this.model.allowScrolling && this._renderScroller();
            this._addMedia();
            if (this.model.scrollSettings.allowVirtualScrolling) {
                this._refreshVirtualContent();
				this.getContent().first().ejScroller("refresh");
                if (this.getContent().ejScroller("isVScroll")){
                    this.element.find(".e-gridheader").addClass("e-scrollcss");
                    this.getHeaderTable().first().width(this.getContentTable().width());
                }
                else
                    this.element.find(".e-gridheader").removeClass("e-scrollcss");
            }
            if (this.model.allowFiltering && this.model.filterSettings.filterType == "filterbar" && !this.model.allowPaging && !this.model.scrollSettings.allowVirtualScrolling)
                this._createPagerStatusBar();
            if (ej.gridFeatures.common)
                this.rowHeightRefresh()
            if (ej.gridFeatures.filter && ["menu", "excel"].indexOf(this.model.filterSettings.filterType) != -1)
                this._refreshFilterIcon();
        },
        _addMedia: function () {
			if(this.model.allowScrolling)
				this.model._scrollWidth = this.model.scrollSettings.width;
            if (this.model.minWidth && !this.model.enableResponsiveRow) {
                this._$onresize = $.proxy(this._windowonresize, this);
                $(window).bind("resize", this._$onresize);
                if ($.isFunction(window.matchMedia)){
                    var mediaFilterObj = window.matchMedia("(max-width: 768px)");
                    this._mediaStatus = mediaFilterObj.matches;
                }
                this._windowonresize();
            }
        },
        _mediaQueryUpdate: function (addScroller) {
            if (addScroller) {
                if (this.model.minWidth && !this.element.hasClass("e-responsive") && !this._scrollerAddedOnMedia) {
                    this.getContentTable().css("min-width", this.model.minWidth);
                    this.getHeaderTable().css("min-width", this.model.minWidth);
                    this.model.allowScrolling = true;
                    this._mediaQuery = true;
                    this.model.scrollSettings.width = this.getContent().width();
                    this.element.find(".e-gridheader").first().find("div").first().addClass("e-headercontent");
                    this._renderScroller();
                    this._mediaQuery = false;
                    this._scrollerAddedOnMedia = true;
                }
                this.getContent().ejScroller({ width: this.getHeaderContent().outerWidth(), height: this.model.scrollSettings.height });
            } else if (this._scrollerAddedOnMedia) {
                if (this.getHeaderContent().hasClass("e-scrollcss")) {
                    this.getHeaderContent().removeClass("e-scrollcss");
                    this.getHeaderContent().find(".e-headercontent").first().removeClass("e-headercontent");
                }
                if (this.getContent().data("ejScroller"))
                    this.getContent().ejScroller("destroy");
                this.getContentTable().css("min-width", "");
                this.getHeaderTable().css("min-width", "");
                this._scrollerAddedOnMedia = false;
            }
        },
        _windowonresize: function () {
			var $width = $(window).width()<= this.model._scrollWidth || ej.isNullOrUndefined(this.model._scrollWidth) ? "auto" : this.model._scrollWidth;
            this.element.css("width",$width);
			this.getHeaderContent().css("width",$width);
			this.getContent().css("width",$width);
            this._mediaQueryUpdate(this.getContent().width() < this.getContent().find('table').width());
        },
        _removeMedia: function () {
            $(window).unbind("resize", this._$onresize);
            this.getContentTable().css("min-width", "");
            this.getHeaderTable().css("min-width", "");
            this.model.scrollSettings.width = "auto";
            if (this.getContent().data("ejScroller"))
                this.getContent().ejScroller("destroy");
        },
        _getRowHeights: function () {
            var trs = this.getRows();
            if (trs !== null) {
                this._rowHeightCollection = [];
                if ((this.model.scrollSettings.frozenColumns > 0 && trs[0] !== undefined && trs[1] !== undefined) || (typeof trs[0].item !== "undefined" && typeof trs[0].length == "number" && typeof trs[1].item !== "undefined" && typeof trs[1].length == "number")) {
                    frotrs = trs[0];
                    movtrs = trs[1];
                    for (var i = 0 ; i < frotrs.length ; i++) {
                        this._rowHeightCollection[i] = frotrs[i].offsetTop >= movtrs[i].offsetTop ? frotrs[i].offsetTop : movtrs[i].offsetTop;
                    }
                }
                else {
                    for (var i = 0 ; i < trs.length ; i++) {
                        this._rowHeightCollection[i] = trs[i].offsetTop;
                    }
                }
            }
            return this._rowHeightCollection;
        },
        _getEmptyTbody: function () {
            var $emptyTd = ej.buildTag('td.emptyrecord', this._getLocalizedLabels("EmptyRecord"), {}, { colSpan: this.model.columns.length });
            return $(document.createElement("tr")).append($emptyTd);
        },
        _getIndentCol: function () {
            return ej.buildTag("col", "", { width: "30px" });
        },
        _createSortElement: function () {
            return ej.buildTag('span.e-icon', "&nbsp;");
        },
        _createSortNumber: function (number, header) {
            if (header.css("text-align") == "right")
                return ej.buildTag('span.e-number', number, { "color": "white", "font-size": "9px", "float": "left" });
            else
                return ej.buildTag('span.e-number', number, { "color": "white", "font-size": "9px", "float": "right" });
        },
        _wireEvents: function () {
            this._on(this.element, ($.isFunction($.fn.tap) && this.model.enableTouch) ? "tap" : "click", this._clickHandler);
            this._on(this.element, ($.isFunction($.fn.tap) && this.model.enableTouch) ? "tap" : "click", ".e-gridheader", this._mouseClickHandler);
            if (ej.gridFeatures.common) {
                this._on(this.element, "dblclick", ".e-gridcontent", this._recorddblClickHandler);
                if (this.model.rightClick)
                    this._on(this.element, "contextmenu", this._rightClickHandler);
                this._on(this.element, "click", ".e-gridcontent", this._recordClick);
                this._enableRowHover();
                if (this.model.enableTouch)
                    this._on(this.element, "swipeleft swiperight", ".e-gridcontent .e-table", $.proxy(this._touchGrid, this));
                else
                    this.element.addClass("e-touch");
                this._on(this.element, "mousedown", ".e-gridheader", this._headerMouseDown);
                this._on(this.element, "mouseover mouseleave", ".e-gridheader", this._headerHover);
                this._on(this.element, ej.eventType.mouseMove, ".e-gridheader", this._headerHover);
                this.model.allowResizeToFit && this._on(this.element, "dblclick", ".e-gridheader", this._headerdblClickHandler);
                if (this.model.allowResizing) {
                    this._on(this.element, ej.eventType.mouseMove, this._mouseMove);
                    this._on(this.element, "mouseup", this._mouseUp);
                }
				if (this.model.allowKeyboardNavigation) {
					this.element[0].tabIndex = 0;
					this.element[0].accessKey = "e";
					this._on(this.element, "keyup", this._keyDownHandler);
                }
            }
            if (ej.gridFeatures.edit) {
                this._enableEditingEvents();
                this._on(this.element, "click", ".e-gridcontent .e-unboundcelldiv", this._unboundClickHandler);
            }
            if (this.model.allowGrouping) {
                this._enableGroupingEvents();
                this._on(this.element, "mouseenter mouseleave", ".e-groupdroparea,.e-groupheadercell", this._dropAreaHover);
               
            }
            if (!this.model.editSettings.allowEditing)
                this._on(this.element, "dblclick", ".e-gridcontent", this._recorddblClickHandler);
            this._enableFilterEvents();
        },
        _enableFilterEvents: function () {
            if (this.model.allowMultiSorting || this.model.selectionType == "multiple" || this.model.allowFiltering)
                this._on($(document), "click", this._docClickHandler);
            if (this.model.allowFiltering) {
                var proxy = this, $target;
                this._off(this.element, "keyup", ".e-filterbar input")._on(this.element, "keyup", ".e-filterbar input", this._filterBarHandler);
                this._on(this.element, "focus click", ".e-filterbar", this._filterBarClose);
            }
        },
        _docClickHandler: function (e) {
            var details = this.getBrowserDetails();
            if (this._customPop != null && this.element.find(e.target).length == 0)
                this._customPop.hide();
            if (this.model.allowFiltering) {
                if (this.model.filterSettings.filterType == "menu" || this.model.filterSettings.filterType == "excel") {
                    if (this._$colType && ($(e.target).find(".e-grid.e-dlgcontainer").length > 1 || $(e.target).find(".e-excelfilter").length > 1))
                        if (details.browser == "msie")
                            e.target.tagName != "BODY" && (!this.isExcelFilter ? this._closeFilterDlg() : this._excelFilter.closeXFDialog(e));
                        else
                            !this._isExcelFilter ? this._closeFilterDlg() : this._excelFilter.closeXFDialog(e);
                } else if (!$(e.target).hasClass("e-filtertext"))
                    this.getFilterBar().find(".e-cancel").addClass("e-hide");
            }

        },
        _mouseClickHandler: function (e) {
            var $temp = $(e.target), $target;
            if (this.getHeaderTable().find('.e-columnheader').not('.e-stackedHeaderRow').css('cursor') == "col-resize")
                return;
           if ($temp.hasClass("e-headercelldiv"))
					$target = this.getHeaderTable().find(".e-headercelldiv[ej-mappingname='" + $.trim($($temp.parent()).text()).replace(/\s/g, "") + "']");
				else if ($(e.target).is(".e-ascending, .e-descending"))
					$target = $(e.target.parentNode);
				else
                    $target = $(e.target);
            if (this._$fDlgIsOpen && this.model.allowFiltering && (this.model.filterSettings.filterType == "menu" || this._isExcelFilter)) {
                $.fx.off = true;
                if (this._isExcelFilter)
                    this._excelFilter.closeXFDialog();
                else if ($("#" + this._id + "_" + this._$prevColType + "Dlg").data("ejDialog") != undefined)
                    $("#" + this._id + "_" + this._$prevColType + "Dlg").ejDialog("close");
                $.fx.off = false;
            }
            this.getHeaderTable().find(".e-columnheader").find(".e-headercellactive").removeClass("e-headercellactive").removeClass("e-active");
            if ($target.hasClass("e-headercelldiv") || (!$target.hasClass("e-togglegroupbutton") && $target.closest(".e-headercelldiv").length && $.inArray($target[0].tagName, ["SELECT", "INPUT", "TEXTAREA"]) == -1)) {
                if (!this.model.allowSorting || ej.gridFeatures.sort === undefined)
                    return;
                $target = $target.hasClass("e-headercelldiv") ? $target : $target.closest(".e-headercelldiv");
                var columnName = $target.attr("ej-mappingname");
                var columnSortDirection = ej.sortOrder.Ascending;
                this._$prevSElementTarget = this._$curSElementTarget;
                this._$curSElementTarget = $target;
                if ($target.find('span').hasClass("e-ascending"))
                    var columnSortDirection = ej.sortOrder.Descending;
                else
                    var columnSortDirection = ej.sortOrder.Ascending;
                if (e["pointerType"] == "touch" && this._customPop != null && !this._customPop.is(":visible") && this._customPop.find(".e-sortdirect").hasClass("e-spanclicked"))
                    this._customPop.show();
                if (e["pointerType"] == "touch" && this._customPop != null && (this._customPop.find(".e-rowselect").is(":visible") || !this._customPop.find(".e-sortdirect").hasClass("e-spanclicked")) && this.model.allowMultiSorting) {
                    var $offset = $target.offset();
                    this._customPop.removeAttr("style");
                    this._customPop.offset({ left: $offset.left, top: $offset.top - this.getHeaderTable().find(".e-columnheader").height() }).find(".e-sortdirect").show().end()
                        .find(".e-rowselect").hide().end().show();
                }
                if (this.model.allowMultiSorting && (e.ctrlKey || this._enableSortMultiTouch))
                    this.multiSortRequest = true;
                if (e.shiftKey && $.inArray(columnName, this.model.groupSettings.groupedColumns) == -1) {
                    this._removeSortedColumnFromCollection(columnName);
                    this.multiSortRequest = true;
                    columnName = null;
                }
                if (!ej.isNullOrUndefined(columnName))
                this.sortColumn(columnName, columnSortDirection);
            } else if ($target.hasClass("e-togglegroupbutton") && this.model.allowGrouping) {
                var field = $target.parent().attr("ej-mappingname");
                $target.hasClass("e-togglegroup") && this.groupColumn(field);
                $target.hasClass("e-toggleungroup") && this.ungroupColumn(field);
            } else if ($target.hasClass("e-filtericon") || $target.hasClass("e-filteredicon") || $target.hasClass('e-responsivefilterColDiv') || $target.parent().hasClass('e-responsivefilterColDiv')) {
                var columnName = $target.parent().find(".e-headercelldiv").attr("ej-mappingname") || $target.attr("ej-mappingname") || $($target.parent()).attr("ej-mappingname");
                this._$prevFieldName = this._$curFieldName;
                if (this.model.allowFiltering) {
                    var proxy = this;
                    $.each(this.model.columns, function (indx, col) {
                        if (col.field == columnName) {
                            proxy._$colType = col.type;
                            proxy._$curFieldName = col.field;
                            proxy._$colFormat = col.format;
                            proxy._$colForeignKeyField = col.foreignKeyField ? col.foreignKeyField : col.field;
                            proxy._$colForeignKeyValue = col.foreignKeyValue;
                            proxy._$colDropdownData = col.dataSource;
                        }
                    });
                    if (!this._isExcelFilter) {
                        var $id = "#" + this._id + "_" + this._$colType + "Dlg";
                        if (this._$colType == "string") {
                            if (this._$colForeignKeyValue && this._$colDropdownData)
                                $("#" + this._id + "_acString").ejAutocomplete({ fields: { text: proxy._$colForeignKeyValue, key: proxy._$colForeignKeyField }, dataSource: proxy._$colDropdownData });
                            else
                                $("#" + this._id + "_acString").ejAutocomplete({ fields: { text: proxy._$curFieldName, key: this._getIdField() }, dataSource: this._dataSource() });
                        } else if (this._$colType == "date") {
                            if (this._$colFormat != undefined) {
                                this._$colFormat = this._$colFormat.replace("{0:", "").replace("}", "");
                                $($id).find(".e-datewidget input").ejDatePicker({ dateFormat: this._$colFormat.replace("{0:", "").replace("}", "") });
                            }
                            else
                                $($id).find(".e-datewidget input").ejDatePicker({ dateFormat: "MM/dd/yyyy" });
                        }
                        else if (this._$colType == "datetime") {
                            if (this._$colFormat != undefined) {
                                this._$colFormat = this._$colFormat.replace("{0:", "").replace("}", "");
                                $($id).find(".e-datetimewidget input").ejDateTimePicker({ dateFormat: this._$colFormat.replace("{0:", "").replace("}", "") });
                            }
                            this._setFilterFieldValues($id);
                        }
                    }
                    this._mediaStatus = document.documentElement.clientWidth < 768;
                    if (this.model.isResponsive && this._mediaStatus) {
                        var gridObj = this;
                        var $headerDiv = ej.buildTag('div.e-resFilterDialogHeaderDiv');
                        var $titleSapn = ej.buildTag('div.labelRes', '<span>Filter</span>');
                        var $dlgBtn = ej.buildTag('div.e-filterMenuBtn');
                        var $inputOk = ej.buildTag('input.e-resposnsiveFilterBtnLeft');
                        var $inputCancel = ej.buildTag('input.e-resposnsiveFilterBtnRight');

                        $headerDiv.append($titleSapn);
                        $headerDiv.css('width', '100%');
                        var $dlgClone = $($id).css('padding-left', '0px');
                        if ($target.parent().hasClass('e-responsivefilterColDiv') && $target.hasClass('e-filternone')) {
                            proxy._fltrClrHandler();
                            $target.remove();
                            $("#responsiveFilter").css('display', 'block');
                            // this.element.css('display', 'block');
                        }
                        else {
                            this.element.css('display', 'none');
                            setTimeout(function () { $("#responsiveFilter").css('display', 'none'), 0 });
                            if (!this._isExcelFilter) {
                                var btnText = this.model.enableResponsiveRow ? 'OK' : 'Filter', clearText = this.model.enableResponsiveRow ? 'Cancel' : 'Clear';
                                $inputOk.ejButton({ text: btnText, type: 'button', click: $.proxy(this._fltrBtnHandler, this) });
                                $inputCancel.ejButton({
                                    text: clearText,type:'button', click: function () {
                                        if (clearText == 'Clear') {
                                            proxy.element.css('display', 'block');
                                            proxy._fltrClrHandler();
                                        }
                                        $($id).css('display', 'none');
										if($inputCancel.hasClass("e-resposnsiveFilterBtnRight"))
											proxy.element.css('display', 'block');
                                    }
                                });
                                if ($target.parent().hasClass('e-responsivefilterColDiv') && $target.hasClass('e-filternone')) {
                                    proxy._fltrClrHandler();
                                    $target.remove();
                                }
                                else {
                                    $dlgClone.addClass('e-resMenuFltr');
                                    $dlgClone.css('height', $(window).height() - 1).css('width', $(window).width() - 2);
                                    $dlgClone.find('.e-operator').addClass('e-resFilterOperator');
                                    $dlgClone.find('.e-value').addClass('e-resFilterOperator');
                                    var $btnContainer = $dlgClone.find('.e-dlgBtns').remove().addClass('e-filterMenuBtn');
                                    $dlgClone.append($dlgBtn.append($inputOk).append($inputCancel));
                                    if (ej.isNullOrUndefined($dlgClone.find('.e-resFilterDialogHeaderDiv')[0])) {
                                        $dlgClone.insertAfter(this.element);
                                        var $backIcon = ej.buildTag('div.e-resFilterleftIcon', '', {}, { closeDialogue: $id.slice(1), openDialogue: 'responsiveFilter' });
                                        var $spanIcon = ej.buildTag('span.e-icon e-resIcon e-responisveBack', '', {}, { closeDialogue: $id.slice(1), openDialogue: 'responsiveFilter' })
                                        $backIcon.click(function (e) {
                                           $dlgClone.css('display','none');
                                            if (gridObj.model.enableResponsiveRow)
                                               $("#responsiveFilter").css('display','block');
                                            else
                                               gridObj.element.css('display','block');
                                        })
                                        $headerDiv.append($backIcon.append($spanIcon));
                                        var $closeIcon = ej.buildTag('div.e-resFIlterRigthIcon', '', {}, { closeDialogue: $id.slice(1), gridEle: true });
                                        var $closeSpan = ej.buildTag('span.e-icon e-resIcon e-responisveClose', '', {}, { closeDialogue: $id.slice(1), gridEle: true })
                                        $closeIcon.click(function (e) {
                                            $dlgClone.css('display', 'none');
                                            gridObj.element.css('display', 'block');
                                        });
                                        var $ejWid = $($dlgClone.find('.e-value').find('input:last'));
                                        if (proxy._$colType == 'string') {
                                            var model = $($dlgClone.find('.e-value').find('input:last')).ejAutocomplete('model');
                                            $ejWid.ejAutocomplete('destroy').ejAutocomplete({enableDistinct:true, dataSource: model.dataSource, fields: model.fields, width: model.width, focusIn: function (args) { 
												var $dropdown = this.element.closest(".e-filterDialoge").find(".e-dropdownlist");
												this.model.filterType = $dropdown.val();
											}});
                                        }
                                        $headerDiv.append($closeIcon.append($closeSpan));
                                        $dlgClone.prepend($headerDiv);
                                    }
                                    $dlgClone.find('.e-responsiveLabelDiv').remove();
                                    var $label = ej.buildTag('div.e-responsiveLabelDiv', '', { 'margin-left': '5%', 'font-size': '17px', 'margin-top': '5%' }).append(ej.buildTag('span', this.getHeaderTextByFieldName(columnName), { 'font-weight': 'bold' }));
                                    $label.insertAfter($dlgClone.find('.e-resFilterDialogHeaderDiv'));
                                    $dlgClone.fadeIn(100, "easeOutQuad", function () {
                                    });
                                }
                            }
                            else {
                                this._excelDlg = $id = "#" + this._id + this._$colType + "_excelDlg";
                                if (ej.isNullOrUndefined($dlgClone.find('.e-resFilterDialogHeaderDiv')[0])) {
                                    $inputOk.ejButton({
                                        text: 'OK', type: 'button', click: function (sender) {
                                            gridObj._excelFilter._openedFltr = $(gridObj._excelDlg);
                                            gridObj._excelFilter._fltrBtnHandler();
                                            gridObj._setResponsiveFilterIcon();
                                            gridObj.element.css('display', 'block');
                                        }
                                    });
                                    $inputCancel.ejButton({ text: 'Cancel', type: 'button', click: function () { $($id).css('display', 'none'); proxy.element.css('display', 'block') } });
                                    $($id).children().not('.e-searchcontainer').remove();
                                    var excelObj = this._excelFilter;
                                    var $backIcon = ej.buildTag('div.e-resFilterleftIcon', '', {}, { closeDialogue: $id.slice(1), openDialogue: 'responsiveFilter' });
                                    var $spanIcon = ej.buildTag('span.e-icon e-resIcon e-responisveBack', '', {}, { closeDialogue: $id.slice(1), openDialogue: 'responsiveFilter' })
                                    $backIcon.click(function (e) {
                                        $.proxy(gridObj._closeDivIcon(e), this);
                                    })
                                    $headerDiv.append($backIcon.append($spanIcon));
                                    var $closeIcon = ej.buildTag('div.e-resFIlterRigthIcon', '', {}, { closeDialogue: $id.slice(1), gridEle: true });
                                    var $closeSpan = ej.buildTag('span.e-icon e-resIcon e-responisveCustomFilter', '', {}, { closeDialogue: $id.slice(1), gridEle: true })
                                    $closeIcon.click(function (e) {
                                        $.proxy(gridObj._closeDivIcon(e), this);
                                    })
                                    if (proxy._$colType != 'boolean')
                                        $headerDiv.append($closeIcon.append($closeSpan));
                                    $($id).css('padding', '0px');
                                    var $searchContainer = $($id).css('height', $(window).height() - 2);
                                    $searchContainer.css('width', $(window).width() - 2);
                                    var $searchBox = $searchContainer.find('.e-searchcontainer .e-searchbox').css('margin-top', '10px');
                                    $searchBox.children().css('margin-top', '10px');
                                    var $checkBoxDiv = $searchContainer.find('.e-checkboxlist');
                                    var scrolWidth = $(window).width() * (97 / 100), scrollHeight = $(window).height() * (65 / 100);
                                    $($searchContainer.find('.e-searchcontainer')).addClass('e-resSearch');
                                    var $btn = $searchContainer.find('.e-resSearch .e-btncontainer').remove();
                                    $btn.find('input:first').css('width', '45.6%');
                                    $btn.find('input:first').addClass('e-resposnsiveFilterBtnLeft');
                                    $btn.find('input:last').addClass('e-resposnsiveFilterBtnRight');
                                    $searchContainer.find('.e-excelLabel').remove();
                                    var $labelDiv = ej.buildTag('div.e-excelLabel', 'Order Id', { 'font-weight': 'bold', 'margin-top': '10px' });
                                    var $searchBox = $searchContainer.find('.e-searchcontainer');
                                    $labelDiv.insertAfter($searchContainer.find('.e-searchcontainer .e-searchbox'));
                                    $searchContainer.prepend($headerDiv);
                                    $($id).append($dlgBtn.append($inputOk).append($inputCancel))
                                    $checkBoxDiv.ejScroller({ height: scrollHeight, width: scrolWidth }).ejScroller('refresh');
                                }
                                this._excelFilter.openXFDialog({ field: columnName, enableResponsiveRow: true, displayName: this.getHeaderTextByFieldName(columnName), dataSource: this._dataSource(), position: { X: xPos, Y: yPos }, dimension: { height: $(window).height(), width: $(window).width() }, cssClass: "resFilter", type: this._$colType, format: this._$colFormat });
                                $($id).insertAfter(this.element);
                                !ej.isNullOrUndefined($($id).parents('.e-grid')[0]) && $($id).remove();
                                $closeIcon.click(function (e) {
                                    $(gridObj._excelDlg).css('display', 'none');
                                    var height = $(window).height() - 5, width = $(window).width();
                                    excelObj._openCustomFilter('equal');
                                    var $dlgClone = $id = $("#" + gridObj._id + gridObj._$colType + "_CustomFDlg").addClass('e-responsviesExcelFilter');
                                    if (ej.isNullOrUndefined($dlgClone.find('.e-resFilterDialogHeaderDiv')[0])) {
                                        var $headerDivCustom = ej.buildTag('div.e-resFilterDialogHeaderDiv');
                                        var $titleSapn = ej.buildTag('div.labelRes', '<span>Custom Filter</span>');
                                        $headerDivCustom.append($titleSapn);
                                        var $backIcon = ej.buildTag('div.e-resFilterleftIcon', '', {}, { closeDialogue: gridObj._id + gridObj._$colType + "_CustomFDlg", openDialogue: gridObj._excelDlg.slice(1) });
                                        var $spanIcon = ej.buildTag('span.e-icon e-resIcon e-responisveBack', '', {}, { closeDialogue: gridObj._id + gridObj._$colType + "_CustomFDlg", openDialogue: gridObj._excelDlg.slice(1) })
                                        $backIcon.click(function (e) {
                                            $dlgClone.css('display','none');
                                            if (gridObj.model.enableResponsiveRow)
                                               $("#responsiveFilter").css('display','block');
                                            else
                                                gridObj.element.css('display','block');
                                        });
                                        $headerDivCustom.append($backIcon.append($spanIcon));
                                        var $closeIconCust = ej.buildTag('div.e-resFIlterRigthIcon', '', {}, { closeDialogue: gridObj._id + gridObj._$colType + "_CustomFDlg", gridEle: true });
                                        var $closeSpan = ej.buildTag('span.e-icon e-resIcon e-responisveClose', '', {}, { closeDialogue: gridObj._id + gridObj._$colType + "_CustomFDlg", gridEle: true })
                                        $headerDivCustom.append($closeIconCust.append($closeSpan));
                                        $closeIconCust.click(function (e) {
                                            $dlgClone.css('display', 'none');
                                            gridObj.element.css('display', 'block');
                                        })
                                        $dlgClone.prepend($headerDivCustom);
                                        $dlgClone.insertAfter(gridObj.element);
                                        $dlgClone.find('.e-dlgfields').css('width', '100%');
                                        var $firstDiv = $dlgClone.find('.e-dlgfields:first').css('width', '92%').css('margin-left', '6%');
                                        $firstDiv.css('margin-top', '4%');
                                        var colName = $dlgClone.find('.e-dlgfields').find('.e-fieldset legend').text();
                                        var $labelDiv = ej.buildTag('div.e-responsiveLabelDiv', colName, { 'margin-left': '6%' });
                                        $labelDiv.insertAfter($firstDiv);
                                        var $fieldSet = $dlgClone.find('.e-dlgfields').find('.e-fieldset').find('table').css('width', '61%');
                                        $dlgClone.find('.e-dlgfields').find('.e-fieldset').replaceWith($fieldSet);
                                        var $fieldDiv = $fieldSet.parent('div').addClass('e-responsiveExcelFilterFieldDiv');
                                        var $ddl = $fieldSet.find('.e-dropdownlist')
                                        $fieldSet.find('.e-dropdownlist').each(function (index, object) {
                                            var ds = $(object).ejDropDownList('model.dataSource');
                                            var wid = $(window).width() * (40 / 100);
                                            $(object).ejDropDownList('destroy').ejDropDownList({ width: wid, popupWidth: wid + "px", dataSource: ds });
                                        });
                                        $fieldSet.find('.e-autocomplete').each(function (index, object) {
                                            var model = $(object).ejAutocomplete('model.dataSource');
                                            var wid = $(window).width() * (40 / 100);
                                            $(object).ejAutocomplete('destroy').ejAutocomplete({ width: wid, dataSource: model.dataSource, fields: model.fields });
                                        });
                                        $fieldSet.find('.e-datepicker').each(function (index, object) {
                                            var ds = $(object).ejDatePicker('model.dataSource');
                                            var wid = $(window).width() * (40 / 100);
                                            $(object).ejDatePicker('destroy').ejDatePicker({ width: wid });
                                        });
                                        var $okClone = $inputOk.clone(), $cancelClone = $inputCancel.clone();
                                        $okClone.ejButton({
                                            text: 'OK', type: 'button', click: function (sender) {
                                                gridObj._excelFilter._openedFltr = $dlgClone;
                                                gridObj._excelFilter._fltrBtnHandler();
                                                if ($dlgClone.hasClass('e-dlgcustom'))
                                                    $dlgClone.ejDialog('close');
                                                gridObj._setResponsiveFilterIcon();
                                                gridObj.element.css('display', 'block');
                                            }
                                        });
                                        $cancelClone.ejButton({ text: 'Cancel', type: 'button', click: function () { $dlgClone.ejDialog('close'); proxy.element.css('display', 'block') } });
                                        $dlgClone.append($dlgBtn.clone().append($okClone).append($cancelClone))
                                        var $btnContainer = $dlgClone.find('.e-dlgfields .e-btncontainer').remove();
                                        $btnContainer.find('input:first').addClass('e-resposnsiveFilterBtnLeft');
                                        $btnContainer.find('input:first').css('width', '45.6%')
                                        $btnContainer.find('input:last').addClass('e-resposnsiveFilterBtnRight');
                                    }
                                    gridObj.element.css('display', 'none');
                                    $dlgClone.ejDialog({ enableModal: false, height: height, width: width, position: { X: 0, Y: 0 }, enableResize: false, showHeader: false }).ejDialog('open');
                                })
                                var $searchdiv = ej.buildTag('div');
                            }
                        }
                    }
                    else {
                        $($id).ejDialog({ position: { X: "", Y: "" } });
                        var docWidth = $(document).width(), dlgWidth = document.documentElement.clientWidth < 800 ? 130 : 250, xPos = $target.position().left + 18, yPos = $target.position().top + 2;
                        var marginLeft = e.clientX - xPos;
                        if (docWidth - e.clientX <= dlgWidth)
                            xPos = docWidth - dlgWidth - marginLeft;
                        if (!this._isExcelFilter)
                            $($id).ejDialog({ position: { X: xPos, Y: yPos }, width: dlgWidth })
                            .ejDialog("open");
                        else
                            this._excelFilter.openXFDialog({ field: columnName, displayName: this.getHeaderTextByFieldName(columnName), dataSource: this._dataSource(), position: { X: xPos, Y: yPos }, type: this._$colType, format: this._$colFormat });
                    }
                    this._setFilterFieldValues($id);
                    if (this._$colType == "number")
                        $($id).find(".e-numerictextbox").ejNumericTextbox({ width: "100%" });
                    this._$prevColType = this._$colType;
                    this._$fDlgIsOpen = true;
                }
            }

            e.preventDefault();

        },
        _responsiveFilterClose: function () {
            this.element.css('display', 'block');
        },
        _clickHandler: function (e) {
            var $target = $(e.target), fieldName, $form = $("#" + this._id + "EditForm"), index, columnIndex, rowIndex;
            if ($target.hasClass("e-button") && ($target.hasClass("e-disable") || $target.prop("disabled"))) return;
            if ($target.closest(".e-grid").attr("id") !== this._id) return;
            if ($target.closest("#" + this._id + "EditForm").length)
                return;
            if ($target.hasClass("e-rowcell") || $target.closest("td").is(".e-rowcell") || ($target.hasClass("e-headercell") && ((e.clientY - $target.offset().top) < ($target.height() / 4)))) {
                if (this._bulkEditCellDetails.cancelSave) {
                    this._bulkEditCellDetails.cancelSave = false;
                    return;
                }
                if (this.model.editSettings.editMode == "batch" && ($.isFunction($.validator) && $form.length && $form.validate().errorList.length > 0))
                    return;
                this.model.editSettings.editMode == "batch" && this.element.focus();
                index = $target.closest("tr").hasClass("e-insertedrow") ? this.model.groupSettings.groupedColumns.length : 0;
                columnIndex = $target.hasClass("e-rowcell") ? $target.index() : $target.parent().index() - index;
                columnIndex = this.model.detailsTemplate != null||this.model.childGrid !=null ? columnIndex - 1 : columnIndex;
                rowIndex = this.getIndexByRow($target.closest("tr"));
                this._bulkEditCellDetails.columnIndex = columnIndex;
                this._bulkEditCellDetails.rowIndex = rowIndex;
                if (this.model.allowSelection && ej.gridFeatures.selection) {
                    if (this.model.selectionType == "multiple") {
                        if (e.ctrlKey || this._enableSelectMultiTouch) {
                            this.multiSelectCtrlRequest = true;
                        }
                        if (e.shiftKey) {
                            this._multiSelectShiftRequest = true;
                            if (this._allowcellSelection && rowIndex > -1)
                                this.selectCells([[rowIndex, [columnIndex]]]);
                            if (this._allowrowSelection) 
                                    this.selectRows(this._previousIndex, this.getIndexByRow($target.closest('tr')), $target);
                            if (this._allowcolumnSelection && $target.hasClass("e-headercell") && ((e.clientY - $target.offset().top) < ($target.height() / 4)))
                                this.selectColumns(this._previousColumnIndex, $target.index());
                        }
                        if (e["pointerType"] == "touch" && this._customPop != null && !this._customPop.is(":visible") && this._customPop.find(".e-rowselect").hasClass("e-spanclicked"))
                            this._customPop.show();
                        if (e["pointerType"] == "touch" && this._customPop != null && (this._customPop.find(".e-sortdirect").is(":visible") || !this._customPop.find(".e-rowselect").hasClass("e-spanclicked")) && this.model.selectionType == "multiple") {
                            this._customPop.removeAttr("style");
                            var offset = $target.offset();
                            this._customPop.offset({ top: 0, left: 0 }).offset({ left: offset.left, top: offset.top - this.getRowHeight() }).find(".e-sortdirect").hide().end()
                                .find(".e-rowselect").show().end().show();
                        }
                    }
                    if (!this._multiSelectShiftRequest) {
                        if (this._allowcellSelection && rowIndex > -1) {
                            if (this.model.selectionSettings.enableToggle && this.selectedRowCellIndexes.length == 1 &&
                                this.selectedRowCellIndexes[0].rowIndex == rowIndex && this.selectedRowCellIndexes[0].cellIndex.length == 1 &&
                                parseInt(this.selectedRowCellIndexes[0].cellIndex) == columnIndex)
                                this.clearCellSelection();
                            else
                                this.selectCells([[rowIndex, [columnIndex]]]);
                        }
                        if (this._allowrowSelection && rowIndex > -1) {
                            if (this.model.selectionSettings.enableToggle && this.getSelectedRecords().length == 1 && $.inArray(this.getIndexByRow($target.closest('tr')), this.selectedRowsIndexes) != -1)
                                this.clearSelection(this.getIndexByRow($target.closest('tr')));
                            else
                                this.selectRows(this.getIndexByRow($target.closest('tr')), null, $target);
                        }
                        if (this._allowcolumnSelection && $target.hasClass("e-headercell") && ((e.clientY - $target.offset().top) < ($target.height() / 4))) {
                            if (this.model.selectionSettings.enableToggle && this.selectedColumnIndexes.length == 1 && $.inArray($target.index(), this.selectedColumnIndexes) != -1)
                                this.clearColumnSelection($target.index());
                            else
                                this.selectColumns($target.index());
                        }
                        this.multiSelectCtrlRequest = false;
                    }
                    this._multiSelectShiftRequest = false;
                }
				
                fieldName = this.model.columns[this._bulkEditCellDetails.columnIndex]["field"];
                if (fieldName)
                    this.model.editSettings.allowEditing && this.model.editSettings.editMode == ej.Grid.EditMode.Batch && this.editCell($.inArray($target.closest("tr").get(0), this.getRows()), fieldName);
            }
            if ($target.hasClass("e-rowselect") || $target.hasClass("e-sortdirect")) {
                if (!$target.hasClass("e-spanclicked")) {
                    $target.addClass("e-spanclicked");
                    if ($target.hasClass("e-rowselect"))
                        this._enableSelectMultiTouch = true;
                    if ($target.hasClass("e-sortdirect"))
                        this._enableSortMultiTouch = true;
                } else {
                    $target.removeClass("e-spanclicked");
                    if ($target.hasClass("e-rowselect"))
                        this._enableSelectMultiTouch = false;
                    if ($target.hasClass("e-sortdirect"))
                        this._enableSortMultiTouch = false;
                    this._customPop.hide();
                }
            }			
            if (ej.gridFeatures.common) {
                this.expandCollapse($target);
            if (this.model.childGrid && $target.hasClass("e-gdiagonalnext") || $target.hasClass("e-gnextforward"))
                e.stopPropagation();
            }
			if ($target.is(".e-filtericon") && $target.closest(".e-detailrow").length != 0)
                e.stopPropagation();
            if (this.model.allowFiltering && (this.model.filterSettings.filterType == "menu" || this._isExcelFilter) && !$target.is(".e-filtericon") && $target.closest(".e-dlgcontainer").length != 1)
                !this._isExcelFilter ? this._closeFilterDlg() : this._excelFilter.closeXFDialog(e);
        },
        /**
         * Destroy the grid widget
		 * all events bound using this._on will be unbind automatically and bring the control to pre-init state.
		 * @alias ejGrid#destroy
		 * @return jQuery
		 * @example 
		 * &lt;script&gt;
		 * var gridObj = $("#Grid").data("ejGrid");
		 * gridObj.destroy(); // destroy the Grid
		 * &lt;/script&gt;
		 * @example 
		 * &lt;script&gt;
		 * // destroy the Grid
		 * $("#Grid").ejGrid("destroy");        
		 * &lt;/script&gt;
         */
        _destroy: function () {
            /// <summary>This function is  used to destroy the Grid Object</summary>
            this.element.find(".e-gridheader").find(".e-headercontent,.e-movableheader")
                .add(this.getContent().find(".e-content,.e-movablecontent")).unbind('scroll');
            var editForm = $("#" + this._id + "EditForm");
            if (editForm.length) {
                var $formEle = editForm.find('.e-field'), $element;
                for (var i = 0; i < $formEle.length; i++) {
                    $element = $($formEle[i]);
                    if ($element.hasClass('e-datetimepicker'))
                        $element.ejDateTimePicker("destroy");
                    else if ($element.hasClass('e-datepicker'))
                        $element.ejDatePicker("destroy");
                    else if ($element.hasClass('e-dropdownlist'))
                        $element.ejDropDownList("destroy");
                }
                editForm.remove();
            }
            if (this._confirmDialog)
                this._confirmDialog.ejDialog("destroy");
            if (this.model.allowFiltering && this.model.filterSettings.filterType == "menu") {
                var proxy = this, $colType;
                $.each(this.model.columns, function (indx, col) {
                    $colType = col.type;
                    $("#" + proxy._id + $colType + "_ddinput_popup_wrapper").remove();
                    if ($colType == "string")
                        $("#" + proxy._id + "_stringDlg").find('.e-autocomplete').ejAutocomplete("destroy");
                    else if ($colType == "date")
                        $("#" + proxy._id + "_dateDlg").find('.e-datepicker').ejDatePicker("destroy");
                    else if ($colType == "datetime")
                        $("#" + proxy._id + "_datetimeDlg").find('.e-datetimepicker').ejDateTimePicker("destroy");
                    else if ($colType == "number")
                        $("#" + proxy._id + "_numberDlg").find('.e-numerictextbox').ejNumericTextbox("destroy");
                });
            }
            if (this._$onresize)
                $(window).unbind("resize", this._$onresize);
            this.element.empty().removeClass("e-grid " + this.model.cssClass);
            this.element.ejWaitingPopup("destroy");
        },
        _getLocalizedLabels: function (property) {
            return (ej.Grid.locale[this.model.locale] === undefined || ej.Grid.locale[this.model.locale][property] === undefined) ? ej.Grid.locale["en-US"][property] : ej.Grid.locale[this.model.locale][property];
        },
    });
    if (ej.gridFeatures.common)
        $.extend(ej.Grid.prototype, ej.gridFeatures.common);
    if (ej.gridFeatures.edit)
        $.extend(ej.Grid.prototype, ej.gridFeatures.edit);
    if (ej.gridFeatures.filter)
        $.extend(ej.Grid.prototype, ej.gridFeatures.filter);
    if (ej.gridFeatures.group)
        $.extend(ej.Grid.prototype, ej.gridFeatures.group);
    if (ej.gridFeatures.selection)
        $.extend(ej.Grid.prototype, ej.gridFeatures.selection);
    if (ej.gridFeatures.sort)
        $.extend(ej.Grid.prototype, ej.gridFeatures.sort);
    if (ej.gridFeatures.dragAndDrop)
        $.extend(ej.Grid.prototype, ej.gridFeatures.dragAndDrop);

    ej.Grid.locale = {};

    ej.Grid.locale["en-US"] = {
        EmptyRecord: "No records to display",
        GroupDropArea: "Drag a column header here to group its column",
        DeleteOperationAlert: "No records selected for delete operation",
        EditOperationAlert: "No records selected for edit operation",
        SaveButton: "Save",
        OkButton: "OK",
        CancelButton: "Cancel",
        EditFormTitle: "Details of ",
        AddFormTitle: "Add New Record",
        Notactionkeyalert: "This Key-Combination is not avaiable",
        Keyconfigalerttext: "This Key-Combination has already been assigned to ",
        GroupCaptionFormat: "items",
        BatchSaveConfirm: "Are you sure you want to save changes?",
        BatchSaveLostChanges: "Unsaved changes will be lost. Are you sure you want to continue?",
        ConfirmDelete: "Are you sure you want to Delete Record?",
        PagerInfo: "{0} of {1} pages ({2} items)",
        FrozenColumnsViewAlert: "Frozen columns should be in grid view area",
        FrozenColumnsScrollAlert: "Enable allowScrolling while using frozen Columns",
        FrozenNotSupportedException: "Frozen Columns and Rows are not supported for Grouping, Row Template, Detail Template and Batch Editing",
        Add: "Add",
        Edit: "Edit",
        Delete: "Delete",
        Update: "Update",
        Cancel: "Cancel",
        PrintGrid: "Print",
        ExcelExport: "Excel Export",
        WordExport: "Word Export",
        PdfExport: "PDF Export",
        StringMenuOptions: [{ text: "StartsWith", value: "StartsWith" }, { text: "EndsWith", value: "EndsWith" }, { text: "Contains", value: "Contains" }, { text: "Equal", value: "Equal" }, { text: "NotEqual", value: "NotEqual" }],
        NumberMenuOptions: [{ text: "LessThan", value: "LessThan" }, { text: "GreaterThan", value: "GreaterThan" }, { text: "LessThanOrEqual", value: "LessThanOrEqual" }, { text: "GreaterThanOrEqual", value: "GreaterThanOrEqual" }, { text: "Equal", value: "Equal" }, { text: "NotEqual", value: "NotEqual" }],
        PredicateAnd: "AND",
        PredicateOr: "OR",
        Filter: "Filter",
        MatchCase: "Match Case",
        Clear: "Clear",
        ResponsiveFilter: "Filter",
        ResponsiveSorting: "Sort",
        Search: "Search",
        DatePickerWaterMark: "Select date"
    };
    ej.Grid.Actions = {
        /** Used to specify paging action in grid   */
        Paging: "paging",
        /** Used to specify sorting action in grid   */
        Sorting: "sorting",
        /** Used to specify filtering action in grid   */
        Filtering: "filtering",
        /** Used to specify begin edit action in grid   */
        BeginEdit: "beginedit",
        /** Used to specify saving action in grid   */
        Save: "save",
        /** Used to specify adding action in grid   */
        Add: "add",
        /** Used to specify deleting action in grid   */
        Delete: "delete",
        /** Used to specify cancelling action in grid   */
        Cancel: "cancel",
        /** Used to specify grouping action in grid   */
        Grouping: "grouping",
        /** Used to specify un-grouping action in grid   */
        Ungrouping: "ungrouping",
        /** Used to specify refresh action in grid   */
        Refresh: "refresh",
        /** Used to specify reordering action in grid   */
        Reorder: "reorder",
        /** Used to specify searching action in grid   */
        Search: "searching",
        /** Used to specify batch save action in grid   */
        BatchSave: "batchsave",
        /** Used to specify virtual scroll action in grid   */
        VirtualScroll: "virtualscroll"
    };
    /**
     * Enum for various grid summary type	 
     * @enum {string}
     * @global 
     */
    ej.Grid.SummaryType = {
        /**  Creates grid with summary type as Average */
        Average: "average",
        /**  Creates grid with summary type as Minimum */
        Minimum: "minimum",
        /**  Creates grid with summary type as Maximum */
        Maximum: "maximum",
        /**  Creates grid with summary type as Count */
        Count: "count",
        /**  Creates grid with summary type as Sum */
        Sum: "sum",
        /**  Creates grid with summary type as TrueCount */
        TrueCount: "truecount",
        /**  Creates grid with summary type as FalseCount */
        FalseCount: "falsecount",
        /**  Creates grid with summary type as Custom */
        Custom: "custom"
    };
    /**
	 * Enum for specifying edit mode in grid 
	 * @enum {string}
	 * @global 
	 */
    ej.Grid.EditMode = {
        /**  Creates grid with editMode as Normal */
        Normal: "normal",
        /**  Creates grid with editMode as Dialog */
        Dialog: "dialog",
        /**  Creates grid with editMode as DialogTemplate */
        DialogTemplate: "dialogtemplate",
        /**  Creates grid with editMode as Batch */
        Batch: "batch",
        /**  Creates grid with editMode as ExternalForm */
        ExternalForm: "externalform",
        /**  Creates grid with editMode as ExternalFormTemplate */
        ExternalFormTemplate: "externalformtemplate",
        /**  Creates grid with editMode as InlineForm */
        InlineForm: "inlineform",
        /**  Creates grid with editMode as InlineTemplateForm */
        InlineTemplateForm: "inlineformtemplate"
    };

    /**
      * Enum for specifying row position in grid 
      * @enum {string}
      * @global 
      */
    ej.Grid.Rowposition = {
        /** Add new row in the top of the grid */
        Top: "top",
        /** Add new row in the bottom of the grid */
        Bottom: "bottom",
    };
    /**
	 * Enum for specifying form position in grid 
	 * @enum {string}
	 * @global 
	 */
    ej.Grid.FormPosition = {
        /**  Creates grid with formPosition as BottomLeft */
        BottomLeft: "bottomleft",
        /**  Creates grid with formPosition as TopRight */
        TopRight: "topright"
    };
    /**
	 * Enum for specifying various editing type in grid	 
	 * @enum {string}
	 * @global 
	 */
    ej.Grid.EditingType = {
        /**  Allows to set edit type as string edit type */
        String: "stringedit",
        /**  Allows to set edit type as boolean edit type */
        Boolean: "booleanedit",
        /**  Allows to set edit type as numeric edit type */
        Numeric: "numericedit",
        /**  Allows to set edit type as drop down edit type */
        Dropdown: "dropdownedit",
        /**  Allows to set edit type as date picker edit type */
        DatePicker: "datepicker",
        /**  Allows to set edit type as date time picker edit type */
        DateTimePicker: "datetimepicker",
    };
    /**
	 * Enum for specifying various unbound type in grid	 
	 * @enum {string}
	 * @global 
	 */
    ej.Grid.UnboundType = {
        /** Used to specify unbound type as Edit   */
        Edit: "edit",
        /** Used to specify unbound type as Save   */
        Save: "save",
        /** Used to specify unbound type as Delete   */
        Delete: "delete",
        /** Used to specify unbound type as Cancel   */
        Cancel: "cancel"
    };
    /**
	 * Enum for specifying various tool bar items in grid	 
	 * @enum {string}
	 * @global 
	 */
    ej.Grid.ToolBarItems = {
        /** Used to add toolbar item for adding records    */
        Add: "add",
        /** Used to add toolbar item for editing records    */
        Edit: "edit",
        /** Used to add toolbar item for deleting records    */
        Delete: "delete",
        /** Used to add toolbar item for updating records    */
        Update: "update",
        /** Used to add toolbar item for cancelling records    */
        Cancel: "cancel",
        /** Used to add toolbar item for searching records    */
        Search: "search",
        /** Used to add toolbar item for printing grid    */
        PrintGrid: "printGrid",
         /** Used to add toolbar item for exproting grid to excel    */
        ExcelExport: "excelExport",
        /** Used to add toolbar item for exporting grid to word    */
        WordExport: "wordExport",
        /** Used to add toolbar item for exporting grid to pdf    */
        PdfExport: "pdfExport"
    };
    /**
     * Enum for various grid filtering type	 
     * @enum {string}
     * @global 
     */
    ej.Grid.FilterType = {
        /**  Creates grid with filtering type as Menu */
        Menu: "menu",
        /**  Creates grid with filtering type as FilterBar */
        FilterBar: "filterbar",
        /** Creates grid with filtering type as Excel */
        Excel: "excel"
    };

    /**
	 * Enum for specifying various filter bar mode in grid	 
	 * @enum {string}
	 * @global 
	 */
    ej.Grid.FilterBarMode = {
        /** Used to set filter bar mode as Immediate mode */
        Immediate: "immediate",
        /** Used to set filter bar mode as OnEnter mode */
        OnEnter: "onenter"
    };
    /**
     * Enum for various selection type in grid 
     * @enum {string}
     * @global 
     */
    ej.Grid.SelectionType = {
        /**  Support for Single selection only in grid */
        Single: "single",
        /**  Support for multiple selections in grid */
        Multiple: "multiple"
    };
     /**
     * Enum for various virtual scroll mode in grid 
     * @enum {string}
     * @global 
     */
    ej.Grid.VirtualScrollMode = {
        /** Used to set the Normal mode virtual paging*/
        Normal: "normal",
        /** Used to set the Continuous mode virtual paging*/
        Continuous: "continuous"
    };
    /**
    * Enum for various selection mode in grid 
    * @enum {string}
    * @global 
    */
    ej.Grid.SelectionMode = {
	    /**  Support for Row selection in grid */
        Row: "row",
        /**  Support for Cell selection in grid */
        Cell: "cell",       
        /**  Support for Column selection in grid */
        Column: "column"
    };
})(jQuery, Syncfusion);